(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3474077,      62058]*)
(*NotebookOutlinePosition[   3474775,      62082]*)
(*  CellTagsIndexPosition[   3474731,      62078]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Another histogram modeling example", "Title"],

Cell[TextData[{
  "This notebook illustrates Gaussian mixture modeling for some 2d synthetic \
data, and assumes that the definitions in the notebook \"",
  StyleBox["statistical_modeling.nb",
    FontColor->RGBColor[1, 0, 0]],
  "\" have already been evaluated."
}], "Text"],

Cell[CellGroupData[{

Cell["Global user definitions", "Section"],

Cell[CellGroupData[{

Cell["Colors representing two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Data colors", "Subsubsection"],

Cell[BoxData[{
    \(\(data1Color = Red;\)\), "\[IndentingNewLine]", 
    \(\(data2Color = Blue;\)\), "\[IndentingNewLine]", 
    \(\(centroidColor\  = \ Magenta;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\(style1\  = \ {data1Color, 
          PointSize[ .02]};\)\), "\[IndentingNewLine]", 
    \(\(style2\  = \ {data2Color, 
          PointSize[ .02]};\)\), "\[IndentingNewLine]", 
    \(\(centroidStyle\  = \ {centroidColor, PointSize[ .02]};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification region colors", "Subsubsection"],

Cell[BoxData[{
    \(\(class1Color\  = \ RGBColor[1, 1,  .5];\)\), "\[IndentingNewLine]", 
    \(\(class2Color\  = \ RGBColor[ .5, 1, 1];\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(classColors\  = \ {class1Color, \ class2Color};\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Default plot range", "Subsection"],

Cell[BoxData[
    \(\(pr\  = \ {{0, 1}, {0, 1}};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["No frame ticks", "Subsection"],

Cell[BoxData[{
    \(\(nF = FrameTicks \[Rule] None;\)\), "\[IndentingNewLine]", 
    \(\(FS = Sequence[yS, \ nF];\)\)}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Local definitions", "Section"],

Cell[CellGroupData[{

Cell["Specialized data generation and visualization functions", "Subsection"],

Cell[BoxData[
    \(\(AnnularRegion[center_, \ r1_, \ r2_, \ n_] := 
        Module[{tst, x1, x2, count, xd, t1, t2, range1, \ 
            range2}, {x1, x2}\  = \ 
            center; \[IndentingNewLine]range1\  = \ {x1\  - \ r2, \ 
              x1 + \ r2}; \[IndentingNewLine]range2\  = \ {x2\  - \ r2, \ 
              x2\  + \ r2}; \[IndentingNewLine]count\  = \ 
            1; \[IndentingNewLine]xd\  = \ 
            Table[0, \ {n}]; \[IndentingNewLine]While[
            count\  <= \ 
              n, {t1, t2}\  = \ {Random[Real, \ range1], \ 
                Random[Real, \ range2]}; 
            If[\((tst\  = 
                      Sqrt[\((t1 - x1)\)^2\  + \ \((t2 - x2)\)^2])\)\  < \ 
                  r2\  && \ tst\  > \ r1, 
              xd[\([\(count++\)]\)]\  = \ {t1, 
                  t2}]\[IndentingNewLine]]; \[IndentingNewLine]xd\
\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(AntiAnnularRegion[center_, \ r1_, \ r2_, \ n_] := 
        Module[{tst, x1, x2, count, xd, t1, t2, range1, \ 
            range2}, {x1, x2}\  = \ 
            center; \[IndentingNewLine]range1\  = \ {0, \ 
              1}; \[IndentingNewLine]range2\  = \ {0, 
              1}; \[IndentingNewLine]count\  = \ 
            1; \[IndentingNewLine]xd\  = \ 
            Table[0, \ {n}]; \[IndentingNewLine]While[
            count\  <= \ 
              n, {t1, t2}\  = \ {Random[Real, \ range1], \ 
                Random[Real, \ range2]}; 
            If[\((tst\  = 
                      Sqrt[\((t1 - x1)\)^2\  + \ \((t2 - x2)\)^2])\)\  > \ 
                  r2\  || \ tst\  < \ r1, 
              xd[\([\(count++\)]\)]\  = \ {t1, 
                  t2}]\[IndentingNewLine]]; \[IndentingNewLine]xd\
\[IndentingNewLine]];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Region definitions", "Subsubsection"],

Cell[BoxData[
    \(\(\(\(c1\  = \ { .5,  .5};\) (*\ 
      center\ of\ annular\ region\ *) \[IndentingNewLine]
    \(rr1\  = \  .12;\) (*\ inner\ radius\ *) \[IndentingNewLine]
    \(rr2\  = \  .35;\)\)\( (*\ outer\ radius\ *) \)\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(DrawAnnularRegion2[center_, r1_, r2_, pr_, \ color_:  LightPink, \ 
          color2_:  White, 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[\[IndentingNewLine]Graphics[{{color, 
                  Disk[center, \ r2]}, {color2, Disk[center, r1]}}], \ 
            AspectRatio \[Rule] Automatic, \ 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, 
            Frame \[Rule] True, opt]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(specialClassPlot\  := 
        Show[Graphics[{class1Color, 
              Rectangle[{0, 0}, {1, 1}]}], \ \ DrawAnnularRegion2[c1, rr1, 
            rr2, \ pr, class2Color, \ class1Color, nS]\ , 
          AspectRatio -> Automatic, \ Frame \[Rule] True, \ nF];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize annular region in 2d", "Subsection"],

Cell[CellGroupData[{

Cell["Draw annular region in 2d", "Subsubsection"],

Cell[BoxData[
    \(\(DrawAnnularRegion[center_, r1_, r2_, pr_, \ color_:  LightPink, \ 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[\[IndentingNewLine]Graphics[{{color, 
                  Disk[center, \ r2]}, {GrayLevel[1. ], 
                  Disk[center, r1]}}], \ AspectRatio \[Rule] Automatic, \ 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, 
            Frame \[Rule] True, opt]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot multiple results for annular region", "Subsubsection"],

Cell[BoxData[
    \(\(AnnularAllPlot[center_, \ r1_, \ 
          r2_, \ {\[Mu]_, \[CapitalSigma]_, 
            priors_}] := \[IndentingNewLine]Module[{pr, g1, g2, g3, g4, g5, 
            ga, gb}, \[IndentingNewLine]pr\  = \ {{0, 1}, {0, 
                1}}; \[IndentingNewLine]g1\  = \ \ DrawAnnularRegion[center, 
              rr1, rr2, \ pr, LightPink, \ nF, 
              nS]; \[IndentingNewLine]g2\  = \ 
            PlotMeans[{\[Mu], \[CapitalSigma], priors}, \ pr, \ Blue, \ nF, 
              nS]; \[IndentingNewLine]g3\  = \ 
            PlotContourPDFOverlay[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              nF, nS]; \[IndentingNewLine]g4\  = \ 
            PlotContourPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, nF, 
              nS]; \[IndentingNewLine]g5\  = \ 
            PlotPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              Axes \[Rule] False, nS]; \[IndentingNewLine]ga\  = \ 
            Show[g1, g2]; \[IndentingNewLine]gb\  = \ 
            Show[g1, g3]; \[IndentingNewLine]Show[
            GraphicsArray[{{ga, gb}, {g4, g5}}], yS, \ 
            imSize]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Data generation and visualization", "Section"],

Cell[CellGroupData[{

Cell["Idealized data classes", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(idealPlot\  = \ specialClassPlot;\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 1 .5 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.5 1 1 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
1 1 .5 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooo
ooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6oooo
o`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003ooooooooo
o`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglC
ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
ooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001oooo
o`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooo
oglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1
o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
0oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4ooo
ogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001
ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003o
ooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
oooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_oo
ool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool0
0003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo
4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?o
oooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo
1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000oooo
ooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooo
oomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooon6ooooO`P0OoooQ?ooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?oooooN_oooglP07ooogSooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooogGooomo:@1ooomdooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooom`ooooOc<0OoooKoooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
K_oooglg07ooofgooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooof[ooomo@01o
oomXooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooomWooooOdD0OoooI_ooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooIOooogm907ooofCooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooof?ooomoC@1ooomRooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooomQooooOe40OoooH?ooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?oooooGoooogmF07oooegooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
oooooecooomoF`1ooomKooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooomJoooo
Oel0OoooFOooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooF?ooogmS07oooeOo
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooeOooomoI@1ooomFooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooomFooooOfL0OoooEOooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?oooooE?ooogm[07oooe?ooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooooe;ooomoK`1ooomAooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooomAooooOg40OoooD?ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
D?ooogmc07ooodoooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooodkooomoM`1o
oom=ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooom=ooooOgP0OoooCOooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooCOooogmi07ooodcooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03oooood_ooomoO@1ooom:ooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooom:ooooOgl0OoooBOooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?oooooBOooogn107ooodSooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooodSooomoP`1ooom7ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooom7oooo
OhD0OoooA_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooA_ooogn707ooodGo
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooodGooomoR@1ooom4ooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooom4ooooOh/0Oooo@oooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo@oooogn=07oood;ooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooood;ooomoS`1ooom1ooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooom1ooooOi00Oooo@Oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
@OooognA07oood3ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocoooomoU@1o
oolnooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolnooooOiH0Oooo?_ooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo?_ooognG07ooocgooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooocgooomoV@1ooollooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooollooooOi/0Oooo>oooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo>oooognL07oooc_ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
oooooc_ooomoW@1oooljooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooljoooo
Oih0Oooo>_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo>_ooognO07ooocWo
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocWooomoX@1ooolhooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooolhooooOj<0Oooo=oooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo=oooognT07ooocOooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooocOooomoY@1ooolfooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooolfooooOjH0Oooo=_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
=_ooognW07ooocGooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocGooomoZ01o
ooleooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooleooooOjT0Oooo=?ooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=?ooognZ07ooocCooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooocCooomoZ`1ooolcooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooolcooooOj`0Oooo<oooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo<oooogn/07oooc?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
oooooc?ooomo[@1ooolbooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolboooo
Ojh0Oooo<_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo<_ooogn_07oooc7o
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooc7ooomo/01ooolaooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooolaooooOk40Oooo<?ooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo<?ooognb07oooc3ooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooooc3ooomo/`1oool_ooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00oooool_ooooOeD0Oooo2`3oogmD07oooboooomo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03oooooboooomoD@1ooolC0?ooOe40Oooo;_ooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo;_ooogm?07oooaX0oomoC@1oool^ooooO`Kooooo0Ol00001ooooo`0000?o0000
ooooooooool00oooool^ooooOdd0Oooo7@3oogm<07ooobkooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooobkooomoC01ooolQ0?ooOdT0Oooo;_ooogl6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooo;_ooogm:07ooob@0oomoB01oool^ooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00oooool^ooooOdL0Oooo:03oogm807ooobgooomo1_ooool1o`00007ooooo
00000ol0003oooooooooo`03ooooobgooomoA`1ooolZ0?ooOdL0Oooo;Oooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo;Oooogm607ooob`0oomoA`1oool/ooooO`Kooooo0Ol00001
ooooo`0000?o0000ooooooooool00oooool/ooooOdL0Oooo;@3oogm607ooobcooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooobcooomoAP1oool_0?ooOdD0Oooo;?ooogl6ooooo`7o
00000Oooool00003o`000?oooooooooo00?ooooo;?ooogm507oooc40oomoA01oool/ooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00oooool/ooooOd@0Oooo<P3oogm407ooobcooomo1_oo
ool1o`00007ooooo00000ol0003oooooooooo`03ooooobcooomo@`1ooold0?ooOd@0Oooo:oooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo:oooogm407ooocD0oomo@`1oool[oooo
O`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool[ooooOd<0Oooo=`3oogm207ooob_o
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooob_ooomo@P1oooli0?ooOd40Oooo
:oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo:oooogm207ooocT0oomo@P1o
oolZooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolZooooOd80Oooo>`3oogm1
07ooob[ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooob[ooomo@@1oooll0?oo
Od40Oooo:_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo:_ooogm107oooc`0
oomo@@1ooolZooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolZooooOd00Oooo
?P3oogm007ooob[ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooob[ooomo@01o
ooln0?ooOd00Oooo:_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo:_ooogm0
07oooch0oomo@01ooolZooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolZoooo
Od00Oooo?`3ooglo07ooob[ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooob[o
oomo?`1ooom00?ooOcl0Oooo:_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
:_oooglo07oood00oomo?`1ooolZooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
oolZooooOcl0Oooo@03ooglo07ooob[ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooob[ooomo?`1ooom00?ooOcl0Oooo:_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo
00?ooooo:_oooglo07oood40oomo?`1ooolYooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooolYooooOcl0Oooo@P3ooglo07ooobWooomo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03ooooobWooomo?`1ooom20?ooOcl0Oooo:Oooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo:Ooooglo07oood80oomo?`1ooolYooooO`Kooooo0Ol00001ooooo`0000?o0000
ooooooooool00ooooolYooooOcl0Oooo@P3ooglo07ooobWooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooobWooomo?`1ooom20?ooOcl0Oooo:Oooogl6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooo:Ooooglo07oood80oomo?`1ooolYooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooolZooooOch0Oooo@P3ooglo07ooobWooomo1_ooool1o`00007ooooo
00000ol0003oooooooooo`03ooooob[ooomo?`1ooom10?ooOch0Oooo:_ooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo:_oooglo07oood00oomo?`1ooolZooooO`Kooooo0Ol00001
ooooo`0000?o0000ooooooooool00ooooolZooooOcl0Oooo@03ooglo07ooob[ooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooob[ooomo?`1ooom00?ooOcl0Oooo:_ooogl6ooooo`7o
00000Oooool00003o`000?oooooooooo00?ooooo:_oooglo07oood00oomo?`1ooolZooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooolZooooOd00Oooo?`3ooglo07ooob[ooomo1_oo
ool1o`00007ooooo00000ol0003oooooooooo`03ooooob[ooomo@01oooln0?ooOd00Oooo:_ooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo:_ooogm007oooch0oomo@01ooolZoooo
O`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolZooooOd40Oooo?@3oogm007ooob[o
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooob[ooomo@@1oooll0?ooOd40Oooo
:_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo:_ooogm107oooc`0oomo@@1o
oolZooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool[ooooOd40Oooo>P3oogm2
07ooob[ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooob_ooomo@P1oooli0?oo
Od40Oooo:oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo:oooogm207ooocP0
oomo@P1oool[ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool[ooooOd<0Oooo
=P3oogm307ooob_ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooob_ooomoA01o
oole0?ooOd<0Oooo:oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo;?ooogm4
07oooc<0oomoA01oool[ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool/oooo
OdD0Oooo<@3oogm407ooobcooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooobco
oomoA@1oool`0?ooOdD0Oooo;?ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
;?ooogm607ooobh0oomoAP1oool/ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
ool/ooooOdL0Oooo;03oogm707ooobcooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooobgooomoB01ooolY0?ooOdP0Oooo;?ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo
00?ooooo;Oooogm907ooobL0oomoB01oool]ooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00oooool^ooooOd/0Oooo8`3oogm907ooobgooomo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03ooooobkooomoC@1ooolO0?ooOdX0Oooo;_ooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo;_ooogm>07oooa/0oomoC@1oool^ooooO`Kooooo0Ol00001ooooo`0000?o0000
ooooooooool00oooool^ooooOe40Oooo5`3oogm>07ooobkooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooooboooomoD@1ooolC0?ooOe40Oooo;_ooogl6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooo;oooogmF07ooo`T0oomoE@1oool_ooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00oooool_ooooOk@0Oooo;oooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo<?ooognc07oooboooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
oooooc3ooomo/P1oool`ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolaoooo
Ok40Oooo<?ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo<Oooogn`07oooc7o
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooc;ooomo[`1ooolaooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooolbooooOjh0Oooo<_ooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo<oooogn]07oooc;ooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooooc?ooomo[01ooolcooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00oooooldooooOj/0Oooo<oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
=?ooognZ07ooocCooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocCooomoZP1o
ooldooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooleooooOjT0Oooo=?ooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=OooognX07ooocGooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooocKooomoY`1oooleooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooolfooooOjH0Oooo=_ooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo=oooognU07ooocKooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooocSooomoX`1ooolgooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolioooo
Oj40Oooo>?ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo>OooognP07ooocWo
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooc[ooomoW`1oooliooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00oooooljooooOih0Oooo>_ooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo>oooognM07oooc[ooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooooccooomoV`1ooolkooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooolmooooOiT0Oooo??ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
?OooognH07ooocgooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooockooomoU`1o
oolmooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooom0ooooOi<0Oooo?oooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo@?ooognB07oood3ooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03oooood7ooomoT@1ooom0ooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooom2ooooOhl0Oooo@Oooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo@oooogn=07oood;ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooodCooomoR`1ooom3ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooom5oooo
OhT0OoooA?ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooA_ooogn707ooodGo
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooodOooomoQ@1ooom6ooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooom8ooooOh<0OoooAoooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?oooooBOooogn107ooodSooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooood[ooomoO`1ooom9ooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooom<ooooOg/0OoooBoooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
C?ooogmj07ooodcooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooodgooomoN@1o
oom<ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooom?ooooOgD0OoooC_ooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooD?ooogmc07ooodoooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03oooooe7ooomoL@1ooom@ooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooomCooooOfd0OoooD_ooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?oooooEOooogmY07oooeCooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
oooooeKooomoI`1ooomEooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooomGoooo
OfD0OoooE_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooFOooogmQ07oooeSo
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooe_ooomoG@1ooomJooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooomMooooOeT0OoooG?ooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?oooooH?ooogmD07oooekooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooof;ooomoC`1ooomQooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooomTooooOd/0OoooHoooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
I_ooogm707ooofGooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooofSooomo@`1o
oomWooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooom[ooooOch0OoooJOooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooKoooogle07ooofkooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooog7ooomo<@1ooom`ooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooomfooooObL0OoooMOooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?oooooNooooglN07ooogWooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooohOooomo1P1ooon5ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooooooo
Oa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o
00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o
0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCoooo
O`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007o
oooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooo
ooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6oooo
o`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003ooooooooo
o`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglC
ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
ooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001oooo
o`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooo
oglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1
o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
0oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4ooo
ogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001
ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003o
ooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
oooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_oo
ool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool0
0003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo
4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0254629, -0.0254629, \
0.00366176, 0.00366176}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data from above distributions", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[{
    \(\(n1\  = \ 1000;\)\), "\[IndentingNewLine]", 
    \(\(n2\  = \ 1000;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = AnnularRegion[c1, \ rr1, \ rr2, \ n1];\)\), "\n", 
    \(\(data2\  = AntiAnnularRegion[c1, \ rr1, \ rr2, \ n2];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[data2, pr, style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, gd2, \ FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.57086 .29556 Mdot
.50407 .34657 Mdot
.46655 .63873 Mdot
.37143 .78266 Mdot
.30469 .41219 Mdot
.21935 .61945 Mdot
.75874 .36291 Mdot
.21642 .68992 Mdot
.69121 .46804 Mdot
.17803 .44769 Mdot
.27721 .32934 Mdot
.5171 .25799 Mdot
.6538 .53375 Mdot
.30253 .31846 Mdot
.32082 .30112 Mdot
.25833 .52481 Mdot
.34273 .31876 Mdot
.49466 .69386 Mdot
.74595 .66885 Mdot
.37431 .52138 Mdot
.38571 .56772 Mdot
.56365 .83077 Mdot
.24005 .40612 Mdot
.3997 .68651 Mdot
.24221 .49985 Mdot
.29823 .31856 Mdot
.25867 .53652 Mdot
.33469 .41998 Mdot
.46083 .30594 Mdot
.24338 .6277 Mdot
.52287 .64008 Mdot
.80612 .62042 Mdot
.72077 .27744 Mdot
.61897 .58405 Mdot
.44114 .32093 Mdot
.16613 .5698 Mdot
.47896 .70156 Mdot
.80624 .54325 Mdot
.67606 .26478 Mdot
.27935 .6454 Mdot
.69425 .47291 Mdot
.50352 .21821 Mdot
.66794 .68084 Mdot
.25932 .35157 Mdot
.20998 .32747 Mdot
.62349 .49315 Mdot
.24687 .62735 Mdot
.66739 .43167 Mdot
.24675 .70452 Mdot
.29707 .69398 Mdot
.46387 .84092 Mdot
.47227 .17001 Mdot
.40149 .25737 Mdot
.36982 .66157 Mdot
.34838 .77304 Mdot
.58947 .32528 Mdot
.25837 .30254 Mdot
.16848 .44116 Mdot
.77388 .56986 Mdot
.20109 .38203 Mdot
.63367 .71902 Mdot
.58035 .38425 Mdot
.31826 .70587 Mdot
.33573 .28374 Mdot
.35898 .71902 Mdot
.4369 .82541 Mdot
.71737 .61014 Mdot
.67314 .38497 Mdot
.71562 .53653 Mdot
.55423 .6738 Mdot
.75706 .71697 Mdot
.60578 .6295 Mdot
.76971 .51999 Mdot
.40367 .75361 Mdot
.19758 .46869 Mdot
.32335 .70168 Mdot
.58812 .82239 Mdot
.56007 .23589 Mdot
.1813 .60863 Mdot
.21454 .68043 Mdot
.35286 .7518 Mdot
.59706 .3215 Mdot
.70265 .43509 Mdot
.45895 .80537 Mdot
.41223 .28418 Mdot
.5225 .75219 Mdot
.73602 .51697 Mdot
.46483 .22863 Mdot
.7109 .75027 Mdot
.6805 .33009 Mdot
.70196 .56489 Mdot
.37841 .36786 Mdot
.72691 .52811 Mdot
.65747 .25824 Mdot
.25786 .36035 Mdot
.48174 .27934 Mdot
.72361 .42195 Mdot
.62292 .55759 Mdot
.50206 .21096 Mdot
.55918 .17592 Mdot
.25895 .32899 Mdot
.55221 .73121 Mdot
.44012 .37346 Mdot
.22734 .60873 Mdot
.55964 .79464 Mdot
.44756 .20801 Mdot
.55154 .17853 Mdot
.70266 .51897 Mdot
.70157 .55033 Mdot
.53843 .35372 Mdot
.41832 .33373 Mdot
.70182 .38223 Mdot
.17726 .53698 Mdot
.64425 .48482 Mdot
.68263 .63686 Mdot
.38585 .42778 Mdot
.2784 .56756 Mdot
.69055 .23093 Mdot
.70322 .39069 Mdot
.37946 .48594 Mdot
.35906 .7921 Mdot
.35715 .52364 Mdot
.73334 .43365 Mdot
.51766 .72992 Mdot
.4137 .76408 Mdot
.53769 .61203 Mdot
.18472 .49316 Mdot
.41616 .20133 Mdot
.3373 .4191 Mdot
.55608 .65378 Mdot
.55468 .64531 Mdot
.59878 .82733 Mdot
.35439 .27853 Mdot
.70858 .55055 Mdot
.67987 .39175 Mdot
.45174 .6296 Mdot
.29904 .62286 Mdot
.42389 .2933 Mdot
.72602 .57839 Mdot
.24346 .71734 Mdot
.3268 .76775 Mdot
.61526 .2793 Mdot
.52997 .79999 Mdot
.66452 .4063 Mdot
.581 .60902 Mdot
.36964 .61984 Mdot
.43882 .8293 Mdot
.78889 .48339 Mdot
.70229 .60919 Mdot
.57354 .66814 Mdot
.61387 .36072 Mdot
.353 .35995 Mdot
.37905 .46185 Mdot
.61514 .59407 Mdot
.33318 .60791 Mdot
.22052 .35862 Mdot
.62038 .357 Mdot
.36137 .59257 Mdot
.39124 .71697 Mdot
.63096 .76756 Mdot
.6205 .51311 Mdot
.58739 .21313 Mdot
.42436 .31002 Mdot
.3652 .59441 Mdot
.65236 .55909 Mdot
.35579 .7524 Mdot
.47604 .79432 Mdot
.29213 .55064 Mdot
.6988 .59418 Mdot
.46442 .72035 Mdot
.68706 .3641 Mdot
.55555 .82051 Mdot
.41956 .21094 Mdot
.34721 .38296 Mdot
.83456 .4737 Mdot
.29115 .54381 Mdot
.69929 .7662 Mdot
.43549 .79277 Mdot
.62559 .77449 Mdot
.28401 .70832 Mdot
.70759 .65424 Mdot
.72283 .57102 Mdot
.25412 .31611 Mdot
.7314 .25418 Mdot
.8061 .61543 Mdot
.52748 .6658 Mdot
.26357 .36612 Mdot
.42927 .7282 Mdot
.56482 .23082 Mdot
.53139 .75292 Mdot
.46756 .75785 Mdot
.64313 .6556 Mdot
.5046 .29928 Mdot
.82026 .47662 Mdot
.50431 .27209 Mdot
.4207 .72637 Mdot
.61211 .35653 Mdot
.42662 .76735 Mdot
.23758 .44675 Mdot
.43759 .63428 Mdot
.45446 .71021 Mdot
.66971 .30979 Mdot
.2135 .50723 Mdot
.29907 .35725 Mdot
.22207 .50906 Mdot
.63859 .58485 Mdot
.67953 .57536 Mdot
.38194 .70828 Mdot
.34209 .6099 Mdot
.74773 .47468 Mdot
.17669 .5722 Mdot
.72076 .37182 Mdot
.6259 .45839 Mdot
.34752 .3711 Mdot
.74128 .66026 Mdot
.30778 .29818 Mdot
.72949 .74056 Mdot
.76897 .43303 Mdot
.54426 .28753 Mdot
.64681 .34351 Mdot
.45615 .81555 Mdot
.56008 .65898 Mdot
.55801 .31215 Mdot
.67166 .41473 Mdot
.48333 .2415 Mdot
.28426 .28406 Mdot
.46209 .28315 Mdot
.60297 .56874 Mdot
.28881 .29225 Mdot
.79929 .38209 Mdot
.58456 .60287 Mdot
.61532 .42623 Mdot
.27034 .6828 Mdot
.28886 .3416 Mdot
.82921 .55559 Mdot
.66991 .21532 Mdot
.53797 .76621 Mdot
.42695 .60477 Mdot
.77008 .35195 Mdot
.77206 .3763 Mdot
.71461 .41477 Mdot
.18161 .60847 Mdot
.72854 .70231 Mdot
.35483 .55002 Mdot
.5023 .71546 Mdot
.66001 .62695 Mdot
.7066 .46362 Mdot
.30527 .75874 Mdot
.32032 .66117 Mdot
.62094 .29411 Mdot
.39822 .8219 Mdot
.21801 .67178 Mdot
.58135 .35181 Mdot
.82894 .56109 Mdot
.71789 .73133 Mdot
.68053 .64548 Mdot
.78335 .64402 Mdot
.51707 .82745 Mdot
.31928 .50677 Mdot
.22509 .58104 Mdot
.56622 .82113 Mdot
.50479 .19381 Mdot
.44364 .36517 Mdot
.58665 .64743 Mdot
.45784 .64722 Mdot
.7119 .75923 Mdot
.60927 .60844 Mdot
.192 .43639 Mdot
.19991 .63045 Mdot
.71818 .63121 Mdot
.62888 .38705 Mdot
.41964 .22455 Mdot
.49109 .79561 Mdot
.7482 .36789 Mdot
.72496 .34404 Mdot
.68191 .55673 Mdot
.33957 .53206 Mdot
.25285 .49779 Mdot
.67533 .78487 Mdot
.46711 .2676 Mdot
.41256 .71718 Mdot
.45868 .72543 Mdot
.19651 .57753 Mdot
.68369 .5829 Mdot
.50099 .20769 Mdot
.39401 .25215 Mdot
.56182 .31042 Mdot
.78103 .4423 Mdot
.30613 .43637 Mdot
.34501 .78041 Mdot
.24191 .46271 Mdot
.58406 .41188 Mdot
.59326 .66432 Mdot
.33592 .70198 Mdot
.18831 .51076 Mdot
.39803 .41655 Mdot
.76196 .69968 Mdot
.30937 .62231 Mdot
.75131 .34821 Mdot
.3221 .70584 Mdot
.32411 .77947 Mdot
.57197 .19838 Mdot
.59015 .66094 Mdot
.65835 .45637 Mdot
.31769 .73993 Mdot
.67811 .3072 Mdot
.68622 .41178 Mdot
.6027 .17951 Mdot
.27111 .37026 Mdot
.61451 .7883 Mdot
.57372 .68264 Mdot
.75851 .38313 Mdot
.35302 .32296 Mdot
.51805 .17263 Mdot
.58937 .36872 Mdot
.59124 .21365 Mdot
.63204 .58667 Mdot
.37403 .24583 Mdot
.34967 .80475 Mdot
.29981 .5209 Mdot
.54527 .19142 Mdot
.4786 .62289 Mdot
.79904 .66584 Mdot
.7305 .5661 Mdot
.74196 .53197 Mdot
.42071 .2791 Mdot
.36239 .37507 Mdot
.33197 .48139 Mdot
.21944 .6973 Mdot
.33532 .68588 Mdot
.51731 .66275 Mdot
.8125 .49689 Mdot
.50865 .288 Mdot
.72555 .63384 Mdot
.37064 .19739 Mdot
.66297 .77967 Mdot
.19218 .35465 Mdot
.30253 .27379 Mdot
.33546 .29166 Mdot
.58426 .27688 Mdot
.3661 .63791 Mdot
.29556 .67299 Mdot
.59294 .30793 Mdot
.26212 .34614 Mdot
.37917 .2674 Mdot
.34385 .75588 Mdot
.29662 .29268 Mdot
.55549 .17266 Mdot
.47988 .18378 Mdot
.5036 .31018 Mdot
.49221 .2038 Mdot
.38695 .70079 Mdot
.53149 .73485 Mdot
.78781 .44805 Mdot
.64805 .31222 Mdot
.33611 .35788 Mdot
.24942 .29642 Mdot
.53695 .37471 Mdot
.61268 .26951 Mdot
.73352 .36491 Mdot
.59121 .32743 Mdot
.40357 .34847 Mdot
.29766 .60464 Mdot
.2051 .46508 Mdot
.53051 .61588 Mdot
.43556 .35244 Mdot
.31509 .28673 Mdot
.37446 .48907 Mdot
.42471 .76496 Mdot
.62639 .31851 Mdot
.479 .16182 Mdot
.37968 .81318 Mdot
.3382 .40032 Mdot
.62485 .36358 Mdot
.69754 .5828 Mdot
.28455 .65536 Mdot
.75323 .32315 Mdot
.27146 .53111 Mdot
.6356 .52615 Mdot
.45427 .2827 Mdot
.59181 .21201 Mdot
.32117 .34746 Mdot
.77059 .31174 Mdot
.65599 .62376 Mdot
.64547 .70841 Mdot
.74145 .6738 Mdot
.56612 .81491 Mdot
.3065 .61865 Mdot
.40181 .62431 Mdot
.33953 .77022 Mdot
.50026 .73401 Mdot
.57108 .17781 Mdot
.35161 .23787 Mdot
.76874 .31254 Mdot
.18416 .48188 Mdot
.7208 .70636 Mdot
.3633 .38732 Mdot
.53812 .77928 Mdot
.42825 .37082 Mdot
.46679 .18118 Mdot
.22591 .42818 Mdot
.54118 .71178 Mdot
.73782 .44478 Mdot
.28643 .43316 Mdot
.63623 .52354 Mdot
.25497 .5874 Mdot
.49489 .67503 Mdot
.21711 .54213 Mdot
.2311 .3227 Mdot
.20914 .64917 Mdot
.26738 .44974 Mdot
.74529 .73887 Mdot
.64719 .30833 Mdot
.56292 .29572 Mdot
.58694 .60934 Mdot
.48869 .81615 Mdot
.48349 .23535 Mdot
.78435 .44235 Mdot
.37298 .62875 Mdot
.40282 .17994 Mdot
.39204 .61217 Mdot
.50067 .28421 Mdot
.33423 .64143 Mdot
.26654 .36654 Mdot
.28263 .52956 Mdot
.27305 .27502 Mdot
.64227 .45107 Mdot
.33184 .67581 Mdot
.42615 .66546 Mdot
.77216 .65273 Mdot
.69988 .41187 Mdot
.4652 .33983 Mdot
.80281 .37973 Mdot
.34901 .22167 Mdot
.3174 .77179 Mdot
.73439 .26319 Mdot
.24501 .5794 Mdot
.65979 .21088 Mdot
.24178 .50451 Mdot
.61972 .32154 Mdot
.79842 .50901 Mdot
.42758 .25673 Mdot
.63788 .58035 Mdot
.41041 .71087 Mdot
.74663 .47402 Mdot
.32226 .28833 Mdot
.20322 .42099 Mdot
.50561 .23432 Mdot
.20282 .62296 Mdot
.28787 .73422 Mdot
.6441 .40827 Mdot
.33258 .38208 Mdot
.37339 .3084 Mdot
.53783 .64486 Mdot
.80612 .44067 Mdot
.63434 .3277 Mdot
.64072 .3092 Mdot
.58798 .74985 Mdot
.29197 .23174 Mdot
.54202 .28375 Mdot
.71442 .50193 Mdot
.41102 .39267 Mdot
.5406 .36573 Mdot
.73394 .50145 Mdot
.25009 .34912 Mdot
.31828 .28818 Mdot
.24369 .61545 Mdot
.36524 .61176 Mdot
.17338 .52179 Mdot
.2868 .60117 Mdot
.31959 .57967 Mdot
.58933 .3923 Mdot
.42879 .23508 Mdot
.68307 .35427 Mdot
.33556 .7291 Mdot
.52165 .22295 Mdot
.37745 .61172 Mdot
.2741 .47449 Mdot
.40708 .69187 Mdot
.66089 .45643 Mdot
.52572 .65974 Mdot
.34702 .77378 Mdot
.45617 .19294 Mdot
.55391 .81755 Mdot
.67896 .32264 Mdot
.17376 .52451 Mdot
.56172 .69129 Mdot
.60981 .67578 Mdot
.60721 .79647 Mdot
.79206 .3762 Mdot
.23835 .29359 Mdot
.73446 .36295 Mdot
.51493 .23797 Mdot
.2428 .72139 Mdot
.78726 .58218 Mdot
.52422 .18696 Mdot
.33431 .74954 Mdot
.38539 .5302 Mdot
.67866 .78318 Mdot
.41429 .41302 Mdot
.78734 .57709 Mdot
.74249 .33192 Mdot
.17931 .53306 Mdot
.77965 .65481 Mdot
.83736 .48619 Mdot
.4123 .62471 Mdot
.65991 .57978 Mdot
.43139 .20644 Mdot
.65977 .6079 Mdot
.27461 .46149 Mdot
.69312 .49776 Mdot
.33627 .39313 Mdot
.7566 .68609 Mdot
.34205 .75008 Mdot
.50116 .21824 Mdot
.52527 .32716 Mdot
.16274 .51344 Mdot
.25075 .27758 Mdot
.34611 .74868 Mdot
.23364 .48417 Mdot
.47368 .71786 Mdot
.6237 .37697 Mdot
.62277 .62955 Mdot
.71024 .53402 Mdot
.43758 .7226 Mdot
.36594 .47264 Mdot
.75545 .55231 Mdot
.36006 .80234 Mdot
.66157 .43159 Mdot
.58479 .79055 Mdot
.54028 .33579 Mdot
.62575 .76788 Mdot
.20634 .4248 Mdot
.6531 .70656 Mdot
.48034 .8361 Mdot
.83467 .43184 Mdot
.46638 .78244 Mdot
.76924 .60351 Mdot
.62413 .55968 Mdot
.62114 .42134 Mdot
.80319 .37675 Mdot
.27651 .42459 Mdot
.40264 .29905 Mdot
.63931 .43163 Mdot
.41111 .71035 Mdot
.32979 .49232 Mdot
.40369 .73195 Mdot
.38024 .66625 Mdot
.39416 .24412 Mdot
.60223 .40177 Mdot
.43411 .71051 Mdot
.31446 .44278 Mdot
.30072 .25397 Mdot
.51828 .16802 Mdot
.73274 .38675 Mdot
.34535 .51883 Mdot
.7848 .63002 Mdot
.505 .33771 Mdot
.27025 .67538 Mdot
.35628 .53978 Mdot
.79893 .38946 Mdot
.21242 .44268 Mdot
.43751 .37831 Mdot
.32282 .21279 Mdot
.24902 .70262 Mdot
.43758 .20882 Mdot
.30736 .22946 Mdot
.4896 .6976 Mdot
.67353 .39539 Mdot
.61797 .79585 Mdot
.45201 .73992 Mdot
.6968 .31147 Mdot
.25067 .62476 Mdot
.6042 .77031 Mdot
.37852 .64315 Mdot
.22725 .46217 Mdot
.6037 .69044 Mdot
.81722 .37549 Mdot
.29412 .26255 Mdot
.27313 .67996 Mdot
.41826 .28489 Mdot
.62482 .45029 Mdot
.34788 .66585 Mdot
.17799 .60298 Mdot
.3738 .44722 Mdot
.71258 .65247 Mdot
.2876 .61898 Mdot
.26514 .56379 Mdot
.51657 .32137 Mdot
.69001 .43576 Mdot
.73489 .71422 Mdot
.71376 .2681 Mdot
.28206 .3227 Mdot
.72133 .71004 Mdot
.42586 .75512 Mdot
.59059 .24792 Mdot
.74907 .49718 Mdot
.38936 .33267 Mdot
.63544 .24837 Mdot
.2933 .47846 Mdot
.62699 .35035 Mdot
.62581 .73473 Mdot
.2899 .44572 Mdot
.54245 .35466 Mdot
.217 .67052 Mdot
.21838 .30662 Mdot
.56391 .68817 Mdot
.28827 .25742 Mdot
.78006 .49468 Mdot
.31111 .60309 Mdot
.83026 .49907 Mdot
.79744 .62348 Mdot
.44467 .30127 Mdot
.50342 .29792 Mdot
.38454 .47388 Mdot
.4419 .83444 Mdot
.72113 .30313 Mdot
.67157 .63745 Mdot
.7842 .65159 Mdot
.5514 .69266 Mdot
.62995 .20537 Mdot
.56428 .35045 Mdot
.67565 .42502 Mdot
.32909 .28397 Mdot
.73506 .57531 Mdot
.73033 .29267 Mdot
.77523 .68044 Mdot
.225 .33795 Mdot
.55226 .35033 Mdot
.43819 .28944 Mdot
.60568 .70756 Mdot
.81959 .37538 Mdot
.20123 .53808 Mdot
.78384 .49509 Mdot
.46891 .27403 Mdot
.38845 .30162 Mdot
.40046 .30174 Mdot
.42504 .27703 Mdot
.53208 .35105 Mdot
.83473 .53971 Mdot
.55562 .81881 Mdot
.44534 .25192 Mdot
.75143 .63994 Mdot
.57056 .78564 Mdot
.33897 .64089 Mdot
.78165 .49601 Mdot
.82677 .41802 Mdot
.40643 .30182 Mdot
.69394 .32615 Mdot
.5467 .6264 Mdot
.33955 .73169 Mdot
.61213 .78919 Mdot
.35588 .46369 Mdot
.43002 .30516 Mdot
.49151 .65228 Mdot
.80671 .50749 Mdot
.24194 .50733 Mdot
.81468 .62918 Mdot
.39114 .33804 Mdot
.20845 .44948 Mdot
.48335 .62712 Mdot
.51977 .2765 Mdot
.43285 .19553 Mdot
.28025 .48768 Mdot
.55067 .74771 Mdot
.57991 .2916 Mdot
.59045 .80792 Mdot
.54873 .26416 Mdot
.38852 .19383 Mdot
.55861 .69929 Mdot
.73784 .56562 Mdot
.67458 .64689 Mdot
.25153 .51215 Mdot
.19139 .49704 Mdot
.69611 .43391 Mdot
.52262 .81553 Mdot
.30424 .32661 Mdot
.39626 .36981 Mdot
.27097 .27359 Mdot
.47014 .21077 Mdot
.67069 .71803 Mdot
.81772 .44099 Mdot
.75613 .58447 Mdot
.67034 .27125 Mdot
.62203 .64904 Mdot
.23844 .64393 Mdot
.38264 .4361 Mdot
.50075 .28192 Mdot
.66096 .71318 Mdot
.34768 .65927 Mdot
.55908 .2903 Mdot
.5845 .69245 Mdot
.84222 .51794 Mdot
.75729 .57807 Mdot
.37705 .71204 Mdot
.67572 .77727 Mdot
.33183 .65221 Mdot
.33345 .56276 Mdot
.78833 .64388 Mdot
.23056 .64421 Mdot
.64475 .66113 Mdot
.69757 .41423 Mdot
.72305 .49672 Mdot
.77786 .69598 Mdot
.54861 .3424 Mdot
.4671 .71412 Mdot
.74699 .52441 Mdot
.39248 .58785 Mdot
.17326 .44135 Mdot
.53804 .33049 Mdot
.67802 .34906 Mdot
.23846 .63884 Mdot
.30832 .77353 Mdot
.61066 .4152 Mdot
.59827 .60046 Mdot
.30042 .54422 Mdot
.69442 .23291 Mdot
.67802 .63469 Mdot
.36991 .62588 Mdot
.71651 .49913 Mdot
.63492 .70343 Mdot
.48804 .76057 Mdot
.61605 .24496 Mdot
.73291 .31698 Mdot
.36047 .44938 Mdot
.3515 .80476 Mdot
.48709 .79338 Mdot
.65961 .52793 Mdot
.69532 .24682 Mdot
.43291 .18149 Mdot
.36414 .32938 Mdot
.65999 .77967 Mdot
.47437 .16927 Mdot
.34436 .39266 Mdot
.43588 .77147 Mdot
.62296 .64829 Mdot
.23227 .47895 Mdot
.42832 .68667 Mdot
.61184 .3156 Mdot
.73613 .43875 Mdot
.3358 .29097 Mdot
.52886 .26623 Mdot
.51895 .35443 Mdot
.61862 .32549 Mdot
.55163 .31349 Mdot
.54321 .68968 Mdot
.28017 .46996 Mdot
.51146 .31122 Mdot
.65672 .66582 Mdot
.48213 .70404 Mdot
.70307 .34727 Mdot
.77365 .54741 Mdot
.31673 .50072 Mdot
.65034 .23432 Mdot
.36183 .33975 Mdot
.29574 .76624 Mdot
.29993 .46066 Mdot
.61002 .69094 Mdot
.3065 .23704 Mdot
.28834 .33191 Mdot
.6675 .37613 Mdot
.4284 .82778 Mdot
.73699 .67186 Mdot
.26854 .48392 Mdot
.24352 .5944 Mdot
.74985 .30103 Mdot
.79091 .6713 Mdot
.60678 .68351 Mdot
.67807 .68828 Mdot
.70842 .66066 Mdot
.16743 .46901 Mdot
.43688 .67602 Mdot
.27358 .64028 Mdot
.32521 .34896 Mdot
.4185 .20479 Mdot
.23915 .37458 Mdot
.65486 .36443 Mdot
.25458 .44927 Mdot
.6581 .37186 Mdot
.41965 .60413 Mdot
.79282 .55434 Mdot
.40909 .29198 Mdot
.5128 .72146 Mdot
.29237 .49484 Mdot
.34446 .52936 Mdot
.26231 .44895 Mdot
.76909 .48143 Mdot
.2711 .27387 Mdot
.76858 .62511 Mdot
.45614 .74514 Mdot
.50579 .17784 Mdot
.50646 .34767 Mdot
.25357 .729 Mdot
.83679 .46934 Mdot
.80433 .39102 Mdot
.6492 .78311 Mdot
.72324 .45854 Mdot
.67571 .71083 Mdot
.609 .34154 Mdot
.30973 .43953 Mdot
.40134 .22161 Mdot
.64641 .24873 Mdot
.30463 .33574 Mdot
.65275 .62253 Mdot
.34344 .78786 Mdot
.48769 .15951 Mdot
.28031 .38087 Mdot
.65512 .29182 Mdot
.51444 .19619 Mdot
.36158 .5998 Mdot
.50352 .82762 Mdot
.35575 .64874 Mdot
.74869 .72854 Mdot
.52462 .70137 Mdot
.62169 .66513 Mdot
.71264 .56642 Mdot
.26411 .6258 Mdot
.80779 .51719 Mdot
.34422 .51807 Mdot
.26225 .7271 Mdot
.43867 .63266 Mdot
.56845 .3217 Mdot
.69894 .59842 Mdot
.65088 .29574 Mdot
.74836 .26974 Mdot
.32463 .66457 Mdot
.23156 .64149 Mdot
.58565 .37547 Mdot
.67066 .45393 Mdot
.65044 .72137 Mdot
.75929 .64014 Mdot
.48613 .24848 Mdot
.31836 .42705 Mdot
.24367 .6287 Mdot
.68873 .26976 Mdot
.58056 .30891 Mdot
.77325 .43068 Mdot
.84143 .50077 Mdot
.72688 .45546 Mdot
.36634 .27186 Mdot
.74209 .51657 Mdot
.27953 .4863 Mdot
.21023 .40367 Mdot
.54211 .33425 Mdot
.19216 .58784 Mdot
.612 .74671 Mdot
.59803 .26991 Mdot
.31012 .63161 Mdot
.22706 .57099 Mdot
.70386 .456 Mdot
.58119 .81283 Mdot
.19594 .63544 Mdot
.42708 .73187 Mdot
.67219 .61882 Mdot
.64521 .39992 Mdot
.60199 .20469 Mdot
.66528 .6164 Mdot
.74127 .59183 Mdot
.31694 .62213 Mdot
.55668 .64301 Mdot
.69392 .25482 Mdot
.17859 .47914 Mdot
.29854 .47657 Mdot
.52161 .68262 Mdot
.55738 .81341 Mdot
.36154 .21735 Mdot
.43633 .64598 Mdot
.38976 .81897 Mdot
.67044 .30995 Mdot
.36803 .49669 Mdot
.42668 .38276 Mdot
.222 .32227 Mdot
.16372 .44288 Mdot
.57052 .64004 Mdot
.59169 .27264 Mdot
.74322 .48696 Mdot
.38052 .61908 Mdot
.19347 .42684 Mdot
.47168 .68643 Mdot
.46413 .23002 Mdot
.45727 .63027 Mdot
.36726 .64128 Mdot
.8298 .50327 Mdot
.54895 .29755 Mdot
.60854 .29201 Mdot
.64959 .37808 Mdot
.67022 .53948 Mdot
.349 .79169 Mdot
.39774 .40981 Mdot
.58359 .65655 Mdot
.6839 .72324 Mdot
.77714 .43533 Mdot
.49481 .69853 Mdot
.33013 .30442 Mdot
.43977 .34464 Mdot
.18465 .61799 Mdot
.63005 .36505 Mdot
.36868 .44645 Mdot
.78929 .48495 Mdot
.43468 .16798 Mdot
.77561 .30118 Mdot
.783 .31259 Mdot
.31944 .65212 Mdot
.59624 .80653 Mdot
.64396 .70353 Mdot
.50474 .66908 Mdot
.55859 .341 Mdot
.62612 .19668 Mdot
.31695 .23216 Mdot
.70434 .39093 Mdot
.56385 .26877 Mdot
.56954 .3568 Mdot
.76302 .40837 Mdot
.22166 .53086 Mdot
.48774 .83756 Mdot
.50621 .34672 Mdot
.72322 .30691 Mdot
.69945 .26386 Mdot
.27259 .42606 Mdot
.55187 .31415 Mdot
.63199 .74891 Mdot
.30111 .75449 Mdot
.6977 .63854 Mdot
.65397 .31976 Mdot
.81761 .48849 Mdot
.37816 .66154 Mdot
.27503 .3815 Mdot
.26244 .39235 Mdot
.27992 .50857 Mdot
.5537 .23506 Mdot
.76485 .32929 Mdot
.49358 .16405 Mdot
.6206 .41794 Mdot
.63902 .36865 Mdot
.66455 .72329 Mdot
.48289 .20116 Mdot
.42333 .83322 Mdot
.38688 .37573 Mdot
.43637 .6218 Mdot
.42026 .27754 Mdot
.61496 .74164 Mdot
.67493 .68404 Mdot
.22544 .39985 Mdot
.3489 .63974 Mdot
.64525 .40976 Mdot
.41971 .67365 Mdot
.23313 .41212 Mdot
.41222 .1937 Mdot
.56451 .64301 Mdot
.77329 .69954 Mdot
.72412 .50153 Mdot
.58126 .21666 Mdot
.31842 .38615 Mdot
.74933 .34931 Mdot
.72399 .53133 Mdot
.43721 .61495 Mdot
.48766 .71358 Mdot
.34561 .29136 Mdot
.60668 .36892 Mdot
.60749 .23156 Mdot
.52781 .27715 Mdot
.44594 .68855 Mdot
.52349 .18268 Mdot
.24314 .41087 Mdot
.53999 .81701 Mdot
.35124 .68251 Mdot
.58689 .60781 Mdot
.46412 .20808 Mdot
.29781 .7624 Mdot
.78205 .61057 Mdot
.6012 .42317 Mdot
.41542 .58475 Mdot
.78545 .4584 Mdot
.32914 .33074 Mdot
.57366 .63345 Mdot
.20795 .64516 Mdot
.4642 .1942 Mdot
.27447 .41073 Mdot
.32326 .27494 Mdot
.33555 .6433 Mdot
.56519 .69491 Mdot
.62287 .39337 Mdot
.59099 .72782 Mdot
.37741 .75197 Mdot
.32632 .26368 Mdot
.43559 .63242 Mdot
.70525 .22634 Mdot
.31799 .37854 Mdot
.53886 .79454 Mdot
.82558 .57838 Mdot
.21917 .51982 Mdot
.3508 .70627 Mdot
.47132 .63514 Mdot
.64707 .69061 Mdot
.78495 .62114 Mdot
.70041 .52981 Mdot
.40295 .66974 Mdot
.65567 .43162 Mdot
.23534 .70697 Mdot
.34121 .63962 Mdot
0 0 1 r
.15994 .86097 Mdot
.82907 .15102 Mdot
.44004 .09847 Mdot
.80278 .28193 Mdot
.52316 .41561 Mdot
.02628 .72954 Mdot
.1716 .66333 Mdot
.20509 .79892 Mdot
.76283 .07299 Mdot
.47291 .40641 Mdot
.20955 .69714 Mdot
.50058 .39673 Mdot
.07035 .30806 Mdot
.53738 .88264 Mdot
.54161 .54446 Mdot
.60295 .16594 Mdot
.86362 .33914 Mdot
.94244 .88863 Mdot
.45166 .5017 Mdot
.30299 .08606 Mdot
.73509 .79245 Mdot
.84393 .311 Mdot
.20328 .2578 Mdot
.47815 .09168 Mdot
.84715 .51225 Mdot
.86539 .91594 Mdot
.97373 .18292 Mdot
.91315 .03712 Mdot
.47129 .52561 Mdot
.02648 .46467 Mdot
.08997 .33197 Mdot
.23624 .03078 Mdot
.08811 .41443 Mdot
.74828 .92929 Mdot
.23115 .89237 Mdot
.87308 .02316 Mdot
.95013 .97623 Mdot
.91815 .18813 Mdot
.48864 .46042 Mdot
.90148 .71365 Mdot
.40847 .13825 Mdot
.6297 .06103 Mdot
.18204 .11728 Mdot
.09223 .02519 Mdot
.16427 .82726 Mdot
.10229 .70856 Mdot
.25299 .12341 Mdot
.61348 .07218 Mdot
.51178 .47264 Mdot
.07189 .42557 Mdot
.09763 .30427 Mdot
.54677 .14925 Mdot
.95584 .96065 Mdot
.86335 .2619 Mdot
.18914 .67198 Mdot
.57972 .89506 Mdot
.04276 .75562 Mdot
.18494 .87045 Mdot
.07712 .78516 Mdot
.68 .05156 Mdot
.02463 .85129 Mdot
.75774 .74709 Mdot
.40802 .88122 Mdot
.72478 .98166 Mdot
.23288 .02057 Mdot
.54308 .95921 Mdot
.11504 .64234 Mdot
.30588 .96837 Mdot
.11102 .16019 Mdot
.07311 .54115 Mdot
.94163 .21533 Mdot
.87934 .67034 Mdot
.48812 .54209 Mdot
.7741 .03781 Mdot
.04944 .72994 Mdot
.47802 .05964 Mdot
.92861 .57956 Mdot
.41472 .50869 Mdot
.74962 .84876 Mdot
.97623 .76443 Mdot
.04441 .55891 Mdot
.43807 .53906 Mdot
.54648 .02663 Mdot
.76143 .94273 Mdot
.96369 .52125 Mdot
.02161 .10377 Mdot
.97766 .74701 Mdot
.68459 .87476 Mdot
.94305 .19791 Mdot
.88973 .8844 Mdot
.3311 .1967 Mdot
.37014 .90883 Mdot
.93878 .44218 Mdot
.69226 .10647 Mdot
.02071 .54944 Mdot
.1097 .27201 Mdot
.12118 .65523 Mdot
.68368 .88896 Mdot
.0485 .47804 Mdot
.40552 .1611 Mdot
.07213 .87427 Mdot
.64505 .16335 Mdot
.52276 .93906 Mdot
.96148 .45148 Mdot
.92278 .96364 Mdot
.24768 .79375 Mdot
.07995 .11303 Mdot
.94889 .04591 Mdot
.6505 .15035 Mdot
.43593 .09704 Mdot
.39323 .91909 Mdot
.22936 .89347 Mdot
.15535 .13514 Mdot
.15922 .79024 Mdot
.55271 .48513 Mdot
.83414 .30926 Mdot
.59402 .44903 Mdot
.19344 .16872 Mdot
.16789 .36179 Mdot
.50442 .46986 Mdot
.74799 .74443 Mdot
.08122 .81637 Mdot
.91606 .69104 Mdot
.37901 .06072 Mdot
.76933 .75688 Mdot
.83721 .12269 Mdot
.1564 .64983 Mdot
.09902 .36846 Mdot
.08499 .82365 Mdot
.56079 .51749 Mdot
.15912 .14242 Mdot
.77617 .9169 Mdot
.01664 .16983 Mdot
.30508 .14217 Mdot
.45807 .02928 Mdot
.24899 .1151 Mdot
.1738 .28165 Mdot
.79826 .14333 Mdot
.02448 .14904 Mdot
.23851 .22233 Mdot
.95996 .94204 Mdot
.23168 .06231 Mdot
.66468 .80968 Mdot
.82628 .29738 Mdot
.21641 .7902 Mdot
.83776 .14899 Mdot
.42309 .90063 Mdot
.0493 .01546 Mdot
.93823 .49636 Mdot
.12175 .20878 Mdot
.52486 .02651 Mdot
.11157 .11607 Mdot
.80882 .89698 Mdot
.03986 .3394 Mdot
.46346 .10067 Mdot
.4579 .56223 Mdot
.9288 .08397 Mdot
.7235 .92423 Mdot
.82703 .95809 Mdot
.0482 .3115 Mdot
.14349 .62302 Mdot
.76652 .02767 Mdot
.61025 .82701 Mdot
.94789 .12089 Mdot
.04465 .53716 Mdot
.91783 .77168 Mdot
.57139 .44629 Mdot
.69803 .96392 Mdot
.92171 .94605 Mdot
.06182 .93459 Mdot
.96402 .83497 Mdot
.02697 .40723 Mdot
.05599 .07309 Mdot
.44578 .95113 Mdot
.57645 .84402 Mdot
.01704 .19439 Mdot
.14199 .59488 Mdot
.23666 .79426 Mdot
.2758 .07138 Mdot
.19047 .73097 Mdot
.82022 .11044 Mdot
.60421 .87715 Mdot
.02683 .51182 Mdot
.01959 .32723 Mdot
.66481 .90424 Mdot
.43133 .08443 Mdot
.20448 .28037 Mdot
.11565 .38367 Mdot
.02382 .53959 Mdot
.2686 .76141 Mdot
.0136 .62064 Mdot
.5842 .52994 Mdot
.57247 .54601 Mdot
.21236 .09451 Mdot
.10652 .70104 Mdot
.94417 .08322 Mdot
.31437 .11848 Mdot
.50672 .59796 Mdot
.41001 .88712 Mdot
.01014 .56115 Mdot
.58911 .46912 Mdot
.05616 .48774 Mdot
.04662 .80272 Mdot
.03405 .89764 Mdot
.68171 .08709 Mdot
.11732 .41255 Mdot
.5184 .93363 Mdot
.48159 .14071 Mdot
.54272 .97296 Mdot
.12891 .34282 Mdot
.1198 .47546 Mdot
.09876 .91132 Mdot
.78293 .25634 Mdot
.57055 .96789 Mdot
.51203 .51516 Mdot
.09877 .83699 Mdot
.95951 .5324 Mdot
.84041 .19939 Mdot
.41281 .92406 Mdot
.98824 .6869 Mdot
.03854 .1643 Mdot
.18833 .9551 Mdot
.76571 .04085 Mdot
.47269 .57264 Mdot
.92262 .86771 Mdot
.95281 .37059 Mdot
.95477 .67389 Mdot
.92604 .51939 Mdot
.4636 .91256 Mdot
.972 .52344 Mdot
.50911 .941 Mdot
.54649 .58021 Mdot
.10559 .32193 Mdot
.58192 .89652 Mdot
.60643 .47789 Mdot
.4483 .92121 Mdot
.88877 .82264 Mdot
.97489 .01845 Mdot
.90696 .309 Mdot
.85135 .76818 Mdot
.27923 .86186 Mdot
.81588 .82251 Mdot
.37738 .89149 Mdot
.39268 .88285 Mdot
.59769 .51103 Mdot
.41017 .98508 Mdot
.0796 .8789 Mdot
.81201 .74619 Mdot
.64643 .86052 Mdot
.44443 .84489 Mdot
.91185 .21804 Mdot
.06155 .95224 Mdot
.11364 .85515 Mdot
.45405 .45102 Mdot
.69367 .86026 Mdot
.15447 .64336 Mdot
.73676 .97401 Mdot
.86508 .29812 Mdot
.91495 .23763 Mdot
.42858 .42088 Mdot
.96472 .96006 Mdot
.49948 .48455 Mdot
.35481 .83139 Mdot
.8437 .42373 Mdot
.47993 .54307 Mdot
.91895 .19591 Mdot
.26128 .12508 Mdot
.94468 .8957 Mdot
.02966 .3921 Mdot
.05513 .42223 Mdot
.26186 .07615 Mdot
.45506 .02449 Mdot
.89724 .23495 Mdot
.21433 .20957 Mdot
.45983 .12021 Mdot
.169 .77753 Mdot
.20777 .05387 Mdot
.30073 .80911 Mdot
.11238 .18169 Mdot
.86381 .13683 Mdot
.20539 .18499 Mdot
.48662 .88912 Mdot
.98125 .96562 Mdot
.0366 .77871 Mdot
.82206 .19789 Mdot
.81902 .73465 Mdot
.12773 .42525 Mdot
.52809 .91573 Mdot
.02515 .25336 Mdot
.58558 .47651 Mdot
.9467 .23828 Mdot
.44308 .55084 Mdot
.56707 .13781 Mdot
.09596 .88086 Mdot
.4338 .45921 Mdot
.43168 .10196 Mdot
.83842 .9729 Mdot
.47518 .85387 Mdot
.01511 .52431 Mdot
.06911 .36528 Mdot
.56223 .96366 Mdot
.93817 .16707 Mdot
.05289 .52471 Mdot
.85201 .27641 Mdot
.60929 .07531 Mdot
.76106 .09261 Mdot
.94514 .32059 Mdot
.93983 .78647 Mdot
.25332 .04595 Mdot
.75128 .79887 Mdot
.10871 .21845 Mdot
.15731 .21467 Mdot
.33784 .13565 Mdot
.20236 .88428 Mdot
.03502 .72442 Mdot
.25272 .10761 Mdot
.85551 .28481 Mdot
.03042 .8796 Mdot
.83843 .23995 Mdot
.69093 .03509 Mdot
.86586 .27096 Mdot
.49837 .14101 Mdot
.25545 .0432 Mdot
.07856 .83866 Mdot
.05795 .94926 Mdot
.95447 .13912 Mdot
.12584 .88936 Mdot
.53201 .94701 Mdot
.4251 .86408 Mdot
.91693 .73287 Mdot
.80589 .15892 Mdot
.29095 .94108 Mdot
.32668 .81176 Mdot
.94347 .98797 Mdot
.21065 .9126 Mdot
.42126 .05076 Mdot
.77574 .05832 Mdot
.84901 .31565 Mdot
.93942 .20598 Mdot
.21208 .88573 Mdot
.88677 .65548 Mdot
.51328 .54414 Mdot
.56001 .54636 Mdot
.36904 .91151 Mdot
.14855 .5054 Mdot
.5835 .86299 Mdot
.38363 .16011 Mdot
.43441 .94432 Mdot
.54696 .94097 Mdot
.23213 .06839 Mdot
.0903 .45157 Mdot
.15885 .95828 Mdot
.0201 .46268 Mdot
.13776 .65746 Mdot
.40327 .11012 Mdot
.84651 .15934 Mdot
.96013 .29967 Mdot
.20592 .85424 Mdot
.26088 .77541 Mdot
.12542 .41247 Mdot
.11184 .80733 Mdot
.40416 .87241 Mdot
.10154 .35445 Mdot
.2762 .22475 Mdot
.46507 .05187 Mdot
.86312 .12444 Mdot
.02642 .9553 Mdot
.81069 .11086 Mdot
.0518 .60873 Mdot
.93016 .7916 Mdot
.30073 .80638 Mdot
.03433 .59142 Mdot
.12014 .71127 Mdot
.1448 .51168 Mdot
.80745 .32713 Mdot
.82549 .90718 Mdot
.32849 .89605 Mdot
.97726 .47003 Mdot
.60392 .07494 Mdot
.15236 .82784 Mdot
.01737 .32596 Mdot
.67633 .03654 Mdot
.68327 .90554 Mdot
.90108 .31815 Mdot
.07366 .20311 Mdot
.08539 .40116 Mdot
.09832 .92133 Mdot
.4412 .97303 Mdot
.4846 .8562 Mdot
.29864 .15499 Mdot
.98121 .51214 Mdot
.29108 .81922 Mdot
.59801 .90388 Mdot
.2397 .83495 Mdot
.7453 .96895 Mdot
.06876 .29511 Mdot
.4494 .97142 Mdot
.05539 .80417 Mdot
.63571 .83201 Mdot
.71737 .04788 Mdot
.83692 .41869 Mdot
.48913 .96859 Mdot
.73237 .22437 Mdot
.96829 .74795 Mdot
.48311 .95275 Mdot
.83712 .823 Mdot
.75594 .91467 Mdot
.01 .41412 Mdot
.51107 .43572 Mdot
.53609 .50678 Mdot
.0907 .74263 Mdot
.4284 .52542 Mdot
.0391 .9725 Mdot
.93596 .8508 Mdot
.54619 .02956 Mdot
.10865 .0376 Mdot
.78045 .10508 Mdot
.10845 .61368 Mdot
.96609 .85735 Mdot
.50668 .43533 Mdot
.4179 .11812 Mdot
.08808 .9001 Mdot
.3886 .13581 Mdot
.14231 .0591 Mdot
.8326 .11606 Mdot
.04347 .0313 Mdot
.06196 .02078 Mdot
.92522 .40781 Mdot
.83097 .78473 Mdot
.15618 .66158 Mdot
.75269 .87482 Mdot
.62018 .82553 Mdot
.91537 .42931 Mdot
.86322 .41834 Mdot
.31385 .18598 Mdot
.75878 .01141 Mdot
.47308 .39145 Mdot
.84482 .79465 Mdot
.1002 .67149 Mdot
.91964 .37514 Mdot
.50388 .85764 Mdot
.06623 .947 Mdot
.84258 .46142 Mdot
.72357 .18531 Mdot
.95499 .18371 Mdot
.07526 .88398 Mdot
.35239 .83388 Mdot
.49777 .04903 Mdot
.75079 .83823 Mdot
.89841 .38661 Mdot
.36968 .11118 Mdot
.81374 .35786 Mdot
.30422 .21739 Mdot
.47116 .51418 Mdot
.93954 .82062 Mdot
.96359 .47496 Mdot
.68486 .12475 Mdot
.92426 .27672 Mdot
.88336 .1036 Mdot
.03566 .88031 Mdot
.11464 .56203 Mdot
.29109 .21397 Mdot
.81013 .68998 Mdot
.83674 .22483 Mdot
.44148 .41396 Mdot
.11146 .6802 Mdot
.73989 .11866 Mdot
.34226 .84438 Mdot
.06404 .22519 Mdot
.50593 .89523 Mdot
.06816 .90416 Mdot
.07225 .1567 Mdot
.94689 .23376 Mdot
.90026 .60273 Mdot
.21681 .12491 Mdot
.86975 .74717 Mdot
.08189 .129 Mdot
.26986 .02482 Mdot
.02766 .894 Mdot
.51193 .98897 Mdot
.44948 .84207 Mdot
.42882 .49419 Mdot
.96181 .4908 Mdot
.88972 .37161 Mdot
.08219 .60709 Mdot
.87187 .4678 Mdot
.62852 .96518 Mdot
.25281 .25684 Mdot
.91047 .61715 Mdot
.81419 .75285 Mdot
.40924 .8772 Mdot
.50971 .5154 Mdot
.19735 .15437 Mdot
.62803 .0574 Mdot
.31601 .91275 Mdot
.34782 .95161 Mdot
.95716 .58361 Mdot
.88003 .77633 Mdot
.62009 .03448 Mdot
.05782 .191 Mdot
.43255 .87031 Mdot
.41999 .1434 Mdot
.86373 .70072 Mdot
.07531 .61827 Mdot
.83712 .01981 Mdot
.18547 .83214 Mdot
.24118 .1322 Mdot
.13283 .92735 Mdot
.81138 .97899 Mdot
.2593 .23643 Mdot
.84559 .83035 Mdot
.62647 .82037 Mdot
.01827 .82034 Mdot
.4508 .97843 Mdot
.88542 .18078 Mdot
.4879 .39435 Mdot
.76239 .24362 Mdot
.5129 .017 Mdot
.01703 .96198 Mdot
.16164 .14144 Mdot
.19446 .72858 Mdot
.15317 .31129 Mdot
.83863 .56937 Mdot
.92639 .40019 Mdot
.08604 .33555 Mdot
.26948 .98484 Mdot
.26225 .03266 Mdot
.74241 .7598 Mdot
.11042 .88142 Mdot
.55775 .04102 Mdot
.94744 .57994 Mdot
.81409 .29088 Mdot
.96566 .7117 Mdot
.88942 .38596 Mdot
.33588 .06741 Mdot
.08483 .37751 Mdot
.96461 .48629 Mdot
.03572 .26659 Mdot
.02698 .89655 Mdot
.21182 .9659 Mdot
.48402 .12095 Mdot
.23636 .26401 Mdot
.87725 .71614 Mdot
.33714 .86825 Mdot
.01106 .81064 Mdot
.47474 .93827 Mdot
.41758 .52264 Mdot
.50033 .46178 Mdot
.48315 .55543 Mdot
.18965 .29015 Mdot
.98933 .44428 Mdot
.94349 .03595 Mdot
.12188 .71833 Mdot
.61615 .1579 Mdot
.5623 .40256 Mdot
.09736 .45449 Mdot
.20712 .80501 Mdot
.58724 .9829 Mdot
.11389 .43728 Mdot
.11475 .98319 Mdot
.98306 .27466 Mdot
.06616 .09438 Mdot
.43056 .8623 Mdot
.24414 .93231 Mdot
.64188 .97783 Mdot
.79309 .13435 Mdot
.53693 .98483 Mdot
.13038 .88208 Mdot
.07403 .7975 Mdot
.12331 .84787 Mdot
.62277 .06018 Mdot
.38843 .11807 Mdot
.03435 .02496 Mdot
.94994 .71511 Mdot
.38267 .03734 Mdot
.16666 .59056 Mdot
.83593 .0427 Mdot
.04608 .69868 Mdot
.96224 .89138 Mdot
.34928 .841 Mdot
.40785 .02498 Mdot
.95104 .73273 Mdot
.38331 .00982 Mdot
.0109 .02743 Mdot
.01044 .96268 Mdot
.16471 .92979 Mdot
.79817 .71858 Mdot
.85324 .62667 Mdot
.82612 .8174 Mdot
.67488 .18123 Mdot
.48665 .9666 Mdot
.27684 .16605 Mdot
.88373 .16603 Mdot
.88309 .19354 Mdot
.87248 .08039 Mdot
.86514 .61748 Mdot
.05617 .25319 Mdot
.91342 .28981 Mdot
.04371 .04292 Mdot
.0395 .13358 Mdot
.1466 .93024 Mdot
.81894 .0277 Mdot
.93665 .9375 Mdot
.53367 .07842 Mdot
.89029 .69412 Mdot
.95872 .55925 Mdot
.83528 .58285 Mdot
.03187 .61195 Mdot
.13178 .90802 Mdot
.95819 .88187 Mdot
.5478 .54912 Mdot
.48492 .10647 Mdot
.1671 .34014 Mdot
.9036 .07121 Mdot
.71911 .95046 Mdot
.07812 .47855 Mdot
.75691 .95451 Mdot
.57507 .43049 Mdot
.78891 .08245 Mdot
.78368 .92999 Mdot
.30857 .83333 Mdot
.09362 .19319 Mdot
.18022 .13178 Mdot
.88221 .36335 Mdot
.11191 .64343 Mdot
.19496 .02484 Mdot
.54648 .60647 Mdot
.8166 .64476 Mdot
.30536 .09275 Mdot
.22154 .88976 Mdot
.89691 .48781 Mdot
.05113 .76778 Mdot
.0245 .13426 Mdot
.92942 .13416 Mdot
.81974 .11922 Mdot
.59403 .44524 Mdot
.05735 .82897 Mdot
.39305 .87031 Mdot
.74219 .74603 Mdot
.86541 .07849 Mdot
.53045 .84646 Mdot
.9587 .58087 Mdot
.48913 .08849 Mdot
.944 .45641 Mdot
.54991 .94453 Mdot
.13407 .347 Mdot
.94608 .50909 Mdot
.90481 .81232 Mdot
.89853 .67031 Mdot
.52156 .93221 Mdot
.16615 .91448 Mdot
.64635 .86353 Mdot
.62589 .07782 Mdot
.14657 .97953 Mdot
.72404 .82625 Mdot
.58686 .04481 Mdot
.59977 .48905 Mdot
.72265 .84579 Mdot
.1734 .72491 Mdot
.56631 .92151 Mdot
.51725 .85157 Mdot
.93061 .85349 Mdot
.79384 .86415 Mdot
.11537 .73287 Mdot
.21678 .82915 Mdot
.84354 .45745 Mdot
.64724 .84217 Mdot
.1398 .9808 Mdot
.19483 .67902 Mdot
.336 .94993 Mdot
.85859 .84852 Mdot
.89686 .19904 Mdot
.22115 .01615 Mdot
.09116 .02555 Mdot
.2828 .01007 Mdot
.73002 .21138 Mdot
.59594 .90524 Mdot
.90691 .47984 Mdot
.05813 .62152 Mdot
.82717 .61518 Mdot
.12733 .73301 Mdot
.83473 .73275 Mdot
.95506 .01518 Mdot
.11451 .53117 Mdot
.36892 .10013 Mdot
.06687 .68437 Mdot
.40388 .97917 Mdot
.81129 .76456 Mdot
.84643 .75918 Mdot
.54246 .98239 Mdot
.04491 .06817 Mdot
.63122 .0792 Mdot
.17528 .02937 Mdot
.07411 .6956 Mdot
.96309 .47412 Mdot
.25303 .92124 Mdot
.3968 .17186 Mdot
.89968 .4932 Mdot
.86458 .43484 Mdot
.34384 .09948 Mdot
.17836 .07991 Mdot
.17885 .66004 Mdot
.91602 .729 Mdot
.58062 .92475 Mdot
.52903 .56694 Mdot
.61954 .08354 Mdot
.38949 .15715 Mdot
.05545 .06748 Mdot
.86728 .97776 Mdot
.41693 .8746 Mdot
.1008 .45702 Mdot
.8781 .31747 Mdot
.87228 .90236 Mdot
.26836 .24374 Mdot
.51339 .59504 Mdot
.01139 .3216 Mdot
.88845 .328 Mdot
.2517 .81398 Mdot
.79745 .86117 Mdot
.91537 .94901 Mdot
.10525 .27238 Mdot
.97582 .49666 Mdot
.91184 .64755 Mdot
.51751 .45889 Mdot
.66994 .82377 Mdot
.2205 .06469 Mdot
.37668 .92864 Mdot
.05796 .04141 Mdot
.95111 .16136 Mdot
.13632 .38406 Mdot
.45658 .55049 Mdot
.72335 .11456 Mdot
.15044 .23303 Mdot
.92847 .47565 Mdot
.92014 .17815 Mdot
.57596 .05036 Mdot
.30131 .78099 Mdot
.20909 .11191 Mdot
.25315 .74938 Mdot
.24817 .94075 Mdot
.12663 .37513 Mdot
.79496 .25789 Mdot
.66025 .81484 Mdot
.08141 .15314 Mdot
.51962 .59161 Mdot
.14314 .66768 Mdot
.05483 .87329 Mdot
.11971 .57446 Mdot
.9184 .50797 Mdot
.24334 .18304 Mdot
.73853 .10151 Mdot
.11001 .50556 Mdot
.15865 .66844 Mdot
.54283 .86862 Mdot
.85068 .04576 Mdot
.80565 .16267 Mdot
.08464 .76915 Mdot
.87745 .6449 Mdot
.6193 .95177 Mdot
.87097 .86006 Mdot
.72212 .20143 Mdot
.8735 .88555 Mdot
.86164 .16547 Mdot
.06579 .0126 Mdot
.17854 .3579 Mdot
.84423 .32023 Mdot
.54944 .39632 Mdot
.32769 .05069 Mdot
.89174 .27691 Mdot
.93675 .33483 Mdot
.02804 .38155 Mdot
.08492 .17916 Mdot
.32948 .82979 Mdot
.02893 .17636 Mdot
.70576 .0766 Mdot
.84058 .80866 Mdot
.85172 .74657 Mdot
.62247 .88588 Mdot
.61405 .06683 Mdot
.57881 .16044 Mdot
.44015 .97453 Mdot
.19325 .68859 Mdot
.80787 .09845 Mdot
.14176 .52779 Mdot
.92729 .20279 Mdot
.53115 .14609 Mdot
.64272 .96575 Mdot
.93967 .91135 Mdot
.07371 .81512 Mdot
.16317 .72245 Mdot
.95056 .44171 Mdot
.60222 .47244 Mdot
.81861 .90412 Mdot
.0322 .3039 Mdot
.34779 .84667 Mdot
.94869 .47898 Mdot
.13941 .34179 Mdot
.61187 .06793 Mdot
.84648 .85343 Mdot
.57259 .45581 Mdot
.16877 .28969 Mdot
.92754 .82171 Mdot
.21028 .80091 Mdot
.1399 .41691 Mdot
.05516 .31837 Mdot
.47276 .85275 Mdot
.10225 .96008 Mdot
.19743 .18438 Mdot
.92368 .68019 Mdot
.72321 .86948 Mdot
.45236 .85335 Mdot
.14441 .1365 Mdot
.0158 .18486 Mdot
.01431 .70979 Mdot
.95084 .85669 Mdot
.72089 .16593 Mdot
.48788 .01374 Mdot
.30025 .81956 Mdot
.04996 .47649 Mdot
.96195 .62676 Mdot
.5818 .43828 Mdot
.82283 .78047 Mdot
.11174 .62434 Mdot
.14307 .56785 Mdot
.47349 .4381 Mdot
.83301 .73849 Mdot
.76873 .92225 Mdot
.79286 .2718 Mdot
.79698 .30529 Mdot
.95983 .79543 Mdot
.14681 .02476 Mdot
.01191 .6386 Mdot
.04487 .39062 Mdot
.85904 .08055 Mdot
.56158 .94271 Mdot
.03583 .33226 Mdot
.78304 .03026 Mdot
.23317 .07027 Mdot
.97626 .71516 Mdot
.02811 .4118 Mdot
.02623 .90993 Mdot
.86962 .89497 Mdot
.5241 .48228 Mdot
.48993 .54118 Mdot
.27471 .09935 Mdot
.48743 .89648 Mdot
.85156 .48612 Mdot
.60801 .01132 Mdot
.46843 .92329 Mdot
.93453 .45082 Mdot
.49069 .91591 Mdot
.01057 .38453 Mdot
.18135 .21126 Mdot
.4969 .55851 Mdot
.91514 .52371 Mdot
.01927 .65222 Mdot
.07338 .04739 Mdot
.59515 .11429 Mdot
.62799 .17316 Mdot
.14711 .24744 Mdot
.14635 .85311 Mdot
.04282 .16121 Mdot
.11788 .6277 Mdot
.0543 .59011 Mdot
.23852 .98186 Mdot
.44934 .48563 Mdot
.78872 .82216 Mdot
.46343 .58087 Mdot
.58416 .4693 Mdot
.05707 .77118 Mdot
.39856 .10009 Mdot
.80874 .77952 Mdot
.93942 .60465 Mdot
.21781 .95121 Mdot
.1605 .77269 Mdot
.02521 .98549 Mdot
.74026 .23883 Mdot
.18358 .22461 Mdot
.87445 .66852 Mdot
.08366 .82766 Mdot
.91206 .33717 Mdot
.50732 .52427 Mdot
.49192 .52898 Mdot
.90977 .22389 Mdot
.0611 .97832 Mdot
.736 .98948 Mdot
.17684 .3196 Mdot
.51144 .38913 Mdot
.5006 .60228 Mdot
.43758 .55167 Mdot
.92046 .0372 Mdot
.09418 .59012 Mdot
.43835 .49842 Mdot
.34009 .15396 Mdot
.28879 .16584 Mdot
.77297 .28505 Mdot
.12175 .83644 Mdot
.27133 .88611 Mdot
.82395 .34425 Mdot
.04242 .95924 Mdot
.89369 .31685 Mdot
.93843 .37892 Mdot
.93657 .53409 Mdot
.32917 .07873 Mdot
.1734 .25885 Mdot
.21722 .2325 Mdot
.89226 .36293 Mdot
.59606 .97873 Mdot
.07812 .02848 Mdot
.56345 .0293 Mdot
.17463 .70183 Mdot
.69968 .88341 Mdot
.01686 .4156 Mdot
.5897 .11008 Mdot
.47048 .12398 Mdot
.86461 .13544 Mdot
.31097 .11595 Mdot
.4545 .02664 Mdot
.74502 .13343 Mdot
.67889 .05978 Mdot
.98191 .7645 Mdot
.0108 .7033 Mdot
.53052 .58912 Mdot
.70457 .91708 Mdot
.09505 .20822 Mdot
.65919 .88196 Mdot
.87593 .06776 Mdot
.97049 .83199 Mdot
.88421 .29346 Mdot
.9695 .13849 Mdot
.44878 .53956 Mdot
.78287 .08588 Mdot
.07144 .31254 Mdot
.76873 .82698 Mdot
.18571 .25458 Mdot
.78843 .98519 Mdot
.2917 .95132 Mdot
.80913 .8565 Mdot
.02206 .63936 Mdot
.31987 .15504 Mdot
.14957 .52212 Mdot
.25823 .8327 Mdot
.08233 .58791 Mdot
.75387 .82404 Mdot
.98113 .29488 Mdot
.39351 .50711 Mdot
.96887 .64572 Mdot
.80622 .26625 Mdot
.30522 .0588 Mdot
.33785 .07987 Mdot
.54722 .44328 Mdot
.95895 .5248 Mdot
.55629 .1582 Mdot
.57524 .0275 Mdot
.57761 .50268 Mdot
.75922 .75145 Mdot
.90901 .012 Mdot
.10257 .02692 Mdot
.78754 .95832 Mdot
.18039 .27416 Mdot
.07473 .60948 Mdot
.62336 .82108 Mdot
.10598 .09448 Mdot
.07688 .67269 Mdot
.52094 .07678 Mdot
.07202 .82359 Mdot
.8618 .33029 Mdot
.88182 .55923 Mdot
.79687 .71101 Mdot
.20119 .06546 Mdot
.70192 .87584 Mdot
.14108 .70802 Mdot
.75889 .94541 Mdot
.07886 .87463 Mdot
.88728 .62492 Mdot
.18724 .3252 Mdot
.10021 .9041 Mdot
.90917 .58705 Mdot
.20995 .7184 Mdot
.02567 .64576 Mdot
.87479 .92793 Mdot
.02322 .51935 Mdot
.80573 .06311 Mdot
.12613 .88463 Mdot
.03572 .97072 Mdot
.70932 .15086 Mdot
.98173 .60966 Mdot
.43605 .96475 Mdot
.96587 .9541 Mdot
.10089 .03598 Mdot
.64054 .97083 Mdot
.28535 .96306 Mdot
.52421 .09601 Mdot
.4983 .11548 Mdot
.92812 .1037 Mdot
.85229 .41273 Mdot
.93658 .48424 Mdot
.42604 .43817 Mdot
.96091 .52033 Mdot
.76229 .92838 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`1<ooooo`?o003o6_ooool3o`00ocko
oooo0ol00?lXooooo`?o003o:?ooool3o`00oaSooooo0Ol00001ooooo`0000?o0000ooooooooool0
2Oooool3o`00o`;ooooo0ol00?ljooooo`Go003o6?ooool5o`00oa[ooooo0ol00?lOooooo`Go003o
9_ooool5o`00obKooooo1Ol00?l9ooooo`?o003o2oooool1o`00007ooooo00000ol0003ooooooooo
o`08ooooo`[o003o:Oooool3o`00o`gooooo1Ol00?lHooooo`Go003o6Oooool5o`00o`?ooooo0ol0
0?lHooooo`Go003o9_ooool5o`00obKooooo1Ol00?l8ooooo`Go003o0_ooool3o`00o`Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool02?ooool:o`00obSooooo1ol00?l:ooooo`Go003o6?ooool5
o`00oaWooooo1Ol00?l2ooooo`Go003o5oooool5o`00obKooooo1Ol00?lBooooo`?o003o4Oooool5
o`00o`Sooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Cooooo0Ol00001ooooo`0000?o0000oooo
ooooool01Oooool=o`00o`?ooooo1?l00?l<ooooo`?o003o2oooool3o`00o`Cooooo2?l00?l7oooo
o`Ko003o6_ooool3o`00o`Cooooo0ol00?l;ooooo`?o003o1Oooool5o`00o`;ooooo1Ol00?lHoooo
o`?o003o:?ooool3o`00oa;ooooo1Ol00?l7ooooo`?o003o1oooool3o`00o`Wooooo1Ol00?l00ooo
oooo003oo`00o`03o`00o`Cooooo0Ol00001ooooo`0000Co0000o`00ool00?oo003o0oooool=o`00
o`03ooooool00?oo003o00So003o2?ooool5o`00o`Gooooo0ol00?l00ooooooo003oo`00o`03o`00
o`?ooooo2?l00?l6ooooo`Go003o8_ooool5o`00o`Wooooo1Ol00?l5ooooo`?o003o0oooool8o`00
o`?ooooo0ol00?l2ooooo`Ko003o=?ooool3o`00o`cooooo0ol00?l00ooooooo003oo`00o`03o`00
o`Kooooo1Ol00?lCooooo`?o003o0_ooool5o`00o`Cooooo0Ol00001ooooo`001Ol00?l2ooooo`Oo
003o00?oooooo`00ool00?l03ol00?l7ooooo`Go003o1?ooool:o`00o`Cooooo1ol00?l5ooooo`Ko
003o8_ooool5o`00o`Wooooo1_l00?l;ooooo`So003o00?oooooo`00ool00?l02ol00?lbooooo`Go
003o00Coooooo`00ool00?oo003o1_ooool:o`00o`Kooooo1Ol00?lIooooo`?o003o1Oooool1o`00
007ooooo0005o`00o`;ooooo2?l00?l01Ooooooo003oo`00ool00?oooooo00co003o1oooool5o`00
o`Cooooo2_l00?l7ooooo`Go003o0oooool7o`00ob;ooooo1Ol00?l9ooooo`Ko003o3_ooool5o`00
o`03ooooool00?oo003o00_o003o2Oooool3o`00o`gooooo0ol00?l01?oooooo003oo`00ool00?lB
ooooo`[o003o1Oooool5o`00o`04ooooool00?oo003oo`00o`Oooooo1Ol00?l@ooooo`?o003o3_oo
ool1o`00007ooooo0005o`00o`?ooooo1ol00?l5ooooo`co003o2?ooool3o`00o`Gooooo1Ol00?l0
1?oooooo003oo`00ool00?l8ooooo`Go003o0oooool6o`00oagooooo0ol00?l4ooooo`?o003o2_oo
ool6o`00o`kooooo1Ol00?l00ooooooo003oo`00o`0;o`00o`Sooooo1Ol00?l;ooooo`Wo003o4Ooo
ool:o`00o`Gooooo1Ol00?l<ooooo`?o003o2?ooool5o`00o`?ooooo1Ol00?l=ooooo`7o00000Ooo
ool00004o`000?l00?oo003oo`00o`Kooooo2?l00?l3ooooo`?o003o0_ooool7o`00oa3ooooo0ol0
0?l=ooooo`Go003o0_ooool6o`00oagooooo1Ol00?lAooooo`Co003o4?ooool3o`00o`?ooooo2ol0
0?l9ooooo`Go003o2oooool9o`00oa;ooooo2Ol00?l6ooooo`?o003o0_ooool3o`00oa;ooooo1ol0
0?l2ooooo`Go003o3Oooool1o`00007ooooo00000ol0003oooooooooo`07ooooo`Wo003o1oooool7
o`00ob7ooooo0ol00?l2ooooo`Ko003o7_ooool5o`00obgooooo1Ol00?l5ooooo`?o003o1Oooool5
o`00o`_ooooo2Ol00?lAooooo`Wo003o2oooool8o`00o`kooooo1ol00?l2ooooo`Go003o3Oooool1
o`00007ooooo00000ol0003oooooooooo`07ooooo`co003o1Oooool6o`00obGooooo1_l00?l@oooo
o`?o003o3?ooool5o`00o`Oooooo0ol00?lCooooo`?o003o3Oooool5o`00o`03ooooool00?oo003o
00Ko003o1Oooool3o`00o`gooooo0ol00?l01?oooooo003oo`00ool00?l5ooooo`?o003o2_ooool7
o`00o`gooooo2Ol00?l=ooooo`Oo003o0oooool5o`00o`cooooo0Ol00001ooooo`0000?o0000oooo
ooooool01oooool=o`00o`Kooooo0ol00?lJooooo`?o003o2Oooool6o`00o`oooooo1Ol00?l<oooo
o`?o003o1oooool5o`00o`Wooooo0ol00?l5ooooo`Go003o3?ooool>o`00oaKooooo0ol00?l7oooo
o`Go003o2Oooool6o`00o`kooooo2Ol00?l>ooooo`Go003o1?ooool5o`00o`cooooo0Ol00001oooo
o`0000?o0000ooooooooool02?ooool3o`00o`03ooooool00?oo003o00Ko003o8_ooool5o`00o`So
oooo1Ol00?l@ooooo`Go003o5_ooool5o`00o`Sooooo1Ol00?l4ooooo`Go003o3Oooool3o`00o`03
ooooool00?oo003o00Oo003o1oooool3o`00o`_ooooo1Ol00?l6ooooo`Go003o2_ooool3o`00oa7o
oooo2?l00?lGooooo`Go003o3?ooool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`Go003o
4?ooool3o`00o`oooooo1Ol00?l9ooooo`?o003o3?ooool3o`00o`;ooooo1Ol00?l;ooooo`?o003o
2?ooool5o`00o`Sooooo1ol00?l2ooooo`Go003o4Oooool8o`00o`Oooooo1Ol00?l:ooooo`Go003o
1_ooool5o`00o`gooooo0ol00?lBooooo`?o003o6Oooool3o`00o`gooooo0Ol00001ooooo`0000?o
0000ooooooooool04?ooool3o`00oa3ooooo1Ol00?l>ooooo`_o003o4Oooool5o`00o`;ooooo0ol0
0?l;ooooo`Go003o2?ooool3o`00o`Wooooo2?l00?l2ooooo`?o003o4oooool3o`00o`[ooooo1ol0
0?l9ooooo`Go003o1oooool3o`00o`gooooo1Ol00?l4ooooo`?o003o=_ooool1o`00007ooooo0000
0ol0003oooooooooo`08ooooo`Ko003o5Oooool5o`00o`gooooo3Ol00?l@ooooo`Go003o1Oooool3
o`00o`Sooooo1Ol00?lEooooo`Oo003o8oooool9o`00o`Wooooo1Ol00?lGooooo`Go003o0oooool5
o`00oa3ooooo0ol00?lRooooo`7o00000Oooool00003o`000?oooooooooo00Oooooo2?l00?lDoooo
o`Go003o3?ooool5o`00o`03ooooool00?oo003o00Ko003o2?ooool3o`00o`Gooooo1Ol00?l4oooo
o`Go003o1oooool5o`00oaOooooo1Ol00?lRooooo`[o003o2Oooool5o`00oaOooooo1Ol00?l3oooo
o`Go003o3oooool5o`00o`Cooooo0ol00?lJooooo`7o00000Oooool00003o`000?oooooooooo00Oo
oooo2?l00?lEooooo`?o003o3Oooool5o`00o`03ooooool00?oo003o00Ko003o1oooool5o`00o`Go
oooo0ol00?l5ooooo`Go003o2?ooool3o`00oaWooooo0ol00?lQooooo`_o003o2oooool3o`00oaGo
oooo0ol00?l01?oooooo003oo`00ool00?l4ooooo`Go003o3oooool5o`00o`?ooooo1Ol00?lIoooo
o`7o00000Oooool00003o`000?oooooooooo00Oooooo2?l00?lUooooo`Go003o0_ooool7o`00o`Co
oooo2?l00?l=ooooo`Go003o<Oooool6o`00oa3ooooo2ol00?lDooooo`?o003o3?ooool5o`00o`So
oooo0ol00?l>ooooo`Oo003o0oooool5o`00oaWooooo0Ol00001ooooo`0000?o0000ooooooooool0
2?ooool7o`00oaoooooo0ol00?l4ooooo`?o003o1Oooool5o`00o`?ooooo2Ol00?l<ooooo`Go003o
<Oooool8o`00o`oooooo3?l00?lBooooo`Go003o2oooool5o`00oaSooooo1ol00?l4ooooo`Go003o
6Oooool1o`00007ooooo00000ol0003oooooooooo`0:ooooo`Go003o7_ooool5o`00o`cooooo0ol0
0?l4ooooo`So003o3?ooool7o`00oaOooooo0ol00?lFooooo`So003o3oooool=o`00oa7ooooo1Ol0
0?l;ooooo`Go003o1?ooool3o`00oa3ooooo2?l00?l5ooooo`?o003o1Oooool3o`00o`04ooooool0
0?oo003oo`00o`kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool3o`00oaoooooo1Ol0
0?lCooooo`Go003o2?ooool3o`00o`Cooooo1ol00?lFooooo`Go003o3Oooool3o`00o`Gooooo2?l0
0?l@ooooo`co003o2oooool3o`00o`?ooooo1Ol00?l<ooooo`?o003o0oooool6o`00o`oooooo2?l0
0?l<ooooo`Wo003o3Oooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`Go003o5?ooool3
o`00o`Sooooo1Ol00?l3ooooo`Oo003o5_ooool5o`00o`Wooooo2?l00?l5ooooo`Ko003o4oooool:
o`00o`[ooooo1Ol00?l3ooooo`?o003o3Oooool3o`00o`;ooooo1ol00?l?ooooo`So003o3?ooool9
o`00o`gooooo0Ol00001ooooo`0000?o0000ooooooooool03_ooool3o`00o`Wooooo0ol00?lAoooo
o`?o003o1oooool3o`00oaKooooo1Ol00?l4ooooo`Go003o5oooool5o`00o`Sooooo2Ol00?l6oooo
o`?o003o5oooool7o`00o`_ooooo1Ol00?lBooooo`Go003o00?oooooo`00ool00?l01Ol00?l@oooo
o`Ko003o3Oooool9o`00o`gooooo0Ol00001ooooo`0000?o0000ooooooooool03Oooool5o`00o`Oo
oooo1Ol00?lIooooo`Go003o3_ooool3o`00o`Cooooo1_l00?l7ooooo`?o003o5_ooool5o`00o`Oo
oooo2Ol00?l5ooooo`Go003o5oooool3o`00o`kooooo1Ol00?lBooooo`Go003o00?oooooo`00ool0
0?l01?l00?l2ooooo`?o003o8?ooool3o`00o`04ooooool00?oo003oo`00o`kooooo0Ol00001oooo
o`0000?o0000ooooooooool03Oooool5o`00o`Oooooo1Ol00?lIooooo`Go003o3Oooool5o`00o`Co
oooo1Ol00?l6ooooo`Go003o0oooool3o`00o`Kooooo0ol00?l6ooooo`Ko003o0oooool;o`00o`Ko
oooo1Ol00?lYooooo`?o003o3Oooool3o`00o`?ooooo1Ol00?l2ooooo`?o003o0oooool5o`00ocCo
oooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool3o`00o`Sooooo1Ol00?l7ooooo`Go003o
6Oooool5o`00o`gooooo1Ol00?l4ooooo`Go003o1_ooool5o`00o`;ooooo1Ol00?l4ooooo`Go003o
1?ooool7o`00o`;ooooo2_l00?l8ooooo`Go003o;?ooool3o`00o`Wooooo1Ol00?l3ooooo`?o003o
0_ooool3o`00o`Cooooo1Ol00?lBooooo`?o003o2Oooool3o`00oa?ooooo0Ol00001ooooo`0000Co
0000oooooooooooooooo1Ol00?l8ooooo`?o003o2Oooool3o`00oa_ooooo0ol00?l9ooooo`?o003o
0_ooool5o`00o`Gooooo0ol00?l7ooooo`Go003o0_ooool5o`00o`Cooooo1Ol00?l4ooooo`Oo003o
0_ooool5o`00o`03ooooool00?oo003o00?o003o2?ooool3o`00obcooooo1Ol00?l8ooooo`Go003o
1oooool5o`00o`?ooooo1Ol00?lAooooo`Go003o1oooool5o`00oa;ooooo0Ol00001ooooo`0000Co
0000oooooooooooooooo1Ol00?l<ooooo`?o003o8_ooool3o`00o`Wooooo1Ol00?l2ooooo`?o003o
4Oooool3o`00o`?ooooo1Ol00?l4ooooo`Go003o1?ooool6o`00o`?ooooo1Ol00?l00ooooooo003o
o`00o`03o`00oa[ooooo0ol00?lJooooo`Go003o2?ooool5o`00o`Oooooo1Ol00?l4ooooo`Oo003o
3_ooool5o`00o`Oooooo1Ol00?lBooooo`7o00000Oooool00004o`000?ooooooooooooooo`Go003o
2oooool5o`00o`Gooooo0ol00?lHooooo`Go003o2?ooool5o`00o`cooooo0ol00?l=ooooo`Go003o
1Oooool5o`00o`Cooooo0ol00?l6ooooo`?o003o0_ooool8o`00oaKooooo1_l00?lHooooo`Go003o
1Oooool3o`00o`04ooooool00?oo003oo`00o`Sooooo1Ol00?l4ooooo`[o003o2oooool5o`00o`Oo
oooo1Ol00?lBooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo0ol00?l<ooooo`Go003o
1?ooool5o`00oa7ooooo0ol00?l3ooooo`Go003o1oooool6o`00o`_ooooo1Ol00?l<ooooo`Go003o
0_ooool;o`00o`Wooooo0ol00?l4ooooo`So003o5Oooool7o`00oaSooooo0ol00?l5ooooo`So003o
2Oooool3o`00o`Gooooo2ol00?l;ooooo`?o003o2Oooool3o`00oa?ooooo0Ol00001ooooo`0000?o
0000ooooooooool04Oooool5o`00o`Cooooo1Ol00?l@ooooo`Go003o0_ooool5o`00o`Oooooo1Ol0
0?l<ooooo`Ko003o2oooool5o`00o`03ooooool00?oo003o00_o003o1oooool7o`00o`03ooooool0
0?oo003o00Ko003o5Oooool7o`00ob3ooooo2Ol00?l@ooooo`_o003o7Oooool3o`00o`gooooo0Ol0
0001ooooo`0000?o0000ooooooooool04_ooool3o`00o`Gooooo1Ol00?l@ooooo`Go003o0oooool5
o`00o`Kooooo1ol00?l:ooooo`Ko003o3?ooool3o`00o`;ooooo3Ol00?l7oooooa3o003o5_ooool6
o`00oaKooooo0ol00?l7ooooo`Wo003o4Oooool;o`00o`Cooooo0ol00?lDooooo`Go003o3?ooool1
o`00007ooooo00000ol0003oooooooooo`0Cooooo`?o003o1Oooool3o`00oa7ooooo1Ol00?l4oooo
o`Go003o1_ooool7o`00o`[ooooo1Ol00?lAooooo`Go003o0oooool5o`00o`Oooooo3ol00?lIoooo
o`?o003o5_ooool5o`00o`Oooooo2?l00?lBooooo`[o003o0oooool5o`00oa?ooooo1Ol00?l<oooo
o`7o00000Oooool00003o`000?oooooooooo00;ooooo0ol00?l2ooooo`?o003o2?ooool5o`00oaSo
oooo1?l00?l5ooooo`Go003o0oooool:o`00o`_ooooo0ol00?lCooooo`?o003o1Oooool3o`00o`Wo
oooo2ol00?leooooo`Go003o2oooool5o`00o`_ooooo0ol00?l4ooooo`?o003o00?oooooo`00ool0
0?l00ol00?l3ooooo`Go003o3oooool3o`00o`03ooooool00?oo003o00?o003o3?ooool1o`00007o
oooo00001?l0003oooooooooooooool:o`00o`Oooooo1Ol00?l>ooooo`Ko003o0oooool5o`00o`Go
oooo1Ol00?l2ooooo`_o003o4_ooool3o`00o`cooooo0ol00?lDooooo`?o003o00Coooooo`00ool0
0?oo003o5Oooool3o`00oakooooo1Ol00?l<ooooo`Go003o2Oooool5o`00o`Sooooo0ol00?l4oooo
o`Go003o3_ooool5o`00o`04ooooool00?oo003oo`00o`gooooo0Ol00001ooooo`0000Co0000oooo
oooooooooooo2_l00?l7ooooo`Go003o3Oooool9o`00o`03ooooool00?oo003o00?o003o1_ooool3
o`00o`?ooooo1Ol00?l2ooooo`?o003o4_ooool5o`00o`[ooooo1Ol00?l01?oooooo003oo`00ool0
0?lBooooo`?o003o0_ooool3o`00oa3ooooo1Ol00?lNooooo`?o003o3Oooool5o`00o`Wooooo1Ol0
0?l?ooooo`Go003o3_ooool5o`00o`?ooooo0ol00?l01?oooooo003oo`00ool00?l7ooooo`7o0000
0Oooool00004o`000?ooooooooooooooo`[o003o2?ooool3o`00o`kooooo3ol00?l<ooooo`Go003o
3oooool3o`00o`Gooooo1Ol00?l:ooooo`go003o3Oooool:o`00o`oooooo1Ol00?l^ooooo`Go003o
2Oooool5o`00o`oooooo1Ol00?l>ooooo`Go003o0_ooool9o`00o`Kooooo0Ol00001ooooo`0000?o
0000ooooooooool00_ooool3o`00o`;ooooo0ol00?lJooooo`[o003o00Coooooo`00ool00?oo003o
3_ooool3o`00o`oooooo1Ol00?l4ooooo`Go003o2_ooool>o`00o`cooooo2_l00?l6ooooo`?o003o
1_ooool5o`00oboooooo0ol00?l;ooooo`Go003o3_ooool5o`00o`oooooo0ol00?l3ooooo`Wo003o
1_ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`?o003o8?ooool9o`00obCooooo1Ol0
0?l5ooooo`?o003o3?ooool3o`00o`03ooooool00?oo003o00Oo003o3?ooool:o`00o`Gooooo2?l0
0?l3ooooo`?o003o5Oooool3o`00o`kooooo0ol00?lEooooo`Go003o1Oooool6o`00o`Cooooo0ol0
0?lFooooo`Wo003o1_ooool1o`00007ooooo00001?l0003oooooooooooooool5o`00o`gooooo0ol0
0?lBooooo`Go003o1oooool3o`00oa[ooooo2Ol00?l3ooooo`?o003o4?ooool8o`00o`gooooo0ol0
0?l2ooooo`?o003o1_ooool9o`00oaWooooo1Ol00?l<ooooo`Go003o5?ooool5o`00o`Cooooo2?l0
0?lMooooo`?o003o00Coooooo`00ool00?oo003o1oooool1o`00007ooooo00001?l0003ooooooooo
ooooool5o`00o`[ooooo1ol00?lBooooo`?o003o1oooool5o`00oaSooooo2ol00?l00ooooooo003o
o`00o`03o`00o`[ooooo0ol00?l6ooooo`?o003o7?ooool;o`00o`kooooo0ol00?l6ooooo`Go003o
3?ooool5o`00oaGooooo0ol00?l5ooooo`So003o:oooool1o`00007ooooo00001?l0003ooooooooo
ooooool5o`00o`;ooooo0ol00?l4ooooo`So003o1?ooool3o`00oaGooooo1Ol00?lHooooo`Go003o
00?oooooo`00ool00?l00ol00?l00ooooooo003oo`00o`03o`00o`Sooooo1_l00?l01?oooooo003o
o`00ool00?lBooooo`Goo`002_ooool;o`00o`;ooooo0ol00?l7ooooo`Go003o1Oooool5o`00o`co
oooo1Ol00?lGooooo`?o003o0oooool9o`00oa_ooooo0ol00?l<ooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo0ol00?l00ooooooo003oo`00o`04o`00o`?ooooo2?l00?l3ooooo`Go003o
5?ooool5o`00oaKooooo1ol00?l00ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00?o003o
1oooool<o`00oa3ooooo2?oo000<ooooo`Oo003o00?oooooo`00ool00?l00ol00?l6ooooo`Go003o
1?ooool5o`00o`kooooo0ol00?lGooooo`Go003o0oooool<o`00oaKooooo1Ol00?l;ooooo`7o0000
0Oooool00003o`000?oooooooooo00Gooooo1ol00?l3ooooo`Oo003o1?ooool5o`00oaCooooo1?l0
0?lDooooo`Wo003o0oooool3o`00o`?ooooo0ol00?l8ooooo`co003o1?ooool3ool000Sooooo2_oo
0003ooooo`?oo`001oooool5o`00o`03ooooool00?oo003o00?o003o0oooool8o`00o`?ooooo1Ol0
0?lBooooo`?o003o5?ooool5o`00o`Oooooo2Ol00?l3ooooo`?o003o3?ooool8o`00o`_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool00ol00?l2ooooo`Oo003o1?ooool3o`00o`Oooooo1Ol00?lC
ooooo`Go003o4oooool8o`00oaKooooo3?l00?l3ooooo`Goo`001_ooool;ool000;ooooo1Ooo0007
ooooo`?o003o0_ooool5o`00o`;ooooo2?l00?l4ooooo`Go003o4Oooool5o`00oa?ooooo1Ol00?l7
ooooo`Wo003o0_ooool5o`00o`[ooooo2Ol00?l;ooooo`7o00000Oooool00003o`000?oooooo003o
00Co003o00?oooooo`00ool00?l01?l00?l@ooooo`?o003o5?ooool5o`00oa?ooooo2?l00?lGoooo
o`[o003o1?ooool5ool000Kooooo2ooo0002ooooo`Goo`001_ooool5ool000;ooooo0ol00?l3oooo
o`Go003o0oooool3o`00o`03ooooool00?oo003o00?o003o4Oooool5o`00oa?ooooo1Ol00?l8oooo
o`So003o0_ooool5o`00o`[ooooo2?l00?l<ooooo`7o00000Oooool00003o`000?oooooo003o00Wo
003o2oooool3o`00oa_ooooo1Ol00?lCooooo`Oo003o6oooool5o`00o`Kooooo1Ooo0006ooooo`Go
o`000_ooool;ool000Gooooo2Ooo0005ooooo`Go003o0_ooool5o`00o`04ooooool00?oo003oo`00
oa;ooooo1Ol00?lDooooo`?o003o3Oooool3o`00o`?ooooo1Ol00?l6ooooo`?o003o00?oooooo`00
ool00?l00ol00?l?ooooo`7o00000Oooool00003o`000?oooooo003o00So003o2oooool5o`00o`Co
oooo0ol00?lDooooo`?o003o2oooool3o`00o`Oooooo0ol00?lNooooo`Go003o00?oo`00oooooooo
ool00oooool4ool000Kooooo1_oo0004ooooo`Woo`001?ooool;ool000Cooooo00Goo`00o`00ool0
0?oo003oool00002ooooo`Go003o2_ooool3o`00o`[ooooo0ol00?l/ooooo`?o003o1_ooool5o`00
o`04ooooool00?oo003oo`00o`Sooooo0ol00?l5ooooo`7o00000Oooool00003o`000?oooooooooo
00So003o2oooool5o`00o`?ooooo1Ol00?lDooooo`Go003o1oooool5o`00oa3ooooo0ol00?lEoooo
o`?o003o0ooo0003ooooo`Goo`001Oooool8ool000?ooooo2_oo0003ooooo`_oo`001?ooool5ool0
00;ooooo1Ol00?l9ooooo`Go003o2_ooool3o`00ob[ooooo1Ol00?l5ooooo`Go003o1_ooool3o`00
o`;ooooo1Ol00?l4ooooo`7o00000Oooool00003o`000?oooooo003o00So003o2oooool5o`00o`?o
oooo1Ol00?lCooooo`Oo003o1_ooool5o`00o`oooooo1Ol00?lEooooo`Goo`000oooool5ool000Go
oooo2Ooo0002ooooo`[oo`000oooool;ool000Cooooo1Ooo0003ooooo`?o003o2_ooool5o`00o`Wo
oooo1Ol00?lYooooo`Go003o1Oooool5o`00o`Gooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Co
oooo0Ol00001ooooo`0000?o0000ooooool00?l01ol00?l5ooooo`?o003o1Oooool5o`00o`;ooooo
1Ol00?lCooooo`Oo003o1_ooool5o`00o`oooooo1Ol00?lEooooo`Ooo`0000?oooooool00?oo0000
0ooo0003ooooo`_oo`000oooool3ool00003oooooooo003oo`0000Coo`000_ooool4ool000?ooooo
0ooo0006ooooo`?oo`004Oooool5o`00o`Wooooo1Ol00?lYooooo`Go003o1Oooool5o`00o`Gooooo
1Ol00?l00ooooooo003oo`00o`03o`00o`Cooooo0Ol00001ooooo`0000?o0000ooooool00?l01?l0
0?l7ooooo`Go003o1Oooool5o`00o`;ooooo0ol00?lDooooo`Oo003o1oooool3o`00oa3ooooo1Ol0
0?l01?oooooo003oo`00ool00?l>ooooo`?oo`0000?oooooool00?oo00001Ooo00001?ooooooo`00
ool00?oo0003ooooo`coo`000oooool:ool00003oooooooo003oo`0000?oo`004oooool3ool000_o
oooo0ol00?l:ooooo`Go003o:Oooool5o`00o`Gooooo1Ol00?l5ooooo`Go003o0_ooool3o`00o`Go
oooo0Ol00001ooooo`0000?o0000ooooool00?l01?l00?l7ooooo`Go003o1Oooool5o`00oa[ooooo
1Ol00?lLooooo`?o003o00?oooooo`00ool00?l00ol00?l8ooooo`?oo`0000?oooooool00?oo0000
0ooo0002ooooo`[oo`000_ooool7ool00004oooooooo003oo`00ool000?ooooo2ooo00000ooooooo
o`00ool00003ool000?ooooo0ooo000<ooooo`Goo`006?ooool3o`00oaWooooo0ol00?l2ooooo`?o
003o2Oooool7o`00o`?ooooo1Ol00?l3ooooo`Ko003o2oooool1o`00007ooooo00000ol0003ooooo
o`00o`04o`00o`Oooooo2?l00?l2ooooo`Go003o?oooool5o`00o`Oooooo2_oo0002ooooo`[oo`00
0_ooool7ool000;ooooo3ooo0002ooooo`Goo`000_ooool5ool000_ooooo1Ooo000Gooooo`?o003o
6Oooool:o`00o`Sooooo2?l00?l2ooooo`Ko003o00?oooooo`00ool00?l00ol00?l=ooooo`7o0000
0Oooool00003o`000?oooooo003o00Co003o2?ooool8o`00o`;ooooo0ol00?m0ooooo`Go003o1ooo
ool:ool000?ooooo2Ooo0003ooooo`Koo`0000?oooooool00?oo00003?oo0005ooooo`?oo`000ooo
ool5ool000Gooooo0ooo0003ooooo`Goo`005_ooool5o`00oaSooooo2_l00?l9ooooo`Oo003o0_oo
ool<o`00o`gooooo0Ol00001ooooo`0000?o0000ooooooooool00ol00?l<ooooo`Go003o0oooool3
o`00o`Cooooo0ol00?lHooooo`?o003o7_ooool3o`00o`Sooooo1Ooo00001?ooooooo`00ool00?oo
0004ooooo`goo`0000?oooooool00?oo00004?oo000<ooooo`Goo`001?ooool5ool000?ooooo1Ooo
0005ooooo`?oo`003Oooool5o`00oaSooooo2_l00?l;ooooo`Go003o0oooool;o`00o`gooooo0Ol0
0001ooooo`0000?o0000ooooooooool03oooool5o`00o`;ooooo1Ol00?l2ooooo`Go003o1_ooool3
o`00o`Cooooo0ol00?l6ooooo`Go003o4_ooool3o`00o`Kooooo0ooo000;ooooo`?oo`002OoooolM
ool0013ooooo0ooo0002ooooo`Soo`000oooool5ool000Cooooo1Ooo000<ooooo`Oo003o5oooool3
o`00o`;ooooo0ol00?l=ooooo`?o003o1Oooool9o`00o`kooooo0Ol00001ooooo`0000?o0000oooo
ooooool04?ooool3o`00o`?ooooo1Ol00?l2ooooo`Go003o1Oooool5o`00o`;ooooo1Ol00?l5oooo
o`Go003o4Oooool8o`00o`03oooooooo003oo`0000?oo`001oooool3ool000cooooo7Ooo000Coooo
o`[oo`000oooool5ool000Cooooo1_oo000<ooooo`Oo003o<?ooool3o`00o`03ooooool00?oo003o
00Ko003o3_ooool1o`00007ooooo00000ol0003oooooooooo`0Fooooo`co003o1Oooool5o`00o`;o
oooo1Ol00?l5ooooo`Go003o4Oooool9o`00o`Goo`001_ooool5ool000Oooooo0ooo0002oooooa?o
o`001?ooool5ool001;ooooo2_oo0005ooooo`?oo`001Oooool7ool000gooooo1Ol00?l_ooooo`Go
003o0oooool5o`00o`kooooo0Ol00001ooooo`0000?o0000ooooooooool05oooool:o`00o`Kooooo
1Ol00?l2ooooo`Go003o1_ooool3o`00o`Cooooo0ol00?l8ooooo`co003o1Ooo0003ooooo`Soo`00
1_ooool5ool000;ooooo0ooo0002ooooo`Koo`0000?oooooool00?oo00000ooo0005ooooo`Koo`00
00Coooooool00?oo003oo`003Oooool8ool0013ooooo1_oo000=ooooo`Go003o6_ooool3o`00oa;o
oooo1Ol00?l3ooooo`Go003o3_ooool1o`00007ooooo00000ol0003oooooooooo`0>ooooo`?o003o
2?ooool5o`00o`[ooooo0ol00?l4ooooo`Go003o2oooool5o`00o`Kooooo3Ol00?l01?ooooooo`00
ool00?oo0003ooooo`Woo`001_ooool5ool00003oooooooo003oo`0000?oo`002Oooool3ool000Ko
oooo2ooo000<ooooo`Ooo`004_ooool5ool000Oooooo0ooo0003ooooo`Go003o6Oooool5o`00oa3o
oooo1_l00?l3ooooo`Go003o3_ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`Go003o
1oooool5o`00oa7ooooo1Ol00?l;ooooo`Go003o1_ooool5o`00o`?oo`0000Coooooo`00ool00?oo
003o2?ooool8ool000Oooooo1Ooo00000oooooooo`00ool00003ool000Sooooo1Ooo0005ooooo`_o
o`002?ooool3ool000;ooooo0ooo0005ooooo`?oo`003_ooool3ool000?ooooo0ooo00000ooooooo
o`00ool00003ool000;ooooo1Ol00?lIooooo`Go003o4?ooool5o`00o`Gooooo0ol00?l?ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo1Ol00?l8ooooo`?o003o2Oooool3o`00o`Kooooo
1Ol00?l6ooooo`?o003o0_ooool5o`00o`Kooooo1Ol00?l:ool000Gooooo1Ooo000;ooooo`?oo`00
0_ooool6ool000Kooooo1_oo00001?ooooooo`00ool00?oo0002ooooo`Coo`0000?oooooool00?oo
00000ooo0005ooooo`Ooo`002?ooool5ool000Sooooo0ooo0007ooooo`[oo`000_ooool5o`00oaWo
oooo1Ol00?l>ooooo`Oo003o1oooool3o`00o`gooooo0Ol00001ooooo`0000?o0000ooooooooool0
3Oooool5o`00oa?ooooo1Ol00?l6ooooo`?o003o1_ooool5o`00o`;ooooo0ol00?l3ooooo`?o003o
0_ooool3o`00o`coo`001Oooool4ool0017ooooo1_oo0005ooooo`_oo`0000?oooooool00?oo0000
1ooo0005ooooo`Soo`002?ooool5ool000Oooooo1Ooo0006ooooo`[oo`000oooool6o`00oaSooooo
0ol00?l>ooooo`Wo003o1Oooool5o`00o`cooooo0Ol00001ooooo`0000?o0000ooooooooool03_oo
ool3o`00oaCooooo1Ol00?l?ooooo`Go003o1oooool5o`00o`Cooooo3?oo0005ooooo`Goo`004Ooo
ool5ool000Gooooo1Ooo00000oooooooo`00ool00003ool00003oooooooo003oo`0000Koo`001_oo
ool8ool000Sooooo1Ooo0007ooooo`Goo`001_ooool9ool000Kooooo1Ol00?lHooooo`?o003o3Ooo
ool:o`00o`Cooooo1Ol00?l<ooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo1Ol00?l?
ooooo`Go003o1oooool6o`00o`Cooooo2ooo0005ooooo`Goo`000oooool3ool000;ooooo0ooo0006
ooooo`Goo`001_ooool3ool000;ooooo1Ooo00000oooooooo`00ool00006ool000Kooooo1ooo000:
ooooo`Goo`001_ooool5ool000Oooooo1Ooo0009ooooo`Go003o0_ooool3o`00oa;ooooo1Ol00?l<
ooooo`[o003o1?ooool5o`00o`cooooo0Ol00001ooooo`0000?o0000ooooooooool09Oooool4o`00
oa7ooooo0ol00?l8ooooo`Oo003o1_ooool7ool000Kooooo1Ooo0002ooooo`[oo`001_ooool3ool0
00cooooo1Ooo0002ooooo`Ooo`001oooool6ool000Gooooo0ooo0003ooooo`Goo`000_ooool7ool0
00Wooooo1?oo0009ooooo`Go003o00?oooooo`00ool00?l00ol00?lAooooo`Go003o3Oooool3o`00
o`03ooooool00?oo003o00?o003o1?ooool5o`00o`cooooo0Ol00001ooooo`0000?o0000oooooooo
ool09?ooool5o`00oagooooo1_l00?l7ooooo`?oo`002_ooool3ool000?ooooo2_oo000;ooooo`?o
o`001oooool6ool000Cooooo0ooo000:ooooo`?oo`001Oooool5ool000;ooooo1Ooo00000ooooooo
o`00ool00006ool000Wooooo1Ooo0009ooooo`?o003o0_ooool5o`00oa7ooooo1Ol00?lBooooo`?o
003o1_ooool3o`00o`gooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool3o`00o`Gooooo
0ol00?lFooooo`Go003o2?ooool3o`00oa?ooooo1Ol00?l6ooooo`?oo`004Oooool:ool000[ooooo
1Ooo0007ooooo`Goo`006Oooool5ool000;ooooo1Ooo00000oooooooo`00ool00006ool000Wooooo
1Ooo0006ooooo`?oo`001Oooool5o`00o`;ooooo0ol00?l=ooooo`?o003o;?ooool1o`00007ooooo
00000ol0003oooooooooo`02ooooo`Go003o0oooool5o`00oaGooooo1Ol00?l4ooooo`So003o00Co
ooooo`00ool00?oo003o2oooool3o`00o`04ooooool00?oo003oo`00o`?ooooo2?oo000Aooooo`?o
o`0000?oooooool00?oo00001?oo0005ooooo`?oo`0000?oooooool00?oo00000ooo0007ooooo`Go
o`001Oooool3ool0017ooooo1Ooo0003ooooo`?oo`000_ooool:ool000Kooooo1_oo0005ooooo`Go
o`001Oooool3o`00o`;ooooo1ol00?liooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo
1Ol00?l3ooooo`Go003o5_ooool3o`00o`Cooooo3_l00?l9ooooo`Go003o1Oooool9ool001Gooooo
1ooo0003ooooo`[oo`002?ooool3ool000Gooooo1Ooo000Aooooo`?oo`002_ooool:ool000Gooooo
1Ooo0006ooooo`Goo`002_ooool8o`00oa3ooooo0ol00?lUooooo`7o00000Oooool00003o`000?oo
oooooooo00;ooooo1ol00?l00ooooooo003oo`00o`03o`00oagooooo3_l00?l5ooooo`?o003o00?o
ooooo`00ool00?l00ol00?l5ooooo`Woo`000oooool3ool0013ooooo1_oo0003ooooo`Goo`0000Co
ooooool00?oo003oo`004Oooool7ool000?ooooo0ooo000Kooooo`Goo`0000Goooooool00?oo003o
o`00ooooo`06ool000Gooooo1_oo0009ooooo`[o003o3Oooool5o`00obCooooo0Ol00001ooooo`00
00?o0000ooooooooool00oooool7o`00o`04ooooool00?oo003oo`00oakooooo2?l00?l00ooooooo
003oo`00o`03o`00o`Cooooo2_l00?l5ooooo`Soo`000oooool5ool000_ooooo0ooo0002ooooo`Go
o`000oooool5ool000Oooooo0ooo000;ooooo`Soo`0000?oooooool00?oo00001_oo0007ooooo`?o
o`0000Coooooool00?oo003oo`002OoooolDool000;ooooo2?oo0007ooooo`[o003o3?ooool5o`00
obCooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool5o`00o`oooooo1Ol00?l?ooooo`?o
003o1_ooool3o`00o`Gooooo1Ol00?l01?oooooo003oo`00ool00?l2ooooo`?oo`000_ooool7ool0
00?ooooo1Ooo0007ooooo`Soo`000_ooool3ool000Gooooo0ooo0007ooooo`Goo`001oooool3ool0
0003oooooooo003oo`0000Goo`0000?oooooool00?oo00001ooo0004ooooo`[oo`002Oooool3ool0
0003oooooooo003oo`0000koo`0000?oooooool00?oo00001ooo0009ooooo`Oo003o3?ooool5o`00
obCooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool5o`00o`kooooo1ol00?l@ooooo`?o
003o3?ooool5o`00o`Gooooo1Ooo0003ooooo`Koo`000_ooool5ool000Kooooo2Ooo0009ooooo`?o
o`002?ooool5ool000Kooooo3?oo00000oooooooo`00ool00007ool000;ooooo3?oo000<oooooa;o
o`0000?oooooool00?oo00001_oo0008ooooo`So003o2_ooool8o`00o`?ooooo0ol00?l6ooooo`?o
003o3_ooool3o`00o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool3o`00o`oooooo
1ol00?l?ooooo`Go003o0oooool3o`00o`Kooooo0ol00?l01?ooooooo`00ool00?oo0002ooooo`Ko
o`000oooool5ool00003oooooooo003oo`0000?oo`001Oooool;ool000Sooooo1Ooo0007ooooo`So
o`000oooool<ool000;ooooo2?oo00000oooooooo`00ool0000;ool000cooooo4ooo0003ooooo`Go
o`002?ooool7o`00o`[ooooo2Ol00?l2ooooo`Go003o1?ooool5o`00o`cooooo1Ol00?l2ooooo`7o
00000Oooool00003o`000?oooooooooo01Sooooo1ol00?l>ooooo`Ko003o0_ooool5o`00o`Sooooo
1Ooo00000oooooooo`00ool00006ool00003oooooooo003oo`0000?oo`0000?oooooool00?oo0000
1_oo00000oooooooo`00ool00009ool000Oooooo1ooo0005ooooo`_oo`000_ooool?ool000?ooooo
0ooo0002ooooo`Soo`0000?oooooool00?oo00000ooo000;ooooo`Goo`0000Coooooool00?oo003o
o`001?ooool6ool000Cooooo0ooo0009ooooo`Oo003o2_ooool9o`00o`;ooooo1Ol00?l4ooooo`Go
003o3?ooool5o`00o`;ooooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool5o`00o`kooooo
1ol00?l2ooooo`Go003o2?ooool5ool000;ooooo2?oo00001Oooooooo`00ool00?oo003ooooo017o
o`002_ooool8ool000Cooooo3?oo00000oooooooo`00ool0000?ool000Oooooo1_oo0003ooooo`Go
o`003?ooool3ool000[ooooo1Ooo000;ooooo`?o003o0oooool7o`00o`Wooooo2?l00?l3ooooo`Go
003o1?ooool5o`00o`cooooo1Ol00?l2ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo
3_l00?l8ooooo`Goo`000oooool7ool000Cooooo4?oo000<ooooo`Ooo`0000Goooooool00?oo003o
o`00ooooo`0<ool00003oooooooo003oo`0000ooo`0000Coooooool00?oo003oo`001?ooool3ool0
00Gooooo1Ooo000Jooooo`?oo`002oooool5o`00o`Cooooo1ol00?l8ooooo`Go003o1_ooool3o`00
o`?ooooo1_l00?l>ooooo`?o003o0oooool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`ko
003o1oooool6ool000Kooooo1ooo0002ooooo`ooo`003OoooolCool00004oooooooo003oo`00ool0
00;ooooo1ooo0005ooooo`[oo`000_ooool3ool000Gooooo1_oo0007ooooo`?oo`004oooool3ool0
00Sooooo1Ol00?l4ooooo`So003o1oooool5o`00o`Cooooo0ol00?l4ooooo`Go003o4?ooool3o`00
o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool03oooool3o`00oaWooooo1Ol00?l00ooooooo
003oo`00o`03o`00o`Wooooo1ooo0007oooooaGoo`003_ooool=ool00003oooooooo003oo`0000?o
o`002?ooool6ool000Gooooo4?oo0003ooooo`Soo`001Oooool5ool0017ooooo1Ooo0007ooooo`Go
003o1Oooool9o`00o`Gooooo1_l00?l2ooooo`Go003o0oooool5o`00o`oooooo1Ol00?l2ooooo`7o
00000Oooool00003o`000?oooooooooo00kooooo1Ol00?lHooooo`Go003o00?oooooo`00ool00?l0
0ol00?l9ooooo`Soo`001_oooolEool000Wooooo4ooo000=ooooo`Koo`001_ooool?ool000?ooooo
2?oo0004ooooo`Koo`004Oooool5ool00004oooooooo003oo`00ool000Cooooo0ol00?l00ooo003o
ooooooooo`05ooooo`So003o1Oooool6o`00o`03ooooool00?oo003o00?o003o0oooool5o`00o`[o
oooo0ol00?l2ooooo`Go003o0_ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`?o003o
1_ooool5o`00o`Cooooo0ol00?lBooooo`?o003o0oooool3o`00o`[ooooo2Ooo0005oooooaCoo`00
2OoooolEool000cooooo1Ooo0008ooooo`koo`000oooool8ool000Cooooo1_oo000?ooooo`coo`00
0oooool5ool000;ooooo0ol00?l2ooooo`Oo003o1_ooool5o`00o`03ooooool00?oo003o00?o003o
1?ooool3o`00o`[ooooo1Ol00?l00ooooooo003oo`00o`03o`00o`;ooooo0Ol00001ooooo`0000?o
0000ooooooooool01?ooool5o`00o`Gooooo1Ol00?l3ooooo`Go003o7oooool3ool000?ooooo2Ooo
0005oooooa7oo`001oooool3ool00003oooooooo003oo`0000Soo`0000?oooooool00?oo00002ooo
0009ooooo`Goo`002?ooool@ool000;ooooo1_oo0005ooooo`Goo`001?ooool3ool000Sooooo1ooo
00000oooooooo`00ool00003ool000?ooooo1Ooo00000ooooooo003oo`00o`03o`00o`?ooooo1Ol0
0?l6ooooo`Go003o0_ooool3o`00oa;ooooo1Ol00?l2ooooo`?o003o0oooool1o`00007ooooo0000
0ol0003oooooooooo`04ooooo`So003o0_ooool5o`00o`?ooooo1Ol00?l<ooooo`?o003o3oooool5
ool000Gooooo1_oo000;ooooo`[oo`001oooool?ool00003oooooooo003oo`0000coo`002?ooool6
ool000Sooooo4?oo000:ooooo`Koo`000_ooool7ool00004oooooooo003oo`00ool000?ooooo1_oo
0002ooooo`Goo`000_ooool6ool00003ooooool00?oo003o00?o003o1?ooool8o`00o`?ooooo0ol0
0?l9ooooo`?o003o3?ooool5o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool9
o`00o`03ooooool00?oo003o00?o003o0oooool5o`00o`_ooooo1Ol00?l>ooooo`Goo`001_ooool5
ool000kooooo1ooo0007ooooo`Goo`0000?oooooool00?oo00001_oo00000oooooooo`00ool0000=
ool000Sooooo1ooo0007ooooo`Ooo`0000?oooooool00?oo00001_oo0002ooooo`?oo`001?ooool7
ool00003oooooooo003oo`0000_oo`000_ooool6ool000?ooooo0ooo0002ooooo`Soo`001Ol00?l6
ooooo`So003o3?ooool5o`00o`cooooo0ol00?l9ooooo`7o00000Oooool00003o`000?oooooooooo
00Gooooo3ol00?l3ooooo`?o003o3?ooool5o`00o`kooooo1Ooo0006ooooo`Coo`002Oooool4ool0
00Gooooo0ooo00001?ooooooo`00ool00?oo0004ooooo`Goo`002_ooool6ool000Cooooo1Ooo0008
ooooo`Ooo`001_ooool8ool00003oooooooo003oo`0000Koo`0000?oooooool00?oo00003Ooo0000
0oooooooo`00ool0000;ool000?ooooo1_oo0007ooooo`Woo`000ol00?l7ooooo`Wo003o1?ooool3
o`00o`;ooooo1ol00?lHooooo`7o00000Oooool00003o`000?oooooo003o00;o003o1_ooool<o`00
o`Kooooo0ol00?l9ooooo`Go003o0oooool3o`00o`Wooooo1ooo0002ooooo`Goo`001?ooool3ool0
0003oooooooo003oo`0000Coo`001oooool5ool000Cooooo0ooo000;ooooo`Goo`0000Coooooool0
0?oo003oo`000_ooool3ool000Wooooo1ooo0006ooooobWoo`0000?oooooool00?oo00000ooo0004
ooooo`Koo`001_ooool9ool000[ooooo2Ol00?l3ooooo`go003o1oooool3o`00o`kooooo0Ol00001
ooooo`0000?o0000o`00ool00?l00ol00?l6ooooo`_o003o1Oooool5o`00o`Wooooo0ol00?l3oooo
o`Oo003o1_ooool8ool00003oooooooo003oo`0000?oo`000oooool;ool000Oooooo1ooo000Aoooo
o`?oo`0000?oooooool00?oo00000ooo000>ooooo`Ooo`001Oooool^ool000Kooooo1Ooo0002oooo
o`?oo`0000?oooooool00?oo00001ooo000;ooooo`So003o0oooool<o`00o`Oooooo1Ol00?l=oooo
o`7o00000Oooool00003o`000?l00?oo003o00Co003o1_ooool5o`00o`04ooooool00?oo003oo`00
o`Kooooo1Ol00?l?ooooo`So003o0oooool:ool00003oooooooo003oo`0000Coo`000_ooool;ool0
00Oooooo2_oo000Booooo`Goo`004?ooool7ool000Cooooo2Ooo00000oooooooo`00ool0000?ool0
00;ooooo1Ooo0002ooooo`Woo`001_ooool5ool00003oooooooo003oo`0000Ooo`0000Coooooool0
0?oo003oo`001?ooool3o`00o`Kooooo1_l00?l4ooooo`co003o1oooool5o`00o`gooooo0Ol00001
ooooo`0000?o0000o`00ool00?l01Ol00?l01?oooooo003oo`00ool00?l2ooooo`?o003o1oooool3
o`00o`03ooooool00?oo003o00?o003o3oooool8o`00o`;ooooo2ooo0002oooooa?oo`000oooool3
ool00003oooooooo003oo`0000Soo`000oooool3ool000_ooooo1Ooo000@ooooo`_oo`001?ooool5
ool00003oooooooo003oo`0000Koo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00003
ool000;ooooo2Ooo0007ooooo`koo`001oooool5o`00o`Gooooo1Ol00?l01?oooooo003oo`00ool0
0?l2ooooo`[o003o2?ooool5o`00o`gooooo0Ol00001ooooo`0000?o0000ooooool00?l02_l00?l:
ooooo`Go003o00Coooooo`00ool00?oo003o4Oooool7o`00o`;ooooo2_oo0004oooooa;oo`000_oo
ool5ool000;ooooo2?oo0002ooooo`Goo`001?ooool3ool000Cooooo0ooo000Booooo`_oo`001?oo
ool3ool000;ooooo1ooo0002ooooo`Woo`000_ooool3ool000?ooooo2Ooo0009ooooo`coo`001ooo
ool5o`00o`Kooooo0ol00?l00ooooooo003oo`00o`03o`00o`?ooooo1Ol00?l:ooooo`Go003o3_oo
ool1o`00007ooooo00000ol0003oooooooooo`0:o`00o`Wooooo1_l00?lBooooo`?o003o0oooool3
o`00o`?ooooo2?oo0006oooooa;oo`000_ooool5ool000?ooooo1ooo0002ooooo`Goo`000oooool5
ool000[ooooo0ooo0008ooooo`?oo`000_ooool:ool000Wooooo1Ooo0004ooooo`Soo`002?ooool8
ool000[ooooo3?oo0007ooooo`Go003o2_ooool5o`00o`?ooooo1Ol00?l3ooooo`?o003o0oooool5
o`00o`oooooo0Ol00001ooooo`0000Co0000oooooooooooooooo0ol00?l00ooooooo003oo`00o`04
o`00o`Sooooo1_l00?l7ooooo`Ko003o1?ooool5o`00o`Wooooo2?oo0006ooooo`?oo`000_ooool<
ool000;ooooo1Ooo0004ooooo`Goo`000oooool5ool000?ooooo1Ooo0009ooooo`Goo`001_ooool5
ool000;ooooo3?oo0007ooooo`?oo`000_ooool3ool000Cooooo0ooo00001?ooooooo`00ool00?oo
0005ooooo`Goo`003Oooool5ool000?ooooo0ooo0009ooooo`?o003o2oooool6o`00o`?ooooo0ol0
0?l3ooooo`Go003o0_ooool5o`00o`oooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool5
o`00o`Sooooo1Ol00?l7ooooo`So003o0oooool5o`00o`cooooo1Ooo0006ooooo`?oo`001?ooool:
ool000?ooooo0ooo0005ooooo`Goo`000oooool5ool000?ooooo1Ooo0002ooooo`?oo`001?ooool5
ool000Kooooo1Ooo0005ooooo`[oo`002_ooool5ool000Kooooo1Ooo0005ooooo`?oo`002_ooool3
ool000;ooooo0ooo000Eooooo`?o003o1oooool5o`00o`Wooooo1Ol00?l2ooooo`Go003o3oooool1
o`00007ooooo00000ol0003oooooooooo`06ooooo`Go003o2Oooool3o`00o`Sooooo2?l00?l3oooo
o`Go003o3?ooool5ool000?ooooo1ooo0003ooooo`Goo`0000Goooooool00?oo003oo`00ooooo`05
ool000Kooooo1Ooo0003ooooo`Soo`0000Coooooool00?oo003oo`000_ooool5ool000?ooooo1Ooo
0006ooooo`Goo`001_ooool:ool000Wooooo1Ooo00001?ooooooo`00ool00?oo0002ooooo`Goo`00
1Oooool3ool000Cooooo0ooo0002ooooo`Goo`000oooool4ool0017ooooo1Ol00?l6ooooo`Go003o
2Oooool5o`00o`?ooooo0ol00?l@ooooo`7o00000Oooool00003o`000?oooooooooo00Oooooo0ol0
0?lEooooo`So003o1?ooool3o`00o`kooooo0ooo0003ooooo`Soo`000oooool5ool000Cooooo1ooo
0006ooooo`?oo`001Oooool8ool000Gooooo1Ooo0004ooooo`?oo`001oooool6ool000?ooooo3Ooo
00001?ooooooo`00ool00?oo0004ooooo`[oo`0000?oooooool00?oo00000ooo0004ooooo`Goo`00
0_ooool5ool00003oooooooo003oo`0000?oo`000_ooool6ool00004oooooooo003oo`00ool000co
oooo1Ol00?l7ooooo`?o003o2oooool3o`00oaOooooo0Ol00001ooooo`0000?o0000ooooooooool0
6?ooool3o`00o`Gooooo1_l00?l<ooooo`?oo`003Oooool8ool000Cooooo1_oo0002ooooo`Ooo`00
4Oooool5ool000Cooooo1_oo000>oooooa_oo`001?ooool9ool000;ooooo0ooo0005ooooo`Goo`00
0_ooool5ool00003oooooooo003oo`0000?oo`000_ooool;ool000_ooooo1Ol00?l_ooooo`7o0000
0Oooool00003o`000?oooooooooo01Oooooo1Ol00?l6ooooo`?o003o2_ooool3o`00o`Coo`001Ooo
ool3ool000Cooooo2?oo0006ooooo`Goo`0000?oooooool00?oo00001ooo0002ooooo`?oo`002_oo
ool5ool000Cooooo1Ooo000@oooooa[oo`001?ooool9ool000[ooooo1_oo00000oooooooo`00ool0
0003ool000;ooooo0ooo0003ooooo`_oo`002Oooool6o`00oc3ooooo0Ol00001ooooo`0000?o0000
ooooooooool05oooool5o`00o`oooooo2?l00?l3ool000Cooooo1Ooo0004ooooo`Ooo`001_ooool5
ool000;ooooo3_oo000:ooooo`?oo`001Oooool5ool0017ooooo6Ooo0004ooooo`Soo`001Oooool3
ool000Cooooo1Ooo0002ooooo`?oo`001_ooool3ool00003oooooooo003oo`0000Soo`002?ooool5
o`00o`oooooo1_l00?lMooooo`7o00000Oooool00003o`000?oooooooooo00oooooo0ol00?l5oooo
o`Go003o3_ooool9o`00o`?oo`001?ooool5ool000Gooooo1ooo0005ooooo`Goo`001_ooool:ool0
00?ooooo0ooo000=ooooo`Koo`004Oooool<ool000?ooooo1ooo0005ooooo`Woo`000oooool5ool0
00?ooooo1_oo0009ooooo`koo`002Oooool5o`00o`kooooo2?l00?lLooooo`7o00000Oooool00003
o`000?oooooooooo00kooooo1Ol00?l5ooooo`?o003o3oooool9o`00o`;oo`001Oooool5ool000Go
oooo2?oo0005ooooo`?oo`001oooool:ool000;ooooo1Ooo00001?ooooooo`00ool00?oo0006oooo
o`?oo`0000?oooooool00?oo00000ooo000Aooooo`?oo`000_ooool5ool000Gooooo0ooo0002oooo
o`?oo`000_oooolBool000Cooooo1Ooo0009ooooo`coo`002oooool5o`00o`kooooo2?l00?l>oooo
o`?o003o2oooool1o`00007ooooo00000ol0003oooooooooo`0>ooooo`Go003o1?ooool5o`00o`ko
oooo2?l00?l9ooooo`?oo`000_ooool3ool000;ooooo2?oo000?ooooo`[oo`0000?oooooool00?oo
00002?oo0004ooooo`[oo`005_ooool5ool000Wooooo6?oo0004ooooo`Goo`001_ooool?ool000co
oooo0ol00?l?ooooo`So003o3Oooool5o`00o`[ooooo0Ol00001ooooo`0000?o0000ooooooooool0
3_ooool5o`00o`03ooooool00?oo003o00Ko003o1?ooool3o`00o`Sooooo0ol00?lAooooo`Goo`00
0_ooool7ool000Wooooo0ooo0005oooooa?oo`001?ooool:ool001Gooooo1_oo0009ooooo`[oo`00
00?oooooool00?oo00003_oo0002ooooo`?oo`001_ooool?ool00004oooooooo003oo`00ool000;o
oooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`003oooool6o`00o`Gooooo0ol00?l6oooo
o`Go003o2_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`?o003o2Oooool3o`00o`03
ooooool00?oo003o00Oo003o0oooool5o`00oa7ooooo0ooo0007ooooo`Goo`000oooool8ool000Ko
oooo1Ooo00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`001?ooool9ool001Ko
oooo1Ooo0009oooooagoo`002_ooool8ool00004oooooooo003oo`00ool000?ooooo4_oo000?oooo
o`Go003o1?ooool5o`00o`05ooooool00?oo003oo`00ooooool01Ol00?l:ooooo`7o00000Oooool0
0005o`000?l00?oo003oo`00ooooool01Ol00?l<ooooo`So003o00?oooooo`00ool00?l01ol00?l?
ooooo`Goo`001_ooool5ool000Gooooo1ooo0005oooooa;oo`000_ooool7ool000Kooooo2?oo000F
ooooo`Goo`002Oooool5ool000;ooooo0ooo00000oooooooo`00ool00003ool00003oooooooo003o
o`0000[oo`001_ooool3ool00003oooooooo003oo`0000?oo`001ooooolEool0013ooooo0ol00?l5
ooooo`[o003o00Coooooo`00ool00?oo003o2oooool1o`00007ooooo000:o`00o`cooooo1Ol00?l3
ooooo`_o003o3_ooool5ool000Oooooo0ooo0006ooooo`Ooo`001OoooolAool000?ooooo1Ooo0007
ooooo`Soo`006?ooool3ool000Wooooo1_oo0006ooooo`Koo`000_ooool;ool000Cooooo1Ooo0000
0oooooooo`00ool00004ool000Cooooo5_oo000@ooooo`Ko003o0_ooool:o`00o`oooooo0Ol00001
ooooo`002_l00?l01?oooooo003oo`00ool00?l9ooooo`?o003o1?ooool;o`00o`kooooo1Ooo000>
ooooo`Woo`001_oooolAool000?ooooo0ooo0008ooooo`Ooo`001oooool3o`00o`Sooooo0ol00?l@
ooooo`Koo`001oooool6ool000;ooooo0ooo0002ooooo`Koo`000oooool5ool000?ooooo1Ooo0003
ooooo`Soo`000_ooool;ool0013ooooo2?l00?l2ooooo`?o003o00?oooooo`00ool00?l00ol00?l?
ooooo`7o00000Oooool000Go003o00?oooooo`00ool00?l01ol00?l?ooooo`Go003o00?oooooo`00
ool00?l00ol00?l?ooooo`?oo`003_ooool9ool000Oooooo4Ooo000:ooooo`?oo`0000?oooooool0
0?oo00000ooo0008ooooo`So003o0oooool5o`00o`oooooo1ooo0006ooooo`Koo`001oooool7ool0
00;ooooo1Ooo0003ooooo`Goo`000oooool5ool000Kooooo1ooo000Cooooo`So003o1oooool3o`00
oa3ooooo0Ol00001ooooo`0000Co0000o`00ool00?oo003o0_ooool9o`00oa3ooooo0ol00?l3oooo
o`?o003o8Oooool5ool000_ooooo4Ooo0009ooooo`Goo`0000Coooooool00?oo003oo`002Oooool@
o`00o`Oooooo0ol00?l6ooooo`Koo`001Oooool7ool000Oooooo1ooo0002ooooo`Goo`000oooool5
ool000Cooooo0ooo0007ooooo`Ooo`004oooool8o`00oa[ooooo0Ol00001ooooo`0000?o0000oooo
ooooool00oooool9o`00o`Sooooo0ol00?lUooooo`?oo`001oooool5ool000cooooo0ooo00000ooo
ooooo`00ool00005ool00004oooooooo003oo`00ool000[ooooo1Ooo000=oooooa3o003o1_ooool8
o`00o`?ooooo2?oo0002ooooo`Koo`0000Coooooool00?oo003oo`001?ooool7ool000;ooooo1Ooo
0004ooooo`?oo`003oooool7ool001Cooooo1_l00?l5ooooo`?o003o4oooool1o`00007ooooo0000
0ol0003oooooooooo`04ooooo`?o003o00Coooooo`00ool00?oo003o2?ooool5o`00ob3ooooo2ooo
0004ooooo`?oo`004Oooool7ool000kooooo1Ooo000>ooooo`ko003o1oooool9o`00o`?ooooo2?oo
00000oooooooo`00ool00003ool00003oooooooo003oo`0000?oo`000_ooool7ool000Cooooo0ooo
000Hooooo`Goo`007oooool5o`00oa;ooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool3
o`00o`gooooo1Ol00?lOooooo`goo`005oooool6ool000cooooo0ooo00001?ooooooo`00ool00?oo
000>ooooo`go003o2Oooool9o`00o`Kooooo1Ooo0002ooooo`?oo`000_ooool5ool00003oooooooo
003oo`0000Coo`005oooool3ool002_ooooo1Ol00?lBooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo1Ol00?l<ooooo`Go003o1Oooool5o`00oaGooooo3Ooo0006ooooo`?oo`001_ooool3
ool000Gooooo1Ooo000<ooooo`Goo`0000Coooooool00?oo003oo`003Oooool5o`00o`Cooooo0ol0
0?l;ooooo`So003o0_ooool3ool00003oooooooo003oo`0000?oo`001oooool5ool00003oooooooo
003oo`0000?oo`000_ooool3ool00004oooooooo003oo`00ool000kooooo1Ooo000Fooooo`?o003o
4Oooool5o`00oa;ooooo0Ol00001ooooo`0000?o0000o`00ool00?l01ol00?l=ooooo`Co003o1?oo
ool:o`00oa7ooooo3_oo0004ooooo`Goo`001?ooool5ool000Gooooo0ooo000=ooooo`[oo`001?oo
ool3o`00o`Gooooo1Ol00?l:ooooo`?o003o2Oooool3o`00o`;ooooo1Ooo00000oooooooo`00ool0
0003ool000Kooooo1Ooo00000oooooooo`00ool0000@ool000[ooooo1Ooo000Eooooo`Go003o4?oo
ool5o`00oa;ooooo0Ol00001ooooo`002_l00?l=ooooo`Go003o0oooool;o`00oa7ooooo0ooo0002
ooooo`Soo`001?ooool5ool000Cooooo1Ooo0004ooooo`Coo`003Oooool:ool000?ooooo1Ol00?l5
ooooo`?o003o2_ooool5o`00o`gooooo1Ooo0002ooooo`Ooo`000oooool5ool000;ooooo4_oo0009
ooooo`Goo`003_ooool3ool000?o003o00?oooooo`00ool00?l01Ol00?l>ooooo`Go003o4_ooool1
o`00007ooooo000:o`00o`Cooooo0ol00?l6ooooo`Go003o0oooool;o`00o`oooooo0ooo0004oooo
o`Soo`001?ooool5ool000Cooooo1Ooo0003ooooo`Koo`003?ooool:ool000So003o4_ooool5o`00
o`gooooo1Ooo00000oooooooo`00ool00007ool000?ooooo0ooo0004oooooa?oo`002?ooool3ool0
00kooooo0ooo000=o`00o`kooooo0ol00?lCooooo`7o00000Oooool000Wo003o1?ooool5o`00o`05
ooooool00?oo003oo`00ooooool01Ol00?l4ooooo`[o003o3?ooool7ool000Cooooo1_oo0005oooo
o`Goo`001Oooool3ool00003oooooooo003oo`0000Ooo`003?ooool5ool00004oooooooo003oo`00
ool000Wo003o4_ooool5o`00o`kooooo0ooo00000oooooooo`00ool00008ool000[ooooo5?oo000H
ooooo`?oo`003Ol00?lTooooo`7o00000Oooool00003o`000?l00?oo003o00?o003o1oooool:o`00
o`04ooooool00?oo003oo`00o`Oooooo1ol00?l<ooooo`Soo`000_ooool3ool000Wooooo1ooo0007
ooooo`[oo`002_ooool6ool000Gooooo2?l00?lDooooo`?o003o3?ooool3o`00o`Cooooo2_oo000;
ooooo`Goo`000_ooool3ool000;ooooo1ooo000:ooooo`?oo`002oooool3ool000Oo003o00?ooooo
o`00ool00?l00ol00?l;ooooo`?o003o5_ooool1o`00007ooooo00000ol0003oooooooooo`0:oooo
o`[o003o2oooool5o`00o`kooooo2?oo00000oooooooo`00ool00003ool000Sooooo2?oo0006oooo
o`Woo`002_ooool5ool000Oooooo1Ol00?lUooooo`Go003o0oooool:ool000;ooooo0ooo00000ooo
ooooo`00ool00008ool000;ooooo0ooo0004ooooo`Ooo`001oooool5ool000_ooooo0ooo0006o`00
o`;ooooo0ol00?l;ooooo`Go003o5Oooool1o`00007ooooo00000ol0003oooooooooo`0;ooooo`?o
003o00?oooooo`00ool00?l00ol00?l8ooooo`So003o3_ooool8ool00003oooooooo003oo`0000?o
o`002?ooool9ool000;ooooo2?oo000>ooooo`Goo`002?ooool3o`00oaCooooo1?l00?l>ooooo`Go
003o1?ooool8ool000;ooooo5_oo0003ooooo`Ooo`001Oooool6ool000gooooo0ooo0003o`00o`?o
oooo0ol00?l;ooooo`Go003o5Oooool1o`00007ooooo00000ol0003oooooooooo`0@ooooo`?o003o
2?ooool8o`00o`Wooooo1?oo00000oooooooo`00ool00006ool000;ooooo1Ooo0009ooooo`Soo`00
00?oooooool00?oo00001_oo000>ooooo`Koo`001oooool3o`00o`_ooooo0ol00?l6ooooo`Ko003o
3Oooool6o`00o`Oooooo0ooo0003oooooaOoo`001?ooool5ool000Gooooo1ooo0004ooooo`?oo`00
00Goooooool00?oo003oo`00ooooo`05ool000?ooooo1Ol00?l:ooooo`Go003o5Oooool1o`00007o
oooo00000ol0003oooooooooo`0Kooooo`Go003o2_ooool<ool000;ooooo0ooo00001?ooooooo`00
ool00?oo000=ooooo`Goo`0000?oooooool00?oo00001?oo000@ooooo`Goo`001oooool5o`00o`Wo
oooo1Ol00?l5ooooo`Ko003o1_ooool3o`00o`Gooooo1_l00?l<ooooo`goo`0000?oooooool00?oo
00001ooo0004ooooo`Goo`001Oooool8ool000;ooooo3_oo0003ooooo`Go003o2oooool3o`00o`Co
oooo1_l00?l8ooooo`?o003o0Oooool1o`00007ooooo00000ol0003oooooooooo`0Kooooo`Go003o
2Oooool=ool00003oooooooo003oo`0000?oo`000oooool3ool000_ooooo1?oo00000oooooooo`00
ool00005ool000cooooo2?oo0007ooooo`Go003o2Oooool5o`00o`Gooooo1_l00?l5ooooo`Go003o
0oooool:o`00o`[ooooo0ooo00000oooooooo`00ool00005ool000;ooooo2Ooo0004ooooo`Koo`00
1Oooool8ool00003oooooooo003oo`0000Ooo`0000Coooooool00?oo003oo`001?ooool5o`00oa7o
oooo2?l00?l6ooooo`Go003o0Ol00001ooooo`0000?o0000ooooooooool05Oooool3o`00o`Cooooo
0ol00?l:ooooo`coo`000_ooool5ool000;ooooo1Ooo00000oooooooo`00ool00005ool000;ooooo
1Ooo00000oooooooo`00ool00004ool000[ooooo2Ooo0008ooooo`Go003o1Oooool3o`00o`03oooo
ool00?oo003o00?o003o1_ooool4o`00o`Kooooo1Ol00?l2ooooo`co003o1?ooool3ool000;ooooo
0ooo000;ooooo`?oo`0000Coooooool00?oo003oo`001Oooool6ool000Oooooo4?oo0009ooooo`?o
003o4Oooool;o`00o`Cooooo1Ol00?l1o`00007ooooo00000ol0003oooooooooo`0Dooooo`Ko003o
3oooool9ool000Cooooo1_oo0002ooooo`koo`0000?oooooool00?oo00000ooo0002ooooo`Goo`00
2Oooool9ool000[ooooo0ol00?l5ooooo`Go003o00Coooooo`00ool00?oo003o4Oooool5o`00o`;o
oooo3?l00?l3ooooo`[oo`001Oooool3ool000oooooo1Ooo0007ooooo`Ooo`0000Goooooool00?oo
003oo`00ooooo`03ool001gooooo3Ol00?l3ooooo`Go003o0Ol00001ooooo`0000?o0000oooooooo
ool05?ooool7o`00o`oooooo2?oo0004ooooo`Goo`000oooool>ool00003oooooooo003oo`0000?o
o`000oooool3ool000[ooooo2Ooo000Booooo`Go003o5_ooool3o`00o`?ooooo1Ol00?l2ooooo`Go
003o0oooool:ool00003oooooooo003oo`0000Koo`001Oooool3ool000?ooooo1ooo0009ooooo`Ko
o`003?ooool3o`00oaKooooo3Ol00?l4ooooo`?o003o0Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Dooooo`So003o4_ooool3ool000Gooooo1Ooo00000oooooooo`00ool00004ool00003oooo
oooo003oo`0000Soo`0000?oooooool00?oo00001?oo000>ooooo`Woo`003Oooool3o`00o`;ooooo
1Ol00?l5ooooo`?o003o00Coooooo`00ool00?oo003o0_ooool3o`00o`cooooo1Ol00?l00ooooooo
003oo`00o`03o`00o`?ooooo4ooo0004ooooo`Goo`0000?oooooool00?oo00001?oo000<ooooo`Go
o`002oooool5o`00oaGooooo3Ol00?l8ooooo`7o00000Oooool00004o`000?ooooooooooooooo`Go
003o3oooool7o`00oa[ooooo1?oo00000oooooooo`00ool00003ool00003oooooooo003oo`0000_o
o`000_ooool5ool000cooooo1Ooo00000oooooooo`00ool00003ool000_ooooo1Ol00?l2ooooo`?o
003o1Oooool>o`00o`_ooooo1Ol00?l2ooooo`?o003o1Oooool8ool00003oooooooo003oo`0000Oo
o`001?ooool5ool00003oooooooo003oo`0000Coo`003?ooool5ool000_ooooo1Ol00?lFooooo`Oo
003o00Coooooo`00ool00?oo003o2Oooool1o`00007ooooo00000ol0003oooooooooo`07o`00oa3o
oooo1Ol00?l?ooooo`?oo`001_ooool6ool00003oooooooo003oo`0000Soo`001?ooool5ool000;o
oooo1Ooo000;ooooo`Goo`000_ooool5ool000_ooooo1Ol00?l:ooooo`ko003o2oooool8o`00o`Oo
oooo1Ooo0004ooooo`Soo`000oooool>ool000cooooo1Ooo000;ooooo`Go003o1?ooool3o`00oa7o
oooo1Ol00?l=ooooo`7o00000Oooool00003o`000?oooooooooo00Oo003o4Oooool3o`00o`oooooo
1Ooo0004ooooo`Ooo`0000?oooooool00?oo00002?oo0004ooooo`Koo`0000?oooooool00?oo0000
0ooo000;ooooo`coo`002oooool5o`00o`[ooooo3_l00?l<ooooo`_o003o1?ooool3ool000Kooooo
1?oo0005ooooo`Woo`0000?oooooool00?oo00000_oo000>ooooo`?oo`002oooool00ooo003o003o
o`00o`03o`00o`?ooooo1Ol00?lAooooo`?o003o1oooool3o`00o`Cooooo0Ol00001ooooo`0000?o
0000ooooooooool01ol00?lGooooo`?o003o2Oooool5ool000Cooooo1ooo0002ooooo`?oo`0000?o
ooooool00?oo00000ooo0005ooooo`Koo`0000Coooooool00?oo003oo`003?ooool=ool000_ooooo
0ol00?l<ooooo`?o003o00?oooooo`00ool00?l01_l00?l?ooooo`[o003o5Oooool9ool000Oooooo
1?oo000Eooooo`?oo`000ol00?l4ooooo`Go003o3Oooool3o`00o`Kooooo2Ol00?l3ooooo`7o0000
0Oooool00004o`000?ooooooooooooooo`Go003o0oooool4o`00o`Gooooo0ol00?l8ooooo`Go003o
2?ooool8ool00003oooooooo003oo`0000Coo`001Oooool6ool000Gooooo2ooo000=ooooo`Ooo`00
00?oooooool00?oo00000ooo000Mooooo`Oo003o4?ooool:o`00oaGooooo2?oo0007ooooo`Koo`00
4Oooool8ool000Gooooo1Ol00?l<ooooo`Go003o00?oooooo`00ool00?l02ol00?l3ooooo`7o0000
0Oooool00003o`000?oooooooooo00Sooooo1_l00?l3ooooo`Go003o1oooool5o`00o`Wooooo2?oo
00001?ooooooo`00ool00?oo0006ooooo`Goo`001oooool<ool000Kooooo0ooo0005ooooo`Goo`00
00?oooooool00?oo00000ooo000Mooooo`[o003o3Oooool;o`00oaCooooo1Ooo000:ooooo`Koo`00
0_ooool3ool000_ooooo2Ooo0006ooooo`?o003o1oooool3o`00o`?ooooo4ol00?l3ooooo`7o0000
0Oooool00003o`000?oooooooooo00Sooooo1_l00?l3ooooo`Go003o1oooool5o`00o`cooooo1_oo
0009ooooo`Goo`001_ooool=ool000Gooooo1Ooo0005ooooo`?oo`0000?oooooool00?oo00001?oo
000>ooooo`?o003o3?ooool;o`00o`Cooooo0ol00?l5ooooo`Go003o00?oooooo`00ool00?l00ol0
0?l7ooooo`?oo`002_ooool5ool000[ooooo1_oo00000oooooooo`00ool00003ool000;ooooo0ooo
0005ooooo`Woo`000ol00?l<ooooo`Go003o0_oooolBo`00o`Cooooo0Ol00001ooooo`0000?o0000
ooooooooool02?ooool6o`00o`?ooooo1Ol00?l8ooooo`?o003o3Oooool6ool000Wooooo1Ooo0005
ooooo`koo`001Oooool5ool000Sooooo1_oo000>ooooo`Go003o2_ooool5o`00o`;ooooo1Ol00?l3
ooooo`Go003o1?ooool;o`00o`Kooooo1Ooo000:ooooo`?oo`002oooool5ool000;ooooo1Ooo0000
0oooooooo`00ool00003ool000Cooooo2?oo0005o`00o`[ooooo1_l00?l3ooooo`ko003o1oooool1
o`00007ooooo00000ol0003oooooooooo`09ooooo`Ko003o0oooool3o`00oa[ooooo1Ooo0009oooo
o`Goo`001Oooool=ool000Kooooo1Ooo0007ooooo`Koo`003oooool5o`00o`[ooooo1Ol00?l2oooo
o`Go003o0oooool5o`00o`Gooooo2Ol00?l2ooooo`?oo`000_ooool5ool001Oooooo1Ooo0003oooo
o`Goo`0000?oooooool00?oo00000ooo0003ooooo`Woo`001Ol00?l9ooooo`Oo003o1?ooool7o`00
o`03ooooool00?oo003o00?o003o1oooool1o`00007ooooo00000ol0003oooooooooo`0:ooooo`Go
003o8?ooool6ool000Sooooo1Ooo0005ooooo`_oo`001oooool5ool000Oooooo1ooo000:ooooo`?o
003o0_ooool5o`00o`[ooooo1Ol00?l3ooooo`?o003o1?ooool5o`00o`Sooooo1Ol00?l2ooooo`Go
o`0000?oooooool00?oo00000ooo000Cooooo`?oo`0000?oooooool00?oo00000ooo0004ooooo`[o
o`000_ooool:ool000Go003o2Oooool6o`00o`Gooooo1Ol00?l2ooooo`So003o1Oooool1o`00007o
oooo00000ol0003oooooooooo`0:ooooo`Go003o8?ooool7ool000Sooooo2Ooo00000oooooooo`00
ool00009ool000Kooooo1Ooo0006ooooo`Ooo`002_ooool:o`00o`cooooo0ol00?l<ooooo`?o003o
2Oooool5o`00o`;ooooo1Ooo0002ooooo`?oo`002oooool3ool000Cooooo3?oo0005ooooo`Ooo`00
0_ooool;ool00004ooooool00?oo003oo`00o`[ooooo1Ol00?l6ooooo`Go003o0_ooool9o`00o`Co
oooo0Ol00001ooooo`0000?o0000ooooooooool02oooool3o`00ob7ooooo1ooo000:ooooo`Soo`00
1?ooool7ool000?ooooo2?oo0006ooooo`Koo`002oooool;o`00ob7ooooo0ol00?l3ooooo`?o003o
0oooool5ool000oooooo1Ooo0002ooooo`koo`001?ooool6ool000?ooooo3Ooo000<ooooo`Go003o
1_ooool5o`00o`;ooooo2Ol00?l4ooooo`7o00000Oooool00003o`000?oooooooooo01_ooooo0ol0
0?l8ooooo`?o003o1oooool6ool000?ooooo0ooo0004ooooo`Soo`001_ooool5ool000;ooooo2?oo
0007ooooo`Goo`000oooool3o`00o`Kooooo3?l00?lDooooo`?o003o2?ooool5o`00o`Wooooo0ooo
000@ooooo`Goo`0000?oooooool00?oo00003Ooo0004ooooo`Koo`000oooool>ool000cooooo0ol0
0?l7ooooo`Go003o0oooool8o`00o`Cooooo0Ol00001ooooo`0000?o0000ooooooooool06_ooool5
o`00o`Kooooo1Ol00?l7ooooo`Coo`000oooool6ool000;ooooo2?oo0004ooooo`Koo`000oooool6
ool000[ooooo0ooo0003ooooo`Go003o0_ooool3o`00o`03ooooool00?oo003o00Wo003o4oooool5
o`00o`Oooooo1Ol00?l2ooooo`?o003o5oooool5ool00003oooooooo003oo`0000goo`001Oooool4
ool00003oooooooo003oo`0000Goo`0000?oooooool00?oo00001ooo000Booooo`?o003o0_ooool6
o`00o`Gooooo0ol00?l5ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo0ol00?lDoooo
o`Go003o1_ooool5o`00o`?oo`000oooool5ool000?ooooo1ooo00000oooooooo`00ool00005ool0
00Cooooo1Ooo0005ooooo`Koo`004?ooool5o`00o`03ooooool00?oo003o00?o003o0oooool8o`00
o`04ooooool00?oo003oo`00o`oooooo1Ol00?l7ooooo`Go003o00?oooooo`00ool00?l00ol00?l2
ooooo`?oo`004_ooool3ool000;ooooo3_oo000:ooooo`Soo`0000?oooooool00?oo00001?oo0003
o`00oa7ooooo1Ol00?l3ooooo`Go003o1_ooool3o`00o`?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool00_ooool5o`00oa?ooooo1Ol00?l5ooooo`Ko003o1?oo0002ooooo`Goo`000oooool7ool0
0003oooooooo003oo`0000Goo`001?ooool5ool000Kooooo1Ooo0003ooooo`?oo`002_ooool5o`00
o`03ooooool00?oo003o00?o003o1oooool3o`00o`03ooooool00?oo003o00?o003o1oooool4o`00
o`?ooooo1Ol00?l3ooooo`?o003o0_ooool3o`00o`;ooooo1Ol00?l00oooooooo`00ool00003ool0
01Oooooo2ooo000<ooooo`Soo`000_ooool3ool00003ooooool00?oo003o00?o003o4?ooool5o`00
o`?ooooo1Ol00?l5ooooo`Go003o0_ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`Go
003o5?ooool3o`00o`Kooooo1Ol00?l5ool000;ooooo1Ooo0004ooooo`Koo`000_ooool6ool000Co
oooo1Ooo00001?ooooooo`00ool00?oo0003ooooo`?oo`000oooool5ool000Gooooo0ooo0002oooo
o`?o003o0_ooool5o`00o`_ooooo1Ol00?l6ooooo`Ko003o0oooool3o`00o`?ooooo1Ol00?l6oooo
o`Go003o00?oooooool00?oo00000ooo000Dooooo`?oo`001Oooool7ool000Cooooo0ooo0004oooo
o`Soo`001Oooool00ooo003o003oo`00o`03o`00oa3ooooo1_l00?l2ooooo`Wo003o00?oooooo`00
ool00?l00ol00?l2ooooo`7o00000Oooool00003o`000?oooooooooo00Oo003o0oooool3o`00oaOo
oooo1Ol00?l7ool00004oooooooo003oo`00ool000Gooooo1Ooo0004ooooo`Koo`001?ooool3ool0
0003oooooooo003oo`0000?oo`002?ooool8ool00003oooooooo003oo`0000?oo`001oooool4o`00
o`_ooooo1Ol00?l6ooooo`Ko003o2Oooool5o`00o`Oooooo0ol00?l2ooooo`Goo`0000Coooooool0
0?oo003oo`003oooool5ool000Cooooo2?oo0002ooooo`Goo`001?ooool7ool000Gooooo00?oo`00
o`00ool00?l00ol00?l@ooooo`Oo003o0_ooool>o`00o`;ooooo0Ol00001ooooo`0000?o0000oooo
ool00?l01_l00?l3ooooo`Go003o5_ooool6o`00o`Ooo`002?ooool5ool000Gooooo1_oo0007oooo
o`Goo`002?ooool>ool000Oooooo1ol00?l9ooooo`?o003o1oooool6o`00o`Wooooo1Ol00?l=oooo
o`?oo`0000?oooooool00?oo00000ooo0002ooooo`?oo`002Oooool5ool000?ooooo2_oo00000ooo
ooooo`00ool00003ool000Kooooo1Ooo0005ooooo`;oo`000ol00?l@ooooo`So003o1?ooool;o`00
o`?ooooo0Ol00001ooooo`0000?o0000ooooool00?l01_l00?l3ooooo`Go003o3_ooool3o`00o`Co
oooo1ol00?l2ooooo`Goo`002?ooool5ool000Kooooo2ooo00000oooooooo`00ool00003ool000So
oooo4?oo0005ooooo`So003o1oooool5o`00o`;ooooo0ol00?l00ooooooo003oo`00o`03o`00o`_o
oooo0ol00?l4ooooo`?o003o2oooool5ool00003oooooooo003oo`0000?oo`002?ooool5ool000;o
oooo2ooo00000oooooooo`00ool00003ool000Oooooo0ooo0007ooooo`?oo`004Oooool8o`00o`Co
oooo2Ol00?l5ooooo`7o00000Oooool00003o`000?oooooo003o00Go003o1?ooool5o`00o`gooooo
1Ol00?l3ooooo`Oo003o0_ooool6ool000Sooooo1Ooo0005ooooo`coo`0000Coooooool00?oo003o
o`002Oooool9ool00003oooooooo003oo`0000Goo`001?ooool8o`00o`Oooooo1Ol00?l00ooooooo
003oo`00o`08o`00oa7ooooo1Ol00?l:ooooo`Goo`0000?oooooool00?oo00000ooo0007oooooa?o
o`000_ooool3ool002Kooooo2_l00?l2ooooo`Wo003o1Oooool1o`00007ooooo00000ol0003ooooo
ooooo`03o`00o`Gooooo1Ol00?l>ooooo`Go003o0oooool6o`00o`Cooooo1_oo0002ooooo`?oo`00
0_ooool5ool000Kooooo2ooo000<ooooo`Woo`001?ooool5ool000Gooooo1ol00?l7ooooo`Go003o
00?oooooo`00ool00?l00ol00?l01?oooooo003oo`00ool00?lBooooo`Go003o2_ooool;ool000Oo
oooo4_oo000]ooooo`?o003o0_ooool5o`00o`03ooooool00?oo003o00Ko003o1_ooool1o`00007o
oooo00000ol0003oooooooooo`02ooooo`?o003o0_ooool5o`00o`Cooooo0ol00?l8ooooo`Go003o
1?ooool3o`00o`Kooooo1_oo00000oooooooo`00ool00003ool00003oooooooo003oo`0000?oo`00
1Oooool<ool000cooooo2?oo0005ooooo`Goo`002?ooool9o`00o`?ooooo0ol00?l2ooooo`Go003o
5_ooool5o`00o`_ooooo0ooo00000oooooooo`00ool00006ool000Gooooo4Ooo000Gooooo`?oo`00
6Oooool5o`00o`03ooooool00?oo003o00?o003o2Oooool1o`00007ooooo00001?l0003ooooooooo
ooooool5o`00o`03ooooool00?oo003o00?o003o0oooool5o`00o`Sooooo0ol00?l>ooooo`Koo`00
00?oooooool00?oo00002?oo0006oooooa3oo`002?ooool9ool000Gooooo0ooo000;ooooo`So003o
1Oooool7o`00o`;ooooo0ol00?l6ooooo`?o003o2Oooool3o`00oa3ooooo2Ooo0005ooooo`[oo`00
0_ooool3ool0013ooooo0ooo0004ooooo`Goo`006?ooool5o`00o`03ooooool00?oo003o00?o003o
2Oooool1o`00007ooooo00001?l0003oooooooooooooool5o`00o`03ooooool00?oo003o00?o003o
0oooool5o`00oaWooooo1Ooo0002ooooo`[oo`001_ooool5ool000Gooooo1ooo0008ooooo`Soo`00
4oooool8o`00o`Cooooo2?l00?l00ooooooo003oo`00o`03o`00o`Cooooo1Ol00?l00ooooooo003o
o`00o`04o`00oaGooooo2?oo0008ooooo`Koo`003?ooool3ool000Kooooo1Ooo0003ooooo`Goo`00
6Oooool3o`00o`?ooooo0ol00?l:ooooo`7o00000Oooool00003o`000?oooooooooo00Ko003o0_oo
ool3o`00o`Cooooo1Ol00?lJooooo`?oo`001?ooool3ool00003oooooooo003oo`0000?oo`001ooo
ool3ool000Kooooo1ooo000;ooooo`Goo`004oooool9o`00o`?ooooo2?l00?l00ooooooo003oo`00
o`03o`00o`Cooooo3Ol00?lGooooo`Goo`001Oooool8ool000Sooooo0ooo00000oooooooo`00ool0
0003ool000Gooooo1Ooo0003ooooo`Goo`00;?ooool1o`00007ooooo00000ol0003oooooooooo`05
o`00o`_ooooo0ol00?lWooooo`?oo`004Oooool7ool000_ooooo1Ooo000Cooooo`[o003o0_ooool7
o`00o`;ooooo1Ol00?l4ooooo`go003o6?ooool3ool000Gooooo1ooo0009ooooo`[oo`000_ooool8
ool000;ooooo1Ooo000]ooooo`7o00000Oooool00003o`000?oooooooooo00Go003o0oooool3o`00
od?ooooo1_oo000<ooooo`Goo`004oooool:o`00o`?ooooo2?l00?l01?oooooo003oo`00ool00?l6
ooooo`co003o2oooool3ool000Gooooo0ooo0006ooooo`?oo`0000?oooooool00?oo00001Ooo0009
ooooo`[oo`0000?oooooool00?oo00001_oo0002ooooo`Goo`002oooool3o`00oa?ooooo0ol00?l:
ooooo`7o00000Oooool00003o`000?l00?oo003o00Co003o0oooool5o`00oa3ooooo0ol00?l_oooo
o`Goo`002?ooool3ool000;ooooo1Ooo000Cooooo`[o003o0oooool9o`00o`[ooooo0ol00?l00ooo
oooo003oo`00o`04o`00o`_ooooo1Ooo0003ooooo`Goo`001?ooool<ool000Wooooo1Ooo00001?oo
ooooo`00ool00?oo0002ooooo`Goo`001Oooool5ool000[ooooo1Ol00?lAooooo`Go003o2Oooool1
o`00007ooooo0005o`00o`Gooooo1Ol00?l?ooooo`Go003o9oooool3ool000Gooooo0ooo0008oooo
o`Goo`000_ooool3ool001Gooooo1?l00?l00ooooooo003oo`00o`03o`00o`;ooooo2Ol00?lOoooo
o`Goo`000oooool5ool000Cooooo1Ooo00000oooooooo`00ool00005ool000;ooooo1Ooo0002oooo
o`?oo`001oooool5ool000Gooooo1Ooo000:ooooo`Go003o4Oooool5o`00o`Wooooo0Ol00001oooo
o`001Ol00?l5ooooo`Go003o3oooool5o`00o`Cooooo0ol00?l4ooooo`?oo`006?ooool8ool000co
oooo1Ooo000;ooooo`?oo`004Oooool5o`00o`?ooooo2?l00?l5ooooo`?o003o4_ooool3ool000;o
oooo1Ooo0003ooooo`Goo`001?ooool5ool00003oooooooo003oo`0000goo`001_ooool3ool000?o
oooo0ooo0006ooooo`Coo`000ol00?l8ooooo`Go003o4Oooool5o`00o`Wooooo0Ol00001ooooo`00
1Ol00?l6ooooo`?o003o4?ooool5o`00o`?ooooo1Ol00?l2ooooo`Ooo`002oooool3ool000Oooooo
2Ooo000;ooooo`Goo`002_ooool5ool0013ooooo2?l00?l4ooooo`?o003o1Oooool5o`00oa3ooooo
1Ooo0002ooooo`?oo`001Oooool3ool000Kooooo0ooo0002ooooo`ooo`001Oooool5ool000_ooooo
0ooo0005o`00o`Sooooo0ol00?lCooooo`?o003o2_ooool1o`00007ooooo00001?l0003o003oo`00
ool00?lKooooo`Go003o0_ooool5o`00o`;ooooo2?oo0009ooooo`Goo`001_ooool9ool000cooooo
0ooo000;ooooo`Goo`004Oooool8o`00o`_ooooo1Ol00?l@ooooo`Goo`004_ooool3ool000?ooooo
3ooo0005ooooo`Soo`002Oooool2ool000Go003o:oooool1o`00007ooooo00000ol0003ooooooooo
o`0Mooooo`Go003o00?oooooo`00ool00?l00ol00?l2ooooo`Soo`000_ooool3ool000Cooooo1Ooo
0002ooooo`?oo`000_ooool8ool000Sooooo0ooo000?ooooo`Goo`004_ooool7o`00o`_ooooo1Ol0
0?l01?oooooo003oo`00ool00?l<ooooo`Goo`001_ooool3ool000Cooooo0ooo00000oooooooo`00
ool00003ool000?ooooo3Ooo0002ooooo`?oo`0000?oooooool00?oo00001ooo0007ooooo`?oo`00
1Ol00?lFooooo`?o003o0_ooool6o`00o`[ooooo0Ol00001ooooo`0000?o0000ooooooooool07Ooo
ool5o`00o`;ooooo0ol00?l4ooooo`Ooo`0000?oooooool00?oo00000ooo0003ooooo`Goo`0000?o
ooooool00?oo00000ooo0005ooooo`?oo`002?ooool5ool000oooooo0ooo000Booooo`So003o3?oo
ool3o`00o`03ooooool00?oo003o00?o003o3?ooool3ool000;ooooo0ooo00000oooooooo`00ool0
0003ool000;ooooo2_oo00001?ooooooo`00ool00?oo0004ooooo`Soo`0000?oooooool00?oo0000
0ooo00000oooooooo`00ool00006ool000Kooooo1?oo0004o`00oaKooooo3Ol00?l9ooooo`7o0000
0Oooool00003o`000?oooooooooo01gooooo1Ol00?l<ooooo`?oo`0000?oooooool00?oo00001?oo
0003ooooo`Goo`0000?oooooool00?oo00001?oo000?ooooo`Goo`005oooool3ool000[ooooo1ol0
0?lAooooo`Go003o4?ooool:ool000;ooooo3ooo0004ooooo`Ooo`0000?oooooool00?oo00000ooo
0004ooooo`Goo`001_ooool3ool000Go003o4Oooool3o`00o`;ooooo3Ol00?l9ooooo`7o00000Ooo
ool00003o`000?oooooooooo00_ooooo0ol00?l5ooooo`Ko003o1Oooool3o`00o`[ooooo0ol00?l3
ooooo`Ooo`000oooool5ool00003oooooooo003oo`0000Goo`003_ooool5ool0017ooooo0ooo0002
ooooo`Goo`002Oooool5o`00o`oooooo0ol00?l00ooooooo003oo`00o`03o`00oa3ooooo2_oo0002
ooooo`Goo`0000?oooooool00?oo00001ooo0004ooooo`Koo`000_ooool5ool000Cooooo1Ooo0006
ooooo`?oo`001Ol00?l@ooooo`Go003o00?oooooo`00ool00?l02ol00?l9ooooo`7o00000Oooool0
0003o`000?oooooooooo00Gooooo0ol00?l2ooooo`Go003o0oooool8o`00oa3ooooo1Ol00?l2oooo
o`Koo`001?ooool5ool00003oooooooo003oo`0000Goo`003oooool3ool000Wooooo1?oo0004oooo
o`Goo`0000?oooooool00?oo00000ooo000:ooooo`?o003o3Oooool7o`00o`04ooooool00?oo003o
o`00oa7ooooo2_oo0003ooooo`?oo`000_ooool9ool000Gooooo0ooo00000oooooooo`00ool00006
ool000Cooooo1Ooo0007ooooo`;oo`001Ol00?l@ooooo`Go003o0_ooool3o`00o`;ooooo1ol00?l9
ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo1Ol00?l00ooooooo003oo`00o`03o`00
o`?ooooo2?l00?l:ooooo`?o003o0oooool5o`00o`;ooooo1Ooo0006ooooo`?oo`0000?oooooool0
0?oo00001_oo000Jooooo`Koo`000oooool5ool00003oooooooo003oo`0000?oo`005oooool:o`00
oaCooooo2ooo0009ooooo`?oo`0000?oooooool00?oo00000ooo0007ooooo`Woo`001Oooool3ool0
00_ooooo0ol00?lAooooo`Go003o2_ooool3o`00o`[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool01?ooool5o`00o`03ooooool00?oo003o00?o003o0oooool8o`00o`Wooooo1Ol00?l2ooooo`Go
003o0oooool3ool000_ooooo1ooo0007ooooo`?oo`004Oooool6ool000?ooooo1Ooo0002ooooo`?o
o`005oooool;o`00oa3ooooo0ooo00000oooooooo`00ool00003ool00003oooooooo003oo`0000;o
o`003_ooool5ool000Oooooo2?oo000Yooooo`?o003o6?ooool1o`00007ooooo00000ol0003ooooo
ooooo`04ooooo`Go003o0_ooool3o`00o`Gooooo1_l00?l:ooooo`Go003o0oooool3o`00o`?oo`00
3oooool5ool000Sooooo1ooo00001?ooooooo`00ool00?oo000:ooooo`Koo`001?ooool3ool000Go
oooo1Ooo000Booooo`_o003o3Oooool=ool001?ooooo1Ooo0007ooooo`Goo`001?ooool3ool002;o
oooo0ol00?l9ooooo`?o003o3oooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`?o003o
0_ooool3o`00o`Kooooo0ol00?l=ooooo`Go003o1Oooool5ool000_ooooo0ooo00001?ooooooo`00
ool00?oo0009ooooo`coo`000_ooool3ool000Cooooo1Ooo000<ooooo`Ooo`004?ooool9o`00o`Go
oooo0ol00?l7ooooo`goo`002_ooool3ool000Oooooo1Ooo0008ooooo`?oo`001?ooool5ool0023o
oooo1Ol00?l7ooooo`Go003o3_ooool1o`00007ooooo00000ol0003oooooooooo`04ooooo`?o003o
0_ooool5o`00o`?ooooo1_l00?l=ooooo`?o003o1_ooool6ool000Wooooo1Ooo000<ooooo`coo`00
00?oooooool00?oo00001?oo0002ooooo`Goo`0000Goooooool00?oo003oo`00ooooo`03ool000Co
oooo1ooo000@ooooo`So003o0oooool2ool000Go003o1_ooool<ool000[ooooo1Ooo0006ooooo`Go
o`0000Coooooool00?oo003oo`002oooool8ool001gooooo1Ol00?l7ooooo`Go003o2?ooool3o`00
o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool5o`00o`03ooooool00?oo003o00?o
003o0_ooool7o`00o`?ooooo0ol00?l@ooooo`Koo`002Oooool8ool000[ooooo2ooo00000ooooooo
o`00ool00005ool000;ooooo3Ooo0003ooooo`Woo`003_ooool5o`00o`Gooooo0ooo0005o`00o`Go
oooo3Ooo000:ooooo`Goo`001oooool9ool000[ooooo2Ooo0002ooooo`?oo`001?ooool3o`00oa3o
oooo1Ol00?l7ooooo`Go003o1oooool5o`00o`;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
0oooool5o`00o`03ooooool00?oo003o00?o003o0_ooool7o`00o`;ooooo1Ol00?l@ooooo`Goo`00
2Oooool9ool000Wooooo2_oo0002ooooo`Ooo`000_ooool=ool000Cooooo2Ooo000>ooooo`?o003o
1Oooool4ool000Go003o1Oooool7ool00003oooooooo003oo`0000?oo`002_ooool7ool000Gooooo
2Ooo000;ooooo`Soo`0000?oooooool00?oo00000ooo0002ooooo`Go003o1_ooool3o`00o`Oooooo
1_l00?l6ooooo`?o003o2?ooool5o`00o`;ooooo0Ol00001ooooo`0000?o0000ooooool00?l00_l0
0?l00ooooooo003oo`00o`03o`00o`;ooooo1Ol00?l00ooooooo003oo`00o`04o`00o`?ooooo1Ol0
0?lAooooo`Goo`001_ooool;ool000Sooooo3?oo0002ooooo`Koo`000_ooool=ool000Sooooo1Ooo
000Eooooo`Koo`000ol00?l6ooooo`Ooo`000_ooool3ool000Wooooo2_oo0004ooooo`Woo`003_oo
ool5ool00003oooooooo003oo`0000?oo`000_ooool5o`00o`Gooooo1Ol00?l8ooooo`Go003o4?oo
ool5o`00o`;ooooo0Ol00001ooooo`0000?o0000o`00ool00?l00ol00?l01?oooooo003oo`00ool0
0?l4ooooo`[o003o1?ooool5o`00o`Kooooo0ol00?l8ooooo`Goo`0000Goooooool00?oo003oo`00
ooooo`05ool000;ooooo1_oo00001?ooooooo`00ool00?oo0003ooooo`goo`000oooool3ool000Co
oooo4Ooo0002ooooo`Koo`002?ooool3ool000[ooooo1_oo000:ooooo`Goo`003_ooool;ool000Go
oooo0ooo00001?ooooooo`00ool00?oo000<ooooo`koo`000_ooool5o`00o`Gooooo1Ol00?l3oooo
o`?o003o0_ooool5o`00oa7ooooo0ol00?l3ooooo`7o00000Oooool00003o`000?l00?oo003o00?o
003o2?ooool:o`00o`Gooooo1_l00?l3ooooo`Go003o1oooool?ool000?ooooo2_oo0002ooooo`go
o`002_ooool8ool000;ooooo2?oo00000oooooooo`00ool00003ool00004oooooooo003oo`00ool0
00Cooooo1Ooo0009ooooo`Goo`0000Coooooool00?oo003oo`003_ooool3ool000;ooooo0ooo0004
ooooo`_oo`005ooooolAool00004ooooool00?oo003oo`00o`Cooooo1ol00?l2ooooo`Go003o00?o
ooooo`00ool00?l00ol00?l;ooooo`?o003o2Oooool1o`00007ooooo00000ol0003o003oo`00o`03
o`00o`Sooooo1Ol00?l01?oooooo003oo`00ool00?l6ooooo`Oo003o0_ooool5o`00o`Sooooo0ooo
00000oooooooo`00ool00008ool000;ooooo2ooo0003ooooo`coo`002_ooool7ool000?ooooo2?oo
00000oooooooo`00ool00008ool000?ooooo1_oo0009ooooo`?oo`0000?oooooool00?oo00000ooo
000<ooooo`[oo`000oooool:ool000[ooooo0ooo000;oooooa;oo`001_ooool7o`00o`?ooooo1Ol0
0?l2ooooo`?o003o2oooool5o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooool00?l00_l00?l:
ooooo`?o003o2oooool7o`00o`;ooooo1Ol00?l<ooooo`Goo`0000Coooooool00?oo003oo`000ooo
ool;ool000Gooooo2Ooo000;ooooo`Koo`001?ooool8ool00003oooooooo003oo`00017oo`003Ooo
ool5ool000Cooooo0ooo0005ooooo`[oo`001?ooool7ool00004oooooooo003oo`00ool000Oooooo
1_oo0009oooooa;oo`001_ooool5o`00o`Gooooo1Ol00?l@ooooo`Go003o2?ooool1o`00007ooooo
00000ol0003oooooo`00o`05o`00oaKooooo1_l00?l3ooooo`?o003o3?ooool6ool000Oooooo1_oo
00001?ooooooo`00ool00?oo0007ooooo`Ooo`001Oooool5ool000;ooooo1_oo0005ooooo`Koo`00
0_oooolCool000Oooooo0ooo0003ooooo`Goo`000oooool5ool000Cooooo2_oo0005ooooo`_oo`00
00Coooooool00?oo003oo`000_ooool7ool000Cooooo4?oo00000oooooooo`00ool00003ool000Ko
oooo1Ol00?l6ooooo`?o003o4Oooool5o`00o`Sooooo0Ol00001ooooo`0000?o0000o`00ool00?l0
1_l00?lEooooo`Go003o2?ooool3o`00o`Sooooo1_oo0005ooooo`Ooo`001Oooool3ool000Kooooo
1Ooo0003oooooa3oo`003?oooolBool000Oooooo1Ooo0003ooooo`coo`001Oooool3ool000;ooooo
0ooo0008ooooo`koo`0000?oooooool00?oo00001Ooo0003ooooo`Ooo`000_ooool5ool000Gooooo
0ooo0008ooooo`?o003o7?ooool3o`00o`Wooooo0Ol00001ooooo`0000?o0000o`00ool00?l01_l0
0?lDooooo`Ko003o1oooool5o`00o`Oooooo1ooo0003ooooo`Ooo`001Oooool5ool000Kooooo0ooo
0003oooooa;oo`003?ooool5ool00003oooooooo003oo`0000Koo`002_ooool5ool00005oooooooo
003oo`00ool00?ooool02_oo000Gooooo`coo`000_ooool6ool000?ooooo1ooo0003ooooo`Coo`00
1Oooool3o`00o`oooooo0ol00?lGooooo`?o003o1oooool1o`00007ooooo00000ol0003o003oo`00
o`07o`00oa?ooooo1_l00?l7ooooo`Go003o2?ooool7ool00003oooooooo003oo`0000Koo`001Ooo
ool6ool000_ooooo4_oo000;ooooo`Goo`000oooool6ool000_ooooo4ooo00001?ooooooo`00ool0
0?oo0007ooooo`?oo`002_ooool<ool000Cooooo0ooo0004ooooo`Ooo`000_ooool6ool000?ooooo
1Ol00?l=ooooo`Go003o1_ooool3o`00o`cooooo1Ol00?l6ooooo`7o00000Oooool00003o`000?oo
oooo003o00Oo003o4oooool6o`00o`Oooooo1Ol00?l:ooooo`Goo`0000?oooooool00?oo00001_oo
0005ooooo`Koo`002?oooolEool000_ooooo1Ooo0002ooooo`Koo`001?ooool3ool000Kooooo0ooo
00000oooooooo`00ool0000;ool00003oooooooo003oo`0000?oo`001Oooool5ool000[ooooo1_oo
00001?ooooooo`00ool00?oo0002ooooo`?oo`002?ooool5ool00003oooooooo003oo`0000Koo`00
0oooool5o`00o`gooooo1Ol00?l5ooooo`Go003o2oooool5o`00o`Kooooo0Ol00001ooooo`0000?o
0000ooooooooool01ol00?lDooooo`Ko003o0_ooool3o`00o`03ooooool00?oo003o00?o003o2_oo
ool5ool00003oooooooo003oo`0000Koo`001_ooool6ool000Kooooo5Ooo000<ooooo`Goo`000_oo
ool5ool000Cooooo1Ooo0009ooooo`_oo`000oooool5ool000Gooooo1Ooo0002ooooo`?oo`001Ooo
ool6ool000Cooooo1_oo000<ooooo`Woo`000oooool5o`00o`gooooo1ol00?l3ooooo`Go003o2ooo
ool5o`00o`Kooooo0Ol00001ooooo`0000?o0000ooooooooool01_l00?lGooooo`oo003o0oooool3
o`00o`Cooooo1Ooo0002ooooo`Koo`002?ooool6ool000Gooooo2?oo00000oooooooo`00ool00004
ool001?ooooo0ooo0003ooooo`Goo`001?ooool5ool000Kooooo0ooo00001Oooooooo`00ool00?oo
003ooooo00Goo`000oooool6ool000Gooooo1Ooo00000oooooooo`00ool00003ool000Gooooo1?oo
0004ooooo`Ooo`001?ooool3ool000Gooooo2?oo0005ooooo`?o003o3oooool7o`00o`;ooooo1Ol0
0?l<ooooo`?o003o1oooool1o`00007ooooo00000ol0003oooooooooo`05o`00oaSooooo2_l00?l0
1?oooooo003oo`00ool00?l2ooooo`Ko003o1?ooool3ool001;ooooo1Ooo0005ooooo`koo`0000?o
ooooool00?oo00001?oo000Dooooo`?oo`001Oooool5ool000Cooooo1_oo0004ooooo`Koo`000_oo
ool7ool000Gooooo0ooo0002ooooo`Goo`003Oooool7ool000?ooooo1Ooo0004ooooo`Soo`006Ooo
ool5o`00o`?ooooo0ol00?lGooooo`7o00000Oooool00004o`000?ooooooooooooooo`?o003o6Ooo
oolFo`00oaWooooo1Ooo0005ooooo`Ooo`0000?oooooool00?oo00000ooo00000oooooooo`00ool0
0006ool000[ooooo0ooo000?ooooo`?oo`001?ooool7ool000Gooooo1Ooo0002ooooo`Ooo`001Ooo
ool3ool000;ooooo2?oo000:ooooo`Koo`001?ooool5ool000Gooooo1_oo00001?ooooooo`00ool0
0?oo000Fooooo`Go003o7Oooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`?o003o0ooo
ool3o`00o`;ooooo4?l00?l7ooooo`?oo`004?ooool3ool000Kooooo1_oo0002ooooo`Goo`0000?o
ooooool00?oo00001_oo0003ooooo`?oo`000oooool5ool001;ooooo2ooo0004ooooo`koo`001?oo
ool5ool00003oooooooo003oo`0000Ooo`002Oooool5ool000Gooooo1Ooo0007ooooo`Woo`004_oo
ool:o`00oa_ooooo0Ol00001ooooo`0000?o0000ooooooooool04Oooool3o`00o`?ooooo1Ol00?l7
oooooa;o003o1?ooool5ool001;ooooo0ooo0003ooooo`Koo`000_ooool5ool00003oooooooo003o
o`0000Koo`000_ooool5ool00003oooooooo003oo`0000Coo`003oooool>ool000?ooooo3ooo0004
ooooo`Goo`0000?oooooool00?oo00001ooo000:ooooo`?oo`001_ooool6ool000Sooooo1ooo000A
ooooo`Ko003o00?oooooo`00ool00?l00ol00?l<ooooo`?o003o2oooool1o`00007ooooo00000ol0
003oooooooooo`0@ooooo`Go003o0_ooool5o`00o`Oooooo3Ol00?l00ooooooo003oo`00o`03o`00
o`?ooooo1Ooo000;ooooo`?oo`000oooool5ool000?ooooo1_oo00000oooooooo`00ool00003ool0
00;ooooo1ooo0002ooooo`koo`003?ooool?ool000;ooooo1Ooo00000oooooooo`00ool00003ool0
0004oooooooo003oo`00ool000;ooooo2?oo0002ooooo`Soo`004_ooool7ool000Sooooo1ooo000A
ooooo`Ko003o00?oooooo`00ool00?l00ol00?l;ooooo`Go003o2_ooool1o`00007ooooo00000ol0
003oooooooooo`0@ooooo`Go003o0_ooool7o`00o`Kooooo0ol00?l00ooooooo003oo`00o`03o`00
o`Cooooo1Ol00?l3ooooo`Goo`002_ooool5ool000;ooooo1Ooo0004ooooo`Koo`0000Coooooool0
0?oo003oo`001_ooool3ool000?ooooo3ooo000;ooooo`Soo`000oooool3ool000?ooooo1Ooo0000
0oooooooo`00ool00003ool000Gooooo2?oo0007ooooo`Koo`004?ooool7ool000Gooooo2Ooo000B
ooooo`Ko003o00?oooooo`00ool00?l00ol00?l3ooooo`?o003o1Oooool5o`00o`[ooooo0Ol00001
ooooo`0000?o0000ooooooooool03_ooool7o`00o`?ooooo1ol00?l:ooooo`?o003o1Oooool6o`00
o`03oooooooo003oo`0000Coo`002_ooool6ool00003oooooooo003oo`0000?oo`001Oooool5ool0
00;ooooo0ooo000<ooooo`?oo`0000?oooooool00?oo00002?oo000;ooooo`Ooo`000_ooool3ool0
00Gooooo1Ooo0002ooooo`?oo`001_ooool5ool000cooooo1_oo000>ooooo`Koo`001Oooool8ool0
01Gooooo1?l00?l3ooooo`?o003o0oooool5o`00o`Cooooo1Ol00?l:ooooo`7o00000Oooool00003
o`000?oooooooooo00gooooo1ol00?l6ooooo`Go003o4oooool5o`00o`03oooooooo003oo`0000?o
o`002oooool6ool000;ooooo0ooo0006ooooo`Goo`0000?oooooool00?oo00000ooo000:ooooo`?o
o`000oooool:ool000Gooooo0ooo0003ooooo`?oo`001?ooool5ool000Gooooo2_oo0004ooooo`Ko
o`003?ooool7ool000kooooo1?oo00001?ooooooo`00ool00?oo0002ooooo`Goo`009Oooool5o`00
o`Gooooo0ol00?l7ooooo`?o003o0Oooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`Go
003o2?ooool5o`00oa?ooooo1Ol00?l00oooooooo`00ool00003ool000_ooooo1_oo000<ooooo`[o
o`002Oooool6ool000;ooooo2_oo0003ooooo`Goo`002Oooool5ool000;ooooo0ooo0002ooooo`[o
o`000_ooool5ool000Sooooo0ooo0002ooooo`Soo`004Oooool5ool00003oooooooo003oo`0000?o
o`001_ooool3o`00oa_ooooo1_l00?l>ooooo`Go003o0Ol00001ooooo`0000?o0000ooooooooool0
3Oooool7o`00o`Oooooo0ol00?lDooooo`Go003o00?oooooool00?oo00000ooo000;ooooo`Goo`00
0oooool3ool000Oooooo2_oo0009ooooo`Ooo`0000?oooooool00?oo00002?oo0003ooooo`Goo`00
0_ooool3ool000Cooooo1Ooo00000oooooooo`00ool0000Fool000Kooooo1Ooo0002ooooo`Ooo`00
4Oooool5ool000;ooooo0ooo0006ooooo`Go003o4oooool3o`00o`?ooooo1_l00?l?ooooo`Go003o
0Ol00001ooooo`0000?o0000ooooooooool02Oooool3o`00o`;ooooo1ol00?lMooooo`So003o0ooo
000<ooooo`?oo`000oooool5ool000Kooooo1Ooo00001?ooooooo`00ool00?oo000:ooooo`Ooo`00
00?oooooool00?oo00002?oo0003ooooo`Goo`0000?oooooool00?oo00000ooo0004ooooo`?oo`00
0_oooolHool000Kooooo1Ooo0004ooooo`Goo`004Oooool5ool000;ooooo0ooo0006ooooo`Go003o
4_ooool5o`00o`;ooooo1Ol00?l@ooooo`Go003o0Ol00001ooooo`0000?o0000ooooooooool02?oo
ool5o`00o`?ooooo1Ol00?l5ooooo`?o003o4?ooool3o`00o`?ooooo2?l00?l3ool000Gooooo0ooo
0009ooooo`Goo`001?ooool7ool000_ooooo0ooo00000oooooooo`00ool00004ool000;ooooo0ooo
0002ooooo`?oo`001Oooool:ool000Gooooo0ooo00000oooooooo`00ool00009ool00003oooooooo
003oo`0000[oo`001_ooool5ool000Gooooo0ooo000;ooooo`?oo`001Oooool:ool000Gooooo1Ol0
0?l;ooooo`?o003o1?ooool5o`00o`;ooooo1Ol00?lAooooo`?o003o0Oooool1o`00007ooooo0000
1?l0003o003oo`00ool00?l7ooooo`Go003o0oooool5o`00o`Cooooo1Ol00?l>ooooo`Go003o1Ooo
ool5o`00o`?oo`001?ooool5ool000Sooooo1Ooo0003ooooo`coo`001_ooool5ool000;ooooo0ooo
000Aooooo`Woo`001?ooool5ool00003oooooooo003oo`0000Soo`000_ooool3ool000;ooooo1Ooo
0004ooooo`Ooo`004_ooool6ool000Gooooo2Ooo0006ooooo`?o003o2oooool5o`00o`?ooooo1Ol0
0?l3ooooo`?o003o5_ooool1o`00007ooooo0005o`00o`Kooooo1Ol00?l4ooooo`?o003o1Oooool5
o`00o`Kooooo0ol00?l5ooooo`Go003o1Oooool5o`00o`?oo`0000?oooooool00?oo00001_oo0006
ooooo`Koo`000oooool>ool000Gooooo1Ooo000Fooooo`Woo`001?ooool5ool000?ooooo1ooo0009
ooooo`?oo`001?ooool:ool000oooooo1ooo0005ooooo`Woo`005?ooool5o`00o`Cooooo0ol00?lM
ooooo`7o00000Oooool000Ko003o1_ooool3o`00o`cooooo2Ol00?l2ooooo`Go003o1?ooool5o`00
o`Kooooo0ol00?l3ool00003oooooooo003oo`0000Ooo`001Oooool5ool000Gooooo3_oo0003oooo
o`Ooo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`000oooool8ool000Gooooo2?oo0002oooo
o`?oo`002_ooool5ool000?ooooo3?oo00001?ooooooo`00ool00?oo0009ooooo`Ooo`001Oooool8
ool000?ooooo0ol00?l?ooooo`Go003o6Oooool3o`00o`Sooooo0Ol00001ooooo`001_l00?lEoooo
o`[o003o00?oooooo`00ool00?l00ol00?l5ooooo`?o003o3_ooool8ool000Kooooo1Ooo0005oooo
o`koo`000_ooool7ool000?ooooo1Ooo0002ooooo`Goo`0000?oooooool00?oo00001Ooo00000ooo
ooooo`00ool00003ool00004oooooooo003oo`00ool000Cooooo2?oo000>ooooo`Goo`000ooooolA
ool000Sooooo2?oo0005ooooo`Koo`000oooool5o`00o`oooooo0ol00?l01?oooooo003oo`00ool0
0?l4ooooo`?o003o2oooool:o`00o`Gooooo0Ol00001ooooo`0000?o0000o`00ool00?l00ol00?lE
ooooo`[o003o00?oooooo`00ool00?l00ol00?l@ooooo`?o003o0oooool7ool000Oooooo1Ooo0006
ooooo`Coo`001Oooool5ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00000ooo0002
ooooo`Goo`0000?oooooool00?oo00004?oo0006ooooo`Goo`003_ooool5ool000Cooooo4?oo0008
ooooo`Woo`000_ooool3ool000Sooooo1Ol00?lBooooo`Go003o0_ooool5o`00o`Wooooo3?l00?l4
ooooo`7o00000Oooool00003o`000?oooooo003o00;o003o5oooool3o`00o`03ooooool00?oo003o
00?o003o0_ooool3o`00o`?ooooo0ol00?l:ooooo`Go003o0oooool6ool000Sooooo0ooo000Aoooo
oaGoo`0000?oooooool00?oo00000ooo00000oooooooo`00ool0000Bool000Cooooo1Ooo000?oooo
o`?oo`001?oooolBool000Oooooo2Ooo00000oooooooo`00ool00003ool000Oooooo1Ol00?lBoooo
o`Go003o0_ooool5o`00o`Wooooo3?l00?l4ooooo`7o00000Oooool00003o`000?oooooooooo00Go
oooo0ol00?lEooooo`Go003o1oooool7o`00o`Oooooo1Ol00?l4ooooo`Goo`000_ooool3ool001Oo
oooo1Ooo00001Oooooooo`00ool00?oo003ooooo00Goo`0000?oooooool00?oo00001?oo00000ooo
ooooo`00ool00003ool00003oooooooo003oo`0001;oo`001?ooool3ool001Oooooo4ooo0007oooo
o`Soo`0000?oooooool00?oo00000ooo0007ooooo`Go003o4_ooool5o`00o`;ooooo1Ol00?l9oooo
o`co003o1?ooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`Wo003o4Oooool5o`00o`Oo
oooo2?l00?l2ooooo`?o003o00?oooooo`00ool00?l00ol00?l4ooooo`_oo`004Oooool3ool000;o
oooo1Ooo0005ooooo`Goo`0000?oooooool00?oo00002_oo00000oooooooo`00ool0000:ool00003
oooooooo003oo`0000Koo`004_ooool3ool000Sooooo4ooo000;ooooo`?oo`0000?oooooool00?oo
00001?oo0007ooooo`Go003o4oooool3o`00o`Cooooo0ol00?l01?oooooo003oo`00ool00?l7oooo
o`?o003o1?ooool3o`00o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool;o`00o`oo
oooo1ol00?l6ooooo`So003o00?oooooo`00ool00?l00ol00?l01?oooooo003oo`00ool00?l5oooo
o`_oo`000oooool3ool000[ooooo1Ooo0002ooooo`?oo`001ooooolAool00003oooooooo003oo`00
00Koo`001Oooool9ool000Kooooo0ooo0007ooooo`Goo`002?ooool3ool00003oooooooo003oo`00
00coo`001_ooool3ool000Gooooo1_oo0009ooooo`?o003o2?ooool3o`00oa?ooooo1Ol00?l6oooo
o`?o003o3?ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`_o003o3_ooool9o`00o`Ko
oooo3Ol00?l:ooooo`[oo`000_ooool5ool000Wooooo1_oo000=ooooo`koo`000_ooool5ool000Oo
oooo3Ooo0002ooooo`Goo`001_ooool5ool000Kooooo0ooo0004ooooo`?oo`0000Coooooool00?oo
003oo`000_ooool3ool000Kooooo1Ooo0004ooooo`Goo`004?ooool3o`00o`03ooooool00?oo003o
00?o003o4_ooool5o`00o`Gooooo1Ol00?l;ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo2ol00?l>ooooo`Wo003o2Oooool3o`00o`03ooooool00?oo003o00Co003o3?ooool7ool000?o
oooo1Ooo0004ooooo`?oo`000_ooool6ool000gooooo1Ooo00000oooooooo`00ool00004ool000?o
oooo1Ooo0008ooooo`koo`0000?oooooool00?oo00000ooo0006ooooo`Goo`001Oooool5ool001Go
oooo1ooo0002ooooo`Goo`003oooool:o`00oa;ooooo1Ol00?l5ooooo`Go003o2oooool1o`00007o
oooo00000ol0003oooooooooo`03ooooo`?o003o0oooool3o`00o`Wooooo0ol00?l3ooooo`Wo003o
3Oooool5o`00o`kooooo0ooo0006ooooo`Goo`000oooool5ool000;ooooo1Ooo000=ooooo`Goo`00
0_ooool5ool000;ooooo1Ooo0009ooooo`Goo`0000?oooooool00?oo00001_oo00000oooooooo`00
ool00003ool000Oooooo0ooo0004ooooo`Ooo`005Oooool:ool000?o003o4?ooool:o`00oa;ooooo
1Ol00?l5ooooo`Go003o2oooool1o`00007ooooo00000ol0003oooooooooo`0Dooooo`Go003o0ooo
ool3o`00o`04ooooool00?oo003oo`00o`oooooo0ol00?lIooooo`?oo`001?ooool5ool000?ooooo
0ooo000?ooooo`?oo`001?ooool3ool000?ooooo1Ooo000:ooooo`?oo`001Oooool5ool00003oooo
oooo003oo`0000;oo`003_ooool8ool001Kooooo1ooo0008o`00o`cooooo2_l00?l2ooooo`?o003o
0_ooool3o`00o`[ooooo0ol00?l7ooooo`?o003o0_ooool6o`00o`Cooooo0Ol00001ooooo`0000?o
0000ooooooooool05?ooool5o`00ob_ooooo0ol00?l>ooooo`Goo`0000?oooooool00?oo00001Ooo
000Jooooo`Koo`004_ooool3ool00003oooooooo003oo`0000?oo`001oooool3ool000?ooooo2_oo
000Cooooo`?oo`0000?oooooool00?oo00000_oo000:o`00o`[ooooo2ol00?l00ooooooo003oo`00
o`08o`00oaOooooo2?l00?l3ooooo`7o00000Oooool00003o`000?oooooooooo01Cooooo1Ol00?lZ
ooooo`Go003o2_ooool3ool00005oooooooo003oo`00ool00?ooool02_oo0004ooooo`?oo`001?oo
ool3ool000?ooooo0ooo0005ooooo`Goo`003oooool6ool00003oooooooo003oo`0000?oo`001_oo
ool5ool000;ooooo2ooo000Aooooo`Goo`0000Coooooool00?oo003oo`002_l00?l:ooooo`Go003o
0_ooool3o`00o`;ooooo2_l00?lGooooo`So003o0oooool1o`00007ooooo00000ol0003ooooooooo
o`08ooooo`?o003o2_ooool3o`00ob_ooooo1Ol00?l9ooooo`Goo`001?ooool;ool000;ooooo1Ooo
0002ooooo`Goo`0000?oooooool00?oo00000ooo0004ooooo`Ooo`003?ooool=ool000Kooooo1Ooo
0002ooooo`Goo`0000?oooooool00?oo00000ooo000Aooooo`Goo`001?ooool<o`00o`Sooooo1_l0
0?l6ooooo`[o003o5oooool8o`00o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool5
o`00ocOooooo2?l00?l6ooooo`Goo`001?ooool;ool000;ooooo1Ooo0002ooooo`Goo`0000?ooooo
ool00?oo00000ooo0005ooooo`Ooo`000_ooool3ool000Kooooo2?oo00001?ooooooo`00ool00?oo
0007ooooo`Goo`000oooool3ool000;ooooo1Ooo000Aooooo`Goo`001Oooool3o`00o`03ooooool0
0?oo003o00Ko003o2?ooool5o`00o`Gooooo1Ol00?l2ooooo`?o003o6Oooool6o`00o`Cooooo0Ol0
0001ooooo`0000?o0000ooooooooool01oooool5o`00ocSooooo2?l00?l5ooooo`Koo`001?ooool:
ool000;ooooo1Ooo0002ooooo`_oo`001oooool5ool00003oooooooo003oo`0000?oo`001Oooool8
ool000cooooo0ooo000:ooooo`?oo`004_ooool5ool000Cooooo1Ol00?l00ooooooo003oo`00o`05
o`00o`Sooooo1Ol00?l4ooooo`Go003o8Oooool5o`00o`?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool01oooool6o`00o`Oooooo0ol00?l`ooooo`Go003o1?ooool7ool000;ooooo0ooo00000ooo
ooooo`00ool00005ool000Cooooo0ooo0004ooooo`[oo`001oooool5ool00003oooooooo003oo`00
00?oo`001_ooool8ool001Kooooo1?oo000Aooooo`Ooo`001?ooool5o`00o`?ooooo1Ol00?l7oooo
o`Go003o1Oooool5o`00ob3ooooo1ol00?l2ooooo`7o00000Oooool00003o`000?oooooooooo00So
oooo1ol00?l4ooooo`Go003o;oooool5o`00o`?ooooo4_oo000@ooooo`[oo`001_ooool3ool000;o
oooo1Ooo000:ooooo`Goo`003oooool3ool000;ooooo1_oo000?ooooo`Soo`001?ooool5o`00o`Co
oooo0ol00?l8ooooo`Go003o1Oooool6o`00oa3ooooo0ol00?l<ooooo`Oo003o0_ooool1o`00007o
oooo00000ol0003oooooooooo`09ooooo`Oo003o0oooool5o`00oa7ooooo0ol00?lJooooo`Go003o
1?oooolCool000oooooo2ooo000;ooooo`?oo`002oooool5ool000kooooo1Ooo00000oooooooo`00
ool00004ool000oooooo1ooo0006ooooo`?o003o4?ooool5o`00o`Kooooo1Ol00?l?ooooo`Go003o
2oooool7o`00o`;ooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool:o`00o`?ooooo1Ol0
0?l@ooooo`Oo003o5_ooool5o`00o`Gooooo5?oo000?ooooo`[oo`006Oooool5ool000kooooo1Ooo
00000oooooooo`00ool00004ool000Wooooo0ooo0003ooooo`Goo`006oooool4o`00o`Oooooo1Ol0
0?l5ooooo`?o003o1oooool5o`00o`cooooo1Ol00?l3ooooo`7o00000Oooool00003o`000?oooooo
oooo00Gooooo2ol00?l4ooooo`?o003o4Oooool8o`00oaGooooo1Ol00?l6ooooo`;oo`000ol00?l>
ool000?ooooo0ooo000=ooooo`Koo`001Oooool3ool0017ooooo1Ooo000>ooooo`Goo`0000?ooooo
ool00?oo00000ooo0002ooooo`?oo`0000?oooooool00?oo00001_oo0003ooooo`?oo`006oooool8
o`00o`Gooooo0ol00?l5ooooo`Go003o1_ooool5o`00oaCooooo0Ol00001ooooo`0000?o0000oooo
ooooool01Oooool5o`00o`;ooooo0ol00?l2ooooo`?o003o5?ooool8o`00oaGooooo1Ol00?l7oooo
o`Go003o1_oo00000oooooooo`00ool00004ool000;ooooo1Ooo000>ooooo`?oo`001Oooool5ool0
013ooooo1Ooo0005ooooo`?oo`001oooool3ool000;ooooo1Ooo00000oooooooo`00ool0000;ool0
027ooooo2ol00?l:ooooo`Go003o1oooool3o`00o`?ooooo0ol00?l?ooooo`7o00000Oooool00003
o`000?oooooooooo00Gooooo1Ol00?l6ooooo`Go003o5?ooool7o`00oaKooooo0ol00?l8ooooo`Go
003o1_oo00000oooooooo`00ool00003ool000?ooooo1Ooo000Fooooo`Goo`004?ooool5ool000Co
oooo1Ooo0008ooooo`Ooo`000_ooool>ool0023ooooo3?l00?l9ooooo`Go003o3?ooool5o`00o`ko
oooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool3o`00o`Oooooo1Ol00?lDooooo`Ko003o
2_ooool3o`00oaGooooo1Ol00?l2ooooo`?oo`000_ooool=ool000kooooo0ooo0005ooooo`Goo`00
0_ooool3ool000cooooo0ooo0005ooooo`Soo`001?ooool6ool000Cooooo3_oo000<ooooo`?o003o
4_ooool;o`00o`[ooooo0ol00?l;ooooo`Oo003o3_ooool1o`00007ooooo00000ol0003ooooooooo
o`0@ooooo`Go003o4oooool5o`00o`_ooooo1Ol00?l2ooooo`Ko003o3Oooool3o`00o`Sooooo3?oo
000>ooooo`Goo`001Oooool:ool000_ooooo0ooo0003ooooo`_oo`000_ooool7ool000Gooooo0ooo
00000oooooooo`00ool00007ool000_ooooo1Ol00?lEooooo`[o003o5?ooool8o`00o`;ooooo0ol0
0?l9ooooo`7o00000Oooool00003o`000?oooooooooo017ooooo0ol00?lDooooo`Go003o2Oooool7
o`00o`03ooooool00?oo003o00Ko003o5oooool9ool0017ooooo1Ooo0007ooooo`Woo`001oooool7
ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo00001ooo000<ooooo`Coo`003?ooool5
o`00o`04ooooool00?oo003oo`00oaCooooo2?l00?lCooooo`Oo003o0_ooool5o`00o`Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool02Oooool3o`00o`Cooooo1Ol00?lCooooo`Go003o2?ooool8
o`00o`03ooooool00?oo003o00Ko003o6?ooool8ool0017ooooo1Ooo0007ooooo`Woo`001_ooool8
ool00003oooooooo003oo`0000?oo`000_ooool5ool00003oooooooo003oo`0000Ooo`007?ooool:
o`00oaKooooo1Ol00?lCooooo`Go003o1?ooool5o`00o`Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool02?ooool6o`00o`;ooooo1Ol00?l6ooooo`?o003o2oooool3o`00o`Wooooo1ol00?l2oooo
o`So003o3?ooool3o`00o`[ooooo2?oo000Aooooo`?oo`001?ooool3ool00003oooooooo003oo`00
00Ooo`001_ooool8ool00003oooooooo003oo`0000?oo`000oooool>ool001gooooo0ol00?l00ooo
oooo003oo`00o`03o`00oaKooooo1Ol00?lDooooo`?o003o1Oooool5o`00o`Sooooo0Ol00001oooo
o`0000Co0000o`00ool00?oo003o1oooool7o`00o`03ooooool00?oo003o00?o003o1Oooool5o`00
oaKooooo1ol00?l3ooooo`Ko003o3?ooool5o`00o`Wooooo2?oo000Gooooo`Goo`0000Goooooool0
0?oo003oo`00ooooo`03ool000Oooooo1ooo0003ooooo`?oo`001_ooool7ool00004oooooooo003o
o`00ool000[ooooo0ol00?lEooooo`Go003o5Oooool5o`00oakooooo0ol00?l9ooooo`7o00000Ooo
ool000Go003o1_ooool7o`00o`;ooooo0ol00?l6ooooo`Go003o5oooool6o`00o`Oooooo0ol00?l;
ooooo`Go003o0oooool3o`00o`?ooooo2?oo00001?ooooooo`00ool00?oo000Cooooo`Goo`004?oo
ool3ool000Gooooo0ooo0004ooooo`Soo`003oooool5o`00oaGooooo0ol00?lEooooo`Go003o3ooo
ool3o`00oaWooooo0Ol00001ooooo`001Ol00?l7ooooo`Ko003o00?oooooo`00ool00?l01?l00?l4
ooooo`Go003o5oooool5o`00o`Oooooo1Ol00?l:ooooo`Go003o0_ooool5o`00o`;ooooo1ooo0000
0oooooooo`00ool00003ool001;ooooo1Ooo0004ooooo`?oo`001oooool3ool000;ooooo0ooo0000
0oooooooo`00ool0000>ool000oooooo1Ol00?lZooooo`So003o3_ooool5o`00oaSooooo0Ol00001
ooooo`001ol00?l7ooooo`?o003o00?oooooo`00ool00?l01_l00?l4ooooo`?o003o6Oooool3o`00
o`Sooooo1Ol00?l8ooooo`Oo003o0_ooool5o`00o`?ooooo0ooo0004ooooo`Ooo`003oooool5ool0
00Cooooo1Ooo0005oooooaWoo`001Oooool4o`00o`Kooooo1_l00?lYooooo`Wo003o3_ooool5o`00
o`Kooooo0ol00?l?ooooo`7o00000Oooool00003o`000?l00?oo003o00Go003o2_ooool8o`00ob_o
oooo1Ol00?l7ooooo`Oo003o0oooool5o`00o`[ooooo2_oo000<ooooo`Goo`001?ooool5ool000Go
oooo6?oo0005ooooo`Ko003o1Oooool6o`00oaGooooo0ol00?l7ooooo`?o003o1Oooool:o`00o`_o
oooo0ol00?l00ooooooo003oo`00o`03o`00o`;ooooo2?l00?l>ooooo`7o00000Oooool00003o`00
0?oooooooooo00Go003o2_ooool9o`00o`oooooo1_l00?lFooooo`?o003o2?ooool7o`00o`Cooooo
0ol00?l<ooooo`[oo`001?ooool6ool00003oooooooo003oo`0000?oo`001?ooool5ool00005oooo
oooo003oo`00ool00?ooool06_oo0009o`00o`Gooooo1ol00?l<ooooo`?o003o1?ooool5o`00o`05
ooooool00?oo003oo`00ooooool01Ol00?l3ooooo`_o003o2_ooool5o`00o`04ooooool00?oo003o
o`00o`;ooooo2Ol00?l>ooooo`7o00000Oooool00003o`000?oooooooooo00Go003o1oooool<o`00
o`kooooo2?l00?l;ooooo`?o003o4_ooool7o`00o`Gooooo0ol00?l4ooooo`?o003o1_ooool8ool0
00?ooooo2?oo00001?ooooooo`00ool00?oo0006ooooo`?oo`0000?oooooool00?oo00001ooo0002
ooooo`?oo`0000?oooooool00?oo00001_oo00000oooooooo`00ool00004ool000[o003o1_ooool6
o`00o`_ooooo1Ol00?l3ooooo`oo003o0oooool=o`00o`Sooooo1Ol00?l6ooooo`Wo003o3_ooool1
o`00007ooooo00001?l0003oooooooooooooool3o`00o`Oooooo3Ol00?l>ooooo`So003o0_ooool3
o`00o`Gooooo1Ol00?l3ooooo`?o003o0_ooool3o`00o`Oooooo2?l00?l2ooooo`Go003o0_ooool5
o`00o`Kooooo1ooo0003ooooo`Soo`003_ooool9ool000Oooooo1_oo0002ooooo`Koo`003?l00?l5
ooooo`Go003o2oooool5o`00o`?ooooo3ol00?l3ooooo`Go003o00?oooooo`00ool00?l01_l00?l7
ooooo`Go003o1_ooool8o`00o`Cooooo1Ol00?l6ooooo`7o00000Oooool00003o`000?oooooooooo
00_ooooo3?l00?l01?oooooo003oo`00ool00?l3ooooo`?o003o1Oooool8o`00o`03ooooool00?oo
003o00?o003o1?ooool5o`00o`;ooooo2_l00?l:ooooo`Go003o00?oooooo`00ool00?l00ol00?l0
0ooooooo003oo`00o`04o`00o`Wooooo0ooo0003ooooo`[oo`001oooool5ool00003oooooooo003o
o`0000Ooo`002?ooool5ool000?ooooo1Ooo000=o`00o`Gooooo0ol00?l<ooooo`Go003o1?ooool3
o`00o`03ooooool00?oo003o00?o003o00Coooooo`00ool00?oo003o1Oooool3o`00o`?ooooo1ol0
0?l8ooooo`?o003o2?ooool3o`00o`Oooooo1ol00?l5ooooo`7o00000Oooool00003o`000?oooooo
oooo00_ooooo1Ol00?l00ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00?o003o00?ooooo
o`00ool00?l00ol00?l5ooooo`Ko003o0_ooool5o`00o`Cooooo1Ol00?l2ooooo`[o003o2_ooool5
o`00o`03ooooool00?oo003o00?o003o00?oooooo`00ool00?l01?l00?l?ooooo`Soo`000ol00?l0
1Oooooooo`00ool00?oo003ooooo00Ooo`0000Goooooool00?oo003oo`00ooooo`03ool000Wooooo
1Ooo0006ooooo`?oo`001_l00?l00ooooooo003oo`00o`05o`00oa?ooooo0ol00?l4ooooo`Go003o
00Coooooo`00ool00?oo003o4_ooool5o`00oagooooo1ol00?l5ooooo`7o00000Oooool00003o`00
0?oooooooooo00cooooo0ol00?l2ooooo`Go003o00?oooooo`00ool00?l00ol00?l00ooooooo003o
o`00o`03o`00o`gooooo1Ol00?l5ooooo`?o003o0oooool:o`00o`[ooooo1Ol00?l2ooooo`[o003o
4?ooool7ool000Go003o2ooo000Booooo`?oo`0000Coooooo`00ool00?oo003o3Oooool8o`00oa;o
oooo0ol00?l4ooooo`Go003o5oooool3o`00oakooooo1ol00?l5ooooo`7o00000Oooool00003o`00
0?oooooooooo017ooooo1Ol00?l00ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00?o003o
3_ooool3o`00o`gooooo0ol00?l2ooooo`?o003o3?ooool3o`00o`Gooooo1ol00?lBooooo`?oo`00
0_ooool6o`00o`_oo`002?ooool3o`00o`[ooooo1Ol00?l=ooooo`Oo003o4Oooool5o`00o`?ooooo
1Ol00?lKooooo`?o003o6oooool5o`00o`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo
ool3o`00o`gooooo0ol00?l3ooooo`?o003o0oooool5o`00ocWooooo1ol00?lGooooo`Ko003o0ooo
0003o`00o`Coo`001_ooool7o`00o`Wooooo1Ol00?l?ooooo`Go003o4Oooool5o`00o`;ooooo1Ol0
0?lKooooo`Go003o4_ooool3o`00oa3ooooo0Ol00001ooooo`0000Co0000oooooooooooooooo1Ol0
0?lFooooo`Oo003o0_ooool3o`00o`kooooo0ol00?lSooooo`Oo003o5oooool6o`00o`;oo`001ol0
0?l6ooooo`So003o2Oooool5o`00oa3ooooo0ol00?lBooooo`Go003o0_ooool5o`00oaSooooo2?l0
0?l@ooooo`Ko003o3oooool1o`00007ooooo00001?l0003oooooooooooooool5o`00oaGooooo2?l0
0?l00ooooooo003oo`00o`03o`00o`cooooo1Ol00?lSooooo`Ko003o6?ooool6o`00o`03ooooool0
0?oo003o00Ko003o0_ooool;o`00o`[ooooo0ol00?lWooooo`?o003o0oooool5o`00o`gooooo0ol0
0?l7ooooo`Wo003o3oooool:o`00o`04ooooool00?oo003oo`00o`Sooooo0Ol00001ooooo`0000Co
0000oooooooooooooooo1Ol00?lEooooo`Oo003o0_ooool8o`00o`Wooooo1Ol00?lAooooo`?o003o
4Oooool3o`00oaGooooo0ol00?l2ooooo`Go003o00?oooooo`00ool00?l01_l00?l00ooooooo003o
o`00o`09o`00o`gooooo0ol00?l?ooooo`?o003o2_ooool3o`00o`gooooo0ol00?l;ooooo`Oo003o
1_ooool;o`00o`gooooo3ol00?l7ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo0ol0
0?lFooooo`Go003o1?ooool9o`00o`Sooooo1Ol00?l@ooooo`Go003o9_ooool6o`00o`03ooooool0
0?oo003o00?o003o0_ooool7o`00o`03ooooool00?oo003o00Ko003o3oooool5o`00o`gooooo1Ol0
0?l8ooooo`Go003o6Oooool8o`00o`Kooooo1Ol00?l2ooooo`Go003o3?ooool?o`00o`Oooooo0Ol0
0001ooooo`0000?o0000ooooooooool07?ooool3o`00o`Kooooo2?l00?l9ooooo`?o003o4Oooool5
o`00o`gooooo0ol00?l=ooooo`?o003o1Oooool7o`00o`;ooooo0ol00?l4ooooo`Go003o0_ooool5
o`00o`Oooooo0ol00?l8ooooo`Go003o3Oooool5o`00o`Sooooo1Ol00?l5ooooo`?o003o4?ooool9
o`00o`Oooooo0ol00?l3ooooo`Go003o2oooool5o`00o`;ooooo2Ol00?l7ooooo`7o00000Oooool0
0003o`000?oooooooooo00_ooooo0ol00?lJooooo`Go003o0oooool3o`00oaOooooo1Ol00?l<oooo
o`Go003o2oooool7o`00o`;ooooo1ol00?lAooooo`?o003o1oooool5o`00o`Oooooo1Ol00?l=oooo
o`Go003o2?ooool5o`00o`Cooooo1Ol00?l?ooooo`So003o3_ooool5o`00o`[ooooo1Ol00?l4oooo
o`?o003o00Coooooo`00ool00?oo003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0:oooo
o`Go003o00?oooooo`00ool00?l00ol00?lDooooo`?o003o0oooool5o`00oaOooooo0ol00?l=oooo
o`Go003o2oooool@o`00oa_ooooo1Ol00?l8ooooo`?o003o0oooool3o`00o`Sooooo1Ol00?l7oooo
o`So003o0_ooool5o`00o`Cooooo0ol00?l8ooooo`Go003o4_ooool3o`00o`_ooooo1Ol00?lCoooo
o`7o00000Oooool00003o`000?oooooooooo00Cooooo1Ol00?l00ooooooo003oo`00o`0:o`00oaWo
oooo1Ol00?lWooooo`Go003o2oooool@o`00oa_ooooo1Ol00?l=ooooo`Go003o2?ooool3o`00o`Oo
oooo2_l00?l00ooooooo003oo`00o`03o`00o`?ooooo1Ol00?l8ooooo`?o003o8Oooool5o`00oa?o
oooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolCo`00o`05ooooool00?oo003oo`00oooo
ool00ol00?l3ooooo`?o003o2oooool5o`00obSooooo0ol00?l=ooooo`ko003o6oooool5o`00o`ko
oooo1Ol00?l;ooooo`?o003o1?ooool:o`00o`;ooooo0ol00?l4ooooo`Go003o;Oooool3o`00o`Oo
oooo0ol00?l:ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo1ol00?l01Ooooooo003o
o`00ool00?oooooo01Ko003o2oooool3o`00o`;ooooo1_l00?l>ooooo`?o003o7oooool<o`00oago
oooo1Ol00?l?ooooo`Go003o00Coooooo`00ool00?oo003o1_ooool5o`00o`?ooooo2_l00?l9oooo
o`Go003o7oooool3o`00o`04ooooool00?oo003oo`00oa3ooooo1Ol00?l9ooooo`7o00000Oooool0
0003o`000?oooooooooo00?ooooo1ol00?l6oooooaGo003o3oooool:o`00o`[ooooo1Ol00?lNoooo
o`_o003o4Oooool3o`00o`[ooooo1Ol00?l@ooooo`?o003o00?oooooo`00ool00?l00ol00?l5oooo
o`Go003o0oooool9o`00o`_ooooo0ol00?lOooooo`Wo003o3?ooool8o`00o`Wooooo0Ol00001oooo
o`0000?o0000ooooooooool00oooool6o`00o`Oooooo1Ol00?l00ooooooo003oo`00o`0=o`00o`oo
oooo3Ol00?l7ooooo`Go003o6oooool=o`00oa7ooooo1Ol00?l9ooooo`Go003o5?ooool5o`00o`Go
oooo1Ol00?l2ooooo`[o003o;Oooool9o`00o`_ooooo2Ol00?l9ooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo1_l00?l9ooooo`?o003o0oooool3o`00o`03ooooool00?oo003o00Oo003o
4?ooool>o`00o`Kooooo1Ol00?l=ooooo`?o003o2_ooool8o`00o`03ooooool00?oo003o00?o003o
4Oooool5o`00o`04ooooool00?oo003oo`00o`Kooooo0ol00?l:ooooo`?o003o2?ooool5o`00o`Ko
oooo0ol00?l3ooooo`Go003o00Coooooo`00ool00?oo003o7?ooool3o`00o`oooooo2Ol00?l;oooo
o`[o003o2?ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`Oo003o3?ooool3o`00o`Ko
oooo1Ol00?lBooooo`go003o1oooool3o`00o`gooooo1Ol00?l9ooooo`Go003o1Oooool3o`00o`04
ooooool00?oo003oo`00o`kooooo2_l00?lAooooo`Go003o2?ooool3o`00o`gooooo1Ol00?lOoooo
o`Go003o3Oooool5o`00o`04ooooool00?oo003oo`00o`cooooo2_l00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00;ooooo1ol00?l6ooooo`?o003o0_ooool7o`00o`Cooooo0ol00?lIoooo
o`Oo003o5oooool5o`00o`Wooooo1Ol00?l8ooooo`Go003o3Oooool:o`00oa7ooooo1Ol00?l01?oo
oooo003oo`00ool00?l@ooooo`?o003o0_ooool3o`00ob3ooooo1ol00?l;ooooo`Go003o4?ooool:
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool7o`00o`Gooooo1Ol00?l00ooo
oooo003oo`00o`06o`00o`Gooooo0ol00?lIooooo`Co003o6?ooool5o`00o`[ooooo0ol00?l9oooo
o`Go003o3Oooool:o`00oa7ooooo2_l00?l>ooooo`Go003o00Coooooo`00ool00?oo003o8?ooool9
o`00o`Wooooo1Ol00?l@ooooo`Go003o00Coooooo`00ool00?oo003o2Oooool1o`00007ooooo0000
0ol0003oooooooooo`03ooooo`Go003o1_ooool5o`00o`03ooooool00?oo003o00Ko003o1?ooool5
o`00ocGooooo0ol00?l8ooooo`?o003o3?ooool5o`00o`kooooo0ol00?l2ooooo`?o003o4oooool9
o`00o`kooooo2_l00?lPooooo`Wo003o2?ooool5o`00oa3ooooo1?l00?l>ooooo`7o00000Oooool0
0003o`000?oooooooooo00;ooooo1Ol00?l7ooooo`Go003o0_ooool7o`00o`Cooooo1Ol00?l6oooo
o`?o003o2_ooool3o`00oa_ooooo0ol00?l;ooooo`Go003o3?ooool3o`00o`Sooooo0ol00?lRoooo
o`Ko003o3_ooool:o`00oa7ooooo0ol00?l>ooooo`Oo003o2?ooool5o`00o`oooooo1Ol00?l>oooo
o`7o00000Oooool00003o`000?oooooooooo00;ooooo1Ol00?l8ooooo`?o003o1Oooool5o`00o`Co
oooo1Ol00?l5ooooo`Go003o2?ooool5o`00oaWooooo1Ol00?l:ooooo`Go003o0oooool3o`00oa3o
oooo1Ol00?l4ooooo`?o003o2?ooool3o`00o`oooooo1Ol00?l@ooooo`?o003o00?oooooo`00ool0
0?l00ol00?l2ooooo`?o003o2oooool5o`00o`;ooooo0ol00?l9ooooo`Ko003o1oooool5o`00oa3o
oooo1Ol00?l>ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo1Ol00?l@ooooo`Go003o
1Oooool3o`00o`Kooooo1Ol00?l8ooooo`Go003o2?ooool3o`00o`kooooo1Ol00?l:ooooo`Go003o
0_ooool5o`00o`cooooo2?l00?l3ooooo`Go003o1_ooool5o`00o`Oooooo0ol00?l5ooooo`?o003o
5_ooool3o`00o`;ooooo1Ol00?l:ooooo`_o003o2_ooool3o`00o`Oooooo1Ol00?lAooooo`Go003o
3_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`?o003o4Oooool5o`00o`kooooo1Ol0
0?l8ooooo`Go003o1oooool5o`00o`gooooo1Ol00?l;ooooo`?o003o0oooool5o`00o`;ooooo0ol0
0?l6ooooo`[o003o0_ooool5o`00o`Kooooo1Ol00?l6ooooo`So003o7oooool5o`00o`;ooooo0ol0
0?l5ooooo`_o003o5?ooool5o`00oa;ooooo0ol00?l?ooooo`7o00000Oooool00003o`000?oooooo
oooo01Oooooo1Ol00?l5ooooo`?o003o1oooool3o`00o`[ooooo0ol00?l8ooooo`Go003o3_ooool3
o`00o`kooooo0ol00?l00ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00?o003o1Oooool;
o`00o`03ooooool00?oo003o00?o003o1_ooool5o`00o`Kooooo2Ol00?lNooooo`Go003o00?ooooo
o`00ool00?l00ol00?l3ooooo`co003o5?ooool7o`00ob;ooooo0Ol00001ooooo`0000?o0000oooo
ooooool05oooool5o`00o`Cooooo2?l00?l3ooooo`?o003o4oooool7o`00oakooooo1Ol00?l01?oo
oooo003oo`00ool00?l2ooooo`Go003o1Oooool5o`00o`03ooooool00?oo003o00?o003o0_ooool3
o`00o`Kooooo1Ol00?l7ooooo`Wo003o7oooool3o`00o`;ooooo1Ol00?l2ooooo`ko003o5?ooool7
o`00ob7ooooo0Ol00001ooooo`0000?o0000ooooooooool03Oooool3o`00o`Sooooo0ol00?l5oooo
o`Wo003o00?oooooo`00ool00?l00ol00?lAooooo`Oo003o7oooool5o`00o`Kooooo1Ol00?l6oooo
o`?o003o0_ooool5o`00o`[ooooo1Ol00?l9ooooo`So003o9?ooool5o`00o`;ooooo3ol00?lEoooo
o`Go003o8Oooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`Go003o3oooool9o`00o`03
ooooool00?oo003o00?o003o4Oooool5o`00ob7ooooo1Ol00?l7ooooo`?o003o3Oooool4o`00o`Wo
oooo1_l00?l=ooooo`?o003o9_ooool3o`00o`?ooooo2Ol00?l00ooooooo003oo`00o`03o`00oaGo
oooo1Ol00?l>ooooo`?o003o4?ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`Go003o
4?ooool8o`00o`03ooooool00?oo003o00?o003o4Oooool5o`00o`[ooooo0ol00?lEooooo`?o003o
6?ooool5o`00o`Kooooo2?l00?l3ooooo`?o003o00Coooooo`00ool00?oo003o<oooool3o`00o`04
ooooool00?oo003oo`00o`;ooooo1Ol00?lFooooo`?o003o3_ooool5o`00o`?ooooo0ol00?l9oooo
o`7o00000Oooool00003o`000?oooooooooo00cooooo1Ol00?lDooooo`?o003o0oooool3o`00oa?o
oooo1Ol00?l8ooooo`Go003o9Oooool3o`00o`Oooooo1Ol00?l5oooooaCo003o=Oooool5o`00o`;o
oooo0ol00?lUooooo`So003o0_ooool5o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
3?ooool6o`00oboooooo1Ol00?l8ooooo`Go003o2Oooool3o`00oaSooooo1Ol00?l6ooooo`Go003o
1OoooolDo`00ob[ooooo0ol00?l7ooooo`Ko003o:?ooool:o`00o`;ooooo1Ol00?l8ooooo`7o0000
0Oooool00003o`000?oooooooooo00_ooooo1ol00?lXooooo`?o003o1?ooool5o`00o`Sooooo1Ol0
0?l8ooooo`Oo003o5Oooool7o`00o`Gooooo1_l00?l3oooooaCo003o3Oooool3o`00oaWooooo1Ol0
0?l6ooooo`Ko003o9oooool:o`00o`?ooooo1Ol00?l8ooooo`7o00000Oooool00003o`000?oooooo
oooo00?ooooo0ol00?l5ooooo`Oo003o7oooool3o`00o`Gooooo1Ol00?l4ooooo`?o003o2Oooool5
o`00o`Sooooo2?l00?lDooooo`So003o1_ooool5o`00o`?ooooo0ol00?l3ooooo`co003o3Oooool5
o`00oaSooooo1Ol00?l6ooooo`Go003o:?ooool7o`00o`Oooooo1?l00?l8ooooo`7o00000Oooool0
0003o`000?oooooooooo00;ooooo2?l00?l00ooooooo003oo`00o`04o`00o`Sooooo0ol00?l=oooo
o`?o003o1?ooool5o`00o`Cooooo1Ol00?l@ooooo`Go003o2?ooool8o`00oaGooooo1ol00?l6oooo
o`Go003o2_ooool8o`00oa3ooooo1Ol00?lHooooo`Go003o1Oooool5o`00o`Gooooo0ol00?l8oooo
o`?o003o5_ooool6o`00o`Kooooo1ol00?l7ooooo`7o00000Oooool00003o`000?l00?oo003o00_o
003o00?oooooo`00ool00?l00ol00?l7ooooo`Go003o2oooool5o`00o`?ooooo1Ol00?l4ooooo`Go
003o3oooool6o`00o`Wooooo1ol00?lGooooo`Go003o1_ooool5o`00o`cooooo1Ol00?l2ooooo`?o
003o3?ooool5o`00oa;ooooo0ol00?l4ooooo`?o003o1_ooool5o`00o`Cooooo1Ol00?l6ooooo`Go
003o5_ooool5o`00o`Gooooo2?l00?l7ooooo`7o00000Oooool000ko003o0_ooool3o`00o`Sooooo
1Ol00?l;ooooo`Go003o0oooool5o`00o`?ooooo1Ol00?l?ooooo`Ko003o3Oooool3o`00oaKooooo
1_l00?l8ooooo`Co003o3?ooool5o`00o`03ooooool00?oo003o00Co003o2oooool6o`00o`04oooo
ool00?oo003oo`00o`_ooooo1Ol00?l<ooooo`Go003o1?ooool5o`00o`Kooooo1Ol00?lGooooo`Go
003o1?ooool8o`00o`04ooooool00?oo003oo`00o`?ooooo0Ol00001ooooo`003_l00?l=ooooo`Go
003o2oooool5o`00o`Cooooo0ol00?l3ooooo`Go003o4?ooool5o`00o`;ooooo0ol00?lQooooo`So
003o1oooool5o`00o`_ooooo1Ol00?l00ooooooo003oo`00o`05o`00o`cooooo2Ol00?l:ooooo`Go
003o2_ooool6o`00o`Gooooo1Ol00?l6ooooo`Go003o5oooool5o`00o`Cooooo3Ol00?l2ooooo`7o
00000Oooool000Oo003o00?oooooo`00ool00?l00ol00?l?ooooo`?o003o3Oooool3o`00o`_ooooo
1Ol00?l@ooooo`Go003o00?oooooo`00ool00?l00ol00?lPooooo`Wo003o1_ooool6o`00o`_ooooo
0ol00?l2ooooo`Oo003o3?ooool9o`00o`[ooooo1Ol00?l8ooooo`Ko003o2?ooool3o`00o`Sooooo
0ol00?l01?oooooo003oo`00ool00?lDooooo`Go003o1Oooool6o`00o`03ooooool00?oo003o00?o
003o0_ooool1o`00007ooooo00000ol0003o003oo`00o`03o`00o`;ooooo1_l00?l2ooooo`?o003o
9oooool5o`00oa7ooooo0ol00?l2ooooo`Go003o8?ooool9o`00o`Kooooo1_l00?l:ooooo`Go003o
0_ooool6o`00o`cooooo2Ol00?l;ooooo`?o003o2?ooool7o`00oaKooooo1Ol00?l4ooooo`?o003o
3Oooool3o`00o`Gooooo0ol00?l5ooooo`Go003o0_ooool1o`00007ooooo00000ol0003ooooooooo
o`05ooooo`Ko003o00?oooooo`00ool00?l00ol00?lBooooo`Go003o4?ooool3o`00o`Gooooo0ol0
0?l?ooooo`Go003o6?ooool3o`00o`Kooooo2Ol00?l6ooooo`Go003o2_ooool5o`00o`Cooooo0ol0
0?l4ooooo`?o003o1oooool7o`00oaCooooo2_l00?l?ooooo`?o003o1?ooool5o`00o`?ooooo1Ol0
0?lCooooo`Go003o1Oooool3o`00o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool5
o`00o`03ooooool00?oo003o00?o003o2oooool3o`00o`?ooooo1ol00?lFooooo`Go003o1Oooool3
o`00o`Oooooo0ol00?lHooooo`Ko003o1Oooool8o`00o`Oooooo0ol00?l:ooooo`Ko003o2Oooool6
o`00o`Sooooo1Ol00?lCooooo`[o003o2Oooool3o`00o`?ooooo1Ol00?l3ooooo`Go003o0oooool5
o`00oa?ooooo1Ol00?l;ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo0ol00?l01?oo
oooo003oo`00ool00?l2ooooo`Go003o2_ooool5o`00o`;ooooo1ol00?lFooooo`Go003o1?ooool5
o`00ob7ooooo1ol00?l5ooooo`Oo003o4oooool7o`00o`Sooooo1ol00?l8ooooo`Go003o4oooool8
o`00o`[ooooo1Ol00?l2ooooo`Go003o1?ooool3o`00o`Cooooo1Ol00?lBooooo`Ko003o2oooool1
o`00007ooooo00000ol0003oooooooooo`02ooooo`Go003o1_ooool3o`00o`_ooooo1Ol00?l2oooo
o`Oo003o5_ooool5o`00o`Cooooo1Ol00?lQooooo`Oo003o2?ooool3o`00o`kooooo0ol00?l3oooo
o`Oo003o2?ooool7o`00o`Wooooo0ol00?lDooooo`Oo003o2oooool5o`00o`;ooooo1Ol00?l<oooo
o`?o003o4_ooool6o`00o`cooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool5o`00oaCo
oooo1Ol00?l3ooooo`Go003o6?ooool3o`00o`Gooooo1Ol00?lRooooo`Ko003o6?ooool5o`00o`;o
oooo1ol00?l8ooooo`Ko003o8_ooool7o`00o`[ooooo1Ol00?l3ooooo`?o003o8_ooool5o`00o`go
oooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool5o`00oaGooooo0ol00?lZooooo`?o003o
9Oooool3o`00oaWooooo1Ol00?l3ooooo`Go003o2_ooool3o`00obKooooo1Ol00?l;ooooo`?o003o
:Oooool5o`00o`gooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool3o`00ohOooooo1Ol0
0?lkooooo`Go003o>?ooool3o`00o`kooooo0Ol00001ooooo`00TOl00003o`00ocgo00000ol00?m;
o`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0104497, -0.0104497, \
0.00355714, 0.00355714}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Histogram modeling", "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  "Number of centroids for each class (",
  Cell[BoxData[
      \(TraditionalForm\`2\^m\)]],
  ")"
}], "Subsection"],

Cell[BoxData[
    \(\(m\  = \ 5;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute data-dependent centroids", "Subsection"],

Cell[BoxData[{
    \(\(vqCentroids1 = \ VQ[data1, m];\)\), "\n", 
    \(\(vqCentroids2\  = VQ[data2, m];\)\), "\n", 
    \(\(vqCentroids\  = \ vqCentroids1~Join~vqCentroids2;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gCentroids = \ 
        PlotData2D[vqCentroids, pr, \ centroidStyle, \ 
          FrameTicks \[Rule] None];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 1 r
.02 w
.73193 .71861 Mdot
.6546 .70272 Mdot
.66163 .61945 Mdot
.56986 .65053 Mdot
.77987 .62072 Mdot
.80494 .50541 Mdot
.71057 .5372 Mdot
.65826 .43933 Mdot
.58605 .7867 Mdot
.46043 .80501 Mdot
.47605 .70994 Mdot
.43222 .63725 Mdot
.34962 .76308 Mdot
.34427 .6452 Mdot
.25698 .68385 Mdot
.22175 .6081 Mdot
.78267 .41593 Mdot
.73306 .3443 Mdot
.64197 .34412 Mdot
.67363 .2516 Mdot
.55145 .34189 Mdot
.5582 .25791 Mdot
.49639 .20622 Mdot
.40962 .21575 Mdot
.34759 .52261 Mdot
.30313 .4544 Mdot
.21668 .50807 Mdot
.20937 .4198 Mdot
.40157 .38149 Mdot
.40043 .30324 Mdot
.29582 .34342 Mdot
.28447 .27798 Mdot
.93511 .91224 Mdot
.80233 .88337 Mdot
.93173 .74402 Mdot
.8147 .72893 Mdot
.69971 .92279 Mdot
.59349 .88613 Mdot
.48406 .9377 Mdot
.38084 .87629 Mdot
.93189 .56679 Mdot
.91255 .45838 Mdot
.89497 .33065 Mdot
.84829 .24493 Mdot
.90964 .109 Mdot
.77788 .09786 Mdot
.62321 .09337 Mdot
.47177 .07347 Mdot
.23243 .932 Mdot
.2253 .81185 Mdot
.07715 .91914 Mdot
.05917 .78646 Mdot
.1433 .67999 Mdot
.06751 .55677 Mdot
.13307 .37138 Mdot
.05002 .33641 Mdot
.53394 .56988 Mdot
.56067 .47411 Mdot
.45481 .53026 Mdot
.48133 .4238 Mdot
.32818 .16076 Mdot
.24576 .07053 Mdot
.1257 .19015 Mdot
.06914 .05423 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00ool0000Po`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703o
ool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040
oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3o
oolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol0
0000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o
00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?oo
o`0?0?ooo`?oo`3oo`3oool:0?ooo`7o00000@3oool00003o`00003oool0oooo00h0oooo1Ooo0?oo
0?ooo`T0oooo0Ol000010?ooo`0000?o00000?ooo`3oool03P3oool5ool0ool0oooo2@3oool1o`00
0040oooo00000ol00000oooo0?ooo`0>0?ooo`Goo`3oo`3oool90?ooo`7o00000@3oool00003o`00
003oool0oooo00l0oooo0ooo0?oo0?ooo`X0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0@P3o
ool3ool0omH0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0@@3oool5ool0ocd0oooo0ooo0?nE
0?ooo`7o00000@3oool00003o`00003oool0oooo0440oooo1Ooo0?ll0?ooo`Goo`3oU03oool1o`00
0040oooo00000ol00000oooo0?ooo`110?ooo`Goo`3o?03oool5ool0oi@0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0@P3oool3ool0ocd0oooo1Ooo0?nD0?ooo`7o00000@3oool00003o`00003o
ool0oooo08<0oooo0ooo0?nE0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1
o`000040oooo00000ol00000oooo0?ooo`2^0?ooo`?oo`3oJP3oool1o`000040oooo00000ol00000
oooo0?ooo`2]0?ooo`Goo`3o:03oool3ool0och0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
[@3oool5ool0obL0oooo1Ooo0?lm0?ooo`7o00000@3oool00003o`00003oool0oooo0:d0oooo1Ooo
0?lW0?ooo`Goo`3o?@3oool1o`000040oooo00000ol00000oooo0?ooo`2^0?ooo`?oo`3o:03oool5
ool0ob80oooo0ooo0?lH0?ooo`7o00000@3oool00003o`00003oool0oooo0=X0oooo0ooo0?lR0?oo
o`Goo`3o5`3oool1o`000040oooo00000ol00000oooo0?ooo`3o0?ooo`Goo`3o5`3oool1o`000040
oooo00000ol00000oooo0?ooo`3o0?ooo`Goo`3o5`3oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?ooo`40oooo0ooo0?lH0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1
o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo
00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL
0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000
oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o0000
0@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`1I
0?ooo`?oo`3o_`3oool1o`000040oooo00000ol00000oooo0?ooo`1H0?ooo`Goo`3o_P3oool1o`00
0040oooo00000ol00000oooo0?ooo`1H0?ooo`Goo`3o_P3oool1o`000040oooo00000ol00000oooo
0?ooo`1H0?ooo`Goo`3o_P3oool1o`000040oooo00000ol00000oooo0?ooo`1I0?ooo`?oo`3o_`3o
ool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040
oooo00000ol00000oooo0?ooo`0O0?ooo`?oo`3on@3oool1o`000040oooo00000ol00000oooo0?oo
o`0N0?ooo`Goo`3on03oool1o`000040oooo00000ol00000oooo0?ooo`0N0?ooo`Goo`3on03oool1
o`000040oooo00000ol00000oooo0?ooo`0N0?ooo`Goo`3on03oool1o`000040oooo00000ol00000
oooo0?ooo`0O0?ooo`?oo`3on@3oool1o`000040oooo00000ol00000oooo0?ooo`2:0?ooo`?oo`3o
SP3oool1o`000040oooo00000ol00000oooo0?ooo`290?ooo`Goo`3oS@3oool1o`000040oooo0000
0ol00000oooo0?ooo`290?ooo`Goo`3oS@3oool1o`000040oooo00000ol00000oooo0?ooo`1a0?oo
o`?oo`3o5@3oool5ool0ohd0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0L03oool5ool0oaD0
oooo0ooo0?n>0?ooo`7o00000@3oool00003o`00003oool0oooo0700oooo1Ooo0?nV0?ooo`7o0000
0@3oool00003o`00003oool0oooo0700oooo1Ooo0?nV0?ooo`7o00000@3oool00003o`00003oool0
oooo0740oooo0ooo0?nW0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`00
0040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0>l0oooo0ooo0?lY0?ooo`7o00000@3o
ool00003o`00003oool0oooo0>h0oooo1Ooo0?lX0?ooo`7o00000@3oool00003o`00003oool0oooo
0;`0oooo0ooo0?l_0?ooo`Goo`3o:03oool1o`000040oooo00000ol00000oooo0?ooo`2k0?ooo`Go
o`3o;P3oool5ool0obP0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0V`3oool3ool0oad0oooo
1Ooo0?l_0?ooo`?oo`3o:@3oool1o`000040oooo00000ol00000oooo0?ooo`2J0?ooo`Goo`3o703o
ool5ool0oe/0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0VP3oool5ool0oad0oooo0ooo0?mL
0?ooo`7o00000@3oool00003o`00003oool0oooo09X0oooo1Ooo0?ml0?ooo`7o00000@3oool00003
o`00003oool0oooo09/0oooo0ooo0?mm0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo
703oool1o`000040oooo00000ol00000oooo0?ooo`1=0?ooo`?oo`3ob`3oool1o`000040oooo0000
0ol00000oooo0?ooo`1<0?ooo`Goo`3obP3oool1o`000040oooo00000ol00000oooo0?ooo`1<0?oo
o`Goo`3obP3oool1o`000040oooo00000ol00000oooo0?ooo`1<0?ooo`Goo`3obP3oool1o`000040
oooo00000ol00000oooo0?ooo`1=0?ooo`?oo`3ob`3oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool0
0003o`00003oool0oooo06h0oooo0ooo0?nZ0?ooo`7o00000@3oool00003o`00003oool0oooo06d0
oooo1Ooo0?nY0?ooo`7o00000@3oool00003o`00003oool0oooo06d0oooo1Ooo0?nY0?ooo`7o0000
0@3oool00003o`00003oool0oooo06d0oooo1Ooo0?nY0?ooo`7o00000@3oool00003o`00003oool0
oooo06h0oooo0ooo0?nZ0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`00
0040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?`0oooo0ooo0?lL0?ooo`7o00000@3o
ool00003o`00003oool0oooo00X0oooo0ooo0?o^0?ooo`Goo`3o6`3oool1o`000040oooo00000ol0
0000oooo0?ooo`090?ooo`Goo`3ok@3oool5ool0oa/0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool02@3oool5ool0od80oooo0ooo0?m60?ooo`?oo`3oG`3oool5ool0oa/0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool02@3oool5ool0od40oooo1Ooo0?m40?ooo`Goo`3o5P3oool3ool0oaP0oooo
0ooo0?l[0?ooo`?oo`3o703oool1o`000040oooo00000ol00000oooo0?ooo`0:0?ooo`?oo`3o@P3o
ool5ool0od@0oooo1Ooo0?lE0?ooo`Goo`3o5P3oool5ool0odT0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0C`3oool5ool0od@0oooo1Ooo0?lE0?ooo`Goo`3o5P3oool5ool0odT0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0D03oool3ool0odH0oooo0ooo0?lF0?ooo`Goo`3o5P3oool5ool0
odT0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0/`3oool3ool0oaP0oooo0ooo0?m:0?ooo`7o
00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool08@3oool3ool0ooL0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0803oool5ool0ooH0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0803oool5ool0ooH0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0803oool5ool0odT0oooo
0ooo0?nZ0?ooo`7o00000@3oool00003o`00003oool0oooo0240oooo0ooo0?m90?ooo`Goo`3oZ@3o
ool1o`000040oooo00000ol00000oooo0?ooo`1]0?ooo`Goo`3oZ@3oool1o`000040oooo00000ol0
0000oooo0?ooo`1]0?ooo`Goo`3oZ@3oool1o`000040oooo00000ol00000oooo0?ooo`1^0?ooo`?o
o`3oZP3oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1
o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0=`0oooo0ooo0?ll0?ooo`7o0000
0@3oool00003o`00003oool0oooo03L0oooo0ooo0?nQ0?ooo`Goo`3o>`3oool1o`000040oooo0000
0ol00000oooo0?ooo`0f0?ooo`Goo`3oBP3oool3ool0oe<0oooo1Ooo0?lk0?ooo`7o00000@3oool0
0003o`00003oool0oooo03H0oooo1Ooo0?m90?ooo`Goo`3oDP3oool5ool0oc/0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0=P3oool5ool0odT0oooo1Ooo0?mC0?ooo`?oo`3o?03oool1o`000040
oooo00000ol00000oooo0?ooo`0g0?ooo`?oo`3oBP3oool5ool0oi80oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0Q@3oool3ool0oi<0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0^03oool3
ool0of00oooo0Ol000010?ooo`0000?o00000?ooo`3oool0]`3oool5ool0oel0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0]`3oool5ool0oel0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
]`3oool5ool0oel0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0DP3oool3ool0of<0oooo0ooo
0?mP0?ooo`7o00000@3oool00003o`00003oool0oooo0540oooo1Ooo0?n[0?ooo`?oo`3o5`3oool1
o`000040oooo00000ol00000oooo0?ooo`1A0?ooo`Goo`3oZP3oool5ool0oaH0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0D@3oool5ool0ojX0oooo1Ooo0?lF0?ooo`7o00000@3oool00003o`00
003oool0oooo0580oooo0ooo0?n[0?ooo`Goo`3o5P3oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?ooo`80oooo0ooo0?lG0?ooo`7o00000@3oool00003o`00003oool0oooo09`0oooo0ooo0?ml
0?ooo`7o00000@3oool00003o`00003oool0oooo09/0oooo1Ooo0?mk0?ooo`7o00000@3oool00003
o`00003oool0oooo09/0oooo1Ooo0?mk0?ooo`7o00000@3oool00003o`00003oool0oooo09/0oooo
1Ooo0?mk0?ooo`7o00000@3oool00003o`00003oool0oooo09`0oooo0ooo0?ml0?ooo`7o00000@3o
ool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3R0?ooo`?oo`3o=P3o
ool1o`000040oooo00000ol00000oooo0?ooo`0i0?ooo`?oo`3oY@3oool5ool0ocD0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0>03oool5ool0oj@0oooo1Ooo0?le0?ooo`7o00000@3oool00003
o`00003oool0oooo03P0oooo1Ooo0?nT0?ooo`Goo`3o=@3oool1o`000040oooo00000ol00000oooo
0?ooo`0h0?ooo`Goo`3oY@3oool3ool0ocH0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0>@3o
ool3ool0ob<0oooo0ooo0?ni0?ooo`7o00000@3oool00003o`00003oool0oooo05h0oooo1Ooo0?nh
0?ooo`7o00000@3oool00003o`00003oool0oooo05h0oooo1Ooo0?lK0?ooo`?oo`3oVP3oool1o`00
0040oooo00000ol00000oooo0?ooo`1N0?ooo`Goo`3o6P3oool5ool0oiT0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0G`3oool3ool0oa/0oooo1Ooo0?m50?ooo`?oo`3oD@3oool1o`000040oooo
00000ol00000oooo0?ooo`1m0?ooo`Goo`3oA03oool5ool0oe00oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool0OP3oool3ool0odD0oooo1Ooo0?m@0?ooo`7o00000@3oool00003o`00003oool0oooo
0<H0oooo1Ooo0?m@0?ooo`7o00000@3oool00003o`00003oool0oooo0<L0oooo0ooo0?mA0?ooo`7o
00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?oo
o`0?0?ooo`?oo`3oo`3oool:0?ooo`7o00000@3oool00003o`00003oool0oooo00h0oooo1Ooo0?oo
0?ooo`T0oooo0Ol000010?ooo`0000?o00000?ooo`3oool03P3oool5ool0oo@0oooo0ooo0?lA0?oo
o`7o00000@3oool00003o`00003oool0oooo00h0oooo1Ooo0?n10?ooo`?oo`3oK`3oool5ool0oa00
oooo0Ol000010?ooo`0000?o00000?ooo`3oool03`3oool3ool0oh40oooo1Ooo0?m^0?ooo`Goo`3o
403oool1o`000040oooo00000ol00000oooo0?ooo`2C0?ooo`Goo`3oKP3oool5ool0oa00oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0T`3oool5ool0ofl0oooo0ooo0?lA0?ooo`7o00000@3oool0
0003o`00003oool0oooo09@0oooo0ooo0?n40?ooo`7o00000@3oool00003o`00003oool0oooo0?l0
oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1
o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo03/0oooo0ooo0?oM0?ooo`7o0000
0@3oool00003o`00003oool0oooo03X0oooo1Ooo0?oL0?ooo`7o00000@3oool00003o`00003oool0
oooo03X0oooo1Ooo0?oL0?ooo`7o00000@3oool00003o`00003oool0oooo03X0oooo1Ooo0?oL0?oo
o`7o00000@3oool00003o`00003oool0oooo03/0oooo0ooo0?mk0?ooo`?oo`3o7`3oool3ool0ocd0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0^03oool5ool0oad0oooo1Ooo0?ll0?ooo`7o0000
0@3oool00003o`00003oool0oooo0;P0oooo1Ooo0?lM0?ooo`Goo`3o?03oool1o`000040oooo0000
0ol00000oooo0?ooo`2h0?ooo`Goo`3o7@3oool5ool0oc`0oooo0Ol000010?ooo`0000?o00000?oo
o`3oool0^@3oool3ool0oal0oooo0ooo0?lm0?ooo`7o00000@3oool00003o`00003oool0oooo07L0
oooo0ooo0?nQ0?ooo`7o00000@3oool00003o`00003oool0oooo07H0oooo1Ooo0?nP0?ooo`7o0000
0@3oool00003o`00003oool0oooo05h0oooo0ooo0?lE0?ooo`Goo`3oX03oool1o`000040oooo0000
0ol00000oooo0?ooo`1M0?ooo`Goo`3o503oool5ool0ob@0oooo0ooo0?mi0?ooo`7o00000@3oool0
0003o`00003oool0oooo05d0oooo1Ooo0?lE0?ooo`?oo`3o903oool5ool0ogP0oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0G@3oool5ool0oc`0oooo1Ooo0?mh0?ooo`7o00000@3oool00003o`00
003oool0oooo05h0oooo0ooo0?lm0?ooo`Goo`3oN03oool1o`000040oooo00000ol00000oooo0?oo
o`2O0?ooo`?oo`3oN@3oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0
oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o
00000?ooo`3oool0903oool3ool0oo@0oooo0Ol000010?ooo`0000?o00000?ooo`3oool08`3oool5
ool0oad0oooo0ooo0?oC0?ooo`7o00000@3oool00003o`00003oool0oooo02<0oooo1Ooo0?lL0?oo
o`Goo`3odP3oool1o`000040oooo00000ol00000oooo0?ooo`0S0?ooo`Goo`3o703oool5ool0om80
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0903oool3ool0oad0oooo1Ooo0?oB0?ooo`7o0000
0@3oool00003o`00003oool0oooo04D0oooo0ooo0?oC0?ooo`7o00000@3oool00003o`00003oool0
oooo0;L0oooo0ooo0?mQ0?ooo`7o00000@3oool00003o`00003oool0oooo0;H0oooo1Ooo0?mP0?oo
o`7o00000@3oool00003o`00003oool0oooo0;H0oooo1Ooo0?mP0?ooo`7o00000@3oool00003o`00
003oool0oooo08@0oooo0ooo0?l_0?ooo`Goo`3oH03oool1o`000040oooo00000ol00000oooo0?oo
o`230?ooo`Goo`3o;`3oool3ool0of40oooo0Ol000010?ooo`0000?o00000?ooo`3oool0P`3oool5
ool0odD0oooo0ooo0?m;0?ooo`7o00000@3oool00003o`00003oool0oooo08<0oooo1Ooo0?m40?oo
o`Goo`3oBP3oool1o`000040oooo00000ol00000oooo0?ooo`240?ooo`?oo`3oA@3oool5ool0odX0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0c03oool5ool0oa@0oooo0ooo0?lc0?ooo`7o0000
0@3oool00003o`00003oool0oooo0<d0oooo0ooo0?lD0?ooo`Goo`3o<P3oool1o`000040oooo0000
0ol00000oooo0?ooo`3T0?ooo`Goo`3o<P3oool1o`000040oooo00000ol00000oooo0?ooo`3T0?oo
o`Goo`3o<P3oool1o`000040oooo00000ol00000oooo0?ooo`3U0?ooo`?oo`3o7P3oool3ool0oa80
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3oool60?ooo`Goo`3o4@3oool1o`000040oooo
00000ol00000oooo0?ooo`3o0?ooo`H0oooo1Ooo0?lA0?ooo`7o00000@3oool00003o`00003oool0
oooo0?l0oooo1P3oool5ool0oa40oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3oool70?oo
o`?oo`3o4P3oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`00
00?o00000?ooo`3oool0H03oool3ool0okP0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0G`3o
ool5ool0okL0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0G`3oool5ool0okL0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0G`3oool5ool0okL0oooo0Ol000010?ooo`0000?o00000?ooo`3o
ool0H03oool3ool0okP0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o0000
0@3oool00003o`00003oool0oooo00`0oooo0ooo0?oo0?ooo`d0oooo0Ol000010?ooo`0000?o0000
0?ooo`3oool02`3oool5ool0oi<0oooo0ooo0?me0?ooo`7o00000@3oool00003o`00003oool0oooo
00/0oooo1Ooo0?nB0?ooo`Goo`3oM03oool1o`000040oooo00000ol00000oooo0?ooo`0;0?ooo`Go
o`3oTP3oool5ool0og@0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0303oool3ool0oi<0oooo
1Ooo0?md0?ooo`7o00000@3oool00003o`00003oool0oooo0:<0oooo0ooo0?me0?ooo`7o00000@3o
ool00003o`00003oool0oooo07l0oooo0ooo0?nI0?ooo`7o00000@3oool00003o`00003oool0oooo
07h0oooo1Ooo0?nH0?ooo`7o00000@3oool00003o`00003oool0oooo03`0oooo0ooo0?lo0?ooo`Go
o`3oV03oool1o`000040oooo00000ol00000oooo0?ooo`0k0?ooo`Goo`3o?P3oool5ool0oiP0oooo
0Ol000010?ooo`0000?o00000?ooo`3oool0>`3oool5ool0ocl0oooo0ooo0?nI0?ooo`7o00000@3o
ool00003o`00003oool0oooo03/0oooo1Ooo0?oK0?ooo`7o00000@3oool00003o`00003oool0oooo
03`0oooo0ooo0?oL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040
oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3o
oolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol0
0000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o
00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?oo
o`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool0
0003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003o
ool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`1Y0?ooo`?oo`3o[`3oool1
o`000040oooo00000ol00000oooo0?ooo`1X0?ooo`Goo`3o[P3oool1o`000040oooo00000ol00000
oooo0?ooo`1X0?ooo`Goo`3oM03oool3ool0ocL0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
J03oool5ool0ocP0oooo0ooo0?lh0?ooo`Goo`3o=P3oool1o`000040oooo00000ol00000oooo0?oo
o`1Y0?ooo`?oo`3o>03oool5ool0ocL0oooo1Ooo0?lf0?ooo`7o00000@3oool00003o`00003oool0
oooo0:@0oooo1Ooo0?lg0?ooo`Goo`3o=P3oool1o`000040oooo00000ol00000oooo0?ooo`2T0?oo
o`Goo`3o>03oool3ool0ocL0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0Y@3oool3ool0og<0
oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003o
ool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol00001
0?ooo`0000?o00000?ooo`3oool0o`3oool80?ooo`?oo`3o4@3oool1o`000040oooo00000ol00000
oooo0?ooo`0A0?ooo`?oo`3olP3oool5ool0oa00oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
403oool5ool0oo40oooo1Ooo0?l@0?ooo`7o00000@3oool00003o`00003oool0oooo0100oooo1Ooo
0?n_0?ooo`?oo`3o?`3oool5ool0oa00oooo0Ol000010?ooo`0000?o00000?ooo`3oool0403oool5
ool0ojh0oooo1Ooo0?lo0?ooo`?oo`3o4@3oool1o`000040oooo00000ol00000oooo0?ooo`0A0?oo
o`?oo`3o:P3oool3ool0oh80oooo1Ooo0?mC0?ooo`7o00000@3oool00003o`00003oool0oooo03d0
oooo1Ooo0?n10?ooo`Goo`3oD`3oool1o`000040oooo00000ol00000oooo0?ooo`0m0?ooo`Goo`3o
A03oool3ool0oc/0oooo0ooo0?mD0?ooo`7o00000@3oool00003o`00003oool0oooo03d0oooo1Ooo
0?m30?ooo`Goo`3oT@3oool1o`000040oooo00000ol00000oooo0?ooo`0n0?ooo`?oo`3oA03oool5
ool0oi40oooo0Ol000010?ooo`0000?o00000?ooo`3oool0Q@3oool5ool0oi40oooo0Ol000010?oo
o`0000?o00000?ooo`3oool0QP3oool3ool0oi80oooo0Ol000010?ooo`0000?o00000?ooo`3oool0
o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo0000
0ol00000oooo0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?oo
o`7o00000@3oool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo
0?ooo`3o0?oooa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3o
ool00003o`00003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oo
oa`0oooo0Ol000010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00
003oool0oooo0?l0oooo703oool1o`000040oooo00000ol00000oooo0?ooo`3o0?oooa`0oooo0Ol0
00010?ooo`0000?o00000?ooo`3oool0o`3ooolL0?ooo`7o00000@3oool00003o`00003oool0oooo
0?l0oooo703oool1o`000040oooo003oo`00023o00000@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0104497, -0.0104497, \
0.00355714, 0.00355714}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize resultant partitioning of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gpart1\  = \ 
        DrawPartitioning[vqCentroids, \ pr, nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[gpart1, gCentroids, yS, FrameTicks \[Rule] None];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.012 w
.73657 .72299 Mdot
.65769 .70677 Mdot
.66486 .62184 Mdot
.57126 .65354 Mdot
.78547 .62314 Mdot
.81103 .50552 Mdot
.71478 .53795 Mdot
.66143 .43811 Mdot
.58777 .79243 Mdot
.45964 .81111 Mdot
.47557 .71414 Mdot
.43086 .63999 Mdot
.34661 .76835 Mdot
.34116 .64811 Mdot
.25212 .68753 Mdot
.21619 .61026 Mdot
.78832 .41425 Mdot
.73772 .34118 Mdot
.64481 .341 Mdot
.67711 .24664 Mdot
.55247 .33873 Mdot
.55936 .25307 Mdot
.49632 .20035 Mdot
.40781 .21006 Mdot
.34454 .52306 Mdot
.29919 .45349 Mdot
.21101 .50823 Mdot
.20356 .4182 Mdot
.3996 .37912 Mdot
.39844 .29931 Mdot
.29173 .34029 Mdot
.28016 .27354 Mdot
.94382 .92049 Mdot
.80838 .89104 Mdot
.94036 .7489 Mdot
.82099 .73351 Mdot
.7037 .93125 Mdot
.59536 .89386 Mdot
.48374 .94645 Mdot
.37846 .88382 Mdot
.94053 .56812 Mdot
.9208 .45755 Mdot
.90287 .32726 Mdot
.85525 .23983 Mdot
.91784 .10118 Mdot
.78344 .08981 Mdot
.62567 .08524 Mdot
.47121 .06494 Mdot
.22707 .94064 Mdot
.2198 .81809 Mdot
.0687 .92753 Mdot
.05035 .79219 Mdot
.13616 .68359 Mdot
.05886 .5579 Mdot
.12573 .36881 Mdot
.04102 .33314 Mdot
.53462 .57128 Mdot
.56188 .47359 Mdot
.45391 .53087 Mdot
.48096 .42228 Mdot
.32474 .15398 Mdot
.24068 .06194 Mdot
.11821 .18395 Mdot
.06052 .04532 Mdot
.01176 .67349 Mdot
.04334 .44604 Mdot
.11466 .27667 Mdot
.11477 .4713 Mdot
.11559 .4708 Mdot
.12813 .85056 Mdot
.13248 .59924 Mdot
.13974 .77462 Mdot
.14462 .56275 Mdot
.14719 .09057 Mdot
.15207 .8836 Mdot
.174 .27426 Mdot
.19222 .74198 Mdot
.19476 .66721 Mdot
.20302 .32129 Mdot
.2046 .33053 Mdot
.22082 .16448 Mdot
.22371 .1844 Mdot
.24234 .46031 Mdot
.26501 .3989 Mdot
.27073 .76141 Mdot
.27327 .55622 Mdot
.27761 .51712 Mdot
.27902 .62803 Mdot
.28897 .87547 Mdot
.29229 .58421 Mdot
.30258 .84261 Mdot
.3151 .70953 Mdot
.33318 .3944 Mdot
.33632 .22639 Mdot
.33675 .2981 Mdot
.34749 .24884 Mdot
.3528 .33989 Mdot
.35624 .04081 Mdot
.37638 .45274 Mdot
.38081 .58661 Mdot
.39162 .70606 Mdot
.3925 .81782 Mdot
.39575 .57558 Mdot
.39808 .7103 Mdot
.40378 .46322 Mdot
.40616 .12294 Mdot
.4079 .46174 Mdot
.41655 .75424 Mdot
.4449 .13986 Mdot
.45048 .88255 Mdot
.45813 .26046 Mdot
.47056 .33817 Mdot
.47152 .34181 Mdot
.47375 .59205 Mdot
.48084 .28292 Mdot
.48288 .29002 Mdot
.49837 .48428 Mdot
.50091 .64831 Mdot
.5022 .63501 Mdot
.51346 .51273 Mdot
.51631 .87083 Mdot
.51924 .7711 Mdot
.5304 .84773 Mdot
.5423 .12179 Mdot
.54748 .40684 Mdot
.5504 .72644 Mdot
.58008 .16424 Mdot
.58877 .72188 Mdot
.59305 .40366 Mdot
.59718 .39913 Mdot
.59964 .29941 Mdot
.60209 .59052 Mdot
.6143 .17776 Mdot
.61987 .27976 Mdot
.62067 .54265 Mdot
.6237 .54055 Mdot
.62607 .66134 Mdot
.63352 .5172 Mdot
.67566 .83684 Mdot
.68033 .79662 Mdot
.69118 .38304 Mdot
.69134 .30422 Mdot
.69253 .82276 Mdot
.70276 .14957 Mdot
.70674 .66814 Mdot
.72121 .40668 Mdot
.72399 .82773 Mdot
.72481 .65533 Mdot
.72539 .60106 Mdot
.73209 .46452 Mdot
.74653 .47311 Mdot
.76419 .19122 Mdot
.76666 .25593 Mdot
.76876 .8086 Mdot
.7756 .55941 Mdot
.78424 .68444 Mdot
.81879 .31637 Mdot
.8206 .33784 Mdot
.84585 .15213 Mdot
.85088 .44714 Mdot
.85638 .57697 Mdot
.86675 .39861 Mdot
.87093 .81678 Mdot
.88321 .65259 Mdot
.88329 .52129 Mdot
.89133 .83572 Mdot
.89134 .65847 Mdot
.99594 .21988 Mdot
.003 w
.84585 .15213 m
0 0 rlineto s
.84585 .15213 m
.85871 0 L
s
.15207 .8836 m
0 0 rlineto s
.15207 .8836 m
.14243 1 L
s
.12813 .85056 m
0 0 rlineto s
.12813 .85056 m
0 .86793 L
s
.69253 .82276 m
.68033 .79662 L
.70674 .66814 L
.72481 .65533 L
.78424 .68444 L
.76876 .8086 L
.72399 .82773 L
.69253 .82276 L
s
.58877 .72188 m
.62607 .66134 L
.70674 .66814 L
.68033 .79662 L
.58877 .72188 L
s
.62607 .66134 m
.60209 .59052 L
.62067 .54265 L
.6237 .54055 L
.72539 .60106 L
.72481 .65533 L
.70674 .66814 L
.62607 .66134 L
s
.50091 .64831 m
.5022 .63501 L
.60209 .59052 L
.62607 .66134 L
.58877 .72188 L
.5504 .72644 L
.50091 .64831 L
s
.72481 .65533 m
.72539 .60106 L
.7756 .55941 L
.85638 .57697 L
.88321 .65259 L
.78424 .68444 L
.72481 .65533 L
s
.7756 .55941 m
.74653 .47311 L
.85088 .44714 L
.88329 .52129 L
.85638 .57697 L
.7756 .55941 L
s
.6237 .54055 m
.63352 .5172 L
.73209 .46452 L
.74653 .47311 L
.7756 .55941 L
.72539 .60106 L
.6237 .54055 L
s
.59305 .40366 m
.59718 .39913 L
.69118 .38304 L
.72121 .40668 L
.73209 .46452 L
.63352 .5172 L
.59305 .40366 L
s
.51924 .7711 m
.5504 .72644 L
.58877 .72188 L
.68033 .79662 L
.69253 .82276 L
.67566 .83684 L
.5304 .84773 L
.51924 .7711 L
s
.3925 .81782 m
.41655 .75424 L
.51924 .7711 L
.5304 .84773 L
.51631 .87083 L
.45048 .88255 L
.3925 .81782 L
s
.41655 .75424 m
.39808 .7103 L
.50091 .64831 L
.5504 .72644 L
.51924 .7711 L
.41655 .75424 L
s
.39162 .70606 m
.38081 .58661 L
.39575 .57558 L
.47375 .59205 L
.5022 .63501 L
.50091 .64831 L
.39808 .7103 L
.39162 .70606 L
s
.27073 .76141 m
.3151 .70953 L
.39162 .70606 L
.39808 .7103 L
.41655 .75424 L
.3925 .81782 L
.30258 .84261 L
.27073 .76141 L
s
.27902 .62803 m
.29229 .58421 L
.38081 .58661 L
.39162 .70606 L
.3151 .70953 L
.27902 .62803 L
s
.19222 .74198 m
.19476 .66721 L
.27902 .62803 L
.3151 .70953 L
.27073 .76141 L
.19222 .74198 L
s
.13248 .59924 m
.14462 .56275 L
.27327 .55622 L
.29229 .58421 L
.27902 .62803 L
.19476 .66721 L
.13248 .59924 L
s
.73209 .46452 m
.72121 .40668 L
.8206 .33784 L
.86675 .39861 L
.85088 .44714 L
.74653 .47311 L
.73209 .46452 L
s
.69118 .38304 m
.69134 .30422 L
.76666 .25593 L
.81879 .31637 L
.8206 .33784 L
.72121 .40668 L
.69118 .38304 L
s
.59964 .29941 m
.61987 .27976 L
.69134 .30422 L
.69118 .38304 L
.59718 .39913 L
.59964 .29941 L
s
.61987 .27976 m
.6143 .17776 L
.70276 .14957 L
.76419 .19122 L
.76666 .25593 L
.69134 .30422 L
.61987 .27976 L
s
.47152 .34181 m
.47056 .33817 L
.48288 .29002 L
.59964 .29941 L
.59718 .39913 L
.59305 .40366 L
.54748 .40684 L
.47152 .34181 L
s
.48288 .29002 m
.48084 .28292 L
.58008 .16424 L
.6143 .17776 L
.61987 .27976 L
.59964 .29941 L
.48288 .29002 L
s
.45813 .26046 m
.4449 .13986 L
.5423 .12179 L
.58008 .16424 L
.48084 .28292 L
.45813 .26046 L
s
.34749 .24884 m
.33632 .22639 L
.40616 .12294 L
.4449 .13986 L
.45813 .26046 L
.34749 .24884 L
s
.29229 .58421 m
.27327 .55622 L
.27761 .51712 L
.37638 .45274 L
.40378 .46322 L
.39575 .57558 L
.38081 .58661 L
.29229 .58421 L
s
.24234 .46031 m
.26501 .3989 L
.33318 .3944 L
.37638 .45274 L
.27761 .51712 L
.24234 .46031 L
s
.14462 .56275 m
.11477 .4713 L
.11559 .4708 L
.24234 .46031 L
.27761 .51712 L
.27327 .55622 L
.14462 .56275 L
s
.2046 .33053 m
.26501 .3989 L
.24234 .46031 L
.11559 .4708 L
.2046 .33053 L
s
.37638 .45274 m
.33318 .3944 L
.3528 .33989 L
.47056 .33817 L
.47152 .34181 L
.4079 .46174 L
.40378 .46322 L
.37638 .45274 L
s
.33675 .2981 m
.34749 .24884 L
.45813 .26046 L
.48084 .28292 L
.48288 .29002 L
.47056 .33817 L
.3528 .33989 L
.33675 .2981 L
s
.2046 .33053 m
.20302 .32129 L
.33675 .2981 L
.3528 .33989 L
.33318 .3944 L
.26501 .3989 L
.2046 .33053 L
s
.174 .27426 m
.22371 .1844 L
.33632 .22639 L
.34749 .24884 L
.33675 .2981 L
.20302 .32129 L
.174 .27426 L
s
.8556 1 m
.89133 .83572 L
s
.89133 .83572 m
1 .83353 L
s
.72399 .82773 m
.76876 .8086 L
.87093 .81678 L
.89133 .83572 L
s
.89133 .83572 m
.8556 1 L
s
.79017 1 m
.72399 .82773 L
s
.87093 .81678 m
.89134 .65847 L
s
.89134 .65847 m
1 .65857 L
s
1 .83353 m
.89133 .83572 L
.87093 .81678 L
s
.76876 .8086 m
.78424 .68444 L
.88321 .65259 L
.89134 .65847 L
.87093 .81678 L
.76876 .8086 L
s
.61935 1 m
.67566 .83684 L
.69253 .82276 L
.72399 .82773 L
s
.72399 .82773 m
.79017 1 L
s
.51631 .87083 m
.5304 .84773 L
.67566 .83684 L
s
.67566 .83684 m
.61935 1 L
s
.57717 1 m
.51631 .87083 L
s
.38061 1 m
.45048 .88255 L
.51631 .87083 L
s
.51631 .87083 m
.57717 1 L
s
.28897 .87547 m
.30258 .84261 L
.3925 .81782 L
.45048 .88255 L
s
.45048 .88255 m
.38061 1 L
s
.33571 1 m
.28897 .87547 L
s
1 .65857 m
.89134 .65847 L
.88321 .65259 L
.85638 .57697 L
.88329 .52129 L
s
.88329 .52129 m
1 .50046 L
s
.85088 .44714 m
.86675 .39861 L
s
.86675 .39861 m
1 .38027 L
s
1 .50046 m
.88329 .52129 L
.85088 .44714 L
s
.8206 .33784 m
.81879 .31637 L
.99594 .21988 L
s
.99594 .21988 m
1 .22015 L
s
1 .38027 m
.86675 .39861 L
.8206 .33784 L
s
.76666 .25593 m
.76419 .19122 L
.84585 .15213 L
.99594 .21988 L
.81879 .31637 L
.76666 .25593 L
s
1 .22015 m
.99594 .21988 L
.84585 .15213 L
s
.84585 .15213 m
.76419 .19122 L
.70276 .14957 L
s
.70276 .14957 m
.70709 0 L
s
.70709 0 m
.70276 .14957 L
.6143 .17776 L
.58008 .16424 L
.5423 .12179 L
s
.5423 .12179 m
.55831 0 L
s
.55831 0 m
.5423 .12179 L
.4449 .13986 L
.40616 .12294 L
.35624 .04081 L
s
.35624 .04081 m
.35677 0 L
s
.15207 .8836 m
.28897 .87547 L
s
.28897 .87547 m
.33571 1 L
s
.12813 .85056 m
.13974 .77462 L
.19222 .74198 L
.27073 .76141 L
.30258 .84261 L
.28897 .87547 L
.15207 .8836 L
.12813 .85056 L
s
.12813 .85056 m
.15207 .8836 L
s
0 .67306 m
.01176 .67349 L
.13974 .77462 L
.12813 .85056 L
s
.01176 .67349 m
.13248 .59924 L
.19476 .66721 L
.19222 .74198 L
.13974 .77462 L
.01176 .67349 L
s
0 .44948 m
.04334 .44604 L
.11477 .4713 L
.14462 .56275 L
.13248 .59924 L
.01176 .67349 L
s
.01176 .67349 m
0 .67306 L
s
.04334 .44604 m
.11466 .27667 L
.174 .27426 L
.20302 .32129 L
.2046 .33053 L
.11559 .4708 L
.11477 .4713 L
.04334 .44604 L
s
0 .21735 m
.11466 .27667 L
.04334 .44604 L
s
.04334 .44604 m
0 .44948 L
s
.47375 .59205 m
.51346 .51273 L
.62067 .54265 L
.60209 .59052 L
.5022 .63501 L
.47375 .59205 L
s
.51346 .51273 m
.49837 .48428 L
.54748 .40684 L
.59305 .40366 L
.63352 .5172 L
.6237 .54055 L
.62067 .54265 L
.51346 .51273 L
s
.39575 .57558 m
.40378 .46322 L
.4079 .46174 L
.49837 .48428 L
.51346 .51273 L
.47375 .59205 L
.39575 .57558 L
s
.4079 .46174 m
.47152 .34181 L
.54748 .40684 L
.49837 .48428 L
.4079 .46174 L
s
.22371 .1844 m
.22082 .16448 L
.35624 .04081 L
.40616 .12294 L
.33632 .22639 L
.22371 .1844 L
s
.14719 .09057 m
0 0 rlineto s
.14719 .09057 m
.15555 0 L
s
.35677 0 m
.35624 .04081 L
.22082 .16448 L
.14719 .09057 L
s
.11466 .27667 m
0 0 rlineto s
.11466 .27667 m
0 .21735 L
s
0 .15182 m
.14719 .09057 L
.22082 .16448 L
.22371 .1844 L
.174 .27426 L
.11466 .27667 L
s
.15555 0 m
.14719 .09057 L
s
.14719 .09057 m
0 .15182 L
s
1 0 1 r
.02 w
.73657 .72299 Mdot
.65769 .70677 Mdot
.66486 .62184 Mdot
.57126 .65354 Mdot
.78547 .62314 Mdot
.81103 .50552 Mdot
.71478 .53795 Mdot
.66143 .43811 Mdot
.58777 .79243 Mdot
.45964 .81111 Mdot
.47557 .71414 Mdot
.43086 .63999 Mdot
.34661 .76835 Mdot
.34116 .64811 Mdot
.25212 .68753 Mdot
.21619 .61026 Mdot
.78832 .41425 Mdot
.73772 .34118 Mdot
.64481 .341 Mdot
.67711 .24664 Mdot
.55247 .33873 Mdot
.55936 .25307 Mdot
.49632 .20035 Mdot
.40781 .21006 Mdot
.34454 .52306 Mdot
.29919 .45349 Mdot
.21101 .50823 Mdot
.20356 .4182 Mdot
.3996 .37912 Mdot
.39844 .29931 Mdot
.29173 .34029 Mdot
.28016 .27354 Mdot
.94382 .92049 Mdot
.80838 .89104 Mdot
.94036 .7489 Mdot
.82099 .73351 Mdot
.7037 .93125 Mdot
.59536 .89386 Mdot
.48374 .94645 Mdot
.37846 .88382 Mdot
.94053 .56812 Mdot
.9208 .45755 Mdot
.90287 .32726 Mdot
.85525 .23983 Mdot
.91784 .10118 Mdot
.78344 .08981 Mdot
.62567 .08524 Mdot
.47121 .06494 Mdot
.22707 .94064 Mdot
.2198 .81809 Mdot
.0687 .92753 Mdot
.05035 .79219 Mdot
.13616 .68359 Mdot
.05886 .5579 Mdot
.12573 .36881 Mdot
.04102 .33314 Mdot
.53462 .57128 Mdot
.56188 .47359 Mdot
.45391 .53087 Mdot
.48096 .42228 Mdot
.32474 .15398 Mdot
.24068 .06194 Mdot
.11821 .18395 Mdot
.06052 .04532 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Yooooo`0300000?oooooooooo03Oo
oooo00<00000ooooooooool0=oooool00`00003oooooooooo`0Wooooo`0300000?oooooooooo02Wo
oooo00<00000ooooooooool09Oooool1o`00007ooooo00000ol0003oooooooooo`0Yooooo`030000
0?oooooooooo03Oooooo00<00000ooooooooool0=oooool00`00003oooooooooo`0Wooooo`030000
0?oooooooooo02Wooooo00<00000ooooooooool09Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Yooooo`0300000?oooooooooo03Oooooo00<00000ooooooooool0=oooool00`00003ooooooooo
o`0Wooooo`0300000?oooooooooo02Wooooo00<00000ooooooooool09Oooool1o`00007ooooo0000
0ol0003oooooooooo`0Yooooo`0300000?oooooooooo03Oooooo00<00000ooooooooool0=_ooool0
0`00003oooooooooo`0Xooooo`0300000?oooooooooo02Wooooo00<00000ooooooooool09Oooool1
o`00007ooooo00000ol0003oooooooooo`0Yooooo`0300000?oooooooooo03Oooooo00<00000oooo
ooooool0=_ooool00`00003oooooooooo`0Xooooo`0300000?oooooooooo02Wooooo00<00000oooo
ooooool09Oooool1o`00007ooooo00000ol0003oooooooooo`0Yooooo`0300000?oooooooooo03Oo
oooo00<00000ooooooooool0=_ooool00`00003oooooooooo`0Xooooo`0300000?oooooooooo02So
oooo00<00000ooooooooool09_ooool1o`00007ooooo00000ol0003oooooooooo`0Xooooo`030000
0?oooooooooo03Sooooo00<00000ooooooooool0=_ooool00`00003oooooooooo`0Xooooo`030000
0?oooooooooo02Sooooo00<00000ooooooooool09_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Xooooo`0300000?oooooooooo03Sooooo00<00000ooooooooool0=_ooool00`00003ooooooooo
o`0Xooooo`0300000?oooooooooo02Sooooo00<00000ooooooooool09_ooool1o`00007ooooo0000
0ol0003oooooooooo`0Xooooo`0300000?oooooooooo03Sooooo00<00000ooooooooool0=_ooool0
0`00003oooooooooo`0Xooooo`0300000?oooooooooo02Sooooo00<00000ooooooooool09_ooool1
o`00007ooooo00000ol0003oooooooooo`0Xooooo`0300000?oooooooooo03Sooooo00<00000oooo
ooooool0=_ooool00`00003oooooooooo`0Xooooo`0300000?oooooooooo02Sooooo00<00000oooo
ooooool09_ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`?oo`3o6?ooool00`00003o
ooooooooo`0gooooo`80000000?o0000ooooooooool0=?ooool00`00003oooooooooo`0Yooooo`03
00000?oooooooooo02Sooooo00<00000ooooooooool09_ooool1o`00007ooooo00000ol0003ooooo
ooooo`0<ooooo`Goo`3o5oooool00`00003oooooooooo`0fooooo`0400000?l000000000o`0003Ko
oooo00<00000ooooooooool0:Oooool00`00003oooooooooo`0Xooooo`0300000?oooooooooo02Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool5ool0oaOooooo00<00000ooooooooool0
=Oooool01@00003oooooo`000?l00000000003Kooooo00<00000ooooooooool0:Oooool00`00003o
ooooooooo`0Xooooo`0300000?oooooooooo02Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
3?ooool5ool0oaOooooo00<00000ooooooooool0=?ooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo03Cooooo00<00000ooooooooool0:Oooool00`00003oooooooooo`0Xooooo`030000
0?oooooooooo02Kooooo0Ol00001ooooo`0000?o0000ooooooooool03Oooool3ool0oaSooooo00<0
0000ooooooooool0<oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo03?ooooo00<0
0000ooooooooool0:Oooool00`00003oooooooooo`0Xooooo`0300000?oooooooooo02Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0:?ooool00`00003oooooooooo`0Eooooo`?oo`3o6_ooool0
0`00003oooooooooo`06ooooo`0300000?oooooooooo03;ooooo00<00000ooooooooool0:Oooool0
0`00003oooooooooo`0Xooooo`0300000?oooooooooo02Kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:?ooool00`00003oooooooooo`0Dooooo`Goo`3o6?ooool00`00003oooooooooo`07oooo
o`0300000?oooooooooo01Wooooo0ooo0?l00ol0003oooooooooo`0Cooooo`0300000?oooooooooo
02Wooooo00<00000ooooooooool09oooool00`00003oooooooooo`0Wooooo`7o00000Oooool00003
o`000?oooooooooo02Sooooo00<00000ooooooooool05?ooool5ool0oaOooooo00<00000oooooooo
ool02Oooool00`00003oooooooooo`0Gooooo`Goo`3o5?ooool00`00003oooooooooo`0Zooooo`03
00000?oooooooooo02Oooooo00<00000ooooooooool09oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Xooooo`0300000?oooooooooo01Cooooo1Ooo0?lFooooo`0300000?oooooooooo00[ooooo
00<00000ooooooooool05oooool5ool0oaCooooo00<00000ooooooooool0:_ooool00`00003ooooo
ooooo`0Wooooo`0300000?oooooooooo02Oooooo0Ol00001ooooo`0000?o0000ooooooooool09ooo
ool00`00003oooooooooo`0Fooooo`?oo`3o5_ooool00`00003oooooooooo`0<ooooo`0300000?oo
oooooooo01Kooooo1Ooo0?lDooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool09ooo
ool00`00003oooooooooo`0Wooooo`7o00000Oooool00003o`000?oooooooooo02Oooooo00<00000
ooooooooool0;_ooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01Kooooo0ooo0?lE
ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool09oooool00`00003oooooooooo`0W
ooooo`7o00000Oooool00003o`000?oooooooooo02Oooooo00<00000ooooooooool0;Oooool00`00
003oooooooooo`0?ooooo`0300000?oooooooooo02kooooo00<00000ooooooooool04_ooool3ool0
oaCooooo00<00000ooooooooool0:?ooool00`00003oooooooooo`0Wooooo`7o00000Oooool00003
o`000?oooooooooo02Oooooo00<00000ooooooooool0:oooool2000001?ooooo00<00000oooooooo
ool0;Oooool00`00003oooooooooo`0Aooooo`Goo`3o4oooool00`00003oooooooooo`0Xooooo`03
00000?oooooooooo02Oooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool00`00003ooooo
ooooo`0Zooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool0;Oooool00`00003ooooo
ooooo`0Aooooo`Goo`3o4oooool00`00003oooooooooo`0Cooooo`?oo`3o4_ooool00`00003ooooo
ooooo`0Wooooo`7o00000Oooool00003o`000?oooooooooo02Kooooo00?o000000000?l00000:_oo
ool00`00003oooooooooo`0Eooooo`0300000?oooooooooo02_ooooo00<00000ooooooooool04_oo
ool5ool0oa?ooooo00<00000ooooooooool04_ooool5ool0oa7ooooo00<00000ooooooooool09ooo
ool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`80000000?o0000ooooooooool09oooool0
0`00003oooooooooo`0Fooooo`0300000?oooooooooo02_ooooo00<00000ooooooooool04oooool3
ool0oaCooooo00<00000ooooooooool04_ooool5ool0oa7ooooo00<00000ooooooooool09oooool1
o`00007ooooo00000ol0003oooooooooo`0Sooooo`<000000_l000000`00003oooooooooo`0Voooo
o`0300000?oooooooooo01Sooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0Zoooo
o`0300000?oooooooooo01;ooooo1Ooo0?lAooooo`0300000?oooooooooo00oooooo0ooo0?lEoooo
o`7o00000Oooool00003o`000?oooooooooo027ooooo0P000006ooooo`0300000?oooooooooo02Co
oooo00<00000ooooooooool06_ooool00`00003oooooooooo`0Yooooo`0300000?oooooooooo02[o
oooo00<00000ooooooooool04oooool3ool0oa7ooooo00<00000ooooooooool03oooool5ool0oaCo
oooo0Ol00001ooooo`0000?o0000ooooooooool07_ooool3000000Wooooo00<00000ooooooooool0
8_ooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo02Wooooo00<00000ooooooooool0
:_ooool00`00003oooooooooo`0Wooooo`0300000?oooooooooo00oooooo1Ooo0?lDooooo`7o0000
0Oooool00003o`000?oooooooooo01cooooo0P00000=ooooo`0300000?oooooooooo023ooooo00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Xooooo`0300000?oooooooooo02[ooooo00<0
0000ooooooooool09oooool00`00003oooooooooo`0?ooooo`Goo`3o5?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Iooooo`<000004?ooool00`00003oooooooooo`0Nooooo`0300000?oooooo
oooo01kooooo00<00000ooooooooool0:?ooool00`00003oooooooooo`0Zooooo`0300000?oooooo
oooo02Oooooo00<00000ooooooooool04?ooool3ool0oaGooooo0Ol00001ooooo`0000?o0000oooo
ooooool05oooool2000001Cooooo00<00000ooooooooool07?ooool00`00003oooooooooo`0Poooo
o`0300000?oooooooooo02Kooooo00<00000ooooooooool0:oooool00`00003oooooooooo`0Woooo
o`0300000?oooooooooo02Sooooo0Ol00001ooooo`0000?o0000ooooooooool05?ooool3000001Oo
oooo00<00000ooooooooool06_ooool00`00003oooooooooo`0Rooooo`0300000?oooooooooo02Go
oooo00<00000ooooooooool0:oooool00`00003oooooooooo`0Wooooo`0300000?oooooooooo02So
oooo0Ol00001ooooo`0000?o0000ooooooooool04_ooool2000001_ooooo00<00000ooooooooool0
6?ooool00`00003oooooooooo`0Sooooo`0300000?l0003o000002Cooooo00?o000000000?l00000
;?ooool00`00003oooooooooo`0Wooooo`0300000?oooooooooo02Sooooo0Ol00001ooooo`0000?o
0000ooooooooool04?ooool2000001kooooo00<00000ooooooooool05Oooool2000002Kooooo00?o
00000000000000008_ooool400000003o`000?oooooooooo02[ooooo00<00000ooooooooool09ooo
ool00`00003oooooooooo`0Xooooo`7o00000Oooool00003o`000?oooooooooo00gooooo0`00000Q
ooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool09_ooool00ol000000000o`000002
000001_ooooo1@000002ooooo`03o`000000003o000002cooooo00<00000ooooooooool09oooool0
0`00003oooooooooo`0Xooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo0P00000Uoooo
o`0300000?oooooooooo017ooooo00<00000ooooooooool09oooool00`00003oooooooooo`02oooo
o`<000004_ooool6000000Wooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0Woooo
o`0300000?oooooooooo02Sooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool3000002So
oooo00<00000ooooooooool03oooool00`00003oooooooooo`0Wooooo`0300000?oooooooooo00Ko
oooo0P00000:ooooo`H000004?ooool00`00003oooooooooo`0Yooooo`0300000?oooooooooo02Oo
oooo00<00000ooooooooool0:?ooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`800000
;?ooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo02Sooooo00<00000ooooooooool0
2?ooool2000000;o000000?ooooo0000000000000`00000Gooooo`0300000?oooooooooo02Sooooo
00<00000ooooooooool09_ooool00`00003oooooooooo`0Yooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo0`00000_ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool0:?oo
ool00`00003oooooooooo`0:ooooo`04o`00000000000000000001gooooo00<00000ooooooooool0
9oooool00`00003oooooooooo`0Vooooo`0300000?oooooooooo02Wooooo0Ol00001ooooo`0000Co
0000oooooooooooooooo0P00000cooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0
:?ooool00`00003oooooooooo`0;ooooo`03o`000000003o000001oooooo00<00000ooooooooool0
9_ooool00`00003oooooooooo`0Vooooo`0300000?oooooooooo02Wooooo0Ol00001ooooo`0000Co
00000000000000000000=_ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo01Cooooo
0ooo0?lBooooo`0300000?oooooooooo00cooooo00<00000ooooooooool07oooool00`00003ooooo
ooooo`0Tooooo`03o`000000003o000002Kooooo00?o000000000?l00000:_ooool1o`00007ooooo
00000`00003oooooooooo`0hooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool05?oo
ool5ool0oa3ooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0Pooooo`0300000?oo
oooooooo02;ooooo1000000Vooooo`<00000:_ooool1o`00007ooooo00000ol0003oooooooooo`0i
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool05Oooool5ool0o`oooooo00<00000
ooooooooool03_ooool00`00003oooooooooo`0Qooooo`0300000?oooooooooo01kooooo0`000000
1Ooooooo0000o`000?l00000000002?ooooo0P000003o`0000800000:?ooool1o`00007ooooo0000
0ol0003oooooooooo`0jooooo`0500000?ooooooooooooooo`0000006?ooool5ool0o`oooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`0Qooooo`0300000?oooooooooo01[ooooo0`00
0008ooooo`8000007oooool2000000Oooooo0P00000Vooooo`7o00000Oooool00003o`000?oooooo
oooo03_ooooo00<00000o`00000000006_ooool3ool0o`oooooo00<00000ooooooooool04?ooool0
0`00003oooooooooo`0Rooooo`0300000?l0003o000001Kooooo0`00000=ooooo`8000006oooool2
000000_ooooo0`00000Sooooo`7o00000Oooool00003o`000?oooooooooo03_ooooo00?o00000000
0?l00000:oooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo02;ooooo00?o00000000
000000004oooool3000001;ooooo00<00000ooooooooool05_ooool20000013ooooo0P00000Qoooo
o`7o00000Oooool00003o`000?oooooooooo03_ooooo00?o000000000?l00000:oooool00`00003o
ooooooooo`0Aooooo`0300000?oooooooooo02;ooooo00?o000000000?l000000`00000=ooooo`<0
00005_ooool2000001?ooooo0`00000Dooooo`8000007oooool1o`00007ooooo00000ol0003ooooo
ooooo`0looooo`0300000?oooooooooo02Wooooo00<00000ooooooooool04_ooool00`00003ooooo
ooooo`0Rooooo`0300000?oooooooooo00?ooooo0P000008ooooo`<000006oooool2000000oooooo
0P00000Iooooo`8000007Oooool1o`00007ooooo00000ol0003oooooooooo`0looooo`0300000?oo
oooooooo02Sooooo00<00000ooooooooool04oooool00`00003oooooooooo`0Qooooo`0300000?oo
oooooooo00Kooooo0`000002o`0000<000008?ooool00`00003oooooooooo`0:ooooo`8000007Ooo
ool2000001_ooooo0Ol00001ooooo`0000?o0000ooooooooool07Oooool3ool0oagooooo00<00000
ooooooooool09oooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo023ooooo00<00000
ooooooooool02Oooool00ol0000000000000000Tooooo`8000002?ooool20000027ooooo0P00000I
ooooo`7o00000Oooool00003o`000?oooooooooo01cooooo1Ooo0?lKooooo`03o`000000003o0000
02Oooooo00<00000ooooooooool05?ooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo
00[ooooo00?o000000000?l000009_ooool2000000Cooooo0P00000Uooooo`8000005oooool1o`00
007ooooo00000ol0003oooooooooo`0Looooo`Goo`3o6oooool00ol0000000000000000Vooooo`03
00000?oooooooooo01Gooooo00<00000ooooooooool07_ooool00`00003oooooooooo`0<ooooo`03
00000?oooooooooo02Oooooo00@00000ooooo`0000000000:Oooool3000001Cooooo0Ol00001oooo
o`0000?o0000ooooooooool07?ooool5ool0oa_ooooo00?o000000000?l000000`00000Sooooo`03
00000?oooooooooo01Kooooo00<00000ooooooooool07Oooool00`00003oooooooooo`0<ooooo`03
00000?oooooooooo02Oooooo00?o000000000?l00000;Oooool2000001;ooooo0Ol00001ooooo`00
00?o0000ooooooooool07Oooool3ool0oacooooo00<00000ooooooooool00oooool3000001oooooo
00<00000ooooooooool05oooool00`00003oooooooooo`09ooooo`?oo`3o4?ooool00`00003ooooo
ooooo`0=ooooo`0300000?oooooooooo02Oooooo00?o000000000?l00000;oooool20000013ooooo
0Ol00001ooooo`0000?o0000ooooooooool0??ooool00`00003oooooooooo`06ooooo`8000007?oo
ool00`00003oooooooooo`0Hooooo`0300000?oooooooooo00Sooooo1Ooo0?l>ooooo`0300000?oo
oooooooo00kooooo00<00000ooooooooool09oooool00ol000000000o`00000aooooo`8000003_oo
ool1o`00007ooooo00000ol0003oooooooooo`0kooooo`0300000?oooooooooo00Wooooo0`00000I
ooooo`0300000?oooooooooo01Sooooo00<00000ooooooooool02?ooool5ool0o`gooooo00<00000
ooooooooool03oooool00`00003oooooooooo`0Xooooo`0300000?oooooooooo03;ooooo0P00000<
ooooo`7o00000Oooool00003o`000?oooooooooo03[ooooo00<00000ooooooooool03Oooool30000
01Gooooo00<00000ooooooooool02oooool3ool0o`_ooooo00<00000ooooooooool02?ooool5ool0
o`cooooo00<00000ooooooooool04?ooool00`00003oooooooooo`0Xooooo`0300000?oooooooooo
03Cooooo0P00000:ooooo`7o00000Oooool00003o`000?oooooooooo03[ooooo00<00000oooooooo
ool04?ooool2000001;ooooo00<00000ooooooooool02oooool5ool0o`[ooooo00<00000oooooooo
ool02Oooool3ool0o`gooooo00<00000ooooooooool04?ooool00`00003oooooooooo`0Xooooo`03
00000?oooooooooo03Kooooo0P000008ooooo`7o00000Oooool00003o`000?oooooooooo03Wooooo
00<00000ooooooooool04oooool3000000oooooo00<00000ooooooooool02oooool5ool0o`[ooooo
00<00000ooooooooool06?ooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo02Sooooo
00<00000ooooooooool0>?ooool3000000Gooooo0Ol00001ooooo`0000?o0000ooooooooool0>Ooo
ool00`00003oooooooooo`0Fooooo`<000002oooool00`00003oooooooooo`0<ooooo`Goo`3o2_oo
ool00`00003oooooooooo`0Gooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool0:?oo
ool00`00003oooooooooo`0kooooo`8000000oooool1o`00007ooooo0002000003Wooooo00<00000
ooooooooool06_ooool2000000Sooooo00<00000ooooooooool03_ooool3ool0o`cooooo00<00000
ooooooooool05Oooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo02Sooooo00<00000
ooooooooool0?Oooool2000000;o00000Oooool00004o`000?ooool00000000003Oooooo00<00000
ooooooooool07?ooool3000000Gooooo00<00000ooooooooool07Oooool00`00003oooooooooo`0D
ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool0:?ooool00`00003oooooooooo`0n
ooooo`8000000Ol00001ooooo`0000Co0000oooooooooooooooo0P00000dooooo`0300000?oooooo
oooo023ooooo0`0000000ol000000000ooooo`0Oooooo`0300000?oooooooooo01?ooooo00<00000
ooooooooool05Oooool00`00003oooooooooo`0Xooooo`0300000?oooooooooo03cooooo0P000003
o`00007ooooo00000ol0003oooooooooo`03ooooo`800000<_ooool00`00003oooooooooo`0Roooo
o`03o`000000003o0000023ooooo00<00000ooooooooool04oooool00`00003oooooooooo`0Eoooo
o`0300000?oooooooooo02Sooooo00<00000ooooooooool0>_ooool2000000Cooooo0Ol00001oooo
o`0000?o0000ooooooooool01Oooool2000002oooooo00<00000ooooooooool08oooool00ol00000
0000o`00000Pooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool05oooool00`00003o
ooooooooo`0Wooooo`0300000?oooooooooo03Sooooo0P000006ooooo`7o00000Oooool00003o`00
0?oooooooooo00Oooooo0P00000/ooooo`0300000?oooooooooo02Kooooo00<00000ooooooooool0
7_ooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo01Sooooo00<00000ooooooooool0
9oooool00`00003oooooooooo`0Fooooo`?oo`3o7Oooool2000000Sooooo0Ol00001ooooo`0000?o
0000ooooooooool02Oooool2000002[ooooo00<00000ooooooooool09_ooool00`00003ooooooooo
o`0Nooooo`0300000?oooooooooo013ooooo00<00000ooooooooool06Oooool00`00003ooooooooo
o`0Wooooo`0300000?oooooooooo01Gooooo1Ooo0?lKooooo`0300000?oooooooooo00Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool02oooool2000002Oooooo00<00000ooooooooool0:?ooool0
0`00003oooooooooo`0Mooooo`0300000?oooooooooo00oooooo00<00000ooooooooool06_ooool0
0`00003oooooooooo`0<ooooo`?oo`3o6?ooool00`00003oooooooooo`0Eooooo`Goo`3o6Oooool2
000000_ooooo0Ol00001ooooo`0000?o0000ooooooooool03Oooool2000002Gooooo00<00000oooo
ooooool0:?ooool00`00003o0000o`00000Mooooo`0300000?oooooooooo00kooooo00<00000oooo
ooooool06oooool00`00003oooooooooo`0;ooooo`Goo`3o5oooool00`00003oooooooooo`0Eoooo
o`Goo`3o5oooool2000000gooooo0Ol00001ooooo`0000?o0000ooooooooool03oooool00`00003o
ooooooooo`0Qooooo`0300000?oooooooooo02Wooooo00?o00000000000000001000000Jooooo`03
00000?oooooooooo00gooooo00<00000ooooooooool02Oooool3ool0o`oooooo00<00000oooooooo
ool02oooool5ool0oaOooooo00<00000ooooooooool05_ooool3ool0oaKooooo0P00000?ooooo`7o
00000Oooool00003o`000?oooooooooo013ooooo0P00000Qooooo`0300000?oooooooooo02Wooooo
00?o000000000?l000001?ooool;000000oooooo00<00000ooooooooool03?ooool00`00003ooooo
ooooo`09ooooo`Goo`3o3_ooool00`00003oooooooooo`0;ooooo`Goo`3o5_ooool00ol000000000
o`00000^ooooo`8000004Oooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`8000007_oo
ool00`00003oooooooooo`0[ooooo`0300000?oooooooooo00kooooo2`000003ooooo`03o`000000
003o000000cooooo00<00000ooooooooool02_ooool5ool0o`kooooo00<00000ooooooooool03?oo
ool3ool0oaOooooo0P0000000ol0003oooooooooo`0Zooooo`8000004oooool1o`00007ooooo0000
0ol0003oooooooooo`0Dooooo`8000007?ooool00`00003oooooooooo`0Zooooo`0300000?oooooo
oooo01[ooooo1@0000000ol0003oooooooooo`09ooooo`0300000?oooooooooo00_ooooo1Ooo0?l>
ooooo`0300000?oooooooooo02Gooooo00@00000o`000000003o0000:_ooool2000001Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool05_ooool2000001Wooooo00<00000ooooooooool0:oooool0
0`00003oooooooooo`0Mooooo`;o000000<00000ooooooooool02?ooool00`00003oooooooooo`0=
ooooo`?oo`3o3oooool00`00003oooooooooo`0Sooooo`8000000oooool00`00003oooooooooo`0V
ooooo`8000005oooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`8000005_ooool00`00
003oooooooooo`0Iooooo`?oo`3o4?ooool00`00003oooooooooo`0Pooooo`0300000?oooooooooo
00Oooooo00<00000ooooooooool07oooool00`00003oooooooooo`0Rooooo`0300000?oooooooooo
00Cooooo00<00000ooooooooool08oooool2000001Wooooo0Ol00001ooooo`0000?o0000oooooooo
ool06_ooool20000017ooooo0ol000000`00003oooooooooo`0Hooooo`Goo`3o3oooool00`00003o
ooooooooo`0Qooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool08?ooool00`00003o
ooooooooo`0Pooooo`8000002?ooool00`00003oooooooooo`0Qooooo`0300000?oooooooooo01Wo
oooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool200000003o`000?oooooooooo00Kooooo
2@00000Kooooo`Goo`3o3oooool00`00003oooooooooo`0Rooooo`0300000?oooooooooo00?ooooo
00<00000ooooooooool08Oooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo00Wooooo
00<00000ooooooooool07_ooool2000001cooooo0Ol00001ooooo`0000?o0000ooooooooool07?oo
ool2o`0000T000001_ooool2o`00000300000?oooooooooo01Wooooo1Ooo0?l>ooooo`0300000?oo
oooooooo02Cooooo00D00000oooooooooooooooo0000000Sooooo`03o`000000003o000001kooooo
0P00000=ooooo`0300000?oooooooooo01_ooooo0P00000Nooooo`7o00000Oooool00003o`000?oo
oooooooo01cooooo0_l000000`00003oooooooooo`0?ooooo`0300000?oooooooooo01Wooooo0ooo
0?l?ooooo`0300000?oooooooooo02Cooooo00Co000000000?l0000000009?ooool01?l000000000
00000000000Looooo`0300000?oooooooooo00kooooo00<00000ooooooooool06?ooool20000023o
oooo0Ol00001ooooo`0000?o0000ooooooooool07Oooool00`00003oooooooooo`0@ooooo`030000
0?oooooooooo02_ooooo00<00000ooooooooool09?ooool2o`00000300000?oooooooooo02?ooooo
00@00000o`000?l0003ooooo0`00000Gooooo`8000004_ooool00`00003oooooooooo`0Eooooo`80
00008_ooool1o`00007ooooo00000ol0003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
00<00000ooooooooool0:_ooool00`00003oooooooooo`0Tooooo`;o000000<00000o`000?ooool0
8_ooool00`00003oooooooooo`05ooooo`<000004oooool00`00003oooooooooo`0Cooooo`030000
0?oooooooooo01;ooooo0P00000Tooooo`7o00000Oooool00003o`000?oooooooooo01cooooo00<0
0000ooooooooool04oooool00`00003oooooooooo`0Yooooo`0300000?oooooooooo02Gooooo00?o
00000000000000002000000Jooooo`0300000?oooooooooo00Wooooo0`00000>ooooo`8000005_oo
ool00`00003oooooooooo`0@ooooo`8000009_ooool1o`00007ooooo00000ol0003oooooooooo`0L
ooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool09oooool00ol000000000o`00000?
ooooo`?oo`3o5Oooool00ol000000000o`000008oooooa4000002?ooool00`00003oooooooooo`0=
ooooo`<000002_ooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo00gooooo0P00000X
ooooo`7o00000Oooool00003o`000?oooooooooo01cooooo00<00000ooooooooool05?ooool00`00
003oooooooooo`0Tooooo`@0000000?o0000ooooooooool03?ooool5ool0oaGooooo00<00000oooo
ooooool06?ooool8000001?ooooo0`000005ooooo`8000006oooool00`00003oooooooooo`0:oooo
o`800000:_ooool1o`00007ooooo00000ol0003oooooooooo`0Kooooo`0300000?oooooooooo01Go
oooo00<00000ooooooooool07oooool5000000;ooooo00?o000000000?l000003_ooool5ool0oaCo
oooo00<00000ooooooooool07_ooool2o`00000300000?oooooooooo01Cooooo0`0000000ol00000
0000ooooo`0Mooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0:_ooool1o`00007o
oooo00000ol0003oooooooooo`0Kooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool0
6?ooool6000000Wooooo00<00000ooooooooool03?ooool5ool0oaCooooo00<00000ooooooooool0
7_ooool2o`00000300000?oooooooooo01Kooooo00?o000000000?l000007oooool00`00003ooooo
ooooo`05ooooo`800000;Oooool1o`00007ooooo00000ol0003oooooooooo`0Jooooo`0300000?oo
oooooooo01Oooooo00<00000ooooooooool04oooool5000000oooooo00<00000ooooooooool03Ooo
ool3ool0oaGooooo00<00000ooooooooool08?ooool00`00003oooooooooo`0Fooooo`03o`000000
003o0000023ooooo00<00000ooooooooool00_ooool2000002oooooo0Ol00001ooooo`0000?o0000
ooooooooool06_ooool00`00003oooooooooo`0Hooooo`0300000?oooooooooo00gooooo1@00000D
ooooo`0300000?oooooooooo02Gooooo00<00000ooooooooool08?ooool00`00003oooooooooo`0G
ooooo`0300000?oooooooooo023ooooo00@00000ooooo`0000000000<Oooool1o`00007ooooo0000
0ol0003oooooooooo`0Iooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool01_ooool6
000001[ooooo00<00000ooooooooool09?ooool00`00003oooooooooo`0Pooooo`0300000?oooooo
oooo01Oooooo00<00000ooooooooool08?ooool00ol000000000o`00000booooo`7o00000Oooool0
0003o`000?oooooooooo01Wooooo00<00000ooooooooool06_ooool01000003o0000o`000?ooool5
0000023ooooo00<00000ooooooooool08oooool00`00003oooooooooo`0Qooooo`0300000?oooooo
oooo01Oooooo00<00000ooooooooool08?ooool00ol000000000o`00000booooo`7o00000Oooool0
0003o`000?oooooooooo01Wooooo00<00000ooooooooool06_ooool01?l00000000000000000000V
ooooo`0300000?oooooooooo02;ooooo00<00000ooooooooool08Oooool00`00003oooooooooo`0G
ooooo`0300000?oooooooooo023ooooo00?o000000000?l000005Oooool3ool0oa[ooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool3ool0o`kooooo00<00000ooooooooool06oooool00ol0
00000000o`00000Wooooo`0300000?oooooooooo02;ooooo00<00000ooooooooool08Oooool00`00
003oooooooooo`0Gooooo`0300000?oooooooooo027ooooo00<00000ooooooooool04oooool5ool0
oaWooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool5ool0o`gooooo00<00000oooooooo
ool06oooool00ol000000000o`00000Xooooo`0300000?oooooooooo027ooooo00<00000oooooooo
ool08Oooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo02;ooooo00<00000oooooooo
ool04_ooool5ool0oaWooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool5ool0o`cooooo
00<00000ooooooooool07?ooool00ol000000000o`00000Xooooo`0300000?oooooooooo027ooooo
00<00000ooooooooool04_ooool3ool0o`cooooo00<00000ooooooooool05oooool00`00003ooooo
ooooo`0Rooooo`0300000?oooooooooo01;ooooo1Ooo0?lIooooo`7o00000Oooool00003o`000?oo
oooooooo00Kooooo1Ooo0?l<ooooo`0300000?oooooooooo01cooooo00<00000o`00000000005_oo
ool3ool0o`oooooo00<00000o`000?l000007_ooool2o`00000300000?oooooooooo01;ooooo1Ooo
0?l;ooooo`0300000?oooooooooo00Sooooo0ooo0?l<ooooo`0300000?oooooooooo00Wooooo0ooo
0?lEooooo`80000000?o0000ooooooooool04_ooool3ool0oa[ooooo0Ol00001ooooo`0000?o0000
ooooooooool01oooool3ool0o`cooooo00<00000ooooooooool07?ooool01@00003ooooooooooooo
ool0000001Cooooo1Ooo0?l>ooooo`03o`000000000000000240000000?o0000ooooooooool04Ooo
ool5ool0o`_ooooo00<00000ooooooooool01oooool5ool0o`_ooooo00<00000ooooooooool02?oo
ool5ool0oa?ooooo00@00000o`000000003o0000<Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Fooooo`0300000?oooooooooo01cooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`0Aooooo`Goo`3o3_ooool00ol000000000o`00000Nooooo`;o00000P00000Cooooo`Goo`3o2ooo
ool00`00003oooooooooo`07ooooo`Goo`3o2oooool00`00003oooooooooo`08ooooo`Goo`3o4Ooo
ool200000004ooooool0003o00000000037ooooo0Ol00001ooooo`0000?o0000ooooooooool05_oo
ool00`00003oooooooooo`0Kooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool04?oo
ool5ool0o`kooooo00<00000ooooooooool07oooool01?l000000000o`000000000Cooooo`?oo`3o
3?ooool00`00003oooooooooo`07ooooo`Goo`3o2oooool00`00003oooooooooo`08ooooo`Goo`3o
4?ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02kooooo0Ol00001ooooo`0000?o
0000ooooooooool05Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo00Gooooo00<0
0000ooooooooool04?ooool3ool0o`oooooo00<00000ooooooooool07oooool01@00003ooooooooo
ooooool00000023ooooo00<00000ooooooooool02Oooool3ool0o`cooooo00<00000ooooooooool0
2Oooool3ool0o`oooooo0P000008ooooo`0300000?oooooooooo02gooooo0Ol00001ooooo`0000?o
0000ooooooooool05Oooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo00Oooooo00<0
0000ooooooooool08Oooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo00;ooooo00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Hooooo`0300000?oooooooooo01[ooooo00<0
0000ooooooooool02?ooool00`00003oooooooooo`0]ooooo`7o00000Oooool00003o`000?oooooo
oooo01Cooooo00<00000ooooooooool06oooool00`00003oooooooooo`09ooooo`0300000?oooooo
oooo01oooooo00<00000ooooooooool07oooool00`00003oooooooooo`04ooooo`8000007Oooool0
0`00003oooooooooo`0Hooooo`0300000?oooooooooo01Wooooo00<00000ooooooooool02_ooool0
0`00003oooooooooo`0/ooooo`7o00000Oooool00003o`000?oooooooooo01Cooooo00<00000oooo
ooooool06oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo01kooooo00<00000oooo
ooooool07oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo01[ooooo00<00000oooo
ooooool06?ooool00`00003oooooooooo`0Gooooo`8000003_ooool00`00003oooooooooo`0[oooo
o`7o00000Oooool00003o`000?oooooooooo01?ooooo00<00000ooooooooool02Oooool3ool0o`oo
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01ko
oooo00<00000ooooooooool02?ooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo01So
oooo00<00000ooooooooool05_ooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo02_o
oooo0Ol00001ooooo`0000?o0000ooooooooool04oooool00`00003oooooooooo`08ooooo`Goo`3o
3_ooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo01cooooo00<00000ooooooooool0
7oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo01Sooooo00<00000ooooooooool0
6?ooool00`00003oooooooooo`0Dooooo`8000004_ooool00`00003oooooooooo`0Zooooo`7o0000
0Oooool00003o`000?oooooooooo01?ooooo00<00000ooooooooool02?ooool5ool0o`gooooo00<0
0000ooooooooool03_ooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo01kooooo00<0
0000ooooooooool02oooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo01Sooooo00<0
0000ooooooooool04oooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo02Wooooo0Ol0
0001ooooo`0000?o0000ooooooooool04_ooool00`00003oooooooooo`09ooooo`Goo`3o3?ooool0
0`00003oooooooooo`0@ooooo`0300000?oooooooooo01Wooooo00<00000ooooooooool03Oooool3
ool0o`kooooo00<00000ooooooooool03Oooool2000001Oooooo00<00000ooooooooool06?ooool0
0`00003oooooooooo`0Aooooo`8000005oooool00`00003oooooooooo`0Xooooo`7o00000Oooool0
0003o`000?oooooooooo01;ooooo00<00000ooooooooool02_ooool3ool0o`gooooo00<00000oooo
ooooool04Oooool00`00003oooooooooo`0Hooooo`0300000?oooooooooo00cooooo1Ooo0?l=oooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool05?ooool00`00003oooooooooo`0Hoooo
o`0300000?oooooooooo013ooooo00<00000ooooooooool05oooool00`00003oooooooooo`0Xoooo
o`7o00000Oooool00003o`000?oooooooooo017ooooo00<00000ooooooooool06_ooool00`00003o
ooooooooo`0Cooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool03?ooool5ool0o`co
oooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo01Go
oooo1@00000?ooooo`8000006oooool00`00003oooooooooo`0Sooooo`@000000Ol00001ooooo`00
00?o0000ooooooooool04Oooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo01Cooooo
00<00000ooooooooool05Oooool00`00003oooooooooo`0=ooooo`Goo`3o3?ooool00`00003ooooo
ooooo`0Booooo`0300000?oooooooooo01;ooooo00<00000ooooooooool04?ooool5000000;ooooo
0ol000000`00003oooooooooo`0;ooooo`0300000?oooooooooo01cooooo00<00000ooooooooool0
6oooool7000000Cooooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool00`00003ooooooooo
o`0Jooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool05?ooool00`00003ooooooooo
o`0>ooooo`?oo`3o3?ooool00`00003oooooooooo`0Dooooo`8000004_ooool00`00003ooooooooo
o`0:ooooo`H000001oooool3o`000003ooooo`00003ooooo00[ooooo00<00000ooooooooool07Ooo
ool00`00003oooooooooo`0Cooooo`P000002oooool1o`00007ooooo00000ol0003oooooooooo`0@
ooooo`0300000?oooooooooo01Wooooo00<00000ooooooooool06?ooool00`00003oooooooooo`0A
ooooo`;o000000<00000ooooooooool07Oooool00`00003oooooooooo`0Fooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool01Oooool5000001;ooooo00<00000ooooooooool01_ooool2
0000027ooooo00<00000ooooooooool02_ooool8000001?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool04?ooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo01Sooooo00?o00000000
0?l000002Oooool:00000003o`000?oooooooooo01cooooo00<00000ooooooooool06?ooool00`00
003oooooooooo`0=ooooo`04o`000000003o0000ooooo`D000006?ooool00`00003oooooooooo`04
ooooo`0300000?oooooooooo02;ooooo00<00000o`000?l000000_ooool7000001_ooooo0Ol00001
ooooo`0000?o0000ooooooooool03oooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo
01Wooooo0_l0000:000000Sooooo00?o000000000?l000007_ooool00`00003oooooooooo`0Ioooo
o`0300000?oooooooooo00cooooo0_l00002000001kooooo00@00000oooooooooooooooo0P00000U
ooooo`03o`00000000000000008000008_ooool1o`00007ooooo00000ol0003oooooooooo`0?oooo
o`0300000?oooooooooo01Sooooo00<00000ooooooooool06_ooool2o`00000300000?oooooooooo
017ooooo00<00000ooooooooool06oooool00`00003oooooooooo`0Jooooo`03o`000000003o0000
00Kooooo1`000002o`00023ooooo00<00000o`00000000009oooool00ol000000000o`00000Toooo
o`7o00000Oooool00003o`000?oooooooooo00kooooo00<00000ooooooooool06Oooool00`00003o
ooooooooo`0Kooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool06_ooool00`00003o
ooooooooo`0Jooooo`;o00001`000004ooooo`;o000000<00000ooooooooool08?ooool00ol00000
0000o`00000Xooooo`0300000?oooooooooo02?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
3_ooool00`00003oooooooooo`0Hooooo`0300000?oooooooooo01cooooo00<00000ooooooooool0
5?ooool00`00003oooooooooo`0Hooooo`0300000?oooooooooo01_ooooo0_l000000`00003ooooo
ooooo`08ooooo`?o000000<00000ooooooooool07oooool00ol000000000o`00000@ooooo`?oo`3o
5?ooool00`00003oooooooooo`0Tooooo`7o00000Oooool00003o`000?oooooooooo00gooooo00<0
0000ooooooooool06Oooool00`00003oooooooooo`0:ooooo`?oo`3o3oooool00`00003ooooooooo
o`0Eooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool07?ooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo023ooooo00<00000ooooooooool03_ooool5ool0oa?ooooo00<0
0000ooooooooool09?ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`0300000?oooooo
oooo01Sooooo00<00000ooooooooool02_ooool5ool0o`gooooo00<00000ooooooooool05_ooool0
0`00003oooooooooo`0Fooooo`0300000?oooooooooo00Wooooo0ooo0?l@ooooo`0300000?oooooo
oooo00gooooo00<00000ooooooooool08Oooool00`00003oooooooooo`0=ooooo`Goo`3o4oooool0
0`00003oooooooooo`0Tooooo`7o00000Oooool00003o`000?oooooooooo00gooooo00<00000oooo
ooooool05oooool00`00003oooooooooo`0;ooooo`Goo`3o3Oooool00`00003oooooooooo`0Goooo
o`0300000?oooooooooo01Gooooo00<00000ooooooooool02?ooool5ool0o`oooooo00<00000oooo
ooooool03_ooool00`00003oooooooooo`0Pooooo`0300000?oooooooooo00gooooo1Ooo0?lBoooo
o`0300000?oooooooooo02Gooooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool00`00003o
ooooooooo`0Hooooo`0300000?oooooooooo00_ooooo1Ooo0?l<ooooo`0300000?oooooooooo01Wo
oooo00<00000ooooooooool04oooool00`00003oooooooooo`09ooooo`Goo`3o3_ooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo023ooooo00<00000ooooooooool03_ooool3ool0oa?o
oooo00<00000ooooooooool09Oooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`030000
0?oooooooooo01Oooooo00<00000ooooooooool03Oooool3ool0o`gooooo00<00000ooooooooool0
6_ooool00`00003oooooooooo`0Booooo`0300000?oooooooooo00Wooooo1Ooo0?l=ooooo`030000
0?oooooooooo013ooooo00<00000ooooooooool08?ooool00`00003oooooooooo`0Tooooo`030000
0?oooooooooo02Gooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool00`00003ooooooooo
o`0Hooooo`0300000?oooooooooo01gooooo00<00000ooooooooool06oooool00`00003ooooooooo
o`0@ooooo`0300000?oooooooooo00_ooooo0ooo0?l>ooooo`0300000?oooooooooo017ooooo00<0
0000ooooooooool08?ooool00`00003oooooooooo`0Sooooo`0300000?oooooooooo02Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool02oooool00`00003oooooooooo`0Gooooo`0300000?oooooo
oooo01gooooo00<00000ooooooooool07Oooool00`00003oooooooooo`0>ooooo`0300000?oooooo
oooo01cooooo00<00000ooooooooool04_ooool00`00003oooooooooo`0<ooooo`?oo`3o4Oooool0
0`00003oooooooooo`0Rooooo`0300000?oooooooooo02Kooooo0Ol00001ooooo`0000?o0000oooo
ooooool02_ooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo01kooooo00<00000oooo
ooooool07Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01cooooo00<00000oooo
ooooool04_ooool00`00003oooooooooo`0;ooooo`Goo`3o4?ooool00`00003oooooooooo`0Roooo
o`0300000?oooooooooo02Kooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool00`00003o
ooooooooo`0Gooooo`0300000?oooooooooo01kooooo00<00000ooooooooool07_ooool00`00003o
ooooooooo`0<ooooo`0300000?oooooooooo01cooooo00<00000ooooooooool05?ooool00`00003o
ooooooooo`0:ooooo`Goo`3o4?ooool00`00003oooooooooo`0Rooooo`0300000?oooooooooo02Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool2o`00000300000?oooooooooo01Kooooo
00<00000ooooooooool07_ooool00`00003oooooooooo`0Pooooo`0300000?oooooooooo00_ooooo
00<00000ooooooooool06oooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo00[ooooo
1Ooo0?l@ooooo`0300000?oooooooooo01oooooo0_l000000`00003oooooooooo`0Wooooo`7o0000
0Oooool00003o`000?oooooooooo00?ooooo2@00000Gooooo`0300000?oooooooooo01kooooo00<0
0000ooooooooool02_ooool3ool0oaCooooo00<00000ooooooooool02Oooool00`00003ooooooooo
o`0Looooo`0300000?oooooooooo01Gooooo00<00000ooooooooool02oooool3ool0oa;ooooo00<0
0000ooooooooool07_ooool3000002Wooooo0Ol00001ooooo`001P000005ooooo`?o000000Cooooo
00000000000000004oooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo00[ooooo1Ooo
0?lBooooo`04o`00000000000000000000Wooooo00<00000ooooooooool06oooool00`00003ooooo
ooooo`0Gooooo`0300000?oooooooooo01oooooo00<00000ooooooooool06_ooool4000000;o0000
00<00000ooooooooool03oooool3ool0oaGooooo0Ol00001ooooo`0000?o0000ooooooooool03ooo
ool3000000oooooo00<00000ooooooooool07oooool00`00003oooooooooo`0:ooooo`Goo`3o4_oo
ool01000003o0000o`000?ooool3000000Gooooo00<00000ooooooooool06oooool00`00003ooooo
ooooo`0Hooooo`0300000?oooooooooo01oooooo00<00000ooooooooool05Oooool5000000Oooooo
00<00000ooooooooool03Oooool5ool0oaCooooo0Ol00001ooooo`0000?o0000ooooooooool04_oo
ool3000000cooooo00<00000ooooooooool07Oooool2o`00000300000?oooooooooo00[ooooo1Ooo
0?l@ooooo`8000000ol00004ooooo`8000000ol000000`00003oooooooooo`0Kooooo`0300000?oo
oooooooo01Sooooo00<00000ooooooooool07oooool00`00003oooooooooo`0Aooooo`@000003?oo
ool00`00003oooooooooo`0=ooooo`Goo`3o5?ooool1o`00007ooooo00000ol0003oooooooooo`0E
ooooo`<000002?ooool00`00003oooooooooo`0Iooooo`L0000000?o0000ooooooooool02oooool3
ool0oa3ooooo00<00000ooooooooool02?ooool00ol00000000000000003000001_ooooo00<00000
ooooooooool06_ooool00`00003oooooooooo`0Mooooo`;o000000<00000ooooooooool03?ooool4
0000017ooooo00<00000ooooooooool03?ooool5ool0oaCooooo0Ol00001ooooo`0000?o0000oooo
ooooool06?ooool3000000Gooooo00<00000ooooooooool03Oooool<000000Gooooo00?o00000000
0?l000007_ooool2000000_ooooo00Co000000000?l0003o00000_ooool5000001Gooooo00<00000
ooooooooool06oooool00`00003oooooooooo`0Mooooo`04o`00000000000000000000Sooooo1@00
000Eooooo`0300000?oooooooooo00gooooo0ooo0?lEooooo`7o00000Oooool00003o`000?oooooo
oooo01_ooooo0`0000000ol000000000ooooo`03ooooo``000004oooool00`00003oooooooooo`0K
ooooo`0300000?oooooooooo00_ooooo00?o000000000?l000002?ooool40000017ooooo00<00000
ooooooooool02_ooool3ool0o`kooooo00<00000ooooooooool07?ooool2000000;o000000?ooooo
0000000000000_l00004000001[ooooo00<00000ooooooooool09Oooool1o`00007ooooo00000ol0
003oooooooooo`0Looooo`;o00001P00000Pooooo`0300000?oooooooooo01Sooooo0P00000?oooo
o`0300000?oooooooooo00_ooooo1000000<ooooo`0300000?oooooooooo00[ooooo1Ooo0?l>oooo
o`0300000?oooooooooo01Wooooo0P000006ooooo`03o`0000000000000001oooooo00<00000oooo
ooooool09?ooool1o`00007ooooo00000ol0003oooooooooo`0Looooo`;o000000<00000o`000?oo
ool08oooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo00oooooo00<00000oooooooo
ool03oooool5000000Oooooo00<00000ooooooooool02_ooool5ool0o`kooooo00<00000oooooooo
ool05oooool2000000Sooooo00?o000000000?l000007oooool00`00003oooooooooo`0Tooooo`7o
00000Oooool00003o`000?oooooooooo01kooooo00<00000ooooooooool09?ooool00`00003ooooo
ooooo`0Dooooo`8000004_ooool00`00003oooooooooo`0Dooooo`@000000_ooool00`00003ooooo
ooooo`0;ooooo`Goo`3o3_ooool00`00003oooooooooo`0Eooooo`8000002oooool00`00003ooooo
ooooo`0Oooooo`0300000?oooooooooo02?ooooo0Ol00001ooooo`0000?o0000ooooooooool07ooo
ool00`00003oooooooooo`0Sooooo`0300000?oooooooooo01;ooooo0P00000Dooooo`0300000?oo
oooooooo01Oooooo00?o00000000000000003oooool3ool0oa3ooooo00<00000ooooooooool04_oo
ool2000000kooooo00<00000ooooooooool07_ooool00`00003oooooooooo`0Sooooo`7o00000Ooo
ool00003o`000?oooooooooo01oooooo00<00000ooooooooool09?ooool00`00003oooooooooo`0@
ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool05oooool2o`00000300000?oooooo
oooo023ooooo00<00000ooooooooool04?ooool20000013ooooo00<00000ooooooooool07oooool0
0`00003oooooooooo`0Rooooo`7o00000Oooool00003o`000?oooooooooo01oooooo00<00000oooo
ooooool09Oooool00`00003oooooooooo`0=ooooo`8000005oooool00`00003oooooooooo`0Goooo
o`?o000000<00000ooooooooool07oooool00`00003oooooooooo`0>ooooo`8000004_ooool00`00
003oooooooooo`0Oooooo`0300000?oooooooooo02;ooooo0Ol00001ooooo`0000?o0000oooooooo
ool08?ooool00`00003oooooooooo`0Tooooo`0300000?oooooooooo00cooooo00<00000oooooooo
ool05_ooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo023ooooo00<00000oooooooo
ool03?ooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo01kooooo00<00000oooooooo
ool08_ooool1o`00007ooooo00000ol0003oooooooooo`0Pooooo`0300000?oooooooooo02Gooooo
00<00000ooooooooool02Oooool2000001Wooooo00<00000ooooooooool07?ooool00`00003ooooo
ooooo`0Oooooo`0300000?oooooooooo00[ooooo0P00000Fooooo`0300000?oooooooooo01oooooo
00<00000ooooooooool08Oooool1o`00007ooooo00000ol0003oooooooooo`0Pooooo`0300000?oo
oooooooo02Kooooo00<00000ooooooooool01oooool00`00003oooooooooo`0Iooooo`0300000?oo
oooooooo01cooooo00<00000ooooooooool07oooool00`00003oooooooooo`08ooooo`8000006?oo
ool00`00003oooooooooo`0<ooooo`?oo`3o4?ooool00`00003oooooooooo`0Nooooo`<000000Ol0
0001ooooo`0000?o0000ooooooooool08Oooool00`00003oooooooooo`0Dooooo`?oo`3o3_ooool0
0`00003oooooooooo`05ooooo`8000007?ooool00`00003oooooooooo`0Looooo`0300000?oooooo
oooo023ooooo00<00000ooooooooool01Oooool2000001_ooooo00<00000ooooooooool02_ooool5
ool0oa3ooooo00<00000ooooooooool06?ooool5000000?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool08Oooool00`00003oooooooooo`0Cooooo`Goo`3o3_ooool00`00003oooooooooo`03oooo
o`0300000?oooooooooo01cooooo00<00000ooooooooool07Oooool00`00003oooooooooo`0Ooooo
o`0300000?oooooooooo00?ooooo0P00000Mooooo`0300000?oooooooooo00[ooooo1Ooo0?l@oooo
o`0300000?oooooooooo01;ooooo1P000008ooooo`7o00000Oooool00003o`000?oooooooooo027o
oooo00<00000ooooooooool04oooool5ool0o`kooooo00@00000oooooooooooooooo0P00000Ooooo
o`0300000?oooooooooo01gooooo00<00000o`000?l000007oooool01000003oooooooooooooool2
000001oooooo00<00000ooooooooool02_ooool5ool0oa7ooooo00<00000ooooooooool03?ooool5
000000kooooo0Ol00001ooooo`0000?o0000ooooooooool08_ooool00`00003oooooooooo`0Boooo
o`Goo`3o3oooool00`00003o00000000000Qooooo`0300000?oooooooooo01gooooo00Co00000000
0000000000007_ooool01?l00000000000000000000Rooooo`0300000?oooooooooo00[ooooo0ooo
0?lBooooo`0300000?oooooooooo00Kooooo1P00000Cooooo`7o00000Oooool00003o`000?oooooo
oooo02;ooooo00<00000ooooooooool04oooool3ool0oa3ooooo00?o000000000?l000004?ooool3
ool0o`kooooo00<00000ooooooooool07Oooool01?l000000000o`000?ooool4000001[ooooo00?o
000000000?l000008oooool00`00003oooooooooo`0Oooooo`0400000?l0003o0000ooooo`D00000
6Oooool1o`00007ooooo00000ol0003oooooooooo`0Rooooo`0300000?oooooooooo02Kooooo00?o
000000000?l000003oooool5ool0o`gooooo00<00000ooooooooool07Oooool00`00003ooooooooo
o`05ooooo`@000005_ooool00ol000000000o`00000Sooooo`0300000?oooooooooo01oooooo00Co
000000000000000000007_ooool1o`00007ooooo00000ol0003oooooooooo`0Rooooo`0300000?oo
oooooooo02Oooooo00<00000ooooooooool03_ooool5ool0o`gooooo00<00000ooooooooool02ooo
ool3ool0o`oooooo00<00000ooooooooool02Oooool4000001;ooooo00<00000ooooooooool09?oo
ool00`00003oooooooooo`0Nooooo`03o`000000003o000001oooooo0Ol00001ooooo`0000?o0000
ooooooooool08oooool00`00003oooooooooo`0Vooooo`0300000?oooooooooo00kooooo1Ooo0?l=
ooooo`0300000?oooooooooo00[ooooo1Ooo0?l=ooooo`0300000?oooooooooo00kooooo0`00000?
ooooo`0300000?oooooooooo02Cooooo00<00000ooooooooool07_ooool00`00003oooooooooo`0O
ooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00<00000ooooooooool09_ooool00`00
003oooooooooo`0?ooooo`?oo`3o3_ooool00`00003oooooooooo`0:ooooo`Goo`3o3Oooool00`00
003oooooooooo`0Aooooo`@000002_ooool00`00003oooooooooo`0Eooooo`?oo`3o3Oooool00`00
003oooooooooo`0Nooooo`0300000?oooooooooo01oooooo0Ol00001ooooo`0000?o0000oooooooo
ool08oooool00`00003oooooooooo`0Vooooo`0300000?oooooooooo023ooooo00<00000oooooooo
ool02_ooool5ool0o`cooooo00<00000ooooooooool05_ooool4000000Kooooo00<00000oooooooo
ool05?ooool5ool0o`gooooo00<00000ooooooooool07?ooool00`00003oooooooooo`0Pooooo`7o
00000Oooool00003o`000?oooooooooo02Cooooo00<00000ooooooooool09?ooool00`00003ooooo
ooooo`0Qooooo`0300000?oooooooooo00_ooooo0ooo0?l<ooooo`0300000?oooooooooo01_ooooo
10000002o`00000300000?oooooooooo01Cooooo1Ooo0?l=ooooo`0300000?oooooooooo01cooooo
00<00000ooooooooool08?ooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`0300000?oo
oooooooo02Cooooo00<00000ooooooooool08Oooool00`00003oooooooooo`0Jooooo`0300000?oo
oooooooo01kooooo00Co000000000000000000005_ooool5ool0o`gooooo00<00000ooooooooool0
6oooool00`00003oooooooooo`0Qooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00<0
0000ooooooooool09?ooool00`00003oooooooooo`0Qooooo`0300000?oooooooooo01Wooooo00<0
0000ooooooooool07oooool2o`00000400000?l000000000000001Gooooo0ooo0?l?ooooo`030000
0?oooooooooo01[ooooo00<00000ooooooooool08Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Uooooo`0300000?oooooooooo02?ooooo00<00000ooooooooool08Oooool00`00003ooooooooo
o`0Iooooo`0300000?oooooooooo023ooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`0Tooooo`0300000?oooooooooo01Wooooo00<00000ooooooooool08_ooool1o`00007ooooo0000
0ol0003oooooooooo`0<ooooo`?oo`3o5_ooool00`00003oooooooooo`0Rooooo`03o`000000003o
0000027ooooo00<00000ooooooooool06Oooool00`00003oooooooooo`0Qooooo`0300000?oooooo
oooo00?ooooo0P00000Tooooo`0300000?oooooooooo01Wooooo00<00000ooooooooool08_ooool1
o`00007ooooo00000ol0003oooooooooo`0;ooooo`Goo`3o5Oooool00`00003oooooooooo`0Joooo
o`X0000000?o0000ooooooooool07oooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo
023ooooo00<00000ooooooooool01_ooool2000002;ooooo00?o000000000?l000006?ooool00`00
003oooooooooo`0Sooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo1Ooo0?lEooooo`03
o`000000003o000000Oooooo4`000008ooooo`03o`000000003o0000027ooooo00<00000oooooooo
ool06?ooool00`00003oooooooooo`0Qooooo`0300000?oooooooooo00Sooooo0P00000Pooooo`@0
00005oooool00`00003oooooooooo`0Sooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo
1Ooo0?lEooooo`03o`0000000000000000L000007Oooool00`00003oooooooooo`0Oooooo`030000
0?oooooooooo01Sooooo00<00000ooooooooool08Oooool00`00003oooooooooo`0:ooooo`030000
0?oooooooooo01cooooo00D00000o`000?l0003o0000ooooo`050000017ooooo00<00000oooooooo
ool04_ooool3ool0o`oooooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool3ool0oaKooooo
00?o000000000?l000009Oooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo01Oooooo
00<00000ooooooooool02_ooool3ool0oaCooooo00<00000ooooooooool03?ooool2000001_ooooo
00<00000ooooooooool02?ooool5000000cooooo00<00000ooooooooool04Oooool5ool0o`kooooo
0Ol00001ooooo`0000?o0000ooooooooool09_ooool00`00003oooooooooo`0Tooooo`0300000?oo
oooooooo01kooooo00<00000ooooooooool05oooool00`00003oooooooooo`09ooooo`Goo`3o4ooo
ool00`00003oooooooooo`0>ooooo`8000006?ooool00`00003oooooooooo`0>ooooo`@000001ooo
ool00`00003oooooooooo`0Booooo`Goo`3o3_ooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`0300000?oooooooooo02Kooooo00<00000ooooooooool07?ooool00ol000000000o`00000G
ooooo`0300000?oooooooooo00[ooooo1Ooo0?lBooooo`0300000?oooooooooo017ooooo0P00000E
ooooo`0300000?oooooooooo01?ooooo1@000002o`00000300000?oooooooooo01;ooooo1Ooo0?l>
ooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo00<00000ooooooooool09_ooool00`00
003oooooooooo`0Looooo`D000005?ooool00`00003oooooooooo`0;ooooo`Goo`3o4_ooool00`00
003oooooooooo`0Cooooo`8000004_ooool00`00003oooooooooo`0Iooooo`80000000?o0000oooo
ooooool04oooool3ool0o`oooooo0Ol00001ooooo`0000?o0000ooooooooool09Oooool00`00003o
ooooooooo`0Wooooo`0300000?l0003o000001[ooooo00@00000o`000?l0003o00000_ooool50000
00oooooo00<00000ooooooooool03?ooool3ool0oa;ooooo00<00000ooooooooool05_ooool00`00
003oooooooooo`0=ooooo`8000007?ooool00ol000000000o`00000Wooooo`7o00000Oooool00003
o`000?oooooooooo02Cooooo00<00000ooooooooool0:?ooool00ol0000000000000000<000000_o
oooo0_l000000`00003oooooooooo`09ooooo`H000002?ooool00`00003oooooooooo`0Rooooo`03
00000?oooooooooo01Oooooo0P00000<ooooo`0300000?oooooooooo01kooooo00<00000oooooooo
ool09Oooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`0300000?oooooooooo02Sooooo
00?o000000000?l000003?ooool=00000003o`000?oooooooooo00oooooo1@000003ooooo`030000
0?oooooooooo023ooooo0_l000000`00003oooooooooo`0Iooooo`8000002Oooool00`00003ooooo
ooooo`0Oooooo`0300000?oooooooooo02Gooooo0Ol00001ooooo`0000?o0000ooooooooool09?oo
ool00`00003oooooooooo`0Yooooo`0300000?oooooooooo01Kooooo00?o000000000?l000005_oo
ool300000003o`000?oooooooooo023ooooo0P0000000ol0003oooooooooo`0Kooooo`8000001_oo
ool00`00003oooooooooo`0Pooooo`0300000?oooooooooo02Gooooo0Ol00001ooooo`0000?o0000
ooooooooool08oooool00`00003oooooooooo`0Yooooo`0300000?oooooooooo01Sooooo00<00000
ooooooooool05_ooool00ol000000000o`00000Pooooo`80000000?o000000000?l000007oooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo02;ooooo00<00000ooooooooool09?ooool1
o`00007ooooo00000ol0003oooooooooo`0Qooooo`03o`0000000000000002_ooooo00<00000oooo
ooooool06?ooool00`00003oooooooooo`0Fooooo`;o000000<00000ooooooooool07?ooool20000
00Cooooo00<00000ooooooooool07_ooool200000003o`000000003ooooo02Cooooo00<00000oooo
ooooool09?ooool1o`00007ooooo00000ol0003oooooooooo`0Qooooo`0300000?l00000000002_o
oooo00<00000ooooooooool06?ooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo01So
oooo0`000006ooooo`0300000?oooooooooo01kooooo0_l000000`00003oooooooooo`0Tooooo`03
00000?oooooooooo02Cooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool2000000?o0000
00<00000ooooooooool04_ooool3ool0oa?ooooo00<00000ooooooooool06?ooool00`00003ooooo
ooooo`0Iooooo`0300000?oooooooooo01Kooooo0P000009ooooo`0300000?oooooooooo01kooooo
0_l000000`00003oooooooooo`0Uooooo`0300000?oooooooooo02?ooooo0Ol00001ooooo`0000?o
0000ooooooooool07Oooool2000000Kooooo00<00000ooooooooool04?ooool5ool0oa7ooooo00<0
0000ooooooooool06Oooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo01?ooooo0P00
000<ooooo`0300000?oooooooooo01oooooo00<00000ooooooooool09Oooool00`00003ooooooooo
o`0Sooooo`7o00000Oooool00003o`000?oooooooooo01cooooo00<00000ooooooooool01oooool0
0`00003oooooooooo`0?ooooo`Goo`3o4Oooool00`00003oooooooooo`0Jooooo`0300000?oooooo
oooo01[ooooo00<00000ooooooooool04?ooool2000000kooooo00<00000ooooooooool07oooool0
0`00003oooooooooo`0Uooooo`0300000?oooooooooo02?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool06_ooool2000000_ooooo00<00000ooooooooool03_ooool5ool0oa7ooooo00<00000oooo
ooooool06_ooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo00gooooo0P00000@oooo
o`0300000?oooooooooo00cooooo0ooo0?l@ooooo`0300000?oooooooooo02Kooooo00<00000oooo
ooooool08_ooool1o`00007ooooo00000ol0003oooooooooo`0Iooooo`0300000?oooooooooo00co
oooo00<00000ooooooooool03_ooool3ool0oa;ooooo00<00000ooooooooool06_ooool00`00003o
ooooooooo`0Kooooo`0300000?oooooooooo00_ooooo0P00000Cooooo`0300000?oooooooooo00[o
oooo1Ooo0?l?ooooo`0300000?oooooooooo00gooooo0ooo0?lFooooo`0300000?oooooooooo02;o
oooo0Ol00001ooooo`0000?o0000ooooooooool05oooool20000013ooooo00<00000ooooooooool0
8_ooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo01cooooo00<00000ooooooooool0
2?ooool2000001Gooooo00<00000ooooooooool02_ooool5ool0o`oooooo00<00000ooooooooool0
3?ooool5ool0oaKooooo00<00000ooooooooool08Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Eooooo`8000004_ooool00`00003oooooooooo`0Oooooo`;o000000<00000ooooooooool06ooo
ool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo0`00000Gooooo`0300000?oo
oooooooo00[ooooo1Ooo0?l?ooooo`0300000?oooooooooo00cooooo1Ooo0?lFooooo`0300000?oo
oooooooo027ooooo0Ol00001ooooo`0000?o0000ooooooooool05?ooool00`00003oooooooooo`0C
ooooo`0300000?oooooooooo01kooooo00?o00000000000000007Oooool00`00003oooooooooo`0M
ooooo`0300000?oooooooooo00;ooooo0P00000Kooooo`0300000?oooooooooo00[ooooo0ooo0?l@
ooooo`0300000?oooooooooo00cooooo1Ooo0?lFooooo`0300000?oooooooooo027ooooo0Ol00001
ooooo`0000?o0000ooooooooool04_ooool2000001Oooooo00<00000ooooooooool07?ooool20000
0003o`000000003ooooo01cooooo00<00000ooooooooool02Oooool3ool0oa7ooooo00?o00000000
0?l000000P00000Mooooo`0300000?oooooooooo01cooooo00<00000ooooooooool03_ooool3ool0
oaSooooo00<00000ooooooooool08?ooool1o`00007ooooo00000ol0003oooooooooo`0Aooooo`03
00000?oooooooooo01Sooooo00<00000ooooooooool06?ooool3000000Cooooo00<00000oooooooo
ool06_ooool00`00003oooooooooo`08ooooo`Goo`3o4?ooool2o`00000300000?oooooooooo01go
oooo00<00000ooooooooool07?ooool00`00003oooooooooo`0Yooooo`0300000?oooooooooo023o
oooo0Ol00001ooooo`0000?o0000ooooooooool03oooool2000001cooooo00<00000ooooooooool0
5Oooool2000000Oooooo00<00000ooooooooool06_ooool00`00003oooooooooo`08ooooo`Goo`3o
4?ooool2o`00000300000?oooooooooo01kooooo00<00000ooooooooool06oooool00`00003ooooo
ooooo`0Yooooo`0300000?oooooooooo023ooooo0Ol00001ooooo`0000?o0000ooooooooool03_oo
ool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01;ooooo0P00000:ooooo`0300000?oo
oooooooo00_ooooo0ooo0?l;ooooo`0300000?oooooooooo00Sooooo1Ooo0?lBooooo`0300000?oo
oooooooo01kooooo00<00000ooooooooool06oooool00`00003oooooooooo`0Zooooo`0300000?oo
oooooooo01oooooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool20000023ooooo00<00000
ooooooooool03oooool3000000cooooo00<00000ooooooooool02_ooool5ool0o`[ooooo00<00000
ooooooooool02Oooool3ool0oa7ooooo00?o000000000?l000004Oooool3ool0o`cooooo00<00000
ooooooooool06oooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo01oooooo0Ol00001
ooooo`0000?o0000ooooooooool02_ooool2000002?ooooo00<00000ooooooooool03?ooool20000
00oooooo00<00000ooooooooool02_ooool5ool0o`_ooooo00<00000ooooooooool07?ooool20000
0003o`000?oooooooooo00kooooo1Ooo0?l<ooooo`0300000?oooooooooo01[ooooo00<00000oooo
ooooool0:_ooool00`00003o0000o`00000Oooooo`7o00000Oooool00003o`000?oooooooooo00Wo
oooo00<00000ooooooooool09?ooool00`00003oooooooooo`09ooooo`8000004_ooool00`00003o
ooooooooo`09ooooo`Goo`3o2oooool00`00003oooooooooo`0Jooooo`80000000?o000000000?l0
00004?ooool5ool0o`cooooo00<00000ooooooooool06Oooool00ol000000000o`00000Zooooo`@0
00007oooool1o`00007ooooo00000ol0003oooooooooo`07ooooo`800000:?ooool00`00003ooooo
ooooo`06ooooo`8000005?ooool00`00003oooooooooo`0:ooooo`?oo`3o3?ooool00`00003ooooo
ooooo`0Iooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool03_ooool5ool0o`cooooo
00<00000o`000?l000006Oooool3000002Oooooo0`0000001?oooooo0000o`000?l0000O0000007o
00000Oooool00003o`000?oooooooooo00Kooooo00<00000ooooooooool0:Oooool00`00003ooooo
ooooo`02ooooo`<000005oooool00`00003oooooooooo`0Hooooo`0300000?oooooooooo01Oooooo
0P000006ooooo`0300000?oooooooooo00kooooo0ooo0?l=ooooo`03o`0000000000000000D00000
4_ooool2000000?o00000P00000Rooooo`<000001_ooool00ol000000000o`00000Mooooo`7o0000
0Oooool00003o`000?oooooooooo00Cooooo0P00000]ooooo`0400000?l000000000000001[ooooo
00<00000ooooooooool06?ooool00`00003oooooooooo`0Eooooo`8000002?ooool00`00003ooooo
ooooo`0Nooooo`03o`000000003o000000Gooooo2`000004ooooo`;o000000<00000ooooooooool0
1Oooool3000001cooooo0`000009ooooo`03o`000000003o000001gooooo0Ol00001ooooo`0000?o
0000ooooooooool00_ooool2000002oooooo00?o000000000?l000007?ooool00`00003ooooooooo
o`0Gooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool02Oooool00`00003ooooooooo
o`0Mooooo`0300000?oooooooooo013ooooo1P0000000ol0003oooooooooo`08ooooo`8000005ooo
ool3000000gooooo00<00000ooooooooool07?ooool1o`00007ooooo00001Ol0003oooooo`000?l0
00000000037ooooo00?o000000000?l000007?ooool00`00003oooooooooo`0Gooooo`0300000?oo
oooooooo01;ooooo0P00000=ooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool05Ooo
ool00ol000000000o`00000<ooooo`8000004_ooool30000013ooooo00<00000ooooooooool07?oo
ool1o`00007ooooo0005000003;ooooo00<00000ooooooooool06oooool00`00003oooooooooo`0G
ooooo`0300000?oooooooooo013ooooo0P00000?ooooo`0300000?oooooooooo01_ooooo00<00000
ooooooooool05_ooool00`00003oooooooooo`0=ooooo`8000003Oooool3000001;ooooo00<00000
ooooooooool07Oooool1o`00007ooooo00000ol0003oooooo`000002o`00000300000?oooooooooo
01gooooo0ooo0?l?ooooo`0300000?oooooooooo01cooooo00<00000ooooooooool05_ooool00`00
003oooooooooo`0>ooooo`8000004_ooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo
01Oooooo00<00000ooooooooool03oooool3000000Oooooo0`00000Eooooo`0300000?oooooooooo
01gooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool00`00003oooooooooo`0Kooooo`Go
o`3o3_ooool00`00003oooooooooo`0=ooooo`?oo`3o3?ooool00`00003oooooooooo`0Fooooo`03
00000?oooooooooo00gooooo00<00000ooooooooool04_ooool00`00003oooooooooo`0Iooooo`03
00000?oooooooooo01Kooooo00<00000ooooooooool04oooool200000003o`000?ooool000000080
00006?ooool00`00003oooooooooo`0Mooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo
00<00000ooooooooool06_ooool5ool0o`kooooo00<00000ooooooooool03?ooool5ool0o`cooooo
00<00000ooooooooool05Oooool00`00003oooooooooo`0;ooooo`8000005_ooool00`00003ooooo
ooooo`0Gooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool04oooool2o`0000800000
6oooool00`00003oooooooooo`0Mooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo0P00
000Jooooo`Goo`3o3_ooool00`00003oooooooooo`0<ooooo`Goo`3o3?ooool00`00003ooooooooo
o`0Fooooo`0300000?oooooooooo00Sooooo0P00000Iooooo`0300000?oooooooooo01Gooooo00<0
0000ooooooooool06?ooool00`00003oooooooooo`0Cooooo`;o000000<00000ooooooooool06_oo
ool00`00003oooooooooo`0Mooooo`7o00000Oooool00003o`000?oooooooooo00Oooooo00<00000
ooooooooool06?ooool3ool0o`oooooo00<00000ooooooooool03?ooool5ool0o`gooooo00<00000
ooooooooool05Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo01Wooooo00<00000
ooooooooool05Oooool00`00003oooooooooo`0Hooooo`0300000?oooooooooo01Gooooo00<00000
ooooooooool06_ooool00`00003oooooooooo`0Mooooo`7o00000Oooool00003o`000?oooooooooo
00Sooooo00<00000ooooooooool0:Oooool00`00003oooooooooo`0=ooooo`?oo`3o3_ooool00`00
003oooooooooo`0Eooooo`0300000?oooooooooo00Gooooo0P00000Mooooo`0300000?oooooooooo
01?ooooo00<00000ooooooooool06Oooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo
01[ooooo00<00000ooooooooool07Oooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`80
0000:Oooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo01Gooooo00<00000oooooooo
ool00oooool20000023ooooo00<00000ooooooooool04_ooool00`00003oooooooooo`0Hooooo`03
00000?oooooooooo01Gooooo00<00000ooooooooool06_ooool00`00003oooooooooo`0Nooooo`7o
00000Oooool00003o`000?oooooooooo00_ooooo00<00000ooooooooool09_ooool00`00003ooooo
ooooo`0Oooooo`0300000?oooooooooo01?ooooo00?o000000000?l000000oooool00`00003ooooo
ooooo`0Pooooo`0300000?oooooooooo017ooooo00<00000ooooooooool03?ooool3ool0o`[ooooo
00<00000ooooooooool05Oooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo01kooooo
0Ol00001ooooo`0000?o0000ooooooooool03?ooool00`00003oooooooooo`0Uooooo`0300000?oo
oooooooo01oooooo00<00000o`000?l000002Oooool=00000003o`0000000000000002Cooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`0<ooooo`Goo`3o2Oooool00`00003ooooooooo
o`0Eooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool07_ooool1o`00007ooooo0000
0ol0003oooooooooo`0=ooooo`0300000?oooooooooo02Cooooo00<00000ooooooooool07oooool0
0ol00000000000000009000000[ooooo0ol000000`00003o0000ooooo`0Booooo`?oo`3o4?ooool0
0`00003oooooooooo`0>ooooo`0300000?oooooooooo00cooooo1Ooo0?l9ooooo`0300000?oooooo
oooo01Gooooo00<00000ooooooooool06_ooool00`00003oooooooooo`0Nooooo`7o00000Oooool0
0003o`000?oooooooooo00kooooo0P00000Tooooo`0300000?oooooooooo01oooooo00?o00000000
0?l000005Oooool00ol000000000o`00000Booooo`Goo`3o3oooool00`00003oooooooooo`0=oooo
o`0300000?oooooooooo00gooooo1Ooo0?l9ooooo`0300000?oooooooooo01Gooooo00<00000oooo
ooooool06_ooool00`00003oooooooooo`0Nooooo`7o00000Oooool00003o`000?oooooooooo013o
oooo00<00000ooooooooool08Oooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo01Oo
oooo00<00000ooooooooool04?ooool5ool0oa3ooooo00<00000ooooooooool03?ooool00`00003o
ooooooooo`0>ooooo`?oo`3o2Oooool00`00003oooooooooo`08ooooo`?oo`3o2oooool00`00003o
ooooooooo`0Jooooo`0300000?oooooooooo01kooooo0Ol00001ooooo`0000?o0000ooooooooool0
4Oooool00`00003oooooooooo`0Pooooo`0300000?oooooooooo01kooooo00<00000ooooooooool0
6?ooool00`00003oooooooooo`0@ooooo`Goo`3o4?ooool00`00003oooooooooo`09ooooo`;o0000
00<00000ooooooooool06oooool00`00003oooooooooo`07ooooo`Goo`3o2_ooool00`00003ooooo
ooooo`0Jooooo`0300000?oooooooooo01kooooo0Ol00001ooooo`0000?o0000ooooooooool04_oo
ool20000023ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`0Iooooo`0300000?oo
oooooooo017ooooo0ooo0?lBooooo`0300000?l0003o000000Cooooo1`00000Mooooo`0300000?oo
oooooooo00Oooooo1Ooo0?l9ooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool07_oo
ool1o`00007ooooo00000ol0003oooooooooo`0Dooooo`0300000?oooooooooo01gooooo00<00000
ooooooooool07?ooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo02Gooooo00?o0000
00000000000010000004ooooo`?o000000<00000ooooooooool06_ooool00`00003oooooooooo`07
ooooo`Goo`3o2Oooool00`00003oooooooooo`08ooooo`?oo`3o3oooool00`00003oooooooooo`0O
ooooo`7o00000Oooool00003o`000?oooooooooo01Gooooo00<00000ooooooooool07?ooool00`00
003oooooooooo`0Kooooo`0300000?oooooooooo01cooooo00<00000ooooooooool09Oooool00ol0
00000000o`00000<ooooo`0300000?oooooooooo01Wooooo00<00000ooooooooool02?ooool3ool0
o`[ooooo00<00000ooooooooool01oooool5ool0o`kooooo00<00000ooooooooool07oooool1o`00
007ooooo00000ol0003oooooooooo`0Fooooo`0300000?oooooooooo01_ooooo00<00000oooooooo
ool06_ooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo02Cooooo00<00000oooooooo
ool03Oooool2000001Sooooo00<00000ooooooooool05_ooool00`00003oooooooooo`07ooooo`Go
o`3o3_ooool00`00003oooooooooo`0Oooooo`7o00000Oooool00003o`000?oooooooooo01Oooooo
0P00000Kooooo`0300000?oooooooooo01Wooooo00<00000ooooooooool07oooool00`00003ooooo
ooooo`0Sooooo`0300000?oooooooooo013ooooo00<00000ooooooooool05Oooool00`00003ooooo
ooooo`0Fooooo`0300000?oooooooooo00Oooooo1Ooo0?l>ooooo`0300000?oooooooooo01oooooo
0Ol00001ooooo`0000?o0000ooooooooool06Oooool00`00003oooooooooo`0Gooooo`@000006Ooo
ool00`00003oooooooooo`0Oooooo`0300000?oooooooooo02?ooooo00<00000ooooooooool04Ooo
ool00`00003oooooooooo`0Dooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool02?oo
ool3ool0o`oooooo00<00000ooooooooool07oooool1o`00007ooooo00000ol0003oooooooooo`0J
ooooo`0300000?oooooooooo01Gooooo00D00000o`000?l0003o0000ooooo`04000001Cooooo00<0
0000ooooooooool08Oooool00`00003oooooooooo`0Qooooo`0300000?oooooooooo01?ooooo00<0
0000ooooooooool04oooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo01[ooooo00<0
0000ooooooooool03Oooool3ool0o`oooooo0Ol00001ooooo`0000?o0000ooooooooool06oooool0
0`00003oooooooooo`0Booooo`80000000Coooooo`000?l0003o00001Oooool30000013ooooo00<0
0000ooooooooool08_ooool00`00003oooooooooo`0Qooooo`0300000?oooooooooo01Cooooo0P00
000Cooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool06oooool00`00003ooooooooo
o`0<ooooo`Goo`3o3_ooool1o`00007ooooo00000ol0003oooooooooo`0Looooo`8000004Oooool0
0`00003oooooooooo`0<ooooo`@000002oooool00`00003oooooooooo`0Sooooo`0300000?l0003o
0000023ooooo00<00000ooooooooool05oooool00`00003oooooooooo`0@ooooo`0300000?oooooo
oooo01Gooooo00<00000ooooooooool06oooool00`00003oooooooooo`0<ooooo`Goo`3o3_ooool1
o`00007ooooo00000ol0003oooooooooo`0Nooooo`0300000?oooooooooo00cooooo0P00000Coooo
o`@000001_ooool00`00003oooooooooo`0Tooooo`03o`00000000000000008000007Oooool00`00
003oooooooooo`0Iooooo`0300000?oooooooooo00kooooo00<00000ooooooooool05_ooool00`00
003oooooooooo`0Jooooo`0300000?oooooooooo00gooooo1Ooo0?l>ooooo`7o00000Oooool00003
o`000?oooooooooo01oooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0Gooooo`<0
00000_l000000`00003oooooooooo`0Uooooo`03o`000000003o000000;ooooo1P00000Gooooo`03
00000?oooooooooo01[ooooo0P00000>ooooo`0300000?oooooooooo01Kooooo00<00000oooooooo
ool06_ooool00`00003oooooooooo`0>ooooo`?oo`3o3oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Pooooo`8000002?ooool2000001gooooo0P0000000ol0003oooooooooo`0Aooooo`?oo`3o
4Oooool00`00003oooooooooo`08ooooo`H000004?ooool00`00003oooooooooo`0Mooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool05_ooool00`00003oooooooooo`0Jooooo`030000
0?oooooooooo023ooooo0Ol00001ooooo`0000?o0000ooooooooool08_ooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo01gooooo00?o000000000?l000004_ooool5ool0oa3ooooo00<0
0000ooooooooool03_ooool6000000[ooooo00<00000ooooooooool07_ooool00`00003ooooooooo
o`0:ooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool06_ooool00`00003ooooooooo
o`0Pooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00@00000oooooooooooooooo0P00
000Rooooo`0300000?oooooooooo013ooooo1Ooo0?l@ooooo`0300000?oooooooooo01Cooooo1P00
0003o`00000300000?oooooooooo023ooooo00<00000ooooooooool02Oooool00`00003ooooooooo
o`0Fooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool08?ooool1o`00007ooooo0000
0ol0003oooooooooo`0Tooooo`0300000?l00000000002Cooooo00<00000ooooooooool04?ooool5
ool0o`oooooo00<00000ooooooooool06oooool3000002Cooooo0P000008ooooo`0300000?oooooo
oooo01Kooooo00<00000ooooooooool06oooool00`00003oooooooooo`0Pooooo`7o00000Oooool0
0003o`000?oooooooooo02Cooooo00?o000000000?l000009?ooool00`00003oooooooooo`0Aoooo
o`?oo`3o4?ooool00`00003oooooooooo`0Kooooo`;o000000<00000ooooooooool09?ooool00`00
003oooooooooo`05ooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool06oooool00`00
003oooooooooo`0Pooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00?o000000000?l0
00009Oooool00`00003oooooooooo`0Rooooo`0300000?oooooooooo01kooooo00<00000oooooooo
ool09Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo01Kooooo00<00000oooooooo
ool06_ooool00`00003oooooooooo`0Qooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo
00<00000ooooooooool09?ooool00`00003oooooooooo`0Rooooo`0300000?oooooooooo01kooooo
00<00000ooooooooool09_ooool2000000Cooooo00<00000ooooooooool05_ooool00`00003ooooo
ooooo`0Jooooo`0300000?oooooooooo027ooooo0Ol00001ooooo`0000?o0000ooooooooool02_oo
ool3ool0oaSooooo00<00000ooooooooool09Oooool00`00003oooooooooo`0Qooooo`0300000?oo
oooooooo01kooooo00<00000ooooooooool03oooool3ool0oaKooooo00D00000oooooooooooooooo
0000000Hooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool08Oooool1o`00007ooooo
00000ol0003oooooooooo`09ooooo`Goo`3o5_ooool00`00003oooooooooo`0Vooooo`0300000?oo
oooooooo023ooooo00<00000ooooooooool08?ooool00`00003oooooooooo`0=ooooo`Goo`3o5_oo
ool00`00003ooooo0000000Iooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool08Ooo
ool1o`00007ooooo00000ol0003oooooooooo`09ooooo`Goo`3o5_ooool00`00003oooooooooo`0V
ooooo`0300000?oooooooooo023ooooo00<00000ooooooooool08?ooool00`00003oooooooooo`0=
ooooo`Goo`3o5oooool200000003o`000?oooooooooo01Kooooo00<00000ooooooooool06_ooool0
0`00003oooooooooo`0Qooooo`7o00000Oooool00003o`000?oooooooooo00Wooooo1Ooo0?lFoooo
o`0300000?oooooooooo02Oooooo00<00000ooooooooool07oooool00`00003oooooooooo`0Poooo
o`0300000?oooooooooo00gooooo1Ooo0?lGooooo`03o`000000003o000001Oooooo00<00000oooo
ooooool06oooool00`00003oooooooooo`0Qooooo`7o00000Oooool00003o`000?oooooooooo00[o
oooo0ooo0?lGooooo`0300000?oooooooooo02Oooooo00<00000ooooooooool07_ooool00`00003o
ooooooooo`0Qooooo`0300000?oooooooooo00kooooo0ooo0?lHooooo`03o`000000003o000001Oo
oooo00<00000ooooooooool06oooool00`00003oooooooooo`0Qooooo`7o00000Oooool00003o`00
0?oooooooooo02Cooooo00<00000ooooooooool0:?ooool00`00003oooooooooo`0Mooooo`030000
0?oooooooooo027ooooo00<00000ooooooooool0:oooool00`00003oooooooooo`0Eooooo`030000
0?oooooooooo01_ooooo00<00000ooooooooool08Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Sooooo`0300000?oooooooooo02Wooooo00<00000ooooooooool07?ooool00`00003ooooooooo
o`0>ooooo`?oo`3o4Oooool00`00003oooooooooo`0[ooooo`0300000?oooooooooo01Cooooo1`00
000Gooooo`0300000?oooooooooo02;ooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool0
0`00003oooooooooo`0Yooooo`0300000?oooooooooo01cooooo00<00000ooooooooool03Oooool5
ool0oa3ooooo00<00000ooooooooool0:oooool00`00003oooooooooo`0Booooo`8000000ol00004
ooooo`X000003Oooool00`00003oooooooooo`0Rooooo`7o00000Oooool00003o`000?oooooooooo
02?ooooo00<00000ooooooooool05?ooool3ool0oa?ooooo00<00000ooooooooool06Oooool2o`00
000300000?oooooooooo00gooooo1Ooo0?lAooooo`0300000?oooooooooo02_ooooo00<00000oooo
ooooool03oooool2000000;ooooo0ol0000>ooooo`T000000oooool00ol000000000o`00000Soooo
o`7o00000Oooool00003o`000?oooooooooo02?ooooo00<00000ooooooooool04oooool5ool0oa;o
oooo00<00000ooooooooool06?ooool300000003o`000?oooooooooo00gooooo1Ooo0?lAooooo`03
00000?oooooooooo02_ooooo00<00000ooooooooool03?ooool3000001kooooo1P00000Sooooo`7o
00000Oooool00003o`000?oooooooooo02?ooooo00<00000ooooooooool04oooool5ool0oa;ooooo
00<00000ooooooooool05?ooool400000004ooooool000000000o`00013ooooo0ooo0?lBooooo`03
00000?oooooooooo02_ooooo00<00000o`000?l000002_ooool2000002Cooooo0ol000000`00003o
ooooooooo`0Pooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo00<00000ooooooooool0
4oooool5ool0oa?ooooo00<00000ooooooooool04?ooool3000000Oooooo00<00000ooooooooool0
8oooool00`00003oooooooooo`0[ooooo`L000000_ooool2o`0000800000:_ooool00`00003ooooo
ooooo`0Oooooo`7o00000Oooool00003o`000?oooooooooo02;ooooo00<00000ooooooooool05Ooo
ool3ool0oaCooooo00<00000ooooooooool03?ooool4000000_ooooo00<00000ooooooooool08_oo
ool00`00003oooooooooo`0Zooooo`0400000?l0003o0000o`0000Cooooo100000000ol0003ooooo
ooooo`0Zooooo`0300000?oooooooooo01kooooo0Ol00001ooooo`0000?o0000ooooooooool08_oo
ool00`00003oooooooooo`0]ooooo`0300000?oooooooooo00Oooooo1000000@ooooo`0300000?oo
oooooooo027ooooo00<00000ooooooooool0:Oooool00`00003oooooooooo`08ooooo`03o`000000
003o000002gooooo00<00000o`000?l000007Oooool1o`00007ooooo00000ol0003oooooooooo`0R
ooooo`0300000?oooooooooo02gooooo00<00000ooooooooool01?ooool3000001Gooooo00<00000
ooooooooool08?ooool00`00003oooooooooo`0Vooooo`;o000000<00000ooooooooool02oooool0
0`00003oooooooooo`0[ooooo`03o`0000000000000001d000000Ol00001ooooo`0000?o0000oooo
ooooool08_ooool00`00003oooooooooo`0]ooooo`0300000?l0003o000000@000006Oooool00`00
003oooooooooo`0Pooooo`0300000?oooooooooo01oooooo200000000ol0003oooooooooo`0;oooo
o`0300000?oooooooooo02_ooooo00?o000000000?l000007Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Rooooo`0300000?oooooooooo02gooooo00?o00000000000000007_ooool00`00003o
ooooooooo`0Oooooo`0300000?oooooooooo017ooooo3P000006ooooo`03o`000000003o000000go
oooo00<00000ooooooooool0;?ooool00`00003oooooooooo`0Looooo`7o00000Oooool00003o`00
0?oooooooooo027ooooo00<00000ooooooooool0;_ooool00ol000000000o`00000Oooooo`030000
0?oooooooooo01gooooo00?o000000000?l000001Oooool=000001Cooooo00<00000ooooooooool0
3_ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo01gooooo0Ol00001ooooo`0000?o
0000ooooooooool08?ooool00ol000000000o`00000_ooooo`0300000?oooooooooo023ooooo00<0
0000ooooooooool07?ooool00ol000000000000000050000027ooooo00<00000ooooooooool03_oo
ool00`00003oooooooooo`0Zooooo`0300000?oooooooooo01gooooo0Ol00001ooooo`0000?o0000
ooooooooool07Oooool500000003o`000?oooooooooo02gooooo00<00000ooooooooool08Oooool0
0`00003oooooooooo`0Kooooo`03o`000000003o000002Kooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`0Yooooo`0300000?oooooooooo01gooooo0Ol00001ooooo`0000?o0000oooo
ooooool05_ooool7000000?ooooo00?o000000000?l00000;oooool00`00003oooooooooo`0Qoooo
o`0300000?oooooooooo01_ooooo00<00000ooooooooool09Oooool00`00003oooooooooo`0@oooo
o`0300000?oooooooooo02Wooooo00<00000ooooooooool07Oooool1o`00007ooooo00000ol0003o
ooooooooo`0?ooooo`L000003?ooool00`00003oooooooooo`0/ooooo`0300000?oooooooooo02?o
oooo00<00000ooooooooool06Oooool00`00003oooooooooo`0Vooooo`0300000?oooooooooo013o
oooo00<00000ooooooooool0:Oooool00`00003oooooooooo`0Mooooo`7o00000Oooool00003o`00
0?oooooooooo00Sooooo1`00000Dooooo`0300000?oooooooooo02_ooooo00<00000ooooooooool0
9?ooool00`00003oooooooooo`0Hooooo`0300000?oooooooooo02Kooooo00<00000ooooooooool0
4Oooool00`00003oooooooooo`0Wooooo`0300000?oooooooooo01kooooo0Ol00001ooooo`0000Co
0000oooooooooooooooo1`00000Looooo`0300000?oooooooooo02Wooooo00<00000ooooooooool0
9_ooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo02Kooooo00<00000ooooooooool0
4_ooool00`00003oooooooooo`0Wooooo`0300000?oooooooooo01kooooo0Ol00001ooooo`001000
000Tooooo`0300000?oooooooooo02Sooooo00<00000ooooooooool09oooool00`00003ooooooooo
o`0Booooo`<00000:Oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo02Oooooo00<0
0000ooooooooool07_ooool1o`00007ooooo00000ol0003oooooooooo`0Uooooo`0300000?oooooo
oooo02Kooooo0_l000000`00003oooooooooo`0Xooooo`0300000?oooooooooo00cooooo1@000002
o`00000300000?oooooooooo02Oooooo00<00000ooooooooool04oooool00`00003oooooooooo`0V
ooooo`0300000?oooooooooo01kooooo0Ol00001ooooo`0000?o0000ooooooooool09_ooool00`00
003oooooooooo`0Looooo`/0000000?o0000ooooooooool05Oooool3ool0oa7ooooo00<00000oooo
ooooool01_ooool5000000Gooooo0ol000000`00003oooooooooo`0Uooooo`0300000?oooooooooo
01Cooooo00<00000ooooooooool09_ooool00`00003oooooooooo`0Nooooo`7o00000Oooool00003
o`000?oooooooooo02Oooooo00<00000o`000?l000002?oooolC000000Wooooo00?o000000000?l0
00005_ooool5ool0oa7ooooo00<00000o`000?l000001@00000=ooooo`0300000?oooooooooo02Go
oooo00<00000ooooooooool05Oooool00`00003oooooooooo`0Tooooo`0300000?oooooooooo01oo
oooo0Ol00001ooooo`0000?o0000ooooooooool09oooool00ol00000000000000008000001kooooo
00<00000ooooooooool05?ooool5ool0oa7ooooo00?o00000000000000004oooool00`00003ooooo
ooooo`0Tooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool03_ooool3ool0oa?ooooo
00<00000ooooooooool07oooool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`03o`000000
003o000002Kooooo00<00000ooooooooool05?ooool5ool0oa7ooooo00?o000000000?l000004ooo
ool00`00003oooooooooo`0@ooooo`?oo`3o4?ooool00`00003oooooooooo`0Fooooo`0300000?oo
oooooooo00gooooo1Ooo0?lBooooo`0300000?oooooooooo01oooooo0Ol00001ooooo`0000?o0000
ooooooooool0:?ooool00`00003oooooooooo`0Uooooo`0300000?oooooooooo01Gooooo0ooo0?lB
ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool03_ooool5ool0o`oooooo00<00000
ooooooooool05oooool00`00003oooooooooo`0<ooooo`Goo`3o4_ooool00`00003oooooooooo`0O
ooooo`7o00000Oooool00003o`000?oooooooooo02Sooooo00<00000ooooooooool09_ooool00`00
003oooooooooo`0Xooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool03_ooool5ool0
o`oooooo00<00000ooooooooool05oooool00`00003oooooooooo`0<ooooo`Goo`3o4Oooool00`00
003oooooooooo`0Pooooo`7o00000Oooool00003o`000?oooooooooo02Sooooo00<00000oooooooo
ool09_ooool00`00003oooooooooo`0Xooooo`0300000?oooooooooo01Gooooo00<00000oooooooo
ool03_ooool5ool0o`kooooo00<00000ooooooooool06Oooool00`00003oooooooooo`0<ooooo`?o
o`3o4_ooool00`00003oooooooooo`0Pooooo`7o00000Oooool00003o`000?oooooooooo02Sooooo
00<00000ooooooooool09oooool00`00003oooooooooo`0Vooooo`0300000?oooooooooo01Oooooo
00<00000ooooooooool03_ooool3ool0o`oooooo00<00000ooooooooool06Oooool00`00003ooooo
ooooo`0Qooooo`0300000?oooooooooo023ooooo0Ol00001ooooo`0000?o0000ooooooooool09ooo
ool00`00003oooooooooo`0Xooooo`0300000?oooooooooo02Kooooo00<00000ooooooooool05ooo
ool00`00003oooooooooo`0Pooooo`0300000?oooooooooo01Wooooo00<00000ooooooooool08Ooo
ool00`00003oooooooooo`0Pooooo`7o00000Oooool00003o`000?oooooooooo02Oooooo00<00000
ooooooooool0:?ooool00`00003oooooooooo`0Uooooo`0300000?oooooooooo01Wooooo00<00000
ooooooooool07_ooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo023ooooo00<00000
ooooooooool08?ooool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`0300000?oooooooooo
02Wooooo00<00000ooooooooool08oooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo
01kooooo00<00000ooooooooool06oooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo
027ooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool00`00003oooooooooo`0Yooooo`03
00000?oooooooooo02?ooooo00<00000ooooooooool06oooool00`00003oooooooooo`0Mooooo`03
00000?oooooooooo01cooooo00<00000ooooooooool07_ooool00`00003oooooooooo`0@ooooo`?o
o`3o3_ooool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`0300000?oooooooooo02[ooooo
00<00000ooooooooool08Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01cooooo
00<00000ooooooooool07Oooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo00oooooo
1Ooo0?l=ooooo`7o00000Oooool00003o`000?oooooooooo00oooooo0ooo0?lEooooo`0300000?oo
oooooooo02[ooooo00<00000ooooooooool08Oooool00`00003oooooooooo`0Mooooo`0300000?oo
oooooooo01_ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`0Nooooo`0300000?oo
oooooooo00oooooo1Ooo0?l=ooooo`7o00000Oooool00003o`000?oooooooooo00kooooo1Ooo0?lD
ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool08?ooool00`00003oooooooooo`0N
ooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool03Oooool3ool0o`oooooo00<00000
ooooooooool07Oooool00`00003oooooooooo`0?ooooo`Goo`3o3Oooool1o`00007ooooo00000ol0
003oooooooooo`0>ooooo`Goo`3o5?ooool00`00003oooooooooo`0[ooooo`0300000?oooooooooo
01kooooo00<00000ooooooooool08?ooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo
00cooooo1Ooo0?l>ooooo`0300000?oooooooooo01cooooo00<00000ooooooooool04Oooool3ool0
o`kooooo0Ol00001ooooo`0000?o0000ooooooooool03_ooool5ool0oaCooooo00<00000oooooooo
ool0:oooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo023ooooo00<00000oooooooo
ool06Oooool00`00003oooooooooo`0<ooooo`Goo`3o3_ooool00`00003oooooooooo`0Looooo`03
00000?oooooooooo02;ooooo0Ol00001ooooo`0000?o0000ooooooooool03oooool3ool0oaGooooo
00<00000ooooooooool04_ooool3ool0oaOooooo00<00000ooooooooool07?ooool00`00003ooooo
ooooo`0Rooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool03Oooool5ool0o`oooooo
00<00000ooooooooool06oooool00`00003oooooooooo`0Rooooo`7o00000Oooool00003o`000?oo
oooooooo02Oooooo00<00000ooooooooool04Oooool5ool0oaKooooo00<00000ooooooooool07?oo
ool00`00003oooooooooo`0>ooooo`?oo`3o4Oooool00`00003oooooooooo`0Gooooo`0300000?oo
oooooooo00kooooo0ooo0?l@ooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool08_oo
ool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`0300000?oooooooooo01;ooooo1Ooo0?lF
ooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool03_ooool5ool0oa3ooooo00<00000
ooooooooool05oooool00`00003oooooooooo`0Rooooo`0300000?oooooooooo01[ooooo00<00000
ooooooooool08_ooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`0300000?oooooooooo
01;ooooo1Ooo0?lGooooo`0300000?oooooooooo01Wooooo00<00000ooooooooool03oooool5ool0
oa7ooooo00<00000ooooooooool05Oooool00`00003oooooooooo`0Sooooo`0300000?oooooooooo
01Wooooo00<00000ooooooooool08oooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`03
00000?oooooooooo01?ooooo0ooo0?lHooooo`0300000?oooooooooo01Wooooo00<00000oooooooo
ool03oooool5ool0oa7ooooo00<00000ooooooooool05Oooool00`00003oooooooooo`0Sooooo`03
00000?oooooooooo01Wooooo00<00000ooooooooool08oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Vooooo`0300000?oooooooooo02oooooo00<00000ooooooooool05oooool00`00003ooooo
ooooo`0Aooooo`?oo`3o4oooool00`00003oooooooooo`0Dooooo`0300000?oooooooooo02Cooooo
00<00000ooooooooool06?ooool00`00003oooooooooo`0Sooooo`7o00000Oooool00003o`000?oo
oooooooo02Kooooo00<00000ooooooooool0;oooool00`00003oooooooooo`0Gooooo`0300000?oo
oooooooo02Oooooo00<00000ooooooooool04oooool00`00003oooooooooo`0Uooooo`0300000?oo
oooooooo01Sooooo00<00000ooooooooool08oooool1o`00007ooooo00000ol0003oooooooooo`0V
ooooo`0300000?oooooooooo02oooooo00<00000ooooooooool05_ooool00`00003oooooooooo`0Y
ooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool09_ooool00`00003oooooooooo`0F
ooooo`0300000?oooooooooo02Cooooo0Ol00001ooooo`0000?o0000ooooooooool09_ooool00`00
003oooooooooo`0`ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool0:_ooool00`00
003oooooooooo`0Booooo`0300000?oooooooooo02Kooooo00<00000ooooooooool05_ooool00`00
003oooooooooo`0Tooooo`7o00000Oooool00003o`000?oooooooooo02Kooooo00<00000oooooooo
ool0<?ooool00`00003oooooooooo`0Dooooo`0300000?oooooooooo02_ooooo00<00000oooooooo
ool04?ooool00`00003oooooooooo`0Wooooo`0300000?oooooooooo01Kooooo00<00000oooooooo
ool09?ooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`0300000?oooooooooo037ooooo
00<00000ooooooooool04_ooool00`00003oooooooooo`0/ooooo`0300000?oooooooooo013ooooo
00<00000ooooooooool0:?ooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo02Cooooo
0Ol00001ooooo`0000?o0000ooooooooool09_ooool00`00003oooooooooo`0aooooo`0300000?oo
oooooooo01;ooooo00<00000ooooooooool0;Oooool00`00003oooooooooo`0?ooooo`0300000?oo
oooooooo02Sooooo00<00000ooooooooool05Oooool00`00003oooooooooo`0Tooooo`7o00000Ooo
ool00003o`000?oooooooooo02Kooooo00<00000ooooooooool0<Oooool00`00003oooooooooo`0A
ooooo`0300000?oooooooooo02kooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0Y
ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool09Oooool1o`00007ooooo00000ol0
003oooooooooo`0Uooooo`0300000?oooooooooo03?ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`0_ooooo`0300000?oooooooooo00kooooo00<00000ooooooooool0:_ooool00`00
003oooooooooo`0Cooooo`0300000?oooooooooo02Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool09Oooool00`00003oooooooooo`0cooooo`0300000?oooooooooo00oooooo00<00000oooooooo
ool0<?ooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo02[ooooo00<00000oooooooo
ool04oooool00`00003oooooooooo`0Uooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo
00<00000ooooooooool0=?ooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo037ooooo
00<00000ooooooooool03?ooool00`00003oooooooooo`0/ooooo`0300000?oooooooooo01;ooooo
00<00000ooooooooool09Oooool1o`00007ooooo00000ol0003oooooooooo`0Uooooo`0300000?oo
oooooooo03Cooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0booooo`0300000?oo
oooooooo00_ooooo00<00000ooooooooool0;?ooool00`00003oooooooooo`0Booooo`0300000?oo
oooooooo02Gooooo0Ol00001ooooo`0000?o0000ooooooooool09Oooool00`00003oooooooooo`0d
ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0<oooool00`00003oooooooooo`0;
ooooo`0300000?oooooooooo02cooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0V
ooooo`7o00000Oooool002So000000<00000o`000?l00000=Ol000000`00003o0000o`00000:o`00
000300000?l0003o000003Go000000<00000o`000?l000002Ol000000`00003o0000o`00000^o`00
000300000?l0003o0000013o000000<00000o`000?l000009ol00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.000440924, -0.000440924, \
0.00348739, 0.00348739}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Histograms for two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Compute histograms based on data-dependent centroids", "Subsubsection"],

Cell[BoxData[{
    \(\(h1\  = Histogram[data1, vqCentroids, pr, 150];\)\), "\n", 
    \(\(h2\  = Histogram[data2, vqCentroids, pr, 150];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize two histograms", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gh1\  = 
        DrawHistogram[h1, pr, \ nS, 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(gh2\  = 
        DrawHistogram[h2, pr, \ nS, 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gh1, gh2}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
%%ImageSize: 400 154.502 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37803e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.40309 .60182 .40512 .60371 .40853 .60269 .40651 .6008 Mtetra
.40651 .6008 .40853 .60269 .41195 .60167 .40992 .59977 Mtetra
.40992 .59977 .41195 .60167 .41537 .60064 .41334 .59874 Mtetra
.41334 .59874 .41537 .60064 .41879 .59961 .41677 .59771 Mtetra
.41677 .59771 .41879 .59961 .42222 .59858 .4202 .59668 Mtetra
.4202 .59668 .42222 .59858 .42565 .59755 .42364 .59565 Mtetra
.42364 .59565 .42565 .59755 .42909 .59652 .42708 .59462 Mtetra
.42708 .59462 .42909 .59652 .43253 .59549 .43052 .59358 Mtetra
.43052 .59358 .43253 .59549 .43597 .59446 .43397 .59255 Mtetra
.43397 .59255 .43597 .59446 .43942 .59342 .43742 .59151 Mtetra
.43742 .59151 .43942 .59342 .44288 .59239 .44088 .59047 Mtetra
.44088 .59047 .44288 .59239 .44633 .59135 .44434 .58943 Mtetra
.44434 .58943 .44633 .59135 .4498 .59031 .4478 .58839 Mtetra
.4478 .58839 .4498 .59031 .45326 .58927 .45127 .58735 Mtetra
.45127 .58735 .45326 .58927 .45674 .58823 .45475 .5863 Mtetra
.45475 .5863 .45674 .58823 .46021 .58719 .45823 .58526 Mtetra
.45823 .58526 .46021 .58719 .46369 .58614 .46171 .58421 Mtetra
.46171 .58421 .46369 .58614 .46718 .5851 .4652 .58316 Mtetra
.4652 .58316 .46718 .5851 .47067 .58405 .46869 .58211 Mtetra
.46869 .58211 .47067 .58405 .47416 .583 .47219 .58106 Mtetra
.47219 .58106 .47416 .583 .47766 .58195 .47569 .58001 Mtetra
.47569 .58001 .47766 .58195 .48116 .5809 .47919 .57896 Mtetra
.47919 .57896 .48116 .5809 .48467 .57985 .4827 .5779 Mtetra
.4827 .5779 .48467 .57985 .48818 .57879 .48622 .57685 Mtetra
.48622 .57685 .48818 .57879 .4917 .57774 .48974 .57579 Mtetra
.48974 .57579 .4917 .57774 .49522 .57668 .49326 .57473 Mtetra
.49326 .57473 .49522 .57668 .49874 .57563 .49679 .57367 Mtetra
.49679 .57367 .49874 .57563 .50227 .57457 .50032 .57261 Mtetra
.50032 .57261 .50227 .57457 .50581 .57351 .50386 .57155 Mtetra
.50386 .57155 .50581 .57351 .50935 .57244 .5074 .57048 Mtetra
.5074 .57048 .50935 .57244 .51289 .57138 .51095 .56942 Mtetra
.51095 .56942 .51289 .57138 .51644 .57032 .5145 .56835 Mtetra
.5145 .56835 .51644 .57032 .51999 .56925 .51806 .56728 Mtetra
.51806 .56728 .51999 .56925 .52355 .56818 .52162 .56621 Mtetra
.52162 .56621 .52355 .56818 .52711 .56712 .52518 .56514 Mtetra
.52518 .56514 .52711 .56712 .53068 .56605 .52875 .56407 Mtetra
.52875 .56407 .53068 .56605 .53425 .56497 .53233 .56299 Mtetra
.53233 .56299 .53425 .56497 .53783 .5639 .53591 .56192 Mtetra
.53591 .56192 .53783 .5639 .54141 .56283 .53949 .56084 Mtetra
.53949 .56084 .54141 .56283 .54499 .56175 .54308 .55976 Mtetra
.54308 .55976 .54499 .56175 .54858 .56067 .54667 .55868 Mtetra
.54667 .55868 .54858 .56067 .55218 .5596 .55027 .5576 Mtetra
.55027 .5576 .55218 .5596 .55578 .55852 .55387 .55652 Mtetra
.55387 .55652 .55578 .55852 .55938 .55743 .55748 .55543 Mtetra
.55748 .55543 .55938 .55743 .56299 .55635 .56109 .55435 Mtetra
.56109 .55435 .56299 .55635 .5666 .55527 .56471 .55326 Mtetra
.56471 .55326 .5666 .55527 .57022 .55418 .56833 .55217 Mtetra
.56833 .55217 .57022 .55418 .57385 .5531 .57196 .55109 Mtetra
.57196 .55109 .57385 .5531 .57747 .55201 .57559 .54999 Mtetra
.872 .439 .037 r
.57559 .54999 .57747 .55201 .58111 .55092 .57937 .55796 Mtetra
.495 .196 .388 r
.57937 .55796 .58111 .55092 .5849 .55888 .58302 .55687 Mtetra
.663 .742 .909 r
.58302 .55687 .5849 .55888 .58856 .55779 .58667 .55577 Mtetra
.58667 .55577 .58856 .55779 .59221 .5567 .59033 .55468 Mtetra
.59033 .55468 .59221 .5567 .59587 .5556 .594 .55358 Mtetra
.594 .55358 .59587 .5556 .59954 .55451 .59767 .55249 Mtetra
.59767 .55249 .59954 .55451 .60321 .55342 .60134 .55139 Mtetra
.60134 .55139 .60321 .55342 .60689 .55232 .60502 .55029 Mtetra
.917 .754 .665 r
.60502 .55029 .60689 .55232 .61034 .54215 .60848 .54011 Mtetra
.664 .741 .908 r
.60848 .54011 .61034 .54215 .61401 .54105 .61216 .53901 Mtetra
.61216 .53901 .61401 .54105 .61769 .53994 .61584 .5379 Mtetra
.61584 .5379 .61769 .53994 .62138 .53884 .61953 .53679 Mtetra
.61953 .53679 .62138 .53884 .62507 .53773 .62322 .53568 Mtetra
.62322 .53568 .62507 .53773 .62876 .53662 .62692 .53457 Mtetra
.62692 .53457 .62876 .53662 .63246 .53551 .63063 .53346 Mtetra
.63063 .53346 .63246 .53551 .63617 .5344 .63433 .53234 Mtetra
.63433 .53234 .63617 .5344 .63988 .53329 .63805 .53123 Mtetra
.63805 .53123 .63988 .53329 .64359 .53217 .64176 .53011 Mtetra
.64176 .53011 .64359 .53217 .64731 .53106 .64549 .52899 Mtetra
.64549 .52899 .64731 .53106 .65104 .52994 .64922 .52787 Mtetra
.64922 .52787 .65104 .52994 .65477 .52882 .65295 .52675 Mtetra
.65295 .52675 .65477 .52882 .6585 .5277 .65669 .52563 Mtetra
.65669 .52563 .6585 .5277 .66224 .52658 .66043 .5245 Mtetra
.66043 .5245 .66224 .52658 .66598 .52545 .66418 .52338 Mtetra
.66418 .52338 .66598 .52545 .66973 .52433 .66793 .52225 Mtetra
.66793 .52225 .66973 .52433 .67349 .5232 .67169 .52112 Mtetra
.67169 .52112 .67349 .5232 .67725 .52208 .67545 .51999 Mtetra
.67545 .51999 .67725 .52208 .68101 .52095 .67922 .51886 Mtetra
.67922 .51886 .68101 .52095 .68478 .51982 .68299 .51772 Mtetra
.68299 .51772 .68478 .51982 .68855 .51868 .68677 .51659 Mtetra
.68677 .51659 .68855 .51868 .69233 .51755 .69055 .51545 Mtetra
.69055 .51545 .69233 .51755 .69612 .51641 .69434 .51431 Mtetra
.69434 .51431 .69612 .51641 .69991 .51528 .69813 .51317 Mtetra
.69813 .51317 .69991 .51528 .7037 .51414 .70193 .51203 Mtetra
.70193 .51203 .7037 .51414 .7075 .513 .70573 .51089 Mtetra
.70573 .51089 .7075 .513 .71131 .51186 .70954 .50975 Mtetra
.70954 .50975 .71131 .51186 .71512 .51072 .71335 .5086 Mtetra
.71335 .5086 .71512 .51072 .71893 .50957 .71717 .50745 Mtetra
.71717 .50745 .71893 .50957 .72275 .50842 .72099 .50631 Mtetra
.72099 .50631 .72275 .50842 .72658 .50728 .72482 .50515 Mtetra
.72482 .50515 .72658 .50728 .73041 .50613 .72866 .504 Mtetra
.72866 .504 .73041 .50613 .73424 .50498 .7325 .50285 Mtetra
.7325 .50285 .73424 .50498 .73808 .50383 .73634 .50169 Mtetra
.73634 .50169 .73808 .50383 .74193 .50267 .74019 .50054 Mtetra
.74019 .50054 .74193 .50267 .74578 .50152 .74404 .49938 Mtetra
.74404 .49938 .74578 .50152 .74963 .50036 .7479 .49822 Mtetra
.7479 .49822 .74963 .50036 .7535 .4992 .75177 .49706 Mtetra
.75177 .49706 .7535 .4992 .75736 .49804 .75564 .4959 Mtetra
.75564 .4959 .75736 .49804 .76123 .49688 .75951 .49473 Mtetra
.75951 .49473 .76123 .49688 .76511 .49572 .76339 .49357 Mtetra
.76339 .49357 .76511 .49572 .76899 .49455 .76728 .4924 Mtetra
.76728 .4924 .76899 .49455 .77288 .49339 .77117 .49123 Mtetra
.77117 .49123 .77288 .49339 .77677 .49222 .77507 .49006 Mtetra
.77507 .49006 .77677 .49222 .78067 .49105 .77897 .48889 Mtetra
.77897 .48889 .78067 .49105 .78457 .48988 .78288 .48771 Mtetra
.78288 .48771 .78457 .48988 .78848 .48871 .78679 .48654 Mtetra
.78679 .48654 .78848 .48871 .7924 .48753 .79071 .48536 Mtetra
.79071 .48536 .7924 .48753 .79632 .48636 .79463 .48418 Mtetra
.79463 .48418 .79632 .48636 .80024 .48518 .79856 .483 Mtetra
.79856 .483 .80024 .48518 .80417 .484 .80249 .48182 Mtetra
.80249 .48182 .80417 .484 .80811 .48282 .80643 .48063 Mtetra
.80643 .48063 .80811 .48282 .81205 .48164 .81038 .47945 Mtetra
.81038 .47945 .81205 .48164 .81599 .48045 .81432 .47826 Mtetra
.81432 .47826 .81599 .48045 .81994 .47927 .81828 .47707 Mtetra
.81828 .47707 .81994 .47927 .8239 .47808 .82224 .47588 Mtetra
.82224 .47588 .8239 .47808 .82786 .47689 .82621 .47469 Mtetra
.82621 .47469 .82786 .47689 .83183 .4757 .83018 .4735 Mtetra
.83018 .4735 .83183 .4757 .8358 .47451 .83415 .4723 Mtetra
.83415 .4723 .8358 .47451 .83978 .47332 .83814 .47111 Mtetra
.83814 .47111 .83978 .47332 .84376 .47212 .84213 .46991 Mtetra
.84213 .46991 .84376 .47212 .84775 .47092 .84612 .46871 Mtetra
.84612 .46871 .84775 .47092 .85175 .46973 .85012 .46751 Mtetra
.85012 .46751 .85175 .46973 .85575 .46853 .85412 .46631 Mtetra
.85412 .46631 .85575 .46853 .85976 .46732 .85813 .4651 Mtetra
.85813 .4651 .85976 .46732 .86377 .46612 .86215 .46389 Mtetra
.86215 .46389 .86377 .46612 .86778 .46492 .86617 .46269 Mtetra
.86617 .46269 .86778 .46492 .87181 .46371 .87019 .46148 Mtetra
.87019 .46148 .87181 .46371 .87583 .4625 .87423 .46026 Mtetra
.87423 .46026 .87583 .4625 .87987 .46129 .87826 .45905 Mtetra
.87826 .45905 .87987 .46129 .88391 .46008 .88231 .45784 Mtetra
.88231 .45784 .88391 .46008 .88795 .45886 .88635 .45662 Mtetra
.88635 .45662 .88795 .45886 .892 .45765 .89041 .4554 Mtetra
.89041 .4554 .892 .45765 .89606 .45643 .89447 .45418 Mtetra
.89447 .45418 .89606 .45643 .90012 .45521 .89853 .45296 Mtetra
.89853 .45296 .90012 .45521 .90418 .45399 .90261 .45174 Mtetra
.90261 .45174 .90418 .45399 .90826 .45277 .90668 .45051 Mtetra
.90668 .45051 .90826 .45277 .91234 .45155 .91076 .44929 Mtetra
.91076 .44929 .91234 .45155 .91642 .45032 .91485 .44806 Mtetra
.91485 .44806 .91642 .45032 .92051 .4491 .91895 .44683 Mtetra
.91895 .44683 .92051 .4491 .9246 .44787 .92305 .4456 Mtetra
.92305 .4456 .9246 .44787 .92871 .44664 .92715 .44436 Mtetra
.92715 .44436 .92871 .44664 .93281 .44541 .93126 .44313 Mtetra
.93126 .44313 .93281 .44541 .93692 .44417 .93538 .44189 Mtetra
.93538 .44189 .93692 .44417 .94104 .44294 .9395 .44065 Mtetra
.9395 .44065 .94104 .44294 .94517 .4417 .94363 .43941 Mtetra
.94363 .43941 .94517 .4417 .9493 .44046 .94776 .43817 Mtetra
.94776 .43817 .9493 .44046 .95343 .43922 .9519 .43693 Mtetra
.9519 .43693 .95343 .43922 .95757 .43798 .95605 .43568 Mtetra
.95605 .43568 .95757 .43798 .96172 .43673 .9602 .43443 Mtetra
.9602 .43443 .96172 .43673 .96587 .43549 .96436 .43318 Mtetra
.96436 .43318 .96587 .43549 .97003 .43424 .96852 .43193 Mtetra
.40106 .59993 .40309 .60182 .40651 .6008 .40447 .5989 Mtetra
.40447 .5989 .40651 .6008 .40992 .59977 .40789 .59787 Mtetra
.40789 .59787 .40992 .59977 .41334 .59874 .41132 .59684 Mtetra
.41132 .59684 .41334 .59874 .41677 .59771 .41475 .59581 Mtetra
.41475 .59581 .41677 .59771 .4202 .59668 .41818 .59478 Mtetra
.41818 .59478 .4202 .59668 .42364 .59565 .42162 .59374 Mtetra
.42162 .59374 .42364 .59565 .42708 .59462 .42506 .59271 Mtetra
.42506 .59271 .42708 .59462 .43052 .59358 .42851 .59167 Mtetra
.42851 .59167 .43052 .59358 .43397 .59255 .43196 .59063 Mtetra
.43196 .59063 .43397 .59255 .43742 .59151 .43541 .58959 Mtetra
.43541 .58959 .43742 .59151 .44088 .59047 .43887 .58855 Mtetra
.43887 .58855 .44088 .59047 .44434 .58943 .44234 .58751 Mtetra
.44234 .58751 .44434 .58943 .4478 .58839 .4458 .58646 Mtetra
.4458 .58646 .4478 .58839 .45127 .58735 .44928 .58542 Mtetra
.44928 .58542 .45127 .58735 .45475 .5863 .45275 .58437 Mtetra
.45275 .58437 .45475 .5863 .45823 .58526 .45624 .58332 Mtetra
.45624 .58332 .45823 .58526 .46171 .58421 .45972 .58227 Mtetra
.45972 .58227 .46171 .58421 .4652 .58316 .46321 .58122 Mtetra
.46321 .58122 .4652 .58316 .46869 .58211 .46671 .58017 Mtetra
.46671 .58017 .46869 .58211 .47219 .58106 .47021 .57912 Mtetra
.47021 .57912 .47219 .58106 .47569 .58001 .47371 .57806 Mtetra
.47371 .57806 .47569 .58001 .47919 .57896 .47722 .57701 Mtetra
.47722 .57701 .47919 .57896 .4827 .5779 .48073 .57595 Mtetra
.48073 .57595 .4827 .5779 .48622 .57685 .48425 .57489 Mtetra
.48425 .57489 .48622 .57685 .48974 .57579 .48777 .57383 Mtetra
.48777 .57383 .48974 .57579 .49326 .57473 .4913 .57277 Mtetra
.4913 .57277 .49326 .57473 .49679 .57367 .49483 .57171 Mtetra
.49483 .57171 .49679 .57367 .50032 .57261 .49837 .57064 Mtetra
.49837 .57064 .50032 .57261 .50386 .57155 .50191 .56958 Mtetra
.50191 .56958 .50386 .57155 .5074 .57048 .50545 .56851 Mtetra
.50545 .56851 .5074 .57048 .51095 .56942 .509 .56744 Mtetra
.509 .56744 .51095 .56942 .5145 .56835 .51256 .56637 Mtetra
.51256 .56637 .5145 .56835 .51806 .56728 .51612 .5653 Mtetra
.51612 .5653 .51806 .56728 .52162 .56621 .51968 .56423 Mtetra
.51968 .56423 .52162 .56621 .52518 .56514 .52325 .56316 Mtetra
.52325 .56316 .52518 .56514 .52875 .56407 .52682 .56208 Mtetra
.52682 .56208 .52875 .56407 .53233 .56299 .5304 .56101 Mtetra
.5304 .56101 .53233 .56299 .53591 .56192 .53398 .55993 Mtetra
.53398 .55993 .53591 .56192 .53949 .56084 .53757 .55885 Mtetra
.53757 .55885 .53949 .56084 .54308 .55976 .54116 .55777 Mtetra
.54116 .55777 .54308 .55976 .54667 .55868 .54476 .55669 Mtetra
.54476 .55669 .54667 .55868 .55027 .5576 .54836 .5556 Mtetra
.54836 .5556 .55027 .5576 .55387 .55652 .55196 .55452 Mtetra
.55196 .55452 .55387 .55652 .55748 .55543 .55557 .55343 Mtetra
.55557 .55343 .55748 .55543 .56109 .55435 .55919 .55234 Mtetra
.55919 .55234 .56109 .55435 .56471 .55326 .56281 .55125 Mtetra
.56281 .55125 .56471 .55326 .56833 .55217 .56643 .55016 Mtetra
.56643 .55016 .56833 .55217 .57196 .55109 .57006 .54907 Mtetra
.57006 .54907 .57196 .55109 .57559 .54999 .5737 .54798 Mtetra
.872 .439 .037 r
.5737 .54798 .57559 .54999 .57937 .55796 .57748 .55594 Mtetra
.663 .742 .909 r
.57748 .55594 .57937 .55796 .58302 .55687 .58113 .55485 Mtetra
.58113 .55485 .58302 .55687 .58667 .55577 .58479 .55375 Mtetra
.58479 .55375 .58667 .55577 .59033 .55468 .58845 .55266 Mtetra
.58845 .55266 .59033 .55468 .594 .55358 .59212 .55156 Mtetra
.59212 .55156 .594 .55358 .59767 .55249 .59579 .55046 Mtetra
.59579 .55046 .59767 .55249 .60134 .55139 .59947 .54936 Mtetra
.59947 .54936 .60134 .55139 .60502 .55029 .60315 .54826 Mtetra
.60315 .54826 .60502 .55029 .60848 .54011 .60684 .54715 Mtetra
0 0 .05 r
.60684 .54715 .60848 .54011 .61216 .53901 .6103 .53696 Mtetra
.664 .741 .908 r
.6103 .53696 .61216 .53901 .61584 .5379 .61399 .53585 Mtetra
.61399 .53585 .61584 .5379 .61953 .53679 .61768 .53474 Mtetra
.61768 .53474 .61953 .53679 .62322 .53568 .62138 .53363 Mtetra
.62138 .53363 .62322 .53568 .62692 .53457 .62508 .53251 Mtetra
.62508 .53251 .62692 .53457 .63063 .53346 .62878 .5314 Mtetra
.62878 .5314 .63063 .53346 .63433 .53234 .63249 .53028 Mtetra
.63249 .53028 .63433 .53234 .63805 .53123 .63621 .52916 Mtetra
.63621 .52916 .63805 .53123 .64176 .53011 .63993 .52804 Mtetra
.63993 .52804 .64176 .53011 .64549 .52899 .64366 .52692 Mtetra
.64366 .52692 .64549 .52899 .64922 .52787 .64739 .5258 Mtetra
.64739 .5258 .64922 .52787 .65295 .52675 .65113 .52468 Mtetra
.65113 .52468 .65295 .52675 .65669 .52563 .65487 .52355 Mtetra
.65487 .52355 .65669 .52563 .66043 .5245 .65861 .52242 Mtetra
.65861 .52242 .66043 .5245 .66418 .52338 .66236 .52129 Mtetra
.66236 .52129 .66418 .52338 .66793 .52225 .66612 .52016 Mtetra
.66612 .52016 .66793 .52225 .67169 .52112 .66988 .51903 Mtetra
.66988 .51903 .67169 .52112 .67545 .51999 .67365 .5179 Mtetra
.67365 .5179 .67545 .51999 .67922 .51886 .67742 .51676 Mtetra
.67742 .51676 .67922 .51886 .68299 .51772 .68119 .51563 Mtetra
.68119 .51563 .68299 .51772 .68677 .51659 .68498 .51449 Mtetra
.68498 .51449 .68677 .51659 .69055 .51545 .68876 .51335 Mtetra
.68876 .51335 .69055 .51545 .69434 .51431 .69255 .51221 Mtetra
.69255 .51221 .69434 .51431 .69813 .51317 .69635 .51107 Mtetra
.69635 .51107 .69813 .51317 .70193 .51203 .70015 .50992 Mtetra
.70015 .50992 .70193 .51203 .70573 .51089 .70396 .50878 Mtetra
.70396 .50878 .70573 .51089 .70954 .50975 .70777 .50763 Mtetra
.70777 .50763 .70954 .50975 .71335 .5086 .71159 .50648 Mtetra
.71159 .50648 .71335 .5086 .71717 .50745 .71541 .50533 Mtetra
.71541 .50533 .71717 .50745 .72099 .50631 .71923 .50418 Mtetra
.71923 .50418 .72099 .50631 .72482 .50515 .72307 .50303 Mtetra
.72307 .50303 .72482 .50515 .72866 .504 .7269 .50187 Mtetra
.7269 .50187 .72866 .504 .7325 .50285 .73075 .50072 Mtetra
.73075 .50072 .7325 .50285 .73634 .50169 .73459 .49956 Mtetra
.73459 .49956 .73634 .50169 .74019 .50054 .73845 .4984 Mtetra
.73845 .4984 .74019 .50054 .74404 .49938 .74231 .49724 Mtetra
.74231 .49724 .74404 .49938 .7479 .49822 .74617 .49607 Mtetra
.74617 .49607 .7479 .49822 .75177 .49706 .75004 .49491 Mtetra
.75004 .49491 .75177 .49706 .75564 .4959 .75391 .49374 Mtetra
.75391 .49374 .75564 .4959 .75951 .49473 .75779 .49258 Mtetra
.75779 .49258 .75951 .49473 .76339 .49357 .76167 .49141 Mtetra
.76167 .49141 .76339 .49357 .76728 .4924 .76556 .49024 Mtetra
.76556 .49024 .76728 .4924 .77117 .49123 .76946 .48907 Mtetra
.76946 .48907 .77117 .49123 .77507 .49006 .77336 .48789 Mtetra
.77336 .48789 .77507 .49006 .77897 .48889 .77726 .48672 Mtetra
.77726 .48672 .77897 .48889 .78288 .48771 .78118 .48554 Mtetra
.78118 .48554 .78288 .48771 .78679 .48654 .78509 .48436 Mtetra
.78509 .48436 .78679 .48654 .79071 .48536 .78901 .48318 Mtetra
.78901 .48318 .79071 .48536 .79463 .48418 .79294 .482 Mtetra
.79294 .482 .79463 .48418 .79856 .483 .79687 .48082 Mtetra
.79687 .48082 .79856 .483 .80249 .48182 .80081 .47963 Mtetra
.80081 .47963 .80249 .48182 .80643 .48063 .80475 .47845 Mtetra
.80475 .47845 .80643 .48063 .81038 .47945 .8087 .47726 Mtetra
.8087 .47726 .81038 .47945 .81432 .47826 .81265 .47607 Mtetra
.81265 .47607 .81432 .47826 .81828 .47707 .81661 .47488 Mtetra
.81661 .47488 .81828 .47707 .82224 .47588 .82058 .47368 Mtetra
.82058 .47368 .82224 .47588 .82621 .47469 .82455 .47249 Mtetra
.82455 .47249 .82621 .47469 .83018 .4735 .82852 .47129 Mtetra
.82852 .47129 .83018 .4735 .83415 .4723 .8325 .47009 Mtetra
.8325 .47009 .83415 .4723 .83814 .47111 .83649 .46889 Mtetra
.83649 .46889 .83814 .47111 .84213 .46991 .84048 .46769 Mtetra
.84048 .46769 .84213 .46991 .84612 .46871 .84448 .46649 Mtetra
.84448 .46649 .84612 .46871 .85012 .46751 .84848 .46529 Mtetra
.84848 .46529 .85012 .46751 .85412 .46631 .85249 .46408 Mtetra
.85249 .46408 .85412 .46631 .85813 .4651 .8565 .46287 Mtetra
.8565 .46287 .85813 .4651 .86215 .46389 .86052 .46166 Mtetra
.86052 .46166 .86215 .46389 .86617 .46269 .86455 .46045 Mtetra
.86455 .46045 .86617 .46269 .87019 .46148 .86858 .45924 Mtetra
.86858 .45924 .87019 .46148 .87423 .46026 .87261 .45802 Mtetra
.87261 .45802 .87423 .46026 .87826 .45905 .87665 .45681 Mtetra
.87665 .45681 .87826 .45905 .88231 .45784 .8807 .45559 Mtetra
.8807 .45559 .88231 .45784 .88635 .45662 .88475 .45437 Mtetra
.88475 .45437 .88635 .45662 .89041 .4554 .88881 .45315 Mtetra
.88881 .45315 .89041 .4554 .89447 .45418 .89288 .45193 Mtetra
.89288 .45193 .89447 .45418 .89853 .45296 .89695 .4507 Mtetra
.89695 .4507 .89853 .45296 .90261 .45174 .90102 .44948 Mtetra
.90102 .44948 .90261 .45174 .90668 .45051 .9051 .44825 Mtetra
.9051 .44825 .90668 .45051 .91076 .44929 .90919 .44702 Mtetra
.90919 .44702 .91076 .44929 .91485 .44806 .91328 .44579 Mtetra
.91328 .44579 .91485 .44806 .91895 .44683 .91738 .44455 Mtetra
.91738 .44455 .91895 .44683 .92305 .4456 .92148 .44332 Mtetra
.92148 .44332 .92305 .4456 .92715 .44436 .92559 .44208 Mtetra
.92559 .44208 .92715 .44436 .93126 .44313 .92971 .44084 Mtetra
.92971 .44084 .93126 .44313 .93538 .44189 .93383 .4396 Mtetra
.93383 .4396 .93538 .44189 .9395 .44065 .93795 .43836 Mtetra
.93795 .43836 .9395 .44065 .94363 .43941 .94209 .43712 Mtetra
.94209 .43712 .94363 .43941 .94776 .43817 .94623 .43587 Mtetra
.94623 .43587 .94776 .43817 .9519 .43693 .95037 .43462 Mtetra
.95037 .43462 .9519 .43693 .95605 .43568 .95452 .43338 Mtetra
.95452 .43338 .95605 .43568 .9602 .43443 .95867 .43213 Mtetra
.95867 .43213 .9602 .43443 .96436 .43318 .96284 .43087 Mtetra
.96284 .43087 .96436 .43318 .96852 .43193 .967 .42962 Mtetra
.39902 .59803 .40106 .59993 .40447 .5989 .40244 .597 Mtetra
.40244 .597 .40447 .5989 .40789 .59787 .40586 .59597 Mtetra
.40586 .59597 .40789 .59787 .41132 .59684 .40929 .59494 Mtetra
.40929 .59494 .41132 .59684 .41475 .59581 .41272 .5939 Mtetra
.41272 .5939 .41475 .59581 .41818 .59478 .41615 .59287 Mtetra
.41615 .59287 .41818 .59478 .42162 .59374 .4196 .59183 Mtetra
.4196 .59183 .42162 .59374 .42506 .59271 .42304 .59079 Mtetra
.42304 .59079 .42506 .59271 .42851 .59167 .42649 .58975 Mtetra
.42649 .58975 .42851 .59167 .43196 .59063 .42994 .58871 Mtetra
.42994 .58871 .43196 .59063 .43541 .58959 .4334 .58767 Mtetra
.4334 .58767 .43541 .58959 .43887 .58855 .43686 .58662 Mtetra
.43686 .58662 .43887 .58855 .44234 .58751 .44033 .58558 Mtetra
.44033 .58558 .44234 .58751 .4458 .58646 .4438 .58453 Mtetra
.4438 .58453 .4458 .58646 .44928 .58542 .44728 .58349 Mtetra
.44728 .58349 .44928 .58542 .45275 .58437 .45076 .58244 Mtetra
.45076 .58244 .45275 .58437 .45624 .58332 .45424 .58139 Mtetra
.45424 .58139 .45624 .58332 .45972 .58227 .45773 .58033 Mtetra
.45773 .58033 .45972 .58227 .46321 .58122 .46122 .57928 Mtetra
.46122 .57928 .46321 .58122 .46671 .58017 .46472 .57823 Mtetra
.46472 .57823 .46671 .58017 .47021 .57912 .46823 .57717 Mtetra
.46823 .57717 .47021 .57912 .47371 .57806 .47173 .57611 Mtetra
.47173 .57611 .47371 .57806 .47722 .57701 .47524 .57506 Mtetra
.47524 .57506 .47722 .57701 .48073 .57595 .47876 .574 Mtetra
.47876 .574 .48073 .57595 .48425 .57489 .48228 .57294 Mtetra
.48228 .57294 .48425 .57489 .48777 .57383 .48581 .57187 Mtetra
.48581 .57187 .48777 .57383 .4913 .57277 .48934 .57081 Mtetra
.48934 .57081 .4913 .57277 .49483 .57171 .49287 .56974 Mtetra
.49287 .56974 .49483 .57171 .49837 .57064 .49641 .56868 Mtetra
.49641 .56868 .49837 .57064 .50191 .56958 .49995 .56761 Mtetra
.49995 .56761 .50191 .56958 .50545 .56851 .5035 .56654 Mtetra
.5035 .56654 .50545 .56851 .509 .56744 .50705 .56547 Mtetra
.50705 .56547 .509 .56744 .51256 .56637 .51061 .5644 Mtetra
.51061 .5644 .51256 .56637 .51612 .5653 .51417 .56332 Mtetra
.51417 .56332 .51612 .5653 .51968 .56423 .51774 .56225 Mtetra
.51774 .56225 .51968 .56423 .52325 .56316 .52131 .56117 Mtetra
.52131 .56117 .52325 .56316 .52682 .56208 .52489 .56009 Mtetra
.52489 .56009 .52682 .56208 .5304 .56101 .52847 .55901 Mtetra
.52847 .55901 .5304 .56101 .53398 .55993 .53205 .55793 Mtetra
.53205 .55793 .53398 .55993 .53757 .55885 .53564 .55685 Mtetra
.53564 .55685 .53757 .55885 .54116 .55777 .53924 .55577 Mtetra
.53924 .55577 .54116 .55777 .54476 .55669 .54284 .55468 Mtetra
.54284 .55468 .54476 .55669 .54836 .5556 .54644 .5536 Mtetra
.54644 .5536 .54836 .5556 .55196 .55452 .55005 .55251 Mtetra
.55005 .55251 .55196 .55452 .55557 .55343 .55366 .55142 Mtetra
.55366 .55142 .55557 .55343 .55919 .55234 .55728 .55033 Mtetra
.55728 .55033 .55919 .55234 .56281 .55125 .5609 .54924 Mtetra
.5609 .54924 .56281 .55125 .56643 .55016 .56453 .54815 Mtetra
.56453 .54815 .56643 .55016 .57006 .54907 .56816 .54705 Mtetra
.56816 .54705 .57006 .54907 .5737 .54798 .5718 .54595 Mtetra
.872 .439 .037 r
.5718 .54595 .5737 .54798 .57748 .55594 .57558 .55392 Mtetra
.663 .742 .909 r
.57558 .55392 .57748 .55594 .58113 .55485 .57924 .55283 Mtetra
.57924 .55283 .58113 .55485 .58479 .55375 .5829 .55173 Mtetra
.5829 .55173 .58479 .55375 .58845 .55266 .58656 .55063 Mtetra
.58656 .55063 .58845 .55266 .59212 .55156 .59023 .54953 Mtetra
.59023 .54953 .59212 .55156 .59579 .55046 .59391 .54843 Mtetra
.59391 .54843 .59579 .55046 .59947 .54936 .59759 .54732 Mtetra
.59759 .54732 .59947 .54936 .60315 .54826 .60128 .54622 Mtetra
.60128 .54622 .60315 .54826 .60684 .54715 .60497 .54511 Mtetra
.917 .754 .664 r
.60497 .54511 .60684 .54715 .6103 .53696 .60844 .53491 Mtetra
.664 .741 .908 r
.60844 .53491 .6103 .53696 .61399 .53585 .61213 .5338 Mtetra
.61213 .5338 .61399 .53585 .61768 .53474 .61582 .53269 Mtetra
.61582 .53269 .61768 .53474 .62138 .53363 .61952 .53157 Mtetra
.61952 .53157 .62138 .53363 .62508 .53251 .62323 .53045 Mtetra
.62323 .53045 .62508 .53251 .62878 .5314 .62694 .52934 Mtetra
.62694 .52934 .62878 .5314 .63249 .53028 .63065 .52822 Mtetra
.63065 .52822 .63249 .53028 .63621 .52916 .63437 .5271 Mtetra
.63437 .5271 .63621 .52916 .63993 .52804 .6381 .52597 Mtetra
.6381 .52597 .63993 .52804 .64366 .52692 .64182 .52485 Mtetra
.64182 .52485 .64366 .52692 .64739 .5258 .64556 .52372 Mtetra
.64556 .52372 .64739 .5258 .65113 .52468 .6493 .5226 Mtetra
.6493 .5226 .65113 .52468 .65487 .52355 .65304 .52147 Mtetra
.65304 .52147 .65487 .52355 .65861 .52242 .65679 .52034 Mtetra
.65679 .52034 .65861 .52242 .66236 .52129 .66055 .51921 Mtetra
.66055 .51921 .66236 .52129 .66612 .52016 .66431 .51807 Mtetra
.66431 .51807 .66612 .52016 .66988 .51903 .66807 .51694 Mtetra
.66807 .51694 .66988 .51903 .67365 .5179 .67184 .5158 Mtetra
.67184 .5158 .67365 .5179 .67742 .51676 .67561 .51466 Mtetra
.67561 .51466 .67742 .51676 .68119 .51563 .67939 .51353 Mtetra
.67939 .51353 .68119 .51563 .68498 .51449 .68318 .51239 Mtetra
.68318 .51239 .68498 .51449 .68876 .51335 .68697 .51124 Mtetra
.68697 .51124 .68876 .51335 .69255 .51221 .69076 .5101 Mtetra
.69076 .5101 .69255 .51221 .69635 .51107 .69456 .50895 Mtetra
.69456 .50895 .69635 .51107 .70015 .50992 .69837 .50781 Mtetra
.69837 .50781 .70015 .50992 .70396 .50878 .70218 .50666 Mtetra
.70218 .50666 .70396 .50878 .70777 .50763 .70599 .50551 Mtetra
.70599 .50551 .70777 .50763 .71159 .50648 .70981 .50436 Mtetra
.70981 .50436 .71159 .50648 .71541 .50533 .71364 .5032 Mtetra
.71364 .5032 .71541 .50533 .71923 .50418 .71747 .50205 Mtetra
.71747 .50205 .71923 .50418 .72307 .50303 .72131 .50089 Mtetra
.72131 .50089 .72307 .50303 .7269 .50187 .72515 .49974 Mtetra
.72515 .49974 .7269 .50187 .73075 .50072 .72899 .49858 Mtetra
.72899 .49858 .73075 .50072 .73459 .49956 .73284 .49742 Mtetra
.73284 .49742 .73459 .49956 .73845 .4984 .7367 .49625 Mtetra
.7367 .49625 .73845 .4984 .74231 .49724 .74056 .49509 Mtetra
.74056 .49509 .74231 .49724 .74617 .49607 .74443 .49392 Mtetra
.74443 .49392 .74617 .49607 .75004 .49491 .7483 .49276 Mtetra
.7483 .49276 .75004 .49491 .75391 .49374 .75218 .49159 Mtetra
.75218 .49159 .75391 .49374 .75779 .49258 .75606 .49042 Mtetra
.75606 .49042 .75779 .49258 .76167 .49141 .75995 .48925 Mtetra
.75995 .48925 .76167 .49141 .76556 .49024 .76384 .48807 Mtetra
.76384 .48807 .76556 .49024 .76946 .48907 .76774 .4869 Mtetra
.76774 .4869 .76946 .48907 .77336 .48789 .77165 .48572 Mtetra
.77165 .48572 .77336 .48789 .77726 .48672 .77555 .48454 Mtetra
.77555 .48454 .77726 .48672 .78118 .48554 .77947 .48336 Mtetra
.77947 .48336 .78118 .48554 .78509 .48436 .78339 .48218 Mtetra
.78339 .48218 .78509 .48436 .78901 .48318 .78731 .481 Mtetra
.78731 .481 .78901 .48318 .79294 .482 .79124 .47981 Mtetra
.79124 .47981 .79294 .482 .79687 .48082 .79518 .47863 Mtetra
.79518 .47863 .79687 .48082 .80081 .47963 .79912 .47744 Mtetra
.79912 .47744 .80081 .47963 .80475 .47845 .80307 .47625 Mtetra
.80307 .47625 .80475 .47845 .8087 .47726 .80702 .47506 Mtetra
.80702 .47506 .8087 .47726 .81265 .47607 .81098 .47387 Mtetra
.81098 .47387 .81265 .47607 .81661 .47488 .81494 .47267 Mtetra
.81494 .47267 .81661 .47488 .82058 .47368 .81891 .47148 Mtetra
.81891 .47148 .82058 .47368 .82455 .47249 .82288 .47028 Mtetra
.82288 .47028 .82455 .47249 .82852 .47129 .82686 .46908 Mtetra
.82686 .46908 .82852 .47129 .8325 .47009 .83085 .46788 Mtetra
.83085 .46788 .8325 .47009 .83649 .46889 .83484 .46668 Mtetra
.83484 .46668 .83649 .46889 .84048 .46769 .83883 .46547 Mtetra
.83883 .46547 .84048 .46769 .84448 .46649 .84283 .46427 Mtetra
.84283 .46427 .84448 .46649 .84848 .46529 .84684 .46306 Mtetra
.84684 .46306 .84848 .46529 .85249 .46408 .85085 .46185 Mtetra
.85085 .46185 .85249 .46408 .8565 .46287 .85487 .46064 Mtetra
.85487 .46064 .8565 .46287 .86052 .46166 .85889 .45943 Mtetra
.85889 .45943 .86052 .46166 .86455 .46045 .86292 .45821 Mtetra
.86292 .45821 .86455 .46045 .86858 .45924 .86696 .45699 Mtetra
.86696 .45699 .86858 .45924 .87261 .45802 .871 .45578 Mtetra
.871 .45578 .87261 .45802 .87665 .45681 .87504 .45456 Mtetra
.87504 .45456 .87665 .45681 .8807 .45559 .87909 .45334 Mtetra
.87909 .45334 .8807 .45559 .88475 .45437 .88315 .45211 Mtetra
.88315 .45211 .88475 .45437 .88881 .45315 .88721 .45089 Mtetra
.88721 .45089 .88881 .45315 .89288 .45193 .89128 .44966 Mtetra
.89128 .44966 .89288 .45193 .89695 .4507 .89535 .44844 Mtetra
.89535 .44844 .89695 .4507 .90102 .44948 .89943 .44721 Mtetra
.89943 .44721 .90102 .44948 .9051 .44825 .90352 .44598 Mtetra
.90352 .44598 .9051 .44825 .90919 .44702 .90761 .44474 Mtetra
.90761 .44474 .90919 .44702 .91328 .44579 .91171 .44351 Mtetra
.91171 .44351 .91328 .44579 .91738 .44455 .91581 .44227 Mtetra
.91581 .44227 .91738 .44455 .92148 .44332 .91992 .44103 Mtetra
.91992 .44103 .92148 .44332 .92559 .44208 .92403 .43979 Mtetra
.92403 .43979 .92559 .44208 .92971 .44084 .92815 .43855 Mtetra
.92815 .43855 .92971 .44084 .93383 .4396 .93227 .43731 Mtetra
.93227 .43731 .93383 .4396 .93795 .43836 .9364 .43606 Mtetra
.9364 .43606 .93795 .43836 .94209 .43712 .94054 .43482 Mtetra
.94054 .43482 .94209 .43712 .94623 .43587 .94468 .43357 Mtetra
.94468 .43357 .94623 .43587 .95037 .43462 .94883 .43232 Mtetra
.94883 .43232 .95037 .43462 .95452 .43338 .95299 .43107 Mtetra
.95299 .43107 .95452 .43338 .95867 .43213 .95715 .42981 Mtetra
.95715 .42981 .95867 .43213 .96284 .43087 .96131 .42856 Mtetra
.96131 .42856 .96284 .43087 .967 .42962 .96548 .4273 Mtetra
.39697 .59613 .39902 .59803 .40244 .597 .4004 .59509 Mtetra
.4004 .59509 .40244 .597 .40586 .59597 .40382 .59406 Mtetra
.40382 .59406 .40586 .59597 .40929 .59494 .40725 .59302 Mtetra
.40725 .59302 .40929 .59494 .41272 .5939 .41069 .59199 Mtetra
.41069 .59199 .41272 .5939 .41615 .59287 .41412 .59095 Mtetra
.41412 .59095 .41615 .59287 .4196 .59183 .41757 .58991 Mtetra
.41757 .58991 .4196 .59183 .42304 .59079 .42102 .58887 Mtetra
.42102 .58887 .42304 .59079 .42649 .58975 .42447 .58783 Mtetra
.42447 .58783 .42649 .58975 .42994 .58871 .42792 .58678 Mtetra
.42792 .58678 .42994 .58871 .4334 .58767 .43138 .58574 Mtetra
.43138 .58574 .4334 .58767 .43686 .58662 .43485 .58469 Mtetra
.43485 .58469 .43686 .58662 .44033 .58558 .43832 .58365 Mtetra
.43832 .58365 .44033 .58558 .4438 .58453 .44179 .5826 Mtetra
.44179 .5826 .4438 .58453 .44728 .58349 .44527 .58155 Mtetra
.44527 .58155 .44728 .58349 .45076 .58244 .44875 .5805 Mtetra
.44875 .5805 .45076 .58244 .45424 .58139 .45224 .57944 Mtetra
.45224 .57944 .45424 .58139 .45773 .58033 .45573 .57839 Mtetra
.45573 .57839 .45773 .58033 .46122 .57928 .45923 .57733 Mtetra
.45923 .57733 .46122 .57928 .46472 .57823 .46273 .57628 Mtetra
.46273 .57628 .46472 .57823 .46823 .57717 .46624 .57522 Mtetra
.46624 .57522 .46823 .57717 .47173 .57611 .46975 .57416 Mtetra
.46975 .57416 .47173 .57611 .47524 .57506 .47326 .5731 Mtetra
.47326 .5731 .47524 .57506 .47876 .574 .47678 .57204 Mtetra
.47678 .57204 .47876 .574 .48228 .57294 .4803 .57097 Mtetra
.4803 .57097 .48228 .57294 .48581 .57187 .48383 .56991 Mtetra
.48383 .56991 .48581 .57187 .48934 .57081 .48737 .56884 Mtetra
.48737 .56884 .48934 .57081 .49287 .56974 .4909 .56777 Mtetra
.4909 .56777 .49287 .56974 .49641 .56868 .49444 .5667 Mtetra
.49444 .5667 .49641 .56868 .49995 .56761 .49799 .56563 Mtetra
.49799 .56563 .49995 .56761 .5035 .56654 .50154 .56456 Mtetra
.50154 .56456 .5035 .56654 .50705 .56547 .5051 .56349 Mtetra
.5051 .56349 .50705 .56547 .51061 .5644 .50866 .56241 Mtetra
.50866 .56241 .51061 .5644 .51417 .56332 .51222 .56134 Mtetra
.51222 .56134 .51417 .56332 .51774 .56225 .51579 .56026 Mtetra
.51579 .56026 .51774 .56225 .52131 .56117 .51937 .55918 Mtetra
.51937 .55918 .52131 .56117 .52489 .56009 .52295 .5581 Mtetra
.52295 .5581 .52489 .56009 .52847 .55901 .52653 .55702 Mtetra
.52653 .55702 .52847 .55901 .53205 .55793 .53012 .55594 Mtetra
.53012 .55594 .53205 .55793 .53564 .55685 .53371 .55485 Mtetra
.53371 .55485 .53564 .55685 .53924 .55577 .53731 .55376 Mtetra
.53731 .55376 .53924 .55577 .54284 .55468 .54091 .55268 Mtetra
.54091 .55268 .54284 .55468 .54644 .5536 .54452 .55159 Mtetra
.54452 .55159 .54644 .5536 .55005 .55251 .54813 .5505 Mtetra
.54813 .5505 .55005 .55251 .55366 .55142 .55175 .54941 Mtetra
.55175 .54941 .55366 .55142 .55728 .55033 .55537 .54831 Mtetra
.55537 .54831 .55728 .55033 .5609 .54924 .55899 .54722 Mtetra
.55899 .54722 .5609 .54924 .56453 .54815 .56262 .54612 Mtetra
.56262 .54612 .56453 .54815 .56816 .54705 .56626 .54503 Mtetra
.873 .441 .04 r
.56626 .54503 .56816 .54705 .5718 .54595 .57002 .55299 Mtetra
.493 .193 .385 r
.57002 .55299 .5718 .54595 .57558 .55392 .57368 .5519 Mtetra
.663 .742 .909 r
.57368 .5519 .57558 .55392 .57924 .55283 .57734 .5508 Mtetra
.57734 .5508 .57924 .55283 .5829 .55173 .581 .5497 Mtetra
.581 .5497 .5829 .55173 .58656 .55063 .58467 .5486 Mtetra
.58467 .5486 .58656 .55063 .59023 .54953 .58834 .54749 Mtetra
.58834 .54749 .59023 .54953 .59391 .54843 .59202 .54639 Mtetra
.59202 .54639 .59391 .54843 .59759 .54732 .59571 .54528 Mtetra
.59571 .54528 .59759 .54732 .60128 .54622 .5994 .54417 Mtetra
.5994 .54417 .60128 .54622 .60497 .54511 .60309 .54307 Mtetra
.60309 .54307 .60497 .54511 .60844 .53491 .60679 .54196 Mtetra
0 0 .048 r
.60679 .54196 .60844 .53491 .61213 .5338 .61026 .53174 Mtetra
.664 .741 .908 r
.61026 .53174 .61213 .5338 .61582 .53269 .61396 .53063 Mtetra
.61396 .53063 .61582 .53269 .61952 .53157 .61766 .52951 Mtetra
.61766 .52951 .61952 .53157 .62323 .53045 .62137 .52839 Mtetra
.62137 .52839 .62323 .53045 .62694 .52934 .62508 .52727 Mtetra
.62508 .52727 .62694 .52934 .63065 .52822 .6288 .52615 Mtetra
.6288 .52615 .63065 .52822 .63437 .5271 .63253 .52502 Mtetra
.63253 .52502 .63437 .5271 .6381 .52597 .63625 .5239 Mtetra
.63625 .5239 .6381 .52597 .64182 .52485 .63999 .52277 Mtetra
.63999 .52277 .64182 .52485 .64556 .52372 .64372 .52164 Mtetra
.64372 .52164 .64556 .52372 .6493 .5226 .64747 .52051 Mtetra
.64747 .52051 .6493 .5226 .65304 .52147 .65122 .51938 Mtetra
.65122 .51938 .65304 .52147 .65679 .52034 .65497 .51825 Mtetra
.65497 .51825 .65679 .52034 .66055 .51921 .65873 .51711 Mtetra
.65873 .51711 .66055 .51921 .66431 .51807 .66249 .51598 Mtetra
.66249 .51598 .66431 .51807 .66807 .51694 .66626 .51484 Mtetra
.66626 .51484 .66807 .51694 .67184 .5158 .67003 .5137 Mtetra
.67003 .5137 .67184 .5158 .67561 .51466 .67381 .51256 Mtetra
.67381 .51256 .67561 .51466 .67939 .51353 .67759 .51142 Mtetra
.67759 .51142 .67939 .51353 .68318 .51239 .68138 .51028 Mtetra
.68138 .51028 .68318 .51239 .68697 .51124 .68517 .50913 Mtetra
.68517 .50913 .68697 .51124 .69076 .5101 .68897 .50798 Mtetra
.68897 .50798 .69076 .5101 .69456 .50895 .69277 .50684 Mtetra
.69277 .50684 .69456 .50895 .69837 .50781 .69658 .50569 Mtetra
.69658 .50569 .69837 .50781 .70218 .50666 .7004 .50453 Mtetra
.7004 .50453 .70218 .50666 .70599 .50551 .70421 .50338 Mtetra
.70421 .50338 .70599 .50551 .70981 .50436 .70804 .50223 Mtetra
.70804 .50223 .70981 .50436 .71364 .5032 .71187 .50107 Mtetra
.71187 .50107 .71364 .5032 .71747 .50205 .7157 .49991 Mtetra
.7157 .49991 .71747 .50205 .72131 .50089 .71954 .49876 Mtetra
.71954 .49876 .72131 .50089 .72515 .49974 .72339 .49759 Mtetra
.72339 .49759 .72515 .49974 .72899 .49858 .72723 .49643 Mtetra
.72723 .49643 .72899 .49858 .73284 .49742 .73109 .49527 Mtetra
.73109 .49527 .73284 .49742 .7367 .49625 .73495 .4941 Mtetra
.73495 .4941 .7367 .49625 .74056 .49509 .73882 .49294 Mtetra
.73882 .49294 .74056 .49509 .74443 .49392 .74269 .49177 Mtetra
.74269 .49177 .74443 .49392 .7483 .49276 .74656 .4906 Mtetra
.74656 .4906 .7483 .49276 .75218 .49159 .75044 .48943 Mtetra
.75044 .48943 .75218 .49159 .75606 .49042 .75433 .48825 Mtetra
.75433 .48825 .75606 .49042 .75995 .48925 .75822 .48708 Mtetra
.75822 .48708 .75995 .48925 .76384 .48807 .76212 .4859 Mtetra
.76212 .4859 .76384 .48807 .76774 .4869 .76602 .48472 Mtetra
.76602 .48472 .76774 .4869 .77165 .48572 .76993 .48355 Mtetra
.76993 .48355 .77165 .48572 .77555 .48454 .77384 .48236 Mtetra
.77384 .48236 .77555 .48454 .77947 .48336 .77776 .48118 Mtetra
.77776 .48118 .77947 .48336 .78339 .48218 .78168 .48 Mtetra
.78168 .48 .78339 .48218 .78731 .481 .78561 .47881 Mtetra
.78561 .47881 .78731 .481 .79124 .47981 .78955 .47762 Mtetra
.78955 .47762 .79124 .47981 .79518 .47863 .79349 .47643 Mtetra
.79349 .47643 .79518 .47863 .79912 .47744 .79743 .47524 Mtetra
.79743 .47524 .79912 .47744 .80307 .47625 .80138 .47405 Mtetra
.80138 .47405 .80307 .47625 .80702 .47506 .80534 .47286 Mtetra
.80534 .47286 .80702 .47506 .81098 .47387 .8093 .47166 Mtetra
.8093 .47166 .81098 .47387 .81494 .47267 .81327 .47046 Mtetra
.81327 .47046 .81494 .47267 .81891 .47148 .81724 .46926 Mtetra
.81724 .46926 .81891 .47148 .82288 .47028 .82122 .46806 Mtetra
.82122 .46806 .82288 .47028 .82686 .46908 .8252 .46686 Mtetra
.8252 .46686 .82686 .46908 .83085 .46788 .82919 .46566 Mtetra
.82919 .46566 .83085 .46788 .83484 .46668 .83318 .46445 Mtetra
.83318 .46445 .83484 .46668 .83883 .46547 .83718 .46324 Mtetra
.83718 .46324 .83883 .46547 .84283 .46427 .84119 .46203 Mtetra
.84119 .46203 .84283 .46427 .84684 .46306 .8452 .46082 Mtetra
.8452 .46082 .84684 .46306 .85085 .46185 .84921 .45961 Mtetra
.84921 .45961 .85085 .46185 .85487 .46064 .85323 .4584 Mtetra
.85323 .4584 .85487 .46064 .85889 .45943 .85726 .45718 Mtetra
.85726 .45718 .85889 .45943 .86292 .45821 .86129 .45596 Mtetra
.86129 .45596 .86292 .45821 .86696 .45699 .86533 .45475 Mtetra
.86533 .45475 .86696 .45699 .871 .45578 .86938 .45352 Mtetra
.86938 .45352 .871 .45578 .87504 .45456 .87343 .4523 Mtetra
.87343 .4523 .87504 .45456 .87909 .45334 .87748 .45108 Mtetra
.87748 .45108 .87909 .45334 .88315 .45211 .88154 .44985 Mtetra
.88154 .44985 .88315 .45211 .88721 .45089 .88561 .44863 Mtetra
.88561 .44863 .88721 .45089 .89128 .44966 .88968 .4474 Mtetra
.88968 .4474 .89128 .44966 .89535 .44844 .89376 .44616 Mtetra
.89376 .44616 .89535 .44844 .89943 .44721 .89784 .44493 Mtetra
.89784 .44493 .89943 .44721 .90352 .44598 .90193 .4437 Mtetra
.90193 .4437 .90352 .44598 .90761 .44474 .90603 .44246 Mtetra
.90603 .44246 .90761 .44474 .91171 .44351 .91013 .44122 Mtetra
.91013 .44122 .91171 .44351 .91581 .44227 .91423 .43998 Mtetra
.91423 .43998 .91581 .44227 .91992 .44103 .91835 .43874 Mtetra
.91835 .43874 .91992 .44103 .92403 .43979 .92246 .4375 Mtetra
.92246 .4375 .92403 .43979 .92815 .43855 .92659 .43626 Mtetra
.92659 .43626 .92815 .43855 .93227 .43731 .93072 .43501 Mtetra
.93072 .43501 .93227 .43731 .9364 .43606 .93485 .43376 Mtetra
.93485 .43376 .9364 .43606 .94054 .43482 .93899 .43251 Mtetra
.93899 .43251 .94054 .43482 .94468 .43357 .94314 .43126 Mtetra
.94314 .43126 .94468 .43357 .94883 .43232 .94729 .43001 Mtetra
.94729 .43001 .94883 .43232 .95299 .43107 .95145 .42875 Mtetra
.95145 .42875 .95299 .43107 .95715 .42981 .95561 .42749 Mtetra
.95561 .42749 .95715 .42981 .96131 .42856 .95978 .42623 Mtetra
.95978 .42623 .96131 .42856 .96548 .4273 .96396 .42497 Mtetra
.39493 .59422 .39697 .59613 .4004 .59509 .39835 .59318 Mtetra
.39835 .59318 .4004 .59509 .40382 .59406 .40178 .59215 Mtetra
.40178 .59215 .40382 .59406 .40725 .59302 .40521 .59111 Mtetra
.40521 .59111 .40725 .59302 .41069 .59199 .40865 .59007 Mtetra
.40865 .59007 .41069 .59199 .41412 .59095 .41209 .58903 Mtetra
.41209 .58903 .41412 .59095 .41757 .58991 .41554 .58799 Mtetra
.41554 .58799 .41757 .58991 .42102 .58887 .41899 .58695 Mtetra
.41899 .58695 .42102 .58887 .42447 .58783 .42244 .5859 Mtetra
.42244 .5859 .42447 .58783 .42792 .58678 .4259 .58485 Mtetra
.4259 .58485 .42792 .58678 .43138 .58574 .42936 .58381 Mtetra
.42936 .58381 .43138 .58574 .43485 .58469 .43283 .58276 Mtetra
.43283 .58276 .43485 .58469 .43832 .58365 .4363 .58171 Mtetra
.4363 .58171 .43832 .58365 .44179 .5826 .43978 .58066 Mtetra
.43978 .58066 .44179 .5826 .44527 .58155 .44326 .57961 Mtetra
.44326 .57961 .44527 .58155 .44875 .5805 .44675 .57855 Mtetra
.44675 .57855 .44875 .5805 .45224 .57944 .45024 .5775 Mtetra
.45024 .5775 .45224 .57944 .45573 .57839 .45373 .57644 Mtetra
.45373 .57644 .45573 .57839 .45923 .57733 .45723 .57538 Mtetra
.45723 .57538 .45923 .57733 .46273 .57628 .46074 .57432 Mtetra
.46074 .57432 .46273 .57628 .46624 .57522 .46424 .57326 Mtetra
.46424 .57326 .46624 .57522 .46975 .57416 .46776 .5722 Mtetra
.46776 .5722 .46975 .57416 .47326 .5731 .47127 .57114 Mtetra
.47127 .57114 .47326 .5731 .47678 .57204 .4748 .57007 Mtetra
.4748 .57007 .47678 .57204 .4803 .57097 .47832 .56901 Mtetra
.47832 .56901 .4803 .57097 .48383 .56991 .48185 .56794 Mtetra
.48185 .56794 .48383 .56991 .48737 .56884 .48539 .56687 Mtetra
.48539 .56687 .48737 .56884 .4909 .56777 .48893 .5658 Mtetra
.48893 .5658 .4909 .56777 .49444 .5667 .49248 .56473 Mtetra
.49248 .56473 .49444 .5667 .49799 .56563 .49602 .56365 Mtetra
.49602 .56365 .49799 .56563 .50154 .56456 .49958 .56258 Mtetra
.49958 .56258 .50154 .56456 .5051 .56349 .50314 .5615 Mtetra
.50314 .5615 .5051 .56349 .50866 .56241 .5067 .56043 Mtetra
.5067 .56043 .50866 .56241 .51222 .56134 .51027 .55935 Mtetra
.51027 .55935 .51222 .56134 .51579 .56026 .51384 .55827 Mtetra
.51384 .55827 .51579 .56026 .51937 .55918 .51742 .55719 Mtetra
.51742 .55719 .51937 .55918 .52295 .5581 .521 .5561 Mtetra
.521 .5561 .52295 .5581 .52653 .55702 .52459 .55502 Mtetra
.52459 .55502 .52653 .55702 .53012 .55594 .52818 .55393 Mtetra
.52818 .55393 .53012 .55594 .53371 .55485 .53178 .55284 Mtetra
.53178 .55284 .53371 .55485 .53731 .55376 .53538 .55176 Mtetra
.53538 .55176 .53731 .55376 .54091 .55268 .53898 .55067 Mtetra
.53898 .55067 .54091 .55268 .54452 .55159 .54259 .54957 Mtetra
.54259 .54957 .54452 .55159 .54813 .5505 .54621 .54848 Mtetra
.54621 .54848 .54813 .5505 .55175 .54941 .54983 .54739 Mtetra
.54983 .54739 .55175 .54941 .55537 .54831 .55345 .54629 Mtetra
.55345 .54629 .55537 .54831 .55899 .54722 .55708 .54519 Mtetra
.55708 .54519 .55899 .54722 .56262 .54612 .56071 .5441 Mtetra
.56071 .5441 .56262 .54612 .56626 .54503 .56435 .543 Mtetra
.873 .441 .04 r
.56435 .543 .56626 .54503 .57002 .55299 .56811 .55097 Mtetra
.663 .742 .909 r
.56811 .55097 .57002 .55299 .57368 .5519 .57177 .54987 Mtetra
.57177 .54987 .57368 .5519 .57734 .5508 .57543 .54877 Mtetra
.57543 .54877 .57734 .5508 .581 .5497 .5791 .54766 Mtetra
.5791 .54766 .581 .5497 .58467 .5486 .58277 .54656 Mtetra
.58277 .54656 .58467 .5486 .58834 .54749 .58645 .54545 Mtetra
.58645 .54545 .58834 .54749 .59202 .54639 .59013 .54435 Mtetra
.59013 .54435 .59202 .54639 .59571 .54528 .59382 .54324 Mtetra
.59382 .54324 .59571 .54528 .5994 .54417 .59751 .54213 Mtetra
.59751 .54213 .5994 .54417 .60309 .54307 .60121 .54101 Mtetra
.60121 .54101 .60309 .54307 .60679 .54196 .60491 .5399 Mtetra
.60491 .5399 .60679 .54196 .61026 .53174 .60862 .53879 Mtetra
0 0 .048 r
.60862 .53879 .61026 .53174 .61396 .53063 .61209 .52856 Mtetra
.664 .741 .908 r
.61209 .52856 .61396 .53063 .61766 .52951 .6158 .52744 Mtetra
.6158 .52744 .61766 .52951 .62137 .52839 .61951 .52632 Mtetra
.61951 .52632 .62137 .52839 .62508 .52727 .62323 .5252 Mtetra
.62323 .5252 .62508 .52727 .6288 .52615 .62695 .52407 Mtetra
.62695 .52407 .6288 .52615 .63253 .52502 .63068 .52294 Mtetra
.63068 .52294 .63253 .52502 .63625 .5239 .63441 .52182 Mtetra
.63441 .52182 .63625 .5239 .63999 .52277 .63814 .52069 Mtetra
.63814 .52069 .63999 .52277 .64372 .52164 .64188 .51955 Mtetra
.64188 .51955 .64372 .52164 .64747 .52051 .64563 .51842 Mtetra
.64563 .51842 .64747 .52051 .65122 .51938 .64938 .51729 Mtetra
.64938 .51729 .65122 .51938 .65497 .51825 .65314 .51615 Mtetra
.65314 .51615 .65497 .51825 .65873 .51711 .6569 .51502 Mtetra
.6569 .51502 .65873 .51711 .66249 .51598 .66067 .51388 Mtetra
.66067 .51388 .66249 .51598 .66626 .51484 .66444 .51274 Mtetra
.66444 .51274 .66626 .51484 .67003 .5137 .66821 .51159 Mtetra
.66821 .51159 .67003 .5137 .67381 .51256 .672 .51045 Mtetra
.672 .51045 .67381 .51256 .67759 .51142 .67578 .50931 Mtetra
.67578 .50931 .67759 .51142 .68138 .51028 .67957 .50816 Mtetra
.67957 .50816 .68138 .51028 .68517 .50913 .68337 .50701 Mtetra
.68337 .50701 .68517 .50913 .68897 .50798 .68717 .50586 Mtetra
.68717 .50586 .68897 .50798 .69277 .50684 .69098 .50471 Mtetra
.69098 .50471 .69277 .50684 .69658 .50569 .69479 .50356 Mtetra
.69479 .50356 .69658 .50569 .7004 .50453 .69861 .50241 Mtetra
.69861 .50241 .7004 .50453 .70421 .50338 .70243 .50125 Mtetra
.70243 .50125 .70421 .50338 .70804 .50223 .70626 .50009 Mtetra
.70626 .50009 .70804 .50223 .71187 .50107 .71009 .49893 Mtetra
.71009 .49893 .71187 .50107 .7157 .49991 .71393 .49777 Mtetra
.71393 .49777 .7157 .49991 .71954 .49876 .71777 .49661 Mtetra
.71777 .49661 .71954 .49876 .72339 .49759 .72162 .49545 Mtetra
.72162 .49545 .72339 .49759 .72723 .49643 .72547 .49428 Mtetra
.72547 .49428 .72723 .49643 .73109 .49527 .72933 .49312 Mtetra
.72933 .49312 .73109 .49527 .73495 .4941 .73319 .49195 Mtetra
.73319 .49195 .73495 .4941 .73882 .49294 .73706 .49078 Mtetra
.73706 .49078 .73882 .49294 .74269 .49177 .74094 .48961 Mtetra
.74094 .48961 .74269 .49177 .74656 .4906 .74482 .48843 Mtetra
.74482 .48843 .74656 .4906 .75044 .48943 .7487 .48726 Mtetra
.7487 .48726 .75044 .48943 .75433 .48825 .75259 .48608 Mtetra
.75259 .48608 .75433 .48825 .75822 .48708 .75649 .48491 Mtetra
.75649 .48491 .75822 .48708 .76212 .4859 .76039 .48373 Mtetra
.76039 .48373 .76212 .4859 .76602 .48472 .76429 .48255 Mtetra
.76429 .48255 .76602 .48472 .76993 .48355 .76821 .48136 Mtetra
.76821 .48136 .76993 .48355 .77384 .48236 .77212 .48018 Mtetra
.77212 .48018 .77384 .48236 .77776 .48118 .77604 .47899 Mtetra
.77604 .47899 .77776 .48118 .78168 .48 .77997 .47781 Mtetra
.77997 .47781 .78168 .48 .78561 .47881 .7839 .47662 Mtetra
.7839 .47662 .78561 .47881 .78955 .47762 .78784 .47543 Mtetra
.78784 .47543 .78955 .47762 .79349 .47643 .79179 .47423 Mtetra
.79179 .47423 .79349 .47643 .79743 .47524 .79574 .47304 Mtetra
.79574 .47304 .79743 .47524 .80138 .47405 .79969 .47184 Mtetra
.79969 .47184 .80138 .47405 .80534 .47286 .80365 .47065 Mtetra
.80365 .47065 .80534 .47286 .8093 .47166 .80761 .46945 Mtetra
.80761 .46945 .8093 .47166 .81327 .47046 .81159 .46825 Mtetra
.81159 .46825 .81327 .47046 .81724 .46926 .81556 .46705 Mtetra
.81556 .46705 .81724 .46926 .82122 .46806 .81954 .46584 Mtetra
.81954 .46584 .82122 .46806 .8252 .46686 .82353 .46464 Mtetra
.82353 .46464 .8252 .46686 .82919 .46566 .82752 .46343 Mtetra
.82752 .46343 .82919 .46566 .83318 .46445 .83152 .46222 Mtetra
.83152 .46222 .83318 .46445 .83718 .46324 .83552 .46101 Mtetra
.83552 .46101 .83718 .46324 .84119 .46203 .83953 .4598 Mtetra
.83953 .4598 .84119 .46203 .8452 .46082 .84355 .45858 Mtetra
.84355 .45858 .8452 .46082 .84921 .45961 .84757 .45737 Mtetra
.84757 .45737 .84921 .45961 .85323 .4584 .85159 .45615 Mtetra
.85159 .45615 .85323 .4584 .85726 .45718 .85562 .45493 Mtetra
.85562 .45493 .85726 .45718 .86129 .45596 .85966 .45371 Mtetra
.85966 .45371 .86129 .45596 .86533 .45475 .8637 .45249 Mtetra
.8637 .45249 .86533 .45475 .86938 .45352 .86775 .45127 Mtetra
.86775 .45127 .86938 .45352 .87343 .4523 .87181 .45004 Mtetra
.87181 .45004 .87343 .4523 .87748 .45108 .87587 .44881 Mtetra
.87587 .44881 .87748 .45108 .88154 .44985 .87993 .44759 Mtetra
.87993 .44759 .88154 .44985 .88561 .44863 .884 .44635 Mtetra
.884 .44635 .88561 .44863 .88968 .4474 .88808 .44512 Mtetra
.88808 .44512 .88968 .4474 .89376 .44616 .89216 .44389 Mtetra
.89216 .44389 .89376 .44616 .89784 .44493 .89625 .44265 Mtetra
.89625 .44265 .89784 .44493 .90193 .4437 .90034 .44141 Mtetra
.90034 .44141 .90193 .4437 .90603 .44246 .90444 .44018 Mtetra
.90444 .44018 .90603 .44246 .91013 .44122 .90854 .43893 Mtetra
.90854 .43893 .91013 .44122 .91423 .43998 .91265 .43769 Mtetra
.91265 .43769 .91423 .43998 .91835 .43874 .91677 .43645 Mtetra
.91677 .43645 .91835 .43874 .92246 .4375 .92089 .4352 Mtetra
.92089 .4352 .92246 .4375 .92659 .43626 .92502 .43395 Mtetra
.92502 .43395 .92659 .43626 .93072 .43501 .92915 .4327 Mtetra
.92915 .4327 .93072 .43501 .93485 .43376 .93329 .43145 Mtetra
.93329 .43145 .93485 .43376 .93899 .43251 .93744 .4302 Mtetra
.93744 .4302 .93899 .43251 .94314 .43126 .94159 .42894 Mtetra
.94159 .42894 .94314 .43126 .94729 .43001 .94575 .42769 Mtetra
.94575 .42769 .94729 .43001 .95145 .42875 .94991 .42643 Mtetra
.94991 .42643 .95145 .42875 .95561 .42749 .95408 .42517 Mtetra
.95408 .42517 .95561 .42749 .95978 .42623 .95825 .42391 Mtetra
.95825 .42391 .95978 .42623 .96396 .42497 .96243 .42264 Mtetra
.39287 .59231 .39493 .59422 .39835 .59318 .3963 .59127 Mtetra
.3963 .59127 .39835 .59318 .40178 .59215 .39973 .59023 Mtetra
.39973 .59023 .40178 .59215 .40521 .59111 .40317 .58919 Mtetra
.40317 .58919 .40521 .59111 .40865 .59007 .40661 .58815 Mtetra
.40661 .58815 .40865 .59007 .41209 .58903 .41005 .58711 Mtetra
.41005 .58711 .41209 .58903 .41554 .58799 .4135 .58606 Mtetra
.4135 .58606 .41554 .58799 .41899 .58695 .41695 .58502 Mtetra
.41695 .58502 .41899 .58695 .42244 .5859 .42041 .58397 Mtetra
.42041 .58397 .42244 .5859 .4259 .58485 .42387 .58292 Mtetra
.42387 .58292 .4259 .58485 .42936 .58381 .42734 .58187 Mtetra
.42734 .58187 .42936 .58381 .43283 .58276 .43081 .58082 Mtetra
.43081 .58082 .43283 .58276 .4363 .58171 .43428 .57977 Mtetra
.43428 .57977 .4363 .58171 .43978 .58066 .43776 .57871 Mtetra
.43776 .57871 .43978 .58066 .44326 .57961 .44125 .57766 Mtetra
.44125 .57766 .44326 .57961 .44675 .57855 .44474 .5766 Mtetra
.44474 .5766 .44675 .57855 .45024 .5775 .44823 .57554 Mtetra
.44823 .57554 .45024 .5775 .45373 .57644 .45173 .57449 Mtetra
.45173 .57449 .45373 .57644 .45723 .57538 .45523 .57342 Mtetra
.45523 .57342 .45723 .57538 .46074 .57432 .45874 .57236 Mtetra
.45874 .57236 .46074 .57432 .46424 .57326 .46225 .5713 Mtetra
.46225 .5713 .46424 .57326 .46776 .5722 .46576 .57024 Mtetra
.46576 .57024 .46776 .5722 .47127 .57114 .46928 .56917 Mtetra
.46928 .56917 .47127 .57114 .4748 .57007 .47281 .5681 Mtetra
.47281 .5681 .4748 .57007 .47832 .56901 .47634 .56703 Mtetra
.47634 .56703 .47832 .56901 .48185 .56794 .47987 .56596 Mtetra
.47987 .56596 .48185 .56794 .48539 .56687 .48341 .56489 Mtetra
.48341 .56489 .48539 .56687 .48893 .5658 .48695 .56382 Mtetra
.48695 .56382 .48893 .5658 .49248 .56473 .4905 .56274 Mtetra
.4905 .56274 .49248 .56473 .49602 .56365 .49405 .56167 Mtetra
.49405 .56167 .49602 .56365 .49958 .56258 .49761 .56059 Mtetra
.49761 .56059 .49958 .56258 .50314 .5615 .50117 .55951 Mtetra
.50117 .55951 .50314 .5615 .5067 .56043 .50474 .55843 Mtetra
.50474 .55843 .5067 .56043 .51027 .55935 .50831 .55735 Mtetra
.50831 .55735 .51027 .55935 .51384 .55827 .51189 .55627 Mtetra
.51189 .55627 .51384 .55827 .51742 .55719 .51547 .55518 Mtetra
.51547 .55518 .51742 .55719 .521 .5561 .51905 .5541 Mtetra
.51905 .5541 .521 .5561 .52459 .55502 .52264 .55301 Mtetra
.52264 .55301 .52459 .55502 .52818 .55393 .52624 .55192 Mtetra
.52624 .55192 .52818 .55393 .53178 .55284 .52983 .55083 Mtetra
.52983 .55083 .53178 .55284 .53538 .55176 .53344 .54974 Mtetra
.53344 .54974 .53538 .55176 .53898 .55067 .53705 .54865 Mtetra
.53705 .54865 .53898 .55067 .54259 .54957 .54066 .54756 Mtetra
.54066 .54756 .54259 .54957 .54621 .54848 .54428 .54646 Mtetra
.54428 .54646 .54621 .54848 .54983 .54739 .5479 .54536 Mtetra
.5479 .54536 .54983 .54739 .55345 .54629 .55153 .54426 Mtetra
.55153 .54426 .55345 .54629 .55708 .54519 .55516 .54316 Mtetra
.55516 .54316 .55708 .54519 .56071 .5441 .5588 .54206 Mtetra
.5588 .54206 .56071 .5441 .56435 .543 .56244 .54096 Mtetra
.873 .441 .04 r
.56244 .54096 .56435 .543 .56811 .55097 .5662 .54894 Mtetra
.663 .742 .909 r
.5662 .54894 .56811 .55097 .57177 .54987 .56986 .54783 Mtetra
.56986 .54783 .57177 .54987 .57543 .54877 .57352 .54673 Mtetra
.57352 .54673 .57543 .54877 .5791 .54766 .5772 .54562 Mtetra
.5772 .54562 .5791 .54766 .58277 .54656 .58087 .54452 Mtetra
.58087 .54452 .58277 .54656 .58645 .54545 .58455 .54341 Mtetra
.58455 .54341 .58645 .54545 .59013 .54435 .58824 .5423 Mtetra
.58824 .5423 .59013 .54435 .59382 .54324 .59193 .54119 Mtetra
.59193 .54119 .59382 .54324 .59751 .54213 .59562 .54007 Mtetra
.59562 .54007 .59751 .54213 .60121 .54101 .59932 .53896 Mtetra
.59932 .53896 .60121 .54101 .60491 .5399 .60303 .53784 Mtetra
.60303 .53784 .60491 .5399 .60862 .53879 .60674 .53673 Mtetra
.918 .755 .664 r
.60674 .53673 .60862 .53879 .61209 .52856 .61022 .52649 Mtetra
.664 .741 .908 r
.61022 .52649 .61209 .52856 .6158 .52744 .61393 .52537 Mtetra
.61393 .52537 .6158 .52744 .61951 .52632 .61765 .52424 Mtetra
.61765 .52424 .61951 .52632 .62323 .5252 .62137 .52312 Mtetra
.62137 .52312 .62323 .5252 .62695 .52407 .62509 .52199 Mtetra
.62509 .52199 .62695 .52407 .63068 .52294 .62882 .52086 Mtetra
.62882 .52086 .63068 .52294 .63441 .52182 .63256 .51973 Mtetra
.63256 .51973 .63441 .52182 .63814 .52069 .6363 .5186 Mtetra
.6363 .5186 .63814 .52069 .64188 .51955 .64004 .51746 Mtetra
.64004 .51746 .64188 .51955 .64563 .51842 .64379 .51633 Mtetra
.64379 .51633 .64563 .51842 .64938 .51729 .64755 .51519 Mtetra
.64755 .51519 .64938 .51729 .65314 .51615 .6513 .51405 Mtetra
.6513 .51405 .65314 .51615 .6569 .51502 .65507 .51291 Mtetra
.65507 .51291 .6569 .51502 .66067 .51388 .65884 .51177 Mtetra
.65884 .51177 .66067 .51388 .66444 .51274 .66261 .51063 Mtetra
.66261 .51063 .66444 .51274 .66821 .51159 .66639 .50948 Mtetra
.66639 .50948 .66821 .51159 .672 .51045 .67018 .50834 Mtetra
.67018 .50834 .672 .51045 .67578 .50931 .67397 .50719 Mtetra
.67397 .50719 .67578 .50931 .67957 .50816 .67776 .50604 Mtetra
.67776 .50604 .67957 .50816 .68337 .50701 .68156 .50489 Mtetra
.68156 .50489 .68337 .50701 .68717 .50586 .68537 .50374 Mtetra
.68537 .50374 .68717 .50586 .69098 .50471 .68918 .50258 Mtetra
.68918 .50258 .69098 .50471 .69479 .50356 .693 .50143 Mtetra
.693 .50143 .69479 .50356 .69861 .50241 .69682 .50027 Mtetra
.69682 .50027 .69861 .50241 .70243 .50125 .70064 .49911 Mtetra
.70064 .49911 .70243 .50125 .70626 .50009 .70447 .49795 Mtetra
.70447 .49795 .70626 .50009 .71009 .49893 .70831 .49679 Mtetra
.70831 .49679 .71009 .49893 .71393 .49777 .71215 .49563 Mtetra
.71215 .49563 .71393 .49777 .71777 .49661 .716 .49446 Mtetra
.716 .49446 .71777 .49661 .72162 .49545 .71985 .4933 Mtetra
.71985 .4933 .72162 .49545 .72547 .49428 .72371 .49213 Mtetra
.72371 .49213 .72547 .49428 .72933 .49312 .72757 .49096 Mtetra
.72757 .49096 .72933 .49312 .73319 .49195 .73144 .48979 Mtetra
.73144 .48979 .73319 .49195 .73706 .49078 .73531 .48861 Mtetra
.73531 .48861 .73706 .49078 .74094 .48961 .73919 .48744 Mtetra
.73919 .48744 .74094 .48961 .74482 .48843 .74307 .48626 Mtetra
.74307 .48626 .74482 .48843 .7487 .48726 .74696 .48509 Mtetra
.74696 .48509 .7487 .48726 .75259 .48608 .75085 .48391 Mtetra
.75085 .48391 .75259 .48608 .75649 .48491 .75475 .48273 Mtetra
.75475 .48273 .75649 .48491 .76039 .48373 .75865 .48155 Mtetra
.75865 .48155 .76039 .48373 .76429 .48255 .76256 .48036 Mtetra
.76256 .48036 .76429 .48255 .76821 .48136 .76648 .47918 Mtetra
.76648 .47918 .76821 .48136 .77212 .48018 .7704 .47799 Mtetra
.7704 .47799 .77212 .48018 .77604 .47899 .77433 .4768 Mtetra
.77433 .4768 .77604 .47899 .77997 .47781 .77826 .47561 Mtetra
.77826 .47561 .77997 .47781 .7839 .47662 .78219 .47442 Mtetra
.78219 .47442 .7839 .47662 .78784 .47543 .78614 .47322 Mtetra
.78614 .47322 .78784 .47543 .79179 .47423 .79008 .47203 Mtetra
.79008 .47203 .79179 .47423 .79574 .47304 .79404 .47083 Mtetra
.79404 .47083 .79574 .47304 .79969 .47184 .79799 .46963 Mtetra
.79799 .46963 .79969 .47184 .80365 .47065 .80196 .46843 Mtetra
.80196 .46843 .80365 .47065 .80761 .46945 .80593 .46723 Mtetra
.80593 .46723 .80761 .46945 .81159 .46825 .8099 .46603 Mtetra
.8099 .46603 .81159 .46825 .81556 .46705 .81388 .46482 Mtetra
.81388 .46482 .81556 .46705 .81954 .46584 .81787 .46362 Mtetra
.81787 .46362 .81954 .46584 .82353 .46464 .82186 .46241 Mtetra
.82186 .46241 .82353 .46464 .82752 .46343 .82585 .4612 Mtetra
.82585 .4612 .82752 .46343 .83152 .46222 .82986 .45999 Mtetra
.82986 .45999 .83152 .46222 .83552 .46101 .83386 .45877 Mtetra
.83386 .45877 .83552 .46101 .83953 .4598 .83788 .45756 Mtetra
.83788 .45756 .83953 .4598 .84355 .45858 .84189 .45634 Mtetra
.84189 .45634 .84355 .45858 .84757 .45737 .84592 .45512 Mtetra
.84592 .45512 .84757 .45737 .85159 .45615 .84995 .4539 Mtetra
.84995 .4539 .85159 .45615 .85562 .45493 .85398 .45268 Mtetra
.85398 .45268 .85562 .45493 .85966 .45371 .85802 .45146 Mtetra
.85802 .45146 .85966 .45371 .8637 .45249 .86207 .45023 Mtetra
.86207 .45023 .8637 .45249 .86775 .45127 .86612 .449 Mtetra
.86612 .449 .86775 .45127 .87181 .45004 .87018 .44777 Mtetra
.87018 .44777 .87181 .45004 .87587 .44881 .87424 .44654 Mtetra
.87424 .44654 .87587 .44881 .87993 .44759 .87831 .44531 Mtetra
.87831 .44531 .87993 .44759 .884 .44635 .88239 .44408 Mtetra
.88239 .44408 .884 .44635 .88808 .44512 .88647 .44284 Mtetra
.88647 .44284 .88808 .44512 .89216 .44389 .89055 .4416 Mtetra
.89055 .4416 .89216 .44389 .89625 .44265 .89465 .44037 Mtetra
.89465 .44037 .89625 .44265 .90034 .44141 .89874 .43913 Mtetra
.89874 .43913 .90034 .44141 .90444 .44018 .90285 .43788 Mtetra
.90285 .43788 .90444 .44018 .90854 .43893 .90696 .43664 Mtetra
.90696 .43664 .90854 .43893 .91265 .43769 .91107 .43539 Mtetra
.91107 .43539 .91265 .43769 .91677 .43645 .91519 .43414 Mtetra
.91519 .43414 .91677 .43645 .92089 .4352 .91932 .4329 Mtetra
.91932 .4329 .92089 .4352 .92502 .43395 .92345 .43164 Mtetra
.92345 .43164 .92502 .43395 .92915 .4327 .92759 .43039 Mtetra
.92759 .43039 .92915 .4327 .93329 .43145 .93173 .42914 Mtetra
.93173 .42914 .93329 .43145 .93744 .4302 .93588 .42788 Mtetra
.93588 .42788 .93744 .4302 .94159 .42894 .94004 .42662 Mtetra
.94004 .42662 .94159 .42894 .94575 .42769 .9442 .42536 Mtetra
.9442 .42536 .94575 .42769 .94991 .42643 .94836 .4241 Mtetra
.94836 .4241 .94991 .42643 .95408 .42517 .95254 .42284 Mtetra
.95254 .42284 .95408 .42517 .95825 .42391 .95672 .42157 Mtetra
.95672 .42157 .95825 .42391 .96243 .42264 .9609 .4203 Mtetra
.39081 .59039 .39287 .59231 .3963 .59127 .39424 .58935 Mtetra
.39424 .58935 .3963 .59127 .39973 .59023 .39768 .58831 Mtetra
.39768 .58831 .39973 .59023 .40317 .58919 .40112 .58727 Mtetra
.40112 .58727 .40317 .58919 .40661 .58815 .40456 .58622 Mtetra
.40456 .58622 .40661 .58815 .41005 .58711 .408 .58518 Mtetra
.408 .58518 .41005 .58711 .4135 .58606 .41146 .58413 Mtetra
.41146 .58413 .4135 .58606 .41695 .58502 .41491 .58308 Mtetra
.41491 .58308 .41695 .58502 .42041 .58397 .41837 .58203 Mtetra
.41837 .58203 .42041 .58397 .42387 .58292 .42184 .58098 Mtetra
.42184 .58098 .42387 .58292 .42734 .58187 .42531 .57993 Mtetra
.42531 .57993 .42734 .58187 .43081 .58082 .42878 .57888 Mtetra
.42878 .57888 .43081 .58082 .43428 .57977 .43226 .57782 Mtetra
.43226 .57782 .43428 .57977 .43776 .57871 .43574 .57677 Mtetra
.43574 .57677 .43776 .57871 .44125 .57766 .43923 .57571 Mtetra
.43923 .57571 .44125 .57766 .44474 .5766 .44272 .57465 Mtetra
.44272 .57465 .44474 .5766 .44823 .57554 .44622 .57359 Mtetra
.44622 .57359 .44823 .57554 .45173 .57449 .44972 .57253 Mtetra
.44972 .57253 .45173 .57449 .45523 .57342 .45322 .57146 Mtetra
.45322 .57146 .45523 .57342 .45874 .57236 .45673 .5704 Mtetra
.45673 .5704 .45874 .57236 .46225 .5713 .46024 .56933 Mtetra
.46024 .56933 .46225 .5713 .46576 .57024 .46376 .56827 Mtetra
.46376 .56827 .46576 .57024 .46928 .56917 .46729 .5672 Mtetra
.46729 .5672 .46928 .56917 .47281 .5681 .47081 .56613 Mtetra
.47081 .56613 .47281 .5681 .47634 .56703 .47435 .56506 Mtetra
.47435 .56506 .47634 .56703 .47987 .56596 .47788 .56398 Mtetra
.47788 .56398 .47987 .56596 .48341 .56489 .48143 .56291 Mtetra
.48143 .56291 .48341 .56489 .48695 .56382 .48497 .56183 Mtetra
.48497 .56183 .48695 .56382 .4905 .56274 .48852 .56076 Mtetra
.48852 .56076 .4905 .56274 .49405 .56167 .49208 .55968 Mtetra
.49208 .55968 .49405 .56167 .49761 .56059 .49564 .5586 Mtetra
.49564 .5586 .49761 .56059 .50117 .55951 .4992 .55752 Mtetra
.4992 .55752 .50117 .55951 .50474 .55843 .50277 .55644 Mtetra
.50277 .55644 .50474 .55843 .50831 .55735 .50635 .55535 Mtetra
.50635 .55535 .50831 .55735 .51189 .55627 .50993 .55427 Mtetra
.50993 .55427 .51189 .55627 .51547 .55518 .51351 .55318 Mtetra
.51351 .55318 .51547 .55518 .51905 .5541 .5171 .55209 Mtetra
.5171 .55209 .51905 .5541 .52264 .55301 .52069 .551 Mtetra
.52069 .551 .52264 .55301 .52624 .55192 .52429 .54991 Mtetra
.52429 .54991 .52624 .55192 .52983 .55083 .52789 .54882 Mtetra
.52789 .54882 .52983 .55083 .53344 .54974 .5315 .54772 Mtetra
.5315 .54772 .53344 .54974 .53705 .54865 .53511 .54663 Mtetra
.53511 .54663 .53705 .54865 .54066 .54756 .53872 .54553 Mtetra
.53872 .54553 .54066 .54756 .54428 .54646 .54235 .54443 Mtetra
.54235 .54443 .54428 .54646 .5479 .54536 .54597 .54333 Mtetra
.54597 .54333 .5479 .54536 .55153 .54426 .5496 .54223 Mtetra
.5496 .54223 .55153 .54426 .55516 .54316 .55324 .54113 Mtetra
.55324 .54113 .55516 .54316 .5588 .54206 .55688 .54003 Mtetra
.874 .443 .044 r
.55688 .54003 .5588 .54206 .56244 .54096 .56062 .548 Mtetra
.491 .189 .382 r
.56062 .548 .56244 .54096 .5662 .54894 .56428 .5469 Mtetra
.663 .742 .909 r
.56428 .5469 .5662 .54894 .56986 .54783 .56794 .54579 Mtetra
.56794 .54579 .56986 .54783 .57352 .54673 .57161 .54469 Mtetra
.57161 .54469 .57352 .54673 .5772 .54562 .57529 .54358 Mtetra
.57529 .54358 .5772 .54562 .58087 .54452 .57897 .54247 Mtetra
.57897 .54247 .58087 .54452 .58455 .54341 .58265 .54136 Mtetra
.58265 .54136 .58455 .54341 .58824 .5423 .58634 .54024 Mtetra
.58634 .54024 .58824 .5423 .59193 .54119 .59003 .53913 Mtetra
.59003 .53913 .59193 .54119 .59562 .54007 .59373 .53801 Mtetra
.59373 .53801 .59562 .54007 .59932 .53896 .59744 .5369 Mtetra
.59744 .5369 .59932 .53896 .60303 .53784 .60114 .53578 Mtetra
.60114 .53578 .60303 .53784 .60674 .53673 .60486 .53466 Mtetra
.60486 .53466 .60674 .53673 .61022 .52649 .60858 .53354 Mtetra
0 0 .045 r
.60858 .53354 .61022 .52649 .61393 .52537 .61206 .52329 Mtetra
.664 .741 .908 r
.61206 .52329 .61393 .52537 .61765 .52424 .61578 .52216 Mtetra
.61578 .52216 .61765 .52424 .62137 .52312 .6195 .52103 Mtetra
.6195 .52103 .62137 .52312 .62509 .52199 .62323 .5199 Mtetra
.62323 .5199 .62509 .52199 .62882 .52086 .62696 .51877 Mtetra
.62696 .51877 .62882 .52086 .63256 .51973 .6307 .51764 Mtetra
.6307 .51764 .63256 .51973 .6363 .5186 .63444 .5165 Mtetra
.63444 .5165 .6363 .5186 .64004 .51746 .63819 .51537 Mtetra
.63819 .51537 .64004 .51746 .64379 .51633 .64195 .51423 Mtetra
.64195 .51423 .64379 .51633 .64755 .51519 .6457 .51309 Mtetra
.6457 .51309 .64755 .51519 .6513 .51405 .64947 .51195 Mtetra
.64947 .51195 .6513 .51405 .65507 .51291 .65323 .5108 Mtetra
.65323 .5108 .65507 .51291 .65884 .51177 .65701 .50966 Mtetra
.65701 .50966 .65884 .51177 .66261 .51063 .66079 .50851 Mtetra
.66079 .50851 .66261 .51063 .66639 .50948 .66457 .50737 Mtetra
.66457 .50737 .66639 .50948 .67018 .50834 .66836 .50622 Mtetra
.66836 .50622 .67018 .50834 .67397 .50719 .67215 .50507 Mtetra
.67215 .50507 .67397 .50719 .67776 .50604 .67595 .50391 Mtetra
.67595 .50391 .67776 .50604 .68156 .50489 .67975 .50276 Mtetra
.67975 .50276 .68156 .50489 .68537 .50374 .68356 .50161 Mtetra
.68356 .50161 .68537 .50374 .68918 .50258 .68738 .50045 Mtetra
.68738 .50045 .68918 .50258 .693 .50143 .6912 .49929 Mtetra
.6912 .49929 .693 .50143 .69682 .50027 .69502 .49813 Mtetra
.69502 .49813 .69682 .50027 .70064 .49911 .69885 .49697 Mtetra
.69885 .49697 .70064 .49911 .70447 .49795 .70268 .49581 Mtetra
.70268 .49581 .70447 .49795 .70831 .49679 .70652 .49464 Mtetra
.70652 .49464 .70831 .49679 .71215 .49563 .71037 .49348 Mtetra
.71037 .49348 .71215 .49563 .716 .49446 .71422 .49231 Mtetra
.71422 .49231 .716 .49446 .71985 .4933 .71807 .49114 Mtetra
.71807 .49114 .71985 .4933 .72371 .49213 .72193 .48997 Mtetra
.72193 .48997 .72371 .49213 .72757 .49096 .7258 .4888 Mtetra
.7258 .4888 .72757 .49096 .73144 .48979 .72967 .48762 Mtetra
.72967 .48762 .73144 .48979 .73531 .48861 .73355 .48645 Mtetra
.73355 .48645 .73531 .48861 .73919 .48744 .73743 .48527 Mtetra
.73743 .48527 .73919 .48744 .74307 .48626 .74132 .48409 Mtetra
.74132 .48409 .74307 .48626 .74696 .48509 .74521 .48291 Mtetra
.74521 .48291 .74696 .48509 .75085 .48391 .74911 .48173 Mtetra
.74911 .48173 .75085 .48391 .75475 .48273 .75301 .48054 Mtetra
.75301 .48054 .75475 .48273 .75865 .48155 .75692 .47936 Mtetra
.75692 .47936 .75865 .48155 .76256 .48036 .76083 .47817 Mtetra
.76083 .47817 .76256 .48036 .76648 .47918 .76475 .47698 Mtetra
.76475 .47698 .76648 .47918 .7704 .47799 .76867 .47579 Mtetra
.76867 .47579 .7704 .47799 .77433 .4768 .7726 .4746 Mtetra
.7726 .4746 .77433 .4768 .77826 .47561 .77654 .47341 Mtetra
.77654 .47341 .77826 .47561 .78219 .47442 .78048 .47221 Mtetra
.78048 .47221 .78219 .47442 .78614 .47322 .78442 .47102 Mtetra
.78442 .47102 .78614 .47322 .79008 .47203 .78838 .46982 Mtetra
.78838 .46982 .79008 .47203 .79404 .47083 .79233 .46862 Mtetra
.79233 .46862 .79404 .47083 .79799 .46963 .79629 .46742 Mtetra
.79629 .46742 .79799 .46963 .80196 .46843 .80026 .46621 Mtetra
.80026 .46621 .80196 .46843 .80593 .46723 .80423 .46501 Mtetra
.80423 .46501 .80593 .46723 .8099 .46603 .80821 .4638 Mtetra
.80821 .4638 .8099 .46603 .81388 .46482 .8122 .46259 Mtetra
.8122 .46259 .81388 .46482 .81787 .46362 .81619 .46138 Mtetra
.81619 .46138 .81787 .46362 .82186 .46241 .82018 .46017 Mtetra
.82018 .46017 .82186 .46241 .82585 .4612 .82418 .45896 Mtetra
.82418 .45896 .82585 .4612 .82986 .45999 .82819 .45774 Mtetra
.82819 .45774 .82986 .45999 .83386 .45877 .8322 .45653 Mtetra
.8322 .45653 .83386 .45877 .83788 .45756 .83622 .45531 Mtetra
.83622 .45531 .83788 .45756 .84189 .45634 .84024 .45409 Mtetra
.84024 .45409 .84189 .45634 .84592 .45512 .84427 .45287 Mtetra
.84427 .45287 .84592 .45512 .84995 .4539 .8483 .45164 Mtetra
.8483 .45164 .84995 .4539 .85398 .45268 .85234 .45042 Mtetra
.85234 .45042 .85398 .45268 .85802 .45146 .85638 .44919 Mtetra
.85638 .44919 .85802 .45146 .86207 .45023 .86043 .44796 Mtetra
.86043 .44796 .86207 .45023 .86612 .449 .86449 .44673 Mtetra
.86449 .44673 .86612 .449 .87018 .44777 .86855 .4455 Mtetra
.86855 .4455 .87018 .44777 .87424 .44654 .87262 .44427 Mtetra
.87262 .44427 .87424 .44654 .87831 .44531 .87669 .44303 Mtetra
.87669 .44303 .87831 .44531 .88239 .44408 .88077 .4418 Mtetra
.88077 .4418 .88239 .44408 .88647 .44284 .88486 .44056 Mtetra
.88486 .44056 .88647 .44284 .89055 .4416 .88895 .43932 Mtetra
.88895 .43932 .89055 .4416 .89465 .44037 .89304 .43807 Mtetra
.89304 .43807 .89465 .44037 .89874 .43913 .89714 .43683 Mtetra
.89714 .43683 .89874 .43913 .90285 .43788 .90125 .43558 Mtetra
.90125 .43558 .90285 .43788 .90696 .43664 .90536 .43434 Mtetra
.90536 .43434 .90696 .43664 .91107 .43539 .90948 .43309 Mtetra
.90948 .43309 .91107 .43539 .91519 .43414 .91361 .43184 Mtetra
.91361 .43184 .91519 .43414 .91932 .4329 .91774 .43058 Mtetra
.91774 .43058 .91932 .4329 .92345 .43164 .92187 .42933 Mtetra
.92187 .42933 .92345 .43164 .92759 .43039 .92602 .42807 Mtetra
.92602 .42807 .92759 .43039 .93173 .42914 .93016 .42682 Mtetra
.93016 .42682 .93173 .42914 .93588 .42788 .93432 .42556 Mtetra
.93432 .42556 .93588 .42788 .94004 .42662 .93848 .42429 Mtetra
.93848 .42429 .94004 .42662 .9442 .42536 .94264 .42303 Mtetra
.94264 .42303 .9442 .42536 .94836 .4241 .94681 .42177 Mtetra
.94681 .42177 .94836 .4241 .95254 .42284 .95099 .4205 Mtetra
.95099 .4205 .95254 .42284 .95672 .42157 .95518 .41923 Mtetra
.95518 .41923 .95672 .42157 .9609 .4203 .95936 .41796 Mtetra
.38875 .58847 .39081 .59039 .39424 .58935 .39218 .58743 Mtetra
.39218 .58743 .39424 .58935 .39768 .58831 .39562 .58638 Mtetra
.39562 .58638 .39768 .58831 .40112 .58727 .39906 .58534 Mtetra
.39906 .58534 .40112 .58727 .40456 .58622 .40251 .58429 Mtetra
.40251 .58429 .40456 .58622 .408 .58518 .40596 .58324 Mtetra
.40596 .58324 .408 .58518 .41146 .58413 .40941 .58219 Mtetra
.40941 .58219 .41146 .58413 .41491 .58308 .41287 .58114 Mtetra
.41287 .58114 .41491 .58308 .41837 .58203 .41633 .58009 Mtetra
.41633 .58009 .41837 .58203 .42184 .58098 .4198 .57904 Mtetra
.4198 .57904 .42184 .58098 .42531 .57993 .42327 .57798 Mtetra
.42327 .57798 .42531 .57993 .42878 .57888 .42675 .57693 Mtetra
.42675 .57693 .42878 .57888 .43226 .57782 .43023 .57587 Mtetra
.43023 .57587 .43226 .57782 .43574 .57677 .43371 .57481 Mtetra
.43371 .57481 .43574 .57677 .43923 .57571 .4372 .57375 Mtetra
.4372 .57375 .43923 .57571 .44272 .57465 .4407 .57269 Mtetra
.4407 .57269 .44272 .57465 .44622 .57359 .4442 .57163 Mtetra
.4442 .57163 .44622 .57359 .44972 .57253 .4477 .57056 Mtetra
.4477 .57056 .44972 .57253 .45322 .57146 .45121 .5695 Mtetra
.45121 .5695 .45322 .57146 .45673 .5704 .45472 .56843 Mtetra
.45472 .56843 .45673 .5704 .46024 .56933 .45824 .56736 Mtetra
.45824 .56736 .46024 .56933 .46376 .56827 .46176 .56629 Mtetra
.46176 .56629 .46376 .56827 .46729 .5672 .46529 .56522 Mtetra
.46529 .56522 .46729 .5672 .47081 .56613 .46882 .56415 Mtetra
.46882 .56415 .47081 .56613 .47435 .56506 .47235 .56307 Mtetra
.47235 .56307 .47435 .56506 .47788 .56398 .47589 .562 Mtetra
.47589 .562 .47788 .56398 .48143 .56291 .47944 .56092 Mtetra
.47944 .56092 .48143 .56291 .48497 .56183 .48299 .55984 Mtetra
.48299 .55984 .48497 .56183 .48852 .56076 .48654 .55877 Mtetra
.48654 .55877 .48852 .56076 .49208 .55968 .4901 .55768 Mtetra
.4901 .55768 .49208 .55968 .49564 .5586 .49366 .5566 Mtetra
.49366 .5566 .49564 .5586 .4992 .55752 .49723 .55552 Mtetra
.49723 .55552 .4992 .55752 .50277 .55644 .5008 .55443 Mtetra
.5008 .55443 .50277 .55644 .50635 .55535 .50438 .55335 Mtetra
.50438 .55335 .50635 .55535 .50993 .55427 .50796 .55226 Mtetra
.50796 .55226 .50993 .55427 .51351 .55318 .51155 .55117 Mtetra
.51155 .55117 .51351 .55318 .5171 .55209 .51514 .55008 Mtetra
.51514 .55008 .5171 .55209 .52069 .551 .51873 .54899 Mtetra
.51873 .54899 .52069 .551 .52429 .54991 .52233 .54789 Mtetra
.52233 .54789 .52429 .54991 .52789 .54882 .52594 .5468 Mtetra
.52594 .5468 .52789 .54882 .5315 .54772 .52955 .5457 Mtetra
.52955 .5457 .5315 .54772 .53511 .54663 .53316 .5446 Mtetra
.53316 .5446 .53511 .54663 .53872 .54553 .53678 .5435 Mtetra
.53678 .5435 .53872 .54553 .54235 .54443 .54041 .5424 Mtetra
.54041 .5424 .54235 .54443 .54597 .54333 .54404 .5413 Mtetra
.54404 .5413 .54597 .54333 .5496 .54223 .54767 .5402 Mtetra
.54767 .5402 .5496 .54223 .55324 .54113 .55131 .53909 Mtetra
.55131 .53909 .55324 .54113 .55688 .54003 .55495 .53798 Mtetra
.874 .443 .044 r
.55495 .53798 .55688 .54003 .56062 .548 .55869 .54596 Mtetra
.663 .742 .909 r
.55869 .54596 .56062 .548 .56428 .5469 .56235 .54486 Mtetra
.56235 .54486 .56428 .5469 .56794 .54579 .56602 .54375 Mtetra
.56602 .54375 .56794 .54579 .57161 .54469 .56969 .54264 Mtetra
.56969 .54264 .57161 .54469 .57529 .54358 .57337 .54153 Mtetra
.57337 .54153 .57529 .54358 .57897 .54247 .57705 .54042 Mtetra
.57705 .54042 .57897 .54247 .58265 .54136 .58074 .5393 Mtetra
.58074 .5393 .58265 .54136 .58634 .54024 .58443 .53819 Mtetra
.58443 .53819 .58634 .54024 .59003 .53913 .58813 .53707 Mtetra
.58813 .53707 .59003 .53913 .59373 .53801 .59183 .53595 Mtetra
.59183 .53595 .59373 .53801 .59744 .5369 .59554 .53483 Mtetra
.59554 .53483 .59744 .5369 .60114 .53578 .59925 .53371 Mtetra
.59925 .53371 .60114 .53578 .60486 .53466 .60297 .53259 Mtetra
.60297 .53259 .60486 .53466 .60858 .53354 .60669 .53146 Mtetra
.918 .755 .664 r
.60669 .53146 .60858 .53354 .61206 .52329 .61018 .52121 Mtetra
.664 .741 .908 r
.61018 .52121 .61206 .52329 .61578 .52216 .61391 .52008 Mtetra
.61391 .52008 .61578 .52216 .6195 .52103 .61763 .51894 Mtetra
.61763 .51894 .6195 .52103 .62323 .5199 .62136 .51781 Mtetra
.62136 .51781 .62323 .5199 .62696 .51877 .6251 .51668 Mtetra
.6251 .51668 .62696 .51877 .6307 .51764 .62884 .51554 Mtetra
.62884 .51554 .6307 .51764 .63444 .5165 .63259 .5144 Mtetra
.63259 .5144 .63444 .5165 .63819 .51537 .63634 .51326 Mtetra
.63634 .51326 .63819 .51537 .64195 .51423 .6401 .51212 Mtetra
.6401 .51212 .64195 .51423 .6457 .51309 .64386 .51098 Mtetra
.64386 .51098 .6457 .51309 .64947 .51195 .64762 .50983 Mtetra
.64762 .50983 .64947 .51195 .65323 .5108 .6514 .50869 Mtetra
.6514 .50869 .65323 .5108 .65701 .50966 .65517 .50754 Mtetra
.65517 .50754 .65701 .50966 .66079 .50851 .65895 .50639 Mtetra
.65895 .50639 .66079 .50851 .66457 .50737 .66274 .50524 Mtetra
.66274 .50524 .66457 .50737 .66836 .50622 .66653 .50409 Mtetra
.66653 .50409 .66836 .50622 .67215 .50507 .67033 .50294 Mtetra
.67033 .50294 .67215 .50507 .67595 .50391 .67413 .50178 Mtetra
.67413 .50178 .67595 .50391 .67975 .50276 .67794 .50063 Mtetra
.67794 .50063 .67975 .50276 .68356 .50161 .68175 .49947 Mtetra
.68175 .49947 .68356 .50161 .68738 .50045 .68557 .49831 Mtetra
.68557 .49831 .68738 .50045 .6912 .49929 .68939 .49715 Mtetra
.68939 .49715 .6912 .49929 .69502 .49813 .69322 .49599 Mtetra
.69322 .49599 .69502 .49813 .69885 .49697 .69705 .49482 Mtetra
.69705 .49482 .69885 .49697 .70268 .49581 .70089 .49366 Mtetra
.70089 .49366 .70268 .49581 .70652 .49464 .70473 .49249 Mtetra
.70473 .49249 .70652 .49464 .71037 .49348 .70858 .49132 Mtetra
.70858 .49132 .71037 .49348 .71422 .49231 .71244 .49015 Mtetra
.71244 .49015 .71422 .49231 .71807 .49114 .71629 .48898 Mtetra
.71629 .48898 .71807 .49114 .72193 .48997 .72016 .4878 Mtetra
.72016 .4878 .72193 .48997 .7258 .4888 .72403 .48663 Mtetra
.72403 .48663 .7258 .4888 .72967 .48762 .7279 .48545 Mtetra
.7279 .48545 .72967 .48762 .73355 .48645 .73178 .48427 Mtetra
.73178 .48427 .73355 .48645 .73743 .48527 .73567 .48309 Mtetra
.73567 .48309 .73743 .48527 .74132 .48409 .73956 .48191 Mtetra
.73956 .48191 .74132 .48409 .74521 .48291 .74345 .48073 Mtetra
.74345 .48073 .74521 .48291 .74911 .48173 .74736 .47954 Mtetra
.74736 .47954 .74911 .48173 .75301 .48054 .75126 .47835 Mtetra
.75126 .47835 .75301 .48054 .75692 .47936 .75517 .47717 Mtetra
.75517 .47717 .75692 .47936 .76083 .47817 .75909 .47598 Mtetra
.75909 .47598 .76083 .47817 .76475 .47698 .76301 .47478 Mtetra
.76301 .47478 .76475 .47698 .76867 .47579 .76694 .47359 Mtetra
.76694 .47359 .76867 .47579 .7726 .4746 .77088 .4724 Mtetra
.77088 .4724 .7726 .4746 .77654 .47341 .77481 .4712 Mtetra
.77481 .4712 .77654 .47341 .78048 .47221 .77876 .47 Mtetra
.77876 .47 .78048 .47221 .78442 .47102 .78271 .4688 Mtetra
.78271 .4688 .78442 .47102 .78838 .46982 .78666 .4676 Mtetra
.78666 .4676 .78838 .46982 .79233 .46862 .79062 .4664 Mtetra
.79062 .4664 .79233 .46862 .79629 .46742 .79459 .46519 Mtetra
.79459 .46519 .79629 .46742 .80026 .46621 .79856 .46399 Mtetra
.79856 .46399 .80026 .46621 .80423 .46501 .80254 .46278 Mtetra
.80254 .46278 .80423 .46501 .80821 .4638 .80652 .46157 Mtetra
.80652 .46157 .80821 .4638 .8122 .46259 .81051 .46036 Mtetra
.81051 .46036 .8122 .46259 .81619 .46138 .8145 .45915 Mtetra
.8145 .45915 .81619 .46138 .82018 .46017 .8185 .45793 Mtetra
.8185 .45793 .82018 .46017 .82418 .45896 .8225 .45671 Mtetra
.8225 .45671 .82418 .45896 .82819 .45774 .82651 .4555 Mtetra
.82651 .4555 .82819 .45774 .8322 .45653 .83053 .45428 Mtetra
.83053 .45428 .8322 .45653 .83622 .45531 .83455 .45306 Mtetra
.83455 .45306 .83622 .45531 .84024 .45409 .83858 .45183 Mtetra
.83858 .45183 .84024 .45409 .84427 .45287 .84261 .45061 Mtetra
.84261 .45061 .84427 .45287 .8483 .45164 .84665 .44938 Mtetra
.84665 .44938 .8483 .45164 .85234 .45042 .85069 .44815 Mtetra
.85069 .44815 .85234 .45042 .85638 .44919 .85474 .44692 Mtetra
.85474 .44692 .85638 .44919 .86043 .44796 .85879 .44569 Mtetra
.85879 .44569 .86043 .44796 .86449 .44673 .86285 .44446 Mtetra
.86285 .44446 .86449 .44673 .86855 .4455 .86692 .44322 Mtetra
.86692 .44322 .86855 .4455 .87262 .44427 .87099 .44199 Mtetra
.87099 .44199 .87262 .44427 .87669 .44303 .87507 .44075 Mtetra
.87507 .44075 .87669 .44303 .88077 .4418 .87915 .43951 Mtetra
.87915 .43951 .88077 .4418 .88486 .44056 .88324 .43827 Mtetra
.88324 .43827 .88486 .44056 .88895 .43932 .88733 .43702 Mtetra
.88733 .43702 .88895 .43932 .89304 .43807 .89143 .43578 Mtetra
.89143 .43578 .89304 .43807 .89714 .43683 .89554 .43453 Mtetra
.89554 .43453 .89714 .43683 .90125 .43558 .89965 .43328 Mtetra
.89965 .43328 .90125 .43558 .90536 .43434 .90377 .43203 Mtetra
.90377 .43203 .90536 .43434 .90948 .43309 .90789 .43078 Mtetra
.90789 .43078 .90948 .43309 .91361 .43184 .91202 .42952 Mtetra
.91202 .42952 .91361 .43184 .91774 .43058 .91616 .42827 Mtetra
.91616 .42827 .91774 .43058 .92187 .42933 .9203 .42701 Mtetra
.9203 .42701 .92187 .42933 .92602 .42807 .92444 .42575 Mtetra
.92444 .42575 .92602 .42807 .93016 .42682 .92859 .42449 Mtetra
.92859 .42449 .93016 .42682 .93432 .42556 .93275 .42323 Mtetra
.93275 .42323 .93432 .42556 .93848 .42429 .93692 .42196 Mtetra
.93692 .42196 .93848 .42429 .94264 .42303 .94109 .42069 Mtetra
.94109 .42069 .94264 .42303 .94681 .42177 .94526 .41943 Mtetra
.94526 .41943 .94681 .42177 .95099 .4205 .94944 .41816 Mtetra
.94944 .41816 .95099 .4205 .95518 .41923 .95363 .41688 Mtetra
.95363 .41688 .95518 .41923 .95936 .41796 .95782 .41561 Mtetra
.38668 .58654 .38875 .58847 .39218 .58743 .39012 .5855 Mtetra
.39012 .5855 .39218 .58743 .39562 .58638 .39356 .58445 Mtetra
.39356 .58445 .39562 .58638 .39906 .58534 .397 .5834 Mtetra
.397 .5834 .39906 .58534 .40251 .58429 .40045 .58236 Mtetra
.40045 .58236 .40251 .58429 .40596 .58324 .4039 .58131 Mtetra
.4039 .58131 .40596 .58324 .40941 .58219 .40736 .58025 Mtetra
.40736 .58025 .40941 .58219 .41287 .58114 .41082 .5792 Mtetra
.41082 .5792 .41287 .58114 .41633 .58009 .41429 .57815 Mtetra
.41429 .57815 .41633 .58009 .4198 .57904 .41776 .57709 Mtetra
.41776 .57709 .4198 .57904 .42327 .57798 .42123 .57603 Mtetra
.42123 .57603 .42327 .57798 .42675 .57693 .42471 .57497 Mtetra
.42471 .57497 .42675 .57693 .43023 .57587 .42819 .57391 Mtetra
.42819 .57391 .43023 .57587 .43371 .57481 .43168 .57285 Mtetra
.43168 .57285 .43371 .57481 .4372 .57375 .43517 .57179 Mtetra
.43517 .57179 .4372 .57375 .4407 .57269 .43867 .57073 Mtetra
.43867 .57073 .4407 .57269 .4442 .57163 .44217 .56966 Mtetra
.44217 .56966 .4442 .57163 .4477 .57056 .44568 .56859 Mtetra
.44568 .56859 .4477 .57056 .45121 .5695 .44919 .56753 Mtetra
.44919 .56753 .45121 .5695 .45472 .56843 .45271 .56646 Mtetra
.45271 .56646 .45472 .56843 .45824 .56736 .45623 .56539 Mtetra
.45623 .56539 .45824 .56736 .46176 .56629 .45975 .56431 Mtetra
.45975 .56431 .46176 .56629 .46529 .56522 .46328 .56324 Mtetra
.46328 .56324 .46529 .56522 .46882 .56415 .46681 .56217 Mtetra
.46681 .56217 .46882 .56415 .47235 .56307 .47035 .56109 Mtetra
.47035 .56109 .47235 .56307 .47589 .562 .47389 .56001 Mtetra
.47389 .56001 .47589 .562 .47944 .56092 .47744 .55893 Mtetra
.47744 .55893 .47944 .56092 .48299 .55984 .48099 .55785 Mtetra
.48099 .55785 .48299 .55984 .48654 .55877 .48455 .55677 Mtetra
.48455 .55677 .48654 .55877 .4901 .55768 .48811 .55569 Mtetra
.48811 .55569 .4901 .55768 .49366 .5566 .49168 .5546 Mtetra
.49168 .5546 .49366 .5566 .49723 .55552 .49525 .55351 Mtetra
.49525 .55351 .49723 .55552 .5008 .55443 .49882 .55243 Mtetra
.49882 .55243 .5008 .55443 .50438 .55335 .5024 .55134 Mtetra
.5024 .55134 .50438 .55335 .50796 .55226 .50599 .55025 Mtetra
.50599 .55025 .50796 .55226 .51155 .55117 .50958 .54915 Mtetra
.50958 .54915 .51155 .55117 .51514 .55008 .51317 .54806 Mtetra
.51317 .54806 .51514 .55008 .51873 .54899 .51677 .54697 Mtetra
.51677 .54697 .51873 .54899 .52233 .54789 .52038 .54587 Mtetra
.52038 .54587 .52233 .54789 .52594 .5468 .52398 .54477 Mtetra
.52398 .54477 .52594 .5468 .52955 .5457 .5276 .54367 Mtetra
.5276 .54367 .52955 .5457 .53316 .5446 .53121 .54257 Mtetra
.53121 .54257 .53316 .5446 .53678 .5435 .53484 .54147 Mtetra
.53484 .54147 .53678 .5435 .54041 .5424 .53846 .54037 Mtetra
.53846 .54037 .54041 .5424 .54404 .5413 .5421 .53926 Mtetra
.5421 .53926 .54404 .5413 .54767 .5402 .54573 .53815 Mtetra
.54573 .53815 .54767 .5402 .55131 .53909 .54938 .53705 Mtetra
.876 .445 .048 r
.54938 .53705 .55131 .53909 .55495 .53798 .5531 .54503 Mtetra
.489 .187 .379 r
.5531 .54503 .55495 .53798 .55869 .54596 .55676 .54392 Mtetra
.663 .742 .909 r
.55676 .54392 .55869 .54596 .56235 .54486 .56043 .54281 Mtetra
.56043 .54281 .56235 .54486 .56602 .54375 .5641 .5417 Mtetra
.5641 .5417 .56602 .54375 .56969 .54264 .56777 .54059 Mtetra
.56777 .54059 .56969 .54264 .57337 .54153 .57145 .53947 Mtetra
.57145 .53947 .57337 .54153 .57705 .54042 .57514 .53836 Mtetra
.57514 .53836 .57705 .54042 .58074 .5393 .57883 .53724 Mtetra
.57883 .53724 .58074 .5393 .58443 .53819 .58253 .53612 Mtetra
.58253 .53612 .58443 .53819 .58813 .53707 .58623 .535 Mtetra
.58623 .535 .58813 .53707 .59183 .53595 .58993 .53388 Mtetra
.58993 .53388 .59183 .53595 .59554 .53483 .59364 .53276 Mtetra
.59364 .53276 .59554 .53483 .59925 .53371 .59736 .53164 Mtetra
.59736 .53164 .59925 .53371 .60297 .53259 .60108 .53051 Mtetra
.60108 .53051 .60297 .53259 .60669 .53146 .6048 .52938 Mtetra
.6048 .52938 .60669 .53146 .61018 .52121 .60853 .52825 Mtetra
0 0 .042 r
.60853 .52825 .61018 .52121 .61391 .52008 .61203 .51799 Mtetra
.664 .741 .908 r
.61203 .51799 .61391 .52008 .61763 .51894 .61576 .51685 Mtetra
.61576 .51685 .61763 .51894 .62136 .51781 .61949 .51572 Mtetra
.61949 .51572 .62136 .51781 .6251 .51668 .62323 .51458 Mtetra
.62323 .51458 .6251 .51668 .62884 .51554 .62698 .51344 Mtetra
.62698 .51344 .62884 .51554 .63259 .5144 .63073 .5123 Mtetra
.63073 .5123 .63259 .5144 .63634 .51326 .63448 .51115 Mtetra
.63448 .51115 .63634 .51326 .6401 .51212 .63824 .51001 Mtetra
.63824 .51001 .6401 .51212 .64386 .51098 .64201 .50887 Mtetra
.64201 .50887 .64386 .51098 .64762 .50983 .64578 .50772 Mtetra
.64578 .50772 .64762 .50983 .6514 .50869 .64955 .50657 Mtetra
.64955 .50657 .6514 .50869 .65517 .50754 .65333 .50542 Mtetra
.65333 .50542 .65517 .50754 .65895 .50639 .65712 .50427 Mtetra
.65712 .50427 .65895 .50639 .66274 .50524 .66091 .50312 Mtetra
.66091 .50312 .66274 .50524 .66653 .50409 .6647 .50196 Mtetra
.6647 .50196 .66653 .50409 .67033 .50294 .6685 .5008 Mtetra
.6685 .5008 .67033 .50294 .67413 .50178 .67231 .49965 Mtetra
.67231 .49965 .67413 .50178 .67794 .50063 .67612 .49849 Mtetra
.67612 .49849 .67794 .50063 .68175 .49947 .67993 .49733 Mtetra
.67993 .49733 .68175 .49947 .68557 .49831 .68376 .49616 Mtetra
.68376 .49616 .68557 .49831 .68939 .49715 .68758 .495 Mtetra
.68758 .495 .68939 .49715 .69322 .49599 .69141 .49383 Mtetra
.69141 .49383 .69322 .49599 .69705 .49482 .69525 .49267 Mtetra
.69525 .49267 .69705 .49482 .70089 .49366 .69909 .4915 Mtetra
.69909 .4915 .70089 .49366 .70473 .49249 .70294 .49033 Mtetra
.70294 .49033 .70473 .49249 .70858 .49132 .70679 .48916 Mtetra
.70679 .48916 .70858 .49132 .71244 .49015 .71065 .48798 Mtetra
.71065 .48798 .71244 .49015 .71629 .48898 .71451 .48681 Mtetra
.71451 .48681 .71629 .48898 .72016 .4878 .71838 .48563 Mtetra
.71838 .48563 .72016 .4878 .72403 .48663 .72225 .48445 Mtetra
.72225 .48445 .72403 .48663 .7279 .48545 .72613 .48327 Mtetra
.72613 .48327 .7279 .48545 .73178 .48427 .73001 .48209 Mtetra
.73001 .48209 .73178 .48427 .73567 .48309 .7339 .48091 Mtetra
.7339 .48091 .73567 .48309 .73956 .48191 .7378 .47972 Mtetra
.7378 .47972 .73956 .48191 .74345 .48073 .7417 .47854 Mtetra
.7417 .47854 .74345 .48073 .74736 .47954 .7456 .47735 Mtetra
.7456 .47735 .74736 .47954 .75126 .47835 .74951 .47616 Mtetra
.74951 .47616 .75126 .47835 .75517 .47717 .75343 .47497 Mtetra
.75343 .47497 .75517 .47717 .75909 .47598 .75735 .47378 Mtetra
.75735 .47378 .75909 .47598 .76301 .47478 .76127 .47258 Mtetra
.76127 .47258 .76301 .47478 .76694 .47359 .76521 .47138 Mtetra
.76521 .47138 .76694 .47359 .77088 .4724 .76914 .47019 Mtetra
.76914 .47019 .77088 .4724 .77481 .4712 .77309 .46899 Mtetra
.77309 .46899 .77481 .4712 .77876 .47 .77703 .46779 Mtetra
.77703 .46779 .77876 .47 .78271 .4688 .78099 .46658 Mtetra
.78099 .46658 .78271 .4688 .78666 .4676 .78495 .46538 Mtetra
.78495 .46538 .78666 .4676 .79062 .4664 .78891 .46417 Mtetra
.78891 .46417 .79062 .4664 .79459 .46519 .79288 .46297 Mtetra
.79288 .46297 .79459 .46519 .79856 .46399 .79686 .46176 Mtetra
.79686 .46176 .79856 .46399 .80254 .46278 .80084 .46054 Mtetra
.80084 .46054 .80254 .46278 .80652 .46157 .80482 .45933 Mtetra
.80482 .45933 .80652 .46157 .81051 .46036 .80881 .45812 Mtetra
.80881 .45812 .81051 .46036 .8145 .45915 .81281 .4569 Mtetra
.81281 .4569 .8145 .45915 .8185 .45793 .81681 .45568 Mtetra
.81681 .45568 .8185 .45793 .8225 .45671 .82082 .45446 Mtetra
.82082 .45446 .8225 .45671 .82651 .4555 .82484 .45324 Mtetra
.82484 .45324 .82651 .4555 .83053 .45428 .82886 .45202 Mtetra
.82886 .45202 .83053 .45428 .83455 .45306 .83288 .4508 Mtetra
.83288 .4508 .83455 .45306 .83858 .45183 .83691 .44957 Mtetra
.83691 .44957 .83858 .45183 .84261 .45061 .84095 .44834 Mtetra
.84095 .44834 .84261 .45061 .84665 .44938 .84499 .44711 Mtetra
.84499 .44711 .84665 .44938 .85069 .44815 .84904 .44588 Mtetra
.84904 .44588 .85069 .44815 .85474 .44692 .85309 .44465 Mtetra
.85309 .44465 .85474 .44692 .85879 .44569 .85715 .44341 Mtetra
.85715 .44341 .85879 .44569 .86285 .44446 .86121 .44218 Mtetra
.86121 .44218 .86285 .44446 .86692 .44322 .86528 .44094 Mtetra
.86528 .44094 .86692 .44322 .87099 .44199 .86936 .4397 Mtetra
.86936 .4397 .87099 .44199 .87507 .44075 .87344 .43846 Mtetra
.87344 .43846 .87507 .44075 .87915 .43951 .87753 .43721 Mtetra
.87753 .43721 .87915 .43951 .88324 .43827 .88162 .43597 Mtetra
.88162 .43597 .88324 .43827 .88733 .43702 .88572 .43472 Mtetra
.88572 .43472 .88733 .43702 .89143 .43578 .88982 .43347 Mtetra
.88982 .43347 .89143 .43578 .89554 .43453 .89393 .43222 Mtetra
.89393 .43222 .89554 .43453 .89965 .43328 .89805 .43097 Mtetra
.89805 .43097 .89965 .43328 .90377 .43203 .90217 .42972 Mtetra
.90217 .42972 .90377 .43203 .90789 .43078 .9063 .42846 Mtetra
.9063 .42846 .90789 .43078 .91202 .42952 .91043 .4272 Mtetra
.91043 .4272 .91202 .42952 .91616 .42827 .91457 .42594 Mtetra
.91457 .42594 .91616 .42827 .9203 .42701 .91871 .42468 Mtetra
.91871 .42468 .9203 .42701 .92444 .42575 .92286 .42342 Mtetra
.92286 .42342 .92444 .42575 .92859 .42449 .92702 .42216 Mtetra
.92702 .42216 .92859 .42449 .93275 .42323 .93118 .42089 Mtetra
.93118 .42089 .93275 .42323 .93692 .42196 .93535 .41962 Mtetra
.93535 .41962 .93692 .42196 .94109 .42069 .93953 .41835 Mtetra
.93953 .41835 .94109 .42069 .94526 .41943 .94371 .41708 Mtetra
.94371 .41708 .94526 .41943 .94944 .41816 .94789 .41581 Mtetra
.94789 .41581 .94944 .41816 .95363 .41688 .95208 .41453 Mtetra
.95208 .41453 .95363 .41688 .95782 .41561 .95628 .41325 Mtetra
.38461 .58461 .38668 .58654 .39012 .5855 .38805 .58357 Mtetra
.38805 .58357 .39012 .5855 .39356 .58445 .39149 .58252 Mtetra
.39149 .58252 .39356 .58445 .397 .5834 .39494 .58147 Mtetra
.39494 .58147 .397 .5834 .40045 .58236 .39839 .58042 Mtetra
.39839 .58042 .40045 .58236 .4039 .58131 .40184 .57936 Mtetra
.40184 .57936 .4039 .58131 .40736 .58025 .4053 .57831 Mtetra
.4053 .57831 .40736 .58025 .41082 .5792 .40877 .57725 Mtetra
.40877 .57725 .41082 .5792 .41429 .57815 .41223 .5762 Mtetra
.41223 .5762 .41429 .57815 .41776 .57709 .41571 .57514 Mtetra
.41571 .57514 .41776 .57709 .42123 .57603 .41918 .57408 Mtetra
.41918 .57408 .42123 .57603 .42471 .57497 .42267 .57302 Mtetra
.42267 .57302 .42471 .57497 .42819 .57391 .42615 .57195 Mtetra
.42615 .57195 .42819 .57391 .43168 .57285 .42964 .57089 Mtetra
.42964 .57089 .43168 .57285 .43517 .57179 .43314 .56983 Mtetra
.43314 .56983 .43517 .57179 .43867 .57073 .43664 .56876 Mtetra
.43664 .56876 .43867 .57073 .44217 .56966 .44015 .56769 Mtetra
.44015 .56769 .44217 .56966 .44568 .56859 .44365 .56662 Mtetra
.44365 .56662 .44568 .56859 .44919 .56753 .44717 .56555 Mtetra
.44717 .56555 .44919 .56753 .45271 .56646 .45069 .56448 Mtetra
.45069 .56448 .45271 .56646 .45623 .56539 .45421 .56341 Mtetra
.45421 .56341 .45623 .56539 .45975 .56431 .45774 .56233 Mtetra
.45774 .56233 .45975 .56431 .46328 .56324 .46127 .56125 Mtetra
.46127 .56125 .46328 .56324 .46681 .56217 .46481 .56018 Mtetra
.46481 .56018 .46681 .56217 .47035 .56109 .46835 .5591 Mtetra
.46835 .5591 .47035 .56109 .47389 .56001 .47189 .55802 Mtetra
.47189 .55802 .47389 .56001 .47744 .55893 .47544 .55694 Mtetra
.47544 .55694 .47744 .55893 .48099 .55785 .479 .55585 Mtetra
.479 .55585 .48099 .55785 .48455 .55677 .48256 .55477 Mtetra
.48256 .55477 .48455 .55677 .48811 .55569 .48612 .55368 Mtetra
.48612 .55368 .48811 .55569 .49168 .5546 .48969 .55259 Mtetra
.48969 .55259 .49168 .5546 .49525 .55351 .49327 .5515 Mtetra
.49327 .5515 .49525 .55351 .49882 .55243 .49684 .55041 Mtetra
.49684 .55041 .49882 .55243 .5024 .55134 .50043 .54932 Mtetra
.50043 .54932 .5024 .55134 .50599 .55025 .50401 .54823 Mtetra
.50401 .54823 .50599 .55025 .50958 .54915 .50761 .54713 Mtetra
.50761 .54713 .50958 .54915 .51317 .54806 .5112 .54604 Mtetra
.5112 .54604 .51317 .54806 .51677 .54697 .51481 .54494 Mtetra
.51481 .54494 .51677 .54697 .52038 .54587 .51841 .54384 Mtetra
.51841 .54384 .52038 .54587 .52398 .54477 .52202 .54274 Mtetra
.52202 .54274 .52398 .54477 .5276 .54367 .52564 .54164 Mtetra
.52564 .54164 .5276 .54367 .53121 .54257 .52926 .54054 Mtetra
.52926 .54054 .53121 .54257 .53484 .54147 .53289 .53943 Mtetra
.53289 .53943 .53484 .54147 .53846 .54037 .53652 .53833 Mtetra
.53652 .53833 .53846 .54037 .5421 .53926 .54015 .53722 Mtetra
.54015 .53722 .5421 .53926 .54573 .53815 .54379 .53611 Mtetra
.54379 .53611 .54573 .53815 .54938 .53705 .54744 .535 Mtetra
.876 .445 .048 r
.54744 .535 .54938 .53705 .5531 .54503 .55116 .54298 Mtetra
.663 .742 .909 r
.55116 .54298 .5531 .54503 .55676 .54392 .55482 .54187 Mtetra
.55482 .54187 .55676 .54392 .56043 .54281 .55849 .54076 Mtetra
.55849 .54076 .56043 .54281 .5641 .5417 .56217 .53964 Mtetra
.56217 .53964 .5641 .5417 .56777 .54059 .56585 .53853 Mtetra
.56585 .53853 .56777 .54059 .57145 .53947 .56953 .53741 Mtetra
.56953 .53741 .57145 .53947 .57514 .53836 .57322 .53629 Mtetra
.57322 .53629 .57514 .53836 .57883 .53724 .57691 .53518 Mtetra
.57691 .53518 .57883 .53724 .58253 .53612 .58061 .53405 Mtetra
.58061 .53405 .58253 .53612 .58623 .535 .58432 .53293 Mtetra
.58432 .53293 .58623 .535 .58993 .53388 .58802 .53181 Mtetra
.58802 .53181 .58993 .53388 .59364 .53276 .59174 .53068 Mtetra
.59174 .53068 .59364 .53276 .59736 .53164 .59546 .52956 Mtetra
.59546 .52956 .59736 .53164 .60108 .53051 .59918 .52843 Mtetra
.59918 .52843 .60108 .53051 .6048 .52938 .60291 .5273 Mtetra
.60291 .5273 .6048 .52938 .60853 .52825 .60664 .52617 Mtetra
.60664 .52617 .60853 .52825 .61203 .51799 .61038 .52503 Mtetra
0 0 .042 r
.61038 .52503 .61203 .51799 .61576 .51685 .61388 .51475 Mtetra
.664 .741 .908 r
.61388 .51475 .61576 .51685 .61949 .51572 .61762 .51361 Mtetra
.61762 .51361 .61949 .51572 .62323 .51458 .62136 .51247 Mtetra
.62136 .51247 .62323 .51458 .62698 .51344 .62511 .51133 Mtetra
.62511 .51133 .62698 .51344 .63073 .5123 .62886 .51019 Mtetra
.62886 .51019 .63073 .5123 .63448 .51115 .63262 .50904 Mtetra
.63262 .50904 .63448 .51115 .63824 .51001 .63638 .5079 Mtetra
.63638 .5079 .63824 .51001 .64201 .50887 .64015 .50675 Mtetra
.64015 .50675 .64201 .50887 .64578 .50772 .64392 .5056 Mtetra
.64392 .5056 .64578 .50772 .64955 .50657 .6477 .50445 Mtetra
.6477 .50445 .64955 .50657 .65333 .50542 .65149 .50329 Mtetra
.65149 .50329 .65333 .50542 .65712 .50427 .65528 .50214 Mtetra
.65528 .50214 .65712 .50427 .66091 .50312 .65907 .50098 Mtetra
.65907 .50098 .66091 .50312 .6647 .50196 .66287 .49983 Mtetra
.66287 .49983 .6647 .50196 .6685 .5008 .66667 .49867 Mtetra
.66667 .49867 .6685 .5008 .67231 .49965 .67048 .49751 Mtetra
.67048 .49751 .67231 .49965 .67612 .49849 .67429 .49634 Mtetra
.67429 .49634 .67612 .49849 .67993 .49733 .67811 .49518 Mtetra
.67811 .49518 .67993 .49733 .68376 .49616 .68194 .49401 Mtetra
.68194 .49401 .68376 .49616 .68758 .495 .68577 .49285 Mtetra
.68577 .49285 .68758 .495 .69141 .49383 .6896 .49168 Mtetra
.6896 .49168 .69141 .49383 .69525 .49267 .69344 .49051 Mtetra
.69344 .49051 .69525 .49267 .69909 .4915 .69729 .48934 Mtetra
.69729 .48934 .69909 .4915 .70294 .49033 .70114 .48816 Mtetra
.70114 .48816 .70294 .49033 .70679 .48916 .70499 .48699 Mtetra
.70499 .48699 .70679 .48916 .71065 .48798 .70886 .48581 Mtetra
.70886 .48581 .71065 .48798 .71451 .48681 .71272 .48463 Mtetra
.71272 .48463 .71451 .48681 .71838 .48563 .71659 .48345 Mtetra
.71659 .48345 .71838 .48563 .72225 .48445 .72047 .48227 Mtetra
.72047 .48227 .72225 .48445 .72613 .48327 .72435 .48109 Mtetra
.72435 .48109 .72613 .48327 .73001 .48209 .72824 .47991 Mtetra
.72824 .47991 .73001 .48209 .7339 .48091 .73213 .47872 Mtetra
.73213 .47872 .7339 .48091 .7378 .47972 .73603 .47753 Mtetra
.73603 .47753 .7378 .47972 .7417 .47854 .73993 .47634 Mtetra
.73993 .47634 .7417 .47854 .7456 .47735 .74384 .47515 Mtetra
.74384 .47515 .7456 .47735 .74951 .47616 .74776 .47396 Mtetra
.74776 .47396 .74951 .47616 .75343 .47497 .75168 .47276 Mtetra
.75168 .47276 .75343 .47497 .75735 .47378 .7556 .47157 Mtetra
.7556 .47157 .75735 .47378 .76127 .47258 .75953 .47037 Mtetra
.75953 .47037 .76127 .47258 .76521 .47138 .76347 .46917 Mtetra
.76347 .46917 .76521 .47138 .76914 .47019 .76741 .46797 Mtetra
.76741 .46797 .76914 .47019 .77309 .46899 .77135 .46677 Mtetra
.77135 .46677 .77309 .46899 .77703 .46779 .77531 .46556 Mtetra
.77531 .46556 .77703 .46779 .78099 .46658 .77926 .46436 Mtetra
.77926 .46436 .78099 .46658 .78495 .46538 .78323 .46315 Mtetra
.78323 .46315 .78495 .46538 .78891 .46417 .78719 .46194 Mtetra
.78719 .46194 .78891 .46417 .79288 .46297 .79117 .46073 Mtetra
.79117 .46073 .79288 .46297 .79686 .46176 .79515 .45952 Mtetra
.79515 .45952 .79686 .46176 .80084 .46054 .79913 .4583 Mtetra
.79913 .4583 .80084 .46054 .80482 .45933 .80312 .45709 Mtetra
.80312 .45709 .80482 .45933 .80881 .45812 .80712 .45587 Mtetra
.80712 .45587 .80881 .45812 .81281 .4569 .81112 .45465 Mtetra
.81112 .45465 .81281 .4569 .81681 .45568 .81512 .45343 Mtetra
.81512 .45343 .81681 .45568 .82082 .45446 .81914 .45221 Mtetra
.81914 .45221 .82082 .45446 .82484 .45324 .82315 .45098 Mtetra
.82315 .45098 .82484 .45324 .82886 .45202 .82718 .44976 Mtetra
.82718 .44976 .82886 .45202 .83288 .4508 .83121 .44853 Mtetra
.83121 .44853 .83288 .4508 .83691 .44957 .83524 .4473 Mtetra
.83524 .4473 .83691 .44957 .84095 .44834 .83928 .44607 Mtetra
.83928 .44607 .84095 .44834 .84499 .44711 .84333 .44484 Mtetra
.84333 .44484 .84499 .44711 .84904 .44588 .84738 .4436 Mtetra
.84738 .4436 .84904 .44588 .85309 .44465 .85144 .44237 Mtetra
.85144 .44237 .85309 .44465 .85715 .44341 .8555 .44113 Mtetra
.8555 .44113 .85715 .44341 .86121 .44218 .85957 .43989 Mtetra
.85957 .43989 .86121 .44218 .86528 .44094 .86364 .43865 Mtetra
.86364 .43865 .86528 .44094 .86936 .4397 .86772 .4374 Mtetra
.86772 .4374 .86936 .4397 .87344 .43846 .87181 .43616 Mtetra
.87181 .43616 .87344 .43846 .87753 .43721 .8759 .43491 Mtetra
.8759 .43491 .87753 .43721 .88162 .43597 .87999 .43366 Mtetra
.87999 .43366 .88162 .43597 .88572 .43472 .8841 .43241 Mtetra
.8841 .43241 .88572 .43472 .88982 .43347 .88821 .43116 Mtetra
.88821 .43116 .88982 .43347 .89393 .43222 .89232 .42991 Mtetra
.89232 .42991 .89393 .43222 .89805 .43097 .89644 .42865 Mtetra
.89644 .42865 .89805 .43097 .90217 .42972 .90057 .4274 Mtetra
.90057 .4274 .90217 .42972 .9063 .42846 .9047 .42614 Mtetra
.9047 .42614 .9063 .42846 .91043 .4272 .90883 .42488 Mtetra
.90883 .42488 .91043 .4272 .91457 .42594 .91298 .42361 Mtetra
.91298 .42361 .91457 .42594 .91871 .42468 .91713 .42235 Mtetra
.91713 .42235 .91871 .42468 .92286 .42342 .92128 .42108 Mtetra
.92128 .42108 .92286 .42342 .92702 .42216 .92544 .41982 Mtetra
.92544 .41982 .92702 .42216 .93118 .42089 .92961 .41855 Mtetra
.92961 .41855 .93118 .42089 .93535 .41962 .93378 .41728 Mtetra
.93378 .41728 .93535 .41962 .93953 .41835 .93796 .416 Mtetra
.93796 .416 .93953 .41835 .94371 .41708 .94214 .41473 Mtetra
.94214 .41473 .94371 .41708 .94789 .41581 .94633 .41345 Mtetra
.94633 .41345 .94789 .41581 .95208 .41453 .95053 .41217 Mtetra
.95053 .41217 .95208 .41453 .95628 .41325 .95473 .41089 Mtetra
.38253 .58268 .38461 .58461 .38805 .58357 .38597 .58163 Mtetra
.38597 .58163 .38805 .58357 .39149 .58252 .38942 .58058 Mtetra
.38942 .58058 .39149 .58252 .39494 .58147 .39287 .57952 Mtetra
.39287 .57952 .39494 .58147 .39839 .58042 .39632 .57847 Mtetra
.39632 .57847 .39839 .58042 .40184 .57936 .39978 .57742 Mtetra
.39978 .57742 .40184 .57936 .4053 .57831 .40324 .57636 Mtetra
.40324 .57636 .4053 .57831 .40877 .57725 .40671 .5753 Mtetra
.40671 .5753 .40877 .57725 .41223 .5762 .41018 .57424 Mtetra
.41018 .57424 .41223 .5762 .41571 .57514 .41365 .57318 Mtetra
.41365 .57318 .41571 .57514 .41918 .57408 .41713 .57212 Mtetra
.41713 .57212 .41918 .57408 .42267 .57302 .42062 .57105 Mtetra
.42062 .57105 .42267 .57302 .42615 .57195 .42411 .56999 Mtetra
.42411 .56999 .42615 .57195 .42964 .57089 .4276 .56892 Mtetra
.4276 .56892 .42964 .57089 .43314 .56983 .4311 .56786 Mtetra
.4311 .56786 .43314 .56983 .43664 .56876 .4346 .56679 Mtetra
.4346 .56679 .43664 .56876 .44015 .56769 .43811 .56572 Mtetra
.43811 .56572 .44015 .56769 .44365 .56662 .44162 .56464 Mtetra
.44162 .56464 .44365 .56662 .44717 .56555 .44514 .56357 Mtetra
.44514 .56357 .44717 .56555 .45069 .56448 .44866 .5625 Mtetra
.44866 .5625 .45069 .56448 .45421 .56341 .45219 .56142 Mtetra
.45219 .56142 .45421 .56341 .45774 .56233 .45572 .56034 Mtetra
.45572 .56034 .45774 .56233 .46127 .56125 .45925 .55926 Mtetra
.45925 .55926 .46127 .56125 .46481 .56018 .46279 .55818 Mtetra
.46279 .55818 .46481 .56018 .46835 .5591 .46634 .5571 Mtetra
.46634 .5571 .46835 .5591 .47189 .55802 .46989 .55602 Mtetra
.46989 .55602 .47189 .55802 .47544 .55694 .47344 .55493 Mtetra
.47344 .55493 .47544 .55694 .479 .55585 .477 .55385 Mtetra
.477 .55385 .479 .55585 .48256 .55477 .48056 .55276 Mtetra
.48056 .55276 .48256 .55477 .48612 .55368 .48413 .55167 Mtetra
.48413 .55167 .48612 .55368 .48969 .55259 .4877 .55058 Mtetra
.4877 .55058 .48969 .55259 .49327 .5515 .49128 .54949 Mtetra
.49128 .54949 .49327 .5515 .49684 .55041 .49486 .5484 Mtetra
.49486 .5484 .49684 .55041 .50043 .54932 .49844 .5473 Mtetra
.49844 .5473 .50043 .54932 .50401 .54823 .50203 .54621 Mtetra
.50203 .54621 .50401 .54823 .50761 .54713 .50563 .54511 Mtetra
.50563 .54511 .50761 .54713 .5112 .54604 .50923 .54401 Mtetra
.50923 .54401 .5112 .54604 .51481 .54494 .51284 .54291 Mtetra
.51284 .54291 .51481 .54494 .51841 .54384 .51645 .54181 Mtetra
.51645 .54181 .51841 .54384 .52202 .54274 .52006 .54071 Mtetra
.52006 .54071 .52202 .54274 .52564 .54164 .52368 .5396 Mtetra
.52368 .5396 .52564 .54164 .52926 .54054 .5273 .5385 Mtetra
.5273 .5385 .52926 .54054 .53289 .53943 .53093 .53739 Mtetra
.53093 .53739 .53289 .53943 .53652 .53833 .53457 .53628 Mtetra
.53457 .53628 .53652 .53833 .54015 .53722 .5382 .53517 Mtetra
.5382 .53517 .54015 .53722 .54379 .53611 .54185 .53406 Mtetra
.54185 .53406 .54379 .53611 .54744 .535 .5455 .53294 Mtetra
.876 .445 .048 r
.5455 .53294 .54744 .535 .55116 .54298 .54921 .54093 Mtetra
.663 .742 .909 r
.54921 .54093 .55116 .54298 .55482 .54187 .55288 .53982 Mtetra
.55288 .53982 .55482 .54187 .55849 .54076 .55655 .5387 Mtetra
.55655 .5387 .55849 .54076 .56217 .53964 .56023 .53758 Mtetra
.56023 .53758 .56217 .53964 .56585 .53853 .56391 .53647 Mtetra
.56391 .53647 .56585 .53853 .56953 .53741 .5676 .53535 Mtetra
.5676 .53535 .56953 .53741 .57322 .53629 .57129 .53423 Mtetra
.57129 .53423 .57322 .53629 .57691 .53518 .57499 .5331 Mtetra
.57499 .5331 .57691 .53518 .58061 .53405 .57869 .53198 Mtetra
.57869 .53198 .58061 .53405 .58432 .53293 .5824 .53086 Mtetra
.5824 .53086 .58432 .53293 .58802 .53181 .58611 .52973 Mtetra
.58611 .52973 .58802 .53181 .59174 .53068 .58983 .5286 Mtetra
.58983 .5286 .59174 .53068 .59546 .52956 .59355 .52747 Mtetra
.59355 .52747 .59546 .52956 .59918 .52843 .59728 .52634 Mtetra
.59728 .52634 .59918 .52843 .60291 .5273 .60101 .52521 Mtetra
.60101 .52521 .60291 .5273 .60664 .52617 .60475 .52407 Mtetra
.60475 .52407 .60664 .52617 .61038 .52503 .60849 .52294 Mtetra
.919 .756 .663 r
.60849 .52294 .61038 .52503 .61388 .51475 .612 .51265 Mtetra
.664 .741 .908 r
.612 .51265 .61388 .51475 .61762 .51361 .61574 .51151 Mtetra
.61574 .51151 .61762 .51361 .62136 .51247 .61948 .51036 Mtetra
.61948 .51036 .62136 .51247 .62511 .51133 .62323 .50922 Mtetra
.62323 .50922 .62511 .51133 .62886 .51019 .62699 .50807 Mtetra
.62699 .50807 .62886 .51019 .63262 .50904 .63075 .50692 Mtetra
.63075 .50692 .63262 .50904 .63638 .5079 .63452 .50577 Mtetra
.63452 .50577 .63638 .5079 .64015 .50675 .63829 .50462 Mtetra
.63829 .50462 .64015 .50675 .64392 .5056 .64207 .50347 Mtetra
.64207 .50347 .64392 .5056 .6477 .50445 .64585 .50232 Mtetra
.64585 .50232 .6477 .50445 .65149 .50329 .64964 .50116 Mtetra
.64964 .50116 .65149 .50329 .65528 .50214 .65343 .5 Mtetra
.65343 .5 .65528 .50214 .65907 .50098 .65723 .49884 Mtetra
.65723 .49884 .65907 .50098 .66287 .49983 .66103 .49768 Mtetra
.66103 .49768 .66287 .49983 .66667 .49867 .66484 .49652 Mtetra
.66484 .49652 .66667 .49867 .67048 .49751 .66865 .49536 Mtetra
.66865 .49536 .67048 .49751 .67429 .49634 .67247 .49419 Mtetra
.67247 .49419 .67429 .49634 .67811 .49518 .67629 .49303 Mtetra
.67629 .49303 .67811 .49518 .68194 .49401 .68012 .49186 Mtetra
.68012 .49186 .68194 .49401 .68577 .49285 .68395 .49069 Mtetra
.68395 .49069 .68577 .49285 .6896 .49168 .68779 .48952 Mtetra
.68779 .48952 .6896 .49168 .69344 .49051 .69163 .48834 Mtetra
.69163 .48834 .69344 .49051 .69729 .48934 .69548 .48717 Mtetra
.69548 .48717 .69729 .48934 .70114 .48816 .69934 .48599 Mtetra
.69934 .48599 .70114 .48816 .70499 .48699 .70319 .48482 Mtetra
.70319 .48482 .70499 .48699 .70886 .48581 .70706 .48364 Mtetra
.70706 .48364 .70886 .48581 .71272 .48463 .71093 .48245 Mtetra
.71093 .48245 .71272 .48463 .71659 .48345 .7148 .48127 Mtetra
.7148 .48127 .71659 .48345 .72047 .48227 .71868 .48009 Mtetra
.71868 .48009 .72047 .48227 .72435 .48109 .72257 .4789 Mtetra
.72257 .4789 .72435 .48109 .72824 .47991 .72646 .47771 Mtetra
.72646 .47771 .72824 .47991 .73213 .47872 .73036 .47653 Mtetra
.73036 .47653 .73213 .47872 .73603 .47753 .73426 .47533 Mtetra
.73426 .47533 .73603 .47753 .73993 .47634 .73817 .47414 Mtetra
.73817 .47414 .73993 .47634 .74384 .47515 .74208 .47295 Mtetra
.74208 .47295 .74384 .47515 .74776 .47396 .746 .47175 Mtetra
.746 .47175 .74776 .47396 .75168 .47276 .74992 .47056 Mtetra
.74992 .47056 .75168 .47276 .7556 .47157 .75385 .46936 Mtetra
.75385 .46936 .7556 .47157 .75953 .47037 .75778 .46816 Mtetra
.75778 .46816 .75953 .47037 .76347 .46917 .76172 .46695 Mtetra
.76172 .46695 .76347 .46917 .76741 .46797 .76567 .46575 Mtetra
.76567 .46575 .76741 .46797 .77135 .46677 .76962 .46454 Mtetra
.76962 .46454 .77135 .46677 .77531 .46556 .77357 .46334 Mtetra
.77357 .46334 .77531 .46556 .77926 .46436 .77753 .46213 Mtetra
.77753 .46213 .77926 .46436 .78323 .46315 .7815 .46092 Mtetra
.7815 .46092 .78323 .46315 .78719 .46194 .78547 .45971 Mtetra
.78547 .45971 .78719 .46194 .79117 .46073 .78945 .45849 Mtetra
.78945 .45849 .79117 .46073 .79515 .45952 .79343 .45728 Mtetra
.79343 .45728 .79515 .45952 .79913 .4583 .79742 .45606 Mtetra
.79742 .45606 .79913 .4583 .80312 .45709 .80142 .45484 Mtetra
.80142 .45484 .80312 .45709 .80712 .45587 .80541 .45362 Mtetra
.80541 .45362 .80712 .45587 .81112 .45465 .80942 .4524 Mtetra
.80942 .4524 .81112 .45465 .81512 .45343 .81343 .45117 Mtetra
.81343 .45117 .81512 .45343 .81914 .45221 .81745 .44995 Mtetra
.81745 .44995 .81914 .45221 .82315 .45098 .82147 .44872 Mtetra
.82147 .44872 .82315 .45098 .82718 .44976 .8255 .44749 Mtetra
.8255 .44749 .82718 .44976 .83121 .44853 .82953 .44626 Mtetra
.82953 .44626 .83121 .44853 .83524 .4473 .83357 .44503 Mtetra
.83357 .44503 .83524 .4473 .83928 .44607 .83761 .44379 Mtetra
.83761 .44379 .83928 .44607 .84333 .44484 .84166 .44256 Mtetra
.84166 .44256 .84333 .44484 .84738 .4436 .84572 .44132 Mtetra
.84572 .44132 .84738 .4436 .85144 .44237 .84978 .44008 Mtetra
.84978 .44008 .85144 .44237 .8555 .44113 .85384 .43884 Mtetra
.85384 .43884 .8555 .44113 .85957 .43989 .85792 .4376 Mtetra
.85792 .4376 .85957 .43989 .86364 .43865 .862 .43635 Mtetra
.862 .43635 .86364 .43865 .86772 .4374 .86608 .4351 Mtetra
.86608 .4351 .86772 .4374 .87181 .43616 .87017 .43386 Mtetra
.87017 .43386 .87181 .43616 .8759 .43491 .87426 .43261 Mtetra
.87426 .43261 .8759 .43491 .87999 .43366 .87837 .43136 Mtetra
.87837 .43136 .87999 .43366 .8841 .43241 .88247 .4301 Mtetra
.88247 .4301 .8841 .43241 .88821 .43116 .88658 .42885 Mtetra
.88658 .42885 .88821 .43116 .89232 .42991 .8907 .42759 Mtetra
.8907 .42759 .89232 .42991 .89644 .42865 .89483 .42633 Mtetra
.89483 .42633 .89644 .42865 .90057 .4274 .89896 .42507 Mtetra
.89896 .42507 .90057 .4274 .9047 .42614 .90309 .42381 Mtetra
.90309 .42381 .9047 .42614 .90883 .42488 .90723 .42254 Mtetra
.90723 .42254 .90883 .42488 .91298 .42361 .91138 .42128 Mtetra
.91138 .42128 .91298 .42361 .91713 .42235 .91554 .42001 Mtetra
.91554 .42001 .91713 .42235 .92128 .42108 .91969 .41874 Mtetra
.91969 .41874 .92128 .42108 .92544 .41982 .92386 .41747 Mtetra
.92386 .41747 .92544 .41982 .92961 .41855 .92803 .4162 Mtetra
.92803 .4162 .92961 .41855 .93378 .41728 .93221 .41492 Mtetra
.93221 .41492 .93378 .41728 .93796 .416 .93639 .41365 Mtetra
.93639 .41365 .93796 .416 .94214 .41473 .94058 .41237 Mtetra
.94058 .41237 .94214 .41473 .94633 .41345 .94477 .41109 Mtetra
.94477 .41109 .94633 .41345 .95053 .41217 .94897 .40981 Mtetra
.94897 .40981 .95053 .41217 .95473 .41089 .95318 .40852 Mtetra
.38045 .58074 .38253 .58268 .38597 .58163 .38389 .57969 Mtetra
.38389 .57969 .38597 .58163 .38942 .58058 .38734 .57863 Mtetra
.38734 .57863 .38942 .58058 .39287 .57952 .39079 .57758 Mtetra
.39079 .57758 .39287 .57952 .39632 .57847 .39425 .57652 Mtetra
.39425 .57652 .39632 .57847 .39978 .57742 .39771 .57546 Mtetra
.39771 .57546 .39978 .57742 .40324 .57636 .40117 .5744 Mtetra
.40117 .5744 .40324 .57636 .40671 .5753 .40464 .57334 Mtetra
.40464 .57334 .40671 .5753 .41018 .57424 .40812 .57228 Mtetra
.40812 .57228 .41018 .57424 .41365 .57318 .4116 .57122 Mtetra
.4116 .57122 .41365 .57318 .41713 .57212 .41508 .57015 Mtetra
.41508 .57015 .41713 .57212 .42062 .57105 .41857 .56909 Mtetra
.41857 .56909 .42062 .57105 .42411 .56999 .42206 .56802 Mtetra
.42206 .56802 .42411 .56999 .4276 .56892 .42556 .56695 Mtetra
.42556 .56695 .4276 .56892 .4311 .56786 .42906 .56588 Mtetra
.42906 .56588 .4311 .56786 .4346 .56679 .43256 .56481 Mtetra
.43256 .56481 .4346 .56679 .43811 .56572 .43607 .56374 Mtetra
.43607 .56374 .43811 .56572 .44162 .56464 .43959 .56266 Mtetra
.43959 .56266 .44162 .56464 .44514 .56357 .44311 .56159 Mtetra
.44311 .56159 .44514 .56357 .44866 .5625 .44663 .56051 Mtetra
.44663 .56051 .44866 .5625 .45219 .56142 .45016 .55943 Mtetra
.45016 .55943 .45219 .56142 .45572 .56034 .45369 .55835 Mtetra
.45369 .55835 .45572 .56034 .45925 .55926 .45723 .55727 Mtetra
.45723 .55727 .45925 .55926 .46279 .55818 .46078 .55619 Mtetra
.46078 .55619 .46279 .55818 .46634 .5571 .46432 .5551 Mtetra
.46432 .5551 .46634 .5571 .46989 .55602 .46787 .55402 Mtetra
.46787 .55402 .46989 .55602 .47344 .55493 .47143 .55293 Mtetra
.47143 .55293 .47344 .55493 .477 .55385 .47499 .55184 Mtetra
.47499 .55184 .477 .55385 .48056 .55276 .47856 .55075 Mtetra
.47856 .55075 .48056 .55276 .48413 .55167 .48213 .54966 Mtetra
.48213 .54966 .48413 .55167 .4877 .55058 .4857 .54857 Mtetra
.4857 .54857 .4877 .55058 .49128 .54949 .48928 .54747 Mtetra
.48928 .54747 .49128 .54949 .49486 .5484 .49287 .54638 Mtetra
.49287 .54638 .49486 .5484 .49844 .5473 .49646 .54528 Mtetra
.49646 .54528 .49844 .5473 .50203 .54621 .50005 .54418 Mtetra
.50005 .54418 .50203 .54621 .50563 .54511 .50365 .54308 Mtetra
.50365 .54308 .50563 .54511 .50923 .54401 .50725 .54198 Mtetra
.50725 .54198 .50923 .54401 .51284 .54291 .51086 .54088 Mtetra
.51086 .54088 .51284 .54291 .51645 .54181 .51447 .53977 Mtetra
.51447 .53977 .51645 .54181 .52006 .54071 .51809 .53867 Mtetra
.51809 .53867 .52006 .54071 .52368 .5396 .52171 .53756 Mtetra
.52171 .53756 .52368 .5396 .5273 .5385 .52534 .53645 Mtetra
.52534 .53645 .5273 .5385 .53093 .53739 .52897 .53534 Mtetra
.52897 .53534 .53093 .53739 .53457 .53628 .53261 .53423 Mtetra
.53261 .53423 .53457 .53628 .5382 .53517 .53625 .53311 Mtetra
.53625 .53311 .5382 .53517 .54185 .53406 .5399 .532 Mtetra
.877 .447 .051 r
.5399 .532 .54185 .53406 .5455 .53294 .5436 .53999 Mtetra
.487 .183 .376 r
.5436 .53999 .5455 .53294 .54921 .54093 .54727 .53887 Mtetra
.663 .742 .909 r
.54727 .53887 .54921 .54093 .55288 .53982 .55094 .53776 Mtetra
.55094 .53776 .55288 .53982 .55655 .5387 .55461 .53664 Mtetra
.55461 .53664 .55655 .5387 .56023 .53758 .55829 .53552 Mtetra
.55829 .53552 .56023 .53758 .56391 .53647 .56198 .5344 Mtetra
.56198 .5344 .56391 .53647 .5676 .53535 .56567 .53328 Mtetra
.56567 .53328 .5676 .53535 .57129 .53423 .56936 .53215 Mtetra
.56936 .53215 .57129 .53423 .57499 .5331 .57306 .53103 Mtetra
.57306 .53103 .57499 .5331 .57869 .53198 .57677 .5299 Mtetra
.57677 .5299 .57869 .53198 .5824 .53086 .58048 .52877 Mtetra
.58048 .52877 .5824 .53086 .58611 .52973 .5842 .52765 Mtetra
.5842 .52765 .58611 .52973 .58983 .5286 .58792 .52651 Mtetra
.58792 .52651 .58983 .5286 .59355 .52747 .59164 .52538 Mtetra
.59164 .52538 .59355 .52747 .59728 .52634 .59537 .52425 Mtetra
.59537 .52425 .59728 .52634 .60101 .52521 .59911 .52311 Mtetra
.59911 .52311 .60101 .52521 .60475 .52407 .60285 .52198 Mtetra
.60285 .52198 .60475 .52407 .60849 .52294 .60659 .52084 Mtetra
.60659 .52084 .60849 .52294 .612 .51265 .61034 .5197 Mtetra
0 0 .039 r
.61034 .5197 .612 .51265 .61574 .51151 .61385 .50939 Mtetra
.664 .741 .908 r
.61385 .50939 .61574 .51151 .61948 .51036 .6176 .50825 Mtetra
.6176 .50825 .61948 .51036 .62323 .50922 .62136 .5071 Mtetra
.62136 .5071 .62323 .50922 .62699 .50807 .62512 .50595 Mtetra
.62512 .50595 .62699 .50807 .63075 .50692 .62888 .5048 Mtetra
.62888 .5048 .63075 .50692 .63452 .50577 .63265 .50365 Mtetra
.63265 .50365 .63452 .50577 .63829 .50462 .63643 .50249 Mtetra
.63643 .50249 .63829 .50462 .64207 .50347 .64021 .50134 Mtetra
.64021 .50134 .64207 .50347 .64585 .50232 .64399 .50018 Mtetra
.64399 .50018 .64585 .50232 .64964 .50116 .64778 .49902 Mtetra
.64778 .49902 .64964 .50116 .65343 .5 .65158 .49786 Mtetra
.65158 .49786 .65343 .5 .65723 .49884 .65538 .4967 Mtetra
.65538 .4967 .65723 .49884 .66103 .49768 .65918 .49554 Mtetra
.65918 .49554 .66103 .49768 .66484 .49652 .663 .49437 Mtetra
.663 .49437 .66484 .49652 .66865 .49536 .66681 .49321 Mtetra
.66681 .49321 .66865 .49536 .67247 .49419 .67063 .49204 Mtetra
.67063 .49204 .67247 .49419 .67629 .49303 .67446 .49087 Mtetra
.67446 .49087 .67629 .49303 .68012 .49186 .67829 .4897 Mtetra
.67829 .4897 .68012 .49186 .68395 .49069 .68213 .48852 Mtetra
.68213 .48852 .68395 .49069 .68779 .48952 .68597 .48735 Mtetra
.68597 .48735 .68779 .48952 .69163 .48834 .68982 .48617 Mtetra
.68982 .48617 .69163 .48834 .69548 .48717 .69367 .485 Mtetra
.69367 .485 .69548 .48717 .69934 .48599 .69753 .48382 Mtetra
.69753 .48382 .69934 .48599 .70319 .48482 .70139 .48264 Mtetra
.70139 .48264 .70319 .48482 .70706 .48364 .70526 .48145 Mtetra
.70526 .48145 .70706 .48364 .71093 .48245 .70913 .48027 Mtetra
.70913 .48027 .71093 .48245 .7148 .48127 .71301 .47908 Mtetra
.71301 .47908 .7148 .48127 .71868 .48009 .71689 .4779 Mtetra
.71689 .4779 .71868 .48009 .72257 .4789 .72078 .47671 Mtetra
.72078 .47671 .72257 .4789 .72646 .47771 .72468 .47552 Mtetra
.72468 .47552 .72646 .47771 .73036 .47653 .72858 .47433 Mtetra
.72858 .47433 .73036 .47653 .73426 .47533 .73248 .47313 Mtetra
.73248 .47313 .73426 .47533 .73817 .47414 .7364 .47194 Mtetra
.7364 .47194 .73817 .47414 .74208 .47295 .74031 .47074 Mtetra
.74031 .47074 .74208 .47295 .746 .47175 .74423 .46954 Mtetra
.74423 .46954 .746 .47175 .74992 .47056 .74816 .46834 Mtetra
.74816 .46834 .74992 .47056 .75385 .46936 .75209 .46714 Mtetra
.75209 .46714 .75385 .46936 .75778 .46816 .75603 .46593 Mtetra
.75603 .46593 .75778 .46816 .76172 .46695 .75997 .46473 Mtetra
.75997 .46473 .76172 .46695 .76567 .46575 .76392 .46352 Mtetra
.76392 .46352 .76567 .46575 .76962 .46454 .76788 .46231 Mtetra
.76788 .46231 .76962 .46454 .77357 .46334 .77184 .4611 Mtetra
.77184 .4611 .77357 .46334 .77753 .46213 .7758 .45989 Mtetra
.7758 .45989 .77753 .46213 .7815 .46092 .77977 .45868 Mtetra
.77977 .45868 .7815 .46092 .78547 .45971 .78375 .45746 Mtetra
.78375 .45746 .78547 .45971 .78945 .45849 .78773 .45625 Mtetra
.78773 .45625 .78945 .45849 .79343 .45728 .79171 .45503 Mtetra
.79171 .45503 .79343 .45728 .79742 .45606 .79571 .45381 Mtetra
.79571 .45381 .79742 .45606 .80142 .45484 .7997 .45258 Mtetra
.7997 .45258 .80142 .45484 .80541 .45362 .80371 .45136 Mtetra
.80371 .45136 .80541 .45362 .80942 .4524 .80772 .45014 Mtetra
.80772 .45014 .80942 .4524 .81343 .45117 .81173 .44891 Mtetra
.81173 .44891 .81343 .45117 .81745 .44995 .81575 .44768 Mtetra
.81575 .44768 .81745 .44995 .82147 .44872 .81978 .44645 Mtetra
.81978 .44645 .82147 .44872 .8255 .44749 .82381 .44522 Mtetra
.82381 .44522 .8255 .44749 .82953 .44626 .82785 .44398 Mtetra
.82785 .44398 .82953 .44626 .83357 .44503 .83189 .44275 Mtetra
.83189 .44275 .83357 .44503 .83761 .44379 .83594 .44151 Mtetra
.83594 .44151 .83761 .44379 .84166 .44256 .83999 .44027 Mtetra
.83999 .44027 .84166 .44256 .84572 .44132 .84405 .43903 Mtetra
.84405 .43903 .84572 .44132 .84978 .44008 .84812 .43779 Mtetra
.84812 .43779 .84978 .44008 .85384 .43884 .85219 .43654 Mtetra
.85219 .43654 .85384 .43884 .85792 .4376 .85626 .4353 Mtetra
.85626 .4353 .85792 .4376 .862 .43635 .86035 .43405 Mtetra
.86035 .43405 .862 .43635 .86608 .4351 .86443 .4328 Mtetra
.86443 .4328 .86608 .4351 .87017 .43386 .86853 .43155 Mtetra
.86853 .43155 .87017 .43386 .87426 .43261 .87263 .43029 Mtetra
.87263 .43029 .87426 .43261 .87837 .43136 .87673 .42904 Mtetra
.87673 .42904 .87837 .43136 .88247 .4301 .88084 .42778 Mtetra
.88084 .42778 .88247 .4301 .88658 .42885 .88496 .42652 Mtetra
.88496 .42652 .88658 .42885 .8907 .42759 .88908 .42526 Mtetra
.88908 .42526 .8907 .42759 .89483 .42633 .89321 .424 Mtetra
.89321 .424 .89483 .42633 .89896 .42507 .89734 .42274 Mtetra
.89734 .42274 .89896 .42507 .90309 .42381 .90148 .42147 Mtetra
.90148 .42147 .90309 .42381 .90723 .42254 .90563 .42021 Mtetra
.90563 .42021 .90723 .42254 .91138 .42128 .90978 .41894 Mtetra
.90978 .41894 .91138 .42128 .91554 .42001 .91394 .41767 Mtetra
.91394 .41767 .91554 .42001 .91969 .41874 .9181 .41639 Mtetra
.9181 .41639 .91969 .41874 .92386 .41747 .92227 .41512 Mtetra
.92227 .41512 .92386 .41747 .92803 .4162 .92645 .41384 Mtetra
.92645 .41384 .92803 .4162 .93221 .41492 .93063 .41257 Mtetra
.93063 .41257 .93221 .41492 .93639 .41365 .93482 .41129 Mtetra
.93482 .41129 .93639 .41365 .94058 .41237 .93901 .41 Mtetra
.93901 .41 .94058 .41237 .94477 .41109 .94321 .40872 Mtetra
.94321 .40872 .94477 .41109 .94897 .40981 .94741 .40743 Mtetra
.94741 .40743 .94897 .40981 .95318 .40852 .95162 .40615 Mtetra
.37836 .57879 .38045 .58074 .38389 .57969 .38181 .57774 Mtetra
.38181 .57774 .38389 .57969 .38734 .57863 .38526 .57668 Mtetra
.38526 .57668 .38734 .57863 .39079 .57758 .38871 .57563 Mtetra
.38871 .57563 .39079 .57758 .39425 .57652 .39217 .57457 Mtetra
.39217 .57457 .39425 .57652 .39771 .57546 .39563 .57351 Mtetra
.39563 .57351 .39771 .57546 .40117 .5744 .3991 .57244 Mtetra
.3991 .57244 .40117 .5744 .40464 .57334 .40257 .57138 Mtetra
.40257 .57138 .40464 .57334 .40812 .57228 .40605 .57032 Mtetra
.40605 .57032 .40812 .57228 .4116 .57122 .40953 .56925 Mtetra
.40953 .56925 .4116 .57122 .41508 .57015 .41302 .56818 Mtetra
.41302 .56818 .41508 .57015 .41857 .56909 .41651 .56712 Mtetra
.41651 .56712 .41857 .56909 .42206 .56802 .42001 .56605 Mtetra
.42001 .56605 .42206 .56802 .42556 .56695 .4235 .56497 Mtetra
.4235 .56497 .42556 .56695 .42906 .56588 .42701 .5639 Mtetra
.42701 .5639 .42906 .56588 .43256 .56481 .43052 .56283 Mtetra
.43052 .56283 .43256 .56481 .43607 .56374 .43403 .56175 Mtetra
.43403 .56175 .43607 .56374 .43959 .56266 .43755 .56067 Mtetra
.43755 .56067 .43959 .56266 .44311 .56159 .44107 .5596 Mtetra
.44107 .5596 .44311 .56159 .44663 .56051 .4446 .55852 Mtetra
.4446 .55852 .44663 .56051 .45016 .55943 .44813 .55743 Mtetra
.44813 .55743 .45016 .55943 .45369 .55835 .45167 .55635 Mtetra
.45167 .55635 .45369 .55835 .45723 .55727 .45521 .55527 Mtetra
.45521 .55527 .45723 .55727 .46078 .55619 .45875 .55418 Mtetra
.45875 .55418 .46078 .55619 .46432 .5551 .4623 .5531 Mtetra
.4623 .5531 .46432 .5551 .46787 .55402 .46586 .55201 Mtetra
.46586 .55201 .46787 .55402 .47143 .55293 .46942 .55092 Mtetra
.46942 .55092 .47143 .55293 .47499 .55184 .47298 .54983 Mtetra
.47298 .54983 .47499 .55184 .47856 .55075 .47655 .54873 Mtetra
.47655 .54873 .47856 .55075 .48213 .54966 .48012 .54764 Mtetra
.48012 .54764 .48213 .54966 .4857 .54857 .4837 .54654 Mtetra
.4837 .54654 .4857 .54857 .48928 .54747 .48728 .54545 Mtetra
.48728 .54545 .48928 .54747 .49287 .54638 .49087 .54435 Mtetra
.49087 .54435 .49287 .54638 .49646 .54528 .49446 .54325 Mtetra
.49446 .54325 .49646 .54528 .50005 .54418 .49806 .54215 Mtetra
.49806 .54215 .50005 .54418 .50365 .54308 .50166 .54105 Mtetra
.50166 .54105 .50365 .54308 .50725 .54198 .50527 .53994 Mtetra
.50527 .53994 .50725 .54198 .51086 .54088 .50888 .53884 Mtetra
.50888 .53884 .51086 .54088 .51447 .53977 .5125 .53773 Mtetra
.5125 .53773 .51447 .53977 .51809 .53867 .51612 .53662 Mtetra
.51612 .53662 .51809 .53867 .52171 .53756 .51974 .53551 Mtetra
.51974 .53551 .52171 .53756 .52534 .53645 .52337 .5344 Mtetra
.52337 .5344 .52534 .53645 .52897 .53534 .52701 .53329 Mtetra
.52701 .53329 .52897 .53534 .53261 .53423 .53065 .53217 Mtetra
.53065 .53217 .53261 .53423 .53625 .53311 .53429 .53106 Mtetra
.53429 .53106 .53625 .53311 .5399 .532 .53794 .52994 Mtetra
.877 .447 .051 r
.53794 .52994 .5399 .532 .5436 .53999 .54164 .53793 Mtetra
.663 .742 .909 r
.54164 .53793 .5436 .53999 .54727 .53887 .54531 .53681 Mtetra
.54531 .53681 .54727 .53887 .55094 .53776 .54899 .53569 Mtetra
.54899 .53569 .55094 .53776 .55461 .53664 .55266 .53457 Mtetra
.55266 .53457 .55461 .53664 .55829 .53552 .55635 .53345 Mtetra
.55635 .53345 .55829 .53552 .56198 .5344 .56004 .53233 Mtetra
.56004 .53233 .56198 .5344 .56567 .53328 .56373 .5312 Mtetra
.56373 .5312 .56567 .53328 .56936 .53215 .56743 .53008 Mtetra
.56743 .53008 .56936 .53215 .57306 .53103 .57113 .52895 Mtetra
.57113 .52895 .57306 .53103 .57677 .5299 .57484 .52782 Mtetra
.57484 .52782 .57677 .5299 .58048 .52877 .57856 .52669 Mtetra
.57856 .52669 .58048 .52877 .5842 .52765 .58227 .52556 Mtetra
.58227 .52556 .5842 .52765 .58792 .52651 .586 .52442 Mtetra
.586 .52442 .58792 .52651 .59164 .52538 .58973 .52329 Mtetra
.58973 .52329 .59164 .52538 .59537 .52425 .59346 .52215 Mtetra
.59346 .52215 .59537 .52425 .59911 .52311 .5972 .52101 Mtetra
.5972 .52101 .59911 .52311 .60285 .52198 .60094 .51987 Mtetra
.60094 .51987 .60285 .52198 .60659 .52084 .60469 .51873 Mtetra
.60469 .51873 .60659 .52084 .61034 .5197 .60844 .51759 Mtetra
.92 .756 .663 r
.60844 .51759 .61034 .5197 .61385 .50939 .61196 .50728 Mtetra
.664 .741 .908 r
.61196 .50728 .61385 .50939 .6176 .50825 .61572 .50613 Mtetra
.61572 .50613 .6176 .50825 .62136 .5071 .61947 .50498 Mtetra
.61947 .50498 .62136 .5071 .62512 .50595 .62324 .50383 Mtetra
.62324 .50383 .62512 .50595 .62888 .5048 .62701 .50267 Mtetra
.62701 .50267 .62888 .5048 .63265 .50365 .63078 .50152 Mtetra
.63078 .50152 .63265 .50365 .63643 .50249 .63456 .50036 Mtetra
.63456 .50036 .63643 .50249 .64021 .50134 .63834 .4992 Mtetra
.63834 .4992 .64021 .50134 .64399 .50018 .64213 .49804 Mtetra
.64213 .49804 .64399 .50018 .64778 .49902 .64592 .49688 Mtetra
.64592 .49688 .64778 .49902 .65158 .49786 .64972 .49572 Mtetra
.64972 .49572 .65158 .49786 .65538 .4967 .65353 .49455 Mtetra
.65353 .49455 .65538 .4967 .65918 .49554 .65734 .49339 Mtetra
.65734 .49339 .65918 .49554 .663 .49437 .66115 .49222 Mtetra
.66115 .49222 .663 .49437 .66681 .49321 .66497 .49105 Mtetra
.66497 .49105 .66681 .49321 .67063 .49204 .66879 .48988 Mtetra
.66879 .48988 .67063 .49204 .67446 .49087 .67262 .48871 Mtetra
.67262 .48871 .67446 .49087 .67829 .4897 .67646 .48753 Mtetra
.67646 .48753 .67829 .4897 .68213 .48852 .6803 .48636 Mtetra
.6803 .48636 .68213 .48852 .68597 .48735 .68415 .48518 Mtetra
.68415 .48518 .68597 .48735 .68982 .48617 .688 .484 Mtetra
.688 .484 .68982 .48617 .69367 .485 .69185 .48282 Mtetra
.69185 .48282 .69367 .485 .69753 .48382 .69571 .48164 Mtetra
.69571 .48164 .69753 .48382 .70139 .48264 .69958 .48045 Mtetra
.69958 .48045 .70139 .48264 .70526 .48145 .70345 .47927 Mtetra
.70345 .47927 .70526 .48145 .70913 .48027 .70733 .47808 Mtetra
.70733 .47808 .70913 .48027 .71301 .47908 .71121 .47689 Mtetra
.71121 .47689 .71301 .47908 .71689 .4779 .7151 .4757 Mtetra
.7151 .4757 .71689 .4779 .72078 .47671 .71899 .47451 Mtetra
.71899 .47451 .72078 .47671 .72468 .47552 .72289 .47332 Mtetra
.72289 .47332 .72468 .47552 .72858 .47433 .7268 .47212 Mtetra
.7268 .47212 .72858 .47433 .73248 .47313 .7307 .47092 Mtetra
.7307 .47092 .73248 .47313 .7364 .47194 .73462 .46973 Mtetra
.73462 .46973 .7364 .47194 .74031 .47074 .73854 .46853 Mtetra
.73854 .46853 .74031 .47074 .74423 .46954 .74246 .46732 Mtetra
.74246 .46732 .74423 .46954 .74816 .46834 .7464 .46612 Mtetra
.7464 .46612 .74816 .46834 .75209 .46714 .75033 .46492 Mtetra
.75033 .46492 .75209 .46714 .75603 .46593 .75427 .46371 Mtetra
.75427 .46371 .75603 .46593 .75997 .46473 .75822 .4625 Mtetra
.75822 .4625 .75997 .46473 .76392 .46352 .76217 .46129 Mtetra
.76217 .46129 .76392 .46352 .76788 .46231 .76613 .46008 Mtetra
.76613 .46008 .76788 .46231 .77184 .4611 .77009 .45886 Mtetra
.77009 .45886 .77184 .4611 .7758 .45989 .77406 .45765 Mtetra
.77406 .45765 .7758 .45989 .77977 .45868 .77804 .45643 Mtetra
.77804 .45643 .77977 .45868 .78375 .45746 .78202 .45521 Mtetra
.78202 .45521 .78375 .45746 .78773 .45625 .786 .45399 Mtetra
.786 .45399 .78773 .45625 .79171 .45503 .78999 .45277 Mtetra
.78999 .45277 .79171 .45503 .79571 .45381 .79399 .45155 Mtetra
.79399 .45155 .79571 .45381 .7997 .45258 .79799 .45032 Mtetra
.79799 .45032 .7997 .45258 .80371 .45136 .802 .4491 Mtetra
.802 .4491 .80371 .45136 .80772 .45014 .80601 .44787 Mtetra
.80601 .44787 .80772 .45014 .81173 .44891 .81003 .44664 Mtetra
.81003 .44664 .81173 .44891 .81575 .44768 .81405 .44541 Mtetra
.81405 .44541 .81575 .44768 .81978 .44645 .81808 .44417 Mtetra
.81808 .44417 .81978 .44645 .82381 .44522 .82212 .44294 Mtetra
.82212 .44294 .82381 .44522 .82785 .44398 .82616 .4417 Mtetra
.82616 .4417 .82785 .44398 .83189 .44275 .83021 .44046 Mtetra
.83021 .44046 .83189 .44275 .83594 .44151 .83426 .43922 Mtetra
.83426 .43922 .83594 .44151 .83999 .44027 .83832 .43798 Mtetra
.83832 .43798 .83999 .44027 .84405 .43903 .84238 .43673 Mtetra
.84238 .43673 .84405 .43903 .84812 .43779 .84645 .43549 Mtetra
.84645 .43549 .84812 .43779 .85219 .43654 .85052 .43424 Mtetra
.85052 .43424 .85219 .43654 .85626 .4353 .8546 .43299 Mtetra
.8546 .43299 .85626 .4353 .86035 .43405 .85869 .43174 Mtetra
.85869 .43174 .86035 .43405 .86443 .4328 .86278 .43049 Mtetra
.86278 .43049 .86443 .4328 .86853 .43155 .86688 .42923 Mtetra
.86688 .42923 .86853 .43155 .87263 .43029 .87098 .42798 Mtetra
.87098 .42798 .87263 .43029 .87673 .42904 .87509 .42672 Mtetra
.87509 .42672 .87673 .42904 .88084 .42778 .87921 .42546 Mtetra
.87921 .42546 .88084 .42778 .88496 .42652 .88333 .4242 Mtetra
.88333 .4242 .88496 .42652 .88908 .42526 .88746 .42293 Mtetra
.88746 .42293 .88908 .42526 .89321 .424 .89159 .42167 Mtetra
.89159 .42167 .89321 .424 .89734 .42274 .89573 .4204 Mtetra
.89573 .4204 .89734 .42274 .90148 .42147 .89987 .41913 Mtetra
.89987 .41913 .90148 .42147 .90563 .42021 .90402 .41786 Mtetra
.90402 .41786 .90563 .42021 .90978 .41894 .90818 .41659 Mtetra
.90818 .41659 .90978 .41894 .91394 .41767 .91234 .41532 Mtetra
.91234 .41532 .91394 .41767 .9181 .41639 .91651 .41404 Mtetra
.91651 .41404 .9181 .41639 .92227 .41512 .92068 .41276 Mtetra
.92068 .41276 .92227 .41512 .92645 .41384 .92486 .41148 Mtetra
.92486 .41148 .92645 .41384 .93063 .41257 .92905 .4102 Mtetra
.92905 .4102 .93063 .41257 .93482 .41129 .93324 .40892 Mtetra
.93324 .40892 .93482 .41129 .93901 .41 .93744 .40763 Mtetra
.93744 .40763 .93901 .41 .94321 .40872 .94164 .40635 Mtetra
.94164 .40635 .94321 .40872 .94741 .40743 .94585 .40506 Mtetra
.94585 .40506 .94741 .40743 .95162 .40615 .95006 .40377 Mtetra
.37627 .57685 .37836 .57879 .38181 .57774 .37972 .57579 Mtetra
.37972 .57579 .38181 .57774 .38526 .57668 .38317 .57473 Mtetra
.38317 .57473 .38526 .57668 .38871 .57563 .38663 .57367 Mtetra
.38663 .57367 .38871 .57563 .39217 .57457 .39009 .57261 Mtetra
.39009 .57261 .39217 .57457 .39563 .57351 .39356 .57155 Mtetra
.39356 .57155 .39563 .57351 .3991 .57244 .39703 .57048 Mtetra
.39703 .57048 .3991 .57244 .40257 .57138 .4005 .56942 Mtetra
.4005 .56942 .40257 .57138 .40605 .57032 .40398 .56835 Mtetra
.40398 .56835 .40605 .57032 .40953 .56925 .40747 .56728 Mtetra
.40747 .56728 .40953 .56925 .41302 .56818 .41095 .56621 Mtetra
.41095 .56621 .41302 .56818 .41651 .56712 .41445 .56514 Mtetra
.41445 .56514 .41651 .56712 .42001 .56605 .41795 .56407 Mtetra
.41795 .56407 .42001 .56605 .4235 .56497 .42145 .56299 Mtetra
.42145 .56299 .4235 .56497 .42701 .5639 .42496 .56192 Mtetra
.42496 .56192 .42701 .5639 .43052 .56283 .42847 .56084 Mtetra
.42847 .56084 .43052 .56283 .43403 .56175 .43198 .55976 Mtetra
.43198 .55976 .43403 .56175 .43755 .56067 .4355 .55868 Mtetra
.4355 .55868 .43755 .56067 .44107 .5596 .43903 .5576 Mtetra
.43903 .5576 .44107 .5596 .4446 .55852 .44256 .55652 Mtetra
.44256 .55652 .4446 .55852 .44813 .55743 .44609 .55543 Mtetra
.44609 .55543 .44813 .55743 .45167 .55635 .44963 .55435 Mtetra
.44963 .55435 .45167 .55635 .45521 .55527 .45318 .55326 Mtetra
.45318 .55326 .45521 .55527 .45875 .55418 .45673 .55217 Mtetra
.45673 .55217 .45875 .55418 .4623 .5531 .46028 .55109 Mtetra
.46028 .55109 .4623 .5531 .46586 .55201 .46384 .54999 Mtetra
.46384 .54999 .46586 .55201 .46942 .55092 .4674 .5489 Mtetra
.4674 .5489 .46942 .55092 .47298 .54983 .47097 .54781 Mtetra
.47097 .54781 .47298 .54983 .47655 .54873 .47454 .54671 Mtetra
.47454 .54671 .47655 .54873 .48012 .54764 .47811 .54562 Mtetra
.47811 .54562 .48012 .54764 .4837 .54654 .4817 .54452 Mtetra
.4817 .54452 .4837 .54654 .48728 .54545 .48528 .54342 Mtetra
.48528 .54342 .48728 .54545 .49087 .54435 .48887 .54232 Mtetra
.48887 .54232 .49087 .54435 .49446 .54325 .49247 .54122 Mtetra
.49247 .54122 .49446 .54325 .49806 .54215 .49607 .54011 Mtetra
.49607 .54011 .49806 .54215 .50166 .54105 .49967 .53901 Mtetra
.49967 .53901 .50166 .54105 .50527 .53994 .50328 .5379 Mtetra
.50328 .5379 .50527 .53994 .50888 .53884 .5069 .53679 Mtetra
.5069 .53679 .50888 .53884 .5125 .53773 .51051 .53568 Mtetra
.51051 .53568 .5125 .53773 .51612 .53662 .51414 .53457 Mtetra
.51414 .53457 .51612 .53662 .51974 .53551 .51777 .53346 Mtetra
.51777 .53346 .51974 .53551 .52337 .5344 .5214 .53234 Mtetra
.5214 .53234 .52337 .5344 .52701 .53329 .52504 .53123 Mtetra
.52504 .53123 .52701 .53329 .53065 .53217 .52868 .53011 Mtetra
.52868 .53011 .53065 .53217 .53429 .53106 .53233 .52899 Mtetra
.53233 .52899 .53429 .53106 .53794 .52994 .53598 .52787 Mtetra
.877 .447 .051 r
.53598 .52787 .53794 .52994 .54164 .53793 .53968 .53586 Mtetra
.663 .742 .909 r
.53968 .53586 .54164 .53793 .54531 .53681 .54335 .53474 Mtetra
.54335 .53474 .54531 .53681 .54899 .53569 .54703 .53362 Mtetra
.54703 .53362 .54899 .53569 .55266 .53457 .55071 .5325 Mtetra
.55071 .5325 .55266 .53457 .55635 .53345 .5544 .53138 Mtetra
.5544 .53138 .55635 .53345 .56004 .53233 .55809 .53025 Mtetra
.55809 .53025 .56004 .53233 .56373 .5312 .56179 .52912 Mtetra
.56179 .52912 .56373 .5312 .56743 .53008 .56549 .52799 Mtetra
.56549 .52799 .56743 .53008 .57113 .52895 .5692 .52686 Mtetra
.5692 .52686 .57113 .52895 .57484 .52782 .57291 .52573 Mtetra
.57291 .52573 .57484 .52782 .57856 .52669 .57663 .5246 Mtetra
.57663 .5246 .57856 .52669 .58227 .52556 .58035 .52346 Mtetra
.58035 .52346 .58227 .52556 .586 .52442 .58407 .52233 Mtetra
.58407 .52233 .586 .52442 .58973 .52329 .58781 .52119 Mtetra
.58781 .52119 .58973 .52329 .59346 .52215 .59154 .52005 Mtetra
.59154 .52005 .59346 .52215 .5972 .52101 .59528 .51891 Mtetra
.59528 .51891 .5972 .52101 .60094 .51987 .59903 .51776 Mtetra
.59903 .51776 .60094 .51987 .60469 .51873 .60278 .51662 Mtetra
.60278 .51662 .60469 .51873 .60844 .51759 .60654 .51547 Mtetra
.60654 .51547 .60844 .51759 .61196 .50728 .6103 .51433 Mtetra
0 0 .036 r
.6103 .51433 .61196 .50728 .61572 .50613 .61382 .504 Mtetra
.664 .741 .908 r
.61382 .504 .61572 .50613 .61947 .50498 .61759 .50285 Mtetra
.61759 .50285 .61947 .50498 .62324 .50383 .62135 .50169 Mtetra
.62135 .50169 .62324 .50383 .62701 .50267 .62512 .50054 Mtetra
.62512 .50054 .62701 .50267 .63078 .50152 .6289 .49938 Mtetra
.6289 .49938 .63078 .50152 .63456 .50036 .63268 .49822 Mtetra
.63268 .49822 .63456 .50036 .63834 .4992 .63647 .49706 Mtetra
.63647 .49706 .63834 .4992 .64213 .49804 .64026 .4959 Mtetra
.64026 .4959 .64213 .49804 .64592 .49688 .64406 .49473 Mtetra
.64406 .49473 .64592 .49688 .64972 .49572 .64786 .49357 Mtetra
.64786 .49357 .64972 .49572 .65353 .49455 .65167 .4924 Mtetra
.65167 .4924 .65353 .49455 .65734 .49339 .65548 .49123 Mtetra
.65548 .49123 .65734 .49339 .66115 .49222 .6593 .49006 Mtetra
.6593 .49006 .66115 .49222 .66497 .49105 .66312 .48889 Mtetra
.66312 .48889 .66497 .49105 .66879 .48988 .66695 .48771 Mtetra
.66695 .48771 .66879 .48988 .67262 .48871 .67079 .48654 Mtetra
.67079 .48654 .67262 .48871 .67646 .48753 .67462 .48536 Mtetra
.67462 .48536 .67646 .48753 .6803 .48636 .67847 .48418 Mtetra
.67847 .48418 .6803 .48636 .68415 .48518 .68232 .483 Mtetra
.68232 .483 .68415 .48518 .688 .484 .68617 .48182 Mtetra
.68617 .48182 .688 .484 .69185 .48282 .69003 .48063 Mtetra
.69003 .48063 .69185 .48282 .69571 .48164 .6939 .47945 Mtetra
.6939 .47945 .69571 .48164 .69958 .48045 .69777 .47826 Mtetra
.69777 .47826 .69958 .48045 .70345 .47927 .70164 .47707 Mtetra
.70164 .47707 .70345 .47927 .70733 .47808 .70552 .47588 Mtetra
.70552 .47588 .70733 .47808 .71121 .47689 .70941 .47469 Mtetra
.70941 .47469 .71121 .47689 .7151 .4757 .7133 .4735 Mtetra
.7133 .4735 .7151 .4757 .71899 .47451 .7172 .4723 Mtetra
.7172 .4723 .71899 .47451 .72289 .47332 .7211 .47111 Mtetra
.7211 .47111 .72289 .47332 .7268 .47212 .72501 .46991 Mtetra
.72501 .46991 .7268 .47212 .7307 .47092 .72892 .46871 Mtetra
.72892 .46871 .7307 .47092 .73462 .46973 .73284 .46751 Mtetra
.73284 .46751 .73462 .46973 .73854 .46853 .73676 .46631 Mtetra
.73676 .46631 .73854 .46853 .74246 .46732 .74069 .4651 Mtetra
.74069 .4651 .74246 .46732 .7464 .46612 .74463 .46389 Mtetra
.74463 .46389 .7464 .46612 .75033 .46492 .74857 .46269 Mtetra
.74857 .46269 .75033 .46492 .75427 .46371 .75251 .46148 Mtetra
.75251 .46148 .75427 .46371 .75822 .4625 .75646 .46026 Mtetra
.75646 .46026 .75822 .4625 .76217 .46129 .76042 .45905 Mtetra
.76042 .45905 .76217 .46129 .76613 .46008 .76438 .45784 Mtetra
.76438 .45784 .76613 .46008 .77009 .45886 .76835 .45662 Mtetra
.76835 .45662 .77009 .45886 .77406 .45765 .77232 .4554 Mtetra
.77232 .4554 .77406 .45765 .77804 .45643 .7763 .45418 Mtetra
.7763 .45418 .77804 .45643 .78202 .45521 .78028 .45296 Mtetra
.78028 .45296 .78202 .45521 .786 .45399 .78427 .45174 Mtetra
.78427 .45174 .786 .45399 .78999 .45277 .78827 .45051 Mtetra
.78827 .45051 .78999 .45277 .79399 .45155 .79227 .44929 Mtetra
.79227 .44929 .79399 .45155 .79799 .45032 .79627 .44806 Mtetra
.79627 .44806 .79799 .45032 .802 .4491 .80028 .44683 Mtetra
.80028 .44683 .802 .4491 .80601 .44787 .8043 .4456 Mtetra
.8043 .4456 .80601 .44787 .81003 .44664 .80832 .44436 Mtetra
.80832 .44436 .81003 .44664 .81405 .44541 .81235 .44313 Mtetra
.81235 .44313 .81405 .44541 .81808 .44417 .81638 .44189 Mtetra
.81638 .44189 .81808 .44417 .82212 .44294 .82042 .44065 Mtetra
.82042 .44065 .82212 .44294 .82616 .4417 .82447 .43941 Mtetra
.82447 .43941 .82616 .4417 .83021 .44046 .82852 .43817 Mtetra
.82852 .43817 .83021 .44046 .83426 .43922 .83258 .43693 Mtetra
.83258 .43693 .83426 .43922 .83832 .43798 .83664 .43568 Mtetra
.83664 .43568 .83832 .43798 .84238 .43673 .8407 .43443 Mtetra
.8407 .43443 .84238 .43673 .84645 .43549 .84478 .43318 Mtetra
.84478 .43318 .84645 .43549 .85052 .43424 .84886 .43193 Mtetra
.84886 .43193 .85052 .43424 .8546 .43299 .85294 .43068 Mtetra
.85294 .43068 .8546 .43299 .85869 .43174 .85703 .42943 Mtetra
.85703 .42943 .85869 .43174 .86278 .43049 .86113 .42817 Mtetra
.86113 .42817 .86278 .43049 .86688 .42923 .86523 .42691 Mtetra
.86523 .42691 .86688 .42923 .87098 .42798 .86934 .42565 Mtetra
.86934 .42565 .87098 .42798 .87509 .42672 .87345 .42439 Mtetra
.87345 .42439 .87509 .42672 .87921 .42546 .87757 .42313 Mtetra
.87757 .42313 .87921 .42546 .88333 .4242 .8817 .42186 Mtetra
.8817 .42186 .88333 .4242 .88746 .42293 .88583 .4206 Mtetra
.88583 .4206 .88746 .42293 .89159 .42167 .88997 .41933 Mtetra
.88997 .41933 .89159 .42167 .89573 .4204 .89411 .41806 Mtetra
.89411 .41806 .89573 .4204 .89987 .41913 .89826 .41679 Mtetra
.89826 .41679 .89987 .41913 .90402 .41786 .90241 .41551 Mtetra
.90241 .41551 .90402 .41786 .90818 .41659 .90657 .41424 Mtetra
.90657 .41424 .90818 .41659 .91234 .41532 .91074 .41296 Mtetra
.91074 .41296 .91234 .41532 .91651 .41404 .91491 .41168 Mtetra
.91491 .41168 .91651 .41404 .92068 .41276 .91909 .4104 Mtetra
.91909 .4104 .92068 .41276 .92486 .41148 .92327 .40912 Mtetra
.92327 .40912 .92486 .41148 .92905 .4102 .92746 .40783 Mtetra
.92746 .40783 .92905 .4102 .93324 .40892 .93166 .40654 Mtetra
.93166 .40654 .93324 .40892 .93744 .40763 .93586 .40526 Mtetra
.93586 .40526 .93744 .40763 .94164 .40635 .94007 .40396 Mtetra
.94007 .40396 .94164 .40635 .94585 .40506 .94428 .40267 Mtetra
.94428 .40267 .94585 .40506 .95006 .40377 .9485 .40138 Mtetra
.37417 .57489 .37627 .57685 .37972 .57579 .37762 .57383 Mtetra
.37762 .57383 .37972 .57579 .38317 .57473 .38108 .57277 Mtetra
.38108 .57277 .38317 .57473 .38663 .57367 .38454 .57171 Mtetra
.38454 .57171 .38663 .57367 .39009 .57261 .388 .57064 Mtetra
.388 .57064 .39009 .57261 .39356 .57155 .39147 .56958 Mtetra
.39147 .56958 .39356 .57155 .39703 .57048 .39494 .56851 Mtetra
.39494 .56851 .39703 .57048 .4005 .56942 .39842 .56744 Mtetra
.39842 .56744 .4005 .56942 .40398 .56835 .40191 .56637 Mtetra
.40191 .56637 .40398 .56835 .40747 .56728 .40539 .5653 Mtetra
.40539 .5653 .40747 .56728 .41095 .56621 .40888 .56423 Mtetra
.40888 .56423 .41095 .56621 .41445 .56514 .41238 .56316 Mtetra
.41238 .56316 .41445 .56514 .41795 .56407 .41588 .56208 Mtetra
.41588 .56208 .41795 .56407 .42145 .56299 .41939 .56101 Mtetra
.41939 .56101 .42145 .56299 .42496 .56192 .4229 .55993 Mtetra
.4229 .55993 .42496 .56192 .42847 .56084 .42641 .55885 Mtetra
.42641 .55885 .42847 .56084 .43198 .55976 .42993 .55777 Mtetra
.42993 .55777 .43198 .55976 .4355 .55868 .43345 .55669 Mtetra
.43345 .55669 .4355 .55868 .43903 .5576 .43698 .5556 Mtetra
.43698 .5556 .43903 .5576 .44256 .55652 .44052 .55452 Mtetra
.44052 .55452 .44256 .55652 .44609 .55543 .44405 .55343 Mtetra
.44405 .55343 .44609 .55543 .44963 .55435 .4476 .55234 Mtetra
.4476 .55234 .44963 .55435 .45318 .55326 .45114 .55125 Mtetra
.45114 .55125 .45318 .55326 .45673 .55217 .45469 .55016 Mtetra
.45469 .55016 .45673 .55217 .46028 .55109 .45825 .54907 Mtetra
.45825 .54907 .46028 .55109 .46384 .54999 .46181 .54798 Mtetra
.46181 .54798 .46384 .54999 .4674 .5489 .46538 .54688 Mtetra
.46538 .54688 .4674 .5489 .47097 .54781 .46895 .54579 Mtetra
.46895 .54579 .47097 .54781 .47454 .54671 .47252 .54469 Mtetra
.47252 .54469 .47454 .54671 .47811 .54562 .4761 .54359 Mtetra
.4761 .54359 .47811 .54562 .4817 .54452 .47968 .54249 Mtetra
.47968 .54249 .4817 .54452 .48528 .54342 .48327 .54139 Mtetra
.48327 .54139 .48528 .54342 .48887 .54232 .48687 .54028 Mtetra
.48687 .54028 .48887 .54232 .49247 .54122 .49046 .53918 Mtetra
.49046 .53918 .49247 .54122 .49607 .54011 .49407 .53807 Mtetra
.49407 .53807 .49607 .54011 .49967 .53901 .49768 .53696 Mtetra
.49768 .53696 .49967 .53901 .50328 .5379 .50129 .53585 Mtetra
.50129 .53585 .50328 .5379 .5069 .53679 .50491 .53474 Mtetra
.50491 .53474 .5069 .53679 .51051 .53568 .50853 .53363 Mtetra
.50853 .53363 .51051 .53568 .51414 .53457 .51215 .53251 Mtetra
.51215 .53251 .51414 .53457 .51777 .53346 .51579 .5314 Mtetra
.51579 .5314 .51777 .53346 .5214 .53234 .51942 .53028 Mtetra
.51942 .53028 .5214 .53234 .52504 .53123 .52306 .52916 Mtetra
.52306 .52916 .52504 .53123 .52868 .53011 .52671 .52804 Mtetra
.52671 .52804 .52868 .53011 .53233 .52899 .53036 .52692 Mtetra
.878 .448 .055 r
.53036 .52692 .53233 .52899 .53598 .52787 .53404 .53492 Mtetra
.484 .179 .373 r
.53404 .53492 .53598 .52787 .53968 .53586 .53771 .5338 Mtetra
.663 .742 .909 r
.53771 .5338 .53968 .53586 .54335 .53474 .54139 .53267 Mtetra
.54139 .53267 .54335 .53474 .54703 .53362 .54507 .53155 Mtetra
.54507 .53155 .54703 .53362 .55071 .5325 .54875 .53042 Mtetra
.54875 .53042 .55071 .5325 .5544 .53138 .55245 .5293 Mtetra
.55245 .5293 .5544 .53138 .55809 .53025 .55614 .52817 Mtetra
.55614 .52817 .55809 .53025 .56179 .52912 .55984 .52704 Mtetra
.55984 .52704 .56179 .52912 .56549 .52799 .56355 .5259 Mtetra
.56355 .5259 .56549 .52799 .5692 .52686 .56726 .52477 Mtetra
.56726 .52477 .5692 .52686 .57291 .52573 .57097 .52364 Mtetra
.57097 .52364 .57291 .52573 .57663 .5246 .57469 .5225 Mtetra
.57469 .5225 .57663 .5246 .58035 .52346 .57842 .52136 Mtetra
.57842 .52136 .58035 .52346 .58407 .52233 .58215 .52022 Mtetra
.58215 .52022 .58407 .52233 .58781 .52119 .58588 .51908 Mtetra
.58588 .51908 .58781 .52119 .59154 .52005 .58962 .51794 Mtetra
.58962 .51794 .59154 .52005 .59528 .51891 .59337 .5168 Mtetra
.59337 .5168 .59528 .51891 .59903 .51776 .59712 .51565 Mtetra
.59712 .51565 .59903 .51776 .60278 .51662 .60087 .5145 Mtetra
.60087 .5145 .60278 .51662 .60654 .51547 .60463 .51335 Mtetra
.60463 .51335 .60654 .51547 .6103 .51433 .6084 .5122 Mtetra
.6084 .5122 .6103 .51433 .61382 .504 .61217 .51105 Mtetra
0 0 .036 r
.61217 .51105 .61382 .504 .61759 .50285 .61569 .50072 Mtetra
.664 .741 .908 r
.61569 .50072 .61759 .50285 .62135 .50169 .61946 .49956 Mtetra
.61946 .49956 .62135 .50169 .62512 .50054 .62324 .4984 Mtetra
.62324 .4984 .62512 .50054 .6289 .49938 .62702 .49724 Mtetra
.62702 .49724 .6289 .49938 .63268 .49822 .6308 .49607 Mtetra
.6308 .49607 .63268 .49822 .63647 .49706 .6346 .49491 Mtetra
.6346 .49491 .63647 .49706 .64026 .4959 .63839 .49374 Mtetra
.63839 .49374 .64026 .4959 .64406 .49473 .64219 .49258 Mtetra
.64219 .49258 .64406 .49473 .64786 .49357 .646 .49141 Mtetra
.646 .49141 .64786 .49357 .65167 .4924 .64981 .49024 Mtetra
.64981 .49024 .65167 .4924 .65548 .49123 .65363 .48907 Mtetra
.65363 .48907 .65548 .49123 .6593 .49006 .65745 .48789 Mtetra
.65745 .48789 .6593 .49006 .66312 .48889 .66127 .48672 Mtetra
.66127 .48672 .66312 .48889 .66695 .48771 .66511 .48554 Mtetra
.66511 .48554 .66695 .48771 .67079 .48654 .66894 .48436 Mtetra
.66894 .48436 .67079 .48654 .67462 .48536 .67278 .48318 Mtetra
.67278 .48318 .67462 .48536 .67847 .48418 .67663 .482 Mtetra
.67663 .482 .67847 .48418 .68232 .483 .68049 .48082 Mtetra
.68049 .48082 .68232 .483 .68617 .48182 .68434 .47963 Mtetra
.68434 .47963 .68617 .48182 .69003 .48063 .68821 .47845 Mtetra
.68821 .47845 .69003 .48063 .6939 .47945 .69208 .47726 Mtetra
.69208 .47726 .6939 .47945 .69777 .47826 .69595 .47607 Mtetra
.69595 .47607 .69777 .47826 .70164 .47707 .69983 .47488 Mtetra
.69983 .47488 .70164 .47707 .70552 .47588 .70371 .47368 Mtetra
.70371 .47368 .70552 .47588 .70941 .47469 .7076 .47249 Mtetra
.7076 .47249 .70941 .47469 .7133 .4735 .7115 .47129 Mtetra
.7115 .47129 .7133 .4735 .7172 .4723 .7154 .47009 Mtetra
.7154 .47009 .7172 .4723 .7211 .47111 .7193 .46889 Mtetra
.7193 .46889 .7211 .47111 .72501 .46991 .72322 .46769 Mtetra
.72322 .46769 .72501 .46991 .72892 .46871 .72713 .46649 Mtetra
.72713 .46649 .72892 .46871 .73284 .46751 .73105 .46529 Mtetra
.73105 .46529 .73284 .46751 .73676 .46631 .73498 .46408 Mtetra
.73498 .46408 .73676 .46631 .74069 .4651 .73891 .46287 Mtetra
.73891 .46287 .74069 .4651 .74463 .46389 .74285 .46166 Mtetra
.74285 .46166 .74463 .46389 .74857 .46269 .7468 .46045 Mtetra
.7468 .46045 .74857 .46269 .75251 .46148 .75075 .45924 Mtetra
.75075 .45924 .75251 .46148 .75646 .46026 .7547 .45802 Mtetra
.7547 .45802 .75646 .46026 .76042 .45905 .75866 .45681 Mtetra
.75866 .45681 .76042 .45905 .76438 .45784 .76263 .45559 Mtetra
.76263 .45559 .76438 .45784 .76835 .45662 .7666 .45437 Mtetra
.7666 .45437 .76835 .45662 .77232 .4554 .77057 .45315 Mtetra
.77057 .45315 .77232 .4554 .7763 .45418 .77455 .45193 Mtetra
.77455 .45193 .7763 .45418 .78028 .45296 .77854 .4507 Mtetra
.77854 .4507 .78028 .45296 .78427 .45174 .78254 .44948 Mtetra
.78254 .44948 .78427 .45174 .78827 .45051 .78653 .44825 Mtetra
.78653 .44825 .78827 .45051 .79227 .44929 .79054 .44702 Mtetra
.79054 .44702 .79227 .44929 .79627 .44806 .79455 .44579 Mtetra
.79455 .44579 .79627 .44806 .80028 .44683 .79856 .44455 Mtetra
.79856 .44455 .80028 .44683 .8043 .4456 .80258 .44332 Mtetra
.80258 .44332 .8043 .4456 .80832 .44436 .80661 .44208 Mtetra
.80661 .44208 .80832 .44436 .81235 .44313 .81064 .44084 Mtetra
.81064 .44084 .81235 .44313 .81638 .44189 .81468 .4396 Mtetra
.81468 .4396 .81638 .44189 .82042 .44065 .81872 .43836 Mtetra
.81872 .43836 .82042 .44065 .82447 .43941 .82277 .43712 Mtetra
.82277 .43712 .82447 .43941 .82852 .43817 .82683 .43587 Mtetra
.82683 .43587 .82852 .43817 .83258 .43693 .83089 .43462 Mtetra
.83089 .43462 .83258 .43693 .83664 .43568 .83495 .43338 Mtetra
.83495 .43338 .83664 .43568 .8407 .43443 .83903 .43213 Mtetra
.83903 .43213 .8407 .43443 .84478 .43318 .8431 .43087 Mtetra
.8431 .43087 .84478 .43318 .84886 .43193 .84719 .42962 Mtetra
.84719 .42962 .84886 .43193 .85294 .43068 .85128 .42836 Mtetra
.85128 .42836 .85294 .43068 .85703 .42943 .85537 .42711 Mtetra
.85537 .42711 .85703 .42943 .86113 .42817 .85947 .42585 Mtetra
.85947 .42585 .86113 .42817 .86523 .42691 .86358 .42459 Mtetra
.86358 .42459 .86523 .42691 .86934 .42565 .86769 .42332 Mtetra
.86769 .42332 .86934 .42565 .87345 .42439 .87181 .42206 Mtetra
.87181 .42206 .87345 .42439 .87757 .42313 .87593 .42079 Mtetra
.87593 .42079 .87757 .42313 .8817 .42186 .88006 .41952 Mtetra
.88006 .41952 .8817 .42186 .88583 .4206 .88419 .41825 Mtetra
.88419 .41825 .88583 .4206 .88997 .41933 .88834 .41698 Mtetra
.88834 .41698 .88997 .41933 .89411 .41806 .89248 .41571 Mtetra
.89248 .41571 .89411 .41806 .89826 .41679 .89664 .41443 Mtetra
.89664 .41443 .89826 .41679 .90241 .41551 .90079 .41316 Mtetra
.90079 .41316 .90241 .41551 .90657 .41424 .90496 .41188 Mtetra
.90496 .41188 .90657 .41424 .91074 .41296 .90913 .4106 Mtetra
.90913 .4106 .91074 .41296 .91491 .41168 .91331 .40931 Mtetra
.91331 .40931 .91491 .41168 .91909 .4104 .91749 .40803 Mtetra
.91749 .40803 .91909 .4104 .92327 .40912 .92168 .40674 Mtetra
.92168 .40674 .92327 .40912 .92746 .40783 .92587 .40545 Mtetra
.92587 .40545 .92746 .40783 .93166 .40654 .93007 .40416 Mtetra
.93007 .40416 .93166 .40654 .93586 .40526 .93428 .40287 Mtetra
.93428 .40287 .93586 .40526 .94007 .40396 .93849 .40158 Mtetra
.93849 .40158 .94007 .40396 .94428 .40267 .94271 .40028 Mtetra
.94271 .40028 .94428 .40267 .9485 .40138 .94693 .39899 Mtetra
.37207 .57294 .37417 .57489 .37762 .57383 .37552 .57187 Mtetra
.37552 .57187 .37762 .57383 .38108 .57277 .37898 .57081 Mtetra
.37898 .57081 .38108 .57277 .38454 .57171 .38244 .56974 Mtetra
.38244 .56974 .38454 .57171 .388 .57064 .38591 .56868 Mtetra
.38591 .56868 .388 .57064 .39147 .56958 .38938 .56761 Mtetra
.38938 .56761 .39147 .56958 .39494 .56851 .39286 .56654 Mtetra
.39286 .56654 .39494 .56851 .39842 .56744 .39634 .56547 Mtetra
.39634 .56547 .39842 .56744 .40191 .56637 .39983 .5644 Mtetra
.39983 .5644 .40191 .56637 .40539 .5653 .40332 .56332 Mtetra
.40332 .56332 .40539 .5653 .40888 .56423 .40681 .56225 Mtetra
.40681 .56225 .40888 .56423 .41238 .56316 .41031 .56117 Mtetra
.41031 .56117 .41238 .56316 .41588 .56208 .41381 .56009 Mtetra
.41381 .56009 .41588 .56208 .41939 .56101 .41732 .55901 Mtetra
.41732 .55901 .41939 .56101 .4229 .55993 .42083 .55793 Mtetra
.42083 .55793 .4229 .55993 .42641 .55885 .42435 .55685 Mtetra
.42435 .55685 .42641 .55885 .42993 .55777 .42787 .55577 Mtetra
.42787 .55577 .42993 .55777 .43345 .55669 .4314 .55468 Mtetra
.4314 .55468 .43345 .55669 .43698 .5556 .43493 .5536 Mtetra
.43493 .5536 .43698 .5556 .44052 .55452 .43847 .55251 Mtetra
.43847 .55251 .44052 .55452 .44405 .55343 .44201 .55142 Mtetra
.44201 .55142 .44405 .55343 .4476 .55234 .44555 .55033 Mtetra
.44555 .55033 .4476 .55234 .45114 .55125 .4491 .54924 Mtetra
.4491 .54924 .45114 .55125 .45469 .55016 .45266 .54815 Mtetra
.45266 .54815 .45469 .55016 .45825 .54907 .45622 .54705 Mtetra
.45622 .54705 .45825 .54907 .46181 .54798 .45978 .54595 Mtetra
.45978 .54595 .46181 .54798 .46538 .54688 .46335 .54486 Mtetra
.46335 .54486 .46538 .54688 .46895 .54579 .46692 .54376 Mtetra
.46692 .54376 .46895 .54579 .47252 .54469 .4705 .54266 Mtetra
.4705 .54266 .47252 .54469 .4761 .54359 .47408 .54155 Mtetra
.47408 .54155 .4761 .54359 .47968 .54249 .47767 .54045 Mtetra
.47767 .54045 .47968 .54249 .48327 .54139 .48126 .53935 Mtetra
.48126 .53935 .48327 .54139 .48687 .54028 .48486 .53824 Mtetra
.48486 .53824 .48687 .54028 .49046 .53918 .48846 .53713 Mtetra
.48846 .53713 .49046 .53918 .49407 .53807 .49206 .53602 Mtetra
.49206 .53602 .49407 .53807 .49768 .53696 .49567 .53491 Mtetra
.49567 .53491 .49768 .53696 .50129 .53585 .49929 .5338 Mtetra
.49929 .5338 .50129 .53585 .50491 .53474 .50291 .53269 Mtetra
.50291 .53269 .50491 .53474 .50853 .53363 .50654 .53157 Mtetra
.50654 .53157 .50853 .53363 .51215 .53251 .51017 .53045 Mtetra
.51017 .53045 .51215 .53251 .51579 .5314 .5138 .52934 Mtetra
.5138 .52934 .51579 .5314 .51942 .53028 .51744 .52822 Mtetra
.51744 .52822 .51942 .53028 .52306 .52916 .52109 .5271 Mtetra
.52109 .5271 .52306 .52916 .52671 .52804 .52473 .52597 Mtetra
.52473 .52597 .52671 .52804 .53036 .52692 .52839 .52485 Mtetra
.878 .448 .055 r
.52839 .52485 .53036 .52692 .53404 .53492 .53207 .53285 Mtetra
.663 .742 .909 r
.53207 .53285 .53404 .53492 .53771 .5338 .53574 .53172 Mtetra
.53574 .53172 .53771 .5338 .54139 .53267 .53942 .5306 Mtetra
.53942 .5306 .54139 .53267 .54507 .53155 .5431 .52947 Mtetra
.5431 .52947 .54507 .53155 .54875 .53042 .54679 .52834 Mtetra
.54679 .52834 .54875 .53042 .55245 .5293 .55049 .52721 Mtetra
.55049 .52721 .55245 .5293 .55614 .52817 .55418 .52608 Mtetra
.55418 .52608 .55614 .52817 .55984 .52704 .55789 .52495 Mtetra
.55789 .52495 .55984 .52704 .56355 .5259 .5616 .52381 Mtetra
.5616 .52381 .56355 .5259 .56726 .52477 .56531 .52267 Mtetra
.56531 .52267 .56726 .52477 .57097 .52364 .56903 .52154 Mtetra
.56903 .52154 .57097 .52364 .57469 .5225 .57275 .5204 Mtetra
.57275 .5204 .57469 .5225 .57842 .52136 .57648 .51926 Mtetra
.57648 .51926 .57842 .52136 .58215 .52022 .58021 .51812 Mtetra
.58021 .51812 .58215 .52022 .58588 .51908 .58395 .51697 Mtetra
.58395 .51697 .58588 .51908 .58962 .51794 .5877 .51583 Mtetra
.5877 .51583 .58962 .51794 .59337 .5168 .59144 .51468 Mtetra
.59144 .51468 .59337 .5168 .59712 .51565 .5952 .51353 Mtetra
.5952 .51353 .59712 .51565 .60087 .5145 .59896 .51238 Mtetra
.59896 .51238 .60087 .5145 .60463 .51335 .60272 .51123 Mtetra
.60272 .51123 .60463 .51335 .6084 .5122 .60649 .51008 Mtetra
.60649 .51008 .6084 .5122 .61217 .51105 .61026 .50892 Mtetra
.92 .757 .662 r
.61026 .50892 .61217 .51105 .61569 .50072 .6138 .49858 Mtetra
.664 .741 .908 r
.6138 .49858 .61569 .50072 .61946 .49956 .61757 .49742 Mtetra
.61757 .49742 .61946 .49956 .62324 .4984 .62135 .49625 Mtetra
.62135 .49625 .62324 .4984 .62702 .49724 .62513 .49509 Mtetra
.62513 .49509 .62702 .49724 .6308 .49607 .62892 .49392 Mtetra
.62892 .49392 .6308 .49607 .6346 .49491 .63272 .49276 Mtetra
.63272 .49276 .6346 .49491 .63839 .49374 .63651 .49159 Mtetra
.63651 .49159 .63839 .49374 .64219 .49258 .64032 .49042 Mtetra
.64032 .49042 .64219 .49258 .646 .49141 .64413 .48925 Mtetra
.64413 .48925 .646 .49141 .64981 .49024 .64794 .48807 Mtetra
.64794 .48807 .64981 .49024 .65363 .48907 .65176 .4869 Mtetra
.65176 .4869 .65363 .48907 .65745 .48789 .65559 .48572 Mtetra
.65559 .48572 .65745 .48789 .66127 .48672 .65942 .48454 Mtetra
.65942 .48454 .66127 .48672 .66511 .48554 .66325 .48336 Mtetra
.66325 .48336 .66511 .48554 .66894 .48436 .66709 .48218 Mtetra
.66709 .48218 .66894 .48436 .67278 .48318 .67094 .481 Mtetra
.67094 .481 .67278 .48318 .67663 .482 .67479 .47981 Mtetra
.67479 .47981 .67663 .482 .68049 .48082 .67865 .47863 Mtetra
.67865 .47863 .68049 .48082 .68434 .47963 .68251 .47744 Mtetra
.68251 .47744 .68434 .47963 .68821 .47845 .68638 .47625 Mtetra
.68638 .47625 .68821 .47845 .69208 .47726 .69025 .47506 Mtetra
.69025 .47506 .69208 .47726 .69595 .47607 .69413 .47387 Mtetra
.69413 .47387 .69595 .47607 .69983 .47488 .69801 .47267 Mtetra
.69801 .47267 .69983 .47488 .70371 .47368 .7019 .47148 Mtetra
.7019 .47148 .70371 .47368 .7076 .47249 .70579 .47028 Mtetra
.70579 .47028 .7076 .47249 .7115 .47129 .70969 .46908 Mtetra
.70969 .46908 .7115 .47129 .7154 .47009 .71359 .46788 Mtetra
.71359 .46788 .7154 .47009 .7193 .46889 .7175 .46668 Mtetra
.7175 .46668 .7193 .46889 .72322 .46769 .72142 .46547 Mtetra
.72142 .46547 .72322 .46769 .72713 .46649 .72534 .46427 Mtetra
.72534 .46427 .72713 .46649 .73105 .46529 .72926 .46306 Mtetra
.72926 .46306 .73105 .46529 .73498 .46408 .7332 .46185 Mtetra
.7332 .46185 .73498 .46408 .73891 .46287 .73713 .46064 Mtetra
.73713 .46064 .73891 .46287 .74285 .46166 .74107 .45943 Mtetra
.74107 .45943 .74285 .46166 .7468 .46045 .74502 .45821 Mtetra
.74502 .45821 .7468 .46045 .75075 .45924 .74897 .45699 Mtetra
.74897 .45699 .75075 .45924 .7547 .45802 .75293 .45578 Mtetra
.75293 .45578 .7547 .45802 .75866 .45681 .7569 .45456 Mtetra
.7569 .45456 .75866 .45681 .76263 .45559 .76087 .45334 Mtetra
.76087 .45334 .76263 .45559 .7666 .45437 .76484 .45211 Mtetra
.76484 .45211 .7666 .45437 .77057 .45315 .76882 .45089 Mtetra
.76882 .45089 .77057 .45315 .77455 .45193 .77281 .44966 Mtetra
.77281 .44966 .77455 .45193 .77854 .4507 .7768 .44844 Mtetra
.7768 .44844 .77854 .4507 .78254 .44948 .7808 .44721 Mtetra
.7808 .44721 .78254 .44948 .78653 .44825 .7848 .44598 Mtetra
.7848 .44598 .78653 .44825 .79054 .44702 .78881 .44474 Mtetra
.78881 .44474 .79054 .44702 .79455 .44579 .79282 .44351 Mtetra
.79282 .44351 .79455 .44579 .79856 .44455 .79684 .44227 Mtetra
.79684 .44227 .79856 .44455 .80258 .44332 .80086 .44103 Mtetra
.80086 .44103 .80258 .44332 .80661 .44208 .80489 .43979 Mtetra
.80489 .43979 .80661 .44208 .81064 .44084 .80893 .43855 Mtetra
.80893 .43855 .81064 .44084 .81468 .4396 .81297 .43731 Mtetra
.81297 .43731 .81468 .4396 .81872 .43836 .81702 .43606 Mtetra
.81702 .43606 .81872 .43836 .82277 .43712 .82107 .43482 Mtetra
.82107 .43482 .82277 .43712 .82683 .43587 .82513 .43357 Mtetra
.82513 .43357 .82683 .43587 .83089 .43462 .8292 .43232 Mtetra
.8292 .43232 .83089 .43462 .83495 .43338 .83327 .43107 Mtetra
.83327 .43107 .83495 .43338 .83903 .43213 .83734 .42981 Mtetra
.83734 .42981 .83903 .43213 .8431 .43087 .84142 .42856 Mtetra
.84142 .42856 .8431 .43087 .84719 .42962 .84551 .4273 Mtetra
.84551 .4273 .84719 .42962 .85128 .42836 .8496 .42604 Mtetra
.8496 .42604 .85128 .42836 .85537 .42711 .8537 .42478 Mtetra
.8537 .42478 .85537 .42711 .85947 .42585 .85781 .42352 Mtetra
.85781 .42352 .85947 .42585 .86358 .42459 .86192 .42225 Mtetra
.86192 .42225 .86358 .42459 .86769 .42332 .86603 .42099 Mtetra
.86603 .42099 .86769 .42332 .87181 .42206 .87016 .41972 Mtetra
.87016 .41972 .87181 .42206 .87593 .42079 .87428 .41845 Mtetra
.87428 .41845 .87593 .42079 .88006 .41952 .87842 .41718 Mtetra
.87842 .41718 .88006 .41952 .88419 .41825 .88256 .4159 Mtetra
.88256 .4159 .88419 .41825 .88834 .41698 .8867 .41463 Mtetra
.8867 .41463 .88834 .41698 .89248 .41571 .89085 .41335 Mtetra
.89085 .41335 .89248 .41571 .89664 .41443 .89501 .41207 Mtetra
.89501 .41207 .89664 .41443 .90079 .41316 .89917 .41079 Mtetra
.89917 .41079 .90079 .41316 .90496 .41188 .90334 .40951 Mtetra
.90334 .40951 .90496 .41188 .90913 .4106 .90752 .40823 Mtetra
.90752 .40823 .90913 .4106 .91331 .40931 .9117 .40694 Mtetra
.9117 .40694 .91331 .40931 .91749 .40803 .91589 .40565 Mtetra
.91589 .40565 .91749 .40803 .92168 .40674 .92008 .40436 Mtetra
.92008 .40436 .92168 .40674 .92587 .40545 .92428 .40307 Mtetra
.92428 .40307 .92587 .40545 .93007 .40416 .92848 .40178 Mtetra
.92848 .40178 .93007 .40416 .93428 .40287 .93269 .40048 Mtetra
.93269 .40048 .93428 .40287 .93849 .40158 .93691 .39918 Mtetra
.93691 .39918 .93849 .40158 .94271 .40028 .94113 .39789 Mtetra
.94113 .39789 .94271 .40028 .94693 .39899 .94536 .39659 Mtetra
.36996 .57097 .37207 .57294 .37552 .57187 .37342 .56991 Mtetra
.37342 .56991 .37552 .57187 .37898 .57081 .37688 .56884 Mtetra
.37688 .56884 .37898 .57081 .38244 .56974 .38034 .56777 Mtetra
.38034 .56777 .38244 .56974 .38591 .56868 .38381 .5667 Mtetra
.38381 .5667 .38591 .56868 .38938 .56761 .38729 .56563 Mtetra
.38729 .56563 .38938 .56761 .39286 .56654 .39077 .56456 Mtetra
.39077 .56456 .39286 .56654 .39634 .56547 .39425 .56349 Mtetra
.39425 .56349 .39634 .56547 .39983 .5644 .39774 .56241 Mtetra
.39774 .56241 .39983 .5644 .40332 .56332 .40123 .56134 Mtetra
.40123 .56134 .40332 .56332 .40681 .56225 .40473 .56026 Mtetra
.40473 .56026 .40681 .56225 .41031 .56117 .40823 .55918 Mtetra
.40823 .55918 .41031 .56117 .41381 .56009 .41174 .5581 Mtetra
.41174 .5581 .41381 .56009 .41732 .55901 .41525 .55702 Mtetra
.41525 .55702 .41732 .55901 .42083 .55793 .41877 .55594 Mtetra
.41877 .55594 .42083 .55793 .42435 .55685 .42229 .55485 Mtetra
.42229 .55485 .42435 .55685 .42787 .55577 .42581 .55376 Mtetra
.42581 .55376 .42787 .55577 .4314 .55468 .42934 .55268 Mtetra
.42934 .55268 .4314 .55468 .43493 .5536 .43287 .55159 Mtetra
.43287 .55159 .43493 .5536 .43847 .55251 .43641 .5505 Mtetra
.43641 .5505 .43847 .55251 .44201 .55142 .43996 .54941 Mtetra
.43996 .54941 .44201 .55142 .44555 .55033 .4435 .54831 Mtetra
.4435 .54831 .44555 .55033 .4491 .54924 .44706 .54722 Mtetra
.44706 .54722 .4491 .54924 .45266 .54815 .45061 .54612 Mtetra
.45061 .54612 .45266 .54815 .45622 .54705 .45418 .54503 Mtetra
.45418 .54503 .45622 .54705 .45978 .54595 .45774 .54393 Mtetra
.45774 .54393 .45978 .54595 .46335 .54486 .46131 .54283 Mtetra
.46131 .54283 .46335 .54486 .46692 .54376 .46489 .54172 Mtetra
.46489 .54172 .46692 .54376 .4705 .54266 .46847 .54062 Mtetra
.46847 .54062 .4705 .54266 .47408 .54155 .47206 .53952 Mtetra
.47206 .53952 .47408 .54155 .47767 .54045 .47565 .53841 Mtetra
.47565 .53841 .47767 .54045 .48126 .53935 .47924 .5373 Mtetra
.47924 .5373 .48126 .53935 .48486 .53824 .48284 .53619 Mtetra
.48284 .53619 .48486 .53824 .48846 .53713 .48645 .53508 Mtetra
.48645 .53508 .48846 .53713 .49206 .53602 .49006 .53397 Mtetra
.49006 .53397 .49206 .53602 .49567 .53491 .49367 .53286 Mtetra
.49367 .53286 .49567 .53491 .49929 .5338 .49729 .53174 Mtetra
.49729 .53174 .49929 .5338 .50291 .53269 .50091 .53063 Mtetra
.50091 .53063 .50291 .53269 .50654 .53157 .50454 .52951 Mtetra
.50454 .52951 .50654 .53157 .51017 .53045 .50817 .52839 Mtetra
.50817 .52839 .51017 .53045 .5138 .52934 .51181 .52727 Mtetra
.51181 .52727 .5138 .52934 .51744 .52822 .51545 .52615 Mtetra
.51545 .52615 .51744 .52822 .52109 .5271 .5191 .52502 Mtetra
.5191 .52502 .52109 .5271 .52473 .52597 .52275 .5239 Mtetra
.879 .45 .058 r
.52275 .5239 .52473 .52597 .52839 .52485 .52642 .53189 Mtetra
.483 .177 .371 r
.52642 .53189 .52839 .52485 .53207 .53285 .53009 .53077 Mtetra
.663 .742 .909 r
.53009 .53077 .53207 .53285 .53574 .53172 .53376 .52964 Mtetra
.53376 .52964 .53574 .53172 .53942 .5306 .53745 .52851 Mtetra
.53745 .52851 .53942 .5306 .5431 .52947 .54113 .52738 Mtetra
.54113 .52738 .5431 .52947 .54679 .52834 .54483 .52625 Mtetra
.54483 .52625 .54679 .52834 .55049 .52721 .54852 .52512 Mtetra
.54852 .52512 .55049 .52721 .55418 .52608 .55222 .52399 Mtetra
.55222 .52399 .55418 .52608 .55789 .52495 .55593 .52285 Mtetra
.55593 .52285 .55789 .52495 .5616 .52381 .55964 .52171 Mtetra
.55964 .52171 .5616 .52381 .56531 .52267 .56336 .52057 Mtetra
.56336 .52057 .56531 .52267 .56903 .52154 .56708 .51943 Mtetra
.56708 .51943 .56903 .52154 .57275 .5204 .57081 .51829 Mtetra
.57081 .51829 .57275 .5204 .57648 .51926 .57454 .51715 Mtetra
.57454 .51715 .57648 .51926 .58021 .51812 .57828 .516 Mtetra
.57828 .516 .58021 .51812 .58395 .51697 .58202 .51486 Mtetra
.58202 .51486 .58395 .51697 .5877 .51583 .58577 .51371 Mtetra
.58577 .51371 .5877 .51583 .59144 .51468 .58952 .51256 Mtetra
.58952 .51256 .59144 .51468 .5952 .51353 .59327 .51141 Mtetra
.59327 .51141 .5952 .51353 .59896 .51238 .59704 .51025 Mtetra
.59704 .51025 .59896 .51238 .60272 .51123 .6008 .5091 Mtetra
.6008 .5091 .60272 .51123 .60649 .51008 .60458 .50794 Mtetra
.60458 .50794 .60649 .51008 .61026 .50892 .60835 .50679 Mtetra
.60835 .50679 .61026 .50892 .6138 .49858 .61214 .50563 Mtetra
0 0 .033 r
.61214 .50563 .6138 .49858 .61757 .49742 .61567 .49527 Mtetra
.664 .741 .908 r
.61567 .49527 .61757 .49742 .62135 .49625 .61945 .4941 Mtetra
.61945 .4941 .62135 .49625 .62513 .49509 .62324 .49294 Mtetra
.62324 .49294 .62513 .49509 .62892 .49392 .62703 .49177 Mtetra
.62703 .49177 .62892 .49392 .63272 .49276 .63083 .4906 Mtetra
.63083 .4906 .63272 .49276 .63651 .49159 .63463 .48943 Mtetra
.63463 .48943 .63651 .49159 .64032 .49042 .63844 .48825 Mtetra
.63844 .48825 .64032 .49042 .64413 .48925 .64225 .48708 Mtetra
.64225 .48708 .64413 .48925 .64794 .48807 .64607 .4859 Mtetra
.64607 .4859 .64794 .48807 .65176 .4869 .6499 .48472 Mtetra
.6499 .48472 .65176 .4869 .65559 .48572 .65372 .48355 Mtetra
.65372 .48355 .65559 .48572 .65942 .48454 .65756 .48236 Mtetra
.65756 .48236 .65942 .48454 .66325 .48336 .6614 .48118 Mtetra
.6614 .48118 .66325 .48336 .66709 .48218 .66524 .48 Mtetra
.66524 .48 .66709 .48218 .67094 .481 .66909 .47881 Mtetra
.66909 .47881 .67094 .481 .67479 .47981 .67295 .47762 Mtetra
.67295 .47762 .67479 .47981 .67865 .47863 .67681 .47643 Mtetra
.67681 .47643 .67865 .47863 .68251 .47744 .68067 .47524 Mtetra
.68067 .47524 .68251 .47744 .68638 .47625 .68454 .47405 Mtetra
.68454 .47405 .68638 .47625 .69025 .47506 .68842 .47286 Mtetra
.68842 .47286 .69025 .47506 .69413 .47387 .6923 .47166 Mtetra
.6923 .47166 .69413 .47387 .69801 .47267 .69619 .47046 Mtetra
.69619 .47046 .69801 .47267 .7019 .47148 .70008 .46926 Mtetra
.70008 .46926 .7019 .47148 .70579 .47028 .70397 .46806 Mtetra
.70397 .46806 .70579 .47028 .70969 .46908 .70788 .46686 Mtetra
.70788 .46686 .70969 .46908 .71359 .46788 .71178 .46566 Mtetra
.71178 .46566 .71359 .46788 .7175 .46668 .7157 .46445 Mtetra
.7157 .46445 .7175 .46668 .72142 .46547 .71962 .46324 Mtetra
.71962 .46324 .72142 .46547 .72534 .46427 .72354 .46203 Mtetra
.72354 .46203 .72534 .46427 .72926 .46306 .72747 .46082 Mtetra
.72747 .46082 .72926 .46306 .7332 .46185 .73141 .45961 Mtetra
.73141 .45961 .7332 .46185 .73713 .46064 .73535 .4584 Mtetra
.73535 .4584 .73713 .46064 .74107 .45943 .73929 .45718 Mtetra
.73929 .45718 .74107 .45943 .74502 .45821 .74324 .45596 Mtetra
.74324 .45596 .74502 .45821 .74897 .45699 .7472 .45475 Mtetra
.7472 .45475 .74897 .45699 .75293 .45578 .75116 .45352 Mtetra
.75116 .45352 .75293 .45578 .7569 .45456 .75513 .4523 Mtetra
.75513 .4523 .7569 .45456 .76087 .45334 .7591 .45108 Mtetra
.7591 .45108 .76087 .45334 .76484 .45211 .76308 .44985 Mtetra
.76308 .44985 .76484 .45211 .76882 .45089 .76707 .44863 Mtetra
.76707 .44863 .76882 .45089 .77281 .44966 .77106 .4474 Mtetra
.77106 .4474 .77281 .44966 .7768 .44844 .77505 .44616 Mtetra
.77505 .44616 .7768 .44844 .7808 .44721 .77905 .44493 Mtetra
.77905 .44493 .7808 .44721 .7848 .44598 .78306 .4437 Mtetra
.78306 .4437 .7848 .44598 .78881 .44474 .78707 .44246 Mtetra
.78707 .44246 .78881 .44474 .79282 .44351 .79109 .44122 Mtetra
.79109 .44122 .79282 .44351 .79684 .44227 .79511 .43998 Mtetra
.79511 .43998 .79684 .44227 .80086 .44103 .79914 .43874 Mtetra
.79914 .43874 .80086 .44103 .80489 .43979 .80317 .4375 Mtetra
.80317 .4375 .80489 .43979 .80893 .43855 .80721 .43626 Mtetra
.80721 .43626 .80893 .43855 .81297 .43731 .81126 .43501 Mtetra
.81126 .43501 .81297 .43731 .81702 .43606 .81531 .43376 Mtetra
.81531 .43376 .81702 .43606 .82107 .43482 .81937 .43251 Mtetra
.81937 .43251 .82107 .43482 .82513 .43357 .82343 .43126 Mtetra
.82343 .43126 .82513 .43357 .8292 .43232 .8275 .43001 Mtetra
.8275 .43001 .8292 .43232 .83327 .43107 .83157 .42875 Mtetra
.83157 .42875 .83327 .43107 .83734 .42981 .83565 .42749 Mtetra
.83565 .42749 .83734 .42981 .84142 .42856 .83974 .42623 Mtetra
.83974 .42623 .84142 .42856 .84551 .4273 .84383 .42497 Mtetra
.84383 .42497 .84551 .4273 .8496 .42604 .84793 .42371 Mtetra
.84793 .42371 .8496 .42604 .8537 .42478 .85203 .42245 Mtetra
.85203 .42245 .8537 .42478 .85781 .42352 .85614 .42118 Mtetra
.85614 .42118 .85781 .42352 .86192 .42225 .86025 .41991 Mtetra
.86025 .41991 .86192 .42225 .86603 .42099 .86438 .41864 Mtetra
.86438 .41864 .86603 .42099 .87016 .41972 .8685 .41737 Mtetra
.8685 .41737 .87016 .41972 .87428 .41845 .87263 .4161 Mtetra
.87263 .4161 .87428 .41845 .87842 .41718 .87677 .41482 Mtetra
.87677 .41482 .87842 .41718 .88256 .4159 .88092 .41355 Mtetra
.88092 .41355 .88256 .4159 .8867 .41463 .88506 .41227 Mtetra
.88506 .41227 .8867 .41463 .89085 .41335 .88922 .41099 Mtetra
.88922 .41099 .89085 .41335 .89501 .41207 .89338 .40971 Mtetra
.89338 .40971 .89501 .41207 .89917 .41079 .89755 .40842 Mtetra
.89755 .40842 .89917 .41079 .90334 .40951 .90172 .40714 Mtetra
.90172 .40714 .90334 .40951 .90752 .40823 .9059 .40585 Mtetra
.9059 .40585 .90752 .40823 .9117 .40694 .91009 .40456 Mtetra
.91009 .40456 .9117 .40694 .91589 .40565 .91428 .40327 Mtetra
.91428 .40327 .91589 .40565 .92008 .40436 .91847 .40198 Mtetra
.91847 .40198 .92008 .40436 .92428 .40307 .92268 .40068 Mtetra
.92268 .40068 .92428 .40307 .92848 .40178 .92689 .39938 Mtetra
.92689 .39938 .92848 .40178 .93269 .40048 .9311 .39809 Mtetra
.9311 .39809 .93269 .40048 .93691 .39918 .93532 .39679 Mtetra
.93532 .39679 .93691 .39918 .94113 .39789 .93955 .39548 Mtetra
.93955 .39548 .94113 .39789 .94536 .39659 .94378 .39418 Mtetra
.36785 .56901 .36996 .57097 .37342 .56991 .37131 .56794 Mtetra
.37131 .56794 .37342 .56991 .37688 .56884 .37477 .56687 Mtetra
.37477 .56687 .37688 .56884 .38034 .56777 .37824 .5658 Mtetra
.37824 .5658 .38034 .56777 .38381 .5667 .38171 .56473 Mtetra
.38171 .56473 .38381 .5667 .38729 .56563 .38519 .56365 Mtetra
.38519 .56365 .38729 .56563 .39077 .56456 .38867 .56258 Mtetra
.38867 .56258 .39077 .56456 .39425 .56349 .39216 .5615 Mtetra
.39216 .5615 .39425 .56349 .39774 .56241 .39565 .56043 Mtetra
.39565 .56043 .39774 .56241 .40123 .56134 .39914 .55935 Mtetra
.39914 .55935 .40123 .56134 .40473 .56026 .40265 .55827 Mtetra
.40265 .55827 .40473 .56026 .40823 .55918 .40615 .55719 Mtetra
.40615 .55719 .40823 .55918 .41174 .5581 .40966 .5561 Mtetra
.40966 .5561 .41174 .5581 .41525 .55702 .41317 .55502 Mtetra
.41317 .55502 .41525 .55702 .41877 .55594 .41669 .55393 Mtetra
.41669 .55393 .41877 .55594 .42229 .55485 .42022 .55284 Mtetra
.42022 .55284 .42229 .55485 .42581 .55376 .42374 .55176 Mtetra
.42374 .55176 .42581 .55376 .42934 .55268 .42728 .55067 Mtetra
.42728 .55067 .42934 .55268 .43287 .55159 .43081 .54957 Mtetra
.43081 .54957 .43287 .55159 .43641 .5505 .43435 .54848 Mtetra
.43435 .54848 .43641 .5505 .43996 .54941 .4379 .54739 Mtetra
.4379 .54739 .43996 .54941 .4435 .54831 .44145 .54629 Mtetra
.44145 .54629 .4435 .54831 .44706 .54722 .44501 .54519 Mtetra
.44501 .54519 .44706 .54722 .45061 .54612 .44857 .5441 Mtetra
.44857 .5441 .45061 .54612 .45418 .54503 .45213 .543 Mtetra
.45213 .543 .45418 .54503 .45774 .54393 .4557 .54189 Mtetra
.4557 .54189 .45774 .54393 .46131 .54283 .45928 .54079 Mtetra
.45928 .54079 .46131 .54283 .46489 .54172 .46286 .53969 Mtetra
.46286 .53969 .46489 .54172 .46847 .54062 .46644 .53858 Mtetra
.46644 .53858 .46847 .54062 .47206 .53952 .47003 .53747 Mtetra
.47003 .53747 .47206 .53952 .47565 .53841 .47362 .53636 Mtetra
.47362 .53636 .47565 .53841 .47924 .5373 .47722 .53525 Mtetra
.47722 .53525 .47924 .5373 .48284 .53619 .48082 .53414 Mtetra
.48082 .53414 .48284 .53619 .48645 .53508 .48443 .53303 Mtetra
.48443 .53303 .48645 .53508 .49006 .53397 .48804 .53191 Mtetra
.48804 .53191 .49006 .53397 .49367 .53286 .49166 .5308 Mtetra
.49166 .5308 .49367 .53286 .49729 .53174 .49528 .52968 Mtetra
.49528 .52968 .49729 .53174 .50091 .53063 .49891 .52856 Mtetra
.49891 .52856 .50091 .53063 .50454 .52951 .50254 .52744 Mtetra
.50254 .52744 .50454 .52951 .50817 .52839 .50617 .52632 Mtetra
.50617 .52632 .50817 .52839 .51181 .52727 .50982 .5252 Mtetra
.50982 .5252 .51181 .52727 .51545 .52615 .51346 .52407 Mtetra
.51346 .52407 .51545 .52615 .5191 .52502 .51711 .52294 Mtetra
.51711 .52294 .5191 .52502 .52275 .5239 .52077 .52182 Mtetra
.879 .45 .058 r
.52077 .52182 .52275 .5239 .52642 .53189 .52443 .52982 Mtetra
.663 .742 .909 r
.52443 .52982 .52642 .53189 .53009 .53077 .5281 .52869 Mtetra
.5281 .52869 .53009 .53077 .53376 .52964 .53178 .52756 Mtetra
.53178 .52756 .53376 .52964 .53745 .52851 .53547 .52643 Mtetra
.53547 .52643 .53745 .52851 .54113 .52738 .53916 .52529 Mtetra
.53916 .52529 .54113 .52738 .54483 .52625 .54285 .52416 Mtetra
.54285 .52416 .54483 .52625 .54852 .52512 .54655 .52302 Mtetra
.54655 .52302 .54852 .52512 .55222 .52399 .55026 .52189 Mtetra
.55026 .52189 .55222 .52399 .55593 .52285 .55397 .52075 Mtetra
.55397 .52075 .55593 .52285 .55964 .52171 .55768 .51961 Mtetra
.55768 .51961 .55964 .52171 .56336 .52057 .5614 .51847 Mtetra
.5614 .51847 .56336 .52057 .56708 .51943 .56513 .51732 Mtetra
.56513 .51732 .56708 .51943 .57081 .51829 .56886 .51618 Mtetra
.56886 .51618 .57081 .51829 .57454 .51715 .57259 .51503 Mtetra
.57259 .51503 .57454 .51715 .57828 .516 .57633 .51388 Mtetra
.57633 .51388 .57828 .516 .58202 .51486 .58008 .51273 Mtetra
.58008 .51273 .58202 .51486 .58577 .51371 .58383 .51158 Mtetra
.58383 .51158 .58577 .51371 .58952 .51256 .58759 .51043 Mtetra
.58759 .51043 .58952 .51256 .59327 .51141 .59135 .50928 Mtetra
.59135 .50928 .59327 .51141 .59704 .51025 .59511 .50812 Mtetra
.59511 .50812 .59704 .51025 .6008 .5091 .59888 .50696 Mtetra
.59888 .50696 .6008 .5091 .60458 .50794 .60266 .50581 Mtetra
.60266 .50581 .60458 .50794 .60835 .50679 .60644 .50464 Mtetra
.60644 .50464 .60835 .50679 .61214 .50563 .61022 .50348 Mtetra
.964 .675 .435 r
.61022 .50348 .61214 .50563 .61567 .49527 .61695 .61194 Mtetra
.564 .349 .547 r
.61695 .61194 .61567 .49527 .61945 .4941 .62088 .61081 Mtetra
.009 0 .405 r
.62088 .61081 .61945 .4941 .62324 .49294 .62135 .49078 Mtetra
.664 .741 .908 r
.62135 .49078 .62324 .49294 .62703 .49177 .62514 .48961 Mtetra
.62514 .48961 .62703 .49177 .63083 .4906 .62894 .48843 Mtetra
.62894 .48843 .63083 .4906 .63463 .48943 .63275 .48726 Mtetra
.63275 .48726 .63463 .48943 .63844 .48825 .63656 .48608 Mtetra
.63656 .48608 .63844 .48825 .64225 .48708 .64038 .48491 Mtetra
.64038 .48491 .64225 .48708 .64607 .4859 .6442 .48373 Mtetra
.6442 .48373 .64607 .4859 .6499 .48472 .64802 .48255 Mtetra
.64802 .48255 .6499 .48472 .65372 .48355 .65186 .48136 Mtetra
.65186 .48136 .65372 .48355 .65756 .48236 .65569 .48018 Mtetra
.65569 .48018 .65756 .48236 .6614 .48118 .65954 .47899 Mtetra
.65954 .47899 .6614 .48118 .66524 .48 .66338 .47781 Mtetra
.66338 .47781 .66524 .48 .66909 .47881 .66724 .47662 Mtetra
.66724 .47662 .66909 .47881 .67295 .47762 .6711 .47543 Mtetra
.6711 .47543 .67295 .47762 .67681 .47643 .67496 .47423 Mtetra
.67496 .47423 .67681 .47643 .68067 .47524 .67883 .47304 Mtetra
.67883 .47304 .68067 .47524 .68454 .47405 .6827 .47184 Mtetra
.6827 .47184 .68454 .47405 .68842 .47286 .68658 .47065 Mtetra
.68658 .47065 .68842 .47286 .6923 .47166 .69047 .46945 Mtetra
.69047 .46945 .6923 .47166 .69619 .47046 .69436 .46825 Mtetra
.69436 .46825 .69619 .47046 .70008 .46926 .69825 .46705 Mtetra
.69825 .46705 .70008 .46926 .70397 .46806 .70215 .46584 Mtetra
.70215 .46584 .70397 .46806 .70788 .46686 .70606 .46464 Mtetra
.70606 .46464 .70788 .46686 .71178 .46566 .70997 .46343 Mtetra
.70997 .46343 .71178 .46566 .7157 .46445 .71389 .46222 Mtetra
.71389 .46222 .7157 .46445 .71962 .46324 .71781 .46101 Mtetra
.71781 .46101 .71962 .46324 .72354 .46203 .72174 .4598 Mtetra
.72174 .4598 .72354 .46203 .72747 .46082 .72567 .45858 Mtetra
.72567 .45858 .72747 .46082 .73141 .45961 .72961 .45737 Mtetra
.72961 .45737 .73141 .45961 .73535 .4584 .73355 .45615 Mtetra
.73355 .45615 .73535 .4584 .73929 .45718 .7375 .45493 Mtetra
.7375 .45493 .73929 .45718 .74324 .45596 .74146 .45371 Mtetra
.74146 .45371 .74324 .45596 .7472 .45475 .74542 .45249 Mtetra
.74542 .45249 .7472 .45475 .75116 .45352 .74939 .45127 Mtetra
.74939 .45127 .75116 .45352 .75513 .4523 .75336 .45004 Mtetra
.75336 .45004 .75513 .4523 .7591 .45108 .75733 .44881 Mtetra
.75733 .44881 .7591 .45108 .76308 .44985 .76132 .44759 Mtetra
.76132 .44759 .76308 .44985 .76707 .44863 .76531 .44635 Mtetra
.76531 .44635 .76707 .44863 .77106 .4474 .7693 .44512 Mtetra
.7693 .44512 .77106 .4474 .77505 .44616 .7733 .44389 Mtetra
.7733 .44389 .77505 .44616 .77905 .44493 .7773 .44265 Mtetra
.7773 .44265 .77905 .44493 .78306 .4437 .78131 .44141 Mtetra
.78131 .44141 .78306 .4437 .78707 .44246 .78533 .44018 Mtetra
.78533 .44018 .78707 .44246 .79109 .44122 .78935 .43893 Mtetra
.78935 .43893 .79109 .44122 .79511 .43998 .79338 .43769 Mtetra
.79338 .43769 .79511 .43998 .79914 .43874 .79741 .43645 Mtetra
.79741 .43645 .79914 .43874 .80317 .4375 .80145 .4352 Mtetra
.80145 .4352 .80317 .4375 .80721 .43626 .80549 .43395 Mtetra
.80549 .43395 .80721 .43626 .81126 .43501 .80954 .4327 Mtetra
.80954 .4327 .81126 .43501 .81531 .43376 .8136 .43145 Mtetra
.8136 .43145 .81531 .43376 .81937 .43251 .81766 .4302 Mtetra
.81766 .4302 .81937 .43251 .82343 .43126 .82173 .42894 Mtetra
.82173 .42894 .82343 .43126 .8275 .43001 .8258 .42769 Mtetra
.8258 .42769 .8275 .43001 .83157 .42875 .82988 .42643 Mtetra
.82988 .42643 .83157 .42875 .83565 .42749 .83396 .42517 Mtetra
.83396 .42517 .83565 .42749 .83974 .42623 .83805 .42391 Mtetra
.83805 .42391 .83974 .42623 .84383 .42497 .84215 .42264 Mtetra
.84215 .42264 .84383 .42497 .84793 .42371 .84625 .42138 Mtetra
.84625 .42138 .84793 .42371 .85203 .42245 .85036 .42011 Mtetra
.85036 .42011 .85203 .42245 .85614 .42118 .85447 .41884 Mtetra
.85447 .41884 .85614 .42118 .86025 .41991 .85859 .41757 Mtetra
.85859 .41757 .86025 .41991 .86438 .41864 .86271 .4163 Mtetra
.86271 .4163 .86438 .41864 .8685 .41737 .86684 .41502 Mtetra
.86684 .41502 .8685 .41737 .87263 .4161 .87098 .41374 Mtetra
.87098 .41374 .87263 .4161 .87677 .41482 .87512 .41247 Mtetra
.87512 .41247 .87677 .41482 .88092 .41355 .87927 .41119 Mtetra
.87927 .41119 .88092 .41355 .88506 .41227 .88342 .4099 Mtetra
.88342 .4099 .88506 .41227 .88922 .41099 .88758 .40862 Mtetra
.88758 .40862 .88922 .41099 .89338 .40971 .89175 .40734 Mtetra
.89175 .40734 .89338 .40971 .89755 .40842 .89592 .40605 Mtetra
.89592 .40605 .89755 .40842 .90172 .40714 .9001 .40476 Mtetra
.9001 .40476 .90172 .40714 .9059 .40585 .90428 .40347 Mtetra
.90428 .40347 .9059 .40585 .91009 .40456 .90847 .40218 Mtetra
.90847 .40218 .91009 .40456 .91428 .40327 .91267 .40088 Mtetra
.91267 .40088 .91428 .40327 .91847 .40198 .91687 .39958 Mtetra
.91687 .39958 .91847 .40198 .92268 .40068 .92107 .39829 Mtetra
.92107 .39829 .92268 .40068 .92689 .39938 .92529 .39699 Mtetra
.92529 .39699 .92689 .39938 .9311 .39809 .92951 .39568 Mtetra
.92951 .39568 .9311 .39809 .93532 .39679 .93373 .39438 Mtetra
.93373 .39438 .93532 .39679 .93955 .39548 .93796 .39307 Mtetra
.93796 .39307 .93955 .39548 .94378 .39418 .9422 .39177 Mtetra
.36573 .56703 .36785 .56901 .37131 .56794 .36919 .56596 Mtetra
.36919 .56596 .37131 .56794 .37477 .56687 .37266 .56489 Mtetra
.37266 .56489 .37477 .56687 .37824 .5658 .37613 .56382 Mtetra
.37613 .56382 .37824 .5658 .38171 .56473 .3796 .56274 Mtetra
.3796 .56274 .38171 .56473 .38519 .56365 .38309 .56167 Mtetra
.38309 .56167 .38519 .56365 .38867 .56258 .38657 .56059 Mtetra
.38657 .56059 .38867 .56258 .39216 .5615 .39006 .55951 Mtetra
.39006 .55951 .39216 .5615 .39565 .56043 .39355 .55843 Mtetra
.39355 .55843 .39565 .56043 .39914 .55935 .39705 .55735 Mtetra
.39705 .55735 .39914 .55935 .40265 .55827 .40056 .55627 Mtetra
.40056 .55627 .40265 .55827 .40615 .55719 .40406 .55518 Mtetra
.40406 .55518 .40615 .55719 .40966 .5561 .40758 .5541 Mtetra
.40758 .5541 .40966 .5561 .41317 .55502 .41109 .55301 Mtetra
.41109 .55301 .41317 .55502 .41669 .55393 .41461 .55192 Mtetra
.41461 .55192 .41669 .55393 .42022 .55284 .41814 .55083 Mtetra
.41814 .55083 .42022 .55284 .42374 .55176 .42167 .54974 Mtetra
.42167 .54974 .42374 .55176 .42728 .55067 .42521 .54865 Mtetra
.42521 .54865 .42728 .55067 .43081 .54957 .42875 .54756 Mtetra
.42875 .54756 .43081 .54957 .43435 .54848 .43229 .54646 Mtetra
.43229 .54646 .43435 .54848 .4379 .54739 .43584 .54536 Mtetra
.43584 .54536 .4379 .54739 .44145 .54629 .43939 .54426 Mtetra
.43939 .54426 .44145 .54629 .44501 .54519 .44295 .54316 Mtetra
.44295 .54316 .44501 .54519 .44857 .5441 .44652 .54206 Mtetra
.44652 .54206 .44857 .5441 .45213 .543 .45008 .54096 Mtetra
.45008 .54096 .45213 .543 .4557 .54189 .45366 .53986 Mtetra
.45366 .53986 .4557 .54189 .45928 .54079 .45723 .53875 Mtetra
.45723 .53875 .45928 .54079 .46286 .53969 .46082 .53764 Mtetra
.46082 .53764 .46286 .53969 .46644 .53858 .4644 .53654 Mtetra
.4644 .53654 .46644 .53858 .47003 .53747 .46799 .53543 Mtetra
.46799 .53543 .47003 .53747 .47362 .53636 .47159 .53431 Mtetra
.47159 .53431 .47362 .53636 .47722 .53525 .47519 .5332 Mtetra
.47519 .5332 .47722 .53525 .48082 .53414 .4788 .53209 Mtetra
.4788 .53209 .48082 .53414 .48443 .53303 .48241 .53097 Mtetra
.48241 .53097 .48443 .53303 .48804 .53191 .48602 .52985 Mtetra
.48602 .52985 .48804 .53191 .49166 .5308 .48964 .52873 Mtetra
.48964 .52873 .49166 .5308 .49528 .52968 .49327 .52761 Mtetra
.49327 .52761 .49528 .52968 .49891 .52856 .4969 .52649 Mtetra
.4969 .52649 .49891 .52856 .50254 .52744 .50053 .52537 Mtetra
.50053 .52537 .50254 .52744 .50617 .52632 .50417 .52424 Mtetra
.50417 .52424 .50617 .52632 .50982 .5252 .50782 .52312 Mtetra
.50782 .52312 .50982 .5252 .51346 .52407 .51147 .52199 Mtetra
.51147 .52199 .51346 .52407 .51711 .52294 .51512 .52086 Mtetra
.51512 .52086 .51711 .52294 .52077 .52182 .51878 .51973 Mtetra
.879 .45 .058 r
.51878 .51973 .52077 .52182 .52443 .52982 .52243 .52773 Mtetra
.663 .742 .909 r
.52243 .52773 .52443 .52982 .5281 .52869 .52611 .5266 Mtetra
.52611 .5266 .5281 .52869 .53178 .52756 .5298 .52547 Mtetra
.5298 .52547 .53178 .52756 .53547 .52643 .53349 .52433 Mtetra
.53349 .52433 .53547 .52643 .53916 .52529 .53718 .5232 Mtetra
.53718 .5232 .53916 .52529 .54285 .52416 .54088 .52206 Mtetra
.54088 .52206 .54285 .52416 .54655 .52302 .54458 .52092 Mtetra
.54458 .52092 .54655 .52302 .55026 .52189 .54829 .51978 Mtetra
.54829 .51978 .55026 .52189 .55397 .52075 .552 .51864 Mtetra
.552 .51864 .55397 .52075 .55768 .51961 .55572 .5175 Mtetra
.55572 .5175 .55768 .51961 .5614 .51847 .55944 .51635 Mtetra
.55944 .51635 .5614 .51847 .56513 .51732 .56317 .51521 Mtetra
.56317 .51521 .56513 .51732 .56886 .51618 .56691 .51406 Mtetra
.56691 .51406 .56886 .51618 .57259 .51503 .57064 .51291 Mtetra
.57064 .51291 .57259 .51503 .57633 .51388 .57439 .51176 Mtetra
.57439 .51176 .57633 .51388 .58008 .51273 .57814 .51061 Mtetra
.57814 .51061 .58008 .51273 .58383 .51158 .58189 .50945 Mtetra
.58189 .50945 .58383 .51158 .58759 .51043 .58565 .5083 Mtetra
.58565 .5083 .58759 .51043 .59135 .50928 .58941 .50714 Mtetra
.58941 .50714 .59135 .50928 .59511 .50812 .59318 .50598 Mtetra
.59318 .50598 .59511 .50812 .59888 .50696 .59696 .50482 Mtetra
.59696 .50482 .59888 .50696 .60266 .50581 .60073 .50366 Mtetra
.60073 .50366 .60266 .50581 .60644 .50464 .60452 .5025 Mtetra
.964 .675 .436 r
.60452 .5025 .60644 .50464 .61022 .50348 .61106 .61099 Mtetra
.563 .347 .545 r
.61106 .61099 .61022 .50348 .61695 .61194 .61498 .60986 Mtetra
.654 .753 .922 r
.61498 .60986 .61695 .61194 .62088 .61081 .61891 .60873 Mtetra
.61891 .60873 .62088 .61081 .62135 .49078 .62284 .6076 Mtetra
.563 .348 .546 r
.62284 .6076 .62135 .49078 .62514 .48961 .62678 .60647 Mtetra
.62678 .60647 .62514 .48961 .62894 .48843 .63072 .60533 Mtetra
.63072 .60533 .62894 .48843 .63275 .48726 .63467 .6042 Mtetra
.63467 .6042 .63275 .48726 .63656 .48608 .63863 .60306 Mtetra
.63863 .60306 .63656 .48608 .64038 .48491 .64259 .60192 Mtetra
.021 0 .412 r
.64259 .60192 .64038 .48491 .6442 .48373 .64232 .48155 Mtetra
.664 .741 .908 r
.64232 .48155 .6442 .48373 .64802 .48255 .64615 .48036 Mtetra
.64615 .48036 .64802 .48255 .65186 .48136 .64998 .47918 Mtetra
.64998 .47918 .65186 .48136 .65569 .48018 .65382 .47799 Mtetra
.65382 .47799 .65569 .48018 .65954 .47899 .65767 .4768 Mtetra
.65767 .4768 .65954 .47899 .66338 .47781 .66152 .47561 Mtetra
.66152 .47561 .66338 .47781 .66724 .47662 .66538 .47442 Mtetra
.66538 .47442 .66724 .47662 .6711 .47543 .66924 .47322 Mtetra
.66924 .47322 .6711 .47543 .67496 .47423 .67311 .47203 Mtetra
.67311 .47203 .67496 .47423 .67883 .47304 .67698 .47083 Mtetra
.67698 .47083 .67883 .47304 .6827 .47184 .68086 .46963 Mtetra
.68086 .46963 .6827 .47184 .68658 .47065 .68474 .46843 Mtetra
.68474 .46843 .68658 .47065 .69047 .46945 .68863 .46723 Mtetra
.68863 .46723 .69047 .46945 .69436 .46825 .69252 .46603 Mtetra
.69252 .46603 .69436 .46825 .69825 .46705 .69642 .46482 Mtetra
.69642 .46482 .69825 .46705 .70215 .46584 .70033 .46362 Mtetra
.70033 .46362 .70215 .46584 .70606 .46464 .70424 .46241 Mtetra
.70424 .46241 .70606 .46464 .70997 .46343 .70815 .4612 Mtetra
.70815 .4612 .70997 .46343 .71389 .46222 .71207 .45999 Mtetra
.71207 .45999 .71389 .46222 .71781 .46101 .716 .45877 Mtetra
.716 .45877 .71781 .46101 .72174 .4598 .71993 .45756 Mtetra
.71993 .45756 .72174 .4598 .72567 .45858 .72387 .45634 Mtetra
.72387 .45634 .72567 .45858 .72961 .45737 .72781 .45512 Mtetra
.72781 .45512 .72961 .45737 .73355 .45615 .73176 .4539 Mtetra
.73176 .4539 .73355 .45615 .7375 .45493 .73571 .45268 Mtetra
.73571 .45268 .7375 .45493 .74146 .45371 .73967 .45146 Mtetra
.73967 .45146 .74146 .45371 .74542 .45249 .74364 .45023 Mtetra
.74364 .45023 .74542 .45249 .74939 .45127 .74761 .449 Mtetra
.74761 .449 .74939 .45127 .75336 .45004 .75158 .44777 Mtetra
.75158 .44777 .75336 .45004 .75733 .44881 .75556 .44654 Mtetra
.75556 .44654 .75733 .44881 .76132 .44759 .75955 .44531 Mtetra
.75955 .44531 .76132 .44759 .76531 .44635 .76354 .44408 Mtetra
.76354 .44408 .76531 .44635 .7693 .44512 .76754 .44284 Mtetra
.76754 .44284 .7693 .44512 .7733 .44389 .77154 .4416 Mtetra
.77154 .4416 .7733 .44389 .7773 .44265 .77555 .44037 Mtetra
.77555 .44037 .7773 .44265 .78131 .44141 .77956 .43913 Mtetra
.77956 .43913 .78131 .44141 .78533 .44018 .78358 .43788 Mtetra
.78358 .43788 .78533 .44018 .78935 .43893 .78761 .43664 Mtetra
.78761 .43664 .78935 .43893 .79338 .43769 .79164 .43539 Mtetra
.79164 .43539 .79338 .43769 .79741 .43645 .79568 .43414 Mtetra
.79568 .43414 .79741 .43645 .80145 .4352 .79972 .4329 Mtetra
.79972 .4329 .80145 .4352 .80549 .43395 .80377 .43164 Mtetra
.80377 .43164 .80549 .43395 .80954 .4327 .80782 .43039 Mtetra
.80782 .43039 .80954 .4327 .8136 .43145 .81188 .42914 Mtetra
.81188 .42914 .8136 .43145 .81766 .4302 .81595 .42788 Mtetra
.81595 .42788 .81766 .4302 .82173 .42894 .82002 .42662 Mtetra
.82002 .42662 .82173 .42894 .8258 .42769 .82409 .42536 Mtetra
.82409 .42536 .8258 .42769 .82988 .42643 .82818 .4241 Mtetra
.82818 .4241 .82988 .42643 .83396 .42517 .83227 .42284 Mtetra
.83227 .42284 .83396 .42517 .83805 .42391 .83636 .42157 Mtetra
.83636 .42157 .83805 .42391 .84215 .42264 .84046 .4203 Mtetra
.84046 .4203 .84215 .42264 .84625 .42138 .84456 .41903 Mtetra
.84456 .41903 .84625 .42138 .85036 .42011 .84868 .41776 Mtetra
.84868 .41776 .85036 .42011 .85447 .41884 .85279 .41649 Mtetra
.85279 .41649 .85447 .41884 .85859 .41757 .85692 .41522 Mtetra
.85692 .41522 .85859 .41757 .86271 .4163 .86104 .41394 Mtetra
.86104 .41394 .86271 .4163 .86684 .41502 .86518 .41266 Mtetra
.86518 .41266 .86684 .41502 .87098 .41374 .86932 .41138 Mtetra
.86932 .41138 .87098 .41374 .87512 .41247 .87347 .4101 Mtetra
.87347 .4101 .87512 .41247 .87927 .41119 .87762 .40882 Mtetra
.87762 .40882 .87927 .41119 .88342 .4099 .88178 .40753 Mtetra
.88178 .40753 .88342 .4099 .88758 .40862 .88594 .40625 Mtetra
.88594 .40625 .88758 .40862 .89175 .40734 .89011 .40496 Mtetra
.89011 .40496 .89175 .40734 .89592 .40605 .89429 .40367 Mtetra
.89429 .40367 .89592 .40605 .9001 .40476 .89847 .40237 Mtetra
.89847 .40237 .9001 .40476 .90428 .40347 .90266 .40108 Mtetra
.90266 .40108 .90428 .40347 .90847 .40218 .90685 .39978 Mtetra
.90685 .39978 .90847 .40218 .91267 .40088 .91105 .39849 Mtetra
.91105 .39849 .91267 .40088 .91687 .39958 .91526 .39719 Mtetra
.91526 .39719 .91687 .39958 .92107 .39829 .91947 .39588 Mtetra
.91947 .39588 .92107 .39829 .92529 .39699 .92369 .39458 Mtetra
.92369 .39458 .92529 .39699 .92951 .39568 .92791 .39327 Mtetra
.92791 .39327 .92951 .39568 .93373 .39438 .93214 .39197 Mtetra
.93214 .39197 .93373 .39438 .93796 .39307 .93638 .39066 Mtetra
.93638 .39066 .93796 .39307 .9422 .39177 .94062 .38935 Mtetra
.36361 .56506 .36573 .56703 .36919 .56596 .36707 .56398 Mtetra
.36707 .56398 .36919 .56596 .37266 .56489 .37054 .56291 Mtetra
.37054 .56291 .37266 .56489 .37613 .56382 .37401 .56183 Mtetra
.37401 .56183 .37613 .56382 .3796 .56274 .37749 .56076 Mtetra
.37749 .56076 .3796 .56274 .38309 .56167 .38098 .55968 Mtetra
.38098 .55968 .38309 .56167 .38657 .56059 .38446 .5586 Mtetra
.38446 .5586 .38657 .56059 .39006 .55951 .38796 .55752 Mtetra
.38796 .55752 .39006 .55951 .39355 .55843 .39145 .55644 Mtetra
.39145 .55644 .39355 .55843 .39705 .55735 .39495 .55535 Mtetra
.39495 .55535 .39705 .55735 .40056 .55627 .39846 .55427 Mtetra
.39846 .55427 .40056 .55627 .40406 .55518 .40197 .55318 Mtetra
.40197 .55318 .40406 .55518 .40758 .5541 .40549 .55209 Mtetra
.40549 .55209 .40758 .5541 .41109 .55301 .40901 .551 Mtetra
.40901 .551 .41109 .55301 .41461 .55192 .41253 .54991 Mtetra
.41253 .54991 .41461 .55192 .41814 .55083 .41606 .54882 Mtetra
.41606 .54882 .41814 .55083 .42167 .54974 .41959 .54772 Mtetra
.41959 .54772 .42167 .54974 .42521 .54865 .42313 .54663 Mtetra
.42313 .54663 .42521 .54865 .42875 .54756 .42667 .54553 Mtetra
.42667 .54553 .42875 .54756 .43229 .54646 .43022 .54443 Mtetra
.43022 .54443 .43229 .54646 .43584 .54536 .43377 .54333 Mtetra
.43377 .54333 .43584 .54536 .43939 .54426 .43733 .54223 Mtetra
.43733 .54223 .43939 .54426 .44295 .54316 .44089 .54113 Mtetra
.44089 .54113 .44295 .54316 .44652 .54206 .44446 .54003 Mtetra
.44446 .54003 .44652 .54206 .45008 .54096 .44803 .53892 Mtetra
.44803 .53892 .45008 .54096 .45366 .53986 .4516 .53781 Mtetra
.4516 .53781 .45366 .53986 .45723 .53875 .45519 .53671 Mtetra
.45519 .53671 .45723 .53875 .46082 .53764 .45877 .5356 Mtetra
.45877 .5356 .46082 .53764 .4644 .53654 .46236 .53448 Mtetra
.46236 .53448 .4644 .53654 .46799 .53543 .46595 .53337 Mtetra
.46595 .53337 .46799 .53543 .47159 .53431 .46955 .53226 Mtetra
.46955 .53226 .47159 .53431 .47519 .5332 .47316 .53114 Mtetra
.47316 .53114 .47519 .5332 .4788 .53209 .47677 .53002 Mtetra
.47677 .53002 .4788 .53209 .48241 .53097 .48038 .52891 Mtetra
.48038 .52891 .48241 .53097 .48602 .52985 .484 .52779 Mtetra
.484 .52779 .48602 .52985 .48964 .52873 .48762 .52666 Mtetra
.48762 .52666 .48964 .52873 .49327 .52761 .49125 .52554 Mtetra
.49125 .52554 .49327 .52761 .4969 .52649 .49488 .52442 Mtetra
.49488 .52442 .4969 .52649 .50053 .52537 .49852 .52329 Mtetra
.49852 .52329 .50053 .52537 .50417 .52424 .50216 .52216 Mtetra
.50216 .52216 .50417 .52424 .50782 .52312 .50581 .52103 Mtetra
.50581 .52103 .50782 .52312 .51147 .52199 .50946 .5199 Mtetra
.50946 .5199 .51147 .52199 .51512 .52086 .51312 .51877 Mtetra
.51312 .51877 .51512 .52086 .51878 .51973 .51678 .51764 Mtetra
.879 .45 .058 r
.51678 .51764 .51878 .51973 .52243 .52773 .52044 .52564 Mtetra
.663 .742 .909 r
.52044 .52564 .52243 .52773 .52611 .5266 .52412 .52451 Mtetra
.52412 .52451 .52611 .5266 .5298 .52547 .52781 .52337 Mtetra
.52781 .52337 .5298 .52547 .53349 .52433 .5315 .52224 Mtetra
.5315 .52224 .53349 .52433 .53718 .5232 .53519 .5211 Mtetra
.53519 .5211 .53718 .5232 .54088 .52206 .5389 .51996 Mtetra
.5389 .51996 .54088 .52206 .54458 .52092 .5426 .51882 Mtetra
.5426 .51882 .54458 .52092 .54829 .51978 .54631 .51768 Mtetra
.54631 .51768 .54829 .51978 .552 .51864 .55003 .51653 Mtetra
.55003 .51653 .552 .51864 .55572 .5175 .55375 .51539 Mtetra
.55375 .51539 .55572 .5175 .55944 .51635 .55748 .51424 Mtetra
.55748 .51424 .55944 .51635 .56317 .51521 .56121 .51309 Mtetra
.56121 .51309 .56317 .51521 .56691 .51406 .56495 .51194 Mtetra
.56495 .51194 .56691 .51406 .57064 .51291 .56869 .51079 Mtetra
.56869 .51079 .57064 .51291 .57439 .51176 .57244 .50963 Mtetra
.57244 .50963 .57439 .51176 .57814 .51061 .57619 .50848 Mtetra
.57619 .50848 .57814 .51061 .58189 .50945 .57995 .50732 Mtetra
.57995 .50732 .58189 .50945 .58565 .5083 .58371 .50616 Mtetra
.58371 .50616 .58565 .5083 .58941 .50714 .58747 .505 Mtetra
.58747 .505 .58941 .50714 .59318 .50598 .59125 .50384 Mtetra
.59125 .50384 .59318 .50598 .59696 .50482 .59502 .50268 Mtetra
.59502 .50268 .59696 .50482 .60073 .50366 .59881 .50151 Mtetra
.964 .675 .438 r
.59881 .50151 .60073 .50366 .60452 .5025 .60516 .61003 Mtetra
.563 .347 .545 r
.60516 .61003 .60452 .5025 .61106 .61099 .60908 .6089 Mtetra
.654 .753 .922 r
.60908 .6089 .61106 .61099 .61498 .60986 .613 .60777 Mtetra
.613 .60777 .61498 .60986 .61891 .60873 .61694 .60664 Mtetra
.61694 .60664 .61891 .60873 .62284 .6076 .62087 .60551 Mtetra
.62087 .60551 .62284 .6076 .62678 .60647 .62481 .60437 Mtetra
.62481 .60437 .62678 .60647 .63072 .60533 .62876 .60323 Mtetra
.62876 .60323 .63072 .60533 .63467 .6042 .63271 .60209 Mtetra
.63271 .60209 .63467 .6042 .63863 .60306 .63667 .60095 Mtetra
.63667 .60095 .63863 .60306 .64259 .60192 .64064 .59981 Mtetra
.64064 .59981 .64259 .60192 .64232 .48155 .64461 .59867 Mtetra
.563 .348 .546 r
.64461 .59867 .64232 .48155 .64615 .48036 .64858 .59752 Mtetra
.023 0 .413 r
.64858 .59752 .64615 .48036 .64998 .47918 .64811 .47698 Mtetra
.664 .741 .908 r
.64811 .47698 .64998 .47918 .65382 .47799 .65195 .47579 Mtetra
.65195 .47579 .65382 .47799 .65767 .4768 .6558 .4746 Mtetra
.6558 .4746 .65767 .4768 .66152 .47561 .65966 .47341 Mtetra
.65966 .47341 .66152 .47561 .66538 .47442 .66352 .47221 Mtetra
.66352 .47221 .66538 .47442 .66924 .47322 .66738 .47102 Mtetra
.66738 .47102 .66924 .47322 .67311 .47203 .67125 .46982 Mtetra
.67125 .46982 .67311 .47203 .67698 .47083 .67513 .46862 Mtetra
.67513 .46862 .67698 .47083 .68086 .46963 .67901 .46742 Mtetra
.67901 .46742 .68086 .46963 .68474 .46843 .6829 .46621 Mtetra
.6829 .46621 .68474 .46843 .68863 .46723 .68679 .46501 Mtetra
.68679 .46501 .68863 .46723 .69252 .46603 .69069 .4638 Mtetra
.69069 .4638 .69252 .46603 .69642 .46482 .69459 .46259 Mtetra
.69459 .46259 .69642 .46482 .70033 .46362 .6985 .46138 Mtetra
.6985 .46138 .70033 .46362 .70424 .46241 .70241 .46017 Mtetra
.70241 .46017 .70424 .46241 .70815 .4612 .70633 .45896 Mtetra
.70633 .45896 .70815 .4612 .71207 .45999 .71025 .45774 Mtetra
.71025 .45774 .71207 .45999 .716 .45877 .71418 .45653 Mtetra
.71418 .45653 .716 .45877 .71993 .45756 .71812 .45531 Mtetra
.71812 .45531 .71993 .45756 .72387 .45634 .72206 .45409 Mtetra
.72206 .45409 .72387 .45634 .72781 .45512 .72601 .45287 Mtetra
.72601 .45287 .72781 .45512 .73176 .4539 .72996 .45164 Mtetra
.72996 .45164 .73176 .4539 .73571 .45268 .73392 .45042 Mtetra
.73392 .45042 .73571 .45268 .73967 .45146 .73788 .44919 Mtetra
.73788 .44919 .73967 .45146 .74364 .45023 .74185 .44796 Mtetra
.74185 .44796 .74364 .45023 .74761 .449 .74582 .44673 Mtetra
.74582 .44673 .74761 .449 .75158 .44777 .7498 .4455 Mtetra
.7498 .4455 .75158 .44777 .75556 .44654 .75378 .44427 Mtetra
.75378 .44427 .75556 .44654 .75955 .44531 .75777 .44303 Mtetra
.75777 .44303 .75955 .44531 .76354 .44408 .76177 .4418 Mtetra
.76177 .4418 .76354 .44408 .76754 .44284 .76577 .44056 Mtetra
.76577 .44056 .76754 .44284 .77154 .4416 .76978 .43932 Mtetra
.76978 .43932 .77154 .4416 .77555 .44037 .77379 .43807 Mtetra
.77379 .43807 .77555 .44037 .77956 .43913 .77781 .43683 Mtetra
.77781 .43683 .77956 .43913 .78358 .43788 .78183 .43558 Mtetra
.78183 .43558 .78358 .43788 .78761 .43664 .78586 .43434 Mtetra
.78586 .43434 .78761 .43664 .79164 .43539 .7899 .43309 Mtetra
.7899 .43309 .79164 .43539 .79568 .43414 .79394 .43184 Mtetra
.79394 .43184 .79568 .43414 .79972 .4329 .79799 .43058 Mtetra
.79799 .43058 .79972 .4329 .80377 .43164 .80204 .42933 Mtetra
.80204 .42933 .80377 .43164 .80782 .43039 .8061 .42807 Mtetra
.8061 .42807 .80782 .43039 .81188 .42914 .81016 .42682 Mtetra
.81016 .42682 .81188 .42914 .81595 .42788 .81423 .42556 Mtetra
.81423 .42556 .81595 .42788 .82002 .42662 .8183 .42429 Mtetra
.8183 .42429 .82002 .42662 .82409 .42536 .82239 .42303 Mtetra
.82239 .42303 .82409 .42536 .82818 .4241 .82647 .42177 Mtetra
.82647 .42177 .82818 .4241 .83227 .42284 .83056 .4205 Mtetra
.83056 .4205 .83227 .42284 .83636 .42157 .83466 .41923 Mtetra
.83466 .41923 .83636 .42157 .84046 .4203 .83877 .41796 Mtetra
.83877 .41796 .84046 .4203 .84456 .41903 .84288 .41669 Mtetra
.84288 .41669 .84456 .41903 .84868 .41776 .84699 .41541 Mtetra
.84699 .41541 .84868 .41776 .85279 .41649 .85111 .41414 Mtetra
.85111 .41414 .85279 .41649 .85692 .41522 .85524 .41286 Mtetra
.85524 .41286 .85692 .41522 .86104 .41394 .85937 .41158 Mtetra
.85937 .41158 .86104 .41394 .86518 .41266 .86351 .4103 Mtetra
.86351 .4103 .86518 .41266 .86932 .41138 .86766 .40902 Mtetra
.86766 .40902 .86932 .41138 .87347 .4101 .87181 .40773 Mtetra
.87181 .40773 .87347 .4101 .87762 .40882 .87596 .40644 Mtetra
.87596 .40644 .87762 .40882 .88178 .40753 .88013 .40516 Mtetra
.88013 .40516 .88178 .40753 .88594 .40625 .88429 .40387 Mtetra
.88429 .40387 .88594 .40625 .89011 .40496 .88847 .40257 Mtetra
.88847 .40257 .89011 .40496 .89429 .40367 .89265 .40128 Mtetra
.89265 .40128 .89429 .40367 .89847 .40237 .89683 .39998 Mtetra
.89683 .39998 .89847 .40237 .90266 .40108 .90103 .39869 Mtetra
.90103 .39869 .90266 .40108 .90685 .39978 .90523 .39739 Mtetra
.90523 .39739 .90685 .39978 .91105 .39849 .90943 .39608 Mtetra
.90943 .39608 .91105 .39849 .91526 .39719 .91364 .39478 Mtetra
.91364 .39478 .91526 .39719 .91947 .39588 .91786 .39348 Mtetra
.91786 .39348 .91947 .39588 .92369 .39458 .92208 .39217 Mtetra
.92208 .39217 .92369 .39458 .92791 .39327 .92631 .39086 Mtetra
.92631 .39086 .92791 .39327 .93214 .39197 .93054 .38955 Mtetra
.93054 .38955 .93214 .39197 .93638 .39066 .93478 .38824 Mtetra
.93478 .38824 .93638 .39066 .94062 .38935 .93903 .38692 Mtetra
.36148 .56307 .36361 .56506 .36707 .56398 .36495 .562 Mtetra
.36495 .562 .36707 .56398 .37054 .56291 .36842 .56092 Mtetra
.36842 .56092 .37054 .56291 .37401 .56183 .37189 .55984 Mtetra
.37189 .55984 .37401 .56183 .37749 .56076 .37538 .55877 Mtetra
.37538 .55877 .37749 .56076 .38098 .55968 .37886 .55768 Mtetra
.37886 .55768 .38098 .55968 .38446 .5586 .38235 .5566 Mtetra
.38235 .5566 .38446 .5586 .38796 .55752 .38585 .55552 Mtetra
.38585 .55552 .38796 .55752 .39145 .55644 .38935 .55443 Mtetra
.38935 .55443 .39145 .55644 .39495 .55535 .39285 .55335 Mtetra
.39285 .55335 .39495 .55535 .39846 .55427 .39636 .55226 Mtetra
.39636 .55226 .39846 .55427 .40197 .55318 .39987 .55117 Mtetra
.39987 .55117 .40197 .55318 .40549 .55209 .40339 .55008 Mtetra
.40339 .55008 .40549 .55209 .40901 .551 .40691 .54899 Mtetra
.40691 .54899 .40901 .551 .41253 .54991 .41044 .54789 Mtetra
.41044 .54789 .41253 .54991 .41606 .54882 .41397 .5468 Mtetra
.41397 .5468 .41606 .54882 .41959 .54772 .41751 .5457 Mtetra
.41751 .5457 .41959 .54772 .42313 .54663 .42105 .5446 Mtetra
.42105 .5446 .42313 .54663 .42667 .54553 .4246 .5435 Mtetra
.4246 .5435 .42667 .54553 .43022 .54443 .42815 .5424 Mtetra
.42815 .5424 .43022 .54443 .43377 .54333 .4317 .5413 Mtetra
.4317 .5413 .43377 .54333 .43733 .54223 .43526 .5402 Mtetra
.43526 .5402 .43733 .54223 .44089 .54113 .43883 .53909 Mtetra
.43883 .53909 .44089 .54113 .44446 .54003 .4424 .53798 Mtetra
.4424 .53798 .44446 .54003 .44803 .53892 .44597 .53688 Mtetra
.44597 .53688 .44803 .53892 .4516 .53781 .44955 .53577 Mtetra
.44955 .53577 .4516 .53781 .45519 .53671 .45313 .53466 Mtetra
.45313 .53466 .45519 .53671 .45877 .5356 .45672 .53354 Mtetra
.45672 .53354 .45877 .5356 .46236 .53448 .46031 .53243 Mtetra
.46031 .53243 .46236 .53448 .46595 .53337 .46391 .53131 Mtetra
.46391 .53131 .46595 .53337 .46955 .53226 .46751 .5302 Mtetra
.46751 .5302 .46955 .53226 .47316 .53114 .47112 .52908 Mtetra
.47112 .52908 .47316 .53114 .47677 .53002 .47473 .52796 Mtetra
.47473 .52796 .47677 .53002 .48038 .52891 .47835 .52684 Mtetra
.47835 .52684 .48038 .52891 .484 .52779 .48197 .52571 Mtetra
.48197 .52571 .484 .52779 .48762 .52666 .4856 .52459 Mtetra
.4856 .52459 .48762 .52666 .49125 .52554 .48923 .52346 Mtetra
.48923 .52346 .49125 .52554 .49488 .52442 .49286 .52234 Mtetra
.49286 .52234 .49488 .52442 .49852 .52329 .49651 .52121 Mtetra
.49651 .52121 .49852 .52329 .50216 .52216 .50015 .52008 Mtetra
.50015 .52008 .50216 .52216 .50581 .52103 .5038 .51894 Mtetra
.5038 .51894 .50581 .52103 .50946 .5199 .50746 .51781 Mtetra
.50746 .51781 .50946 .5199 .51312 .51877 .51112 .51668 Mtetra
.51112 .51668 .51312 .51877 .51678 .51764 .51478 .51554 Mtetra
.51478 .51554 .51678 .51764 .52044 .52564 .51845 .5144 Mtetra
.206 .183 .611 r
.51845 .5144 .52044 .52564 .52412 .52451 .52212 .52241 Mtetra
.663 .742 .909 r
.52212 .52241 .52412 .52451 .52781 .52337 .52581 .52127 Mtetra
.52581 .52127 .52781 .52337 .5315 .52224 .5295 .52014 Mtetra
.5295 .52014 .5315 .52224 .53519 .5211 .5332 .51899 Mtetra
.5332 .51899 .53519 .5211 .5389 .51996 .53691 .51785 Mtetra
.53691 .51785 .5389 .51996 .5426 .51882 .54062 .51671 Mtetra
.54062 .51671 .5426 .51882 .54631 .51768 .54433 .51556 Mtetra
.54433 .51556 .54631 .51768 .55003 .51653 .54805 .51441 Mtetra
.54805 .51441 .55003 .51653 .55375 .51539 .55178 .51327 Mtetra
.55178 .51327 .55375 .51539 .55748 .51424 .55551 .51212 Mtetra
.55551 .51212 .55748 .51424 .56121 .51309 .55924 .51096 Mtetra
.55924 .51096 .56121 .51309 .56495 .51194 .56298 .50981 Mtetra
.56298 .50981 .56495 .51194 .56869 .51079 .56673 .50865 Mtetra
.56673 .50865 .56869 .51079 .57244 .50963 .57048 .5075 Mtetra
.57048 .5075 .57244 .50963 .57619 .50848 .57424 .50634 Mtetra
.57424 .50634 .57619 .50848 .57995 .50732 .578 .50518 Mtetra
.578 .50518 .57995 .50732 .58371 .50616 .58176 .50402 Mtetra
.58176 .50402 .58371 .50616 .58747 .505 .58553 .50286 Mtetra
.58553 .50286 .58747 .505 .59125 .50384 .58931 .50169 Mtetra
.58931 .50169 .59125 .50384 .59502 .50268 .59309 .50053 Mtetra
.963 .676 .439 r
.59309 .50053 .59502 .50268 .59881 .50151 .59925 .60908 Mtetra
.562 .346 .545 r
.59925 .60908 .59881 .50151 .60516 .61003 .60317 .60795 Mtetra
.654 .753 .922 r
.60317 .60795 .60516 .61003 .60908 .6089 .60709 .60681 Mtetra
.60709 .60681 .60908 .6089 .613 .60777 .61102 .60568 Mtetra
.61102 .60568 .613 .60777 .61694 .60664 .61496 .60454 Mtetra
.61496 .60454 .61694 .60664 .62087 .60551 .6189 .60341 Mtetra
.6189 .60341 .62087 .60551 .62481 .60437 .62284 .60227 Mtetra
.62284 .60227 .62481 .60437 .62876 .60323 .62679 .60113 Mtetra
.62679 .60113 .62876 .60323 .63271 .60209 .63075 .59999 Mtetra
.63075 .59999 .63271 .60209 .63667 .60095 .63471 .59884 Mtetra
.63471 .59884 .63667 .60095 .64064 .59981 .63868 .5977 Mtetra
.63868 .5977 .64064 .59981 .64461 .59867 .64266 .59655 Mtetra
.64266 .59655 .64461 .59867 .64858 .59752 .64663 .5954 Mtetra
.64663 .5954 .64858 .59752 .64811 .47698 .65062 .59425 Mtetra
.023 0 .413 r
.65062 .59425 .64811 .47698 .65195 .47579 .65007 .47359 Mtetra
.664 .741 .908 r
.65007 .47359 .65195 .47579 .6558 .4746 .65392 .4724 Mtetra
.65392 .4724 .6558 .4746 .65966 .47341 .65778 .4712 Mtetra
.65778 .4712 .65966 .47341 .66352 .47221 .66165 .47 Mtetra
.66165 .47 .66352 .47221 .66738 .47102 .66552 .4688 Mtetra
.66552 .4688 .66738 .47102 .67125 .46982 .66939 .4676 Mtetra
.66939 .4676 .67125 .46982 .67513 .46862 .67327 .4664 Mtetra
.67327 .4664 .67513 .46862 .67901 .46742 .67716 .46519 Mtetra
.67716 .46519 .67901 .46742 .6829 .46621 .68105 .46399 Mtetra
.68105 .46399 .6829 .46621 .68679 .46501 .68494 .46278 Mtetra
.68494 .46278 .68679 .46501 .69069 .4638 .68884 .46157 Mtetra
.68884 .46157 .69069 .4638 .69459 .46259 .69275 .46036 Mtetra
.69275 .46036 .69459 .46259 .6985 .46138 .69666 .45915 Mtetra
.69666 .45915 .6985 .46138 .70241 .46017 .70058 .45793 Mtetra
.70058 .45793 .70241 .46017 .70633 .45896 .7045 .45671 Mtetra
.7045 .45671 .70633 .45896 .71025 .45774 .70843 .4555 Mtetra
.70843 .4555 .71025 .45774 .71418 .45653 .71236 .45428 Mtetra
.71236 .45428 .71418 .45653 .71812 .45531 .7163 .45306 Mtetra
.7163 .45306 .71812 .45531 .72206 .45409 .72025 .45183 Mtetra
.72025 .45183 .72206 .45409 .72601 .45287 .7242 .45061 Mtetra
.7242 .45061 .72601 .45287 .72996 .45164 .72815 .44938 Mtetra
.72815 .44938 .72996 .45164 .73392 .45042 .73211 .44815 Mtetra
.73211 .44815 .73392 .45042 .73788 .44919 .73608 .44692 Mtetra
.73608 .44692 .73788 .44919 .74185 .44796 .74005 .44569 Mtetra
.74005 .44569 .74185 .44796 .74582 .44673 .74403 .44446 Mtetra
.74403 .44446 .74582 .44673 .7498 .4455 .74801 .44322 Mtetra
.74801 .44322 .7498 .4455 .75378 .44427 .752 .44199 Mtetra
.752 .44199 .75378 .44427 .75777 .44303 .756 .44075 Mtetra
.756 .44075 .75777 .44303 .76177 .4418 .76 .43951 Mtetra
.76 .43951 .76177 .4418 .76577 .44056 .764 .43827 Mtetra
.764 .43827 .76577 .44056 .76978 .43932 .76801 .43702 Mtetra
.76801 .43702 .76978 .43932 .77379 .43807 .77203 .43578 Mtetra
.77203 .43578 .77379 .43807 .77781 .43683 .77605 .43453 Mtetra
.77605 .43453 .77781 .43683 .78183 .43558 .78008 .43328 Mtetra
.78008 .43328 .78183 .43558 .78586 .43434 .78411 .43203 Mtetra
.78411 .43203 .78586 .43434 .7899 .43309 .78815 .43078 Mtetra
.78815 .43078 .7899 .43309 .79394 .43184 .7922 .42952 Mtetra
.7922 .42952 .79394 .43184 .79799 .43058 .79625 .42827 Mtetra
.79625 .42827 .79799 .43058 .80204 .42933 .8003 .42701 Mtetra
.8003 .42701 .80204 .42933 .8061 .42807 .80437 .42575 Mtetra
.80437 .42575 .8061 .42807 .81016 .42682 .80843 .42449 Mtetra
.80843 .42449 .81016 .42682 .81423 .42556 .81251 .42323 Mtetra
.81251 .42323 .81423 .42556 .8183 .42429 .81659 .42196 Mtetra
.81659 .42196 .8183 .42429 .82239 .42303 .82067 .42069 Mtetra
.82067 .42069 .82239 .42303 .82647 .42177 .82476 .41943 Mtetra
.82476 .41943 .82647 .42177 .83056 .4205 .82886 .41816 Mtetra
.82886 .41816 .83056 .4205 .83466 .41923 .83296 .41688 Mtetra
.83296 .41688 .83466 .41923 .83877 .41796 .83707 .41561 Mtetra
.83707 .41561 .83877 .41796 .84288 .41669 .84118 .41433 Mtetra
.84118 .41433 .84288 .41669 .84699 .41541 .8453 .41306 Mtetra
.8453 .41306 .84699 .41541 .85111 .41414 .84943 .41178 Mtetra
.84943 .41178 .85111 .41414 .85524 .41286 .85356 .4105 Mtetra
.85356 .4105 .85524 .41286 .85937 .41158 .8577 .40921 Mtetra
.8577 .40921 .85937 .41158 .86351 .4103 .86184 .40793 Mtetra
.86184 .40793 .86351 .4103 .86766 .40902 .86599 .40664 Mtetra
.86599 .40664 .86766 .40902 .87181 .40773 .87014 .40535 Mtetra
.87014 .40535 .87181 .40773 .87596 .40644 .8743 .40406 Mtetra
.8743 .40406 .87596 .40644 .88013 .40516 .87847 .40277 Mtetra
.87847 .40277 .88013 .40516 .88429 .40387 .88264 .40148 Mtetra
.88264 .40148 .88429 .40387 .88847 .40257 .88682 .40018 Mtetra
.88682 .40018 .88847 .40257 .89265 .40128 .89101 .39889 Mtetra
.89101 .39889 .89265 .40128 .89683 .39998 .8952 .39759 Mtetra
.8952 .39759 .89683 .39998 .90103 .39869 .89939 .39628 Mtetra
.89939 .39628 .90103 .39869 .90523 .39739 .9036 .39498 Mtetra
.9036 .39498 .90523 .39739 .90943 .39608 .9078 .39368 Mtetra
.9078 .39368 .90943 .39608 .91364 .39478 .91202 .39237 Mtetra
.91202 .39237 .91364 .39478 .91786 .39348 .91624 .39106 Mtetra
.91624 .39106 .91786 .39348 .92208 .39217 .92047 .38975 Mtetra
.92047 .38975 .92208 .39217 .92631 .39086 .9247 .38844 Mtetra
.9247 .38844 .92631 .39086 .93054 .38955 .92894 .38712 Mtetra
.92894 .38712 .93054 .38955 .93478 .38824 .93318 .38581 Mtetra
.93318 .38581 .93478 .38824 .93903 .38692 .93743 .38449 Mtetra
.35934 .56109 .36148 .56307 .36495 .562 .36281 .56001 Mtetra
.36281 .56001 .36495 .562 .36842 .56092 .36629 .55893 Mtetra
.36629 .55893 .36842 .56092 .37189 .55984 .36977 .55785 Mtetra
.36977 .55785 .37189 .55984 .37538 .55877 .37325 .55677 Mtetra
.37325 .55677 .37538 .55877 .37886 .55768 .37674 .55569 Mtetra
.37674 .55569 .37886 .55768 .38235 .5566 .38024 .5546 Mtetra
.38024 .5546 .38235 .5566 .38585 .55552 .38373 .55351 Mtetra
.38373 .55351 .38585 .55552 .38935 .55443 .38724 .55243 Mtetra
.38724 .55243 .38935 .55443 .39285 .55335 .39074 .55134 Mtetra
.39074 .55134 .39285 .55335 .39636 .55226 .39426 .55025 Mtetra
.39426 .55025 .39636 .55226 .39987 .55117 .39777 .54915 Mtetra
.39777 .54915 .39987 .55117 .40339 .55008 .40129 .54806 Mtetra
.40129 .54806 .40339 .55008 .40691 .54899 .40482 .54697 Mtetra
.40482 .54697 .40691 .54899 .41044 .54789 .40835 .54587 Mtetra
.40835 .54587 .41044 .54789 .41397 .5468 .41188 .54477 Mtetra
.41188 .54477 .41397 .5468 .41751 .5457 .41542 .54367 Mtetra
.41542 .54367 .41751 .5457 .42105 .5446 .41897 .54257 Mtetra
.41897 .54257 .42105 .5446 .4246 .5435 .42252 .54147 Mtetra
.42252 .54147 .4246 .5435 .42815 .5424 .42607 .54037 Mtetra
.42607 .54037 .42815 .5424 .4317 .5413 .42963 .53926 Mtetra
.42963 .53926 .4317 .5413 .43526 .5402 .43319 .53815 Mtetra
.43319 .53815 .43526 .5402 .43883 .53909 .43676 .53705 Mtetra
.43676 .53705 .43883 .53909 .4424 .53798 .44033 .53594 Mtetra
.44033 .53594 .4424 .53798 .44597 .53688 .44391 .53483 Mtetra
.44391 .53483 .44597 .53688 .44955 .53577 .44749 .53371 Mtetra
.44749 .53371 .44955 .53577 .45313 .53466 .45107 .5326 Mtetra
.45107 .5326 .45313 .53466 .45672 .53354 .45467 .53149 Mtetra
.45467 .53149 .45672 .53354 .46031 .53243 .45826 .53037 Mtetra
.45826 .53037 .46031 .53243 .46391 .53131 .46186 .52925 Mtetra
.46186 .52925 .46391 .53131 .46751 .5302 .46547 .52813 Mtetra
.46547 .52813 .46751 .5302 .47112 .52908 .46908 .52701 Mtetra
.46908 .52701 .47112 .52908 .47473 .52796 .47269 .52589 Mtetra
.47269 .52589 .47473 .52796 .47835 .52684 .47631 .52476 Mtetra
.47631 .52476 .47835 .52684 .48197 .52571 .47994 .52364 Mtetra
.47994 .52364 .48197 .52571 .4856 .52459 .48357 .52251 Mtetra
.48357 .52251 .4856 .52459 .48923 .52346 .4872 .52138 Mtetra
.4872 .52138 .48923 .52346 .49286 .52234 .49084 .52025 Mtetra
.49084 .52025 .49286 .52234 .49651 .52121 .49448 .51912 Mtetra
.49448 .51912 .49651 .52121 .50015 .52008 .49813 .51799 Mtetra
.49813 .51799 .50015 .52008 .5038 .51894 .50179 .51685 Mtetra
.50179 .51685 .5038 .51894 .50746 .51781 .50545 .51572 Mtetra
.50545 .51572 .50746 .51781 .51112 .51668 .50911 .51458 Mtetra
.50911 .51458 .51112 .51668 .51478 .51554 .51278 .51344 Mtetra
.51278 .51344 .51478 .51554 .51845 .5144 .51645 .5123 Mtetra
.878 .448 .055 r
.51645 .5123 .51845 .5144 .52212 .52241 .52012 .52031 Mtetra
.663 .742 .909 r
.52012 .52031 .52212 .52241 .52581 .52127 .52381 .51917 Mtetra
.52381 .51917 .52581 .52127 .5295 .52014 .52751 .51803 Mtetra
.52751 .51803 .5295 .52014 .5332 .51899 .53121 .51688 Mtetra
.53121 .51688 .5332 .51899 .53691 .51785 .53492 .51574 Mtetra
.53492 .51574 .53691 .51785 .54062 .51671 .53863 .51459 Mtetra
.53863 .51459 .54062 .51671 .54433 .51556 .54235 .51344 Mtetra
.54235 .51344 .54433 .51556 .54805 .51441 .54607 .51229 Mtetra
.54607 .51229 .54805 .51441 .55178 .51327 .5498 .51114 Mtetra
.5498 .51114 .55178 .51327 .55551 .51212 .55353 .50999 Mtetra
.55353 .50999 .55551 .51212 .55924 .51096 .55727 .50883 Mtetra
.55727 .50883 .55924 .51096 .56298 .50981 .56102 .50768 Mtetra
.56102 .50768 .56298 .50981 .56673 .50865 .56476 .50652 Mtetra
.56476 .50652 .56673 .50865 .57048 .5075 .56852 .50536 Mtetra
.56852 .50536 .57048 .5075 .57424 .50634 .57228 .5042 Mtetra
.57228 .5042 .57424 .50634 .578 .50518 .57604 .50304 Mtetra
.57604 .50304 .578 .50518 .58176 .50402 .57981 .50187 Mtetra
.57981 .50187 .58176 .50402 .58553 .50286 .58358 .50071 Mtetra
.58358 .50071 .58553 .50286 .58931 .50169 .58736 .49954 Mtetra
.963 .676 .441 r
.58736 .49954 .58931 .50169 .59309 .50053 .59334 .60812 Mtetra
.562 .346 .544 r
.59334 .60812 .59309 .50053 .59925 .60908 .59725 .60699 Mtetra
.654 .753 .922 r
.59725 .60699 .59925 .60908 .60317 .60795 .60117 .60585 Mtetra
.60117 .60585 .60317 .60795 .60709 .60681 .6051 .60472 Mtetra
.6051 .60472 .60709 .60681 .61102 .60568 .60903 .60358 Mtetra
.60903 .60358 .61102 .60568 .61496 .60454 .61297 .60244 Mtetra
.61297 .60244 .61496 .60454 .6189 .60341 .61692 .6013 Mtetra
.61692 .6013 .6189 .60341 .62284 .60227 .62087 .60016 Mtetra
.62087 .60016 .62284 .60227 .62679 .60113 .62482 .59902 Mtetra
.62482 .59902 .62679 .60113 .63075 .59999 .62878 .59787 Mtetra
.62878 .59787 .63075 .59999 .63471 .59884 .63275 .59673 Mtetra
.63275 .59673 .63471 .59884 .63868 .5977 .63672 .59558 Mtetra
.63672 .59558 .63868 .5977 .64266 .59655 .6407 .59443 Mtetra
.6407 .59443 .64266 .59655 .64663 .5954 .64468 .59328 Mtetra
.64468 .59328 .64663 .5954 .65062 .59425 .64867 .59213 Mtetra
.64867 .59213 .65062 .59425 .65007 .47359 .65266 .59097 Mtetra
.023 0 .413 r
.65266 .59097 .65007 .47359 .65392 .4724 .65204 .47019 Mtetra
.664 .741 .908 r
.65204 .47019 .65392 .4724 .65778 .4712 .65591 .46899 Mtetra
.65591 .46899 .65778 .4712 .66165 .47 .65977 .46779 Mtetra
.65977 .46779 .66165 .47 .66552 .4688 .66365 .46658 Mtetra
.66365 .46658 .66552 .4688 .66939 .4676 .66753 .46538 Mtetra
.66753 .46538 .66939 .4676 .67327 .4664 .67141 .46417 Mtetra
.67141 .46417 .67327 .4664 .67716 .46519 .6753 .46297 Mtetra
.6753 .46297 .67716 .46519 .68105 .46399 .67919 .46176 Mtetra
.67919 .46176 .68105 .46399 .68494 .46278 .68309 .46054 Mtetra
.68309 .46054 .68494 .46278 .68884 .46157 .687 .45933 Mtetra
.687 .45933 .68884 .46157 .69275 .46036 .69091 .45812 Mtetra
.69091 .45812 .69275 .46036 .69666 .45915 .69482 .4569 Mtetra
.69482 .4569 .69666 .45915 .70058 .45793 .69874 .45568 Mtetra
.69874 .45568 .70058 .45793 .7045 .45671 .70267 .45446 Mtetra
.70267 .45446 .7045 .45671 .70843 .4555 .7066 .45324 Mtetra
.7066 .45324 .70843 .4555 .71236 .45428 .71054 .45202 Mtetra
.71054 .45202 .71236 .45428 .7163 .45306 .71448 .4508 Mtetra
.71448 .4508 .7163 .45306 .72025 .45183 .71843 .44957 Mtetra
.71843 .44957 .72025 .45183 .7242 .45061 .72238 .44834 Mtetra
.72238 .44834 .7242 .45061 .72815 .44938 .72634 .44711 Mtetra
.72634 .44711 .72815 .44938 .73211 .44815 .73031 .44588 Mtetra
.73031 .44588 .73211 .44815 .73608 .44692 .73428 .44465 Mtetra
.73428 .44465 .73608 .44692 .74005 .44569 .73826 .44341 Mtetra
.73826 .44341 .74005 .44569 .74403 .44446 .74224 .44218 Mtetra
.74224 .44218 .74403 .44446 .74801 .44322 .74622 .44094 Mtetra
.74622 .44094 .74801 .44322 .752 .44199 .75022 .4397 Mtetra
.75022 .4397 .752 .44199 .756 .44075 .75421 .43846 Mtetra
.75421 .43846 .756 .44075 .76 .43951 .75822 .43721 Mtetra
.75822 .43721 .76 .43951 .764 .43827 .76223 .43597 Mtetra
.76223 .43597 .764 .43827 .76801 .43702 .76624 .43472 Mtetra
.76624 .43472 .76801 .43702 .77203 .43578 .77026 .43347 Mtetra
.77026 .43347 .77203 .43578 .77605 .43453 .77429 .43222 Mtetra
.77429 .43222 .77605 .43453 .78008 .43328 .77832 .43097 Mtetra
.77832 .43097 .78008 .43328 .78411 .43203 .78236 .42972 Mtetra
.78236 .42972 .78411 .43203 .78815 .43078 .7864 .42846 Mtetra
.7864 .42846 .78815 .43078 .7922 .42952 .79045 .4272 Mtetra
.79045 .4272 .7922 .42952 .79625 .42827 .79451 .42594 Mtetra
.79451 .42594 .79625 .42827 .8003 .42701 .79857 .42468 Mtetra
.79857 .42468 .8003 .42701 .80437 .42575 .80263 .42342 Mtetra
.80263 .42342 .80437 .42575 .80843 .42449 .8067 .42216 Mtetra
.8067 .42216 .80843 .42449 .81251 .42323 .81078 .42089 Mtetra
.81078 .42089 .81251 .42323 .81659 .42196 .81486 .41962 Mtetra
.81486 .41962 .81659 .42196 .82067 .42069 .81895 .41835 Mtetra
.81895 .41835 .82067 .42069 .82476 .41943 .82305 .41708 Mtetra
.82305 .41708 .82476 .41943 .82886 .41816 .82715 .41581 Mtetra
.82715 .41581 .82886 .41816 .83296 .41688 .83125 .41453 Mtetra
.83125 .41453 .83296 .41688 .83707 .41561 .83537 .41325 Mtetra
.83537 .41325 .83707 .41561 .84118 .41433 .83948 .41197 Mtetra
.83948 .41197 .84118 .41433 .8453 .41306 .84361 .41069 Mtetra
.84361 .41069 .8453 .41306 .84943 .41178 .84774 .40941 Mtetra
.84774 .40941 .84943 .41178 .85356 .4105 .85187 .40813 Mtetra
.85187 .40813 .85356 .4105 .8577 .40921 .85602 .40684 Mtetra
.85602 .40684 .8577 .40921 .86184 .40793 .86016 .40555 Mtetra
.86016 .40555 .86184 .40793 .86599 .40664 .86432 .40426 Mtetra
.86432 .40426 .86599 .40664 .87014 .40535 .86848 .40297 Mtetra
.86848 .40297 .87014 .40535 .8743 .40406 .87264 .40168 Mtetra
.87264 .40168 .8743 .40406 .87847 .40277 .87681 .40038 Mtetra
.87681 .40038 .87847 .40277 .88264 .40148 .88099 .39909 Mtetra
.88099 .39909 .88264 .40148 .88682 .40018 .88517 .39779 Mtetra
.88517 .39779 .88682 .40018 .89101 .39889 .88936 .39649 Mtetra
.88936 .39649 .89101 .39889 .8952 .39759 .89356 .39518 Mtetra
.89356 .39518 .8952 .39759 .89939 .39628 .89776 .39388 Mtetra
.89776 .39388 .89939 .39628 .9036 .39498 .90196 .39257 Mtetra
.90196 .39257 .9036 .39498 .9078 .39368 .90618 .39126 Mtetra
.90618 .39126 .9078 .39368 .91202 .39237 .9104 .38995 Mtetra
.9104 .38995 .91202 .39237 .91624 .39106 .91462 .38864 Mtetra
.91462 .38864 .91624 .39106 .92047 .38975 .91885 .38733 Mtetra
.91885 .38733 .92047 .38975 .9247 .38844 .92309 .38601 Mtetra
.92309 .38601 .9247 .38844 .92894 .38712 .92733 .38469 Mtetra
.92733 .38469 .92894 .38712 .93318 .38581 .93158 .38337 Mtetra
.93158 .38337 .93318 .38581 .93743 .38449 .93584 .38205 Mtetra
.35721 .5591 .35934 .56109 .36281 .56001 .36068 .55802 Mtetra
.36068 .55802 .36281 .56001 .36629 .55893 .36416 .55694 Mtetra
.36416 .55694 .36629 .55893 .36977 .55785 .36764 .55585 Mtetra
.36764 .55585 .36977 .55785 .37325 .55677 .37113 .55477 Mtetra
.37113 .55477 .37325 .55677 .37674 .55569 .37462 .55368 Mtetra
.37462 .55368 .37674 .55569 .38024 .5546 .37811 .55259 Mtetra
.37811 .55259 .38024 .5546 .38373 .55351 .38162 .5515 Mtetra
.38162 .5515 .38373 .55351 .38724 .55243 .38512 .55041 Mtetra
.38512 .55041 .38724 .55243 .39074 .55134 .38863 .54932 Mtetra
.38863 .54932 .39074 .55134 .39426 .55025 .39215 .54823 Mtetra
.39215 .54823 .39426 .55025 .39777 .54915 .39566 .54713 Mtetra
.39566 .54713 .39777 .54915 .40129 .54806 .39919 .54604 Mtetra
.39919 .54604 .40129 .54806 .40482 .54697 .40272 .54494 Mtetra
.40272 .54494 .40482 .54697 .40835 .54587 .40625 .54384 Mtetra
.40625 .54384 .40835 .54587 .41188 .54477 .40979 .54274 Mtetra
.40979 .54274 .41188 .54477 .41542 .54367 .41333 .54164 Mtetra
.41333 .54164 .41542 .54367 .41897 .54257 .41688 .54054 Mtetra
.41688 .54054 .41897 .54257 .42252 .54147 .42043 .53943 Mtetra
.42043 .53943 .42252 .54147 .42607 .54037 .42398 .53833 Mtetra
.42398 .53833 .42607 .54037 .42963 .53926 .42755 .53722 Mtetra
.42755 .53722 .42963 .53926 .43319 .53815 .43111 .53611 Mtetra
.43111 .53611 .43319 .53815 .43676 .53705 .43468 .535 Mtetra
.43468 .535 .43676 .53705 .44033 .53594 .43826 .53389 Mtetra
.43826 .53389 .44033 .53594 .44391 .53483 .44184 .53277 Mtetra
.44184 .53277 .44391 .53483 .44749 .53371 .44542 .53166 Mtetra
.44542 .53166 .44749 .53371 .45107 .5326 .44901 .53054 Mtetra
.44901 .53054 .45107 .5326 .45467 .53149 .45261 .52942 Mtetra
.45261 .52942 .45467 .53149 .45826 .53037 .4562 .5283 Mtetra
.4562 .5283 .45826 .53037 .46186 .52925 .45981 .52718 Mtetra
.45981 .52718 .46186 .52925 .46547 .52813 .46342 .52606 Mtetra
.46342 .52606 .46547 .52813 .46908 .52701 .46703 .52494 Mtetra
.46703 .52494 .46908 .52701 .47269 .52589 .47065 .52381 Mtetra
.47065 .52381 .47269 .52589 .47631 .52476 .47427 .52268 Mtetra
.47427 .52268 .47631 .52476 .47994 .52364 .4779 .52155 Mtetra
.4779 .52155 .47994 .52364 .48357 .52251 .48153 .52042 Mtetra
.48153 .52042 .48357 .52251 .4872 .52138 .48517 .51929 Mtetra
.48517 .51929 .4872 .52138 .49084 .52025 .48881 .51816 Mtetra
.48881 .51816 .49084 .52025 .49448 .51912 .49246 .51703 Mtetra
.49246 .51703 .49448 .51912 .49813 .51799 .49611 .51589 Mtetra
.49611 .51589 .49813 .51799 .50179 .51685 .49977 .51475 Mtetra
.49977 .51475 .50179 .51685 .50545 .51572 .50343 .51361 Mtetra
.50343 .51361 .50545 .51572 .50911 .51458 .5071 .51247 Mtetra
.5071 .51247 .50911 .51458 .51278 .51344 .51077 .51133 Mtetra
.51077 .51133 .51278 .51344 .51645 .5123 .51444 .51019 Mtetra
.51444 .51019 .51645 .5123 .52012 .52031 .51812 .50904 Mtetra
.204 .182 .61 r
.51812 .50904 .52012 .52031 .52381 .51917 .5218 .51706 Mtetra
.663 .742 .909 r
.5218 .51706 .52381 .51917 .52751 .51803 .5255 .51591 Mtetra
.5255 .51591 .52751 .51803 .53121 .51688 .52921 .51477 Mtetra
.52921 .51477 .53121 .51688 .53492 .51574 .53292 .51362 Mtetra
.53292 .51362 .53492 .51574 .53863 .51459 .53664 .51247 Mtetra
.53664 .51247 .53863 .51459 .54235 .51344 .54036 .51132 Mtetra
.54036 .51132 .54235 .51344 .54607 .51229 .54409 .51016 Mtetra
.54409 .51016 .54607 .51229 .5498 .51114 .54782 .50901 Mtetra
.54782 .50901 .5498 .51114 .55353 .50999 .55155 .50785 Mtetra
.55155 .50785 .55353 .50999 .55727 .50883 .5553 .5067 Mtetra
.5553 .5067 .55727 .50883 .56102 .50768 .55904 .50554 Mtetra
.55904 .50554 .56102 .50768 .56476 .50652 .56279 .50438 Mtetra
.56279 .50438 .56476 .50652 .56852 .50536 .56655 .50321 Mtetra
.56655 .50321 .56852 .50536 .57228 .5042 .57031 .50205 Mtetra
.57031 .50205 .57228 .5042 .57604 .50304 .57408 .50088 Mtetra
.57408 .50088 .57604 .50304 .57981 .50187 .57785 .49972 Mtetra
.57785 .49972 .57981 .50187 .58358 .50071 .58163 .49855 Mtetra
.963 .676 .442 r
.58163 .49855 .58358 .50071 .58736 .49954 .58741 .60716 Mtetra
.561 .345 .544 r
.58741 .60716 .58736 .49954 .59334 .60812 .59133 .60603 Mtetra
.654 .753 .922 r
.59133 .60603 .59334 .60812 .59725 .60699 .59525 .60489 Mtetra
.59525 .60489 .59725 .60699 .60117 .60585 .59917 .60376 Mtetra
.59917 .60376 .60117 .60585 .6051 .60472 .60311 .60262 Mtetra
.60311 .60262 .6051 .60472 .60903 .60358 .60704 .60148 Mtetra
.60704 .60148 .60903 .60358 .61297 .60244 .61098 .60034 Mtetra
.61098 .60034 .61297 .60244 .61692 .6013 .61493 .5992 Mtetra
.61493 .5992 .61692 .6013 .62087 .60016 .61888 .59805 Mtetra
.61888 .59805 .62087 .60016 .62482 .59902 .62284 .5969 Mtetra
.62284 .5969 .62482 .59902 .62878 .59787 .62681 .59576 Mtetra
.62681 .59576 .62878 .59787 .63275 .59673 .63078 .59461 Mtetra
.63078 .59461 .63275 .59673 .63672 .59558 .63475 .59346 Mtetra
.63475 .59346 .63672 .59558 .6407 .59443 .63874 .5923 Mtetra
.63874 .5923 .6407 .59443 .64468 .59328 .64272 .59115 Mtetra
.64272 .59115 .64468 .59328 .64867 .59213 .64672 .58999 Mtetra
.64672 .58999 .64867 .59213 .65266 .59097 .65071 .58883 Mtetra
.966 .662 .394 r
.65071 .58883 .65266 .59097 .65204 .47019 .65722 .65343 Mtetra
.563 .35 .548 r
.65722 .65343 .65204 .47019 .65591 .46899 .66131 .65229 Mtetra
.033 0 .423 r
.66131 .65229 .65591 .46899 .65977 .46779 .6579 .46556 Mtetra
.664 .741 .908 r
.6579 .46556 .65977 .46779 .66365 .46658 .66177 .46436 Mtetra
.66177 .46436 .66365 .46658 .66753 .46538 .66566 .46315 Mtetra
.66566 .46315 .66753 .46538 .67141 .46417 .66954 .46194 Mtetra
.66954 .46194 .67141 .46417 .6753 .46297 .67343 .46073 Mtetra
.67343 .46073 .6753 .46297 .67919 .46176 .67733 .45952 Mtetra
.67733 .45952 .67919 .46176 .68309 .46054 .68124 .4583 Mtetra
.68124 .4583 .68309 .46054 .687 .45933 .68514 .45709 Mtetra
.68514 .45709 .687 .45933 .69091 .45812 .68906 .45587 Mtetra
.68906 .45587 .69091 .45812 .69482 .4569 .69298 .45465 Mtetra
.69298 .45465 .69482 .4569 .69874 .45568 .6969 .45343 Mtetra
.6969 .45343 .69874 .45568 .70267 .45446 .70083 .45221 Mtetra
.70083 .45221 .70267 .45446 .7066 .45324 .70477 .45098 Mtetra
.70477 .45098 .7066 .45324 .71054 .45202 .70871 .44976 Mtetra
.70871 .44976 .71054 .45202 .71448 .4508 .71266 .44853 Mtetra
.71266 .44853 .71448 .4508 .71843 .44957 .71661 .4473 Mtetra
.71661 .4473 .71843 .44957 .72238 .44834 .72057 .44607 Mtetra
.72057 .44607 .72238 .44834 .72634 .44711 .72453 .44484 Mtetra
.72453 .44484 .72634 .44711 .73031 .44588 .7285 .4436 Mtetra
.7285 .4436 .73031 .44588 .73428 .44465 .73247 .44237 Mtetra
.73247 .44237 .73428 .44465 .73826 .44341 .73645 .44113 Mtetra
.73645 .44113 .73826 .44341 .74224 .44218 .74044 .43989 Mtetra
.74044 .43989 .74224 .44218 .74622 .44094 .74443 .43865 Mtetra
.74443 .43865 .74622 .44094 .75022 .4397 .74843 .4374 Mtetra
.74843 .4374 .75022 .4397 .75421 .43846 .75243 .43616 Mtetra
.75243 .43616 .75421 .43846 .75822 .43721 .75644 .43491 Mtetra
.75644 .43491 .75822 .43721 .76223 .43597 .76045 .43366 Mtetra
.76045 .43366 .76223 .43597 .76624 .43472 .76447 .43241 Mtetra
.76447 .43241 .76624 .43472 .77026 .43347 .76849 .43116 Mtetra
.76849 .43116 .77026 .43347 .77429 .43222 .77252 .42991 Mtetra
.77252 .42991 .77429 .43222 .77832 .43097 .77656 .42865 Mtetra
.77656 .42865 .77832 .43097 .78236 .42972 .7806 .4274 Mtetra
.7806 .4274 .78236 .42972 .7864 .42846 .78465 .42614 Mtetra
.78465 .42614 .7864 .42846 .79045 .4272 .7887 .42488 Mtetra
.7887 .42488 .79045 .4272 .79451 .42594 .79276 .42361 Mtetra
.79276 .42361 .79451 .42594 .79857 .42468 .79682 .42235 Mtetra
.79682 .42235 .79857 .42468 .80263 .42342 .80089 .42108 Mtetra
.80089 .42108 .80263 .42342 .8067 .42216 .80497 .41982 Mtetra
.80497 .41982 .8067 .42216 .81078 .42089 .80905 .41855 Mtetra
.80905 .41855 .81078 .42089 .81486 .41962 .81314 .41728 Mtetra
.81314 .41728 .81486 .41962 .81895 .41835 .81723 .416 Mtetra
.81723 .416 .81895 .41835 .82305 .41708 .82133 .41473 Mtetra
.82133 .41473 .82305 .41708 .82715 .41581 .82543 .41345 Mtetra
.82543 .41345 .82715 .41581 .83125 .41453 .82954 .41217 Mtetra
.82954 .41217 .83125 .41453 .83537 .41325 .83366 .41089 Mtetra
.83366 .41089 .83537 .41325 .83948 .41197 .83778 .40961 Mtetra
.83778 .40961 .83948 .41197 .84361 .41069 .84191 .40832 Mtetra
.84191 .40832 .84361 .41069 .84774 .40941 .84604 .40704 Mtetra
.84604 .40704 .84774 .40941 .85187 .40813 .85018 .40575 Mtetra
.85018 .40575 .85187 .40813 .85602 .40684 .85433 .40446 Mtetra
.85433 .40446 .85602 .40684 .86016 .40555 .85848 .40317 Mtetra
.85848 .40317 .86016 .40555 .86432 .40426 .86264 .40188 Mtetra
.86264 .40188 .86432 .40426 .86848 .40297 .8668 .40058 Mtetra
.8668 .40058 .86848 .40297 .87264 .40168 .87097 .39928 Mtetra
.87097 .39928 .87264 .40168 .87681 .40038 .87515 .39799 Mtetra
.87515 .39799 .87681 .40038 .88099 .39909 .87933 .39669 Mtetra
.87933 .39669 .88099 .39909 .88517 .39779 .88352 .39538 Mtetra
.88352 .39538 .88517 .39779 .88936 .39649 .88771 .39408 Mtetra
.88771 .39408 .88936 .39649 .89356 .39518 .89191 .39277 Mtetra
.89191 .39277 .89356 .39518 .89776 .39388 .89611 .39146 Mtetra
.89611 .39146 .89776 .39388 .90196 .39257 .90033 .39015 Mtetra
.90033 .39015 .90196 .39257 .90618 .39126 .90454 .38884 Mtetra
.90454 .38884 .90618 .39126 .9104 .38995 .90877 .38753 Mtetra
.90877 .38753 .9104 .38995 .91462 .38864 .913 .38621 Mtetra
.913 .38621 .91462 .38864 .91885 .38733 .91723 .3849 Mtetra
.91723 .3849 .91885 .38733 .92309 .38601 .92147 .38358 Mtetra
.92147 .38358 .92309 .38601 .92733 .38469 .92572 .38225 Mtetra
.92572 .38225 .92733 .38469 .93158 .38337 .92998 .38093 Mtetra
.92998 .38093 .93158 .38337 .93584 .38205 .93424 .37961 Mtetra
.35506 .5571 .35721 .5591 .36068 .55802 .35854 .55602 Mtetra
.35854 .55602 .36068 .55802 .36416 .55694 .36202 .55493 Mtetra
.36202 .55493 .36416 .55694 .36764 .55585 .3655 .55385 Mtetra
.3655 .55385 .36764 .55585 .37113 .55477 .36899 .55276 Mtetra
.36899 .55276 .37113 .55477 .37462 .55368 .37249 .55167 Mtetra
.37249 .55167 .37462 .55368 .37811 .55259 .37599 .55058 Mtetra
.37599 .55058 .37811 .55259 .38162 .5515 .37949 .54949 Mtetra
.37949 .54949 .38162 .5515 .38512 .55041 .383 .5484 Mtetra
.383 .5484 .38512 .55041 .38863 .54932 .38651 .5473 Mtetra
.38651 .5473 .38863 .54932 .39215 .54823 .39003 .54621 Mtetra
.39003 .54621 .39215 .54823 .39566 .54713 .39355 .54511 Mtetra
.39355 .54511 .39566 .54713 .39919 .54604 .39708 .54401 Mtetra
.39708 .54401 .39919 .54604 .40272 .54494 .40061 .54291 Mtetra
.40061 .54291 .40272 .54494 .40625 .54384 .40415 .54181 Mtetra
.40415 .54181 .40625 .54384 .40979 .54274 .40769 .54071 Mtetra
.40769 .54071 .40979 .54274 .41333 .54164 .41123 .5396 Mtetra
.41123 .5396 .41333 .54164 .41688 .54054 .41478 .5385 Mtetra
.41478 .5385 .41688 .54054 .42043 .53943 .41834 .53739 Mtetra
.41834 .53739 .42043 .53943 .42398 .53833 .4219 .53628 Mtetra
.4219 .53628 .42398 .53833 .42755 .53722 .42546 .53517 Mtetra
.42546 .53517 .42755 .53722 .43111 .53611 .42903 .53406 Mtetra
.42903 .53406 .43111 .53611 .43468 .535 .4326 .53294 Mtetra
.4326 .53294 .43468 .535 .43826 .53389 .43618 .53183 Mtetra
.43618 .53183 .43826 .53389 .44184 .53277 .43976 .53071 Mtetra
.43976 .53071 .44184 .53277 .44542 .53166 .44335 .52959 Mtetra
.44335 .52959 .44542 .53166 .44901 .53054 .44694 .52848 Mtetra
.44694 .52848 .44901 .53054 .45261 .52942 .45054 .52735 Mtetra
.45054 .52735 .45261 .52942 .4562 .5283 .45414 .52623 Mtetra
.45414 .52623 .4562 .5283 .45981 .52718 .45775 .52511 Mtetra
.45775 .52511 .45981 .52718 .46342 .52606 .46136 .52398 Mtetra
.46136 .52398 .46342 .52606 .46703 .52494 .46498 .52286 Mtetra
.46498 .52286 .46703 .52494 .47065 .52381 .4686 .52173 Mtetra
.4686 .52173 .47065 .52381 .47427 .52268 .47222 .5206 Mtetra
.47222 .5206 .47427 .52268 .4779 .52155 .47586 .51947 Mtetra
.47586 .51947 .4779 .52155 .48153 .52042 .47949 .51833 Mtetra
.47949 .51833 .48153 .52042 .48517 .51929 .48313 .5172 Mtetra
.48313 .5172 .48517 .51929 .48881 .51816 .48678 .51606 Mtetra
.48678 .51606 .48881 .51816 .49246 .51703 .49043 .51493 Mtetra
.49043 .51493 .49246 .51703 .49611 .51589 .49408 .51379 Mtetra
.49408 .51379 .49611 .51589 .49977 .51475 .49774 .51265 Mtetra
.49774 .51265 .49977 .51475 .50343 .51361 .50141 .51151 Mtetra
.50141 .51151 .50343 .51361 .5071 .51247 .50508 .51036 Mtetra
.50508 .51036 .5071 .51247 .51077 .51133 .50875 .50922 Mtetra
.50875 .50922 .51077 .51133 .51444 .51019 .51243 .50807 Mtetra
.51243 .50807 .51444 .51019 .51812 .50904 .51612 .50692 Mtetra
.956 .681 .475 r
.51612 .50692 .51812 .50904 .5218 .51706 .51953 .68909 Mtetra
0 0 .367 r
.51953 .68909 .5218 .51706 .5255 .51591 .5235 .5138 Mtetra
.663 .742 .909 r
.5235 .5138 .5255 .51591 .52921 .51477 .52721 .51265 Mtetra
.52721 .51265 .52921 .51477 .53292 .51362 .53092 .5115 Mtetra
.53092 .5115 .53292 .51362 .53664 .51247 .53464 .51034 Mtetra
.53464 .51034 .53664 .51247 .54036 .51132 .53837 .50919 Mtetra
.53837 .50919 .54036 .51132 .54409 .51016 .5421 .50803 Mtetra
.5421 .50803 .54409 .51016 .54782 .50901 .54583 .50687 Mtetra
.54583 .50687 .54782 .50901 .55155 .50785 .54957 .50572 Mtetra
.54957 .50572 .55155 .50785 .5553 .5067 .55331 .50456 Mtetra
.55331 .50456 .5553 .5067 .55904 .50554 .55707 .50339 Mtetra
.55707 .50339 .55904 .50554 .56279 .50438 .56082 .50223 Mtetra
.56082 .50223 .56279 .50438 .56655 .50321 .56458 .50106 Mtetra
.56458 .50106 .56655 .50321 .57031 .50205 .56835 .4999 Mtetra
.56835 .4999 .57031 .50205 .57408 .50088 .57212 .49873 Mtetra
.57212 .49873 .57408 .50088 .57785 .49972 .57589 .49756 Mtetra
.962 .676 .443 r
.57589 .49756 .57785 .49972 .58163 .49855 .58149 .6062 Mtetra
.561 .344 .543 r
.58149 .6062 .58163 .49855 .58741 .60716 .5854 .60507 Mtetra
.654 .753 .922 r
.5854 .60507 .58741 .60716 .59133 .60603 .58932 .60393 Mtetra
.58932 .60393 .59133 .60603 .59525 .60489 .59324 .60279 Mtetra
.59324 .60279 .59525 .60489 .59917 .60376 .59717 .60166 Mtetra
.59717 .60166 .59917 .60376 .60311 .60262 .6011 .60051 Mtetra
.6011 .60051 .60311 .60262 .60704 .60148 .60504 .59937 Mtetra
.60504 .59937 .60704 .60148 .61098 .60034 .60899 .59823 Mtetra
.60899 .59823 .61098 .60034 .61493 .5992 .61294 .59708 Mtetra
.61294 .59708 .61493 .5992 .61888 .59805 .6169 .59593 Mtetra
.6169 .59593 .61888 .59805 .62284 .5969 .62086 .59478 Mtetra
.62086 .59478 .62284 .5969 .62681 .59576 .62483 .59363 Mtetra
.62483 .59363 .62681 .59576 .63078 .59461 .6288 .59248 Mtetra
.6288 .59248 .63078 .59461 .63475 .59346 .63278 .59133 Mtetra
.63278 .59133 .63475 .59346 .63874 .5923 .63677 .59017 Mtetra
.63677 .59017 .63874 .5923 .64272 .59115 .64076 .58901 Mtetra
.64076 .58901 .64272 .59115 .64672 .58999 .64476 .58785 Mtetra
.64476 .58785 .64672 .58999 .65071 .58883 .64876 .58669 Mtetra
.966 .662 .394 r
.64876 .58669 .65071 .58883 .65722 .65343 .65523 .65133 Mtetra
.648 .76 .931 r
.65523 .65133 .65722 .65343 .66131 .65229 .65933 .65019 Mtetra
.65933 .65019 .66131 .65229 .6579 .46556 .66343 .64905 Mtetra
.563 .349 .548 r
.66343 .64905 .6579 .46556 .66177 .46436 .66753 .64791 Mtetra
.66753 .64791 .66177 .46436 .66566 .46315 .67164 .64677 Mtetra
.67164 .64677 .66566 .46315 .66954 .46194 .67576 .64562 Mtetra
.67576 .64562 .66954 .46194 .67343 .46073 .67988 .64448 Mtetra
.67988 .64448 .67343 .46073 .67733 .45952 .68401 .64333 Mtetra
.68401 .64333 .67733 .45952 .68124 .4583 .68815 .64218 Mtetra
.68815 .64218 .68124 .4583 .68514 .45709 .69229 .64102 Mtetra
.69229 .64102 .68514 .45709 .68906 .45587 .69643 .63987 Mtetra
.69643 .63987 .68906 .45587 .69298 .45465 .70059 .63871 Mtetra
.70059 .63871 .69298 .45465 .6969 .45343 .70475 .63756 Mtetra
.70475 .63756 .6969 .45343 .70083 .45221 .70891 .6364 Mtetra
.70891 .6364 .70083 .45221 .70477 .45098 .71308 .63524 Mtetra
.71308 .63524 .70477 .45098 .70871 .44976 .71726 .63408 Mtetra
.062 0 .439 r
.71726 .63408 .70871 .44976 .71266 .44853 .71083 .44626 Mtetra
.664 .741 .908 r
.71083 .44626 .71266 .44853 .71661 .4473 .71478 .44503 Mtetra
.71478 .44503 .71661 .4473 .72057 .44607 .71874 .44379 Mtetra
.71874 .44379 .72057 .44607 .72453 .44484 .72271 .44256 Mtetra
.72271 .44256 .72453 .44484 .7285 .4436 .72668 .44132 Mtetra
.72668 .44132 .7285 .4436 .73247 .44237 .73066 .44008 Mtetra
.73066 .44008 .73247 .44237 .73645 .44113 .73465 .43884 Mtetra
.73465 .43884 .73645 .44113 .74044 .43989 .73863 .4376 Mtetra
.73863 .4376 .74044 .43989 .74443 .43865 .74263 .43635 Mtetra
.74263 .43635 .74443 .43865 .74843 .4374 .74663 .4351 Mtetra
.74663 .4351 .74843 .4374 .75243 .43616 .75064 .43386 Mtetra
.75064 .43386 .75243 .43616 .75644 .43491 .75465 .43261 Mtetra
.75465 .43261 .75644 .43491 .76045 .43366 .75866 .43136 Mtetra
.75866 .43136 .76045 .43366 .76447 .43241 .76269 .4301 Mtetra
.76269 .4301 .76447 .43241 .76849 .43116 .76672 .42885 Mtetra
.76672 .42885 .76849 .43116 .77252 .42991 .77075 .42759 Mtetra
.77075 .42759 .77252 .42991 .77656 .42865 .77479 .42633 Mtetra
.77479 .42633 .77656 .42865 .7806 .4274 .77884 .42507 Mtetra
.77884 .42507 .7806 .4274 .78465 .42614 .78289 .42381 Mtetra
.78289 .42381 .78465 .42614 .7887 .42488 .78694 .42254 Mtetra
.78694 .42254 .7887 .42488 .79276 .42361 .79101 .42128 Mtetra
.79101 .42128 .79276 .42361 .79682 .42235 .79507 .42001 Mtetra
.79507 .42001 .79682 .42235 .80089 .42108 .79915 .41874 Mtetra
.79915 .41874 .80089 .42108 .80497 .41982 .80323 .41747 Mtetra
.80323 .41747 .80497 .41982 .80905 .41855 .80731 .4162 Mtetra
.80731 .4162 .80905 .41855 .81314 .41728 .81141 .41492 Mtetra
.81141 .41492 .81314 .41728 .81723 .416 .8155 .41365 Mtetra
.8155 .41365 .81723 .416 .82133 .41473 .81961 .41237 Mtetra
.81961 .41237 .82133 .41473 .82543 .41345 .82371 .41109 Mtetra
.82371 .41109 .82543 .41345 .82954 .41217 .82783 .40981 Mtetra
.82783 .40981 .82954 .41217 .83366 .41089 .83195 .40852 Mtetra
.83195 .40852 .83366 .41089 .83778 .40961 .83608 .40724 Mtetra
.83608 .40724 .83778 .40961 .84191 .40832 .84021 .40595 Mtetra
.84021 .40595 .84191 .40832 .84604 .40704 .84435 .40466 Mtetra
.84435 .40466 .84604 .40704 .85018 .40575 .84849 .40337 Mtetra
.84849 .40337 .85018 .40575 .85433 .40446 .85264 .40208 Mtetra
.85264 .40208 .85433 .40446 .85848 .40317 .8568 .40078 Mtetra
.8568 .40078 .85848 .40317 .86264 .40188 .86096 .39948 Mtetra
.86096 .39948 .86264 .40188 .8668 .40058 .86513 .39819 Mtetra
.86513 .39819 .8668 .40058 .87097 .39928 .8693 .39689 Mtetra
.8693 .39689 .87097 .39928 .87515 .39799 .87348 .39558 Mtetra
.87348 .39558 .87515 .39799 .87933 .39669 .87767 .39428 Mtetra
.87767 .39428 .87933 .39669 .88352 .39538 .88186 .39297 Mtetra
.88186 .39297 .88352 .39538 .88771 .39408 .88605 .39167 Mtetra
.88605 .39167 .88771 .39408 .89191 .39277 .89026 .39036 Mtetra
.89026 .39036 .89191 .39277 .89611 .39146 .89447 .38904 Mtetra
.89447 .38904 .89611 .39146 .90033 .39015 .89868 .38773 Mtetra
.89868 .38773 .90033 .39015 .90454 .38884 .90291 .38642 Mtetra
.90291 .38642 .90454 .38884 .90877 .38753 .90713 .3851 Mtetra
.90713 .3851 .90877 .38753 .913 .38621 .91137 .38378 Mtetra
.91137 .38378 .913 .38621 .91723 .3849 .91561 .38246 Mtetra
.91561 .38246 .91723 .3849 .92147 .38358 .91985 .38114 Mtetra
.91985 .38114 .92147 .38358 .92572 .38225 .92411 .37981 Mtetra
.92411 .37981 .92572 .38225 .92998 .38093 .92836 .37848 Mtetra
.92836 .37848 .92998 .38093 .93424 .37961 .93263 .37715 Mtetra
.35291 .5551 .35506 .5571 .35854 .55602 .35639 .55402 Mtetra
.35639 .55402 .35854 .55602 .36202 .55493 .35988 .55293 Mtetra
.35988 .55293 .36202 .55493 .3655 .55385 .36336 .55184 Mtetra
.36336 .55184 .3655 .55385 .36899 .55276 .36686 .55075 Mtetra
.36686 .55075 .36899 .55276 .37249 .55167 .37035 .54966 Mtetra
.37035 .54966 .37249 .55167 .37599 .55058 .37386 .54857 Mtetra
.37386 .54857 .37599 .55058 .37949 .54949 .37736 .54747 Mtetra
.37736 .54747 .37949 .54949 .383 .5484 .38087 .54638 Mtetra
.38087 .54638 .383 .5484 .38651 .5473 .38439 .54528 Mtetra
.38439 .54528 .38651 .5473 .39003 .54621 .38791 .54418 Mtetra
.38791 .54418 .39003 .54621 .39355 .54511 .39143 .54308 Mtetra
.39143 .54308 .39355 .54511 .39708 .54401 .39496 .54198 Mtetra
.39496 .54198 .39708 .54401 .40061 .54291 .3985 .54088 Mtetra
.3985 .54088 .40061 .54291 .40415 .54181 .40204 .53977 Mtetra
.40204 .53977 .40415 .54181 .40769 .54071 .40558 .53867 Mtetra
.40558 .53867 .40769 .54071 .41123 .5396 .40913 .53756 Mtetra
.40913 .53756 .41123 .5396 .41478 .5385 .41268 .53645 Mtetra
.41268 .53645 .41478 .5385 .41834 .53739 .41624 .53534 Mtetra
.41624 .53534 .41834 .53739 .4219 .53628 .4198 .53423 Mtetra
.4198 .53423 .4219 .53628 .42546 .53517 .42337 .53311 Mtetra
.42337 .53311 .42546 .53517 .42903 .53406 .42694 .532 Mtetra
.42694 .532 .42903 .53406 .4326 .53294 .43052 .53088 Mtetra
.43052 .53088 .4326 .53294 .43618 .53183 .4341 .52977 Mtetra
.4341 .52977 .43618 .53183 .43976 .53071 .43768 .52865 Mtetra
.43768 .52865 .43976 .53071 .44335 .52959 .44127 .52753 Mtetra
.44127 .52753 .44335 .52959 .44694 .52848 .44487 .52641 Mtetra
.44487 .52641 .44694 .52848 .45054 .52735 .44847 .52528 Mtetra
.44847 .52528 .45054 .52735 .45414 .52623 .45208 .52416 Mtetra
.45208 .52416 .45414 .52623 .45775 .52511 .45569 .52303 Mtetra
.45569 .52303 .45775 .52511 .46136 .52398 .4593 .5219 Mtetra
.4593 .5219 .46136 .52398 .46498 .52286 .46292 .52077 Mtetra
.46292 .52077 .46498 .52286 .4686 .52173 .46654 .51964 Mtetra
.46654 .51964 .4686 .52173 .47222 .5206 .47017 .51851 Mtetra
.47017 .51851 .47222 .5206 .47586 .51947 .47381 .51738 Mtetra
.47381 .51738 .47586 .51947 .47949 .51833 .47745 .51624 Mtetra
.47745 .51624 .47949 .51833 .48313 .5172 .48109 .5151 Mtetra
.48109 .5151 .48313 .5172 .48678 .51606 .48474 .51396 Mtetra
.48474 .51396 .48678 .51606 .49043 .51493 .48839 .51282 Mtetra
.48839 .51282 .49043 .51493 .49408 .51379 .49205 .51168 Mtetra
.49205 .51168 .49408 .51379 .49774 .51265 .49571 .51054 Mtetra
.49571 .51054 .49774 .51265 .50141 .51151 .49938 .50939 Mtetra
.49938 .50939 .50141 .51151 .50508 .51036 .50305 .50825 Mtetra
.50305 .50825 .50508 .51036 .50875 .50922 .50673 .5071 Mtetra
.50673 .5071 .50875 .50922 .51243 .50807 .51041 .50595 Mtetra
.956 .681 .476 r
.51041 .50595 .51243 .50807 .51612 .50692 .51351 .68817 Mtetra
.563 .349 .548 r
.51351 .68817 .51612 .50692 .51953 .68909 .5174 .68708 Mtetra
.648 .76 .931 r
.5174 .68708 .51953 .68909 .5235 .5138 .52131 .686 Mtetra
.563 .348 .547 r
.52131 .686 .5235 .5138 .52721 .51265 .52521 .68491 Mtetra
.52521 .68491 .52721 .51265 .53092 .5115 .52913 .68382 Mtetra
.52913 .68382 .53092 .5115 .53464 .51034 .53304 .68273 Mtetra
0 0 .373 r
.53304 .68273 .53464 .51034 .53837 .50919 .53637 .50705 Mtetra
.663 .742 .909 r
.53637 .50705 .53837 .50919 .5421 .50803 .5401 .50589 Mtetra
.5401 .50589 .5421 .50803 .54583 .50687 .54384 .50473 Mtetra
.54384 .50473 .54583 .50687 .54957 .50572 .54758 .50357 Mtetra
.54758 .50357 .54957 .50572 .55331 .50456 .55133 .50241 Mtetra
.55133 .50241 .55331 .50456 .55707 .50339 .55508 .50124 Mtetra
.55508 .50124 .55707 .50339 .56082 .50223 .55884 .50008 Mtetra
.55884 .50008 .56082 .50223 .56458 .50106 .5626 .49891 Mtetra
.5626 .49891 .56458 .50106 .56835 .4999 .56637 .49774 Mtetra
.56637 .49774 .56835 .4999 .57212 .49873 .57015 .49657 Mtetra
.962 .676 .445 r
.57015 .49657 .57212 .49873 .57589 .49756 .57555 .60524 Mtetra
.561 .344 .543 r
.57555 .60524 .57589 .49756 .58149 .6062 .57946 .60411 Mtetra
.654 .753 .922 r
.57946 .60411 .58149 .6062 .5854 .60507 .58338 .60297 Mtetra
.58338 .60297 .5854 .60507 .58932 .60393 .5873 .60183 Mtetra
.5873 .60183 .58932 .60393 .59324 .60279 .59123 .60069 Mtetra
.59123 .60069 .59324 .60279 .59717 .60166 .59516 .59955 Mtetra
.59516 .59955 .59717 .60166 .6011 .60051 .5991 .5984 Mtetra
.5991 .5984 .6011 .60051 .60504 .59937 .60304 .59726 Mtetra
.60304 .59726 .60504 .59937 .60899 .59823 .60699 .59611 Mtetra
.60699 .59611 .60899 .59823 .61294 .59708 .61095 .59496 Mtetra
.61095 .59496 .61294 .59708 .6169 .59593 .61491 .59381 Mtetra
.61491 .59381 .6169 .59593 .62086 .59478 .61887 .59266 Mtetra
.61887 .59266 .62086 .59478 .62483 .59363 .62284 .5915 Mtetra
.62284 .5915 .62483 .59363 .6288 .59248 .62682 .59035 Mtetra
.62682 .59035 .6288 .59248 .63278 .59133 .63081 .58919 Mtetra
.63081 .58919 .63278 .59133 .63677 .59017 .63479 .58803 Mtetra
.63479 .58803 .63677 .59017 .64076 .58901 .63879 .58687 Mtetra
.63879 .58687 .64076 .58901 .64476 .58785 .64279 .58571 Mtetra
.64279 .58571 .64476 .58785 .64876 .58669 .6468 .58455 Mtetra
.966 .662 .394 r
.6468 .58455 .64876 .58669 .65523 .65133 .65324 .64923 Mtetra
.648 .76 .931 r
.65324 .64923 .65523 .65133 .65933 .65019 .65734 .64809 Mtetra
.65734 .64809 .65933 .65019 .66343 .64905 .66144 .64694 Mtetra
.66144 .64694 .66343 .64905 .66753 .64791 .66555 .6458 Mtetra
.66555 .6458 .66753 .64791 .67164 .64677 .66967 .64465 Mtetra
.66967 .64465 .67164 .64677 .67576 .64562 .67379 .6435 Mtetra
.67379 .6435 .67576 .64562 .67988 .64448 .67791 .64235 Mtetra
.67791 .64235 .67988 .64448 .68401 .64333 .68205 .6412 Mtetra
.68205 .6412 .68401 .64333 .68815 .64218 .68619 .64005 Mtetra
.68619 .64005 .68815 .64218 .69229 .64102 .69033 .63889 Mtetra
.69033 .63889 .69229 .64102 .69643 .63987 .69448 .63774 Mtetra
.69448 .63774 .69643 .63987 .70059 .63871 .69864 .63658 Mtetra
.69864 .63658 .70059 .63871 .70475 .63756 .7028 .63542 Mtetra
.7028 .63542 .70475 .63756 .70891 .6364 .70697 .63425 Mtetra
.70697 .63425 .70891 .6364 .71308 .63524 .71115 .63309 Mtetra
.71115 .63309 .71308 .63524 .71726 .63408 .71533 .63193 Mtetra
.71533 .63193 .71726 .63408 .71083 .44626 .71952 .63076 Mtetra
.563 .349 .548 r
.71952 .63076 .71083 .44626 .71478 .44503 .72371 .62959 Mtetra
.72371 .62959 .71478 .44503 .71874 .44379 .72791 .62842 Mtetra
.72791 .62842 .71874 .44379 .72271 .44256 .73212 .62725 Mtetra
.73212 .62725 .72271 .44256 .72668 .44132 .73633 .62607 Mtetra
.73633 .62607 .72668 .44132 .73066 .44008 .74055 .6249 Mtetra
.073 0 .445 r
.74055 .6249 .73066 .44008 .73465 .43884 .73283 .43654 Mtetra
.664 .741 .908 r
.73283 .43654 .73465 .43884 .73863 .4376 .73683 .4353 Mtetra
.73683 .4353 .73863 .4376 .74263 .43635 .74083 .43405 Mtetra
.74083 .43405 .74263 .43635 .74663 .4351 .74483 .4328 Mtetra
.74483 .4328 .74663 .4351 .75064 .43386 .74884 .43155 Mtetra
.74884 .43155 .75064 .43386 .75465 .43261 .75285 .43029 Mtetra
.75285 .43029 .75465 .43261 .75866 .43136 .75688 .42904 Mtetra
.75688 .42904 .75866 .43136 .76269 .4301 .7609 .42778 Mtetra
.7609 .42778 .76269 .4301 .76672 .42885 .76494 .42652 Mtetra
.76494 .42652 .76672 .42885 .77075 .42759 .76897 .42526 Mtetra
.76897 .42526 .77075 .42759 .77479 .42633 .77302 .424 Mtetra
.77302 .424 .77479 .42633 .77884 .42507 .77707 .42274 Mtetra
.77707 .42274 .77884 .42507 .78289 .42381 .78112 .42147 Mtetra
.78112 .42147 .78289 .42381 .78694 .42254 .78518 .42021 Mtetra
.78518 .42021 .78694 .42254 .79101 .42128 .78925 .41894 Mtetra
.78925 .41894 .79101 .42128 .79507 .42001 .79332 .41767 Mtetra
.79332 .41767 .79507 .42001 .79915 .41874 .7974 .41639 Mtetra
.7974 .41639 .79915 .41874 .80323 .41747 .80148 .41512 Mtetra
.80148 .41512 .80323 .41747 .80731 .4162 .80557 .41384 Mtetra
.80557 .41384 .80731 .4162 .81141 .41492 .80967 .41257 Mtetra
.80967 .41257 .81141 .41492 .8155 .41365 .81377 .41129 Mtetra
.81377 .41129 .8155 .41365 .81961 .41237 .81788 .41 Mtetra
.81788 .41 .81961 .41237 .82371 .41109 .82199 .40872 Mtetra
.82199 .40872 .82371 .41109 .82783 .40981 .82611 .40743 Mtetra
.82611 .40743 .82783 .40981 .83195 .40852 .83023 .40615 Mtetra
.83023 .40615 .83195 .40852 .83608 .40724 .83437 .40486 Mtetra
.83437 .40486 .83608 .40724 .84021 .40595 .8385 .40357 Mtetra
.8385 .40357 .84021 .40595 .84435 .40466 .84264 .40227 Mtetra
.84264 .40227 .84435 .40466 .84849 .40337 .84679 .40098 Mtetra
.84679 .40098 .84849 .40337 .85264 .40208 .85095 .39968 Mtetra
.85095 .39968 .85264 .40208 .8568 .40078 .85511 .39839 Mtetra
.85511 .39839 .8568 .40078 .86096 .39948 .85927 .39709 Mtetra
.85927 .39709 .86096 .39948 .86513 .39819 .86345 .39578 Mtetra
.86345 .39578 .86513 .39819 .8693 .39689 .86762 .39448 Mtetra
.86762 .39448 .8693 .39689 .87348 .39558 .87181 .39317 Mtetra
.87181 .39317 .87348 .39558 .87767 .39428 .876 .39187 Mtetra
.876 .39187 .87767 .39428 .88186 .39297 .88019 .39056 Mtetra
.88019 .39056 .88186 .39297 .88605 .39167 .8844 .38925 Mtetra
.8844 .38925 .88605 .39167 .89026 .39036 .8886 .38793 Mtetra
.8886 .38793 .89026 .39036 .89447 .38904 .89282 .38662 Mtetra
.89282 .38662 .89447 .38904 .89868 .38773 .89704 .3853 Mtetra
.89704 .3853 .89868 .38773 .90291 .38642 .90126 .38398 Mtetra
.90126 .38398 .90291 .38642 .90713 .3851 .9055 .38266 Mtetra
.9055 .38266 .90713 .3851 .91137 .38378 .90973 .38134 Mtetra
.90973 .38134 .91137 .38378 .91561 .38246 .91398 .38001 Mtetra
.91398 .38001 .91561 .38246 .91985 .38114 .91823 .37869 Mtetra
.91823 .37869 .91985 .38114 .92411 .37981 .92249 .37736 Mtetra
.92249 .37736 .92411 .37981 .92836 .37848 .92675 .37603 Mtetra
.92675 .37603 .92836 .37848 .93263 .37715 .93102 .3747 Mtetra
.35076 .5531 .35291 .5551 .35639 .55402 .35424 .55201 Mtetra
.35424 .55201 .35639 .55402 .35988 .55293 .35773 .55092 Mtetra
.35773 .55092 .35988 .55293 .36336 .55184 .36122 .54983 Mtetra
.36122 .54983 .36336 .55184 .36686 .55075 .36471 .54873 Mtetra
.36471 .54873 .36686 .55075 .37035 .54966 .36821 .54764 Mtetra
.36821 .54764 .37035 .54966 .37386 .54857 .37172 .54654 Mtetra
.37172 .54654 .37386 .54857 .37736 .54747 .37523 .54545 Mtetra
.37523 .54545 .37736 .54747 .38087 .54638 .37874 .54435 Mtetra
.37874 .54435 .38087 .54638 .38439 .54528 .38226 .54325 Mtetra
.38226 .54325 .38439 .54528 .38791 .54418 .38578 .54215 Mtetra
.38578 .54215 .38791 .54418 .39143 .54308 .38931 .54105 Mtetra
.38931 .54105 .39143 .54308 .39496 .54198 .39284 .53994 Mtetra
.39284 .53994 .39496 .54198 .3985 .54088 .39638 .53884 Mtetra
.39638 .53884 .3985 .54088 .40204 .53977 .39992 .53773 Mtetra
.39992 .53773 .40204 .53977 .40558 .53867 .40347 .53662 Mtetra
.40347 .53662 .40558 .53867 .40913 .53756 .40702 .53551 Mtetra
.40702 .53551 .40913 .53756 .41268 .53645 .41058 .5344 Mtetra
.41058 .5344 .41268 .53645 .41624 .53534 .41414 .53329 Mtetra
.41414 .53329 .41624 .53534 .4198 .53423 .4177 .53217 Mtetra
.4177 .53217 .4198 .53423 .42337 .53311 .42127 .53106 Mtetra
.42127 .53106 .42337 .53311 .42694 .532 .42485 .52994 Mtetra
.42485 .52994 .42694 .532 .43052 .53088 .42843 .52882 Mtetra
.42843 .52882 .43052 .53088 .4341 .52977 .43201 .5277 Mtetra
.43201 .5277 .4341 .52977 .43768 .52865 .4356 .52658 Mtetra
.4356 .52658 .43768 .52865 .44127 .52753 .43919 .52545 Mtetra
.43919 .52545 .44127 .52753 .44487 .52641 .44279 .52433 Mtetra
.44279 .52433 .44487 .52641 .44847 .52528 .4464 .5232 Mtetra
.4464 .5232 .44847 .52528 .45208 .52416 .45 .52208 Mtetra
.45 .52208 .45208 .52416 .45569 .52303 .45362 .52095 Mtetra
.45362 .52095 .45569 .52303 .4593 .5219 .45723 .51982 Mtetra
.45723 .51982 .4593 .5219 .46292 .52077 .46086 .51868 Mtetra
.46086 .51868 .46292 .52077 .46654 .51964 .46448 .51755 Mtetra
.46448 .51755 .46654 .51964 .47017 .51851 .46812 .51641 Mtetra
.46812 .51641 .47017 .51851 .47381 .51738 .47175 .51528 Mtetra
.47175 .51528 .47381 .51738 .47745 .51624 .47539 .51414 Mtetra
.47539 .51414 .47745 .51624 .48109 .5151 .47904 .513 Mtetra
.47904 .513 .48109 .5151 .48474 .51396 .48269 .51186 Mtetra
.48269 .51186 .48474 .51396 .48839 .51282 .48635 .51072 Mtetra
.48635 .51072 .48839 .51282 .49205 .51168 .49001 .50957 Mtetra
.49001 .50957 .49205 .51168 .49571 .51054 .49368 .50842 Mtetra
.49368 .50842 .49571 .51054 .49938 .50939 .49735 .50728 Mtetra
.49735 .50728 .49938 .50939 .50305 .50825 .50103 .50613 Mtetra
.50103 .50613 .50305 .50825 .50673 .5071 .50471 .50498 Mtetra
.50471 .50498 .50673 .5071 .51041 .50595 .50839 .50383 Mtetra
.956 .681 .476 r
.50839 .50383 .51041 .50595 .51351 .68817 .51138 .68617 Mtetra
.648 .76 .931 r
.51138 .68617 .51351 .68817 .5174 .68708 .51528 .68508 Mtetra
.51528 .68508 .5174 .68708 .52131 .686 .51918 .68399 Mtetra
.51918 .68399 .52131 .686 .52521 .68491 .52309 .68289 Mtetra
.52309 .68289 .52521 .68491 .52913 .68382 .52701 .6818 Mtetra
.52701 .6818 .52913 .68382 .53304 .68273 .53093 .68071 Mtetra
.53093 .68071 .53304 .68273 .53637 .50705 .53486 .67961 Mtetra
.562 .348 .547 r
.53486 .67961 .53637 .50705 .5401 .50589 .53879 .67851 Mtetra
.53879 .67851 .5401 .50589 .54384 .50473 .54273 .67741 Mtetra
.54273 .67741 .54384 .50473 .54758 .50357 .54667 .67631 Mtetra
0 0 .377 r
.54667 .67631 .54758 .50357 .55133 .50241 .54934 .50026 Mtetra
.663 .742 .909 r
.54934 .50026 .55133 .50241 .55508 .50124 .55309 .49909 Mtetra
.55309 .49909 .55508 .50124 .55884 .50008 .55686 .49792 Mtetra
.55686 .49792 .55884 .50008 .5626 .49891 .56062 .49675 Mtetra
.56062 .49675 .5626 .49891 .56637 .49774 .5644 .49558 Mtetra
.5644 .49558 .56637 .49774 .57015 .49657 .56817 .4944 Mtetra
.962 .676 .445 r
.56817 .4944 .57015 .49657 .57555 .60524 .57352 .60315 Mtetra
.654 .753 .922 r
.57352 .60315 .57555 .60524 .57946 .60411 .57743 .60201 Mtetra
.57743 .60201 .57946 .60411 .58338 .60297 .58135 .60087 Mtetra
.58135 .60087 .58338 .60297 .5873 .60183 .58527 .59972 Mtetra
.58527 .59972 .5873 .60183 .59123 .60069 .58921 .59858 Mtetra
.58921 .59858 .59123 .60069 .59516 .59955 .59314 .59743 Mtetra
.59314 .59743 .59516 .59955 .5991 .5984 .59708 .59629 Mtetra
.59708 .59629 .5991 .5984 .60304 .59726 .60103 .59514 Mtetra
.60103 .59514 .60304 .59726 .60699 .59611 .60499 .59399 Mtetra
.60499 .59399 .60699 .59611 .61095 .59496 .60894 .59284 Mtetra
.60894 .59284 .61095 .59496 .61491 .59381 .61291 .59168 Mtetra
.61291 .59168 .61491 .59381 .61887 .59266 .61688 .59053 Mtetra
.61688 .59053 .61887 .59266 .62284 .5915 .62086 .58937 Mtetra
.62086 .58937 .62284 .5915 .62682 .59035 .62484 .58821 Mtetra
.62484 .58821 .62682 .59035 .63081 .58919 .62882 .58705 Mtetra
.62882 .58705 .63081 .58919 .63479 .58803 .63282 .58589 Mtetra
.63282 .58589 .63479 .58803 .63879 .58687 .63682 .58473 Mtetra
.63682 .58473 .63879 .58687 .64279 .58571 .64082 .58356 Mtetra
.64082 .58356 .64279 .58571 .6468 .58455 .64483 .58239 Mtetra
.966 .662 .394 r
.64483 .58239 .6468 .58455 .65324 .64923 .65124 .64712 Mtetra
.648 .76 .931 r
.65124 .64712 .65324 .64923 .65734 .64809 .65535 .64597 Mtetra
.65535 .64597 .65734 .64809 .66144 .64694 .65945 .64483 Mtetra
.65945 .64483 .66144 .64694 .66555 .6458 .66357 .64368 Mtetra
.66357 .64368 .66555 .6458 .66967 .64465 .66769 .64253 Mtetra
.66769 .64253 .66967 .64465 .67379 .6435 .67181 .64138 Mtetra
.67181 .64138 .67379 .6435 .67791 .64235 .67594 .64023 Mtetra
.67594 .64023 .67791 .64235 .68205 .6412 .68008 .63907 Mtetra
.68008 .63907 .68205 .6412 .68619 .64005 .68422 .63791 Mtetra
.68422 .63791 .68619 .64005 .69033 .63889 .68837 .63676 Mtetra
.68837 .63676 .69033 .63889 .69448 .63774 .69253 .6356 Mtetra
.69253 .6356 .69448 .63774 .69864 .63658 .69669 .63443 Mtetra
.69669 .63443 .69864 .63658 .7028 .63542 .70086 .63327 Mtetra
.70086 .63327 .7028 .63542 .70697 .63425 .70503 .63211 Mtetra
.70503 .63211 .70697 .63425 .71115 .63309 .70921 .63094 Mtetra
.70921 .63094 .71115 .63309 .71533 .63193 .7134 .62977 Mtetra
.7134 .62977 .71533 .63193 .71952 .63076 .71759 .6286 Mtetra
.71759 .6286 .71952 .63076 .72371 .62959 .72179 .62743 Mtetra
.72179 .62743 .72371 .62959 .72791 .62842 .72599 .62625 Mtetra
.72599 .62625 .72791 .62842 .73212 .62725 .7302 .62508 Mtetra
.7302 .62508 .73212 .62725 .73633 .62607 .73442 .6239 Mtetra
.73442 .6239 .73633 .62607 .74055 .6249 .73864 .62272 Mtetra
.73864 .62272 .74055 .6249 .73283 .43654 .74287 .62154 Mtetra
.562 .348 .547 r
.74287 .62154 .73283 .43654 .73683 .4353 .74711 .62036 Mtetra
.075 0 .446 r
.74711 .62036 .73683 .4353 .74083 .43405 .73902 .43174 Mtetra
.664 .741 .908 r
.73902 .43174 .74083 .43405 .74483 .4328 .74302 .43049 Mtetra
.74302 .43049 .74483 .4328 .74884 .43155 .74704 .42923 Mtetra
.74704 .42923 .74884 .43155 .75285 .43029 .75106 .42798 Mtetra
.972 .662 .357 r
.75106 .42798 .75285 .43029 .75688 .42904 .7619 .52288 Mtetra
.073 0 .44 r
.7619 .52288 .75688 .42904 .7609 .42778 .75911 .42546 Mtetra
.664 .741 .908 r
.75911 .42546 .7609 .42778 .76494 .42652 .76315 .4242 Mtetra
.76315 .4242 .76494 .42652 .76897 .42526 .76719 .42293 Mtetra
.76719 .42293 .76897 .42526 .77302 .424 .77124 .42167 Mtetra
.77124 .42167 .77302 .424 .77707 .42274 .77529 .4204 Mtetra
.77529 .4204 .77707 .42274 .78112 .42147 .77935 .41913 Mtetra
.77935 .41913 .78112 .42147 .78518 .42021 .78342 .41786 Mtetra
.78342 .41786 .78518 .42021 .78925 .41894 .78749 .41659 Mtetra
.78749 .41659 .78925 .41894 .79332 .41767 .79157 .41532 Mtetra
.79157 .41532 .79332 .41767 .7974 .41639 .79565 .41404 Mtetra
.79565 .41404 .7974 .41639 .80148 .41512 .79974 .41276 Mtetra
.79974 .41276 .80148 .41512 .80557 .41384 .80383 .41148 Mtetra
.80383 .41148 .80557 .41384 .80967 .41257 .80793 .4102 Mtetra
.80793 .4102 .80967 .41257 .81377 .41129 .81203 .40892 Mtetra
.81203 .40892 .81377 .41129 .81788 .41 .81615 .40763 Mtetra
.81615 .40763 .81788 .41 .82199 .40872 .82026 .40635 Mtetra
.82026 .40635 .82199 .40872 .82611 .40743 .82439 .40506 Mtetra
.82439 .40506 .82611 .40743 .83023 .40615 .82852 .40377 Mtetra
.82852 .40377 .83023 .40615 .83437 .40486 .83265 .40247 Mtetra
.83265 .40247 .83437 .40486 .8385 .40357 .83679 .40118 Mtetra
.83679 .40118 .8385 .40357 .84264 .40227 .84094 .39988 Mtetra
.84094 .39988 .84264 .40227 .84679 .40098 .84509 .39859 Mtetra
.84509 .39859 .84679 .40098 .85095 .39968 .84925 .39729 Mtetra
.84925 .39729 .85095 .39968 .85511 .39839 .85341 .39598 Mtetra
.85341 .39598 .85511 .39839 .85927 .39709 .85758 .39468 Mtetra
.85758 .39468 .85927 .39709 .86345 .39578 .86176 .39338 Mtetra
.86176 .39338 .86345 .39578 .86762 .39448 .86594 .39207 Mtetra
.86594 .39207 .86762 .39448 .87181 .39317 .87013 .39076 Mtetra
.87013 .39076 .87181 .39317 .876 .39187 .87432 .38945 Mtetra
.87432 .38945 .876 .39187 .88019 .39056 .87852 .38814 Mtetra
.87852 .38814 .88019 .39056 .8844 .38925 .88273 .38682 Mtetra
.88273 .38682 .8844 .38925 .8886 .38793 .88694 .3855 Mtetra
.88694 .3855 .8886 .38793 .89282 .38662 .89116 .38419 Mtetra
.89116 .38419 .89282 .38662 .89704 .3853 .89539 .38286 Mtetra
.89539 .38286 .89704 .3853 .90126 .38398 .89962 .38154 Mtetra
.89962 .38154 .90126 .38398 .9055 .38266 .90385 .38022 Mtetra
.90385 .38022 .9055 .38266 .90973 .38134 .9081 .37889 Mtetra
.9081 .37889 .90973 .38134 .91398 .38001 .91235 .37756 Mtetra
.91235 .37756 .91398 .38001 .91823 .37869 .9166 .37623 Mtetra
.9166 .37623 .91823 .37869 .92249 .37736 .92086 .3749 Mtetra
.92086 .3749 .92249 .37736 .92675 .37603 .92513 .37357 Mtetra
.92513 .37357 .92675 .37603 .93102 .3747 .9294 .37223 Mtetra
.3486 .55109 .35076 .5531 .35424 .55201 .35209 .54999 Mtetra
.35209 .54999 .35424 .55201 .35773 .55092 .35557 .5489 Mtetra
.35557 .5489 .35773 .55092 .36122 .54983 .35907 .54781 Mtetra
.35907 .54781 .36122 .54983 .36471 .54873 .36257 .54671 Mtetra
.36257 .54671 .36471 .54873 .36821 .54764 .36607 .54562 Mtetra
.36607 .54562 .36821 .54764 .37172 .54654 .36958 .54452 Mtetra
.36958 .54452 .37172 .54654 .37523 .54545 .37309 .54342 Mtetra
.37309 .54342 .37523 .54545 .37874 .54435 .37661 .54232 Mtetra
.37661 .54232 .37874 .54435 .38226 .54325 .38013 .54122 Mtetra
.38013 .54122 .38226 .54325 .38578 .54215 .38365 .54011 Mtetra
.38365 .54011 .38578 .54215 .38931 .54105 .38718 .53901 Mtetra
.38718 .53901 .38931 .54105 .39284 .53994 .39072 .5379 Mtetra
.39072 .5379 .39284 .53994 .39638 .53884 .39426 .53679 Mtetra
.39426 .53679 .39638 .53884 .39992 .53773 .3978 .53568 Mtetra
.3978 .53568 .39992 .53773 .40347 .53662 .40135 .53457 Mtetra
.40135 .53457 .40347 .53662 .40702 .53551 .40491 .53346 Mtetra
.40491 .53346 .40702 .53551 .41058 .5344 .40847 .53234 Mtetra
.40847 .53234 .41058 .5344 .41414 .53329 .41203 .53123 Mtetra
.41203 .53123 .41414 .53329 .4177 .53217 .4156 .53011 Mtetra
.4156 .53011 .4177 .53217 .42127 .53106 .41917 .52899 Mtetra
.41917 .52899 .42127 .53106 .42485 .52994 .42275 .52787 Mtetra
.42275 .52787 .42485 .52994 .42843 .52882 .42633 .52675 Mtetra
.42633 .52675 .42843 .52882 .43201 .5277 .42992 .52563 Mtetra
.42992 .52563 .43201 .5277 .4356 .52658 .43351 .5245 Mtetra
.43351 .5245 .4356 .52658 .43919 .52545 .43711 .52338 Mtetra
.43711 .52338 .43919 .52545 .44279 .52433 .44071 .52225 Mtetra
.44071 .52225 .44279 .52433 .4464 .5232 .44432 .52112 Mtetra
.44432 .52112 .4464 .5232 .45 .52208 .44793 .51999 Mtetra
.44793 .51999 .45 .52208 .45362 .52095 .45154 .51886 Mtetra
.45154 .51886 .45362 .52095 .45723 .51982 .45516 .51772 Mtetra
.45516 .51772 .45723 .51982 .46086 .51868 .45879 .51659 Mtetra
.45879 .51659 .46086 .51868 .46448 .51755 .46242 .51545 Mtetra
.46242 .51545 .46448 .51755 .46812 .51641 .46605 .51431 Mtetra
.46605 .51431 .46812 .51641 .47175 .51528 .46969 .51317 Mtetra
.46969 .51317 .47175 .51528 .47539 .51414 .47334 .51203 Mtetra
.47334 .51203 .47539 .51414 .47904 .513 .47699 .51089 Mtetra
.47699 .51089 .47904 .513 .48269 .51186 .48064 .50975 Mtetra
.48064 .50975 .48269 .51186 .48635 .51072 .4843 .5086 Mtetra
.4843 .5086 .48635 .51072 .49001 .50957 .48797 .50745 Mtetra
.48797 .50745 .49001 .50957 .49368 .50842 .49164 .50631 Mtetra
.49164 .50631 .49368 .50842 .49735 .50728 .49531 .50515 Mtetra
.49531 .50515 .49735 .50728 .50103 .50613 .49899 .504 Mtetra
.49899 .504 .50103 .50613 .50471 .50498 .50268 .50285 Mtetra
.50268 .50285 .50471 .50498 .50839 .50383 .50637 .50169 Mtetra
.956 .681 .476 r
.50637 .50169 .50839 .50383 .51138 .68617 .50924 .68415 Mtetra
.648 .76 .931 r
.50924 .68415 .51138 .68617 .51528 .68508 .51314 .68306 Mtetra
.51314 .68306 .51528 .68508 .51918 .68399 .51705 .68197 Mtetra
.51705 .68197 .51918 .68399 .52309 .68289 .52097 .68087 Mtetra
.52097 .68087 .52309 .68289 .52701 .6818 .52489 .67978 Mtetra
.52489 .67978 .52701 .6818 .53093 .68071 .52881 .67868 Mtetra
.52881 .67868 .53093 .68071 .53486 .67961 .53274 .67758 Mtetra
.53274 .67758 .53486 .67961 .53879 .67851 .53668 .67648 Mtetra
.53668 .67648 .53879 .67851 .54273 .67741 .54062 .67538 Mtetra
.54062 .67538 .54273 .67741 .54667 .67631 .54457 .67427 Mtetra
.54457 .67427 .54667 .67631 .54934 .50026 .54852 .67317 Mtetra
.562 .347 .546 r
.54852 .67317 .54934 .50026 .55309 .49909 .55248 .67206 Mtetra
.55248 .67206 .55309 .49909 .55686 .49792 .55645 .67095 Mtetra
0 0 .381 r
.55645 .67095 .55686 .49792 .56062 .49675 .55864 .49458 Mtetra
.663 .742 .909 r
.55864 .49458 .56062 .49675 .5644 .49558 .56241 .49341 Mtetra
.962 .676 .446 r
.56241 .49341 .5644 .49558 .56817 .4944 .56756 .60218 Mtetra
.56 .343 .542 r
.56756 .60218 .56817 .4944 .57352 .60315 .57148 .60104 Mtetra
.654 .753 .922 r
.57148 .60104 .57352 .60315 .57743 .60201 .57539 .5999 Mtetra
.57539 .5999 .57743 .60201 .58135 .60087 .57932 .59876 Mtetra
.57932 .59876 .58135 .60087 .58527 .59972 .58325 .59761 Mtetra
.58325 .59761 .58527 .59972 .58921 .59858 .58718 .59646 Mtetra
.58718 .59646 .58921 .59858 .59314 .59743 .59112 .59531 Mtetra
.59112 .59531 .59314 .59743 .59708 .59629 .59507 .59416 Mtetra
.59507 .59416 .59708 .59629 .60103 .59514 .59902 .59301 Mtetra
.59902 .59301 .60103 .59514 .60499 .59399 .60298 .59186 Mtetra
.60298 .59186 .60499 .59399 .60894 .59284 .60694 .5907 Mtetra
.60694 .5907 .60894 .59284 .61291 .59168 .61091 .58955 Mtetra
.61091 .58955 .61291 .59168 .61688 .59053 .61488 .58839 Mtetra
.61488 .58839 .61688 .59053 .62086 .58937 .61886 .58723 Mtetra
.61886 .58723 .62086 .58937 .62484 .58821 .62285 .58607 Mtetra
.62285 .58607 .62484 .58821 .62882 .58705 .62684 .5849 Mtetra
.62684 .5849 .62882 .58705 .63282 .58589 .63083 .58374 Mtetra
.63083 .58374 .63282 .58589 .63682 .58473 .63484 .58257 Mtetra
.63484 .58257 .63682 .58473 .64082 .58356 .63884 .5814 Mtetra
.966 .662 .396 r
.63884 .5814 .64082 .58356 .64483 .58239 .64514 .64615 Mtetra
.556 .334 .533 r
.64514 .64615 .64483 .58239 .65124 .64712 .64924 .645 Mtetra
.648 .76 .931 r
.64924 .645 .65124 .64712 .65535 .64597 .65335 .64386 Mtetra
.65335 .64386 .65535 .64597 .65945 .64483 .65746 .64271 Mtetra
.65746 .64271 .65945 .64483 .66357 .64368 .66158 .64156 Mtetra
.66158 .64156 .66357 .64368 .66769 .64253 .6657 .6404 Mtetra
.6657 .6404 .66769 .64253 .67181 .64138 .66983 .63925 Mtetra
.66983 .63925 .67181 .64138 .67594 .64023 .67396 .63809 Mtetra
.67396 .63809 .67594 .64023 .68008 .63907 .6781 .63693 Mtetra
.6781 .63693 .68008 .63907 .68422 .63791 .68225 .63577 Mtetra
.68225 .63577 .68422 .63791 .68837 .63676 .68641 .63461 Mtetra
.68641 .63461 .68837 .63676 .69253 .6356 .69057 .63345 Mtetra
.69057 .63345 .69253 .6356 .69669 .63443 .69473 .63228 Mtetra
.69473 .63228 .69669 .63443 .70086 .63327 .6989 .63112 Mtetra
.6989 .63112 .70086 .63327 .70503 .63211 .70308 .62995 Mtetra
.70308 .62995 .70503 .63211 .70921 .63094 .70726 .62878 Mtetra
.70726 .62878 .70921 .63094 .7134 .62977 .71146 .62761 Mtetra
.71146 .62761 .7134 .62977 .71759 .6286 .71565 .62643 Mtetra
.71565 .62643 .71759 .6286 .72179 .62743 .71985 .62526 Mtetra
.71985 .62526 .72179 .62743 .72599 .62625 .72406 .62408 Mtetra
.72406 .62408 .72599 .62625 .7302 .62508 .72828 .6229 Mtetra
.72828 .6229 .7302 .62508 .73442 .6239 .7325 .62172 Mtetra
.7325 .62172 .73442 .6239 .73864 .62272 .73673 .62054 Mtetra
.73673 .62054 .73864 .62272 .74287 .62154 .74096 .61936 Mtetra
.74096 .61936 .74287 .62154 .74711 .62036 .7452 .61817 Mtetra
.975 .701 .444 r
.7452 .61817 .74711 .62036 .73902 .43174 .74348 .52552 Mtetra
.559 .341 .54 r
.74348 .52552 .73902 .43174 .74302 .43049 .74761 .52429 Mtetra
.74761 .52429 .74302 .43049 .74704 .42923 .75175 .52307 Mtetra
.75175 .52307 .74704 .42923 .75106 .42798 .7559 .52184 Mtetra
.7559 .52184 .75106 .42798 .7619 .52288 .76005 .52061 Mtetra
.656 .751 .919 r
.76005 .52061 .7619 .52288 .75911 .42546 .76421 .51938 Mtetra
.559 .341 .54 r
.76421 .51938 .75911 .42546 .76315 .4242 .76838 .51815 Mtetra
.76838 .51815 .76315 .4242 .76719 .42293 .77255 .51691 Mtetra
.077 0 .443 r
.77255 .51691 .76719 .42293 .77124 .42167 .76946 .41933 Mtetra
.664 .741 .908 r
.76946 .41933 .77124 .42167 .77529 .4204 .77352 .41806 Mtetra
.77352 .41806 .77529 .4204 .77935 .41913 .77758 .41679 Mtetra
.77758 .41679 .77935 .41913 .78342 .41786 .78165 .41551 Mtetra
.78165 .41551 .78342 .41786 .78749 .41659 .78572 .41424 Mtetra
.78572 .41424 .78749 .41659 .79157 .41532 .7898 .41296 Mtetra
.7898 .41296 .79157 .41532 .79565 .41404 .79389 .41168 Mtetra
.79389 .41168 .79565 .41404 .79974 .41276 .79798 .4104 Mtetra
.79798 .4104 .79974 .41276 .80383 .41148 .80208 .40912 Mtetra
.80208 .40912 .80383 .41148 .80793 .4102 .80618 .40783 Mtetra
.80618 .40783 .80793 .4102 .81203 .40892 .81029 .40654 Mtetra
.81029 .40654 .81203 .40892 .81615 .40763 .81441 .40526 Mtetra
.81441 .40526 .81615 .40763 .82026 .40635 .81853 .40396 Mtetra
.81853 .40396 .82026 .40635 .82439 .40506 .82266 .40267 Mtetra
.82266 .40267 .82439 .40506 .82852 .40377 .82679 .40138 Mtetra
.82679 .40138 .82852 .40377 .83265 .40247 .83093 .40008 Mtetra
.83093 .40008 .83265 .40247 .83679 .40118 .83508 .39879 Mtetra
.83508 .39879 .83679 .40118 .84094 .39988 .83923 .39749 Mtetra
.83923 .39749 .84094 .39988 .84509 .39859 .84338 .39618 Mtetra
.84338 .39618 .84509 .39859 .84925 .39729 .84755 .39488 Mtetra
.84755 .39488 .84925 .39729 .85341 .39598 .85171 .39358 Mtetra
.85171 .39358 .85341 .39598 .85758 .39468 .85589 .39227 Mtetra
.85589 .39227 .85758 .39468 .86176 .39338 .86007 .39096 Mtetra
.86007 .39096 .86176 .39338 .86594 .39207 .86426 .38965 Mtetra
.86426 .38965 .86594 .39207 .87013 .39076 .86845 .38834 Mtetra
.86845 .38834 .87013 .39076 .87432 .38945 .87265 .38702 Mtetra
.87265 .38702 .87432 .38945 .87852 .38814 .87685 .38571 Mtetra
.87685 .38571 .87852 .38814 .88273 .38682 .88106 .38439 Mtetra
.88106 .38439 .88273 .38682 .88694 .3855 .88528 .38307 Mtetra
.88528 .38307 .88694 .3855 .89116 .38419 .8895 .38175 Mtetra
.8895 .38175 .89116 .38419 .89539 .38286 .89373 .38042 Mtetra
.89373 .38042 .89539 .38286 .89962 .38154 .89797 .3791 Mtetra
.89797 .3791 .89962 .38154 .90385 .38022 .90221 .37777 Mtetra
.90221 .37777 .90385 .38022 .9081 .37889 .90646 .37644 Mtetra
.90646 .37644 .9081 .37889 .91235 .37756 .91071 .37511 Mtetra
.91071 .37511 .91235 .37756 .9166 .37623 .91497 .37377 Mtetra
.91497 .37377 .9166 .37623 .92086 .3749 .91923 .37244 Mtetra
.91923 .37244 .92086 .3749 .92513 .37357 .92351 .3711 Mtetra
.92351 .3711 .92513 .37357 .9294 .37223 .92778 .36976 Mtetra
.34644 .54907 .3486 .55109 .35209 .54999 .34992 .54798 Mtetra
.34992 .54798 .35209 .54999 .35557 .5489 .35342 .54688 Mtetra
.35342 .54688 .35557 .5489 .35907 .54781 .35691 .54579 Mtetra
.35691 .54579 .35907 .54781 .36257 .54671 .36041 .54469 Mtetra
.36041 .54469 .36257 .54671 .36607 .54562 .36392 .54359 Mtetra
.36392 .54359 .36607 .54562 .36958 .54452 .36743 .54249 Mtetra
.36743 .54249 .36958 .54452 .37309 .54342 .37095 .54139 Mtetra
.37095 .54139 .37309 .54342 .37661 .54232 .37446 .54028 Mtetra
.37446 .54028 .37661 .54232 .38013 .54122 .37799 .53918 Mtetra
.37799 .53918 .38013 .54122 .38365 .54011 .38152 .53807 Mtetra
.38152 .53807 .38365 .54011 .38718 .53901 .38505 .53696 Mtetra
.38505 .53696 .38718 .53901 .39072 .5379 .38859 .53585 Mtetra
.38859 .53585 .39072 .5379 .39426 .53679 .39213 .53474 Mtetra
.39213 .53474 .39426 .53679 .3978 .53568 .39568 .53363 Mtetra
.39568 .53363 .3978 .53568 .40135 .53457 .39923 .53251 Mtetra
.39923 .53251 .40135 .53457 .40491 .53346 .40279 .5314 Mtetra
.40279 .5314 .40491 .53346 .40847 .53234 .40635 .53028 Mtetra
.40635 .53028 .40847 .53234 .41203 .53123 .40992 .52916 Mtetra
.40992 .52916 .41203 .53123 .4156 .53011 .41349 .52804 Mtetra
.41349 .52804 .4156 .53011 .41917 .52899 .41706 .52692 Mtetra
.41706 .52692 .41917 .52899 .42275 .52787 .42065 .5258 Mtetra
.42065 .5258 .42275 .52787 .42633 .52675 .42423 .52468 Mtetra
.42423 .52468 .42633 .52675 .42992 .52563 .42782 .52355 Mtetra
.42782 .52355 .42992 .52563 .43351 .5245 .43142 .52242 Mtetra
.43142 .52242 .43351 .5245 .43711 .52338 .43502 .52129 Mtetra
.43502 .52129 .43711 .52338 .44071 .52225 .43862 .52016 Mtetra
.43862 .52016 .44071 .52225 .44432 .52112 .44223 .51903 Mtetra
.44223 .51903 .44432 .52112 .44793 .51999 .44584 .5179 Mtetra
.44584 .5179 .44793 .51999 .45154 .51886 .44946 .51676 Mtetra
.44946 .51676 .45154 .51886 .45516 .51772 .45309 .51563 Mtetra
.45309 .51563 .45516 .51772 .45879 .51659 .45672 .51449 Mtetra
.45672 .51449 .45879 .51659 .46242 .51545 .46035 .51335 Mtetra
.46035 .51335 .46242 .51545 .46605 .51431 .46399 .51221 Mtetra
.46399 .51221 .46605 .51431 .46969 .51317 .46763 .51107 Mtetra
.46763 .51107 .46969 .51317 .47334 .51203 .47128 .50992 Mtetra
.47128 .50992 .47334 .51203 .47699 .51089 .47493 .50878 Mtetra
.47493 .50878 .47699 .51089 .48064 .50975 .47859 .50763 Mtetra
.47859 .50763 .48064 .50975 .4843 .5086 .48225 .50648 Mtetra
.48225 .50648 .4843 .5086 .48797 .50745 .48592 .50533 Mtetra
.48592 .50533 .48797 .50745 .49164 .50631 .48959 .50418 Mtetra
.48959 .50418 .49164 .50631 .49531 .50515 .49327 .50303 Mtetra
.49327 .50303 .49531 .50515 .49899 .504 .49695 .50187 Mtetra
.49695 .50187 .49899 .504 .50268 .50285 .50064 .50072 Mtetra
.956 .681 .477 r
.50064 .50072 .50268 .50285 .50637 .50169 .5032 .68323 Mtetra
.561 .347 .546 r
.5032 .68323 .50637 .50169 .50924 .68415 .5071 .68214 Mtetra
.648 .76 .931 r
.5071 .68214 .50924 .68415 .51314 .68306 .51101 .68104 Mtetra
.51101 .68104 .51314 .68306 .51705 .68197 .51492 .67995 Mtetra
.51492 .67995 .51705 .68197 .52097 .68087 .51884 .67885 Mtetra
.51884 .67885 .52097 .68087 .52489 .67978 .52276 .67775 Mtetra
.52276 .67775 .52489 .67978 .52881 .67868 .52669 .67665 Mtetra
.52669 .67665 .52881 .67868 .53274 .67758 .53062 .67555 Mtetra
.53062 .67555 .53274 .67758 .53668 .67648 .53456 .67444 Mtetra
.53456 .67444 .53668 .67648 .54062 .67538 .53851 .67334 Mtetra
.53851 .67334 .54062 .67538 .54457 .67427 .54246 .67223 Mtetra
.54246 .67223 .54457 .67427 .54852 .67317 .54642 .67112 Mtetra
.54642 .67112 .54852 .67317 .55248 .67206 .55038 .67001 Mtetra
.55038 .67001 .55248 .67206 .55645 .67095 .55435 .6689 Mtetra
.55435 .6689 .55645 .67095 .55864 .49458 .55833 .66779 Mtetra
.561 .346 .546 r
.55833 .66779 .55864 .49458 .56241 .49341 .56231 .66667 Mtetra
.413 .231 .521 r
.56231 .66667 .56241 .49341 .56756 .60218 .56551 .60007 Mtetra
.654 .753 .922 r
.56551 .60007 .56756 .60218 .57148 .60104 .56943 .59893 Mtetra
.56943 .59893 .57148 .60104 .57539 .5999 .57335 .59779 Mtetra
.57335 .59779 .57539 .5999 .57932 .59876 .57728 .59664 Mtetra
.57728 .59664 .57932 .59876 .58325 .59761 .58121 .59549 Mtetra
.58121 .59549 .58325 .59761 .58718 .59646 .58515 .59434 Mtetra
.58515 .59434 .58718 .59646 .59112 .59531 .58909 .59319 Mtetra
.58909 .59319 .59112 .59531 .59507 .59416 .59304 .59204 Mtetra
.59304 .59204 .59507 .59416 .59902 .59301 .597 .59088 Mtetra
.597 .59088 .59902 .59301 .60298 .59186 .60096 .58973 Mtetra
.60096 .58973 .60298 .59186 .60694 .5907 .60493 .58857 Mtetra
.60493 .58857 .60694 .5907 .61091 .58955 .6089 .58741 Mtetra
.6089 .58741 .61091 .58955 .61488 .58839 .61288 .58625 Mtetra
.61288 .58625 .61488 .58839 .61886 .58723 .61686 .58508 Mtetra
.61686 .58508 .61886 .58723 .62285 .58607 .62085 .58392 Mtetra
.62085 .58392 .62285 .58607 .62684 .5849 .62484 .58275 Mtetra
.62484 .58275 .62684 .5849 .63083 .58374 .62884 .58158 Mtetra
.62884 .58158 .63083 .58374 .63484 .58257 .63285 .58041 Mtetra
.63285 .58041 .63484 .58257 .63884 .5814 .63686 .57924 Mtetra
.966 .662 .396 r
.63686 .57924 .63884 .5814 .64514 .64615 .64313 .64403 Mtetra
.648 .76 .931 r
.64313 .64403 .64514 .64615 .64924 .645 .64723 .64288 Mtetra
.64723 .64288 .64924 .645 .65335 .64386 .65134 .64173 Mtetra
.65134 .64173 .65335 .64386 .65746 .64271 .65546 .64058 Mtetra
.65546 .64058 .65746 .64271 .66158 .64156 .65958 .63943 Mtetra
.65958 .63943 .66158 .64156 .6657 .6404 .66371 .63827 Mtetra
.66371 .63827 .6657 .6404 .66983 .63925 .66784 .63711 Mtetra
.66784 .63711 .66983 .63925 .67396 .63809 .67198 .63595 Mtetra
.67198 .63595 .67396 .63809 .6781 .63693 .67613 .63479 Mtetra
.67613 .63479 .6781 .63693 .68225 .63577 .68028 .63363 Mtetra
.68028 .63363 .68225 .63577 .68641 .63461 .68443 .63246 Mtetra
.68443 .63246 .68641 .63461 .69057 .63345 .6886 .6313 Mtetra
.6886 .6313 .69057 .63345 .69473 .63228 .69277 .63013 Mtetra
.69277 .63013 .69473 .63228 .6989 .63112 .69694 .62896 Mtetra
.69694 .62896 .6989 .63112 .70308 .62995 .70113 .62779 Mtetra
.70113 .62779 .70308 .62995 .70726 .62878 .70532 .62661 Mtetra
.70532 .62661 .70726 .62878 .71146 .62761 .70951 .62544 Mtetra
.70951 .62544 .71146 .62761 .71565 .62643 .71371 .62426 Mtetra
.71371 .62426 .71565 .62643 .71985 .62526 .71792 .62308 Mtetra
.71792 .62308 .71985 .62526 .72406 .62408 .72213 .6219 Mtetra
.72213 .6219 .72406 .62408 .72828 .6229 .72635 .62072 Mtetra
.72635 .62072 .72828 .6229 .7325 .62172 .73058 .61954 Mtetra
.73058 .61954 .7325 .62172 .73673 .62054 .73481 .61835 Mtetra
.73481 .61835 .73673 .62054 .74096 .61936 .73905 .61717 Mtetra
.73905 .61717 .74096 .61936 .7452 .61817 .74329 .61598 Mtetra
.975 .701 .444 r
.74329 .61598 .7452 .61817 .74348 .52552 .74161 .52325 Mtetra
.656 .751 .919 r
.74161 .52325 .74348 .52552 .74761 .52429 .74575 .52203 Mtetra
.74575 .52203 .74761 .52429 .75175 .52307 .7499 .5208 Mtetra
.7499 .5208 .75175 .52307 .7559 .52184 .75405 .51957 Mtetra
.75405 .51957 .7559 .52184 .76005 .52061 .75821 .51834 Mtetra
.75821 .51834 .76005 .52061 .76421 .51938 .76237 .5171 Mtetra
.76237 .5171 .76421 .51938 .76838 .51815 .76654 .51587 Mtetra
.76654 .51587 .76838 .51815 .77255 .51691 .77072 .51463 Mtetra
.77072 .51463 .77255 .51691 .76946 .41933 .7749 .51339 Mtetra
.559 .34 .539 r
.7749 .51339 .76946 .41933 .77352 .41806 .77909 .51215 Mtetra
.079 0 .444 r
.77909 .51215 .77352 .41806 .77758 .41679 .7758 .41443 Mtetra
.664 .741 .908 r
.7758 .41443 .77758 .41679 .78165 .41551 .77987 .41316 Mtetra
.77987 .41316 .78165 .41551 .78572 .41424 .78395 .41188 Mtetra
.78395 .41188 .78572 .41424 .7898 .41296 .78804 .4106 Mtetra
.78804 .4106 .7898 .41296 .79389 .41168 .79213 .40931 Mtetra
.79213 .40931 .79389 .41168 .79798 .4104 .79622 .40803 Mtetra
.79622 .40803 .79798 .4104 .80208 .40912 .80033 .40674 Mtetra
.80033 .40674 .80208 .40912 .80618 .40783 .80443 .40545 Mtetra
.80443 .40545 .80618 .40783 .81029 .40654 .80855 .40416 Mtetra
.80855 .40416 .81029 .40654 .81441 .40526 .81267 .40287 Mtetra
.81267 .40287 .81441 .40526 .81853 .40396 .81679 .40158 Mtetra
0 .278 .778 r
.81679 .40158 .81853 .40396 .82266 .40267 .82136 .40499 Mtetra
.259 0 0 r
.82136 .40499 .82266 .40267 .82679 .40138 .8255 .40369 Mtetra
.8255 .40369 .82679 .40138 .83093 .40008 .82965 .4024 Mtetra
.82965 .4024 .83093 .40008 .83508 .39879 .83381 .4011 Mtetra
.83381 .4011 .83508 .39879 .83923 .39749 .83797 .39979 Mtetra
.83797 .39979 .83923 .39749 .84338 .39618 .84214 .39849 Mtetra
0 0 0 r
.84214 .39849 .84338 .39618 .84755 .39488 .84584 .39247 Mtetra
.664 .741 .908 r
.84584 .39247 .84755 .39488 .85171 .39358 .85001 .39116 Mtetra
.85001 .39116 .85171 .39358 .85589 .39227 .85419 .38985 Mtetra
.85419 .38985 .85589 .39227 .86007 .39096 .85837 .38854 Mtetra
.85837 .38854 .86007 .39096 .86426 .38965 .86257 .38723 Mtetra
.86257 .38723 .86426 .38965 .86845 .38834 .86676 .38591 Mtetra
.86676 .38591 .86845 .38834 .87265 .38702 .87097 .38459 Mtetra
.87097 .38459 .87265 .38702 .87685 .38571 .87518 .38327 Mtetra
.87518 .38327 .87685 .38571 .88106 .38439 .87939 .38195 Mtetra
.87939 .38195 .88106 .38439 .88528 .38307 .88361 .38063 Mtetra
.88361 .38063 .88528 .38307 .8895 .38175 .88784 .3793 Mtetra
.88784 .3793 .8895 .38175 .89373 .38042 .89207 .37797 Mtetra
.89207 .37797 .89373 .38042 .89797 .3791 .89631 .37664 Mtetra
.89631 .37664 .89797 .3791 .90221 .37777 .90056 .37531 Mtetra
.90056 .37531 .90221 .37777 .90646 .37644 .90481 .37398 Mtetra
.90481 .37398 .90646 .37644 .91071 .37511 .90907 .37264 Mtetra
.90907 .37264 .91071 .37511 .91497 .37377 .91333 .37131 Mtetra
.91333 .37131 .91497 .37377 .91923 .37244 .9176 .36997 Mtetra
.9176 .36997 .91923 .37244 .92351 .3711 .92188 .36863 Mtetra
.92188 .36863 .92351 .3711 .92778 .36976 .92616 .36728 Mtetra
.34427 .54705 .34644 .54907 .34992 .54798 .34776 .54595 Mtetra
.34776 .54595 .34992 .54798 .35342 .54688 .35125 .54486 Mtetra
.35125 .54486 .35342 .54688 .35691 .54579 .35475 .54376 Mtetra
.35475 .54376 .35691 .54579 .36041 .54469 .35826 .54266 Mtetra
.35826 .54266 .36041 .54469 .36392 .54359 .36176 .54155 Mtetra
.36176 .54155 .36392 .54359 .36743 .54249 .36528 .54045 Mtetra
.36528 .54045 .36743 .54249 .37095 .54139 .3688 .53935 Mtetra
.3688 .53935 .37095 .54139 .37446 .54028 .37232 .53824 Mtetra
.37232 .53824 .37446 .54028 .37799 .53918 .37585 .53713 Mtetra
.37585 .53713 .37799 .53918 .38152 .53807 .37938 .53602 Mtetra
.37938 .53602 .38152 .53807 .38505 .53696 .38291 .53491 Mtetra
.38291 .53491 .38505 .53696 .38859 .53585 .38645 .5338 Mtetra
.38645 .5338 .38859 .53585 .39213 .53474 .39 .53269 Mtetra
.39 .53269 .39213 .53474 .39568 .53363 .39355 .53157 Mtetra
.39355 .53157 .39568 .53363 .39923 .53251 .39711 .53045 Mtetra
.39711 .53045 .39923 .53251 .40279 .5314 .40067 .52934 Mtetra
.40067 .52934 .40279 .5314 .40635 .53028 .40423 .52822 Mtetra
.40423 .52822 .40635 .53028 .40992 .52916 .4078 .5271 Mtetra
.4078 .5271 .40992 .52916 .41349 .52804 .41137 .52597 Mtetra
.41137 .52597 .41349 .52804 .41706 .52692 .41495 .52485 Mtetra
.41495 .52485 .41706 .52692 .42065 .5258 .41854 .52372 Mtetra
.41854 .52372 .42065 .5258 .42423 .52468 .42213 .5226 Mtetra
.42213 .5226 .42423 .52468 .42782 .52355 .42572 .52147 Mtetra
.42572 .52147 .42782 .52355 .43142 .52242 .42932 .52034 Mtetra
.42932 .52034 .43142 .52242 .43502 .52129 .43292 .51921 Mtetra
.43292 .51921 .43502 .52129 .43862 .52016 .43653 .51807 Mtetra
.43653 .51807 .43862 .52016 .44223 .51903 .44014 .51694 Mtetra
.44014 .51694 .44223 .51903 .44584 .5179 .44376 .5158 Mtetra
.44376 .5158 .44584 .5179 .44946 .51676 .44738 .51466 Mtetra
.44738 .51466 .44946 .51676 .45309 .51563 .45101 .51353 Mtetra
.45101 .51353 .45309 .51563 .45672 .51449 .45464 .51239 Mtetra
.45464 .51239 .45672 .51449 .46035 .51335 .45827 .51124 Mtetra
.45827 .51124 .46035 .51335 .46399 .51221 .46192 .5101 Mtetra
.46192 .5101 .46399 .51221 .46763 .51107 .46556 .50895 Mtetra
.46556 .50895 .46763 .51107 .47128 .50992 .46921 .50781 Mtetra
.46921 .50781 .47128 .50992 .47493 .50878 .47287 .50666 Mtetra
.47287 .50666 .47493 .50878 .47859 .50763 .47653 .50551 Mtetra
.47653 .50551 .47859 .50763 .48225 .50648 .4802 .50436 Mtetra
.4802 .50436 .48225 .50648 .48592 .50533 .48387 .5032 Mtetra
.48387 .5032 .48592 .50533 .48959 .50418 .48754 .50205 Mtetra
.48754 .50205 .48959 .50418 .49327 .50303 .49122 .50089 Mtetra
.49122 .50089 .49327 .50303 .49695 .50187 .49491 .49974 Mtetra
.49491 .49974 .49695 .50187 .50064 .50072 .4986 .49858 Mtetra
.956 .681 .477 r
.4986 .49858 .50064 .50072 .5032 .68323 .50105 .68121 Mtetra
.648 .76 .931 r
.50105 .68121 .5032 .68323 .5071 .68214 .50495 .68012 Mtetra
.50495 .68012 .5071 .68214 .51101 .68104 .50886 .67902 Mtetra
.50886 .67902 .51101 .68104 .51492 .67995 .51278 .67792 Mtetra
.51278 .67792 .51492 .67995 .51884 .67885 .5167 .67682 Mtetra
.5167 .67682 .51884 .67885 .52276 .67775 .52063 .67572 Mtetra
.52063 .67572 .52276 .67775 .52669 .67665 .52456 .67461 Mtetra
.52456 .67461 .52669 .67665 .53062 .67555 .5285 .67351 Mtetra
.5285 .67351 .53062 .67555 .53456 .67444 .53244 .6724 Mtetra
.53244 .6724 .53456 .67444 .53851 .67334 .53639 .67129 Mtetra
.53639 .67129 .53851 .67334 .54246 .67223 .54035 .67018 Mtetra
.54035 .67018 .54246 .67223 .54642 .67112 .54431 .66907 Mtetra
.54431 .66907 .54642 .67112 .55038 .67001 .54827 .66796 Mtetra
.54827 .66796 .55038 .67001 .55435 .6689 .55225 .66685 Mtetra
.55225 .66685 .55435 .6689 .55833 .66779 .55623 .66573 Mtetra
.55623 .66573 .55833 .66779 .56231 .66667 .56021 .66461 Mtetra
.958 .705 .512 r
.56021 .66461 .56231 .66667 .56551 .60007 .56346 .59796 Mtetra
.654 .753 .922 r
.56346 .59796 .56551 .60007 .56943 .59893 .56738 .59682 Mtetra
.56738 .59682 .56943 .59893 .57335 .59779 .57131 .59567 Mtetra
.57131 .59567 .57335 .59779 .57728 .59664 .57524 .59452 Mtetra
.57524 .59452 .57728 .59664 .58121 .59549 .57917 .59337 Mtetra
.57917 .59337 .58121 .59549 .58515 .59434 .58312 .59221 Mtetra
.58312 .59221 .58515 .59434 .58909 .59319 .58706 .59106 Mtetra
.58706 .59106 .58909 .59319 .59304 .59204 .59102 .5899 Mtetra
.59102 .5899 .59304 .59204 .597 .59088 .59498 .58875 Mtetra
.59498 .58875 .597 .59088 .60096 .58973 .59894 .58759 Mtetra
.59894 .58759 .60096 .58973 .60493 .58857 .60291 .58643 Mtetra
.60291 .58643 .60493 .58857 .6089 .58741 .60689 .58526 Mtetra
.60689 .58526 .6089 .58741 .61288 .58625 .61087 .5841 Mtetra
.61087 .5841 .61288 .58625 .61686 .58508 .61486 .58293 Mtetra
.61486 .58293 .61686 .58508 .62085 .58392 .61885 .58176 Mtetra
.61885 .58176 .62085 .58392 .62484 .58275 .62285 .58059 Mtetra
.62285 .58059 .62484 .58275 .62884 .58158 .62685 .57942 Mtetra
.62685 .57942 .62884 .58158 .63285 .58041 .63086 .57825 Mtetra
.63086 .57825 .63285 .58041 .63686 .57924 .63488 .57708 Mtetra
.966 .662 .396 r
.63488 .57708 .63686 .57924 .64313 .64403 .64111 .64191 Mtetra
.648 .76 .931 r
.64111 .64191 .64313 .64403 .64723 .64288 .64522 .64076 Mtetra
.64522 .64076 .64723 .64288 .65134 .64173 .64933 .6396 Mtetra
.64933 .6396 .65134 .64173 .65546 .64058 .65345 .63845 Mtetra
.65345 .63845 .65546 .64058 .65958 .63943 .65758 .63729 Mtetra
.65758 .63729 .65958 .63943 .66371 .63827 .66171 .63613 Mtetra
.66171 .63613 .66371 .63827 .66784 .63711 .66585 .63497 Mtetra
.66585 .63497 .66784 .63711 .67198 .63595 .66999 .63381 Mtetra
.66999 .63381 .67198 .63595 .67613 .63479 .67414 .63264 Mtetra
.67414 .63264 .67613 .63479 .68028 .63363 .6783 .63148 Mtetra
.6783 .63148 .68028 .63363 .68443 .63246 .68246 .63031 Mtetra
.68246 .63031 .68443 .63246 .6886 .6313 .68663 .62914 Mtetra
.68663 .62914 .6886 .6313 .69277 .63013 .6908 .62797 Mtetra
.6908 .62797 .69277 .63013 .69694 .62896 .69498 .6268 Mtetra
.69498 .6268 .69694 .62896 .70113 .62779 .69917 .62562 Mtetra
.69917 .62562 .70113 .62779 .70532 .62661 .70336 .62444 Mtetra
.70336 .62444 .70532 .62661 .70951 .62544 .70756 .62327 Mtetra
.70756 .62327 .70951 .62544 .71371 .62426 .71176 .62209 Mtetra
.71176 .62209 .71371 .62426 .71792 .62308 .71598 .6209 Mtetra
.71598 .6209 .71792 .62308 .72213 .6219 .72019 .61972 Mtetra
.72019 .61972 .72213 .6219 .72635 .62072 .72442 .61854 Mtetra
.72442 .61854 .72635 .62072 .73058 .61954 .72865 .61735 Mtetra
.72865 .61735 .73058 .61954 .73481 .61835 .73288 .61616 Mtetra
.73288 .61616 .73481 .61835 .73905 .61717 .73713 .61497 Mtetra
.975 .701 .446 r
.73713 .61497 .73905 .61717 .74329 .61598 .73561 .52222 Mtetra
.57 .368 .567 r
.73561 .52222 .74329 .61598 .74161 .52325 .73974 .52099 Mtetra
.656 .751 .919 r
.73974 .52099 .74161 .52325 .74575 .52203 .74389 .51976 Mtetra
.74389 .51976 .74575 .52203 .7499 .5208 .74804 .51853 Mtetra
.74804 .51853 .7499 .5208 .75405 .51957 .75219 .51729 Mtetra
.75219 .51729 .75405 .51957 .75821 .51834 .75635 .51606 Mtetra
.75635 .51606 .75821 .51834 .76237 .5171 .76052 .51482 Mtetra
.76052 .51482 .76237 .5171 .76654 .51587 .7647 .51358 Mtetra
.7647 .51358 .76654 .51587 .77072 .51463 .76888 .51234 Mtetra
.76888 .51234 .77072 .51463 .7749 .51339 .77306 .5111 Mtetra
.77306 .5111 .7749 .51339 .77909 .51215 .77725 .50985 Mtetra
.77725 .50985 .77909 .51215 .7758 .41443 .78145 .5086 Mtetra
.558 .339 .539 r
.78145 .5086 .7758 .41443 .77987 .41316 .78566 .50736 Mtetra
.112 .015 .455 r
.78566 .50736 .77987 .41316 .78395 .41188 .78255 .41421 Mtetra
.257 0 0 r
.78255 .41421 .78395 .41188 .78804 .4106 .78665 .41292 Mtetra
.78665 .41292 .78804 .4106 .79213 .40931 .79075 .41164 Mtetra
.79075 .41164 .79213 .40931 .79622 .40803 .79485 .41035 Mtetra
.79485 .41035 .79622 .40803 .80033 .40674 .79897 .40906 Mtetra
.79897 .40906 .80033 .40674 .80443 .40545 .80309 .40777 Mtetra
.80309 .40777 .80443 .40545 .80855 .40416 .80721 .40648 Mtetra
.80721 .40648 .80855 .40416 .81267 .40287 .81134 .40519 Mtetra
.81134 .40519 .81267 .40287 .81679 .40158 .81548 .40389 Mtetra
.81548 .40389 .81679 .40158 .82136 .40499 .81962 .4026 Mtetra
.663 .742 .908 r
.81962 .4026 .82136 .40499 .8255 .40369 .82377 .4013 Mtetra
.82377 .4013 .8255 .40369 .82965 .4024 .82792 .4 Mtetra
.82792 .4 .82965 .4024 .83381 .4011 .83208 .39869 Mtetra
.83208 .39869 .83381 .4011 .83797 .39979 .83625 .39739 Mtetra
.83625 .39739 .83797 .39979 .84214 .39849 .84042 .39608 Mtetra
.891 .796 .748 r
.84042 .39608 .84214 .39849 .84584 .39247 .84413 .39005 Mtetra
.664 .741 .908 r
.84413 .39005 .84584 .39247 .85001 .39116 .8483 .38874 Mtetra
.8483 .38874 .85001 .39116 .85419 .38985 .85249 .38743 Mtetra
.85249 .38743 .85419 .38985 .85837 .38854 .85668 .38611 Mtetra
.85668 .38611 .85837 .38854 .86257 .38723 .86087 .38479 Mtetra
.86087 .38479 .86257 .38723 .86676 .38591 .86507 .38347 Mtetra
.86507 .38347 .86676 .38591 .87097 .38459 .86928 .38215 Mtetra
.86928 .38215 .87097 .38459 .87518 .38327 .87349 .38083 Mtetra
.87349 .38083 .87518 .38327 .87939 .38195 .87771 .3795 Mtetra
.87771 .3795 .87939 .38195 .88361 .38063 .88194 .37818 Mtetra
.88194 .37818 .88361 .38063 .88784 .3793 .88617 .37685 Mtetra
.88617 .37685 .88784 .3793 .89207 .37797 .89041 .37552 Mtetra
.89041 .37552 .89207 .37797 .89631 .37664 .89465 .37418 Mtetra
.89465 .37418 .89631 .37664 .90056 .37531 .8989 .37285 Mtetra
.8989 .37285 .90056 .37531 .90481 .37398 .90316 .37151 Mtetra
.90316 .37151 .90481 .37398 .90907 .37264 .90742 .37017 Mtetra
.90742 .37017 .90907 .37264 .91333 .37131 .91169 .36883 Mtetra
.91169 .36883 .91333 .37131 .9176 .36997 .91596 .36749 Mtetra
.91596 .36749 .9176 .36997 .92188 .36863 .92025 .36615 Mtetra
.92025 .36615 .92188 .36863 .92616 .36728 .92453 .3648 Mtetra
.34209 .54503 .34427 .54705 .34776 .54595 .34559 .54393 Mtetra
.34559 .54393 .34776 .54595 .35125 .54486 .34908 .54283 Mtetra
.34908 .54283 .35125 .54486 .35475 .54376 .35259 .54172 Mtetra
.35259 .54172 .35475 .54376 .35826 .54266 .35609 .54062 Mtetra
.35609 .54062 .35826 .54266 .36176 .54155 .3596 .53952 Mtetra
.3596 .53952 .36176 .54155 .36528 .54045 .36312 .53841 Mtetra
.36312 .53841 .36528 .54045 .3688 .53935 .36664 .5373 Mtetra
.36664 .5373 .3688 .53935 .37232 .53824 .37017 .53619 Mtetra
.37017 .53619 .37232 .53824 .37585 .53713 .3737 .53508 Mtetra
.3737 .53508 .37585 .53713 .37938 .53602 .37723 .53397 Mtetra
.37723 .53397 .37938 .53602 .38291 .53491 .38077 .53286 Mtetra
.38077 .53286 .38291 .53491 .38645 .5338 .38431 .53174 Mtetra
.38431 .53174 .38645 .5338 .39 .53269 .38786 .53063 Mtetra
.38786 .53063 .39 .53269 .39355 .53157 .39142 .52951 Mtetra
.39142 .52951 .39355 .53157 .39711 .53045 .39497 .52839 Mtetra
.39497 .52839 .39711 .53045 .40067 .52934 .39854 .52727 Mtetra
.39854 .52727 .40067 .52934 .40423 .52822 .4021 .52615 Mtetra
.4021 .52615 .40423 .52822 .4078 .5271 .40568 .52502 Mtetra
.40568 .52502 .4078 .5271 .41137 .52597 .40925 .5239 Mtetra
.40925 .5239 .41137 .52597 .41495 .52485 .41284 .52277 Mtetra
.41284 .52277 .41495 .52485 .41854 .52372 .41642 .52164 Mtetra
.41642 .52164 .41854 .52372 .42213 .5226 .42001 .52051 Mtetra
.42001 .52051 .42213 .5226 .42572 .52147 .42361 .51938 Mtetra
.42361 .51938 .42572 .52147 .42932 .52034 .42721 .51825 Mtetra
.42721 .51825 .42932 .52034 .43292 .51921 .43082 .51711 Mtetra
.43082 .51711 .43292 .51921 .43653 .51807 .43443 .51598 Mtetra
.43443 .51598 .43653 .51807 .44014 .51694 .43804 .51484 Mtetra
.43804 .51484 .44014 .51694 .44376 .5158 .44166 .5137 Mtetra
.44166 .5137 .44376 .5158 .44738 .51466 .44529 .51256 Mtetra
.44529 .51256 .44738 .51466 .45101 .51353 .44892 .51142 Mtetra
.44892 .51142 .45101 .51353 .45464 .51239 .45255 .51028 Mtetra
.45255 .51028 .45464 .51239 .45827 .51124 .45619 .50913 Mtetra
.45619 .50913 .45827 .51124 .46192 .5101 .45984 .50798 Mtetra
.45984 .50798 .46192 .5101 .46556 .50895 .46349 .50684 Mtetra
.46349 .50684 .46556 .50895 .46921 .50781 .46714 .50569 Mtetra
.46714 .50569 .46921 .50781 .47287 .50666 .4708 .50453 Mtetra
.4708 .50453 .47287 .50666 .47653 .50551 .47447 .50338 Mtetra
.47447 .50338 .47653 .50551 .4802 .50436 .47813 .50223 Mtetra
.47813 .50223 .4802 .50436 .48387 .5032 .48181 .50107 Mtetra
.48181 .50107 .48387 .5032 .48754 .50205 .48549 .49991 Mtetra
.48549 .49991 .48754 .50205 .49122 .50089 .48917 .49876 Mtetra
.48917 .49876 .49122 .50089 .49491 .49974 .49286 .49759 Mtetra
.955 .681 .478 r
.49286 .49759 .49491 .49974 .4986 .49858 .49499 .68028 Mtetra
.561 .346 .545 r
.49499 .68028 .4986 .49858 .50105 .68121 .49889 .67919 Mtetra
.648 .76 .931 r
.49889 .67919 .50105 .68121 .50495 .68012 .5028 .67809 Mtetra
.5028 .67809 .50495 .68012 .50886 .67902 .50671 .67699 Mtetra
.50671 .67699 .50886 .67902 .51278 .67792 .51063 .67589 Mtetra
.51063 .67589 .51278 .67792 .5167 .67682 .51456 .67478 Mtetra
.51456 .67478 .5167 .67682 .52063 .67572 .51849 .67368 Mtetra
.51849 .67368 .52063 .67572 .52456 .67461 .52242 .67257 Mtetra
.52242 .67257 .52456 .67461 .5285 .67351 .52637 .67146 Mtetra
.52637 .67146 .5285 .67351 .53244 .6724 .53031 .67036 Mtetra
.53031 .67036 .53244 .6724 .53639 .67129 .53427 .66924 Mtetra
.53427 .66924 .53639 .67129 .54035 .67018 .53823 .66813 Mtetra
.53823 .66813 .54035 .67018 .54431 .66907 .54219 .66702 Mtetra
.54219 .66702 .54431 .66907 .54827 .66796 .54616 .6659 Mtetra
.54616 .6659 .54827 .66796 .55225 .66685 .55014 .66478 Mtetra
.55014 .66478 .55225 .66685 .55623 .66573 .55412 .66366 Mtetra
.55412 .66366 .55623 .66573 .56021 .66461 .55811 .66254 Mtetra
.958 .705 .512 r
.55811 .66254 .56021 .66461 .56346 .59796 .5614 .59584 Mtetra
.654 .753 .922 r
.5614 .59584 .56346 .59796 .56738 .59682 .56532 .5947 Mtetra
.56532 .5947 .56738 .59682 .57131 .59567 .56925 .59354 Mtetra
.56925 .59354 .57131 .59567 .57524 .59452 .57319 .59239 Mtetra
.57319 .59239 .57524 .59452 .57917 .59337 .57713 .59124 Mtetra
.57713 .59124 .57917 .59337 .58312 .59221 .58107 .59008 Mtetra
.58107 .59008 .58312 .59221 .58706 .59106 .58503 .58892 Mtetra
.58503 .58892 .58706 .59106 .59102 .5899 .58898 .58776 Mtetra
.58898 .58776 .59102 .5899 .59498 .58875 .59295 .5866 Mtetra
.59295 .5866 .59498 .58875 .59894 .58759 .59691 .58544 Mtetra
.59691 .58544 .59894 .58759 .60291 .58643 .60089 .58428 Mtetra
.60089 .58428 .60291 .58643 .60689 .58526 .60487 .58311 Mtetra
.60487 .58311 .60689 .58526 .61087 .5841 .60885 .58194 Mtetra
.60885 .58194 .61087 .5841 .61486 .58293 .61284 .58077 Mtetra
.61284 .58077 .61486 .58293 .61885 .58176 .61684 .5796 Mtetra
.61684 .5796 .61885 .58176 .62285 .58059 .62084 .57843 Mtetra
.62084 .57843 .62285 .58059 .62685 .57942 .62485 .57726 Mtetra
.62485 .57726 .62685 .57942 .63086 .57825 .62887 .57608 Mtetra
.62887 .57608 .63086 .57825 .63488 .57708 .63289 .5749 Mtetra
.966 .662 .396 r
.63289 .5749 .63488 .57708 .64111 .64191 .63909 .63978 Mtetra
.648 .76 .931 r
.63909 .63978 .64111 .64191 .64522 .64076 .6432 .63863 Mtetra
.6432 .63863 .64522 .64076 .64933 .6396 .64732 .63747 Mtetra
.64732 .63747 .64933 .6396 .65345 .63845 .65144 .63631 Mtetra
.65144 .63631 .65345 .63845 .65758 .63729 .65557 .63515 Mtetra
.65557 .63515 .65758 .63729 .66171 .63613 .65971 .63399 Mtetra
.65971 .63399 .66171 .63613 .66585 .63497 .66385 .63282 Mtetra
.66385 .63282 .66585 .63497 .66999 .63381 .668 .63166 Mtetra
.668 .63166 .66999 .63381 .67414 .63264 .67215 .63049 Mtetra
.67215 .63049 .67414 .63264 .6783 .63148 .67631 .62932 Mtetra
.67631 .62932 .6783 .63148 .68246 .63031 .68048 .62815 Mtetra
.68048 .62815 .68246 .63031 .68663 .62914 .68465 .62698 Mtetra
.68465 .62698 .68663 .62914 .6908 .62797 .68883 .6258 Mtetra
.68883 .6258 .6908 .62797 .69498 .6268 .69301 .62463 Mtetra
.69301 .62463 .69498 .6268 .69917 .62562 .6972 .62345 Mtetra
.6972 .62345 .69917 .62562 .70336 .62444 .7014 .62227 Mtetra
.7014 .62227 .70336 .62444 .70756 .62327 .7056 .62109 Mtetra
.7056 .62109 .70756 .62327 .71176 .62209 .70981 .6199 Mtetra
.70981 .6199 .71176 .62209 .71598 .6209 .71403 .61872 Mtetra
.71403 .61872 .71598 .6209 .72019 .61972 .71825 .61753 Mtetra
.71825 .61753 .72019 .61972 .72442 .61854 .72248 .61634 Mtetra
.72248 .61634 .72442 .61854 .72865 .61735 .72671 .61515 Mtetra
.72671 .61515 .72865 .61735 .73288 .61616 .73095 .61396 Mtetra
.73095 .61396 .73288 .61616 .73713 .61497 .7352 .61277 Mtetra
.975 .701 .446 r
.7352 .61277 .73713 .61497 .73561 .52222 .73373 .51995 Mtetra
.656 .751 .919 r
.73373 .51995 .73561 .52222 .73974 .52099 .73787 .51872 Mtetra
.73787 .51872 .73974 .52099 .74389 .51976 .74202 .51748 Mtetra
.74202 .51748 .74389 .51976 .74804 .51853 .74617 .51625 Mtetra
.74617 .51625 .74804 .51853 .75219 .51729 .75033 .51501 Mtetra
.75033 .51501 .75219 .51729 .75635 .51606 .7545 .51377 Mtetra
.7545 .51377 .75635 .51606 .76052 .51482 .75867 .51253 Mtetra
.75867 .51253 .76052 .51482 .7647 .51358 .76285 .51129 Mtetra
.76285 .51129 .7647 .51358 .76888 .51234 .76703 .51004 Mtetra
.76703 .51004 .76888 .51234 .77306 .5111 .77122 .5088 Mtetra
.77122 .5088 .77306 .5111 .77725 .50985 .77542 .50755 Mtetra
.77542 .50755 .77725 .50985 .78145 .5086 .77962 .5063 Mtetra
.77962 .5063 .78145 .5086 .78566 .50736 .78383 .50505 Mtetra
.978 .699 .424 r
.78383 .50505 .78566 .50736 .78255 .41421 .78077 .41184 Mtetra
.663 .742 .908 r
.78077 .41184 .78255 .41421 .78665 .41292 .78487 .41055 Mtetra
.78487 .41055 .78665 .41292 .79075 .41164 .78897 .40926 Mtetra
.78897 .40926 .79075 .41164 .79485 .41035 .79309 .40797 Mtetra
.79309 .40797 .79485 .41035 .79897 .40906 .7972 .40668 Mtetra
.7972 .40668 .79897 .40906 .80309 .40777 .80132 .40539 Mtetra
.80132 .40539 .80309 .40777 .80721 .40648 .80545 .40409 Mtetra
.80545 .40409 .80721 .40648 .81134 .40519 .80959 .4028 Mtetra
.80959 .4028 .81134 .40519 .81548 .40389 .81373 .4015 Mtetra
.81373 .4015 .81548 .40389 .81962 .4026 .81787 .4002 Mtetra
.81787 .4002 .81962 .4026 .82377 .4013 .82203 .39889 Mtetra
.82203 .39889 .82377 .4013 .82792 .4 .82618 .39759 Mtetra
.82618 .39759 .82792 .4 .83208 .39869 .83035 .39628 Mtetra
.83035 .39628 .83208 .39869 .83625 .39739 .83452 .39497 Mtetra
.83452 .39497 .83625 .39739 .84042 .39608 .83869 .39366 Mtetra
.891 .796 .748 r
.83869 .39366 .84042 .39608 .84413 .39005 .84241 .38763 Mtetra
.664 .741 .908 r
.84241 .38763 .84413 .39005 .8483 .38874 .84659 .38631 Mtetra
.84659 .38631 .8483 .38874 .85249 .38743 .85078 .385 Mtetra
.85078 .385 .85249 .38743 .85668 .38611 .85497 .38368 Mtetra
.85497 .38368 .85668 .38611 .86087 .38479 .85917 .38236 Mtetra
.85917 .38236 .86087 .38479 .86507 .38347 .86338 .38103 Mtetra
.86338 .38103 .86507 .38347 .86928 .38215 .86759 .37971 Mtetra
.86759 .37971 .86928 .38215 .87349 .38083 .87181 .37838 Mtetra
.87181 .37838 .87349 .38083 .87771 .3795 .87603 .37705 Mtetra
.87603 .37705 .87771 .3795 .88194 .37818 .88026 .37572 Mtetra
.88026 .37572 .88194 .37818 .88617 .37685 .8845 .37439 Mtetra
.8845 .37439 .88617 .37685 .89041 .37552 .88874 .37305 Mtetra
.88874 .37305 .89041 .37552 .89465 .37418 .89299 .37172 Mtetra
.89299 .37172 .89465 .37418 .8989 .37285 .89724 .37038 Mtetra
.89724 .37038 .8989 .37285 .90316 .37151 .9015 .36904 Mtetra
.9015 .36904 .90316 .37151 .90742 .37017 .90577 .3677 Mtetra
.90577 .3677 .90742 .37017 .91169 .36883 .91004 .36635 Mtetra
.91004 .36635 .91169 .36883 .91596 .36749 .91432 .36501 Mtetra
.91432 .36501 .91596 .36749 .92025 .36615 .91861 .36366 Mtetra
.91861 .36366 .92025 .36615 .92453 .3648 .9229 .36231 Mtetra
.33991 .543 .34209 .54503 .34559 .54393 .34341 .54189 Mtetra
.34341 .54189 .34559 .54393 .34908 .54283 .34691 .54079 Mtetra
.34691 .54079 .34908 .54283 .35259 .54172 .35041 .53969 Mtetra
.35041 .53969 .35259 .54172 .35609 .54062 .35392 .53858 Mtetra
.35392 .53858 .35609 .54062 .3596 .53952 .35744 .53747 Mtetra
.35744 .53747 .3596 .53952 .36312 .53841 .36096 .53636 Mtetra
.36096 .53636 .36312 .53841 .36664 .5373 .36448 .53525 Mtetra
.36448 .53525 .36664 .5373 .37017 .53619 .36801 .53414 Mtetra
.36801 .53414 .37017 .53619 .3737 .53508 .37154 .53303 Mtetra
.37154 .53303 .3737 .53508 .37723 .53397 .37508 .53191 Mtetra
.37508 .53191 .37723 .53397 .38077 .53286 .37862 .5308 Mtetra
.37862 .5308 .38077 .53286 .38431 .53174 .38217 .52968 Mtetra
.38217 .52968 .38431 .53174 .38786 .53063 .38572 .52856 Mtetra
.38572 .52856 .38786 .53063 .39142 .52951 .38928 .52744 Mtetra
.38928 .52744 .39142 .52951 .39497 .52839 .39284 .52632 Mtetra
.39284 .52632 .39497 .52839 .39854 .52727 .3964 .5252 Mtetra
.3964 .5252 .39854 .52727 .4021 .52615 .39997 .52407 Mtetra
.39997 .52407 .4021 .52615 .40568 .52502 .40355 .52294 Mtetra
.40355 .52294 .40568 .52502 .40925 .5239 .40713 .52182 Mtetra
.40713 .52182 .40925 .5239 .41284 .52277 .41071 .52069 Mtetra
.41071 .52069 .41284 .52277 .41642 .52164 .4143 .51955 Mtetra
.4143 .51955 .41642 .52164 .42001 .52051 .4179 .51842 Mtetra
.4179 .51842 .42001 .52051 .42361 .51938 .4215 .51729 Mtetra
.4215 .51729 .42361 .51938 .42721 .51825 .4251 .51615 Mtetra
.4251 .51615 .42721 .51825 .43082 .51711 .42871 .51502 Mtetra
.42871 .51502 .43082 .51711 .43443 .51598 .43232 .51388 Mtetra
.43232 .51388 .43443 .51598 .43804 .51484 .43594 .51274 Mtetra
.43594 .51274 .43804 .51484 .44166 .5137 .43957 .51159 Mtetra
.43957 .51159 .44166 .5137 .44529 .51256 .44319 .51045 Mtetra
.44319 .51045 .44529 .51256 .44892 .51142 .44683 .50931 Mtetra
.44683 .50931 .44892 .51142 .45255 .51028 .45047 .50816 Mtetra
.45047 .50816 .45255 .51028 .45619 .50913 .45411 .50701 Mtetra
.45411 .50701 .45619 .50913 .45984 .50798 .45776 .50586 Mtetra
.45776 .50586 .45984 .50798 .46349 .50684 .46141 .50471 Mtetra
.46141 .50471 .46349 .50684 .46714 .50569 .46507 .50356 Mtetra
.46507 .50356 .46714 .50569 .4708 .50453 .46873 .50241 Mtetra
.46873 .50241 .4708 .50453 .47447 .50338 .4724 .50125 Mtetra
.4724 .50125 .47447 .50338 .47813 .50223 .47607 .50009 Mtetra
.47607 .50009 .47813 .50223 .48181 .50107 .47975 .49893 Mtetra
.47975 .49893 .48181 .50107 .48549 .49991 .48343 .49777 Mtetra
.48343 .49777 .48549 .49991 .48917 .49876 .48712 .49661 Mtetra
.48712 .49661 .48917 .49876 .49286 .49759 .49081 .49545 Mtetra
.955 .681 .478 r
.49081 .49545 .49286 .49759 .49499 .68028 .49282 .67826 Mtetra
.648 .76 .931 r
.49282 .67826 .49499 .68028 .49889 .67919 .49673 .67716 Mtetra
.49673 .67716 .49889 .67919 .5028 .67809 .50064 .67606 Mtetra
.50064 .67606 .5028 .67809 .50671 .67699 .50456 .67495 Mtetra
.50456 .67495 .50671 .67699 .51063 .67589 .50848 .67385 Mtetra
.50848 .67385 .51063 .67589 .51456 .67478 .51241 .67274 Mtetra
.51241 .67274 .51456 .67478 .51849 .67368 .51634 .67164 Mtetra
.51634 .67164 .51849 .67368 .52242 .67257 .52028 .67053 Mtetra
.52028 .67053 .52242 .67257 .52637 .67146 .52423 .66942 Mtetra
.52423 .66942 .52637 .67146 .53031 .67036 .52818 .6683 Mtetra
.52818 .6683 .53031 .67036 .53427 .66924 .53214 .66719 Mtetra
.53214 .66719 .53427 .66924 .53823 .66813 .5361 .66607 Mtetra
.5361 .66607 .53823 .66813 .54219 .66702 .54007 .66496 Mtetra
.54007 .66496 .54219 .66702 .54616 .6659 .54404 .66384 Mtetra
.54404 .66384 .54616 .6659 .55014 .66478 .54802 .66272 Mtetra
.54802 .66272 .55014 .66478 .55412 .66366 .55201 .66159 Mtetra
.55201 .66159 .55412 .66366 .55811 .66254 .556 .66047 Mtetra
.556 .66047 .55811 .66254 .5614 .59584 .56 .65934 Mtetra
0 0 .349 r
.56 .65934 .5614 .59584 .56532 .5947 .56326 .59257 Mtetra
.654 .753 .922 r
.56326 .59257 .56532 .5947 .56925 .59354 .5672 .59142 Mtetra
.5672 .59142 .56925 .59354 .57319 .59239 .57113 .59026 Mtetra
.57113 .59026 .57319 .59239 .57713 .59124 .57508 .5891 Mtetra
.57508 .5891 .57713 .59124 .58107 .59008 .57903 .58794 Mtetra
.57903 .58794 .58107 .59008 .58503 .58892 .58298 .58678 Mtetra
.58298 .58678 .58503 .58892 .58898 .58776 .58694 .58562 Mtetra
.58694 .58562 .58898 .58776 .59295 .5866 .59091 .58446 Mtetra
.59091 .58446 .59295 .5866 .59691 .58544 .59488 .58329 Mtetra
.59488 .58329 .59691 .58544 .60089 .58428 .59886 .58212 Mtetra
.59886 .58212 .60089 .58428 .60487 .58311 .60284 .58095 Mtetra
.60284 .58095 .60487 .58311 .60885 .58194 .60683 .57978 Mtetra
.60683 .57978 .60885 .58194 .61284 .58077 .61083 .57861 Mtetra
.61083 .57861 .61284 .58077 .61684 .5796 .61483 .57744 Mtetra
.61483 .57744 .61684 .5796 .62084 .57843 .61884 .57626 Mtetra
.61884 .57626 .62084 .57843 .62485 .57726 .62285 .57508 Mtetra
.62285 .57508 .62485 .57726 .62887 .57608 .62687 .57391 Mtetra
.62687 .57391 .62887 .57608 .63289 .5749 .63089 .57273 Mtetra
.966 .662 .396 r
.63089 .57273 .63289 .5749 .63909 .63978 .63706 .63765 Mtetra
.648 .76 .931 r
.63706 .63765 .63909 .63978 .6432 .63863 .64118 .63649 Mtetra
.64118 .63649 .6432 .63863 .64732 .63747 .6453 .63533 Mtetra
.6453 .63533 .64732 .63747 .65144 .63631 .64943 .63417 Mtetra
.64943 .63417 .65144 .63631 .65557 .63515 .65356 .633 Mtetra
.65356 .633 .65557 .63515 .65971 .63399 .6577 .63184 Mtetra
.6577 .63184 .65971 .63399 .66385 .63282 .66185 .63067 Mtetra
.66185 .63067 .66385 .63282 .668 .63166 .666 .6295 Mtetra
.666 .6295 .668 .63166 .67215 .63049 .67015 .62833 Mtetra
.67015 .62833 .67215 .63049 .67631 .62932 .67432 .62716 Mtetra
.67432 .62716 .67631 .62932 .68048 .62815 .67849 .62598 Mtetra
.67849 .62598 .68048 .62815 .68465 .62698 .68267 .62481 Mtetra
.68267 .62481 .68465 .62698 .68883 .6258 .68685 .62363 Mtetra
.68685 .62363 .68883 .6258 .69301 .62463 .69104 .62245 Mtetra
.69104 .62245 .69301 .62463 .6972 .62345 .69523 .62127 Mtetra
.69523 .62127 .6972 .62345 .7014 .62227 .69943 .62009 Mtetra
.69943 .62009 .7014 .62227 .7056 .62109 .70364 .6189 Mtetra
.70364 .6189 .7056 .62109 .70981 .6199 .70785 .61771 Mtetra
.70785 .61771 .70981 .6199 .71403 .61872 .71207 .61653 Mtetra
.71207 .61653 .71403 .61872 .71825 .61753 .7163 .61534 Mtetra
.7163 .61534 .71825 .61753 .72248 .61634 .72053 .61414 Mtetra
.72053 .61414 .72248 .61634 .72671 .61515 .72477 .61295 Mtetra
.72477 .61295 .72671 .61515 .73095 .61396 .72902 .61176 Mtetra
.975 .706 .457 r
.72902 .61176 .73095 .61396 .7352 .61277 .72892 .53885 Mtetra
.644 .425 .57 r
.72892 .53885 .7352 .61277 .73373 .51995 .73185 .51767 Mtetra
.656 .751 .919 r
.73185 .51767 .73373 .51995 .73787 .51872 .73599 .51644 Mtetra
.73599 .51644 .73787 .51872 .74202 .51748 .74014 .5152 Mtetra
.74014 .5152 .74202 .51748 .74617 .51625 .7443 .51396 Mtetra
.7443 .51396 .74617 .51625 .75033 .51501 .74847 .51272 Mtetra
.74847 .51272 .75033 .51501 .7545 .51377 .75264 .51148 Mtetra
.75264 .51148 .7545 .51377 .75867 .51253 .75681 .51023 Mtetra
.75681 .51023 .75867 .51253 .76285 .51129 .761 .50899 Mtetra
.761 .50899 .76285 .51129 .76703 .51004 .76518 .50774 Mtetra
.76518 .50774 .76703 .51004 .77122 .5088 .76938 .50649 Mtetra
.76938 .50649 .77122 .5088 .77542 .50755 .77358 .50524 Mtetra
.77358 .50524 .77542 .50755 .77962 .5063 .77779 .50399 Mtetra
.77779 .50399 .77962 .5063 .78383 .50505 .782 .50273 Mtetra
.978 .699 .424 r
.782 .50273 .78383 .50505 .78077 .41184 .77898 .40946 Mtetra
.663 .742 .908 r
.77898 .40946 .78077 .41184 .78487 .41055 .78309 .40817 Mtetra
.78309 .40817 .78487 .41055 .78897 .40926 .7872 .40688 Mtetra
.7872 .40688 .78897 .40926 .79309 .40797 .79131 .40559 Mtetra
.79131 .40559 .79309 .40797 .7972 .40668 .79543 .40429 Mtetra
.79543 .40429 .7972 .40668 .80132 .40539 .79956 .403 Mtetra
.79956 .403 .80132 .40539 .80545 .40409 .80369 .4017 Mtetra
.80369 .4017 .80545 .40409 .80959 .4028 .80783 .4004 Mtetra
.80783 .4004 .80959 .4028 .81373 .4015 .81197 .39909 Mtetra
.81197 .39909 .81373 .4015 .81787 .4002 .81613 .39779 Mtetra
.81613 .39779 .81787 .4002 .82203 .39889 .82028 .39648 Mtetra
.82028 .39648 .82203 .39889 .82618 .39759 .82444 .39517 Mtetra
.82444 .39517 .82618 .39759 .83035 .39628 .82861 .39386 Mtetra
.82861 .39386 .83035 .39628 .83452 .39497 .83279 .39255 Mtetra
.83279 .39255 .83452 .39497 .83869 .39366 .83697 .39124 Mtetra
.83697 .39124 .83869 .39366 .84241 .38763 .84115 .38992 Mtetra
0 0 0 r
.84115 .38992 .84241 .38763 .84659 .38631 .84487 .38388 Mtetra
.664 .741 .908 r
.84487 .38388 .84659 .38631 .85078 .385 .84907 .38256 Mtetra
.84907 .38256 .85078 .385 .85497 .38368 .85326 .38124 Mtetra
.85326 .38124 .85497 .38368 .85917 .38236 .85747 .37991 Mtetra
.85747 .37991 .85917 .38236 .86338 .38103 .86168 .37859 Mtetra
.86168 .37859 .86338 .38103 .86759 .37971 .86589 .37726 Mtetra
.86589 .37726 .86759 .37971 .87181 .37838 .87012 .37593 Mtetra
.87012 .37593 .87181 .37838 .87603 .37705 .87435 .37459 Mtetra
.87435 .37459 .87603 .37705 .88026 .37572 .87858 .37326 Mtetra
.87858 .37326 .88026 .37572 .8845 .37439 .88282 .37192 Mtetra
.88282 .37192 .8845 .37439 .88874 .37305 .88707 .37059 Mtetra
.88707 .37059 .88874 .37305 .89299 .37172 .89132 .36925 Mtetra
.89132 .36925 .89299 .37172 .89724 .37038 .89558 .3679 Mtetra
.89558 .3679 .89724 .37038 .9015 .36904 .89984 .36656 Mtetra
.89984 .36656 .9015 .36904 .90577 .3677 .90412 .36521 Mtetra
.90412 .36521 .90577 .3677 .91004 .36635 .90839 .36387 Mtetra
.90839 .36387 .91004 .36635 .91432 .36501 .91268 .36252 Mtetra
.91268 .36252 .91432 .36501 .91861 .36366 .91697 .36116 Mtetra
.91697 .36116 .91861 .36366 .9229 .36231 .92126 .35981 Mtetra
.33773 .54096 .33991 .543 .34341 .54189 .34123 .53986 Mtetra
.34123 .53986 .34341 .54189 .34691 .54079 .34473 .53875 Mtetra
.34473 .53875 .34691 .54079 .35041 .53969 .34824 .53764 Mtetra
.34824 .53764 .35041 .53969 .35392 .53858 .35175 .53654 Mtetra
.35175 .53654 .35392 .53858 .35744 .53747 .35527 .53543 Mtetra
.35527 .53543 .35744 .53747 .36096 .53636 .35879 .53431 Mtetra
.35879 .53431 .36096 .53636 .36448 .53525 .36231 .5332 Mtetra
.36231 .5332 .36448 .53525 .36801 .53414 .36585 .53209 Mtetra
.36585 .53209 .36801 .53414 .37154 .53303 .36938 .53097 Mtetra
.36938 .53097 .37154 .53303 .37508 .53191 .37292 .52985 Mtetra
.37292 .52985 .37508 .53191 .37862 .5308 .37647 .52873 Mtetra
.37647 .52873 .37862 .5308 .38217 .52968 .38002 .52761 Mtetra
.38002 .52761 .38217 .52968 .38572 .52856 .38357 .52649 Mtetra
.38357 .52649 .38572 .52856 .38928 .52744 .38713 .52537 Mtetra
.38713 .52537 .38928 .52744 .39284 .52632 .3907 .52424 Mtetra
.3907 .52424 .39284 .52632 .3964 .5252 .39426 .52312 Mtetra
.39426 .52312 .3964 .5252 .39997 .52407 .39784 .52199 Mtetra
.39784 .52199 .39997 .52407 .40355 .52294 .40142 .52086 Mtetra
.40142 .52086 .40355 .52294 .40713 .52182 .405 .51973 Mtetra
.405 .51973 .40713 .52182 .41071 .52069 .40859 .5186 Mtetra
.40859 .5186 .41071 .52069 .4143 .51955 .41218 .51746 Mtetra
.41218 .51746 .4143 .51955 .4179 .51842 .41578 .51633 Mtetra
.41578 .51633 .4179 .51842 .4215 .51729 .41938 .51519 Mtetra
.41938 .51519 .4215 .51729 .4251 .51615 .42299 .51405 Mtetra
.42299 .51405 .4251 .51615 .42871 .51502 .4266 .51291 Mtetra
.4266 .51291 .42871 .51502 .43232 .51388 .43021 .51177 Mtetra
.43021 .51177 .43232 .51388 .43594 .51274 .43384 .51063 Mtetra
.43384 .51063 .43594 .51274 .43957 .51159 .43746 .50948 Mtetra
.43746 .50948 .43957 .51159 .44319 .51045 .44109 .50834 Mtetra
.44109 .50834 .44319 .51045 .44683 .50931 .44473 .50719 Mtetra
.44473 .50719 .44683 .50931 .45047 .50816 .44837 .50604 Mtetra
.44837 .50604 .45047 .50816 .45411 .50701 .45202 .50489 Mtetra
.45202 .50489 .45411 .50701 .45776 .50586 .45567 .50374 Mtetra
.45567 .50374 .45776 .50586 .46141 .50471 .45932 .50258 Mtetra
.45932 .50258 .46141 .50471 .46507 .50356 .46298 .50143 Mtetra
.46298 .50143 .46507 .50356 .46873 .50241 .46665 .50027 Mtetra
.46665 .50027 .46873 .50241 .4724 .50125 .47032 .49911 Mtetra
.47032 .49911 .4724 .50125 .47607 .50009 .474 .49795 Mtetra
.474 .49795 .47607 .50009 .47975 .49893 .47768 .49679 Mtetra
.47768 .49679 .47975 .49893 .48343 .49777 .48136 .49563 Mtetra
.48136 .49563 .48343 .49777 .48712 .49661 .48505 .49446 Mtetra
.48505 .49446 .48712 .49661 .49081 .49545 .48875 .4933 Mtetra
.955 .681 .478 r
.48875 .4933 .49081 .49545 .49282 .67826 .49065 .67623 Mtetra
.648 .76 .931 r
.49065 .67623 .49282 .67826 .49673 .67716 .49456 .67512 Mtetra
.49456 .67512 .49673 .67716 .50064 .67606 .49847 .67402 Mtetra
.49847 .67402 .50064 .67606 .50456 .67495 .50239 .67291 Mtetra
.50239 .67291 .50456 .67495 .50848 .67385 .50632 .67181 Mtetra
.50632 .67181 .50848 .67385 .51241 .67274 .51025 .6707 Mtetra
.51025 .6707 .51241 .67274 .51634 .67164 .51419 .66959 Mtetra
.51419 .66959 .51634 .67164 .52028 .67053 .51814 .66847 Mtetra
.51814 .66847 .52028 .67053 .52423 .66942 .52209 .66736 Mtetra
.52209 .66736 .52423 .66942 .52818 .6683 .52604 .66624 Mtetra
.52604 .66624 .52818 .6683 .53214 .66719 .53 .66513 Mtetra
.53 .66513 .53214 .66719 .5361 .66607 .53397 .66401 Mtetra
.53397 .66401 .5361 .66607 .54007 .66496 .53794 .66289 Mtetra
.53794 .66289 .54007 .66496 .54404 .66384 .54192 .66177 Mtetra
.54192 .66177 .54404 .66384 .54802 .66272 .5459 .66064 Mtetra
.5459 .66064 .54802 .66272 .55201 .66159 .54989 .65952 Mtetra
.54989 .65952 .55201 .66159 .556 .66047 .55389 .65839 Mtetra
.55389 .65839 .556 .66047 .56 .65934 .55789 .65726 Mtetra
.958 .706 .511 r
.55789 .65726 .56 .65934 .56326 .59257 .5612 .59044 Mtetra
.654 .753 .922 r
.5612 .59044 .56326 .59257 .5672 .59142 .56513 .58928 Mtetra
.56513 .58928 .5672 .59142 .57113 .59026 .56908 .58812 Mtetra
.56908 .58812 .57113 .59026 .57508 .5891 .57302 .58696 Mtetra
.57302 .58696 .57508 .5891 .57903 .58794 .57698 .5858 Mtetra
.57698 .5858 .57903 .58794 .58298 .58678 .58094 .58464 Mtetra
.58094 .58464 .58298 .58678 .58694 .58562 .5849 .58347 Mtetra
.5849 .58347 .58694 .58562 .59091 .58446 .58887 .5823 Mtetra
.58887 .5823 .59091 .58446 .59488 .58329 .59285 .58113 Mtetra
.59285 .58113 .59488 .58329 .59886 .58212 .59683 .57996 Mtetra
.59683 .57996 .59886 .58212 .60284 .58095 .60082 .57879 Mtetra
.60082 .57879 .60284 .58095 .60683 .57978 .60481 .57762 Mtetra
.60481 .57762 .60683 .57978 .61083 .57861 .60881 .57644 Mtetra
.60881 .57644 .61083 .57861 .61483 .57744 .61281 .57527 Mtetra
.61281 .57527 .61483 .57744 .61884 .57626 .61682 .57409 Mtetra
.61682 .57409 .61884 .57626 .62285 .57508 .62084 .57291 Mtetra
.62084 .57291 .62285 .57508 .62687 .57391 .62486 .57172 Mtetra
.62486 .57172 .62687 .57391 .63089 .57273 .62889 .57054 Mtetra
.966 .662 .396 r
.62889 .57054 .63089 .57273 .63706 .63765 .63503 .63551 Mtetra
.648 .76 .931 r
.63503 .63551 .63706 .63765 .64118 .63649 .63915 .63434 Mtetra
.63915 .63434 .64118 .63649 .6453 .63533 .64327 .63318 Mtetra
.64327 .63318 .6453 .63533 .64943 .63417 .6474 .63202 Mtetra
.6474 .63202 .64943 .63417 .65356 .633 .65154 .63085 Mtetra
.65154 .63085 .65356 .633 .6577 .63184 .65569 .62968 Mtetra
.65569 .62968 .6577 .63184 .66185 .63067 .65984 .62851 Mtetra
.65984 .62851 .66185 .63067 .666 .6295 .66399 .62734 Mtetra
.66399 .62734 .666 .6295 .67015 .62833 .66815 .62616 Mtetra
.66815 .62616 .67015 .62833 .67432 .62716 .67232 .62499 Mtetra
.67232 .62499 .67432 .62716 .67849 .62598 .6765 .62381 Mtetra
.6765 .62381 .67849 .62598 .68267 .62481 .68068 .62263 Mtetra
.68068 .62263 .68267 .62481 .68685 .62363 .68486 .62145 Mtetra
.68486 .62145 .68685 .62363 .69104 .62245 .68906 .62027 Mtetra
.68906 .62027 .69104 .62245 .69523 .62127 .69326 .61908 Mtetra
.69326 .61908 .69523 .62127 .69943 .62009 .69746 .6179 Mtetra
.69746 .6179 .69943 .62009 .70364 .6189 .70167 .61671 Mtetra
.70167 .61671 .70364 .6189 .70785 .61771 .70589 .61552 Mtetra
.70589 .61552 .70785 .61771 .71207 .61653 .71012 .61433 Mtetra
.71012 .61433 .71207 .61653 .7163 .61534 .71435 .61314 Mtetra
.71435 .61314 .7163 .61534 .72053 .61414 .71858 .61194 Mtetra
.71858 .61194 .72053 .61414 .72477 .61295 .72283 .61074 Mtetra
.974 .706 .459 r
.72283 .61074 .72477 .61295 .72902 .61176 .72285 .53781 Mtetra
.57 .37 .57 r
.72285 .53781 .72902 .61176 .72892 .53885 .72701 .53658 Mtetra
.965 .745 .555 r
.72701 .53658 .72892 .53885 .73185 .51767 .72996 .51539 Mtetra
.656 .751 .919 r
.72996 .51539 .73185 .51767 .73599 .51644 .73411 .51415 Mtetra
.73411 .51415 .73599 .51644 .74014 .5152 .73826 .51291 Mtetra
.73826 .51291 .74014 .5152 .7443 .51396 .74243 .51167 Mtetra
.74243 .51167 .7443 .51396 .74847 .51272 .7466 .51043 Mtetra
.7466 .51043 .74847 .51272 .75264 .51148 .75077 .50918 Mtetra
.75077 .50918 .75264 .51148 .75681 .51023 .75495 .50793 Mtetra
.75495 .50793 .75681 .51023 .761 .50899 .75914 .50668 Mtetra
.75914 .50668 .761 .50899 .76518 .50774 .76333 .50543 Mtetra
.76333 .50543 .76518 .50774 .76938 .50649 .76753 .50418 Mtetra
.76753 .50418 .76938 .50649 .77358 .50524 .77173 .50292 Mtetra
.77173 .50292 .77358 .50524 .77779 .50399 .77594 .50167 Mtetra
.77594 .50167 .77779 .50399 .782 .50273 .78016 .50041 Mtetra
.978 .699 .424 r
.78016 .50041 .782 .50273 .77898 .40946 .77719 .40708 Mtetra
.663 .742 .908 r
.77719 .40708 .77898 .40946 .78309 .40817 .7813 .40579 Mtetra
.7813 .40579 .78309 .40817 .7872 .40688 .78541 .40449 Mtetra
.78541 .40449 .7872 .40688 .79131 .40559 .78953 .40319 Mtetra
.78953 .40319 .79131 .40559 .79543 .40429 .79366 .4019 Mtetra
.79366 .4019 .79543 .40429 .79956 .403 .79779 .4006 Mtetra
.79779 .4006 .79956 .403 .80369 .4017 .80193 .39929 Mtetra
.80193 .39929 .80369 .4017 .80783 .4004 .80607 .39799 Mtetra
.80607 .39799 .80783 .4004 .81197 .39909 .81022 .39668 Mtetra
.81022 .39668 .81197 .39909 .81613 .39779 .81437 .39538 Mtetra
.81437 .39538 .81613 .39779 .82028 .39648 .81853 .39407 Mtetra
.81853 .39407 .82028 .39648 .82444 .39517 .8227 .39275 Mtetra
.8227 .39275 .82444 .39517 .82861 .39386 .82687 .39144 Mtetra
.82687 .39144 .82861 .39386 .83279 .39255 .83105 .39013 Mtetra
.83105 .39013 .83279 .39255 .83697 .39124 .83524 .38881 Mtetra
.83524 .38881 .83697 .39124 .84115 .38992 .83943 .38749 Mtetra
.892 .797 .748 r
.83943 .38749 .84115 .38992 .84487 .38388 .84315 .38144 Mtetra
.664 .741 .908 r
.84315 .38144 .84487 .38388 .84907 .38256 .84735 .38012 Mtetra
.84735 .38012 .84907 .38256 .85326 .38124 .85155 .37879 Mtetra
.85155 .37879 .85326 .38124 .85747 .37991 .85576 .37746 Mtetra
.85576 .37746 .85747 .37991 .86168 .37859 .85997 .37613 Mtetra
.85997 .37613 .86168 .37859 .86589 .37726 .8642 .3748 Mtetra
.8642 .3748 .86589 .37726 .87012 .37593 .86842 .37347 Mtetra
.86842 .37347 .87012 .37593 .87435 .37459 .87265 .37213 Mtetra
.87265 .37213 .87435 .37459 .87858 .37326 .87689 .37079 Mtetra
.87689 .37079 .87858 .37326 .88282 .37192 .88114 .36945 Mtetra
.88114 .36945 .88282 .37192 .88707 .37059 .88539 .36811 Mtetra
.88539 .36811 .88707 .37059 .89132 .36925 .88965 .36677 Mtetra
.88965 .36677 .89132 .36925 .89558 .3679 .89391 .36542 Mtetra
.89391 .36542 .89558 .3679 .89984 .36656 .89818 .36407 Mtetra
.89818 .36407 .89984 .36656 .90412 .36521 .90246 .36272 Mtetra
.90246 .36272 .90412 .36521 .90839 .36387 .90674 .36137 Mtetra
.90674 .36137 .90839 .36387 .91268 .36252 .91103 .36002 Mtetra
.91103 .36002 .91268 .36252 .91697 .36116 .91532 .35866 Mtetra
.91532 .35866 .91697 .36116 .92126 .35981 .91962 .35731 Mtetra
.33554 .53892 .33773 .54096 .34123 .53986 .33904 .53781 Mtetra
.33904 .53781 .34123 .53986 .34473 .53875 .34254 .53671 Mtetra
.34254 .53671 .34473 .53875 .34824 .53764 .34605 .5356 Mtetra
.34605 .5356 .34824 .53764 .35175 .53654 .34957 .53448 Mtetra
.34957 .53448 .35175 .53654 .35527 .53543 .35309 .53337 Mtetra
.35309 .53337 .35527 .53543 .35879 .53431 .35661 .53226 Mtetra
.35661 .53226 .35879 .53431 .36231 .5332 .36014 .53114 Mtetra
.36014 .53114 .36231 .5332 .36585 .53209 .36368 .53002 Mtetra
.36368 .53002 .36585 .53209 .36938 .53097 .36722 .52891 Mtetra
.36722 .52891 .36938 .53097 .37292 .52985 .37076 .52779 Mtetra
.37076 .52779 .37292 .52985 .37647 .52873 .37431 .52666 Mtetra
.37431 .52666 .37647 .52873 .38002 .52761 .37786 .52554 Mtetra
.37786 .52554 .38002 .52761 .38357 .52649 .38142 .52442 Mtetra
.38142 .52442 .38357 .52649 .38713 .52537 .38498 .52329 Mtetra
.38498 .52329 .38713 .52537 .3907 .52424 .38855 .52216 Mtetra
.38855 .52216 .3907 .52424 .39426 .52312 .39212 .52103 Mtetra
.39212 .52103 .39426 .52312 .39784 .52199 .3957 .5199 Mtetra
.3957 .5199 .39784 .52199 .40142 .52086 .39928 .51877 Mtetra
.39928 .51877 .40142 .52086 .405 .51973 .40286 .51764 Mtetra
.40286 .51764 .405 .51973 .40859 .5186 .40645 .5165 Mtetra
.40645 .5165 .40859 .5186 .41218 .51746 .41005 .51537 Mtetra
.41005 .51537 .41218 .51746 .41578 .51633 .41365 .51423 Mtetra
.41365 .51423 .41578 .51633 .41938 .51519 .41726 .51309 Mtetra
.41726 .51309 .41938 .51519 .42299 .51405 .42087 .51195 Mtetra
.42087 .51195 .42299 .51405 .4266 .51291 .42448 .5108 Mtetra
.42448 .5108 .4266 .51291 .43021 .51177 .4281 .50966 Mtetra
.4281 .50966 .43021 .51177 .43384 .51063 .43173 .50851 Mtetra
.43173 .50851 .43384 .51063 .43746 .50948 .43535 .50737 Mtetra
.43535 .50737 .43746 .50948 .44109 .50834 .43899 .50622 Mtetra
.43899 .50622 .44109 .50834 .44473 .50719 .44263 .50507 Mtetra
.44263 .50507 .44473 .50719 .44837 .50604 .44627 .50391 Mtetra
.44627 .50391 .44837 .50604 .45202 .50489 .44992 .50276 Mtetra
.44992 .50276 .45202 .50489 .45567 .50374 .45358 .50161 Mtetra
.45358 .50161 .45567 .50374 .45932 .50258 .45723 .50045 Mtetra
.45723 .50045 .45932 .50258 .46298 .50143 .4609 .49929 Mtetra
.4609 .49929 .46298 .50143 .46665 .50027 .46457 .49813 Mtetra
.46457 .49813 .46665 .50027 .47032 .49911 .46824 .49697 Mtetra
.46824 .49697 .47032 .49911 .474 .49795 .47192 .49581 Mtetra
.47192 .49581 .474 .49795 .47768 .49679 .4756 .49464 Mtetra
.4756 .49464 .47768 .49679 .48136 .49563 .47929 .49348 Mtetra
.47929 .49348 .48136 .49563 .48505 .49446 .48299 .49231 Mtetra
.955 .681 .479 r
.48299 .49231 .48505 .49446 .48875 .4933 .48456 .67529 Mtetra
.559 .344 .544 r
.48456 .67529 .48875 .4933 .49065 .67623 .48847 .67419 Mtetra
.648 .76 .931 r
.48847 .67419 .49065 .67623 .49456 .67512 .49238 .67308 Mtetra
.49238 .67308 .49456 .67512 .49847 .67402 .4963 .67198 Mtetra
.4963 .67198 .49847 .67402 .50239 .67291 .50023 .67087 Mtetra
.50023 .67087 .50239 .67291 .50632 .67181 .50416 .66976 Mtetra
.50416 .66976 .50632 .67181 .51025 .6707 .50809 .66864 Mtetra
.50809 .66864 .51025 .6707 .51419 .66959 .51204 .66753 Mtetra
.51204 .66753 .51419 .66959 .51814 .66847 .51598 .66642 Mtetra
.51598 .66642 .51814 .66847 .52209 .66736 .51994 .6653 Mtetra
.51994 .6653 .52209 .66736 .52604 .66624 .5239 .66418 Mtetra
.5239 .66418 .52604 .66624 .53 .66513 .52786 .66306 Mtetra
.52786 .66306 .53 .66513 .53397 .66401 .53183 .66194 Mtetra
.53183 .66194 .53397 .66401 .53794 .66289 .53581 .66082 Mtetra
.53581 .66082 .53794 .66289 .54192 .66177 .53979 .65969 Mtetra
.53979 .65969 .54192 .66177 .5459 .66064 .54378 .65856 Mtetra
.54378 .65856 .5459 .66064 .54989 .65952 .54777 .65744 Mtetra
.54777 .65744 .54989 .65952 .55389 .65839 .55177 .65631 Mtetra
.55177 .65631 .55389 .65839 .55789 .65726 .55577 .65517 Mtetra
.55577 .65517 .55789 .65726 .5612 .59044 .55979 .65404 Mtetra
0 0 .348 r
.55979 .65404 .5612 .59044 .56513 .58928 .56307 .58714 Mtetra
.654 .753 .922 r
.56307 .58714 .56513 .58928 .56908 .58812 .56701 .58598 Mtetra
.56701 .58598 .56908 .58812 .57302 .58696 .57096 .58481 Mtetra
.57096 .58481 .57302 .58696 .57698 .5858 .57492 .58365 Mtetra
.57492 .58365 .57698 .5858 .58094 .58464 .57888 .58248 Mtetra
.57888 .58248 .58094 .58464 .5849 .58347 .58285 .58131 Mtetra
.58285 .58131 .5849 .58347 .58887 .5823 .58682 .58014 Mtetra
.58682 .58014 .58887 .5823 .59285 .58113 .5908 .57897 Mtetra
.5908 .57897 .59285 .58113 .59683 .57996 .59479 .5778 Mtetra
.59479 .5778 .59683 .57996 .60082 .57879 .59878 .57662 Mtetra
.59878 .57662 .60082 .57879 .60481 .57762 .60278 .57545 Mtetra
.60278 .57545 .60481 .57762 .60881 .57644 .60678 .57427 Mtetra
.60678 .57427 .60881 .57644 .61281 .57527 .61079 .57309 Mtetra
.61079 .57309 .61281 .57527 .61682 .57409 .6148 .57191 Mtetra
.6148 .57191 .61682 .57409 .62084 .57291 .61882 .57072 Mtetra
.61882 .57072 .62084 .57291 .62486 .57172 .62285 .56954 Mtetra
.62285 .56954 .62486 .57172 .62889 .57054 .62688 .56835 Mtetra
.966 .662 .396 r
.62688 .56835 .62889 .57054 .63503 .63551 .63299 .63336 Mtetra
.648 .76 .931 r
.63299 .63336 .63503 .63551 .63915 .63434 .63711 .63219 Mtetra
.63711 .63219 .63915 .63434 .64327 .63318 .64124 .63103 Mtetra
.64124 .63103 .64327 .63318 .6474 .63202 .64538 .62986 Mtetra
.64538 .62986 .6474 .63202 .65154 .63085 .64952 .62869 Mtetra
.64952 .62869 .65154 .63085 .65569 .62968 .65367 .62752 Mtetra
.65367 .62752 .65569 .62968 .65984 .62851 .65782 .62634 Mtetra
.65782 .62634 .65984 .62851 .66399 .62734 .66198 .62517 Mtetra
.66198 .62517 .66399 .62734 .66815 .62616 .66615 .62399 Mtetra
.66615 .62399 .66815 .62616 .67232 .62499 .67032 .62281 Mtetra
.67032 .62281 .67232 .62499 .6765 .62381 .6745 .62163 Mtetra
.6745 .62163 .6765 .62381 .68068 .62263 .67868 .62045 Mtetra
.67868 .62045 .68068 .62263 .68486 .62145 .68287 .61927 Mtetra
.68287 .61927 .68486 .62145 .68906 .62027 .68707 .61808 Mtetra
.68707 .61808 .68906 .62027 .69326 .61908 .69128 .61689 Mtetra
.69128 .61689 .69326 .61908 .69746 .6179 .69549 .6157 Mtetra
.69549 .6157 .69746 .6179 .70167 .61671 .6997 .61451 Mtetra
.6997 .61451 .70167 .61671 .70589 .61552 .70392 .61332 Mtetra
.70392 .61332 .70589 .61552 .71012 .61433 .70815 .61212 Mtetra
.70815 .61212 .71012 .61433 .71435 .61314 .71239 .61093 Mtetra
.974 .706 .462 r
.71239 .61093 .71435 .61314 .71858 .61194 .71262 .538 Mtetra
.57 .369 .57 r
.71262 .538 .71858 .61194 .72283 .61074 .71678 .53677 Mtetra
.71678 .53677 .72283 .61074 .72285 .53781 .72094 .53554 Mtetra
.655 .753 .922 r
.72094 .53554 .72285 .53781 .72701 .53658 .72511 .53431 Mtetra
.965 .745 .555 r
.72511 .53431 .72701 .53658 .72996 .51539 .72806 .5131 Mtetra
.656 .751 .919 r
.72806 .5131 .72996 .51539 .73411 .51415 .73222 .51186 Mtetra
.73222 .51186 .73411 .51415 .73826 .51291 .73638 .51062 Mtetra
.73638 .51062 .73826 .51291 .74243 .51167 .74055 .50937 Mtetra
.74055 .50937 .74243 .51167 .7466 .51043 .74472 .50812 Mtetra
.74472 .50812 .7466 .51043 .75077 .50918 .7489 .50688 Mtetra
.7489 .50688 .75077 .50918 .75495 .50793 .75308 .50562 Mtetra
.75308 .50562 .75495 .50793 .75914 .50668 .75727 .50437 Mtetra
.75727 .50437 .75914 .50668 .76333 .50543 .76147 .50312 Mtetra
.76147 .50312 .76333 .50543 .76753 .50418 .76567 .50186 Mtetra
.76567 .50186 .76753 .50418 .77173 .50292 .76988 .5006 Mtetra
.76988 .5006 .77173 .50292 .77594 .50167 .7741 .49934 Mtetra
.7741 .49934 .77594 .50167 .78016 .50041 .77832 .49808 Mtetra
.978 .699 .424 r
.77832 .49808 .78016 .50041 .77719 .40708 .7754 .40469 Mtetra
.663 .742 .908 r
.7754 .40469 .77719 .40708 .7813 .40579 .77951 .40339 Mtetra
.77951 .40339 .7813 .40579 .78541 .40449 .78363 .4021 Mtetra
.78363 .4021 .78541 .40449 .78953 .40319 .78775 .4008 Mtetra
.78775 .4008 .78953 .40319 .79366 .4019 .79188 .39949 Mtetra
.79188 .39949 .79366 .4019 .79779 .4006 .79601 .39819 Mtetra
.79601 .39819 .79779 .4006 .80193 .39929 .80016 .39688 Mtetra
.80016 .39688 .80193 .39929 .80607 .39799 .8043 .39558 Mtetra
.8043 .39558 .80607 .39799 .81022 .39668 .80846 .39427 Mtetra
.80846 .39427 .81022 .39668 .81437 .39538 .81261 .39296 Mtetra
.81261 .39296 .81437 .39538 .81853 .39407 .81678 .39164 Mtetra
.81678 .39164 .81853 .39407 .8227 .39275 .82095 .39033 Mtetra
.82095 .39033 .8227 .39275 .82687 .39144 .82513 .38901 Mtetra
.82513 .38901 .82687 .39144 .83105 .39013 .82931 .38769 Mtetra
.82931 .38769 .83105 .39013 .83524 .38881 .8335 .38637 Mtetra
.8335 .38637 .83524 .38881 .83943 .38749 .83769 .38505 Mtetra
.892 .797 .748 r
.83769 .38505 .83943 .38749 .84315 .38144 .84143 .37899 Mtetra
.664 .741 .908 r
.84143 .37899 .84315 .38144 .84735 .38012 .84563 .37767 Mtetra
.84563 .37767 .84735 .38012 .85155 .37879 .84983 .37634 Mtetra
.84983 .37634 .85155 .37879 .85576 .37746 .85405 .375 Mtetra
.85405 .375 .85576 .37746 .85997 .37613 .85827 .37367 Mtetra
.85827 .37367 .85997 .37613 .8642 .3748 .86249 .37233 Mtetra
.86249 .37233 .8642 .3748 .86842 .37347 .86672 .371 Mtetra
.86672 .371 .86842 .37347 .87265 .37213 .87096 .36966 Mtetra
.87096 .36966 .87265 .37213 .87689 .37079 .8752 .36832 Mtetra
.8752 .36832 .87689 .37079 .88114 .36945 .87945 .36697 Mtetra
.87945 .36697 .88114 .36945 .88539 .36811 .88371 .36563 Mtetra
.88371 .36563 .88539 .36811 .88965 .36677 .88797 .36428 Mtetra
.88797 .36428 .88965 .36677 .89391 .36542 .89224 .36293 Mtetra
.89224 .36293 .89391 .36542 .89818 .36407 .89651 .36158 Mtetra
.89651 .36158 .89818 .36407 .90246 .36272 .90079 .36023 Mtetra
.90079 .36023 .90246 .36272 .90674 .36137 .90508 .35887 Mtetra
.90508 .35887 .90674 .36137 .91103 .36002 .90937 .35751 Mtetra
.90937 .35751 .91103 .36002 .91532 .35866 .91367 .35615 Mtetra
.91367 .35615 .91532 .35866 .91962 .35731 .91798 .35479 Mtetra
.33334 .53688 .33554 .53892 .33904 .53781 .33684 .53577 Mtetra
.33684 .53577 .33904 .53781 .34254 .53671 .34035 .53466 Mtetra
.34035 .53466 .34254 .53671 .34605 .5356 .34387 .53354 Mtetra
.34387 .53354 .34605 .5356 .34957 .53448 .34739 .53243 Mtetra
.34739 .53243 .34957 .53448 .35309 .53337 .35091 .53131 Mtetra
.35091 .53131 .35309 .53337 .35661 .53226 .35444 .5302 Mtetra
.35444 .5302 .35661 .53226 .36014 .53114 .35797 .52908 Mtetra
.35797 .52908 .36014 .53114 .36368 .53002 .3615 .52796 Mtetra
.3615 .52796 .36368 .53002 .36722 .52891 .36505 .52684 Mtetra
.36505 .52684 .36722 .52891 .37076 .52779 .36859 .52571 Mtetra
.36859 .52571 .37076 .52779 .37431 .52666 .37214 .52459 Mtetra
.37214 .52459 .37431 .52666 .37786 .52554 .3757 .52346 Mtetra
.3757 .52346 .37786 .52554 .38142 .52442 .37926 .52234 Mtetra
.37926 .52234 .38142 .52442 .38498 .52329 .38283 .52121 Mtetra
.38283 .52121 .38498 .52329 .38855 .52216 .3864 .52008 Mtetra
.3864 .52008 .38855 .52216 .39212 .52103 .38997 .51894 Mtetra
.38997 .51894 .39212 .52103 .3957 .5199 .39355 .51781 Mtetra
.39355 .51781 .3957 .5199 .39928 .51877 .39713 .51668 Mtetra
.39713 .51668 .39928 .51877 .40286 .51764 .40072 .51554 Mtetra
.40072 .51554 .40286 .51764 .40645 .5165 .40432 .5144 Mtetra
.40432 .5144 .40645 .5165 .41005 .51537 .40792 .51326 Mtetra
.40792 .51326 .41005 .51537 .41365 .51423 .41152 .51212 Mtetra
.41152 .51212 .41365 .51423 .41726 .51309 .41513 .51098 Mtetra
.41513 .51098 .41726 .51309 .42087 .51195 .41874 .50983 Mtetra
.41874 .50983 .42087 .51195 .42448 .5108 .42236 .50869 Mtetra
.42236 .50869 .42448 .5108 .4281 .50966 .42598 .50754 Mtetra
.42598 .50754 .4281 .50966 .43173 .50851 .42961 .50639 Mtetra
.42961 .50639 .43173 .50851 .43535 .50737 .43324 .50524 Mtetra
.43324 .50524 .43535 .50737 .43899 .50622 .43688 .50409 Mtetra
.43688 .50409 .43899 .50622 .44263 .50507 .44052 .50294 Mtetra
.44052 .50294 .44263 .50507 .44627 .50391 .44417 .50178 Mtetra
.44417 .50178 .44627 .50391 .44992 .50276 .44782 .50063 Mtetra
.44782 .50063 .44992 .50276 .45358 .50161 .45148 .49947 Mtetra
.45148 .49947 .45358 .50161 .45723 .50045 .45514 .49831 Mtetra
.45514 .49831 .45723 .50045 .4609 .49929 .45881 .49715 Mtetra
.45881 .49715 .4609 .49929 .46457 .49813 .46248 .49599 Mtetra
.46248 .49599 .46457 .49813 .46824 .49697 .46616 .49482 Mtetra
.46616 .49482 .46824 .49697 .47192 .49581 .46984 .49366 Mtetra
.46984 .49366 .47192 .49581 .4756 .49464 .47352 .49249 Mtetra
.47352 .49249 .4756 .49464 .47929 .49348 .47722 .49132 Mtetra
.47722 .49132 .47929 .49348 .48299 .49231 .48091 .49015 Mtetra
.955 .681 .479 r
.48091 .49015 .48299 .49231 .48456 .67529 .48237 .67325 Mtetra
.648 .76 .931 r
.48237 .67325 .48456 .67529 .48847 .67419 .48629 .67215 Mtetra
.48629 .67215 .48847 .67419 .49238 .67308 .4902 .67104 Mtetra
.4902 .67104 .49238 .67308 .4963 .67198 .49413 .66993 Mtetra
.49413 .66993 .4963 .67198 .50023 .67087 .49805 .66882 Mtetra
.49805 .66882 .50023 .67087 .50416 .66976 .50199 .6677 Mtetra
.50199 .6677 .50416 .66976 .50809 .66864 .50593 .66659 Mtetra
.50593 .66659 .50809 .66864 .51204 .66753 .50987 .66547 Mtetra
.50987 .66547 .51204 .66753 .51598 .66642 .51383 .66435 Mtetra
.51383 .66435 .51598 .66642 .51994 .6653 .51778 .66323 Mtetra
.51778 .66323 .51994 .6653 .5239 .66418 .52175 .66211 Mtetra
.52175 .66211 .5239 .66418 .52786 .66306 .52571 .66099 Mtetra
.52571 .66099 .52786 .66306 .53183 .66194 .52969 .65986 Mtetra
.52969 .65986 .53183 .66194 .53581 .66082 .53367 .65874 Mtetra
.53367 .65874 .53581 .66082 .53979 .65969 .53765 .65761 Mtetra
.53765 .65761 .53979 .65969 .54378 .65856 .54165 .65648 Mtetra
.54165 .65648 .54378 .65856 .54777 .65744 .54564 .65535 Mtetra
.54564 .65535 .54777 .65744 .55177 .65631 .54965 .65422 Mtetra
.54965 .65422 .55177 .65631 .55577 .65517 .55365 .65308 Mtetra
.55365 .65308 .55577 .65517 .55979 .65404 .55767 .65194 Mtetra
.959 .706 .51 r
.55767 .65194 .55979 .65404 .56307 .58714 .56099 .58499 Mtetra
.654 .753 .922 r
.56099 .58499 .56307 .58714 .56701 .58598 .56494 .58383 Mtetra
.56494 .58383 .56701 .58598 .57096 .58481 .5689 .58266 Mtetra
.5689 .58266 .57096 .58481 .57492 .58365 .57286 .58149 Mtetra
.57286 .58149 .57492 .58365 .57888 .58248 .57682 .58032 Mtetra
.57682 .58032 .57888 .58248 .58285 .58131 .5808 .57915 Mtetra
.5808 .57915 .58285 .58131 .58682 .58014 .58477 .57798 Mtetra
.58477 .57798 .58682 .58014 .5908 .57897 .58876 .5768 Mtetra
.58876 .5768 .5908 .57897 .59479 .5778 .59275 .57563 Mtetra
.59275 .57563 .59479 .5778 .59878 .57662 .59674 .57445 Mtetra
.59674 .57445 .59878 .57662 .60278 .57545 .60074 .57327 Mtetra
.60074 .57327 .60278 .57545 .60678 .57427 .60475 .57209 Mtetra
.60475 .57209 .60678 .57427 .61079 .57309 .60876 .57091 Mtetra
.60876 .57091 .61079 .57309 .6148 .57191 .61278 .56972 Mtetra
.61278 .56972 .6148 .57191 .61882 .57072 .6168 .56853 Mtetra
.6168 .56853 .61882 .57072 .62285 .56954 .62083 .56734 Mtetra
.966 .663 .398 r
.62083 .56734 .62285 .56954 .62688 .56835 .62682 .63237 Mtetra
.553 .329 .529 r
.62682 .63237 .62688 .56835 .63299 .63336 .63094 .63121 Mtetra
.648 .76 .931 r
.63094 .63121 .63299 .63336 .63711 .63219 .63507 .63004 Mtetra
.63507 .63004 .63711 .63219 .64124 .63103 .6392 .62887 Mtetra
.6392 .62887 .64124 .63103 .64538 .62986 .64334 .6277 Mtetra
.64334 .6277 .64538 .62986 .64952 .62869 .64749 .62652 Mtetra
.64749 .62652 .64952 .62869 .65367 .62752 .65164 .62535 Mtetra
.65164 .62535 .65367 .62752 .65782 .62634 .6558 .62417 Mtetra
.6558 .62417 .65782 .62634 .66198 .62517 .65997 .62299 Mtetra
.65997 .62299 .66198 .62517 .66615 .62399 .66414 .62181 Mtetra
.66414 .62181 .66615 .62399 .67032 .62281 .66831 .62063 Mtetra
.66831 .62063 .67032 .62281 .6745 .62163 .6725 .61945 Mtetra
.6725 .61945 .6745 .62163 .67868 .62045 .67668 .61826 Mtetra
.67668 .61826 .67868 .62045 .68287 .61927 .68088 .61707 Mtetra
.68088 .61707 .68287 .61927 .68707 .61808 .68508 .61589 Mtetra
.68508 .61589 .68707 .61808 .69128 .61689 .68929 .6147 Mtetra
.68929 .6147 .69128 .61689 .69549 .6157 .6935 .6135 Mtetra
.6935 .6135 .69549 .6157 .6997 .61451 .69772 .61231 Mtetra
.69772 .61231 .6997 .61451 .70392 .61332 .70195 .61111 Mtetra
.70195 .61111 .70392 .61332 .70815 .61212 .70618 .60991 Mtetra
.973 .706 .463 r
.70618 .60991 .70815 .61212 .71239 .61093 .70654 .53696 Mtetra
.569 .369 .569 r
.70654 .53696 .71239 .61093 .71262 .538 .7107 .53573 Mtetra
.655 .753 .922 r
.7107 .53573 .71262 .538 .71678 .53677 .71486 .5345 Mtetra
.71486 .5345 .71678 .53677 .72094 .53554 .71902 .53327 Mtetra
.71902 .53327 .72094 .53554 .72511 .53431 .7232 .53203 Mtetra
.965 .745 .555 r
.7232 .53203 .72511 .53431 .72806 .5131 .72617 .51081 Mtetra
.656 .751 .919 r
.72617 .51081 .72806 .5131 .73222 .51186 .73033 .50956 Mtetra
.73033 .50956 .73222 .51186 .73638 .51062 .73449 .50832 Mtetra
.73449 .50832 .73638 .51062 .74055 .50937 .73866 .50707 Mtetra
.73866 .50707 .74055 .50937 .74472 .50812 .74284 .50582 Mtetra
.74284 .50582 .74472 .50812 .7489 .50688 .74702 .50457 Mtetra
.74702 .50457 .7489 .50688 .75308 .50562 .75121 .50331 Mtetra
.75121 .50331 .75308 .50562 .75727 .50437 .75541 .50205 Mtetra
.75541 .50205 .75727 .50437 .76147 .50312 .75961 .5008 Mtetra
.75961 .5008 .76147 .50312 .76567 .50186 .76381 .49954 Mtetra
.76381 .49954 .76567 .50186 .76988 .5006 .76803 .49828 Mtetra
.76803 .49828 .76988 .5006 .7741 .49934 .77225 .49701 Mtetra
.77225 .49701 .7741 .49934 .77832 .49808 .77647 .49575 Mtetra
.978 .699 .424 r
.77647 .49575 .77832 .49808 .7754 .40469 .7736 .4023 Mtetra
.663 .742 .908 r
.7736 .4023 .7754 .40469 .77951 .40339 .77771 .401 Mtetra
.77771 .401 .77951 .40339 .78363 .4021 .78183 .39969 Mtetra
.78183 .39969 .78363 .4021 .78775 .4008 .78596 .39839 Mtetra
.78596 .39839 .78775 .4008 .79188 .39949 .7901 .39709 Mtetra
.7901 .39709 .79188 .39949 .79601 .39819 .79423 .39578 Mtetra
.79423 .39578 .79601 .39819 .80016 .39688 .79838 .39447 Mtetra
.79838 .39447 .80016 .39688 .8043 .39558 .80253 .39316 Mtetra
.80253 .39316 .8043 .39558 .80846 .39427 .80669 .39185 Mtetra
.80669 .39185 .80846 .39427 .81261 .39296 .81085 .39053 Mtetra
.81085 .39053 .81261 .39296 .81678 .39164 .81502 .38921 Mtetra
.81502 .38921 .81678 .39164 .82095 .39033 .8192 .3879 Mtetra
.8192 .3879 .82095 .39033 .82513 .38901 .82338 .38658 Mtetra
.82338 .38658 .82513 .38901 .82931 .38769 .82756 .38525 Mtetra
.82756 .38525 .82931 .38769 .8335 .38637 .83176 .38393 Mtetra
.83176 .38393 .8335 .38637 .83769 .38505 .83596 .3826 Mtetra
.892 .797 .748 r
.83596 .3826 .83769 .38505 .84143 .37899 .8397 .37654 Mtetra
.664 .741 .908 r
.8397 .37654 .84143 .37899 .84563 .37767 .8439 .37521 Mtetra
.8439 .37521 .84563 .37767 .84983 .37634 .84811 .37388 Mtetra
.84811 .37388 .84983 .37634 .85405 .375 .85233 .37254 Mtetra
.85233 .37254 .85405 .375 .85827 .37367 .85655 .3712 Mtetra
.85655 .3712 .85827 .37367 .86249 .37233 .86078 .36986 Mtetra
.86078 .36986 .86249 .37233 .86672 .371 .86502 .36852 Mtetra
.86502 .36852 .86672 .371 .87096 .36966 .86926 .36718 Mtetra
.86926 .36718 .87096 .36966 .8752 .36832 .87351 .36583 Mtetra
.87351 .36583 .8752 .36832 .87945 .36697 .87776 .36449 Mtetra
.87776 .36449 .87945 .36697 .88371 .36563 .88202 .36314 Mtetra
.88202 .36314 .88371 .36563 .88797 .36428 .88629 .36179 Mtetra
.88629 .36179 .88797 .36428 .89224 .36293 .89056 .36043 Mtetra
.89056 .36043 .89224 .36293 .89651 .36158 .89484 .35908 Mtetra
.89484 .35908 .89651 .36158 .90079 .36023 .89913 .35772 Mtetra
.89913 .35772 .90079 .36023 .90508 .35887 .90342 .35636 Mtetra
.90342 .35636 .90508 .35887 .90937 .35751 .90771 .355 Mtetra
.90771 .355 .90937 .35751 .91367 .35615 .91202 .35364 Mtetra
.91202 .35364 .91367 .35615 .91798 .35479 .91633 .35228 Mtetra
.33114 .53483 .33334 .53688 .33684 .53577 .33465 .53371 Mtetra
.33465 .53371 .33684 .53577 .34035 .53466 .33816 .5326 Mtetra
.33816 .5326 .34035 .53466 .34387 .53354 .34167 .53149 Mtetra
.34167 .53149 .34387 .53354 .34739 .53243 .3452 .53037 Mtetra
.3452 .53037 .34739 .53243 .35091 .53131 .34872 .52925 Mtetra
.34872 .52925 .35091 .53131 .35444 .5302 .35225 .52813 Mtetra
.35225 .52813 .35444 .5302 .35797 .52908 .35579 .52701 Mtetra
.35579 .52701 .35797 .52908 .3615 .52796 .35933 .52589 Mtetra
.35933 .52589 .3615 .52796 .36505 .52684 .36287 .52476 Mtetra
.36287 .52476 .36505 .52684 .36859 .52571 .36642 .52364 Mtetra
.36642 .52364 .36859 .52571 .37214 .52459 .36997 .52251 Mtetra
.36997 .52251 .37214 .52459 .3757 .52346 .37353 .52138 Mtetra
.37353 .52138 .3757 .52346 .37926 .52234 .3771 .52025 Mtetra
.3771 .52025 .37926 .52234 .38283 .52121 .38066 .51912 Mtetra
.38066 .51912 .38283 .52121 .3864 .52008 .38424 .51799 Mtetra
.38424 .51799 .3864 .52008 .38997 .51894 .38781 .51685 Mtetra
.38781 .51685 .38997 .51894 .39355 .51781 .3914 .51572 Mtetra
.3914 .51572 .39355 .51781 .39713 .51668 .39498 .51458 Mtetra
.39498 .51458 .39713 .51668 .40072 .51554 .39858 .51344 Mtetra
.39858 .51344 .40072 .51554 .40432 .5144 .40217 .5123 Mtetra
.40217 .5123 .40432 .5144 .40792 .51326 .40578 .51115 Mtetra
.40578 .51115 .40792 .51326 .41152 .51212 .40938 .51001 Mtetra
.40938 .51001 .41152 .51212 .41513 .51098 .41299 .50887 Mtetra
.41299 .50887 .41513 .51098 .41874 .50983 .41661 .50772 Mtetra
.41661 .50772 .41874 .50983 .42236 .50869 .42023 .50657 Mtetra
.42023 .50657 .42236 .50869 .42598 .50754 .42386 .50542 Mtetra
.42386 .50542 .42598 .50754 .42961 .50639 .42749 .50427 Mtetra
.42749 .50427 .42961 .50639 .43324 .50524 .43112 .50312 Mtetra
.43112 .50312 .43324 .50524 .43688 .50409 .43476 .50196 Mtetra
.43476 .50196 .43688 .50409 .44052 .50294 .43841 .5008 Mtetra
.43841 .5008 .44052 .50294 .44417 .50178 .44206 .49965 Mtetra
.44206 .49965 .44417 .50178 .44782 .50063 .44571 .49849 Mtetra
.44571 .49849 .44782 .50063 .45148 .49947 .44937 .49733 Mtetra
.44937 .49733 .45148 .49947 .45514 .49831 .45304 .49616 Mtetra
.45304 .49616 .45514 .49831 .45881 .49715 .45671 .495 Mtetra
.45671 .495 .45881 .49715 .46248 .49599 .46039 .49383 Mtetra
.46039 .49383 .46248 .49599 .46616 .49482 .46407 .49267 Mtetra
.46407 .49267 .46616 .49482 .46984 .49366 .46775 .4915 Mtetra
.46775 .4915 .46984 .49366 .47352 .49249 .47144 .49033 Mtetra
.47144 .49033 .47352 .49249 .47722 .49132 .47514 .48916 Mtetra
.954 .681 .48 r
.47514 .48916 .47722 .49132 .48091 .49015 .47627 .67232 Mtetra
.559 .343 .543 r
.47627 .67232 .48091 .49015 .48237 .67325 .48018 .67121 Mtetra
.648 .76 .931 r
.48018 .67121 .48237 .67325 .48629 .67215 .4841 .6701 Mtetra
.4841 .6701 .48629 .67215 .4902 .67104 .48802 .66899 Mtetra
.48802 .66899 .4902 .67104 .49413 .66993 .49194 .66787 Mtetra
.49194 .66787 .49413 .66993 .49805 .66882 .49588 .66676 Mtetra
.49588 .66676 .49805 .66882 .50199 .6677 .49981 .66564 Mtetra
.49981 .66564 .50199 .6677 .50593 .66659 .50376 .66452 Mtetra
.50376 .66452 .50593 .66659 .50987 .66547 .50771 .66341 Mtetra
.50771 .66341 .50987 .66547 .51383 .66435 .51166 .66228 Mtetra
.51166 .66228 .51383 .66435 .51778 .66323 .51562 .66116 Mtetra
.51562 .66116 .51778 .66323 .52175 .66211 .51959 .66004 Mtetra
.51959 .66004 .52175 .66211 .52571 .66099 .52356 .65891 Mtetra
.52356 .65891 .52571 .66099 .52969 .65986 .52754 .65778 Mtetra
.52754 .65778 .52969 .65986 .53367 .65874 .53152 .65665 Mtetra
.53152 .65665 .53367 .65874 .53765 .65761 .53551 .65552 Mtetra
.53551 .65552 .53765 .65761 .54165 .65648 .53951 .65439 Mtetra
.53951 .65439 .54165 .65648 .54564 .65535 .54351 .65326 Mtetra
.54351 .65326 .54564 .65535 .54965 .65422 .54752 .65212 Mtetra
.54752 .65212 .54965 .65422 .55365 .65308 .55153 .65098 Mtetra
.55153 .65098 .55365 .65308 .55767 .65194 .55555 .64984 Mtetra
.959 .706 .51 r
.55555 .64984 .55767 .65194 .56099 .58499 .55891 .58284 Mtetra
.654 .753 .922 r
.55891 .58284 .56099 .58499 .56494 .58383 .56287 .58167 Mtetra
.56287 .58167 .56494 .58383 .5689 .58266 .56683 .5805 Mtetra
.56683 .5805 .5689 .58266 .57286 .58149 .57079 .57933 Mtetra
.57079 .57933 .57286 .58149 .57682 .58032 .57476 .57816 Mtetra
.57476 .57816 .57682 .58032 .5808 .57915 .57874 .57699 Mtetra
.57874 .57699 .5808 .57915 .58477 .57798 .58272 .57581 Mtetra
.58272 .57581 .58477 .57798 .58876 .5768 .5867 .57463 Mtetra
.5867 .57463 .58876 .5768 .59275 .57563 .5907 .57345 Mtetra
.5907 .57345 .59275 .57563 .59674 .57445 .5947 .57227 Mtetra
.5947 .57227 .59674 .57445 .60074 .57327 .5987 .57109 Mtetra
.5987 .57109 .60074 .57327 .60475 .57209 .60271 .5699 Mtetra
.965 .659 .395 r
.60271 .5699 .60475 .57209 .60876 .57091 .60807 .62453 Mtetra
.551 .325 .525 r
.60807 .62453 .60876 .57091 .61278 .56972 .61216 .62337 Mtetra
.61216 .62337 .61278 .56972 .6168 .56853 .61626 .6222 Mtetra
.61626 .6222 .6168 .56853 .62083 .56734 .62036 .62103 Mtetra
.62036 .62103 .62083 .56734 .62682 .63237 .62447 .61986 Mtetra
.209 .185 .612 r
.62447 .61986 .62682 .63237 .63094 .63121 .62889 .62905 Mtetra
.648 .76 .931 r
.62889 .62905 .63094 .63121 .63507 .63004 .63302 .62788 Mtetra
.63302 .62788 .63507 .63004 .6392 .62887 .63716 .62671 Mtetra
.63716 .62671 .6392 .62887 .64334 .6277 .64131 .62553 Mtetra
.64131 .62553 .64334 .6277 .64749 .62652 .64546 .62435 Mtetra
.64546 .62435 .64749 .62652 .65164 .62535 .64961 .62318 Mtetra
.64961 .62318 .65164 .62535 .6558 .62417 .65377 .622 Mtetra
.65377 .622 .6558 .62417 .65997 .62299 .65794 .62081 Mtetra
.65794 .62081 .65997 .62299 .66414 .62181 .66212 .61963 Mtetra
.66212 .61963 .66414 .62181 .66831 .62063 .6663 .61844 Mtetra
.6663 .61844 .66831 .62063 .6725 .61945 .67049 .61726 Mtetra
.67049 .61726 .6725 .61945 .67668 .61826 .67468 .61607 Mtetra
.67468 .61607 .67668 .61826 .68088 .61707 .67888 .61488 Mtetra
.67888 .61488 .68088 .61707 .68508 .61589 .68309 .61369 Mtetra
.68309 .61369 .68508 .61589 .68929 .6147 .6873 .61249 Mtetra
.6873 .61249 .68929 .6147 .6935 .6135 .69152 .6113 Mtetra
.69152 .6113 .6935 .6135 .69772 .61231 .69574 .6101 Mtetra
.69574 .6101 .69772 .61231 .70195 .61111 .69997 .6089 Mtetra
.973 .706 .465 r
.69997 .6089 .70195 .61111 .70618 .60991 .70046 .53592 Mtetra
.569 .368 .569 r
.70046 .53592 .70618 .60991 .70654 .53696 .70461 .53469 Mtetra
.655 .753 .922 r
.70461 .53469 .70654 .53696 .7107 .53573 .70877 .53346 Mtetra
.70877 .53346 .7107 .53573 .71486 .5345 .71293 .53222 Mtetra
.71293 .53222 .71486 .5345 .71902 .53327 .7171 .53099 Mtetra
.7171 .53099 .71902 .53327 .7232 .53203 .72128 .52975 Mtetra
.965 .745 .555 r
.72128 .52975 .7232 .53203 .72617 .51081 .72426 .50851 Mtetra
.656 .751 .919 r
.72426 .50851 .72617 .51081 .73033 .50956 .72843 .50726 Mtetra
.72843 .50726 .73033 .50956 .73449 .50832 .7326 .50601 Mtetra
.7326 .50601 .73449 .50832 .73866 .50707 .73677 .50476 Mtetra
.73677 .50476 .73866 .50707 .74284 .50582 .74095 .5035 Mtetra
.74095 .5035 .74284 .50582 .74702 .50457 .74514 .50225 Mtetra
.74514 .50225 .74702 .50457 .75121 .50331 .74933 .50099 Mtetra
.74933 .50099 .75121 .50331 .75541 .50205 .75353 .49973 Mtetra
.75353 .49973 .75541 .50205 .75961 .5008 .75774 .49847 Mtetra
.75774 .49847 .75961 .5008 .76381 .49954 .76195 .49721 Mtetra
.76195 .49721 .76381 .49954 .76803 .49828 .76617 .49594 Mtetra
.76617 .49594 .76803 .49828 .77225 .49701 .77039 .49467 Mtetra
.77039 .49467 .77225 .49701 .77647 .49575 .77462 .49341 Mtetra
.77462 .49341 .77647 .49575 .7736 .4023 .77886 .49214 Mtetra
.069 0 .438 r
.77886 .49214 .7736 .4023 .77771 .401 .77591 .39859 Mtetra
.663 .742 .908 r
.77591 .39859 .77771 .401 .78183 .39969 .78004 .39729 Mtetra
.78004 .39729 .78183 .39969 .78596 .39839 .78417 .39598 Mtetra
.78417 .39598 .78596 .39839 .7901 .39709 .78831 .39467 Mtetra
.78831 .39467 .7901 .39709 .79423 .39578 .79245 .39336 Mtetra
.79245 .39336 .79423 .39578 .79838 .39447 .7966 .39205 Mtetra
.7966 .39205 .79838 .39447 .80253 .39316 .80076 .39073 Mtetra
.80076 .39073 .80253 .39316 .80669 .39185 .80492 .38942 Mtetra
.80492 .38942 .80669 .39185 .81085 .39053 .80908 .3881 Mtetra
.80908 .3881 .81085 .39053 .81502 .38921 .81326 .38678 Mtetra
.81326 .38678 .81502 .38921 .8192 .3879 .81744 .38546 Mtetra
.81744 .38546 .8192 .3879 .82338 .38658 .82162 .38413 Mtetra
.82162 .38413 .82338 .38658 .82756 .38525 .82581 .38281 Mtetra
.82581 .38281 .82756 .38525 .83176 .38393 .83001 .38148 Mtetra
.83001 .38148 .83176 .38393 .83596 .3826 .83422 .38015 Mtetra
.892 .797 .748 r
.83422 .38015 .83596 .3826 .8397 .37654 .83796 .37408 Mtetra
.664 .741 .908 r
.83796 .37408 .8397 .37654 .8439 .37521 .84217 .37275 Mtetra
.84217 .37275 .8439 .37521 .84811 .37388 .84639 .37141 Mtetra
.84639 .37141 .84811 .37388 .85233 .37254 .85061 .37007 Mtetra
.85061 .37007 .85233 .37254 .85655 .3712 .85484 .36873 Mtetra
.85484 .36873 .85655 .3712 .86078 .36986 .85907 .36739 Mtetra
.85907 .36739 .86078 .36986 .86502 .36852 .86331 .36604 Mtetra
.86331 .36604 .86502 .36852 .86926 .36718 .86756 .3647 Mtetra
.86756 .3647 .86926 .36718 .87351 .36583 .87181 .36335 Mtetra
.87181 .36335 .87351 .36583 .87776 .36449 .87607 .362 Mtetra
.87607 .362 .87776 .36449 .88202 .36314 .88033 .36064 Mtetra
.88033 .36064 .88202 .36314 .88629 .36179 .8846 .35929 Mtetra
.8846 .35929 .88629 .36179 .89056 .36043 .88888 .35793 Mtetra
.88888 .35793 .89056 .36043 .89484 .35908 .89316 .35657 Mtetra
.89316 .35657 .89484 .35908 .89913 .35772 .89745 .35521 Mtetra
.89745 .35521 .89913 .35772 .90342 .35636 .90175 .35385 Mtetra
.90175 .35385 .90342 .35636 .90771 .355 .90605 .35249 Mtetra
.90605 .35249 .90771 .355 .91202 .35364 .91036 .35112 Mtetra
.91036 .35112 .91202 .35364 .91633 .35228 .91467 .34975 Mtetra
.32893 .53277 .33114 .53483 .33465 .53371 .33244 .53166 Mtetra
.33244 .53166 .33465 .53371 .33816 .5326 .33596 .53054 Mtetra
.33596 .53054 .33816 .5326 .34167 .53149 .33948 .52942 Mtetra
.33948 .52942 .34167 .53149 .3452 .53037 .343 .5283 Mtetra
.343 .5283 .3452 .53037 .34872 .52925 .34653 .52718 Mtetra
.34653 .52718 .34872 .52925 .35225 .52813 .35006 .52606 Mtetra
.35006 .52606 .35225 .52813 .35579 .52701 .3536 .52494 Mtetra
.3536 .52494 .35579 .52701 .35933 .52589 .35714 .52381 Mtetra
.35714 .52381 .35933 .52589 .36287 .52476 .36069 .52268 Mtetra
.36069 .52268 .36287 .52476 .36642 .52364 .36424 .52155 Mtetra
.36424 .52155 .36642 .52364 .36997 .52251 .3678 .52042 Mtetra
.3678 .52042 .36997 .52251 .37353 .52138 .37136 .51929 Mtetra
.37136 .51929 .37353 .52138 .3771 .52025 .37493 .51816 Mtetra
.37493 .51816 .3771 .52025 .38066 .51912 .3785 .51703 Mtetra
.3785 .51703 .38066 .51912 .38424 .51799 .38207 .51589 Mtetra
.38207 .51589 .38424 .51799 .38781 .51685 .38565 .51475 Mtetra
.38565 .51475 .38781 .51685 .3914 .51572 .38924 .51361 Mtetra
.38924 .51361 .3914 .51572 .39498 .51458 .39283 .51247 Mtetra
.39283 .51247 .39498 .51458 .39858 .51344 .39643 .51133 Mtetra
.39643 .51133 .39858 .51344 .40217 .5123 .40003 .51019 Mtetra
.40003 .51019 .40217 .5123 .40578 .51115 .40363 .50904 Mtetra
.40363 .50904 .40578 .51115 .40938 .51001 .40724 .5079 Mtetra
.40724 .5079 .40938 .51001 .41299 .50887 .41085 .50675 Mtetra
.41085 .50675 .41299 .50887 .41661 .50772 .41447 .5056 Mtetra
.41447 .5056 .41661 .50772 .42023 .50657 .4181 .50445 Mtetra
.4181 .50445 .42023 .50657 .42386 .50542 .42173 .50329 Mtetra
.42173 .50329 .42386 .50542 .42749 .50427 .42536 .50214 Mtetra
.42536 .50214 .42749 .50427 .43112 .50312 .429 .50098 Mtetra
.429 .50098 .43112 .50312 .43476 .50196 .43264 .49983 Mtetra
.43264 .49983 .43476 .50196 .43841 .5008 .43629 .49867 Mtetra
.43629 .49867 .43841 .5008 .44206 .49965 .43994 .49751 Mtetra
.43994 .49751 .44206 .49965 .44571 .49849 .4436 .49634 Mtetra
.4436 .49634 .44571 .49849 .44937 .49733 .44727 .49518 Mtetra
.44727 .49518 .44937 .49733 .45304 .49616 .45093 .49401 Mtetra
.45093 .49401 .45304 .49616 .45671 .495 .45461 .49285 Mtetra
.45461 .49285 .45671 .495 .46039 .49383 .45829 .49168 Mtetra
.45829 .49168 .46039 .49383 .46407 .49267 .46197 .49051 Mtetra
.46197 .49051 .46407 .49267 .46775 .4915 .46566 .48934 Mtetra
.46566 .48934 .46775 .4915 .47144 .49033 .46935 .48816 Mtetra
.955 .677 .472 r
.46935 .48816 .47144 .49033 .47514 .48916 .47134 .59619 Mtetra
.711 .466 .552 r
.47134 .59619 .47514 .48916 .47627 .67232 .47407 .67027 Mtetra
.648 .76 .931 r
.47407 .67027 .47627 .67232 .48018 .67121 .47798 .66916 Mtetra
.47798 .66916 .48018 .67121 .4841 .6701 .4819 .66805 Mtetra
.4819 .66805 .4841 .6701 .48802 .66899 .48583 .66693 Mtetra
.48583 .66693 .48802 .66899 .49194 .66787 .48976 .66581 Mtetra
.48976 .66581 .49194 .66787 .49588 .66676 .49369 .6647 Mtetra
.49369 .6647 .49588 .66676 .49981 .66564 .49763 .66358 Mtetra
.49763 .66358 .49981 .66564 .50376 .66452 .50158 .66246 Mtetra
.50158 .66246 .50376 .66452 .50771 .66341 .50553 .66133 Mtetra
.50553 .66133 .50771 .66341 .51166 .66228 .50949 .66021 Mtetra
.50949 .66021 .51166 .66228 .51562 .66116 .51346 .65908 Mtetra
.51346 .65908 .51562 .66116 .51959 .66004 .51743 .65796 Mtetra
.51743 .65796 .51959 .66004 .52356 .65891 .5214 .65683 Mtetra
.5214 .65683 .52356 .65891 .52754 .65778 .52538 .6557 Mtetra
.52538 .6557 .52754 .65778 .53152 .65665 .52937 .65456 Mtetra
.52937 .65456 .53152 .65665 .53551 .65552 .53337 .65343 Mtetra
.53337 .65343 .53551 .65552 .53951 .65439 .53736 .65229 Mtetra
.53736 .65229 .53951 .65439 .54351 .65326 .54137 .65116 Mtetra
.54137 .65116 .54351 .65326 .54752 .65212 .54538 .65002 Mtetra
.54538 .65002 .54752 .65212 .55153 .65098 .5494 .64888 Mtetra
.5494 .64888 .55153 .65098 .55555 .64984 .55342 .64774 Mtetra
.55342 .64774 .55555 .64984 .55891 .58284 .55745 .64659 Mtetra
0 0 .344 r
.55745 .64659 .55891 .58284 .56287 .58167 .56079 .57951 Mtetra
.654 .753 .922 r
.56079 .57951 .56287 .58167 .56683 .5805 .56475 .57834 Mtetra
.56475 .57834 .56683 .5805 .57079 .57933 .56872 .57717 Mtetra
.56872 .57717 .57079 .57933 .57476 .57816 .57269 .57599 Mtetra
.57269 .57599 .57476 .57816 .57874 .57699 .57667 .57481 Mtetra
.963 .66 .405 r
.57667 .57481 .57874 .57699 .58272 .57581 .58157 .62936 Mtetra
.551 .324 .524 r
.58157 .62936 .58272 .57581 .5867 .57463 .58563 .6282 Mtetra
.58563 .6282 .5867 .57463 .5907 .57345 .58969 .62704 Mtetra
.58969 .62704 .5907 .57345 .5947 .57227 .59376 .62588 Mtetra
.59376 .62588 .5947 .57227 .5987 .57109 .59784 .62471 Mtetra
.59784 .62471 .5987 .57109 .60271 .5699 .60192 .62355 Mtetra
.60192 .62355 .60271 .5699 .60807 .62453 .606 .62238 Mtetra
.649 .759 .929 r
.606 .62238 .60807 .62453 .61216 .62337 .6101 .62121 Mtetra
.6101 .62121 .61216 .62337 .61626 .6222 .6142 .62004 Mtetra
.6142 .62004 .61626 .6222 .62036 .62103 .6183 .61886 Mtetra
.6183 .61886 .62036 .62103 .62447 .61986 .62241 .61769 Mtetra
.62241 .61769 .62447 .61986 .62889 .62905 .62653 .61651 Mtetra
.209 .185 .612 r
.62653 .61651 .62889 .62905 .63302 .62788 .63097 .62571 Mtetra
.648 .76 .931 r
.63097 .62571 .63302 .62788 .63716 .62671 .63511 .62453 Mtetra
.63511 .62453 .63716 .62671 .64131 .62553 .63926 .62336 Mtetra
.63926 .62336 .64131 .62553 .64546 .62435 .64342 .62218 Mtetra
.64342 .62218 .64546 .62435 .64961 .62318 .64758 .621 Mtetra
.64758 .621 .64961 .62318 .65377 .622 .65174 .61981 Mtetra
.65174 .61981 .65377 .622 .65794 .62081 .65592 .61863 Mtetra
.65592 .61863 .65794 .62081 .66212 .61963 .6601 .61744 Mtetra
.6601 .61744 .66212 .61963 .6663 .61844 .66428 .61625 Mtetra
.66428 .61625 .6663 .61844 .67049 .61726 .66847 .61506 Mtetra
.66847 .61506 .67049 .61726 .67468 .61607 .67267 .61387 Mtetra
.67267 .61387 .67468 .61607 .67888 .61488 .67687 .61268 Mtetra
.67687 .61268 .67888 .61488 .68309 .61369 .68108 .61148 Mtetra
.68108 .61148 .68309 .61369 .6873 .61249 .6853 .61028 Mtetra
.6853 .61028 .6873 .61249 .69152 .6113 .68952 .60908 Mtetra
.68952 .60908 .69152 .6113 .69574 .6101 .69375 .60788 Mtetra
.973 .706 .466 r
.69375 .60788 .69574 .6101 .69997 .6089 .69436 .53488 Mtetra
.569 .368 .569 r
.69436 .53488 .69997 .6089 .70046 .53592 .69851 .53365 Mtetra
.655 .753 .922 r
.69851 .53365 .70046 .53592 .70461 .53469 .70267 .53241 Mtetra
.70267 .53241 .70461 .53469 .70877 .53346 .70683 .53118 Mtetra
.70683 .53118 .70877 .53346 .71293 .53222 .711 .52994 Mtetra
.711 .52994 .71293 .53222 .7171 .53099 .71518 .5287 Mtetra
.71518 .5287 .7171 .53099 .72128 .52975 .71936 .52746 Mtetra
.71936 .52746 .72128 .52975 .72426 .50851 .72354 .52622 Mtetra
0 0 .302 r
.72354 .52622 .72426 .50851 .72843 .50726 .72652 .50495 Mtetra
.656 .751 .919 r
.72652 .50495 .72843 .50726 .7326 .50601 .7307 .5037 Mtetra
.7307 .5037 .7326 .50601 .73677 .50476 .73487 .50244 Mtetra
.73487 .50244 .73677 .50476 .74095 .5035 .73906 .50118 Mtetra
.73906 .50118 .74095 .5035 .74514 .50225 .74325 .49992 Mtetra
.74325 .49992 .74514 .50225 .74933 .50099 .74745 .49866 Mtetra
.74745 .49866 .74933 .50099 .75353 .49973 .75165 .4974 Mtetra
.75165 .4974 .75353 .49973 .75774 .49847 .75586 .49614 Mtetra
.75586 .49614 .75774 .49847 .76195 .49721 .76008 .49487 Mtetra
.76008 .49487 .76195 .49721 .76617 .49594 .7643 .4936 Mtetra
.7643 .4936 .76617 .49594 .77039 .49467 .76853 .49233 Mtetra
.76853 .49233 .77039 .49467 .77462 .49341 .77277 .49106 Mtetra
.77277 .49106 .77462 .49341 .77886 .49214 .77701 .48978 Mtetra
.978 .698 .422 r
.77701 .48978 .77886 .49214 .77591 .39859 .77411 .39618 Mtetra
.663 .742 .908 r
.77411 .39618 .77591 .39859 .78004 .39729 .77824 .39487 Mtetra
.77824 .39487 .78004 .39729 .78417 .39598 .78237 .39356 Mtetra
.78237 .39356 .78417 .39598 .78831 .39467 .78651 .39225 Mtetra
.78651 .39225 .78831 .39467 .79245 .39336 .79066 .39094 Mtetra
.79066 .39094 .79245 .39336 .7966 .39205 .79481 .38962 Mtetra
.79481 .38962 .7966 .39205 .80076 .39073 .79897 .3883 Mtetra
.79897 .3883 .80076 .39073 .80492 .38942 .80314 .38698 Mtetra
.80314 .38698 .80492 .38942 .80908 .3881 .80731 .38566 Mtetra
.80731 .38566 .80908 .3881 .81326 .38678 .81149 .38434 Mtetra
.81149 .38434 .81326 .38678 .81744 .38546 .81567 .38301 Mtetra
.81567 .38301 .81744 .38546 .82162 .38413 .81986 .38168 Mtetra
.81986 .38168 .82162 .38413 .82581 .38281 .82406 .38035 Mtetra
.82406 .38035 .82581 .38281 .83001 .38148 .82826 .37902 Mtetra
.82826 .37902 .83001 .38148 .83422 .38015 .83247 .37769 Mtetra
.892 .797 .748 r
.83247 .37769 .83422 .38015 .83796 .37408 .83622 .37161 Mtetra
.664 .741 .908 r
.83622 .37161 .83796 .37408 .84217 .37275 .84044 .37028 Mtetra
.84044 .37028 .84217 .37275 .84639 .37141 .84466 .36894 Mtetra
.84466 .36894 .84639 .37141 .85061 .37007 .84888 .36759 Mtetra
.84888 .36759 .85061 .37007 .85484 .36873 .85311 .36625 Mtetra
.85311 .36625 .85484 .36873 .85907 .36739 .85735 .3649 Mtetra
.85735 .3649 .85907 .36739 .86331 .36604 .8616 .36355 Mtetra
.8616 .36355 .86331 .36604 .86756 .3647 .86585 .3622 Mtetra
.86585 .3622 .86756 .3647 .87181 .36335 .8701 .36085 Mtetra
.8701 .36085 .87181 .36335 .87607 .362 .87437 .3595 Mtetra
.87437 .3595 .87607 .362 .88033 .36064 .87864 .35814 Mtetra
.87864 .35814 .88033 .36064 .8846 .35929 .88291 .35678 Mtetra
.88291 .35678 .8846 .35929 .88888 .35793 .88719 .35542 Mtetra
.88719 .35542 .88888 .35793 .89316 .35657 .89148 .35406 Mtetra
.89148 .35406 .89316 .35657 .89745 .35521 .89578 .3527 Mtetra
.89578 .3527 .89745 .35521 .90175 .35385 .90008 .35133 Mtetra
.90008 .35133 .90175 .35385 .90605 .35249 .90438 .34996 Mtetra
.90438 .34996 .90605 .35249 .91036 .35112 .9087 .34859 Mtetra
.9087 .34859 .91036 .35112 .91467 .34975 .91302 .34722 Mtetra
.32672 .53071 .32893 .53277 .33244 .53166 .33023 .52959 Mtetra
.33023 .52959 .33244 .53166 .33596 .53054 .33375 .52848 Mtetra
.33375 .52848 .33596 .53054 .33948 .52942 .33727 .52735 Mtetra
.33727 .52735 .33948 .52942 .343 .5283 .3408 .52623 Mtetra
.3408 .52623 .343 .5283 .34653 .52718 .34433 .52511 Mtetra
.34433 .52511 .34653 .52718 .35006 .52606 .34787 .52398 Mtetra
.34787 .52398 .35006 .52606 .3536 .52494 .35141 .52286 Mtetra
.35141 .52286 .3536 .52494 .35714 .52381 .35495 .52173 Mtetra
.35495 .52173 .35714 .52381 .36069 .52268 .3585 .5206 Mtetra
.3585 .5206 .36069 .52268 .36424 .52155 .36206 .51947 Mtetra
.36206 .51947 .36424 .52155 .3678 .52042 .36562 .51833 Mtetra
.36562 .51833 .3678 .52042 .37136 .51929 .36918 .5172 Mtetra
.36918 .5172 .37136 .51929 .37493 .51816 .37275 .51606 Mtetra
.37275 .51606 .37493 .51816 .3785 .51703 .37633 .51493 Mtetra
.37633 .51493 .3785 .51703 .38207 .51589 .37991 .51379 Mtetra
.37991 .51379 .38207 .51589 .38565 .51475 .38349 .51265 Mtetra
.38349 .51265 .38565 .51475 .38924 .51361 .38708 .51151 Mtetra
.38708 .51151 .38924 .51361 .39283 .51247 .39067 .51036 Mtetra
.39067 .51036 .39283 .51247 .39643 .51133 .39427 .50922 Mtetra
.39427 .50922 .39643 .51133 .40003 .51019 .39787 .50807 Mtetra
.39787 .50807 .40003 .51019 .40363 .50904 .40148 .50692 Mtetra
.40148 .50692 .40363 .50904 .40724 .5079 .40509 .50577 Mtetra
.40509 .50577 .40724 .5079 .41085 .50675 .40871 .50462 Mtetra
.40871 .50462 .41085 .50675 .41447 .5056 .41233 .50347 Mtetra
.41233 .50347 .41447 .5056 .4181 .50445 .41596 .50232 Mtetra
.41596 .50232 .4181 .50445 .42173 .50329 .41959 .50116 Mtetra
.41959 .50116 .42173 .50329 .42536 .50214 .42323 .5 Mtetra
.42323 .5 .42536 .50214 .429 .50098 .42687 .49884 Mtetra
.42687 .49884 .429 .50098 .43264 .49983 .43052 .49768 Mtetra
.43052 .49768 .43264 .49983 .43629 .49867 .43417 .49652 Mtetra
.43417 .49652 .43629 .49867 .43994 .49751 .43782 .49536 Mtetra
.43782 .49536 .43994 .49751 .4436 .49634 .44149 .49419 Mtetra
.44149 .49419 .4436 .49634 .44727 .49518 .44515 .49303 Mtetra
.44515 .49303 .44727 .49518 .45093 .49401 .44882 .49186 Mtetra
.44882 .49186 .45093 .49401 .45461 .49285 .4525 .49069 Mtetra
.953 .677 .477 r
.4525 .49069 .45461 .49285 .45829 .49168 .45392 .59864 Mtetra
.556 .336 .537 r
.45392 .59864 .45829 .49168 .46197 .49051 .45772 .5975 Mtetra
.45772 .5975 .46197 .49051 .46566 .48934 .46154 .59637 Mtetra
.46154 .59637 .46566 .48934 .46935 .48816 .46535 .59523 Mtetra
.46535 .59523 .46935 .48816 .47134 .59619 .46918 .59409 Mtetra
.655 .752 .921 r
.46918 .59409 .47134 .59619 .47407 .67027 .473 .59295 Mtetra
0 0 .396 r
.473 .59295 .47407 .67027 .47798 .66916 .47578 .6671 Mtetra
.648 .76 .931 r
.47578 .6671 .47798 .66916 .4819 .66805 .4797 .66599 Mtetra
.4797 .66599 .4819 .66805 .48583 .66693 .48363 .66487 Mtetra
.48363 .66487 .48583 .66693 .48976 .66581 .48756 .66375 Mtetra
.48756 .66375 .48976 .66581 .49369 .6647 .4915 .66263 Mtetra
.4915 .66263 .49369 .6647 .49763 .66358 .49545 .66151 Mtetra
.49545 .66151 .49763 .66358 .50158 .66246 .4994 .66038 Mtetra
.4994 .66038 .50158 .66246 .50553 .66133 .50336 .65926 Mtetra
.50336 .65926 .50553 .66133 .50949 .66021 .50732 .65813 Mtetra
.50732 .65813 .50949 .66021 .51346 .65908 .51129 .657 Mtetra
.51129 .657 .51346 .65908 .51743 .65796 .51526 .65587 Mtetra
.51526 .65587 .51743 .65796 .5214 .65683 .51924 .65474 Mtetra
.51924 .65474 .5214 .65683 .52538 .6557 .52322 .6536 Mtetra
.52322 .6536 .52538 .6557 .52937 .65456 .52722 .65247 Mtetra
.52722 .65247 .52937 .65456 .53337 .65343 .53121 .65133 Mtetra
.53121 .65133 .53337 .65343 .53736 .65229 .53522 .65019 Mtetra
.53522 .65019 .53736 .65229 .54137 .65116 .53922 .64905 Mtetra
.53922 .64905 .54137 .65116 .54538 .65002 .54324 .64791 Mtetra
.54324 .64791 .54538 .65002 .5494 .64888 .54726 .64677 Mtetra
.54726 .64677 .5494 .64888 .55342 .64774 .55129 .64562 Mtetra
.55129 .64562 .55342 .64774 .55745 .64659 .55532 .64448 Mtetra
.926 .762 .658 r
.55532 .64448 .55745 .64659 .56079 .57951 .55925 .63301 Mtetra
.55 .323 .524 r
.55925 .63301 .56079 .57951 .56475 .57834 .56328 .63186 Mtetra
.56328 .63186 .56475 .57834 .56872 .57717 .56732 .6307 Mtetra
.56732 .6307 .56872 .57717 .57269 .57599 .57137 .62954 Mtetra
.57137 .62954 .57269 .57599 .57667 .57481 .57542 .62838 Mtetra
.57542 .62838 .57667 .57481 .58157 .62936 .57947 .62722 Mtetra
.649 .759 .929 r
.57947 .62722 .58157 .62936 .58563 .6282 .58353 .62606 Mtetra
.58353 .62606 .58563 .6282 .58969 .62704 .5876 .62489 Mtetra
.5876 .62489 .58969 .62704 .59376 .62588 .59167 .62373 Mtetra
.59167 .62373 .59376 .62588 .59784 .62471 .59575 .62256 Mtetra
.59575 .62256 .59784 .62471 .60192 .62355 .59984 .62139 Mtetra
.59984 .62139 .60192 .62355 .606 .62238 .60393 .62022 Mtetra
.60393 .62022 .606 .62238 .6101 .62121 .60802 .61904 Mtetra
.60802 .61904 .6101 .62121 .6142 .62004 .61213 .61787 Mtetra
.61213 .61787 .6142 .62004 .6183 .61886 .61624 .61669 Mtetra
.61624 .61669 .6183 .61886 .62241 .61769 .62035 .61551 Mtetra
.62035 .61551 .62241 .61769 .62653 .61651 .62447 .61433 Mtetra
.854 .416 0 r
.62447 .61433 .62653 .61651 .63097 .62571 .62891 .62354 Mtetra
.648 .76 .931 r
.62891 .62354 .63097 .62571 .63511 .62453 .63306 .62236 Mtetra
.63306 .62236 .63511 .62453 .63926 .62336 .63721 .62118 Mtetra
.63721 .62118 .63926 .62336 .64342 .62218 .64137 .61999 Mtetra
.64137 .61999 .64342 .62218 .64758 .621 .64554 .61881 Mtetra
.64554 .61881 .64758 .621 .65174 .61981 .64971 .61762 Mtetra
.64971 .61762 .65174 .61981 .65592 .61863 .65388 .61643 Mtetra
.65388 .61643 .65592 .61863 .6601 .61744 .65807 .61524 Mtetra
.65807 .61524 .6601 .61744 .66428 .61625 .66226 .61405 Mtetra
.66226 .61405 .66428 .61625 .66847 .61506 .66645 .61286 Mtetra
.66645 .61286 .66847 .61506 .67267 .61387 .67065 .61166 Mtetra
.67065 .61166 .67267 .61387 .67687 .61268 .67486 .61047 Mtetra
.67486 .61047 .67687 .61268 .68108 .61148 .67908 .60927 Mtetra
.67908 .60927 .68108 .61148 .6853 .61028 .6833 .60807 Mtetra
.6833 .60807 .6853 .61028 .68952 .60908 .68752 .60686 Mtetra
.972 .706 .467 r
.68752 .60686 .68952 .60908 .69375 .60788 .68826 .53384 Mtetra
.568 .367 .568 r
.68826 .53384 .69375 .60788 .69436 .53488 .69241 .5326 Mtetra
.655 .753 .922 r
.69241 .5326 .69436 .53488 .69851 .53365 .69656 .53137 Mtetra
.69656 .53137 .69851 .53365 .70267 .53241 .70073 .53013 Mtetra
.70073 .53013 .70267 .53241 .70683 .53118 .70489 .52889 Mtetra
.70489 .52889 .70683 .53118 .711 .52994 .70906 .52765 Mtetra
.70906 .52765 .711 .52994 .71518 .5287 .71324 .52641 Mtetra
.71324 .52641 .71518 .5287 .71936 .52746 .71743 .52517 Mtetra
.71743 .52517 .71936 .52746 .72354 .52622 .72162 .52392 Mtetra
.966 .745 .554 r
.72162 .52392 .72354 .52622 .72652 .50495 .72461 .50263 Mtetra
.656 .751 .919 r
.72461 .50263 .72652 .50495 .7307 .5037 .72879 .50138 Mtetra
.72879 .50138 .7307 .5037 .73487 .50244 .73297 .50012 Mtetra
.73297 .50012 .73487 .50244 .73906 .50118 .73716 .49886 Mtetra
.73716 .49886 .73906 .50118 .74325 .49992 .74136 .4976 Mtetra
.74136 .4976 .74325 .49992 .74745 .49866 .74556 .49633 Mtetra
.74556 .49633 .74745 .49866 .75165 .4974 .74977 .49506 Mtetra
.74977 .49506 .75165 .4974 .75586 .49614 .75398 .4938 Mtetra
.75398 .4938 .75586 .49614 .76008 .49487 .7582 .49253 Mtetra
.7582 .49253 .76008 .49487 .7643 .4936 .76243 .49125 Mtetra
.76243 .49125 .7643 .4936 .76853 .49233 .76666 .48998 Mtetra
.76666 .48998 .76853 .49233 .77277 .49106 .7709 .4887 Mtetra
.7709 .4887 .77277 .49106 .77701 .48978 .77515 .48743 Mtetra
.978 .698 .422 r
.77515 .48743 .77701 .48978 .77411 .39618 .7723 .39376 Mtetra
.663 .742 .908 r
.7723 .39376 .77411 .39618 .77824 .39487 .77643 .39245 Mtetra
.77643 .39245 .77824 .39487 .78237 .39356 .78057 .39114 Mtetra
.78057 .39114 .78237 .39356 .78651 .39225 .78472 .38982 Mtetra
.78472 .38982 .78651 .39225 .79066 .39094 .78887 .3885 Mtetra
.78887 .3885 .79066 .39094 .79481 .38962 .79303 .38718 Mtetra
.79303 .38718 .79481 .38962 .79897 .3883 .79719 .38586 Mtetra
.79719 .38586 .79897 .3883 .80314 .38698 .80136 .38454 Mtetra
.80136 .38454 .80314 .38698 .80731 .38566 .80554 .38321 Mtetra
.80554 .38321 .80731 .38566 .81149 .38434 .80972 .38189 Mtetra
.80972 .38189 .81149 .38434 .81567 .38301 .81391 .38056 Mtetra
.81391 .38056 .81567 .38301 .81986 .38168 .8181 .37923 Mtetra
.8181 .37923 .81986 .38168 .82406 .38035 .8223 .37789 Mtetra
.8223 .37789 .82406 .38035 .82826 .37902 .82651 .37656 Mtetra
.82651 .37656 .82826 .37902 .83247 .37769 .83072 .37522 Mtetra
.892 .797 .748 r
.83072 .37522 .83247 .37769 .83622 .37161 .83448 .36914 Mtetra
.664 .741 .908 r
.83448 .36914 .83622 .37161 .84044 .37028 .8387 .3678 Mtetra
.8387 .3678 .84044 .37028 .84466 .36894 .84292 .36646 Mtetra
.84292 .36646 .84466 .36894 .84888 .36759 .84715 .36511 Mtetra
.84715 .36511 .84888 .36759 .85311 .36625 .85139 .36376 Mtetra
.85139 .36376 .85311 .36625 .85735 .3649 .85563 .36241 Mtetra
.85563 .36241 .85735 .3649 .8616 .36355 .85988 .36106 Mtetra
.85988 .36106 .8616 .36355 .86585 .3622 .86413 .35971 Mtetra
.86413 .35971 .86585 .3622 .8701 .36085 .86839 .35835 Mtetra
.86839 .35835 .8701 .36085 .87437 .3595 .87266 .35699 Mtetra
.87266 .35699 .87437 .3595 .87864 .35814 .87694 .35563 Mtetra
.87694 .35563 .87864 .35814 .88291 .35678 .88122 .35427 Mtetra
.88122 .35427 .88291 .35678 .88719 .35542 .8855 .35291 Mtetra
.8855 .35291 .88719 .35542 .89148 .35406 .88979 .35154 Mtetra
.88979 .35154 .89148 .35406 .89578 .3527 .89409 .35017 Mtetra
.89409 .35017 .89578 .3527 .90008 .35133 .8984 .3488 Mtetra
.8984 .3488 .90008 .35133 .90438 .34996 .90271 .34743 Mtetra
.90271 .34743 .90438 .34996 .9087 .34859 .90703 .34606 Mtetra
.90703 .34606 .9087 .34859 .91302 .34722 .91135 .34468 Mtetra
.3245 .52865 .32672 .53071 .33023 .52959 .32802 .52753 Mtetra
.32802 .52753 .33023 .52959 .33375 .52848 .33154 .52641 Mtetra
.33154 .52641 .33375 .52848 .33727 .52735 .33506 .52528 Mtetra
.33506 .52528 .33727 .52735 .3408 .52623 .33859 .52416 Mtetra
.33859 .52416 .3408 .52623 .34433 .52511 .34213 .52303 Mtetra
.34213 .52303 .34433 .52511 .34787 .52398 .34567 .5219 Mtetra
.34567 .5219 .34787 .52398 .35141 .52286 .34921 .52077 Mtetra
.34921 .52077 .35141 .52286 .35495 .52173 .35276 .51964 Mtetra
.35276 .51964 .35495 .52173 .3585 .5206 .35631 .51851 Mtetra
.35631 .51851 .3585 .5206 .36206 .51947 .35987 .51738 Mtetra
.35987 .51738 .36206 .51947 .36562 .51833 .36343 .51624 Mtetra
.36343 .51624 .36562 .51833 .36918 .5172 .367 .5151 Mtetra
.367 .5151 .36918 .5172 .37275 .51606 .37057 .51396 Mtetra
.37057 .51396 .37275 .51606 .37633 .51493 .37415 .51282 Mtetra
.37415 .51282 .37633 .51493 .37991 .51379 .37773 .51168 Mtetra
.37773 .51168 .37991 .51379 .38349 .51265 .38132 .51054 Mtetra
.38132 .51054 .38349 .51265 .38708 .51151 .38491 .50939 Mtetra
.38491 .50939 .38708 .51151 .39067 .51036 .38851 .50825 Mtetra
.38851 .50825 .39067 .51036 .39427 .50922 .39211 .5071 Mtetra
.39211 .5071 .39427 .50922 .39787 .50807 .39571 .50595 Mtetra
.39571 .50595 .39787 .50807 .40148 .50692 .39932 .5048 Mtetra
.39932 .5048 .40148 .50692 .40509 .50577 .40294 .50365 Mtetra
.40294 .50365 .40509 .50577 .40871 .50462 .40656 .50249 Mtetra
.40656 .50249 .40871 .50462 .41233 .50347 .41018 .50134 Mtetra
.41018 .50134 .41233 .50347 .41596 .50232 .41381 .50018 Mtetra
.41381 .50018 .41596 .50232 .41959 .50116 .41745 .49902 Mtetra
.41745 .49902 .41959 .50116 .42323 .5 .42109 .49786 Mtetra
.42109 .49786 .42323 .5 .42687 .49884 .42473 .4967 Mtetra
.42473 .4967 .42687 .49884 .43052 .49768 .42838 .49554 Mtetra
.42838 .49554 .43052 .49768 .43417 .49652 .43204 .49437 Mtetra
.43204 .49437 .43417 .49652 .43782 .49536 .4357 .49321 Mtetra
.952 .677 .481 r
.4357 .49321 .43782 .49536 .44149 .49419 .43655 .60108 Mtetra
.555 .336 .537 r
.43655 .60108 .44149 .49419 .44515 .49303 .44034 .59995 Mtetra
.44034 .59995 .44515 .49303 .44882 .49186 .44413 .59881 Mtetra
.44413 .59881 .44882 .49186 .4525 .49069 .44793 .59768 Mtetra
.44793 .59768 .4525 .49069 .45392 .59864 .45174 .59654 Mtetra
.655 .752 .921 r
.45174 .59654 .45392 .59864 .45772 .5975 .45555 .5954 Mtetra
.45555 .5954 .45772 .5975 .46154 .59637 .45936 .59426 Mtetra
.45936 .59426 .46154 .59637 .46535 .59523 .46318 .59312 Mtetra
.46318 .59312 .46535 .59523 .46918 .59409 .46701 .59198 Mtetra
.46701 .59198 .46918 .59409 .473 .59295 .47084 .59084 Mtetra
.47084 .59084 .473 .59295 .47578 .6671 .47468 .58969 Mtetra
0 0 .396 r
.47468 .58969 .47578 .6671 .4797 .66599 .47749 .66392 Mtetra
.648 .76 .931 r
.47749 .66392 .4797 .66599 .48363 .66487 .48143 .6628 Mtetra
.48143 .6628 .48363 .66487 .48756 .66375 .48536 .66168 Mtetra
.48536 .66168 .48756 .66375 .4915 .66263 .48931 .66056 Mtetra
.48931 .66056 .4915 .66263 .49545 .66151 .49326 .65943 Mtetra
.49326 .65943 .49545 .66151 .4994 .66038 .49721 .6583 Mtetra
.49721 .6583 .4994 .66038 .50336 .65926 .50117 .65718 Mtetra
.50117 .65718 .50336 .65926 .50732 .65813 .50514 .65604 Mtetra
.50514 .65604 .50732 .65813 .51129 .657 .50911 .65491 Mtetra
.50911 .65491 .51129 .657 .51526 .65587 .51309 .65378 Mtetra
.51309 .65378 .51526 .65587 .51924 .65474 .51707 .65264 Mtetra
.51707 .65264 .51924 .65474 .52322 .6536 .52106 .65151 Mtetra
.52106 .65151 .52322 .6536 .52722 .65247 .52505 .65037 Mtetra
.52505 .65037 .52722 .65247 .53121 .65133 .52905 .64923 Mtetra
.52905 .64923 .53121 .65133 .53522 .65019 .53306 .64809 Mtetra
.53306 .64809 .53522 .65019 .53922 .64905 .53707 .64694 Mtetra
.53707 .64694 .53922 .64905 .54324 .64791 .54109 .6458 Mtetra
.54109 .6458 .54324 .64791 .54726 .64677 .54512 .64465 Mtetra
.54512 .64465 .54726 .64677 .55129 .64562 .54915 .6435 Mtetra
.54915 .6435 .55129 .64562 .55532 .64448 .55318 .64235 Mtetra
.926 .762 .658 r
.55318 .64235 .55532 .64448 .55925 .63301 .55713 .63088 Mtetra
.649 .759 .929 r
.55713 .63088 .55925 .63301 .56328 .63186 .56116 .62972 Mtetra
.56116 .62972 .56328 .63186 .56732 .6307 .5652 .62856 Mtetra
.5652 .62856 .56732 .6307 .57137 .62954 .56925 .6274 Mtetra
.56925 .6274 .57137 .62954 .57542 .62838 .57331 .62624 Mtetra
.57331 .62624 .57542 .62838 .57947 .62722 .57736 .62507 Mtetra
.57736 .62507 .57947 .62722 .58353 .62606 .58143 .62391 Mtetra
.58143 .62391 .58353 .62606 .5876 .62489 .5855 .62274 Mtetra
.5855 .62274 .5876 .62489 .59167 .62373 .58958 .62157 Mtetra
.58958 .62157 .59167 .62373 .59575 .62256 .59366 .6204 Mtetra
.59366 .6204 .59575 .62256 .59984 .62139 .59775 .61922 Mtetra
.59775 .61922 .59984 .62139 .60393 .62022 .60185 .61805 Mtetra
.60185 .61805 .60393 .62022 .60802 .61904 .60595 .61687 Mtetra
.60595 .61687 .60802 .61904 .61213 .61787 .61005 .6157 Mtetra
.61005 .6157 .61213 .61787 .61624 .61669 .61417 .61452 Mtetra
.61417 .61452 .61624 .61669 .62035 .61551 .61829 .61333 Mtetra
.61829 .61333 .62035 .61551 .62447 .61433 .62241 .61215 Mtetra
.62241 .61215 .62447 .61433 .62891 .62354 .62654 .61097 Mtetra
.207 .184 .611 r
.62654 .61097 .62891 .62354 .63306 .62236 .631 .62018 Mtetra
.648 .76 .931 r
.631 .62018 .63306 .62236 .63721 .62118 .63516 .61899 Mtetra
.63516 .61899 .63721 .62118 .64137 .61999 .63932 .61781 Mtetra
.63932 .61781 .64137 .61999 .64554 .61881 .64349 .61662 Mtetra
.64349 .61662 .64554 .61881 .64971 .61762 .64766 .61543 Mtetra
.64766 .61543 .64971 .61762 .65388 .61643 .65185 .61424 Mtetra
.65185 .61424 .65388 .61643 .65807 .61524 .65603 .61304 Mtetra
.65603 .61304 .65807 .61524 .66226 .61405 .66023 .61185 Mtetra
.66023 .61185 .66226 .61405 .66645 .61286 .66443 .61065 Mtetra
.66443 .61065 .66645 .61286 .67065 .61166 .66863 .60945 Mtetra
.66863 .60945 .67065 .61166 .67486 .61047 .67285 .60825 Mtetra
.67285 .60825 .67486 .61047 .67908 .60927 .67706 .60705 Mtetra
.972 .706 .47 r
.67706 .60705 .67908 .60927 .6833 .60807 .67801 .53403 Mtetra
.568 .367 .568 r
.67801 .53403 .6833 .60807 .68752 .60686 .68215 .53279 Mtetra
.68215 .53279 .68752 .60686 .68826 .53384 .6863 .53156 Mtetra
.655 .753 .922 r
.6863 .53156 .68826 .53384 .69241 .5326 .69045 .53032 Mtetra
.69045 .53032 .69241 .5326 .69656 .53137 .69461 .52908 Mtetra
.69461 .52908 .69656 .53137 .70073 .53013 .69878 .52784 Mtetra
.69878 .52784 .70073 .53013 .70489 .52889 .70295 .5266 Mtetra
.70295 .5266 .70489 .52889 .70906 .52765 .70712 .52536 Mtetra
.70712 .52536 .70906 .52765 .71324 .52641 .71131 .52411 Mtetra
.71131 .52411 .71324 .52641 .71743 .52517 .7155 .52286 Mtetra
.7155 .52286 .71743 .52517 .72162 .52392 .71969 .52161 Mtetra
.966 .745 .554 r
.71969 .52161 .72162 .52392 .72461 .50263 .7227 .50031 Mtetra
.656 .751 .919 r
.7227 .50031 .72461 .50263 .72879 .50138 .72688 .49905 Mtetra
.72688 .49905 .72879 .50138 .73297 .50012 .73107 .49779 Mtetra
.73107 .49779 .73297 .50012 .73716 .49886 .73526 .49653 Mtetra
.73526 .49653 .73716 .49886 .74136 .4976 .73946 .49526 Mtetra
.73946 .49526 .74136 .4976 .74556 .49633 .74367 .49399 Mtetra
.74367 .49399 .74556 .49633 .74977 .49506 .74788 .49272 Mtetra
.74788 .49272 .74977 .49506 .75398 .4938 .7521 .49145 Mtetra
.7521 .49145 .75398 .4938 .7582 .49253 .75632 .49018 Mtetra
.75632 .49018 .7582 .49253 .76243 .49125 .76056 .4889 Mtetra
.76056 .4889 .76243 .49125 .76666 .48998 .76479 .48762 Mtetra
.76479 .48762 .76666 .48998 .7709 .4887 .76904 .48634 Mtetra
.76904 .48634 .7709 .4887 .77515 .48743 .77329 .48506 Mtetra
.978 .698 .422 r
.77329 .48506 .77515 .48743 .7723 .39376 .77048 .39134 Mtetra
.663 .742 .908 r
.77048 .39134 .7723 .39376 .77643 .39245 .77462 .39002 Mtetra
.77462 .39002 .77643 .39245 .78057 .39114 .77876 .38871 Mtetra
.77876 .38871 .78057 .39114 .78472 .38982 .78291 .38739 Mtetra
.78291 .38739 .78472 .38982 .78887 .3885 .78707 .38607 Mtetra
.78707 .38607 .78887 .3885 .79303 .38718 .79123 .38474 Mtetra
.79123 .38474 .79303 .38718 .79719 .38586 .7954 .38342 Mtetra
.7954 .38342 .79719 .38586 .80136 .38454 .79957 .38209 Mtetra
.79957 .38209 .80136 .38454 .80554 .38321 .80375 .38076 Mtetra
.80375 .38076 .80554 .38321 .80972 .38189 .80794 .37943 Mtetra
.80794 .37943 .80972 .38189 .81391 .38056 .81213 .3781 Mtetra
.81213 .3781 .81391 .38056 .8181 .37923 .81633 .37676 Mtetra
.81633 .37676 .8181 .37923 .8223 .37789 .82054 .37543 Mtetra
.82054 .37543 .8223 .37789 .82651 .37656 .82475 .37409 Mtetra
.82475 .37409 .82651 .37656 .83072 .37522 .82896 .37275 Mtetra
.892 .797 .748 r
.82896 .37275 .83072 .37522 .83448 .36914 .83273 .36666 Mtetra
.664 .741 .908 r
.83273 .36666 .83448 .36914 .8387 .3678 .83695 .36532 Mtetra
.83695 .36532 .8387 .3678 .84292 .36646 .84118 .36397 Mtetra
.84118 .36397 .84292 .36646 .84715 .36511 .84541 .36262 Mtetra
.84541 .36262 .84715 .36511 .85139 .36376 .84965 .36127 Mtetra
.84965 .36127 .85139 .36376 .85563 .36241 .8539 .35991 Mtetra
.8539 .35991 .85563 .36241 .85988 .36106 .85816 .35856 Mtetra
.85816 .35856 .85988 .36106 .86413 .35971 .86241 .3572 Mtetra
.86241 .3572 .86413 .35971 .86839 .35835 .86668 .35584 Mtetra
.86668 .35584 .86839 .35835 .87266 .35699 .87095 .35448 Mtetra
.87095 .35448 .87266 .35699 .87694 .35563 .87523 .35312 Mtetra
.87523 .35312 .87694 .35563 .88122 .35427 .87952 .35175 Mtetra
.87952 .35175 .88122 .35427 .8855 .35291 .88381 .35038 Mtetra
.88381 .35038 .8855 .35291 .88979 .35154 .8881 .34901 Mtetra
.8881 .34901 .88979 .35154 .89409 .35017 .89241 .34764 Mtetra
.89241 .34764 .89409 .35017 .8984 .3488 .89672 .34627 Mtetra
.89672 .34627 .8984 .3488 .90271 .34743 .90103 .34489 Mtetra
.90103 .34489 .90271 .34743 .90703 .34606 .90536 .34351 Mtetra
.90536 .34351 .90703 .34606 .91135 .34468 .90968 .34213 Mtetra
.32228 .52658 .3245 .52865 .32802 .52753 .3258 .52545 Mtetra
.3258 .52545 .32802 .52753 .33154 .52641 .32932 .52433 Mtetra
.32932 .52433 .33154 .52641 .33506 .52528 .33285 .5232 Mtetra
.33285 .5232 .33506 .52528 .33859 .52416 .33638 .52208 Mtetra
.33638 .52208 .33859 .52416 .34213 .52303 .33992 .52095 Mtetra
.33992 .52095 .34213 .52303 .34567 .5219 .34346 .51982 Mtetra
.34346 .51982 .34567 .5219 .34921 .52077 .34701 .51868 Mtetra
.34701 .51868 .34921 .52077 .35276 .51964 .35056 .51755 Mtetra
.35056 .51755 .35276 .51964 .35631 .51851 .35411 .51641 Mtetra
.35411 .51641 .35631 .51851 .35987 .51738 .35768 .51528 Mtetra
.35768 .51528 .35987 .51738 .36343 .51624 .36124 .51414 Mtetra
.36124 .51414 .36343 .51624 .367 .5151 .36481 .513 Mtetra
.36481 .513 .367 .5151 .37057 .51396 .36839 .51186 Mtetra
.36839 .51186 .37057 .51396 .37415 .51282 .37197 .51072 Mtetra
.37197 .51072 .37415 .51282 .37773 .51168 .37555 .50957 Mtetra
.37555 .50957 .37773 .51168 .38132 .51054 .37914 .50842 Mtetra
.37914 .50842 .38132 .51054 .38491 .50939 .38274 .50728 Mtetra
.38274 .50728 .38491 .50939 .38851 .50825 .38633 .50613 Mtetra
.38633 .50613 .38851 .50825 .39211 .5071 .38994 .50498 Mtetra
.38994 .50498 .39211 .5071 .39571 .50595 .39355 .50383 Mtetra
.39355 .50383 .39571 .50595 .39932 .5048 .39716 .50267 Mtetra
.39716 .50267 .39932 .5048 .40294 .50365 .40078 .50152 Mtetra
.40078 .50152 .40294 .50365 .40656 .50249 .4044 .50036 Mtetra
.4044 .50036 .40656 .50249 .41018 .50134 .40803 .4992 Mtetra
.40803 .4992 .41018 .50134 .41381 .50018 .41167 .49804 Mtetra
.41167 .49804 .41381 .50018 .41745 .49902 .4153 .49688 Mtetra
.4153 .49688 .41745 .49902 .42109 .49786 .41895 .49572 Mtetra
.41895 .49572 .42109 .49786 .42473 .4967 .42259 .49455 Mtetra
.95 .677 .484 r
.42259 .49455 .42473 .4967 .42838 .49554 .42301 .60238 Mtetra
.555 .335 .536 r
.42301 .60238 .42838 .49554 .43204 .49437 .42678 .60125 Mtetra
.42678 .60125 .43204 .49437 .4357 .49321 .43056 .60012 Mtetra
.43056 .60012 .4357 .49321 .43655 .60108 .43435 .59899 Mtetra
.655 .752 .921 r
.43435 .59899 .43655 .60108 .44034 .59995 .43814 .59785 Mtetra
.43814 .59785 .44034 .59995 .44413 .59881 .44194 .59672 Mtetra
.44194 .59672 .44413 .59881 .44793 .59768 .44574 .59558 Mtetra
.44574 .59558 .44793 .59768 .45174 .59654 .44955 .59444 Mtetra
.44955 .59444 .45174 .59654 .45555 .5954 .45336 .5933 Mtetra
.45336 .5933 .45555 .5954 .45936 .59426 .45718 .59216 Mtetra
.45718 .59216 .45936 .59426 .46318 .59312 .461 .59101 Mtetra
.461 .59101 .46318 .59312 .46701 .59198 .46483 .58987 Mtetra
.46483 .58987 .46701 .59198 .47084 .59084 .46867 .58872 Mtetra
.46867 .58872 .47084 .59084 .47468 .58969 .47251 .58757 Mtetra
.47251 .58757 .47468 .58969 .47749 .66392 .47635 .58642 Mtetra
0 0 .396 r
.47635 .58642 .47749 .66392 .48143 .6628 .47922 .66073 Mtetra
.648 .76 .931 r
.47922 .66073 .48143 .6628 .48536 .66168 .48316 .6596 Mtetra
.48316 .6596 .48536 .66168 .48931 .66056 .4871 .65848 Mtetra
.4871 .65848 .48931 .66056 .49326 .65943 .49106 .65735 Mtetra
.49106 .65735 .49326 .65943 .49721 .6583 .49502 .65622 Mtetra
.49502 .65622 .49721 .6583 .50117 .65718 .49898 .65509 Mtetra
.49898 .65509 .50117 .65718 .50514 .65604 .50295 .65395 Mtetra
.50295 .65395 .50514 .65604 .50911 .65491 .50692 .65282 Mtetra
.50692 .65282 .50911 .65491 .51309 .65378 .51091 .65168 Mtetra
.51091 .65168 .51309 .65378 .51707 .65264 .51489 .65054 Mtetra
.51489 .65054 .51707 .65264 .52106 .65151 .51889 .6494 Mtetra
.51889 .6494 .52106 .65151 .52505 .65037 .52289 .64826 Mtetra
.52289 .64826 .52505 .65037 .52905 .64923 .52689 .64712 Mtetra
.52689 .64712 .52905 .64923 .53306 .64809 .5309 .64597 Mtetra
.5309 .64597 .53306 .64809 .53707 .64694 .53492 .64483 Mtetra
.53492 .64483 .53707 .64694 .54109 .6458 .53894 .64368 Mtetra
.53894 .64368 .54109 .6458 .54512 .64465 .54297 .64253 Mtetra
.54297 .64253 .54512 .64465 .54915 .6435 .547 .64138 Mtetra
.926 .762 .659 r
.547 .64138 .54915 .6435 .55318 .64235 .55096 .6299 Mtetra
.599 .452 .653 r
.55096 .6299 .55318 .64235 .55713 .63088 .555 .62874 Mtetra
.649 .759 .929 r
.555 .62874 .55713 .63088 .56116 .62972 .55904 .62758 Mtetra
.55904 .62758 .56116 .62972 .5652 .62856 .56308 .62642 Mtetra
.56308 .62642 .5652 .62856 .56925 .6274 .56713 .62525 Mtetra
.56713 .62525 .56925 .6274 .57331 .62624 .57119 .62409 Mtetra
.57119 .62409 .57331 .62624 .57736 .62507 .57525 .62292 Mtetra
.57525 .62292 .57736 .62507 .58143 .62391 .57932 .62175 Mtetra
.57932 .62175 .58143 .62391 .5855 .62274 .5834 .62058 Mtetra
.5834 .62058 .5855 .62274 .58958 .62157 .58748 .6194 Mtetra
.58748 .6194 .58958 .62157 .59366 .6204 .59157 .61823 Mtetra
.59157 .61823 .59366 .6204 .59775 .61922 .59566 .61705 Mtetra
.59566 .61705 .59775 .61922 .60185 .61805 .59976 .61588 Mtetra
.59976 .61588 .60185 .61805 .60595 .61687 .60386 .6147 Mtetra
.60386 .6147 .60595 .61687 .61005 .6157 .60797 .61352 Mtetra
.60797 .61352 .61005 .6157 .61417 .61452 .61209 .61233 Mtetra
.61209 .61233 .61417 .61452 .61829 .61333 .61621 .61115 Mtetra
.61621 .61115 .61829 .61333 .62241 .61215 .62034 .60996 Mtetra
.62034 .60996 .62241 .61215 .62654 .61097 .62448 .60877 Mtetra
.62448 .60877 .62654 .61097 .631 .62018 .62862 .60758 Mtetra
.207 .184 .611 r
.62862 .60758 .631 .62018 .63516 .61899 .6331 .6168 Mtetra
.648 .76 .931 r
.6331 .6168 .63516 .61899 .63932 .61781 .63726 .61561 Mtetra
.63726 .61561 .63932 .61781 .64349 .61662 .64144 .61442 Mtetra
.64144 .61442 .64349 .61662 .64766 .61543 .64562 .61323 Mtetra
.64562 .61323 .64766 .61543 .65185 .61424 .6498 .61203 Mtetra
.6498 .61203 .65185 .61424 .65603 .61304 .65399 .61084 Mtetra
.65399 .61084 .65603 .61304 .66023 .61185 .65819 .60964 Mtetra
.65819 .60964 .66023 .61185 .66443 .61065 .6624 .60844 Mtetra
.6624 .60844 .66443 .61065 .66863 .60945 .66661 .60723 Mtetra
.66661 .60723 .66863 .60945 .67285 .60825 .67082 .60603 Mtetra
.971 .706 .472 r
.67082 .60603 .67285 .60825 .67706 .60705 .6719 .53298 Mtetra
.568 .366 .568 r
.6719 .53298 .67706 .60705 .67801 .53403 .67604 .53175 Mtetra
.655 .753 .922 r
.67604 .53175 .67801 .53403 .68215 .53279 .68018 .53051 Mtetra
.68018 .53051 .68215 .53279 .6863 .53156 .68433 .52927 Mtetra
.68433 .52927 .6863 .53156 .69045 .53032 .68849 .52803 Mtetra
.68849 .52803 .69045 .53032 .69461 .52908 .69265 .52679 Mtetra
.69265 .52679 .69461 .52908 .69878 .52784 .69682 .52555 Mtetra
.69682 .52555 .69878 .52784 .70295 .5266 .701 .5243 Mtetra
.701 .5243 .70295 .5266 .70712 .52536 .70518 .52306 Mtetra
.70518 .52306 .70712 .52536 .71131 .52411 .70936 .52181 Mtetra
.70936 .52181 .71131 .52411 .7155 .52286 .71356 .52055 Mtetra
.71356 .52055 .7155 .52286 .71969 .52161 .71776 .5193 Mtetra
.966 .745 .554 r
.71776 .5193 .71969 .52161 .7227 .50031 .72078 .49798 Mtetra
.656 .751 .919 r
.72078 .49798 .7227 .50031 .72688 .49905 .72497 .49672 Mtetra
.72497 .49672 .72688 .49905 .73107 .49779 .72916 .49545 Mtetra
.72916 .49545 .73107 .49779 .73526 .49653 .73336 .49419 Mtetra
.73336 .49419 .73526 .49653 .73946 .49526 .73756 .49292 Mtetra
.73756 .49292 .73946 .49526 .74367 .49399 .74177 .49165 Mtetra
.74177 .49165 .74367 .49399 .74788 .49272 .74599 .49037 Mtetra
.74599 .49037 .74788 .49272 .7521 .49145 .75021 .4891 Mtetra
.75021 .4891 .7521 .49145 .75632 .49018 .75444 .48782 Mtetra
.75444 .48782 .75632 .49018 .76056 .4889 .75868 .48654 Mtetra
.75868 .48654 .76056 .4889 .76479 .48762 .76292 .48526 Mtetra
.76292 .48526 .76479 .48762 .76904 .48634 .76717 .48398 Mtetra
.76717 .48398 .76904 .48634 .77329 .48506 .77142 .48269 Mtetra
.978 .698 .422 r
.77142 .48269 .77329 .48506 .77048 .39134 .76866 .38891 Mtetra
.663 .742 .908 r
.76866 .38891 .77048 .39134 .77462 .39002 .7728 .38759 Mtetra
.7728 .38759 .77462 .39002 .77876 .38871 .77695 .38627 Mtetra
.77695 .38627 .77876 .38871 .78291 .38739 .7811 .38495 Mtetra
.7811 .38495 .78291 .38739 .78707 .38607 .78527 .38362 Mtetra
.78527 .38362 .78707 .38607 .79123 .38474 .78943 .3823 Mtetra
.78943 .3823 .79123 .38474 .7954 .38342 .7936 .38097 Mtetra
.7936 .38097 .7954 .38342 .79957 .38209 .79778 .37964 Mtetra
.79778 .37964 .79957 .38209 .80375 .38076 .80197 .3783 Mtetra
.80197 .3783 .80375 .38076 .80794 .37943 .80616 .37697 Mtetra
.80616 .37697 .80794 .37943 .81213 .3781 .81035 .37563 Mtetra
.81035 .37563 .81213 .3781 .81633 .37676 .81456 .3743 Mtetra
.81456 .3743 .81633 .37676 .82054 .37543 .81877 .37296 Mtetra
.81877 .37296 .82054 .37543 .82475 .37409 .82298 .37161 Mtetra
.82298 .37161 .82475 .37409 .82896 .37275 .8272 .37027 Mtetra
.8272 .37027 .82896 .37275 .83273 .36666 .83143 .36892 Mtetra
0 0 0 r
.83143 .36892 .83273 .36666 .83695 .36532 .8352 .36283 Mtetra
.664 .741 .908 r
.8352 .36283 .83695 .36532 .84118 .36397 .83943 .36148 Mtetra
.83943 .36148 .84118 .36397 .84541 .36262 .84367 .36012 Mtetra
.84367 .36012 .84541 .36262 .84965 .36127 .84792 .35877 Mtetra
.84792 .35877 .84965 .36127 .8539 .35991 .85217 .35741 Mtetra
.85217 .35741 .8539 .35991 .85816 .35856 .85643 .35605 Mtetra
.85643 .35605 .85816 .35856 .86241 .3572 .86069 .35469 Mtetra
.86069 .35469 .86241 .3572 .86668 .35584 .86496 .35333 Mtetra
.86496 .35333 .86668 .35584 .87095 .35448 .86924 .35196 Mtetra
.86924 .35196 .87095 .35448 .87523 .35312 .87352 .35059 Mtetra
.87352 .35059 .87523 .35312 .87952 .35175 .87781 .34922 Mtetra
.87781 .34922 .87952 .35175 .88381 .35038 .88211 .34785 Mtetra
.88211 .34785 .88381 .35038 .8881 .34901 .88641 .34648 Mtetra
.88641 .34648 .8881 .34901 .89241 .34764 .89072 .3451 Mtetra
.89072 .3451 .89241 .34764 .89672 .34627 .89503 .34373 Mtetra
.89503 .34373 .89672 .34627 .90103 .34489 .89935 .34235 Mtetra
.89935 .34235 .90103 .34489 .90536 .34351 .90368 .34097 Mtetra
.90368 .34097 .90536 .34351 .90968 .34213 .90801 .33958 Mtetra
.32005 .5245 .32228 .52658 .3258 .52545 .32357 .52338 Mtetra
.32357 .52338 .3258 .52545 .32932 .52433 .3271 .52225 Mtetra
.3271 .52225 .32932 .52433 .33285 .5232 .33063 .52112 Mtetra
.33063 .52112 .33285 .5232 .33638 .52208 .33416 .51999 Mtetra
.33416 .51999 .33638 .52208 .33992 .52095 .3377 .51886 Mtetra
.3377 .51886 .33992 .52095 .34346 .51982 .34125 .51772 Mtetra
.34125 .51772 .34346 .51982 .34701 .51868 .3448 .51659 Mtetra
.3448 .51659 .34701 .51868 .35056 .51755 .34835 .51545 Mtetra
.34835 .51545 .35056 .51755 .35411 .51641 .35191 .51431 Mtetra
.35191 .51431 .35411 .51641 .35768 .51528 .35548 .51317 Mtetra
.35548 .51317 .35768 .51528 .36124 .51414 .35904 .51203 Mtetra
.35904 .51203 .36124 .51414 .36481 .513 .36262 .51089 Mtetra
.36262 .51089 .36481 .513 .36839 .51186 .3662 .50975 Mtetra
.3662 .50975 .36839 .51186 .37197 .51072 .36978 .5086 Mtetra
.36978 .5086 .37197 .51072 .37555 .50957 .37337 .50745 Mtetra
.37337 .50745 .37555 .50957 .37914 .50842 .37696 .50631 Mtetra
.37696 .50631 .37914 .50842 .38274 .50728 .38056 .50515 Mtetra
.38056 .50515 .38274 .50728 .38633 .50613 .38416 .504 Mtetra
.38416 .504 .38633 .50613 .38994 .50498 .38777 .50285 Mtetra
.38777 .50285 .38994 .50498 .39355 .50383 .39138 .50169 Mtetra
.39138 .50169 .39355 .50383 .39716 .50267 .39499 .50054 Mtetra
.39499 .50054 .39716 .50267 .40078 .50152 .39862 .49938 Mtetra
.39862 .49938 .40078 .50152 .4044 .50036 .40224 .49822 Mtetra
.40224 .49822 .4044 .50036 .40803 .4992 .40587 .49706 Mtetra
.40587 .49706 .40803 .4992 .41167 .49804 .40951 .4959 Mtetra
.40951 .4959 .41167 .49804 .4153 .49688 .41315 .49473 Mtetra
.41315 .49473 .4153 .49688 .41895 .49572 .4168 .49357 Mtetra
.4168 .49357 .41895 .49572 .42259 .49455 .42045 .4924 Mtetra
.95 .677 .484 r
.42045 .4924 .42259 .49455 .42301 .60238 .42079 .6003 Mtetra
.655 .752 .921 r
.42079 .6003 .42301 .60238 .42678 .60125 .42457 .59916 Mtetra
.42457 .59916 .42678 .60125 .43056 .60012 .42835 .59803 Mtetra
.42835 .59803 .43056 .60012 .43435 .59899 .43214 .59689 Mtetra
.43214 .59689 .43435 .59899 .43814 .59785 .43594 .59575 Mtetra
.43594 .59575 .43814 .59785 .44194 .59672 .43974 .59461 Mtetra
.43974 .59461 .44194 .59672 .44574 .59558 .44354 .59347 Mtetra
.44354 .59347 .44574 .59558 .44955 .59444 .44736 .59233 Mtetra
.44736 .59233 .44955 .59444 .45336 .5933 .45117 .59119 Mtetra
.45117 .59119 .45336 .5933 .45718 .59216 .45499 .59004 Mtetra
.45499 .59004 .45718 .59216 .461 .59101 .45882 .58889 Mtetra
.45882 .58889 .461 .59101 .46483 .58987 .46265 .58775 Mtetra
.46265 .58775 .46483 .58987 .46867 .58872 .46649 .5866 Mtetra
.46649 .5866 .46867 .58872 .47251 .58757 .47034 .58544 Mtetra
.47034 .58544 .47251 .58757 .47635 .58642 .47419 .58429 Mtetra
.47419 .58429 .47635 .58642 .47922 .66073 .47804 .58313 Mtetra
0 0 .396 r
.47804 .58313 .47922 .66073 .48316 .6596 .48095 .65752 Mtetra
.648 .76 .931 r
.48095 .65752 .48316 .6596 .4871 .65848 .4849 .65639 Mtetra
.4849 .65639 .4871 .65848 .49106 .65735 .48885 .65526 Mtetra
.48885 .65526 .49106 .65735 .49502 .65622 .49282 .65413 Mtetra
.49282 .65413 .49502 .65622 .49898 .65509 .49678 .65299 Mtetra
.49678 .65299 .49898 .65509 .50295 .65395 .50076 .65186 Mtetra
.50076 .65186 .50295 .65395 .50692 .65282 .50474 .65072 Mtetra
.50474 .65072 .50692 .65282 .51091 .65168 .50872 .64958 Mtetra
.50872 .64958 .51091 .65168 .51489 .65054 .51271 .64844 Mtetra
.51271 .64844 .51489 .65054 .51889 .6494 .51671 .6473 Mtetra
.51671 .6473 .51889 .6494 .52289 .64826 .52071 .64615 Mtetra
.52071 .64615 .52289 .64826 .52689 .64712 .52472 .645 Mtetra
.52472 .645 .52689 .64712 .5309 .64597 .52873 .64386 Mtetra
.52873 .64386 .5309 .64597 .53492 .64483 .53275 .64271 Mtetra
.53275 .64271 .53492 .64483 .53894 .64368 .53678 .64156 Mtetra
.53678 .64156 .53894 .64368 .54297 .64253 .54081 .6404 Mtetra
.54081 .6404 .54297 .64253 .547 .64138 .54485 .63925 Mtetra
.926 .762 .659 r
.54485 .63925 .547 .64138 .55096 .6299 .54882 .62776 Mtetra
.649 .759 .929 r
.54882 .62776 .55096 .6299 .555 .62874 .55286 .62659 Mtetra
.55286 .62659 .555 .62874 .55904 .62758 .5569 .62543 Mtetra
.5569 .62543 .55904 .62758 .56308 .62642 .56095 .62426 Mtetra
.56095 .62426 .56308 .62642 .56713 .62525 .56501 .6231 Mtetra
.56501 .6231 .56713 .62525 .57119 .62409 .56907 .62193 Mtetra
.56907 .62193 .57119 .62409 .57525 .62292 .57314 .62076 Mtetra
.57314 .62076 .57525 .62292 .57932 .62175 .57721 .61959 Mtetra
.57721 .61959 .57932 .62175 .5834 .62058 .58129 .61841 Mtetra
.58129 .61841 .5834 .62058 .58748 .6194 .58537 .61724 Mtetra
.58537 .61724 .58748 .6194 .59157 .61823 .58946 .61606 Mtetra
.58946 .61606 .59157 .61823 .59566 .61705 .59356 .61488 Mtetra
.59356 .61488 .59566 .61705 .59976 .61588 .59766 .6137 Mtetra
.59766 .6137 .59976 .61588 .60386 .6147 .60177 .61251 Mtetra
.60177 .61251 .60386 .6147 .60797 .61352 .60589 .61133 Mtetra
.60589 .61133 .60797 .61352 .61209 .61233 .61001 .61014 Mtetra
.61001 .61014 .61209 .61233 .61621 .61115 .61414 .60896 Mtetra
.61414 .60896 .61621 .61115 .62034 .60996 .61827 .60777 Mtetra
.61827 .60777 .62034 .60996 .62448 .60877 .62241 .60657 Mtetra
.62241 .60657 .62448 .60877 .62862 .60758 .62656 .60538 Mtetra
.85 .411 0 r
.62656 .60538 .62862 .60758 .6331 .6168 .63103 .6146 Mtetra
.648 .76 .931 r
.63103 .6146 .6331 .6168 .63726 .61561 .6352 .61341 Mtetra
.6352 .61341 .63726 .61561 .64144 .61442 .63938 .61222 Mtetra
.63938 .61222 .64144 .61442 .64562 .61323 .64356 .61102 Mtetra
.64356 .61102 .64562 .61323 .6498 .61203 .64775 .60982 Mtetra
.64775 .60982 .6498 .61203 .65399 .61084 .65195 .60862 Mtetra
.65195 .60862 .65399 .61084 .65819 .60964 .65615 .60742 Mtetra
.65615 .60742 .65819 .60964 .6624 .60844 .66036 .60622 Mtetra
.66036 .60622 .6624 .60844 .66661 .60723 .66457 .60501 Mtetra
.971 .706 .473 r
.66457 .60501 .66661 .60723 .67082 .60603 .66578 .53194 Mtetra
.567 .366 .567 r
.66578 .53194 .67082 .60603 .6719 .53298 .66991 .5307 Mtetra
.655 .753 .922 r
.66991 .5307 .6719 .53298 .67604 .53175 .67406 .52946 Mtetra
.67406 .52946 .67604 .53175 .68018 .53051 .6782 .52822 Mtetra
.6782 .52822 .68018 .53051 .68433 .52927 .68236 .52698 Mtetra
.68236 .52698 .68433 .52927 .68849 .52803 .68652 .52574 Mtetra
.68652 .52574 .68849 .52803 .69265 .52679 .69069 .52449 Mtetra
.69069 .52449 .69265 .52679 .69682 .52555 .69486 .52325 Mtetra
.69486 .52325 .69682 .52555 .701 .5243 .69904 .522 Mtetra
.69904 .522 .701 .5243 .70518 .52306 .70322 .52075 Mtetra
.70322 .52075 .70518 .52306 .70936 .52181 .70742 .51949 Mtetra
.70742 .51949 .70936 .52181 .71356 .52055 .71161 .51824 Mtetra
.71161 .51824 .71356 .52055 .71776 .5193 .71582 .51698 Mtetra
.71582 .51698 .71776 .5193 .72078 .49798 .72003 .51573 Mtetra
0 0 .297 r
.72003 .51573 .72078 .49798 .72497 .49672 .72304 .49438 Mtetra
.656 .751 .919 r
.72304 .49438 .72497 .49672 .72916 .49545 .72724 .49311 Mtetra
.72724 .49311 .72916 .49545 .73336 .49419 .73144 .49184 Mtetra
.73144 .49184 .73336 .49419 .73756 .49292 .73565 .49057 Mtetra
.73565 .49057 .73756 .49292 .74177 .49165 .73987 .48929 Mtetra
.73987 .48929 .74177 .49165 .74599 .49037 .74409 .48802 Mtetra
.74409 .48802 .74599 .49037 .75021 .4891 .74832 .48674 Mtetra
.74832 .48674 .75021 .4891 .75444 .48782 .75255 .48546 Mtetra
.75255 .48546 .75444 .48782 .75868 .48654 .75679 .48418 Mtetra
.75679 .48418 .75868 .48654 .76292 .48526 .76104 .48289 Mtetra
.76104 .48289 .76292 .48526 .76717 .48398 .76529 .48161 Mtetra
.76529 .48161 .76717 .48398 .77142 .48269 .76955 .48032 Mtetra
.978 .698 .422 r
.76955 .48032 .77142 .48269 .76866 .38891 .76683 .38647 Mtetra
.663 .742 .908 r
.76683 .38647 .76866 .38891 .7728 .38759 .77098 .38515 Mtetra
.77098 .38515 .7728 .38759 .77695 .38627 .77513 .38383 Mtetra
.77513 .38383 .77695 .38627 .7811 .38495 .77929 .3825 Mtetra
.77929 .3825 .7811 .38495 .78527 .38362 .78346 .38117 Mtetra
.78346 .38117 .78527 .38362 .78943 .3823 .78763 .37984 Mtetra
.78763 .37984 .78943 .3823 .7936 .38097 .7918 .37851 Mtetra
.7918 .37851 .7936 .38097 .79778 .37964 .79599 .37718 Mtetra
.79599 .37718 .79778 .37964 .80197 .3783 .80018 .37584 Mtetra
.80018 .37584 .80197 .3783 .80616 .37697 .80437 .3745 Mtetra
.80437 .3745 .80616 .37697 .81035 .37563 .80857 .37316 Mtetra
.80857 .37316 .81035 .37563 .81456 .3743 .81278 .37182 Mtetra
.81278 .37182 .81456 .3743 .81877 .37296 .81699 .37048 Mtetra
.81699 .37048 .81877 .37296 .82298 .37161 .82121 .36913 Mtetra
.82121 .36913 .82298 .37161 .8272 .37027 .82544 .36778 Mtetra
.82544 .36778 .8272 .37027 .83143 .36892 .82967 .36643 Mtetra
.892 .797 .748 r
.82967 .36643 .83143 .36892 .8352 .36283 .83345 .36033 Mtetra
.664 .741 .908 r
.83345 .36033 .8352 .36283 .83943 .36148 .83768 .35898 Mtetra
.83768 .35898 .83943 .36148 .84367 .36012 .84193 .35762 Mtetra
.84193 .35762 .84367 .36012 .84792 .35877 .84618 .35626 Mtetra
.84618 .35626 .84792 .35877 .85217 .35741 .85043 .3549 Mtetra
.85043 .3549 .85217 .35741 .85643 .35605 .8547 .35354 Mtetra
.8547 .35354 .85643 .35605 .86069 .35469 .85896 .35217 Mtetra
.85896 .35217 .86069 .35469 .86496 .35333 .86324 .3508 Mtetra
.86324 .3508 .86496 .35333 .86924 .35196 .86752 .34943 Mtetra
.86752 .34943 .86924 .35196 .87352 .35059 .87181 .34806 Mtetra
.87181 .34806 .87352 .35059 .87781 .34922 .8761 .34669 Mtetra
.8761 .34669 .87781 .34922 .88211 .34785 .8804 .34532 Mtetra
.8804 .34532 .88211 .34785 .88641 .34648 .88471 .34394 Mtetra
.88471 .34394 .88641 .34648 .89072 .3451 .88902 .34256 Mtetra
.88902 .34256 .89072 .3451 .89503 .34373 .89334 .34118 Mtetra
.89334 .34118 .89503 .34373 .89935 .34235 .89766 .3398 Mtetra
.89766 .3398 .89935 .34235 .90368 .34097 .902 .33841 Mtetra
.902 .33841 .90368 .34097 .90801 .33958 .90633 .33702 Mtetra
.31782 .52242 .32005 .5245 .32357 .52338 .32134 .52129 Mtetra
.32134 .52129 .32357 .52338 .3271 .52225 .32487 .52016 Mtetra
.32487 .52016 .3271 .52225 .33063 .52112 .3284 .51903 Mtetra
.3284 .51903 .33063 .52112 .33416 .51999 .33194 .5179 Mtetra
.33194 .5179 .33416 .51999 .3377 .51886 .33549 .51676 Mtetra
.33549 .51676 .3377 .51886 .34125 .51772 .33903 .51563 Mtetra
.33903 .51563 .34125 .51772 .3448 .51659 .34259 .51449 Mtetra
.34259 .51449 .3448 .51659 .34835 .51545 .34614 .51335 Mtetra
.34614 .51335 .34835 .51545 .35191 .51431 .3497 .51221 Mtetra
.3497 .51221 .35191 .51431 .35548 .51317 .35327 .51107 Mtetra
.35327 .51107 .35548 .51317 .35904 .51203 .35684 .50992 Mtetra
.35684 .50992 .35904 .51203 .36262 .51089 .36042 .50878 Mtetra
.36042 .50878 .36262 .51089 .3662 .50975 .364 .50763 Mtetra
.364 .50763 .3662 .50975 .36978 .5086 .36759 .50648 Mtetra
.36759 .50648 .36978 .5086 .37337 .50745 .37118 .50533 Mtetra
.37118 .50533 .37337 .50745 .37696 .50631 .37477 .50418 Mtetra
.37477 .50418 .37696 .50631 .38056 .50515 .37837 .50303 Mtetra
.37837 .50303 .38056 .50515 .38416 .504 .38198 .50187 Mtetra
.38198 .50187 .38416 .504 .38777 .50285 .38559 .50072 Mtetra
.38559 .50072 .38777 .50285 .39138 .50169 .3892 .49956 Mtetra
.3892 .49956 .39138 .50169 .39499 .50054 .39282 .4984 Mtetra
.39282 .4984 .39499 .50054 .39862 .49938 .39645 .49724 Mtetra
.39645 .49724 .39862 .49938 .40224 .49822 .40008 .49607 Mtetra
.40008 .49607 .40224 .49822 .40587 .49706 .40371 .49491 Mtetra
.40371 .49491 .40587 .49706 .40951 .4959 .40735 .49374 Mtetra
.40735 .49374 .40951 .4959 .41315 .49473 .411 .49258 Mtetra
.411 .49258 .41315 .49473 .4168 .49357 .41464 .49141 Mtetra
.41464 .49141 .4168 .49357 .42045 .4924 .4183 .49024 Mtetra
.95 .677 .484 r
.4183 .49024 .42045 .4924 .42079 .6003 .41857 .5982 Mtetra
.655 .752 .921 r
.41857 .5982 .42079 .6003 .42457 .59916 .42235 .59707 Mtetra
.42235 .59707 .42457 .59916 .42835 .59803 .42614 .59593 Mtetra
.42614 .59593 .42835 .59803 .43214 .59689 .42993 .59479 Mtetra
.42993 .59479 .43214 .59689 .43594 .59575 .43373 .59365 Mtetra
.43373 .59365 .43594 .59575 .43974 .59461 .43753 .59251 Mtetra
.43753 .59251 .43974 .59461 .44354 .59347 .44134 .59136 Mtetra
.44134 .59136 .44354 .59347 .44736 .59233 .44516 .59022 Mtetra
.44516 .59022 .44736 .59233 .45117 .59119 .44898 .58907 Mtetra
.44898 .58907 .45117 .59119 .45499 .59004 .4528 .58792 Mtetra
.4528 .58792 .45499 .59004 .45882 .58889 .45663 .58677 Mtetra
.45663 .58677 .45882 .58889 .46265 .58775 .46047 .58562 Mtetra
.46047 .58562 .46265 .58775 .46649 .5866 .46431 .58447 Mtetra
.46431 .58447 .46649 .5866 .47034 .58544 .46816 .58331 Mtetra
.46816 .58331 .47034 .58544 .47419 .58429 .47201 .58215 Mtetra
.47201 .58215 .47419 .58429 .47804 .58313 .47587 .581 Mtetra
.47587 .581 .47804 .58313 .48095 .65752 .47973 .57984 Mtetra
0 0 .396 r
.47973 .57984 .48095 .65752 .4849 .65639 .48268 .6543 Mtetra
.648 .76 .931 r
.48268 .6543 .4849 .65639 .48885 .65526 .48664 .65317 Mtetra
.48664 .65317 .48885 .65526 .49282 .65413 .49061 .65203 Mtetra
.49061 .65203 .49282 .65413 .49678 .65299 .49458 .65089 Mtetra
.49458 .65089 .49678 .65299 .50076 .65186 .49856 .64976 Mtetra
.49856 .64976 .50076 .65186 .50474 .65072 .50254 .64861 Mtetra
.50254 .64861 .50474 .65072 .50872 .64958 .50653 .64747 Mtetra
.50653 .64747 .50872 .64958 .51271 .64844 .51052 .64633 Mtetra
.51052 .64633 .51271 .64844 .51671 .6473 .51453 .64518 Mtetra
.51453 .64518 .51671 .6473 .52071 .64615 .51853 .64403 Mtetra
.51853 .64403 .52071 .64615 .52472 .645 .52254 .64288 Mtetra
.52254 .64288 .52472 .645 .52873 .64386 .52656 .64173 Mtetra
.52656 .64173 .52873 .64386 .53275 .64271 .53059 .64058 Mtetra
.53059 .64058 .53275 .64271 .53678 .64156 .53462 .63943 Mtetra
.53462 .63943 .53678 .64156 .54081 .6404 .53865 .63827 Mtetra
.925 .761 .659 r
.53865 .63827 .54081 .6404 .54485 .63925 .54264 .62677 Mtetra
.599 .452 .653 r
.54264 .62677 .54485 .63925 .54882 .62776 .54668 .62561 Mtetra
.649 .759 .929 r
.54668 .62561 .54882 .62776 .55286 .62659 .55072 .62444 Mtetra
.55072 .62444 .55286 .62659 .5569 .62543 .55476 .62328 Mtetra
.55476 .62328 .5569 .62543 .56095 .62426 .55882 .62211 Mtetra
.55882 .62211 .56095 .62426 .56501 .6231 .56288 .62094 Mtetra
.56288 .62094 .56501 .6231 .56907 .62193 .56694 .61977 Mtetra
.56694 .61977 .56907 .62193 .57314 .62076 .57101 .61859 Mtetra
.57101 .61859 .57314 .62076 .57721 .61959 .57509 .61742 Mtetra
.57509 .61742 .57721 .61959 .58129 .61841 .57917 .61624 Mtetra
.57917 .61624 .58129 .61841 .58537 .61724 .58326 .61506 Mtetra
.58326 .61506 .58537 .61724 .58946 .61606 .58736 .61388 Mtetra
.58736 .61388 .58946 .61606 .59356 .61488 .59146 .6127 Mtetra
.59146 .6127 .59356 .61488 .59766 .6137 .59557 .61151 Mtetra
.59557 .61151 .59766 .6137 .60177 .61251 .59968 .61033 Mtetra
.59968 .61033 .60177 .61251 .60589 .61133 .6038 .60914 Mtetra
.6038 .60914 .60589 .61133 .61001 .61014 .60792 .60795 Mtetra
.60792 .60795 .61001 .61014 .61414 .60896 .61206 .60676 Mtetra
.61206 .60676 .61414 .60896 .61827 .60777 .61619 .60556 Mtetra
.61619 .60556 .61827 .60777 .62241 .60657 .62034 .60437 Mtetra
.62034 .60437 .62241 .60657 .62656 .60538 .62449 .60317 Mtetra
.62449 .60317 .62656 .60538 .63103 .6146 .62864 .60197 Mtetra
.206 .183 .611 r
.62864 .60197 .63103 .6146 .6352 .61341 .63313 .6112 Mtetra
.648 .76 .931 r
.63313 .6112 .6352 .61341 .63938 .61222 .63732 .61001 Mtetra
.63732 .61001 .63938 .61222 .64356 .61102 .6415 .60881 Mtetra
.6415 .60881 .64356 .61102 .64775 .60982 .6457 .60761 Mtetra
.6457 .60761 .64775 .60982 .65195 .60862 .6499 .6064 Mtetra
.6499 .6064 .65195 .60862 .65615 .60742 .6541 .6052 Mtetra
.6541 .6052 .65615 .60742 .66036 .60622 .65832 .60399 Mtetra
.97 .706 .474 r
.65832 .60399 .66036 .60622 .66457 .60501 .65965 .53089 Mtetra
.567 .365 .567 r
.65965 .53089 .66457 .60501 .66578 .53194 .66378 .52966 Mtetra
.655 .753 .922 r
.66378 .52966 .66578 .53194 .66991 .5307 .66792 .52842 Mtetra
.66792 .52842 .66991 .5307 .67406 .52946 .67207 .52717 Mtetra
.67207 .52717 .67406 .52946 .6782 .52822 .67622 .52593 Mtetra
.67622 .52593 .6782 .52822 .68236 .52698 .68038 .52469 Mtetra
.68038 .52469 .68236 .52698 .68652 .52574 .68455 .52344 Mtetra
.68455 .52344 .68652 .52574 .69069 .52449 .68872 .52219 Mtetra
.68872 .52219 .69069 .52449 .69486 .52325 .69289 .52094 Mtetra
.69289 .52094 .69486 .52325 .69904 .522 .69708 .51969 Mtetra
.69708 .51969 .69904 .522 .70322 .52075 .70127 .51843 Mtetra
.70127 .51843 .70322 .52075 .70742 .51949 .70546 .51718 Mtetra
.70546 .51718 .70742 .51949 .71161 .51824 .70966 .51592 Mtetra
.70966 .51592 .71161 .51824 .71582 .51698 .71387 .51466 Mtetra
.71387 .51466 .71582 .51698 .72003 .51573 .71809 .5134 Mtetra
.966 .746 .553 r
.71809 .5134 .72003 .51573 .72304 .49438 .72112 .49204 Mtetra
.656 .751 .919 r
.72112 .49204 .72304 .49438 .72724 .49311 .72532 .49076 Mtetra
.72532 .49076 .72724 .49311 .73144 .49184 .72953 .48949 Mtetra
.72953 .48949 .73144 .49184 .73565 .49057 .73374 .48821 Mtetra
.73374 .48821 .73565 .49057 .73987 .48929 .73796 .48694 Mtetra
.73796 .48694 .73987 .48929 .74409 .48802 .74218 .48566 Mtetra
.74218 .48566 .74409 .48802 .74832 .48674 .74642 .48437 Mtetra
.74642 .48437 .74832 .48674 .75255 .48546 .75065 .48309 Mtetra
.75065 .48309 .75255 .48546 .75679 .48418 .7549 .4818 Mtetra
.7549 .4818 .75679 .48418 .76104 .48289 .75915 .48052 Mtetra
.75915 .48052 .76104 .48289 .76529 .48161 .76341 .47923 Mtetra
.76341 .47923 .76529 .48161 .76955 .48032 .76767 .47793 Mtetra
.978 .698 .422 r
.76767 .47793 .76955 .48032 .76683 .38647 .765 .38403 Mtetra
.663 .742 .908 r
.765 .38403 .76683 .38647 .77098 .38515 .76916 .3827 Mtetra
.76916 .3827 .77098 .38515 .77513 .38383 .77331 .38138 Mtetra
.77331 .38138 .77513 .38383 .77929 .3825 .77747 .38005 Mtetra
.77747 .38005 .77929 .3825 .78346 .38117 .78164 .37871 Mtetra
.78164 .37871 .78346 .38117 .78763 .37984 .78582 .37738 Mtetra
.78582 .37738 .78763 .37984 .7918 .37851 .79 .37605 Mtetra
.79 .37605 .7918 .37851 .79599 .37718 .79419 .37471 Mtetra
.79419 .37471 .79599 .37718 .80018 .37584 .79838 .37337 Mtetra
.79838 .37337 .80018 .37584 .80437 .3745 .80258 .37203 Mtetra
.80258 .37203 .80437 .3745 .80857 .37316 .80678 .37068 Mtetra
.80678 .37068 .80857 .37316 .81278 .37182 .811 .36934 Mtetra
.811 .36934 .81278 .37182 .81699 .37048 .81521 .36799 Mtetra
.81521 .36799 .81699 .37048 .82121 .36913 .81944 .36664 Mtetra
.81944 .36664 .82121 .36913 .82544 .36778 .82367 .36529 Mtetra
.82367 .36529 .82544 .36778 .82967 .36643 .8279 .36394 Mtetra
.892 .797 .748 r
.8279 .36394 .82967 .36643 .83345 .36033 .83169 .35783 Mtetra
.664 .741 .908 r
.83169 .35783 .83345 .36033 .83768 .35898 .83593 .35647 Mtetra
.83593 .35647 .83768 .35898 .84193 .35762 .84018 .35511 Mtetra
.84018 .35511 .84193 .35762 .84618 .35626 .84443 .35375 Mtetra
.84443 .35375 .84618 .35626 .85043 .3549 .84869 .35238 Mtetra
.84869 .35238 .85043 .3549 .8547 .35354 .85296 .35101 Mtetra
.85296 .35101 .8547 .35354 .85896 .35217 .85723 .34965 Mtetra
.85723 .34965 .85896 .35217 .86324 .3508 .86151 .34827 Mtetra
.86151 .34827 .86324 .3508 .86752 .34943 .8658 .3469 Mtetra
.8658 .3469 .86752 .34943 .87181 .34806 .87009 .34553 Mtetra
.87009 .34553 .87181 .34806 .8761 .34669 .87439 .34415 Mtetra
.87439 .34415 .8761 .34669 .8804 .34532 .87869 .34277 Mtetra
.87869 .34277 .8804 .34532 .88471 .34394 .883 .34139 Mtetra
.883 .34139 .88471 .34394 .88902 .34256 .88732 .34001 Mtetra
.88732 .34001 .88902 .34256 .89334 .34118 .89164 .33862 Mtetra
.89164 .33862 .89334 .34118 .89766 .3398 .89597 .33724 Mtetra
.89597 .33724 .89766 .3398 .902 .33841 .90031 .33585 Mtetra
.90031 .33585 .902 .33841 .90633 .33702 .90465 .33446 Mtetra
.31558 .52034 .31782 .52242 .32134 .52129 .31911 .51921 Mtetra
.31911 .51921 .32134 .52129 .32487 .52016 .32264 .51807 Mtetra
.32264 .51807 .32487 .52016 .3284 .51903 .32617 .51694 Mtetra
.32617 .51694 .3284 .51903 .33194 .5179 .32971 .5158 Mtetra
.32971 .5158 .33194 .5179 .33549 .51676 .33326 .51466 Mtetra
.33326 .51466 .33549 .51676 .33903 .51563 .33681 .51353 Mtetra
.33681 .51353 .33903 .51563 .34259 .51449 .34037 .51239 Mtetra
.34037 .51239 .34259 .51449 .34614 .51335 .34393 .51124 Mtetra
.34393 .51124 .34614 .51335 .3497 .51221 .34749 .5101 Mtetra
.34749 .5101 .3497 .51221 .35327 .51107 .35106 .50895 Mtetra
.35106 .50895 .35327 .51107 .35684 .50992 .35464 .50781 Mtetra
.35464 .50781 .35684 .50992 .36042 .50878 .35821 .50666 Mtetra
.35821 .50666 .36042 .50878 .364 .50763 .3618 .50551 Mtetra
.3618 .50551 .364 .50763 .36759 .50648 .36539 .50436 Mtetra
.36539 .50436 .36759 .50648 .37118 .50533 .36898 .5032 Mtetra
.36898 .5032 .37118 .50533 .37477 .50418 .37258 .50205 Mtetra
.37258 .50205 .37477 .50418 .37837 .50303 .37618 .50089 Mtetra
.37618 .50089 .37837 .50303 .38198 .50187 .37979 .49974 Mtetra
.37979 .49974 .38198 .50187 .38559 .50072 .3834 .49858 Mtetra
.3834 .49858 .38559 .50072 .3892 .49956 .38702 .49742 Mtetra
.38702 .49742 .3892 .49956 .39282 .4984 .39065 .49625 Mtetra
.39065 .49625 .39282 .4984 .39645 .49724 .39427 .49509 Mtetra
.39427 .49509 .39645 .49724 .40008 .49607 .39791 .49392 Mtetra
.39791 .49392 .40008 .49607 .40371 .49491 .40154 .49276 Mtetra
.40154 .49276 .40371 .49491 .40735 .49374 .40519 .49159 Mtetra
.40519 .49159 .40735 .49374 .411 .49258 .40883 .49042 Mtetra
.40883 .49042 .411 .49258 .41464 .49141 .41249 .48925 Mtetra
.41249 .48925 .41464 .49141 .4183 .49024 .41614 .48807 Mtetra
.95 .677 .484 r
.41614 .48807 .4183 .49024 .41857 .5982 .41634 .5961 Mtetra
.655 .752 .921 r
.41634 .5961 .41857 .5982 .42235 .59707 .42012 .59497 Mtetra
.42012 .59497 .42235 .59707 .42614 .59593 .42392 .59383 Mtetra
.42392 .59383 .42614 .59593 .42993 .59479 .42771 .59268 Mtetra
.42771 .59268 .42993 .59479 .43373 .59365 .43151 .59154 Mtetra
.43151 .59154 .43373 .59365 .43753 .59251 .43532 .59039 Mtetra
.43532 .59039 .43753 .59251 .44134 .59136 .43913 .58925 Mtetra
.43913 .58925 .44134 .59136 .44516 .59022 .44295 .5881 Mtetra
.44295 .5881 .44516 .59022 .44898 .58907 .44678 .58695 Mtetra
.44678 .58695 .44898 .58907 .4528 .58792 .4506 .5858 Mtetra
.4506 .5858 .4528 .58792 .45663 .58677 .45444 .58464 Mtetra
.45444 .58464 .45663 .58677 .46047 .58562 .45828 .58349 Mtetra
.45828 .58349 .46047 .58562 .46431 .58447 .46212 .58233 Mtetra
.46212 .58233 .46431 .58447 .46816 .58331 .46597 .58117 Mtetra
.46597 .58117 .46816 .58331 .47201 .58215 .46983 .58001 Mtetra
.46983 .58001 .47201 .58215 .47587 .581 .47369 .57885 Mtetra
.47369 .57885 .47587 .581 .47973 .57984 .47756 .57769 Mtetra
.957 .671 .453 r
.47756 .57769 .47973 .57984 .48268 .6543 .48046 .65221 Mtetra
.648 .76 .931 r
.48046 .65221 .48268 .6543 .48664 .65317 .48443 .65107 Mtetra
.48443 .65107 .48664 .65317 .49061 .65203 .4884 .64993 Mtetra
.4884 .64993 .49061 .65203 .49458 .65089 .49237 .64879 Mtetra
.49237 .64879 .49458 .65089 .49856 .64976 .49635 .64765 Mtetra
.49635 .64765 .49856 .64976 .50254 .64861 .50034 .6465 Mtetra
.50034 .6465 .50254 .64861 .50653 .64747 .50433 .64536 Mtetra
.50433 .64536 .50653 .64747 .51052 .64633 .50833 .64421 Mtetra
.50833 .64421 .51052 .64633 .51453 .64518 .51234 .64306 Mtetra
.51234 .64306 .51453 .64518 .51853 .64403 .51635 .64191 Mtetra
.51635 .64191 .51853 .64403 .52254 .64288 .52036 .64076 Mtetra
.52036 .64076 .52254 .64288 .52656 .64173 .52438 .6396 Mtetra
.52438 .6396 .52656 .64173 .53059 .64058 .52841 .63845 Mtetra
.52841 .63845 .53059 .64058 .53462 .63943 .53245 .63729 Mtetra
.53245 .63729 .53462 .63943 .53865 .63827 .53648 .63613 Mtetra
.925 .761 .659 r
.53648 .63613 .53865 .63827 .54264 .62677 .54048 .62462 Mtetra
.649 .759 .929 r
.54048 .62462 .54264 .62677 .54668 .62561 .54452 .62346 Mtetra
.54452 .62346 .54668 .62561 .55072 .62444 .54857 .62229 Mtetra
.54857 .62229 .55072 .62444 .55476 .62328 .55262 .62112 Mtetra
.55262 .62112 .55476 .62328 .55882 .62211 .55668 .61995 Mtetra
.55668 .61995 .55882 .62211 .56288 .62094 .56074 .61877 Mtetra
.56074 .61877 .56288 .62094 .56694 .61977 .56481 .6176 Mtetra
.56481 .6176 .56694 .61977 .57101 .61859 .56888 .61642 Mtetra
.56888 .61642 .57101 .61859 .57509 .61742 .57296 .61524 Mtetra
.57296 .61524 .57509 .61742 .57917 .61624 .57705 .61406 Mtetra
.57705 .61406 .57917 .61624 .58326 .61506 .58115 .61288 Mtetra
.58115 .61288 .58326 .61506 .58736 .61388 .58524 .61169 Mtetra
.58524 .61169 .58736 .61388 .59146 .6127 .58935 .61051 Mtetra
.58935 .61051 .59146 .6127 .59557 .61151 .59346 .60932 Mtetra
.59346 .60932 .59557 .61151 .59968 .61033 .59758 .60813 Mtetra
.59758 .60813 .59968 .61033 .6038 .60914 .6017 .60694 Mtetra
.6017 .60694 .6038 .60914 .60792 .60795 .60583 .60575 Mtetra
.60583 .60575 .60792 .60795 .61206 .60676 .60997 .60455 Mtetra
.60997 .60455 .61206 .60676 .61619 .60556 .61411 .60336 Mtetra
.61411 .60336 .61619 .60556 .62034 .60437 .61826 .60216 Mtetra
.61826 .60216 .62034 .60437 .62449 .60317 .62241 .60096 Mtetra
.62241 .60096 .62449 .60317 .62864 .60197 .62657 .59976 Mtetra
.62657 .59976 .62864 .60197 .63313 .6112 .63074 .59855 Mtetra
.598 .452 .653 r
.63074 .59855 .63313 .6112 .63732 .61001 .63491 .59735 Mtetra
.63491 .59735 .63732 .61001 .6415 .60881 .63909 .59614 Mtetra
.63909 .59614 .6415 .60881 .6457 .60761 .64327 .59493 Mtetra
.64327 .59493 .6457 .60761 .6499 .6064 .64747 .59372 Mtetra
.64747 .59372 .6499 .6064 .6541 .6052 .65166 .59251 Mtetra
.923 .661 .522 r
.65166 .59251 .6541 .6052 .65832 .60399 .65351 .52985 Mtetra
.567 .365 .567 r
.65351 .52985 .65832 .60399 .65965 .53089 .65764 .52861 Mtetra
.655 .753 .922 r
.65764 .52861 .65965 .53089 .66378 .52966 .66178 .52737 Mtetra
.66178 .52737 .66378 .52966 .66792 .52842 .66593 .52612 Mtetra
.66593 .52612 .66792 .52842 .67207 .52717 .67008 .52488 Mtetra
.67008 .52488 .67207 .52717 .67622 .52593 .67423 .52363 Mtetra
.67423 .52363 .67622 .52593 .68038 .52469 .6784 .52238 Mtetra
.6784 .52238 .68038 .52469 .68455 .52344 .68257 .52113 Mtetra
.68257 .52113 .68455 .52344 .68872 .52219 .68674 .51988 Mtetra
.68674 .51988 .68872 .52219 .69289 .52094 .69092 .51863 Mtetra
.69092 .51863 .69289 .52094 .69708 .51969 .69511 .51737 Mtetra
.69511 .51737 .69708 .51969 .70127 .51843 .6993 .51611 Mtetra
.6993 .51611 .70127 .51843 .70546 .51718 .7035 .51485 Mtetra
.7035 .51485 .70546 .51718 .70966 .51592 .70771 .51359 Mtetra
.70771 .51359 .70966 .51592 .71387 .51466 .71192 .51233 Mtetra
.71192 .51233 .71387 .51466 .71809 .5134 .71614 .51106 Mtetra
.966 .746 .553 r
.71614 .51106 .71809 .5134 .72112 .49204 .71919 .48969 Mtetra
.656 .751 .919 r
.71919 .48969 .72112 .49204 .72532 .49076 .72339 .48841 Mtetra
.72339 .48841 .72532 .49076 .72953 .48949 .7276 .48713 Mtetra
.7276 .48713 .72953 .48949 .73374 .48821 .73182 .48585 Mtetra
.73182 .48585 .73374 .48821 .73796 .48694 .73604 .48457 Mtetra
.73604 .48457 .73796 .48694 .74218 .48566 .74027 .48329 Mtetra
.74027 .48329 .74218 .48566 .74642 .48437 .74451 .482 Mtetra
.74451 .482 .74642 .48437 .75065 .48309 .74875 .48071 Mtetra
.74875 .48071 .75065 .48309 .7549 .4818 .753 .47942 Mtetra
.753 .47942 .7549 .4818 .75915 .48052 .75726 .47813 Mtetra
.75726 .47813 .75915 .48052 .76341 .47923 .76152 .47684 Mtetra
.76152 .47684 .76341 .47923 .76767 .47793 .76579 .47554 Mtetra
.978 .698 .422 r
.76579 .47554 .76767 .47793 .765 .38403 .76317 .38158 Mtetra
.663 .742 .908 r
.76317 .38158 .765 .38403 .76916 .3827 .76732 .38025 Mtetra
.76732 .38025 .76916 .3827 .77331 .38138 .77149 .37892 Mtetra
.77149 .37892 .77331 .38138 .77747 .38005 .77565 .37759 Mtetra
.77565 .37759 .77747 .38005 .78164 .37871 .77983 .37625 Mtetra
.77983 .37625 .78164 .37871 .78582 .37738 .78401 .37491 Mtetra
.78401 .37491 .78582 .37738 .79 .37605 .78819 .37357 Mtetra
.78819 .37357 .79 .37605 .79419 .37471 .79238 .37223 Mtetra
.79238 .37223 .79419 .37471 .79838 .37337 .79658 .37089 Mtetra
.79658 .37089 .79838 .37337 .80258 .37203 .80078 .36954 Mtetra
.80078 .36954 .80258 .37203 .80678 .37068 .80499 .3682 Mtetra
.80499 .3682 .80678 .37068 .811 .36934 .80921 .36685 Mtetra
.80921 .36685 .811 .36934 .81521 .36799 .81343 .3655 Mtetra
.81343 .3655 .81521 .36799 .81944 .36664 .81766 .36414 Mtetra
.81766 .36414 .81944 .36664 .82367 .36529 .82189 .36279 Mtetra
.82189 .36279 .82367 .36529 .8279 .36394 .82613 .36143 Mtetra
.892 .797 .748 r
.82613 .36143 .8279 .36394 .83169 .35783 .82992 .35532 Mtetra
.664 .741 .908 r
.82992 .35532 .83169 .35783 .83593 .35647 .83417 .35396 Mtetra
.83417 .35396 .83593 .35647 .84018 .35511 .83842 .35259 Mtetra
.83842 .35259 .84018 .35511 .84443 .35375 .84268 .35122 Mtetra
.84268 .35122 .84443 .35375 .84869 .35238 .84695 .34986 Mtetra
.84695 .34986 .84869 .35238 .85296 .35101 .85122 .34849 Mtetra
.85122 .34849 .85296 .35101 .85723 .34965 .8555 .34711 Mtetra
.8555 .34711 .85723 .34965 .86151 .34827 .85978 .34574 Mtetra
.85978 .34574 .86151 .34827 .8658 .3469 .86407 .34436 Mtetra
.86407 .34436 .8658 .3469 .87009 .34553 .86837 .34298 Mtetra
.86837 .34298 .87009 .34553 .87439 .34415 .87267 .3416 Mtetra
.87267 .3416 .87439 .34415 .87869 .34277 .87698 .34022 Mtetra
.87698 .34022 .87869 .34277 .883 .34139 .88129 .33884 Mtetra
.88129 .33884 .883 .34139 .88732 .34001 .88562 .33745 Mtetra
.88562 .33745 .88732 .34001 .89164 .33862 .88994 .33606 Mtetra
.88994 .33606 .89164 .33862 .89597 .33724 .89428 .33467 Mtetra
.89428 .33467 .89597 .33724 .90031 .33585 .89862 .33328 Mtetra
.89862 .33328 .90031 .33585 .90465 .33446 .90297 .33188 Mtetra
.31333 .51825 .31558 .52034 .31911 .51921 .31686 .51711 Mtetra
.31686 .51711 .31911 .51921 .32264 .51807 .3204 .51598 Mtetra
.3204 .51598 .32264 .51807 .32617 .51694 .32394 .51484 Mtetra
.32394 .51484 .32617 .51694 .32971 .5158 .32748 .5137 Mtetra
.32748 .5137 .32971 .5158 .33326 .51466 .33103 .51256 Mtetra
.33103 .51256 .33326 .51466 .33681 .51353 .33458 .51142 Mtetra
.33458 .51142 .33681 .51353 .34037 .51239 .33814 .51028 Mtetra
.33814 .51028 .34037 .51239 .34393 .51124 .3417 .50913 Mtetra
.3417 .50913 .34393 .51124 .34749 .5101 .34527 .50798 Mtetra
.34527 .50798 .34749 .5101 .35106 .50895 .34884 .50684 Mtetra
.34884 .50684 .35106 .50895 .35464 .50781 .35242 .50569 Mtetra
.35242 .50569 .35464 .50781 .35821 .50666 .356 .50453 Mtetra
.356 .50453 .35821 .50666 .3618 .50551 .35959 .50338 Mtetra
.35959 .50338 .3618 .50551 .36539 .50436 .36318 .50223 Mtetra
.36318 .50223 .36539 .50436 .36898 .5032 .36678 .50107 Mtetra
.36678 .50107 .36898 .5032 .37258 .50205 .37038 .49991 Mtetra
.37038 .49991 .37258 .50205 .37618 .50089 .37399 .49876 Mtetra
.37399 .49876 .37618 .50089 .37979 .49974 .3776 .49759 Mtetra
.3776 .49759 .37979 .49974 .3834 .49858 .38122 .49643 Mtetra
.38122 .49643 .3834 .49858 .38702 .49742 .38484 .49527 Mtetra
.38484 .49527 .38702 .49742 .39065 .49625 .38846 .4941 Mtetra
.38846 .4941 .39065 .49625 .39427 .49509 .39209 .49294 Mtetra
.39209 .49294 .39427 .49509 .39791 .49392 .39573 .49177 Mtetra
.39573 .49177 .39791 .49392 .40154 .49276 .39937 .4906 Mtetra
.39937 .4906 .40154 .49276 .40519 .49159 .40302 .48943 Mtetra
.40302 .48943 .40519 .49159 .40883 .49042 .40667 .48825 Mtetra
.40667 .48825 .40883 .49042 .41249 .48925 .41032 .48708 Mtetra
.41032 .48708 .41249 .48925 .41614 .48807 .41398 .4859 Mtetra
.95 .677 .484 r
.41398 .4859 .41614 .48807 .41634 .5961 .4141 .594 Mtetra
.655 .752 .921 r
.4141 .594 .41634 .5961 .42012 .59497 .41789 .59286 Mtetra
.41789 .59286 .42012 .59497 .42392 .59383 .42169 .59172 Mtetra
.42169 .59172 .42392 .59383 .42771 .59268 .42549 .59057 Mtetra
.42549 .59057 .42771 .59268 .43151 .59154 .42929 .58942 Mtetra
.42929 .58942 .43151 .59154 .43532 .59039 .4331 .58828 Mtetra
.4331 .58828 .43532 .59039 .43913 .58925 .43692 .58713 Mtetra
.43692 .58713 .43913 .58925 .44295 .5881 .44074 .58597 Mtetra
.44074 .58597 .44295 .5881 .44678 .58695 .44457 .58482 Mtetra
.44457 .58482 .44678 .58695 .4506 .5858 .4484 .58367 Mtetra
.4484 .58367 .4506 .5858 .45444 .58464 .45224 .58251 Mtetra
.45224 .58251 .45444 .58464 .45828 .58349 .45608 .58135 Mtetra
.45608 .58135 .45828 .58349 .46212 .58233 .45993 .58019 Mtetra
.45993 .58019 .46212 .58233 .46597 .58117 .46378 .57903 Mtetra
.46378 .57903 .46597 .58117 .46983 .58001 .46764 .57787 Mtetra
.46764 .57787 .46983 .58001 .47369 .57885 .47151 .5767 Mtetra
.47151 .5767 .47369 .57885 .47756 .57769 .47538 .57554 Mtetra
.47538 .57554 .47756 .57769 .48046 .65221 .47926 .57437 Mtetra
0 0 .394 r
.47926 .57437 .48046 .65221 .48443 .65107 .48221 .64897 Mtetra
.648 .76 .931 r
.48221 .64897 .48443 .65107 .4884 .64993 .48618 .64782 Mtetra
.48618 .64782 .4884 .64993 .49237 .64879 .49016 .64668 Mtetra
.49016 .64668 .49237 .64879 .49635 .64765 .49414 .64553 Mtetra
.49414 .64553 .49635 .64765 .50034 .6465 .49813 .64439 Mtetra
.49813 .64439 .50034 .6465 .50433 .64536 .50213 .64324 Mtetra
.50213 .64324 .50433 .64536 .50833 .64421 .50613 .64209 Mtetra
.50613 .64209 .50833 .64421 .51234 .64306 .51014 .64094 Mtetra
.51014 .64094 .51234 .64306 .51635 .64191 .51415 .63978 Mtetra
.51415 .63978 .51635 .64191 .52036 .64076 .51817 .63863 Mtetra
.51817 .63863 .52036 .64076 .52438 .6396 .5222 .63747 Mtetra
.5222 .63747 .52438 .6396 .52841 .63845 .52623 .63631 Mtetra
.52623 .63631 .52841 .63845 .53245 .63729 .53027 .63515 Mtetra
.925 .761 .659 r
.53027 .63515 .53245 .63729 .53648 .63613 .53428 .62364 Mtetra
.598 .451 .653 r
.53428 .62364 .53648 .63613 .54048 .62462 .53832 .62247 Mtetra
.649 .759 .929 r
.53832 .62247 .54048 .62462 .54452 .62346 .54236 .6213 Mtetra
.54236 .6213 .54452 .62346 .54857 .62229 .54641 .62013 Mtetra
.54641 .62013 .54857 .62229 .55262 .62112 .55047 .61895 Mtetra
.55047 .61895 .55262 .62112 .55668 .61995 .55453 .61778 Mtetra
.55453 .61778 .55668 .61995 .56074 .61877 .5586 .6166 Mtetra
.5586 .6166 .56074 .61877 .56481 .6176 .56267 .61542 Mtetra
.56267 .61542 .56481 .6176 .56888 .61642 .56675 .61424 Mtetra
.56675 .61424 .56888 .61642 .57296 .61524 .57083 .61306 Mtetra
.57083 .61306 .57296 .61524 .57705 .61406 .57493 .61188 Mtetra
.57493 .61188 .57705 .61406 .58115 .61288 .57902 .61069 Mtetra
.57902 .61069 .58115 .61288 .58524 .61169 .58313 .6095 Mtetra
.58313 .6095 .58524 .61169 .58935 .61051 .58723 .60832 Mtetra
.58723 .60832 .58935 .61051 .59346 .60932 .59135 .60712 Mtetra
.59135 .60712 .59346 .60932 .59758 .60813 .59547 .60593 Mtetra
.59547 .60593 .59758 .60813 .6017 .60694 .5996 .60474 Mtetra
.5996 .60474 .6017 .60694 .60583 .60575 .60373 .60354 Mtetra
.60373 .60354 .60583 .60575 .60997 .60455 .60787 .60234 Mtetra
.60787 .60234 .60997 .60455 .61411 .60336 .61202 .60114 Mtetra
.61202 .60114 .61411 .60336 .61826 .60216 .61617 .59994 Mtetra
.61617 .59994 .61826 .60216 .62241 .60096 .62033 .59874 Mtetra
.62033 .59874 .62241 .60096 .62657 .59976 .62449 .59753 Mtetra
.62449 .59753 .62657 .59976 .63074 .59855 .62866 .59633 Mtetra
.62866 .59633 .63074 .59855 .63491 .59735 .63284 .59512 Mtetra
.63284 .59512 .63491 .59735 .63909 .59614 .63702 .59391 Mtetra
.63702 .59391 .63909 .59614 .64327 .59493 .64121 .5927 Mtetra
.64121 .5927 .64327 .59493 .64747 .59372 .64541 .59148 Mtetra
.64541 .59148 .64747 .59372 .65166 .59251 .64961 .59027 Mtetra
.64961 .59027 .65166 .59251 .65351 .52985 .65382 .58905 Mtetra
0 0 .374 r
.65382 .58905 .65351 .52985 .65764 .52861 .65563 .52631 Mtetra
.655 .753 .922 r
.65563 .52631 .65764 .52861 .66178 .52737 .65977 .52507 Mtetra
.65977 .52507 .66178 .52737 .66593 .52612 .66392 .52382 Mtetra
.66392 .52382 .66593 .52612 .67008 .52488 .66808 .52257 Mtetra
.66808 .52257 .67008 .52488 .67423 .52363 .67224 .52132 Mtetra
.67224 .52132 .67423 .52363 .6784 .52238 .67641 .52007 Mtetra
.67641 .52007 .6784 .52238 .68257 .52113 .68058 .51882 Mtetra
.68058 .51882 .68257 .52113 .68674 .51988 .68476 .51756 Mtetra
.68476 .51756 .68674 .51988 .69092 .51863 .68895 .51631 Mtetra
.68895 .51631 .69092 .51863 .69511 .51737 .69314 .51505 Mtetra
.69314 .51505 .69511 .51737 .6993 .51611 .69734 .51379 Mtetra
.69734 .51379 .6993 .51611 .7035 .51485 .70154 .51252 Mtetra
.70154 .51252 .7035 .51485 .70771 .51359 .70575 .51126 Mtetra
.70575 .51126 .70771 .51359 .71192 .51233 .70997 .50999 Mtetra
.70997 .50999 .71192 .51233 .71614 .51106 .71419 .50872 Mtetra
.966 .746 .553 r
.71419 .50872 .71614 .51106 .71919 .48969 .71725 .48733 Mtetra
.656 .751 .919 r
.71725 .48733 .71919 .48969 .72339 .48841 .72146 .48605 Mtetra
.72146 .48605 .72339 .48841 .7276 .48713 .72568 .48477 Mtetra
.72568 .48477 .7276 .48713 .73182 .48585 .7299 .48348 Mtetra
.7299 .48348 .73182 .48585 .73604 .48457 .73413 .4822 Mtetra
.73413 .4822 .73604 .48457 .74027 .48329 .73836 .48091 Mtetra
.73836 .48091 .74027 .48329 .74451 .482 .7426 .47962 Mtetra
.7426 .47962 .74451 .482 .74875 .48071 .74685 .47833 Mtetra
.74685 .47833 .74875 .48071 .753 .47942 .7511 .47704 Mtetra
.7511 .47704 .753 .47942 .75726 .47813 .75536 .47574 Mtetra
.75536 .47574 .75726 .47813 .76152 .47684 .75963 .47445 Mtetra
.75963 .47445 .76152 .47684 .76579 .47554 .7639 .47315 Mtetra
.7639 .47315 .76579 .47554 .76317 .38158 .76818 .47185 Mtetra
.055 0 .429 r
.76818 .47185 .76317 .38158 .76732 .38025 .76549 .37779 Mtetra
.663 .742 .908 r
.76549 .37779 .76732 .38025 .77149 .37892 .76965 .37646 Mtetra
.76965 .37646 .77149 .37892 .77565 .37759 .77383 .37512 Mtetra
.77383 .37512 .77565 .37759 .77983 .37625 .778 .37378 Mtetra
.778 .37378 .77983 .37625 .78401 .37491 .78219 .37244 Mtetra
.78219 .37244 .78401 .37491 .78819 .37357 .78638 .3711 Mtetra
.78638 .3711 .78819 .37357 .79238 .37223 .79057 .36975 Mtetra
.79057 .36975 .79238 .37223 .79658 .37089 .79477 .36841 Mtetra
.79477 .36841 .79658 .37089 .80078 .36954 .79898 .36706 Mtetra
.79898 .36706 .80078 .36954 .80499 .3682 .8032 .36571 Mtetra
.8032 .36571 .80499 .3682 .80921 .36685 .80742 .36435 Mtetra
.80742 .36435 .80921 .36685 .81343 .3655 .81164 .363 Mtetra
.81164 .363 .81343 .3655 .81766 .36414 .81588 .36164 Mtetra
.81588 .36164 .81766 .36414 .82189 .36279 .82011 .36028 Mtetra
.82011 .36028 .82189 .36279 .82613 .36143 .82436 .35892 Mtetra
.892 .797 .748 r
.82436 .35892 .82613 .36143 .82992 .35532 .82816 .3528 Mtetra
.664 .741 .908 r
.82816 .3528 .82992 .35532 .83417 .35396 .83241 .35143 Mtetra
.83241 .35143 .83417 .35396 .83842 .35259 .83666 .35007 Mtetra
.83666 .35007 .83842 .35259 .84268 .35122 .84093 .3487 Mtetra
.84093 .3487 .84268 .35122 .84695 .34986 .8452 .34732 Mtetra
.8452 .34732 .84695 .34986 .85122 .34849 .84947 .34595 Mtetra
.84947 .34595 .85122 .34849 .8555 .34711 .85375 .34457 Mtetra
.85375 .34457 .8555 .34711 .85978 .34574 .85804 .3432 Mtetra
.85804 .3432 .85978 .34574 .86407 .34436 .86234 .34182 Mtetra
.86234 .34182 .86407 .34436 .86837 .34298 .86664 .34043 Mtetra
.86664 .34043 .86837 .34298 .87267 .3416 .87095 .33905 Mtetra
.87095 .33905 .87267 .3416 .87698 .34022 .87526 .33766 Mtetra
.87526 .33766 .87698 .34022 .88129 .33884 .87958 .33627 Mtetra
.87958 .33627 .88129 .33884 .88562 .33745 .88391 .33488 Mtetra
.88391 .33488 .88562 .33745 .88994 .33606 .88824 .33349 Mtetra
.88824 .33349 .88994 .33606 .89428 .33467 .89258 .3321 Mtetra
.89258 .3321 .89428 .33467 .89862 .33328 .89692 .3307 Mtetra
.89692 .3307 .89862 .33328 .90297 .33188 .90128 .3293 Mtetra
.31108 .51615 .31333 .51825 .31686 .51711 .31462 .51502 Mtetra
.31462 .51502 .31686 .51711 .3204 .51598 .31815 .51388 Mtetra
.31815 .51388 .3204 .51598 .32394 .51484 .3217 .51274 Mtetra
.3217 .51274 .32394 .51484 .32748 .5137 .32524 .51159 Mtetra
.32524 .51159 .32748 .5137 .33103 .51256 .32879 .51045 Mtetra
.32879 .51045 .33103 .51256 .33458 .51142 .33235 .50931 Mtetra
.33235 .50931 .33458 .51142 .33814 .51028 .33591 .50816 Mtetra
.33591 .50816 .33814 .51028 .3417 .50913 .33948 .50701 Mtetra
.33948 .50701 .3417 .50913 .34527 .50798 .34305 .50586 Mtetra
.34305 .50586 .34527 .50798 .34884 .50684 .34662 .50471 Mtetra
.34662 .50471 .34884 .50684 .35242 .50569 .3502 .50356 Mtetra
.3502 .50356 .35242 .50569 .356 .50453 .35379 .50241 Mtetra
.35379 .50241 .356 .50453 .35959 .50338 .35738 .50125 Mtetra
.35738 .50125 .35959 .50338 .36318 .50223 .36097 .50009 Mtetra
.36097 .50009 .36318 .50223 .36678 .50107 .36457 .49893 Mtetra
.36457 .49893 .36678 .50107 .37038 .49991 .36818 .49777 Mtetra
.36818 .49777 .37038 .49991 .37399 .49876 .37179 .49661 Mtetra
.37179 .49661 .37399 .49876 .3776 .49759 .3754 .49545 Mtetra
.3754 .49545 .3776 .49759 .38122 .49643 .37902 .49428 Mtetra
.37902 .49428 .38122 .49643 .38484 .49527 .38264 .49312 Mtetra
.38264 .49312 .38484 .49527 .38846 .4941 .38627 .49195 Mtetra
.38627 .49195 .38846 .4941 .39209 .49294 .38991 .49078 Mtetra
.38991 .49078 .39209 .49294 .39573 .49177 .39355 .48961 Mtetra
.39355 .48961 .39573 .49177 .39937 .4906 .39719 .48843 Mtetra
.39719 .48843 .39937 .4906 .40302 .48943 .40084 .48726 Mtetra
.40084 .48726 .40302 .48943 .40667 .48825 .40449 .48608 Mtetra
.40449 .48608 .40667 .48825 .41032 .48708 .40815 .48491 Mtetra
.40815 .48491 .41032 .48708 .41398 .4859 .41181 .48373 Mtetra
.41181 .48373 .41398 .4859 .4141 .594 .41548 .48255 Mtetra
0 0 .349 r
.41548 .48255 .4141 .594 .41789 .59286 .41566 .59075 Mtetra
.655 .752 .921 r
.41566 .59075 .41789 .59286 .42169 .59172 .41945 .5896 Mtetra
.41945 .5896 .42169 .59172 .42549 .59057 .42326 .58845 Mtetra
.42326 .58845 .42549 .59057 .42929 .58942 .42707 .5873 Mtetra
.42707 .5873 .42929 .58942 .4331 .58828 .43088 .58615 Mtetra
.43088 .58615 .4331 .58828 .43692 .58713 .4347 .585 Mtetra
.4347 .585 .43692 .58713 .44074 .58597 .43853 .58384 Mtetra
.43853 .58384 .44074 .58597 .44457 .58482 .44236 .58269 Mtetra
.44236 .58269 .44457 .58482 .4484 .58367 .44619 .58153 Mtetra
.44619 .58153 .4484 .58367 .45224 .58251 .45003 .58037 Mtetra
.45003 .58037 .45224 .58251 .45608 .58135 .45388 .57921 Mtetra
.45388 .57921 .45608 .58135 .45993 .58019 .45773 .57805 Mtetra
.45773 .57805 .45993 .58019 .46378 .57903 .46159 .57688 Mtetra
.46159 .57688 .46378 .57903 .46764 .57787 .46545 .57572 Mtetra
.46545 .57572 .46764 .57787 .47151 .5767 .46932 .57455 Mtetra
.46932 .57455 .47151 .5767 .47538 .57554 .47319 .57338 Mtetra
.47319 .57338 .47538 .57554 .47926 .57437 .47707 .57221 Mtetra
.47707 .57221 .47926 .57437 .48221 .64897 .48096 .57104 Mtetra
0 0 .243 r
.48096 .57104 .48221 .64897 .48618 .64782 .48365 .67175 Mtetra
.533 .285 .485 r
.48365 .67175 .48618 .64782 .49016 .64668 .48766 .67062 Mtetra
.48766 .67062 .49016 .64668 .49414 .64553 .49168 .66948 Mtetra
.49168 .66948 .49414 .64553 .49813 .64439 .4957 .66834 Mtetra
.4957 .66834 .49813 .64439 .50213 .64324 .49973 .6672 Mtetra
.49973 .6672 .50213 .64324 .50613 .64209 .50377 .66605 Mtetra
.50377 .66605 .50613 .64209 .51014 .64094 .50781 .66491 Mtetra
.50781 .66491 .51014 .64094 .51415 .63978 .51186 .66376 Mtetra
.51186 .66376 .51415 .63978 .51817 .63863 .51591 .66261 Mtetra
0 0 .232 r
.51591 .66261 .51817 .63863 .5222 .63747 .52001 .63533 Mtetra
.648 .76 .931 r
.52001 .63533 .5222 .63747 .52623 .63631 .52405 .63417 Mtetra
.957 .708 .52 r
.52405 .63417 .52623 .63631 .53027 .63515 .52803 .57682 Mtetra
.568 .368 .571 r
.52803 .57682 .53027 .63515 .53428 .62364 .53202 .57563 Mtetra
.005 0 .438 r
.53202 .57563 .53428 .62364 .53832 .62247 .53615 .62031 Mtetra
.649 .759 .929 r
.53615 .62031 .53832 .62247 .54236 .6213 .5402 .61913 Mtetra
.5402 .61913 .54236 .6213 .54641 .62013 .54425 .61796 Mtetra
.54425 .61796 .54641 .62013 .55047 .61895 .54831 .61678 Mtetra
.54831 .61678 .55047 .61895 .55453 .61778 .55238 .6156 Mtetra
.55238 .6156 .55453 .61778 .5586 .6166 .55645 .61442 Mtetra
.55645 .61442 .5586 .6166 .56267 .61542 .56053 .61324 Mtetra
.56053 .61324 .56267 .61542 .56675 .61424 .56461 .61206 Mtetra
.56461 .61206 .56675 .61424 .57083 .61306 .5687 .61087 Mtetra
.5687 .61087 .57083 .61306 .57493 .61188 .57279 .60969 Mtetra
.57279 .60969 .57493 .61188 .57902 .61069 .57689 .6085 Mtetra
.57689 .6085 .57902 .61069 .58313 .6095 .581 .60731 Mtetra
.581 .60731 .58313 .6095 .58723 .60832 .58511 .60612 Mtetra
.58511 .60612 .58723 .60832 .59135 .60712 .58923 .60492 Mtetra
.58923 .60492 .59135 .60712 .59547 .60593 .59336 .60373 Mtetra
.59336 .60373 .59547 .60593 .5996 .60474 .59749 .60253 Mtetra
.59749 .60253 .5996 .60474 .60373 .60354 .60163 .60133 Mtetra
.60163 .60133 .60373 .60354 .60787 .60234 .60577 .60013 Mtetra
.60577 .60013 .60787 .60234 .61202 .60114 .60992 .59892 Mtetra
.60992 .59892 .61202 .60114 .61617 .59994 .61408 .59772 Mtetra
.61408 .59772 .61617 .59994 .62033 .59874 .61824 .59651 Mtetra
.61824 .59651 .62033 .59874 .62449 .59753 .62241 .59531 Mtetra
.62241 .59531 .62449 .59753 .62866 .59633 .62658 .5941 Mtetra
.62658 .5941 .62866 .59633 .63284 .59512 .63077 .59288 Mtetra
.63077 .59288 .63284 .59512 .63702 .59391 .63495 .59167 Mtetra
.63495 .59167 .63702 .59391 .64121 .5927 .63915 .59045 Mtetra
.63915 .59045 .64121 .5927 .64541 .59148 .64335 .58924 Mtetra
.64335 .58924 .64541 .59148 .64961 .59027 .64755 .58802 Mtetra
.64755 .58802 .64961 .59027 .65382 .58905 .65177 .5868 Mtetra
.97 .709 .481 r
.65177 .5868 .65382 .58905 .65563 .52631 .65362 .52401 Mtetra
.655 .753 .922 r
.65362 .52401 .65563 .52631 .65977 .52507 .65776 .52277 Mtetra
.65776 .52277 .65977 .52507 .66392 .52382 .66192 .52152 Mtetra
.66192 .52152 .66392 .52382 .66808 .52257 .66608 .52027 Mtetra
.66608 .52027 .66808 .52257 .67224 .52132 .67024 .51901 Mtetra
.67024 .51901 .67224 .52132 .67641 .52007 .67441 .51776 Mtetra
.67441 .51776 .67641 .52007 .68058 .51882 .67859 .5165 Mtetra
.67859 .5165 .68058 .51882 .68476 .51756 .68277 .51524 Mtetra
.68277 .51524 .68476 .51756 .68895 .51631 .68696 .51398 Mtetra
.68696 .51398 .68895 .51631 .69314 .51505 .69116 .51272 Mtetra
.69116 .51272 .69314 .51505 .69734 .51379 .69536 .51145 Mtetra
.69536 .51145 .69734 .51379 .70154 .51252 .69957 .51019 Mtetra
.69957 .51019 .70154 .51252 .70575 .51126 .70379 .50892 Mtetra
.70379 .50892 .70575 .51126 .70997 .50999 .70801 .50765 Mtetra
.70801 .50765 .70997 .50999 .71419 .50872 .71224 .50638 Mtetra
.966 .746 .553 r
.71224 .50638 .71419 .50872 .71725 .48733 .71531 .48497 Mtetra
.656 .751 .919 r
.71531 .48497 .71725 .48733 .72146 .48605 .71952 .48368 Mtetra
.71952 .48368 .72146 .48605 .72568 .48477 .72374 .4824 Mtetra
.72374 .4824 .72568 .48477 .7299 .48348 .72797 .48111 Mtetra
.72797 .48111 .7299 .48348 .73413 .4822 .7322 .47982 Mtetra
.7322 .47982 .73413 .4822 .73836 .48091 .73644 .47853 Mtetra
.73644 .47853 .73836 .48091 .7426 .47962 .74069 .47724 Mtetra
.74069 .47724 .7426 .47962 .74685 .47833 .74494 .47594 Mtetra
.74494 .47594 .74685 .47833 .7511 .47704 .74919 .47465 Mtetra
.74919 .47465 .7511 .47704 .75536 .47574 .75346 .47335 Mtetra
.75346 .47335 .75536 .47574 .75963 .47445 .75773 .47205 Mtetra
.75773 .47205 .75963 .47445 .7639 .47315 .76201 .47075 Mtetra
.76201 .47075 .7639 .47315 .76818 .47185 .76629 .46944 Mtetra
.979 .698 .42 r
.76629 .46944 .76818 .47185 .76549 .37779 .76365 .37533 Mtetra
.663 .742 .908 r
.76365 .37533 .76549 .37779 .76965 .37646 .76782 .37399 Mtetra
.76782 .37399 .76965 .37646 .77383 .37512 .77199 .37265 Mtetra
.77199 .37265 .77383 .37512 .778 .37378 .77618 .3713 Mtetra
.77618 .3713 .778 .37378 .78219 .37244 .78036 .36996 Mtetra
.78036 .36996 .78219 .37244 .78638 .3711 .78456 .36861 Mtetra
.78456 .36861 .78638 .3711 .79057 .36975 .78876 .36726 Mtetra
.78876 .36726 .79057 .36975 .79477 .36841 .79296 .36591 Mtetra
.79296 .36591 .79477 .36841 .79898 .36706 .79718 .36456 Mtetra
.79718 .36456 .79898 .36706 .8032 .36571 .80139 .36321 Mtetra
.80139 .36321 .8032 .36571 .80742 .36435 .80562 .36185 Mtetra
.80562 .36185 .80742 .36435 .81164 .363 .80985 .36049 Mtetra
.80985 .36049 .81164 .363 .81588 .36164 .81409 .35913 Mtetra
.81409 .35913 .81588 .36164 .82011 .36028 .81833 .35777 Mtetra
.81833 .35777 .82011 .36028 .82436 .35892 .82258 .35641 Mtetra
.892 .797 .748 r
.82258 .35641 .82436 .35892 .82816 .3528 .82638 .35028 Mtetra
.664 .741 .908 r
.82638 .35028 .82816 .3528 .83241 .35143 .83064 .34891 Mtetra
.83064 .34891 .83241 .35143 .83666 .35007 .8349 .34754 Mtetra
.8349 .34754 .83666 .35007 .84093 .3487 .83917 .34616 Mtetra
.83917 .34616 .84093 .3487 .8452 .34732 .84344 .34479 Mtetra
.84344 .34479 .8452 .34732 .84947 .34595 .84772 .34341 Mtetra
.84772 .34341 .84947 .34595 .85375 .34457 .85201 .34203 Mtetra
.85201 .34203 .85375 .34457 .85804 .3432 .8563 .34065 Mtetra
.8563 .34065 .85804 .3432 .86234 .34182 .8606 .33926 Mtetra
.8606 .33926 .86234 .34182 .86664 .34043 .86491 .33788 Mtetra
.86491 .33788 .86664 .34043 .87095 .33905 .86922 .33649 Mtetra
.86922 .33649 .87095 .33905 .87526 .33766 .87354 .3351 Mtetra
.87354 .3351 .87526 .33766 .87958 .33627 .87786 .33371 Mtetra
.87786 .33371 .87958 .33627 .88391 .33488 .88219 .33231 Mtetra
.88219 .33231 .88391 .33488 .88824 .33349 .88653 .33092 Mtetra
.88653 .33092 .88824 .33349 .89258 .3321 .89087 .32952 Mtetra
.89087 .32952 .89258 .3321 .89692 .3307 .89522 .32812 Mtetra
.89522 .32812 .89692 .3307 .90128 .3293 .89958 .32671 Mtetra
.30883 .51405 .31108 .51615 .31462 .51502 .31236 .51291 Mtetra
.31236 .51291 .31462 .51502 .31815 .51388 .3159 .51177 Mtetra
.3159 .51177 .31815 .51388 .3217 .51274 .31945 .51063 Mtetra
.31945 .51063 .3217 .51274 .32524 .51159 .323 .50948 Mtetra
.323 .50948 .32524 .51159 .32879 .51045 .32655 .50834 Mtetra
.32655 .50834 .32879 .51045 .33235 .50931 .33011 .50719 Mtetra
.33011 .50719 .33235 .50931 .33591 .50816 .33368 .50604 Mtetra
.33368 .50604 .33591 .50816 .33948 .50701 .33724 .50489 Mtetra
.33724 .50489 .33948 .50701 .34305 .50586 .34082 .50374 Mtetra
.34082 .50374 .34305 .50586 .34662 .50471 .3444 .50258 Mtetra
.3444 .50258 .34662 .50471 .3502 .50356 .34798 .50143 Mtetra
.34798 .50143 .3502 .50356 .35379 .50241 .35157 .50027 Mtetra
.35157 .50027 .35379 .50241 .35738 .50125 .35516 .49911 Mtetra
.35516 .49911 .35738 .50125 .36097 .50009 .35876 .49795 Mtetra
.35876 .49795 .36097 .50009 .36457 .49893 .36236 .49679 Mtetra
.36236 .49679 .36457 .49893 .36818 .49777 .36597 .49563 Mtetra
.36597 .49563 .36818 .49777 .37179 .49661 .36958 .49446 Mtetra
.36958 .49446 .37179 .49661 .3754 .49545 .3732 .4933 Mtetra
.3732 .4933 .3754 .49545 .37902 .49428 .37682 .49213 Mtetra
.37682 .49213 .37902 .49428 .38264 .49312 .38045 .49096 Mtetra
.38045 .49096 .38264 .49312 .38627 .49195 .38408 .48979 Mtetra
.38408 .48979 .38627 .49195 .38991 .49078 .38772 .48861 Mtetra
.38772 .48861 .38991 .49078 .39355 .48961 .39136 .48744 Mtetra
.39136 .48744 .39355 .48961 .39719 .48843 .39501 .48626 Mtetra
.39501 .48626 .39719 .48843 .40084 .48726 .39866 .48509 Mtetra
.39866 .48509 .40084 .48726 .40449 .48608 .40231 .48391 Mtetra
.40231 .48391 .40449 .48608 .40815 .48491 .40598 .48273 Mtetra
.40598 .48273 .40815 .48491 .41181 .48373 .40964 .48155 Mtetra
.40964 .48155 .41181 .48373 .41548 .48255 .41331 .48036 Mtetra
.951 .677 .483 r
.41331 .48036 .41548 .48255 .41566 .59075 .41341 .58863 Mtetra
.655 .752 .921 r
.41341 .58863 .41566 .59075 .41945 .5896 .41722 .58748 Mtetra
.41722 .58748 .41945 .5896 .42326 .58845 .42102 .58633 Mtetra
.42102 .58633 .42326 .58845 .42707 .5873 .42483 .58518 Mtetra
.42483 .58518 .42707 .5873 .43088 .58615 .42865 .58402 Mtetra
.42865 .58402 .43088 .58615 .4347 .585 .43248 .58287 Mtetra
.43248 .58287 .4347 .585 .43853 .58384 .4363 .58171 Mtetra
.4363 .58171 .43853 .58384 .44236 .58269 .44014 .58055 Mtetra
.44014 .58055 .44236 .58269 .44619 .58153 .44398 .57939 Mtetra
.44398 .57939 .44619 .58153 .45003 .58037 .44782 .57823 Mtetra
.44782 .57823 .45003 .58037 .45388 .57921 .45167 .57706 Mtetra
.45167 .57706 .45388 .57921 .45773 .57805 .45553 .5759 Mtetra
.45553 .5759 .45773 .57805 .46159 .57688 .45939 .57473 Mtetra
.45939 .57473 .46159 .57688 .46545 .57572 .46325 .57356 Mtetra
.46325 .57356 .46545 .57572 .46932 .57455 .46713 .57239 Mtetra
.46713 .57239 .46932 .57455 .47319 .57338 .471 .57122 Mtetra
.471 .57122 .47319 .57338 .47707 .57221 .47489 .57004 Mtetra
.957 .675 .461 r
.47489 .57004 .47707 .57221 .48096 .57104 .47739 .67079 Mtetra
.552 .33 .532 r
.47739 .67079 .48096 .57104 .48365 .67175 .4814 .66965 Mtetra
.646 .762 .934 r
.4814 .66965 .48365 .67175 .48766 .67062 .48542 .66851 Mtetra
.48542 .66851 .48766 .67062 .49168 .66948 .48944 .66737 Mtetra
.48944 .66737 .49168 .66948 .4957 .66834 .49347 .66623 Mtetra
.49347 .66623 .4957 .66834 .49973 .6672 .4975 .66508 Mtetra
.4975 .66508 .49973 .6672 .50377 .66605 .50154 .66394 Mtetra
.50154 .66394 .50377 .66605 .50781 .66491 .50559 .66279 Mtetra
.50559 .66279 .50781 .66491 .51186 .66376 .50964 .66164 Mtetra
.50964 .66164 .51186 .66376 .51591 .66261 .5137 .66049 Mtetra
.5137 .66049 .51591 .66261 .52001 .63533 .51776 .65934 Mtetra
.532 .284 .485 r
.51776 .65934 .52001 .63533 .52405 .63417 .52183 .65818 Mtetra
.979 .761 .345 r
.52183 .65818 .52405 .63417 .52803 .57682 .52588 .57462 Mtetra
.653 .754 .924 r
.52588 .57462 .52803 .57682 .53202 .57563 .52987 .57343 Mtetra
.52987 .57343 .53202 .57563 .53615 .62031 .53386 .57224 Mtetra
.569 .373 .575 r
.53386 .57224 .53615 .62031 .5402 .61913 .53786 .57105 Mtetra
.008 0 .44 r
.53786 .57105 .5402 .61913 .54425 .61796 .54209 .61579 Mtetra
.649 .759 .929 r
.54209 .61579 .54425 .61796 .54831 .61678 .54615 .61461 Mtetra
.54615 .61461 .54831 .61678 .55238 .6156 .55022 .61342 Mtetra
.55022 .61342 .55238 .6156 .55645 .61442 .55429 .61224 Mtetra
.55429 .61224 .55645 .61442 .56053 .61324 .55838 .61106 Mtetra
.55838 .61106 .56053 .61324 .56461 .61206 .56246 .60987 Mtetra
.56246 .60987 .56461 .61206 .5687 .61087 .56656 .60868 Mtetra
.56656 .60868 .5687 .61087 .57279 .60969 .57065 .60749 Mtetra
.57065 .60749 .57279 .60969 .57689 .6085 .57476 .6063 Mtetra
.57476 .6063 .57689 .6085 .581 .60731 .57887 .60511 Mtetra
.57887 .60511 .581 .60731 .58511 .60612 .58299 .60391 Mtetra
.58299 .60391 .58511 .60612 .58923 .60492 .58711 .60271 Mtetra
.58711 .60271 .58923 .60492 .59336 .60373 .59124 .60151 Mtetra
.59124 .60151 .59336 .60373 .59749 .60253 .59538 .60031 Mtetra
.59538 .60031 .59749 .60253 .60163 .60133 .59952 .59911 Mtetra
.59952 .59911 .60163 .60133 .60577 .60013 .60367 .59791 Mtetra
.60367 .59791 .60577 .60013 .60992 .59892 .60782 .5967 Mtetra
.60782 .5967 .60992 .59892 .61408 .59772 .61198 .59549 Mtetra
.61198 .59549 .61408 .59772 .61824 .59651 .61615 .59428 Mtetra
.61615 .59428 .61824 .59651 .62241 .59531 .62032 .59307 Mtetra
.62032 .59307 .62241 .59531 .62658 .5941 .6245 .59186 Mtetra
.6245 .59186 .62658 .5941 .63077 .59288 .62869 .59064 Mtetra
.62869 .59064 .63077 .59288 .63495 .59167 .63288 .58942 Mtetra
.63288 .58942 .63495 .59167 .63915 .59045 .63707 .58821 Mtetra
.63707 .58821 .63915 .59045 .64335 .58924 .64128 .58698 Mtetra
.64128 .58698 .64335 .58924 .64755 .58802 .64549 .58576 Mtetra
.64549 .58576 .64755 .58802 .65177 .5868 .64971 .58454 Mtetra
.64971 .58454 .65177 .5868 .65362 .52401 .65393 .58331 Mtetra
0 0 .372 r
.65393 .58331 .65362 .52401 .65776 .52277 .65575 .52046 Mtetra
.655 .753 .922 r
.65575 .52046 .65776 .52277 .66192 .52152 .6599 .51921 Mtetra
.6599 .51921 .66192 .52152 .66608 .52027 .66407 .51795 Mtetra
.66407 .51795 .66608 .52027 .67024 .51901 .66824 .51669 Mtetra
.66824 .51669 .67024 .51901 .67441 .51776 .67241 .51543 Mtetra
.67241 .51543 .67441 .51776 .67859 .5165 .67659 .51417 Mtetra
.67659 .51417 .67859 .5165 .68277 .51524 .68078 .51291 Mtetra
.68078 .51291 .68277 .51524 .68696 .51398 .68498 .51165 Mtetra
.68498 .51165 .68696 .51398 .69116 .51272 .68918 .51038 Mtetra
.68918 .51038 .69116 .51272 .69536 .51145 .69338 .50911 Mtetra
.69338 .50911 .69536 .51145 .69957 .51019 .6976 .50784 Mtetra
.6976 .50784 .69957 .51019 .70379 .50892 .70182 .50657 Mtetra
.70182 .50657 .70379 .50892 .70801 .50765 .70604 .5053 Mtetra
.70604 .5053 .70801 .50765 .71224 .50638 .71027 .50402 Mtetra
.71027 .50402 .71224 .50638 .71531 .48497 .71451 .50274 Mtetra
0 0 .289 r
.71451 .50274 .71531 .48497 .71952 .48368 .71758 .48131 Mtetra
.656 .751 .919 r
.71758 .48131 .71952 .48368 .72374 .4824 .72181 .48002 Mtetra
.72181 .48002 .72374 .4824 .72797 .48111 .72604 .47873 Mtetra
.72604 .47873 .72797 .48111 .7322 .47982 .73027 .47744 Mtetra
.73027 .47744 .7322 .47982 .73644 .47853 .73452 .47614 Mtetra
.73452 .47614 .73644 .47853 .74069 .47724 .73876 .47485 Mtetra
.73876 .47485 .74069 .47724 .74494 .47594 .74302 .47355 Mtetra
.74302 .47355 .74494 .47594 .74919 .47465 .74728 .47225 Mtetra
.74728 .47225 .74919 .47465 .75346 .47335 .75155 .47095 Mtetra
.75155 .47095 .75346 .47335 .75773 .47205 .75583 .46964 Mtetra
.75583 .46964 .75773 .47205 .76201 .47075 .76011 .46834 Mtetra
.76011 .46834 .76201 .47075 .76629 .46944 .76439 .46703 Mtetra
.979 .698 .42 r
.76439 .46703 .76629 .46944 .76365 .37533 .7618 .37285 Mtetra
.663 .742 .908 r
.7618 .37285 .76365 .37533 .76782 .37399 .76598 .37151 Mtetra
.76598 .37151 .76782 .37399 .77199 .37265 .77016 .37017 Mtetra
.77016 .37017 .77199 .37265 .77618 .3713 .77434 .36882 Mtetra
.77434 .36882 .77618 .3713 .78036 .36996 .77854 .36747 Mtetra
.77854 .36747 .78036 .36996 .78456 .36861 .78273 .36612 Mtetra
.78273 .36612 .78456 .36861 .78876 .36726 .78694 .36477 Mtetra
.78694 .36477 .78876 .36726 .79296 .36591 .79115 .36342 Mtetra
.79115 .36342 .79296 .36591 .79718 .36456 .79536 .36206 Mtetra
.79536 .36206 .79718 .36456 .80139 .36321 .79959 .3607 Mtetra
.79959 .3607 .80139 .36321 .80562 .36185 .80382 .35934 Mtetra
.80382 .35934 .80562 .36185 .80985 .36049 .80805 .35798 Mtetra
.80805 .35798 .80985 .36049 .81409 .35913 .81229 .35662 Mtetra
.81229 .35662 .81409 .35913 .81833 .35777 .81654 .35525 Mtetra
.81654 .35525 .81833 .35777 .82258 .35641 .8208 .35388 Mtetra
.892 .797 .748 r
.8208 .35388 .82258 .35641 .82638 .35028 .8246 .34775 Mtetra
.664 .741 .908 r
.8246 .34775 .82638 .35028 .83064 .34891 .82886 .34637 Mtetra
.82886 .34637 .83064 .34891 .8349 .34754 .83313 .345 Mtetra
.83313 .345 .8349 .34754 .83917 .34616 .8374 .34362 Mtetra
.8374 .34362 .83917 .34616 .84344 .34479 .84168 .34224 Mtetra
.84168 .34224 .84344 .34479 .84772 .34341 .84597 .34086 Mtetra
.84597 .34086 .84772 .34341 .85201 .34203 .85026 .33948 Mtetra
.85026 .33948 .85201 .34203 .8563 .34065 .85455 .33809 Mtetra
.85455 .33809 .8563 .34065 .8606 .33926 .85886 .3367 Mtetra
.85886 .3367 .8606 .33926 .86491 .33788 .86317 .33531 Mtetra
.86317 .33531 .86491 .33788 .86922 .33649 .86749 .33392 Mtetra
.86749 .33392 .86922 .33649 .87354 .3351 .87181 .33253 Mtetra
.87181 .33253 .87354 .3351 .87786 .33371 .87614 .33113 Mtetra
.87614 .33113 .87786 .33371 .88219 .33231 .88047 .32973 Mtetra
.88047 .32973 .88219 .33231 .88653 .33092 .88482 .32833 Mtetra
.88482 .32833 .88653 .33092 .89087 .32952 .88916 .32693 Mtetra
.88916 .32693 .89087 .32952 .89522 .32812 .89352 .32553 Mtetra
.89352 .32553 .89522 .32812 .89958 .32671 .89788 .32412 Mtetra
.30657 .51195 .30883 .51405 .31236 .51291 .3101 .5108 Mtetra
.3101 .5108 .31236 .51291 .3159 .51177 .31365 .50966 Mtetra
.31365 .50966 .3159 .51177 .31945 .51063 .31719 .50851 Mtetra
.31719 .50851 .31945 .51063 .323 .50948 .32075 .50737 Mtetra
.32075 .50737 .323 .50948 .32655 .50834 .3243 .50622 Mtetra
.3243 .50622 .32655 .50834 .33011 .50719 .32787 .50507 Mtetra
.32787 .50507 .33011 .50719 .33368 .50604 .33143 .50391 Mtetra
.33143 .50391 .33368 .50604 .33724 .50489 .33501 .50276 Mtetra
.33501 .50276 .33724 .50489 .34082 .50374 .33858 .50161 Mtetra
.33858 .50161 .34082 .50374 .3444 .50258 .34216 .50045 Mtetra
.34216 .50045 .3444 .50258 .34798 .50143 .34575 .49929 Mtetra
.34575 .49929 .34798 .50143 .35157 .50027 .34934 .49813 Mtetra
.34934 .49813 .35157 .50027 .35516 .49911 .35294 .49697 Mtetra
.35294 .49697 .35516 .49911 .35876 .49795 .35654 .49581 Mtetra
.35654 .49581 .35876 .49795 .36236 .49679 .36014 .49464 Mtetra
.36014 .49464 .36236 .49679 .36597 .49563 .36375 .49348 Mtetra
.36375 .49348 .36597 .49563 .36958 .49446 .36737 .49231 Mtetra
.36737 .49231 .36958 .49446 .3732 .4933 .37099 .49114 Mtetra
.37099 .49114 .3732 .4933 .37682 .49213 .37461 .48997 Mtetra
.37461 .48997 .37682 .49213 .38045 .49096 .37825 .4888 Mtetra
.37825 .4888 .38045 .49096 .38408 .48979 .38188 .48762 Mtetra
.38188 .48762 .38408 .48979 .38772 .48861 .38552 .48645 Mtetra
.38552 .48645 .38772 .48861 .39136 .48744 .38917 .48527 Mtetra
.38917 .48527 .39136 .48744 .39501 .48626 .39282 .48409 Mtetra
.39282 .48409 .39501 .48626 .39866 .48509 .39647 .48291 Mtetra
.39647 .48291 .39866 .48509 .40231 .48391 .40013 .48173 Mtetra
.40013 .48173 .40231 .48391 .40598 .48273 .40379 .48054 Mtetra
.40379 .48054 .40598 .48273 .40964 .48155 .40746 .47936 Mtetra
.40746 .47936 .40964 .48155 .41331 .48036 .41114 .47817 Mtetra
.951 .677 .483 r
.41114 .47817 .41331 .48036 .41341 .58863 .41117 .58651 Mtetra
.655 .752 .921 r
.41117 .58651 .41341 .58863 .41722 .58748 .41497 .58535 Mtetra
.41497 .58535 .41722 .58748 .42102 .58633 .41878 .5842 Mtetra
.41878 .5842 .42102 .58633 .42483 .58518 .4226 .58304 Mtetra
.4226 .58304 .42483 .58518 .42865 .58402 .42642 .58189 Mtetra
.42642 .58189 .42865 .58402 .43248 .58287 .43024 .58073 Mtetra
.43024 .58073 .43248 .58287 .4363 .58171 .43408 .57957 Mtetra
.43408 .57957 .4363 .58171 .44014 .58055 .43791 .57841 Mtetra
.43791 .57841 .44014 .58055 .44398 .57939 .44176 .57724 Mtetra
.44176 .57724 .44398 .57939 .44782 .57823 .4456 .57608 Mtetra
.4456 .57608 .44782 .57823 .45167 .57706 .44946 .57491 Mtetra
.44946 .57491 .45167 .57706 .45553 .5759 .45332 .57374 Mtetra
.45332 .57374 .45553 .5759 .45939 .57473 .45718 .57257 Mtetra
.45718 .57257 .45939 .57473 .46325 .57356 .46105 .5714 Mtetra
.46105 .5714 .46325 .57356 .46713 .57239 .46493 .57022 Mtetra
.46493 .57022 .46713 .57239 .471 .57122 .46881 .56905 Mtetra
.46881 .56905 .471 .57122 .47489 .57004 .47269 .56787 Mtetra
.957 .675 .461 r
.47269 .56787 .47489 .57004 .47739 .67079 .47513 .66869 Mtetra
.646 .762 .934 r
.47513 .66869 .47739 .67079 .4814 .66965 .47915 .66755 Mtetra
.47915 .66755 .4814 .66965 .48542 .66851 .48317 .66641 Mtetra
.48317 .66641 .48542 .66851 .48944 .66737 .48719 .66526 Mtetra
.48719 .66526 .48944 .66737 .49347 .66623 .49123 .66411 Mtetra
.49123 .66411 .49347 .66623 .4975 .66508 .49526 .66297 Mtetra
.49526 .66297 .4975 .66508 .50154 .66394 .49931 .66182 Mtetra
.49931 .66182 .50154 .66394 .50559 .66279 .50336 .66067 Mtetra
.50336 .66067 .50559 .66279 .50964 .66164 .50741 .65951 Mtetra
.50741 .65951 .50964 .66164 .5137 .66049 .51147 .65836 Mtetra
.51147 .65836 .5137 .66049 .51776 .65934 .51554 .6572 Mtetra
.51554 .6572 .51776 .65934 .52183 .65818 .51962 .65605 Mtetra
.958 .702 .506 r
.51962 .65605 .52183 .65818 .52588 .57462 .52372 .57242 Mtetra
.653 .754 .924 r
.52372 .57242 .52588 .57462 .52987 .57343 .52771 .57123 Mtetra
.52771 .57123 .52987 .57343 .53386 .57224 .53171 .57003 Mtetra
.53171 .57003 .53386 .57224 .53786 .57105 .53571 .56884 Mtetra
.53571 .56884 .53786 .57105 .54209 .61579 .53971 .56764 Mtetra
.008 0 .44 r
.53971 .56764 .54209 .61579 .54615 .61461 .54398 .61242 Mtetra
.649 .759 .929 r
.54398 .61242 .54615 .61461 .55022 .61342 .54806 .61124 Mtetra
.54806 .61124 .55022 .61342 .55429 .61224 .55213 .61005 Mtetra
.55213 .61005 .55429 .61224 .55838 .61106 .55622 .60886 Mtetra
.55622 .60886 .55838 .61106 .56246 .60987 .56031 .60767 Mtetra
.56031 .60767 .56246 .60987 .56656 .60868 .56441 .60648 Mtetra
.56441 .60648 .56656 .60868 .57065 .60749 .56851 .60529 Mtetra
.56851 .60529 .57065 .60749 .57476 .6063 .57262 .60409 Mtetra
.57262 .60409 .57476 .6063 .57887 .60511 .57674 .6029 Mtetra
.57674 .6029 .57887 .60511 .58299 .60391 .58086 .6017 Mtetra
.58086 .6017 .58299 .60391 .58711 .60271 .58498 .6005 Mtetra
.58498 .6005 .58711 .60271 .59124 .60151 .58912 .5993 Mtetra
.58912 .5993 .59124 .60151 .59538 .60031 .59326 .59809 Mtetra
.59326 .59809 .59538 .60031 .59952 .59911 .5974 .59689 Mtetra
.5974 .59689 .59952 .59911 .60367 .59791 .60156 .59568 Mtetra
.60156 .59568 .60367 .59791 .60782 .5967 .60571 .59447 Mtetra
.60571 .59447 .60782 .5967 .61198 .59549 .60988 .59326 Mtetra
.60988 .59326 .61198 .59549 .61615 .59428 .61405 .59204 Mtetra
.61405 .59204 .61615 .59428 .62032 .59307 .61823 .59083 Mtetra
.61823 .59083 .62032 .59307 .6245 .59186 .62241 .58961 Mtetra
.62241 .58961 .6245 .59186 .62869 .59064 .6266 .58839 Mtetra
.6266 .58839 .62869 .59064 .63288 .58942 .63079 .58717 Mtetra
.63079 .58717 .63288 .58942 .63707 .58821 .635 .58595 Mtetra
.635 .58595 .63707 .58821 .64128 .58698 .63921 .58473 Mtetra
.63921 .58473 .64128 .58698 .64549 .58576 .64342 .5835 Mtetra
.64342 .5835 .64549 .58576 .64971 .58454 .64764 .58227 Mtetra
.64764 .58227 .64971 .58454 .65393 .58331 .65187 .58104 Mtetra
.97 .709 .48 r
.65187 .58104 .65393 .58331 .65575 .52046 .65372 .51814 Mtetra
.655 .753 .922 r
.65372 .51814 .65575 .52046 .6599 .51921 .65789 .51689 Mtetra
.65789 .51689 .6599 .51921 .66407 .51795 .66205 .51563 Mtetra
.66205 .51563 .66407 .51795 .66824 .51669 .66623 .51437 Mtetra
.66623 .51437 .66824 .51669 .67241 .51543 .67041 .51311 Mtetra
.67041 .51311 .67241 .51543 .67659 .51417 .67459 .51184 Mtetra
.67459 .51184 .67659 .51417 .68078 .51291 .67879 .51058 Mtetra
.67879 .51058 .68078 .51291 .68498 .51165 .68298 .50931 Mtetra
.68298 .50931 .68498 .51165 .68918 .51038 .68719 .50804 Mtetra
.68719 .50804 .68918 .51038 .69338 .50911 .6914 .50677 Mtetra
.6914 .50677 .69338 .50911 .6976 .50784 .69562 .50549 Mtetra
.69562 .50549 .6976 .50784 .70182 .50657 .69984 .50422 Mtetra
.69984 .50422 .70182 .50657 .70604 .5053 .70407 .50294 Mtetra
.70407 .50294 .70604 .5053 .71027 .50402 .70831 .50166 Mtetra
.70831 .50166 .71027 .50402 .71451 .50274 .71255 .50038 Mtetra
.967 .746 .552 r
.71255 .50038 .71451 .50274 .71758 .48131 .71563 .47893 Mtetra
.656 .751 .919 r
.71563 .47893 .71758 .48131 .72181 .48002 .71986 .47764 Mtetra
.71986 .47764 .72181 .48002 .72604 .47873 .7241 .47634 Mtetra
.7241 .47634 .72604 .47873 .73027 .47744 .72834 .47505 Mtetra
.72834 .47505 .73027 .47744 .73452 .47614 .73258 .47375 Mtetra
.73258 .47375 .73452 .47614 .73876 .47485 .73684 .47245 Mtetra
.73684 .47245 .73876 .47485 .74302 .47355 .7411 .47115 Mtetra
.7411 .47115 .74302 .47355 .74728 .47225 .74537 .46984 Mtetra
.74537 .46984 .74728 .47225 .75155 .47095 .74964 .46854 Mtetra
.74964 .46854 .75155 .47095 .75583 .46964 .75392 .46723 Mtetra
.75392 .46723 .75583 .46964 .76011 .46834 .7582 .46592 Mtetra
.7582 .46592 .76011 .46834 .76439 .46703 .7625 .46461 Mtetra
.979 .698 .42 r
.7625 .46461 .76439 .46703 .7618 .37285 .75995 .37037 Mtetra
.663 .742 .908 r
.75995 .37037 .7618 .37285 .76598 .37151 .76413 .36903 Mtetra
.76413 .36903 .76598 .37151 .77016 .37017 .76832 .36768 Mtetra
.76832 .36768 .77016 .37017 .77434 .36882 .77251 .36633 Mtetra
.77251 .36633 .77434 .36882 .77854 .36747 .7767 .36498 Mtetra
.7767 .36498 .77854 .36747 .78273 .36612 .7809 .36362 Mtetra
.7809 .36362 .78273 .36612 .78694 .36477 .78511 .36227 Mtetra
.78511 .36227 .78694 .36477 .79115 .36342 .78933 .36091 Mtetra
.78933 .36091 .79115 .36342 .79536 .36206 .79355 .35955 Mtetra
.79355 .35955 .79536 .36206 .79959 .3607 .79778 .35819 Mtetra
.79778 .35819 .79959 .3607 .80382 .35934 .80201 .35683 Mtetra
.80201 .35683 .80382 .35934 .80805 .35798 .80625 .35546 Mtetra
.80625 .35546 .80805 .35798 .81229 .35662 .8105 .35409 Mtetra
.8105 .35409 .81229 .35662 .81654 .35525 .81475 .35272 Mtetra
.81475 .35272 .81654 .35525 .8208 .35388 .81901 .35135 Mtetra
.81901 .35135 .8208 .35388 .8246 .34775 .82327 .34998 Mtetra
0 0 0 r
.82327 .34998 .8246 .34775 .82886 .34637 .82709 .34383 Mtetra
.664 .741 .908 r
.82709 .34383 .82886 .34637 .83313 .345 .83136 .34245 Mtetra
.83136 .34245 .83313 .345 .8374 .34362 .83563 .34107 Mtetra
.83563 .34107 .8374 .34362 .84168 .34224 .83992 .33969 Mtetra
.83992 .33969 .84168 .34224 .84597 .34086 .84421 .3383 Mtetra
.84421 .3383 .84597 .34086 .85026 .33948 .8485 .33692 Mtetra
.8485 .33692 .85026 .33948 .85455 .33809 .8528 .33553 Mtetra
.8528 .33553 .85455 .33809 .85886 .3367 .85711 .33414 Mtetra
.85711 .33414 .85886 .3367 .86317 .33531 .86143 .33274 Mtetra
.86143 .33274 .86317 .33531 .86749 .33392 .86575 .33135 Mtetra
.86575 .33135 .86749 .33392 .87181 .33253 .87008 .32995 Mtetra
.87008 .32995 .87181 .33253 .87614 .33113 .87441 .32855 Mtetra
.87441 .32855 .87614 .33113 .88047 .32973 .87875 .32715 Mtetra
.87875 .32715 .88047 .32973 .88482 .32833 .8831 .32574 Mtetra
.8831 .32574 .88482 .32833 .88916 .32693 .88745 .32434 Mtetra
.88745 .32434 .88916 .32693 .89352 .32553 .89181 .32293 Mtetra
.89181 .32293 .89352 .32553 .89788 .32412 .89618 .32152 Mtetra
.3043 .50983 .30657 .51195 .3101 .5108 .30784 .50869 Mtetra
.30784 .50869 .3101 .5108 .31365 .50966 .31139 .50754 Mtetra
.31139 .50754 .31365 .50966 .31719 .50851 .31494 .50639 Mtetra
.31494 .50639 .31719 .50851 .32075 .50737 .31849 .50524 Mtetra
.31849 .50524 .32075 .50737 .3243 .50622 .32205 .50409 Mtetra
.32205 .50409 .3243 .50622 .32787 .50507 .32562 .50294 Mtetra
.32562 .50294 .32787 .50507 .33143 .50391 .32919 .50178 Mtetra
.32919 .50178 .33143 .50391 .33501 .50276 .33276 .50063 Mtetra
.33276 .50063 .33501 .50276 .33858 .50161 .33634 .49947 Mtetra
.33634 .49947 .33858 .50161 .34216 .50045 .33993 .49831 Mtetra
.33993 .49831 .34216 .50045 .34575 .49929 .34351 .49715 Mtetra
.34351 .49715 .34575 .49929 .34934 .49813 .34711 .49599 Mtetra
.34711 .49599 .34934 .49813 .35294 .49697 .35071 .49482 Mtetra
.35071 .49482 .35294 .49697 .35654 .49581 .35431 .49366 Mtetra
.35431 .49366 .35654 .49581 .36014 .49464 .35792 .49249 Mtetra
.35792 .49249 .36014 .49464 .36375 .49348 .36153 .49132 Mtetra
.36153 .49132 .36375 .49348 .36737 .49231 .36515 .49015 Mtetra
.36515 .49015 .36737 .49231 .37099 .49114 .36878 .48898 Mtetra
.36878 .48898 .37099 .49114 .37461 .48997 .3724 .4878 Mtetra
.3724 .4878 .37461 .48997 .37825 .4888 .37604 .48663 Mtetra
.37604 .48663 .37825 .4888 .38188 .48762 .37968 .48545 Mtetra
.37968 .48545 .38188 .48762 .38552 .48645 .38332 .48427 Mtetra
.38332 .48427 .38552 .48645 .38917 .48527 .38697 .48309 Mtetra
.38697 .48309 .38917 .48527 .39282 .48409 .39062 .48191 Mtetra
.39062 .48191 .39282 .48409 .39647 .48291 .39428 .48073 Mtetra
.39428 .48073 .39647 .48291 .40013 .48173 .39794 .47954 Mtetra
.39794 .47954 .40013 .48173 .40379 .48054 .40161 .47835 Mtetra
.40161 .47835 .40379 .48054 .40746 .47936 .40528 .47717 Mtetra
.40528 .47717 .40746 .47936 .41114 .47817 .40896 .47598 Mtetra
.951 .677 .483 r
.40896 .47598 .41114 .47817 .41117 .58651 .40891 .58438 Mtetra
.655 .752 .921 r
.40891 .58438 .41117 .58651 .41497 .58535 .41272 .58322 Mtetra
.41272 .58322 .41497 .58535 .41878 .5842 .41653 .58207 Mtetra
.41653 .58207 .41878 .5842 .4226 .58304 .42035 .58091 Mtetra
.42035 .58091 .4226 .58304 .42642 .58189 .42418 .57975 Mtetra
.42418 .57975 .42642 .58189 .43024 .58073 .42801 .57858 Mtetra
.42801 .57858 .43024 .58073 .43408 .57957 .43184 .57742 Mtetra
.43184 .57742 .43408 .57957 .43791 .57841 .43568 .57626 Mtetra
.43568 .57626 .43791 .57841 .44176 .57724 .43953 .57509 Mtetra
.43953 .57509 .44176 .57724 .4456 .57608 .44338 .57392 Mtetra
.44338 .57392 .4456 .57608 .44946 .57491 .44724 .57275 Mtetra
.44724 .57275 .44946 .57491 .45332 .57374 .4511 .57158 Mtetra
.4511 .57158 .45332 .57374 .45718 .57257 .45497 .57041 Mtetra
.45497 .57041 .45718 .57257 .46105 .5714 .45884 .56923 Mtetra
.45884 .56923 .46105 .5714 .46493 .57022 .46272 .56805 Mtetra
.46272 .56805 .46493 .57022 .46881 .56905 .46661 .56687 Mtetra
.957 .675 .462 r
.46661 .56687 .46881 .56905 .47269 .56787 .46886 .66772 Mtetra
.551 .329 .531 r
.46886 .66772 .47269 .56787 .47513 .66869 .47287 .66658 Mtetra
.646 .762 .934 r
.47287 .66658 .47513 .66869 .47915 .66755 .47689 .66544 Mtetra
.47689 .66544 .47915 .66755 .48317 .66641 .48091 .66429 Mtetra
.48091 .66429 .48317 .66641 .48719 .66526 .48494 .66314 Mtetra
.48494 .66314 .48719 .66526 .49123 .66411 .48898 .66199 Mtetra
.48898 .66199 .49123 .66411 .49526 .66297 .49302 .66084 Mtetra
.49302 .66084 .49526 .66297 .49931 .66182 .49707 .65969 Mtetra
.49707 .65969 .49931 .66182 .50336 .66067 .50112 .65854 Mtetra
.50112 .65854 .50336 .66067 .50741 .65951 .50518 .65738 Mtetra
.50518 .65738 .50741 .65951 .51147 .65836 .50925 .65622 Mtetra
.50925 .65622 .51147 .65836 .51554 .6572 .51332 .65506 Mtetra
.51332 .65506 .51554 .6572 .51962 .65605 .5174 .6539 Mtetra
.958 .702 .506 r
.5174 .6539 .51962 .65605 .52372 .57242 .52156 .57022 Mtetra
.653 .754 .924 r
.52156 .57022 .52372 .57242 .52771 .57123 .52555 .56902 Mtetra
.52555 .56902 .52771 .57123 .53171 .57003 .52955 .56782 Mtetra
.52955 .56782 .53171 .57003 .53571 .56884 .53356 .56662 Mtetra
.53356 .56662 .53571 .56884 .53971 .56764 .53757 .56542 Mtetra
.53757 .56542 .53971 .56764 .54398 .61242 .54158 .56422 Mtetra
.569 .372 .575 r
.54158 .56422 .54398 .61242 .54806 .61124 .5456 .56301 Mtetra
.01 0 .441 r
.5456 .56301 .54806 .61124 .55213 .61005 .54997 .60786 Mtetra
.649 .759 .929 r
.54997 .60786 .55213 .61005 .55622 .60886 .55406 .60667 Mtetra
.55406 .60667 .55622 .60886 .56031 .60767 .55815 .60547 Mtetra
.55815 .60547 .56031 .60767 .56441 .60648 .56225 .60428 Mtetra
.56225 .60428 .56441 .60648 .56851 .60529 .56636 .60308 Mtetra
.56636 .60308 .56851 .60529 .57262 .60409 .57047 .60188 Mtetra
.57047 .60188 .57262 .60409 .57674 .6029 .57459 .60068 Mtetra
.57459 .60068 .57674 .6029 .58086 .6017 .57872 .59948 Mtetra
.57872 .59948 .58086 .6017 .58498 .6005 .58285 .59828 Mtetra
.58285 .59828 .58498 .6005 .58912 .5993 .58699 .59707 Mtetra
.58699 .59707 .58912 .5993 .59326 .59809 .59113 .59586 Mtetra
.59113 .59586 .59326 .59809 .5974 .59689 .59528 .59465 Mtetra
.59528 .59465 .5974 .59689 .60156 .59568 .59944 .59344 Mtetra
.59944 .59344 .60156 .59568 .60571 .59447 .6036 .59223 Mtetra
.6036 .59223 .60571 .59447 .60988 .59326 .60777 .59102 Mtetra
.60777 .59102 .60988 .59326 .61405 .59204 .61194 .5898 Mtetra
.61194 .5898 .61405 .59204 .61823 .59083 .61613 .58858 Mtetra
.61613 .58858 .61823 .59083 .62241 .58961 .62031 .58736 Mtetra
.62031 .58736 .62241 .58961 .6266 .58839 .62451 .58614 Mtetra
.62451 .58614 .6266 .58839 .63079 .58717 .62871 .58491 Mtetra
.62871 .58491 .63079 .58717 .635 .58595 .63291 .58369 Mtetra
.63291 .58369 .635 .58595 .63921 .58473 .63713 .58246 Mtetra
.63713 .58246 .63921 .58473 .64342 .5835 .64134 .58123 Mtetra
.64134 .58123 .64342 .5835 .64764 .58227 .64557 .58 Mtetra
.64557 .58 .64764 .58227 .65187 .58104 .6498 .57877 Mtetra
.6498 .57877 .65187 .58104 .65372 .51814 .65404 .57753 Mtetra
0 0 .371 r
.65404 .57753 .65372 .51814 .65789 .51689 .65586 .51456 Mtetra
.655 .753 .922 r
.65586 .51456 .65789 .51689 .66205 .51563 .66003 .5133 Mtetra
.66003 .5133 .66205 .51563 .66623 .51437 .66421 .51204 Mtetra
.66421 .51204 .66623 .51437 .67041 .51311 .6684 .51077 Mtetra
.6684 .51077 .67041 .51311 .67459 .51184 .67259 .5095 Mtetra
.67259 .5095 .67459 .51184 .67879 .51058 .67678 .50823 Mtetra
.67678 .50823 .67879 .51058 .68298 .50931 .68099 .50696 Mtetra
.68099 .50696 .68298 .50931 .68719 .50804 .68519 .50569 Mtetra
.68519 .50569 .68719 .50804 .6914 .50677 .68941 .50441 Mtetra
.68941 .50441 .6914 .50677 .69562 .50549 .69363 .50314 Mtetra
.69363 .50314 .69562 .50549 .69984 .50422 .69786 .50186 Mtetra
.69786 .50186 .69984 .50422 .70407 .50294 .70209 .50058 Mtetra
.70209 .50058 .70407 .50294 .70831 .50166 .70633 .4993 Mtetra
.70633 .4993 .70831 .50166 .71255 .50038 .71058 .49801 Mtetra
.967 .746 .552 r
.71058 .49801 .71255 .50038 .71563 .47893 .71368 .47654 Mtetra
.656 .751 .919 r
.71368 .47654 .71563 .47893 .71986 .47764 .71791 .47525 Mtetra
.71791 .47525 .71986 .47764 .7241 .47634 .72215 .47395 Mtetra
.72215 .47395 .7241 .47634 .72834 .47505 .7264 .47265 Mtetra
.7264 .47265 .72834 .47505 .73258 .47375 .73065 .47135 Mtetra
.73065 .47135 .73258 .47375 .73684 .47245 .73491 .47004 Mtetra
.73491 .47004 .73684 .47245 .7411 .47115 .73917 .46874 Mtetra
.73917 .46874 .7411 .47115 .74537 .46984 .74344 .46743 Mtetra
.74344 .46743 .74537 .46984 .74964 .46854 .74772 .46612 Mtetra
.74772 .46612 .74964 .46854 .75392 .46723 .752 .46481 Mtetra
.752 .46481 .75392 .46723 .7582 .46592 .75629 .4635 Mtetra
.75629 .4635 .7582 .46592 .7625 .46461 .76059 .46218 Mtetra
.979 .698 .42 r
.76059 .46218 .7625 .46461 .75995 .37037 .7581 .36789 Mtetra
.663 .742 .908 r
.7581 .36789 .75995 .37037 .76413 .36903 .76228 .36654 Mtetra
.76228 .36654 .76413 .36903 .76832 .36768 .76647 .36519 Mtetra
.76647 .36519 .76832 .36768 .77251 .36633 .77066 .36383 Mtetra
.77066 .36383 .77251 .36633 .7767 .36498 .77486 .36248 Mtetra
.77486 .36248 .7767 .36498 .7809 .36362 .77907 .36112 Mtetra
.77907 .36112 .7809 .36362 .78511 .36227 .78328 .35976 Mtetra
.78328 .35976 .78511 .36227 .78933 .36091 .7875 .3584 Mtetra
.7875 .3584 .78933 .36091 .79355 .35955 .79173 .35704 Mtetra
.79173 .35704 .79355 .35955 .79778 .35819 .79596 .35567 Mtetra
.79596 .35567 .79778 .35819 .80201 .35683 .8002 .3543 Mtetra
.8002 .3543 .80201 .35683 .80625 .35546 .80444 .35293 Mtetra
.80444 .35293 .80625 .35546 .8105 .35409 .80869 .35156 Mtetra
.80869 .35156 .8105 .35409 .81475 .35272 .81295 .35019 Mtetra
.81295 .35019 .81475 .35272 .81901 .35135 .81721 .34881 Mtetra
.81721 .34881 .81901 .35135 .82327 .34998 .82148 .34744 Mtetra
.892 .798 .748 r
.82148 .34744 .82327 .34998 .82709 .34383 .8253 .34128 Mtetra
.664 .741 .908 r
.8253 .34128 .82709 .34383 .83136 .34245 .82958 .3399 Mtetra
.82958 .3399 .83136 .34245 .83563 .34107 .83386 .33852 Mtetra
.83386 .33852 .83563 .34107 .83992 .33969 .83815 .33713 Mtetra
.83815 .33713 .83992 .33969 .84421 .3383 .84244 .33574 Mtetra
.84244 .33574 .84421 .3383 .8485 .33692 .84674 .33435 Mtetra
.84674 .33435 .8485 .33692 .8528 .33553 .85105 .33296 Mtetra
.85105 .33296 .8528 .33553 .85711 .33414 .85536 .33156 Mtetra
.85536 .33156 .85711 .33414 .86143 .33274 .85968 .33016 Mtetra
.85968 .33016 .86143 .33274 .86575 .33135 .86401 .32876 Mtetra
.86401 .32876 .86575 .33135 .87008 .32995 .86834 .32736 Mtetra
.86834 .32736 .87008 .32995 .87441 .32855 .87268 .32596 Mtetra
.87268 .32596 .87441 .32855 .87875 .32715 .87702 .32455 Mtetra
.87702 .32455 .87875 .32715 .8831 .32574 .88137 .32315 Mtetra
.88137 .32315 .8831 .32574 .88745 .32434 .88573 .32174 Mtetra
.88573 .32174 .88745 .32434 .89181 .32293 .8901 .32032 Mtetra
.8901 .32032 .89181 .32293 .89618 .32152 .89447 .31891 Mtetra
.30203 .50772 .3043 .50983 .30784 .50869 .30557 .50657 Mtetra
.30557 .50657 .30784 .50869 .31139 .50754 .30912 .50542 Mtetra
.30912 .50542 .31139 .50754 .31494 .50639 .31267 .50427 Mtetra
.31267 .50427 .31494 .50639 .31849 .50524 .31623 .50312 Mtetra
.31623 .50312 .31849 .50524 .32205 .50409 .31979 .50196 Mtetra
.31979 .50196 .32205 .50409 .32562 .50294 .32336 .5008 Mtetra
.32336 .5008 .32562 .50294 .32919 .50178 .32693 .49965 Mtetra
.32693 .49965 .32919 .50178 .33276 .50063 .33051 .49849 Mtetra
.33051 .49849 .33276 .50063 .33634 .49947 .33409 .49733 Mtetra
.33409 .49733 .33634 .49947 .33993 .49831 .33768 .49616 Mtetra
.33768 .49616 .33993 .49831 .34351 .49715 .34127 .495 Mtetra
.34127 .495 .34351 .49715 .34711 .49599 .34487 .49383 Mtetra
.34487 .49383 .34711 .49599 .35071 .49482 .34847 .49267 Mtetra
.34847 .49267 .35071 .49482 .35431 .49366 .35208 .4915 Mtetra
.35208 .4915 .35431 .49366 .35792 .49249 .35569 .49033 Mtetra
.35569 .49033 .35792 .49249 .36153 .49132 .35931 .48916 Mtetra
.35931 .48916 .36153 .49132 .36515 .49015 .36293 .48798 Mtetra
.36293 .48798 .36515 .49015 .36878 .48898 .36656 .48681 Mtetra
.36656 .48681 .36878 .48898 .3724 .4878 .37019 .48563 Mtetra
.37019 .48563 .3724 .4878 .37604 .48663 .37382 .48445 Mtetra
.37382 .48445 .37604 .48663 .37968 .48545 .37746 .48327 Mtetra
.37746 .48327 .37968 .48545 .38332 .48427 .38111 .48209 Mtetra
.38111 .48209 .38332 .48427 .38697 .48309 .38476 .48091 Mtetra
.38476 .48091 .38697 .48309 .39062 .48191 .38842 .47972 Mtetra
.38842 .47972 .39062 .48191 .39428 .48073 .39208 .47854 Mtetra
.39208 .47854 .39428 .48073 .39794 .47954 .39575 .47735 Mtetra
.39575 .47735 .39794 .47954 .40161 .47835 .39942 .47616 Mtetra
.39942 .47616 .40161 .47835 .40528 .47717 .40309 .47497 Mtetra
.40309 .47497 .40528 .47717 .40896 .47598 .40677 .47378 Mtetra
.951 .677 .483 r
.40677 .47378 .40896 .47598 .40891 .58438 .40665 .58224 Mtetra
.655 .752 .921 r
.40665 .58224 .40891 .58438 .41272 .58322 .41046 .58109 Mtetra
.41046 .58109 .41272 .58322 .41653 .58207 .41428 .57993 Mtetra
.41428 .57993 .41653 .58207 .42035 .58091 .4181 .57876 Mtetra
.4181 .57876 .42035 .58091 .42418 .57975 .42193 .5776 Mtetra
.42193 .5776 .42418 .57975 .42801 .57858 .42576 .57644 Mtetra
.42576 .57644 .42801 .57858 .43184 .57742 .4296 .57527 Mtetra
.4296 .57527 .43184 .57742 .43568 .57626 .43345 .5741 Mtetra
.43345 .5741 .43568 .57626 .43953 .57509 .4373 .57293 Mtetra
.4373 .57293 .43953 .57509 .44338 .57392 .44115 .57176 Mtetra
.44115 .57176 .44338 .57392 .44724 .57275 .44501 .57059 Mtetra
.44501 .57059 .44724 .57275 .4511 .57158 .44888 .56941 Mtetra
.44888 .56941 .4511 .57158 .45497 .57041 .45275 .56823 Mtetra
.45275 .56823 .45497 .57041 .45884 .56923 .45663 .56706 Mtetra
.45663 .56706 .45884 .56923 .46272 .56805 .46051 .56588 Mtetra
.46051 .56588 .46272 .56805 .46661 .56687 .4644 .56469 Mtetra
.957 .675 .462 r
.4644 .56469 .46661 .56687 .46886 .66772 .46658 .66561 Mtetra
.646 .762 .934 r
.46658 .66561 .46886 .66772 .47287 .66658 .4706 .66447 Mtetra
.4706 .66447 .47287 .66658 .47689 .66544 .47462 .66332 Mtetra
.47462 .66332 .47689 .66544 .48091 .66429 .47865 .66217 Mtetra
.47865 .66217 .48091 .66429 .48494 .66314 .48268 .66102 Mtetra
.48268 .66102 .48494 .66314 .48898 .66199 .48672 .65987 Mtetra
.48672 .65987 .48898 .66199 .49302 .66084 .49077 .65872 Mtetra
.49077 .65872 .49302 .66084 .49707 .65969 .49482 .65756 Mtetra
.49482 .65756 .49707 .65969 .50112 .65854 .49888 .6564 Mtetra
.49888 .6564 .50112 .65854 .50518 .65738 .50294 .65524 Mtetra
.50294 .65524 .50518 .65738 .50925 .65622 .50701 .65408 Mtetra
.50701 .65408 .50925 .65622 .51332 .65506 .51109 .65292 Mtetra
.51109 .65292 .51332 .65506 .5174 .6539 .51517 .65176 Mtetra
.958 .702 .506 r
.51517 .65176 .5174 .6539 .52156 .57022 .51939 .56801 Mtetra
.653 .754 .924 r
.51939 .56801 .52156 .57022 .52555 .56902 .52339 .56681 Mtetra
.52339 .56681 .52555 .56902 .52955 .56782 .52739 .56561 Mtetra
.52739 .56561 .52955 .56782 .53356 .56662 .5314 .5644 Mtetra
.5314 .5644 .53356 .56662 .53757 .56542 .53541 .5632 Mtetra
.53541 .5632 .53757 .56542 .54158 .56422 .53943 .56199 Mtetra
.53943 .56199 .54158 .56422 .5456 .56301 .54346 .56078 Mtetra
.54346 .56078 .5456 .56301 .54997 .60786 .54749 .55957 Mtetra
.568 .371 .574 r
.54749 .55957 .54997 .60786 .55406 .60667 .55153 .55836 Mtetra
.012 0 .442 r
.55153 .55836 .55406 .60667 .55815 .60547 .55599 .60327 Mtetra
.649 .759 .929 r
.55599 .60327 .55815 .60547 .56225 .60428 .56009 .60207 Mtetra
.56009 .60207 .56225 .60428 .56636 .60308 .5642 .60087 Mtetra
.5642 .60087 .56636 .60308 .57047 .60188 .56832 .59967 Mtetra
.56832 .59967 .57047 .60188 .57459 .60068 .57245 .59846 Mtetra
.57245 .59846 .57459 .60068 .57872 .59948 .57658 .59726 Mtetra
.57658 .59726 .57872 .59948 .58285 .59828 .58071 .59605 Mtetra
.58071 .59605 .58285 .59828 .58699 .59707 .58485 .59484 Mtetra
.58485 .59484 .58699 .59707 .59113 .59586 .589 .59363 Mtetra
.589 .59363 .59113 .59586 .59528 .59465 .59315 .59242 Mtetra
.59315 .59242 .59528 .59465 .59944 .59344 .59732 .5912 Mtetra
.59732 .5912 .59944 .59344 .6036 .59223 .60148 .58999 Mtetra
.60148 .58999 .6036 .59223 .60777 .59102 .60565 .58877 Mtetra
.60565 .58877 .60777 .59102 .61194 .5898 .60983 .58755 Mtetra
.60983 .58755 .61194 .5898 .61613 .58858 .61402 .58633 Mtetra
.61402 .58633 .61613 .58858 .62031 .58736 .61821 .5851 Mtetra
.61821 .5851 .62031 .58736 .62451 .58614 .62241 .58388 Mtetra
.62241 .58388 .62451 .58614 .62871 .58491 .62661 .58265 Mtetra
.62661 .58265 .62871 .58491 .63291 .58369 .63082 .58142 Mtetra
.63082 .58142 .63291 .58369 .63713 .58246 .63504 .58019 Mtetra
.63504 .58019 .63713 .58246 .64134 .58123 .63926 .57896 Mtetra
.63926 .57896 .64134 .58123 .64557 .58 .64349 .57772 Mtetra
.64349 .57772 .64557 .58 .6498 .57877 .64773 .57649 Mtetra
.64773 .57649 .6498 .57877 .65404 .57753 .65197 .57525 Mtetra
.65197 .57525 .65404 .57753 .65586 .51456 .65622 .57401 Mtetra
0 0 .371 r
.65622 .57401 .65586 .51456 .66003 .5133 .65801 .51097 Mtetra
.655 .753 .922 r
.65801 .51097 .66003 .5133 .66421 .51204 .66219 .5097 Mtetra
.66219 .5097 .66421 .51204 .6684 .51077 .66638 .50843 Mtetra
.66638 .50843 .6684 .51077 .67259 .5095 .67057 .50716 Mtetra
.67057 .50716 .67259 .5095 .67678 .50823 .67477 .50589 Mtetra
.67477 .50589 .67678 .50823 .68099 .50696 .67898 .50461 Mtetra
.67898 .50461 .68099 .50696 .68519 .50569 .68319 .50333 Mtetra
.68319 .50333 .68519 .50569 .68941 .50441 .68741 .50206 Mtetra
.68741 .50206 .68941 .50441 .69363 .50314 .69164 .50078 Mtetra
.69164 .50078 .69363 .50314 .69786 .50186 .69587 .49949 Mtetra
.69587 .49949 .69786 .50186 .70209 .50058 .70011 .49821 Mtetra
.70011 .49821 .70209 .50058 .70633 .4993 .70436 .49692 Mtetra
.70436 .49692 .70633 .4993 .71058 .49801 .70861 .49563 Mtetra
.967 .746 .552 r
.70861 .49563 .71058 .49801 .71368 .47654 .71172 .47415 Mtetra
.656 .751 .919 r
.71172 .47415 .71368 .47654 .71791 .47525 .71596 .47285 Mtetra
.71596 .47285 .71791 .47525 .72215 .47395 .7202 .47155 Mtetra
.7202 .47155 .72215 .47395 .7264 .47265 .72445 .47024 Mtetra
.72445 .47024 .7264 .47265 .73065 .47135 .72871 .46894 Mtetra
.72871 .46894 .73065 .47135 .73491 .47004 .73297 .46763 Mtetra
.73297 .46763 .73491 .47004 .73917 .46874 .73724 .46632 Mtetra
.73724 .46632 .73917 .46874 .74344 .46743 .74152 .46501 Mtetra
.74152 .46501 .74344 .46743 .74772 .46612 .7458 .4637 Mtetra
.7458 .4637 .74772 .46612 .752 .46481 .75009 .46239 Mtetra
.75009 .46239 .752 .46481 .75629 .4635 .75438 .46107 Mtetra
.955 .61 .25 r
.75438 .46107 .75629 .4635 .76059 .46218 .76122 .4954 Mtetra
.537 .298 .5 r
.76122 .4954 .76059 .46218 .7581 .36789 .76558 .49409 Mtetra
.552 .331 .534 r
.76558 .49409 .7581 .36789 .76228 .36654 .76994 .49278 Mtetra
.056 0 .433 r
.76994 .49278 .76228 .36654 .76647 .36519 .76462 .36269 Mtetra
.663 .742 .908 r
.76462 .36269 .76647 .36519 .77066 .36383 .76882 .36133 Mtetra
.76882 .36133 .77066 .36383 .77486 .36248 .77302 .35997 Mtetra
.77302 .35997 .77486 .36248 .77907 .36112 .77723 .35861 Mtetra
.77723 .35861 .77907 .36112 .78328 .35976 .78145 .35725 Mtetra
.78145 .35725 .78328 .35976 .7875 .3584 .78567 .35588 Mtetra
.78567 .35588 .7875 .3584 .79173 .35704 .7899 .35451 Mtetra
.7899 .35451 .79173 .35704 .79596 .35567 .79414 .35314 Mtetra
.79414 .35314 .79596 .35567 .8002 .3543 .79838 .35177 Mtetra
.79838 .35177 .8002 .3543 .80444 .35293 .80263 .3504 Mtetra
.80263 .3504 .80444 .35293 .80869 .35156 .80688 .34902 Mtetra
.80688 .34902 .80869 .35156 .81295 .35019 .81115 .34765 Mtetra
.81115 .34765 .81295 .35019 .81721 .34881 .81541 .34627 Mtetra
.81541 .34627 .81721 .34881 .82148 .34744 .81969 .34489 Mtetra
.892 .798 .748 r
.81969 .34489 .82148 .34744 .8253 .34128 .82352 .33873 Mtetra
.664 .741 .908 r
.82352 .33873 .8253 .34128 .82958 .3399 .82779 .33734 Mtetra
.82779 .33734 .82958 .3399 .83386 .33852 .83208 .33595 Mtetra
.83208 .33595 .83386 .33852 .83815 .33713 .83637 .33456 Mtetra
.83637 .33456 .83815 .33713 .84244 .33574 .84067 .33317 Mtetra
.84067 .33317 .84244 .33574 .84674 .33435 .84498 .33178 Mtetra
.84498 .33178 .84674 .33435 .85105 .33296 .84929 .33038 Mtetra
.84929 .33038 .85105 .33296 .85536 .33156 .8536 .32898 Mtetra
.8536 .32898 .85536 .33156 .85968 .33016 .85793 .32758 Mtetra
.85793 .32758 .85968 .33016 .86401 .32876 .86226 .32617 Mtetra
.86226 .32617 .86401 .32876 .86834 .32736 .8666 .32477 Mtetra
.8666 .32477 .86834 .32736 .87268 .32596 .87094 .32336 Mtetra
.87094 .32336 .87268 .32596 .87702 .32455 .87529 .32195 Mtetra
.87529 .32195 .87702 .32455 .88137 .32315 .87965 .32054 Mtetra
.87965 .32054 .88137 .32315 .88573 .32174 .88401 .31913 Mtetra
.88401 .31913 .88573 .32174 .8901 .32032 .88838 .31771 Mtetra
.88838 .31771 .8901 .32032 .89447 .31891 .89275 .31629 Mtetra
.29975 .5056 .30203 .50772 .30557 .50657 .30329 .50445 Mtetra
.30329 .50445 .30557 .50657 .30912 .50542 .30685 .50329 Mtetra
.30685 .50329 .30912 .50542 .31267 .50427 .3104 .50214 Mtetra
.3104 .50214 .31267 .50427 .31623 .50312 .31396 .50098 Mtetra
.31396 .50098 .31623 .50312 .31979 .50196 .31753 .49983 Mtetra
.31753 .49983 .31979 .50196 .32336 .5008 .3211 .49867 Mtetra
.3211 .49867 .32336 .5008 .32693 .49965 .32468 .49751 Mtetra
.32468 .49751 .32693 .49965 .33051 .49849 .32826 .49634 Mtetra
.32826 .49634 .33051 .49849 .33409 .49733 .33184 .49518 Mtetra
.33184 .49518 .33409 .49733 .33768 .49616 .33543 .49401 Mtetra
.33543 .49401 .33768 .49616 .34127 .495 .33903 .49285 Mtetra
.33903 .49285 .34127 .495 .34487 .49383 .34263 .49168 Mtetra
.34263 .49168 .34487 .49383 .34847 .49267 .34623 .49051 Mtetra
.34623 .49051 .34847 .49267 .35208 .4915 .34984 .48934 Mtetra
.34984 .48934 .35208 .4915 .35569 .49033 .35346 .48816 Mtetra
.35346 .48816 .35569 .49033 .35931 .48916 .35708 .48699 Mtetra
.35708 .48699 .35931 .48916 .36293 .48798 .3607 .48581 Mtetra
.3607 .48581 .36293 .48798 .36656 .48681 .36433 .48463 Mtetra
.36433 .48463 .36656 .48681 .37019 .48563 .36796 .48345 Mtetra
.36796 .48345 .37019 .48563 .37382 .48445 .3716 .48227 Mtetra
.3716 .48227 .37382 .48445 .37746 .48327 .37525 .48109 Mtetra
.37525 .48109 .37746 .48327 .38111 .48209 .3789 .47991 Mtetra
.3789 .47991 .38111 .48209 .38476 .48091 .38255 .47872 Mtetra
.38255 .47872 .38476 .48091 .38842 .47972 .38621 .47753 Mtetra
.38621 .47753 .38842 .47972 .39208 .47854 .38988 .47634 Mtetra
.38988 .47634 .39208 .47854 .39575 .47735 .39354 .47515 Mtetra
.39354 .47515 .39575 .47735 .39942 .47616 .39722 .47396 Mtetra
.39722 .47396 .39942 .47616 .40309 .47497 .4009 .47276 Mtetra
.4009 .47276 .40309 .47497 .40677 .47378 .40458 .47157 Mtetra
.951 .677 .483 r
.40458 .47157 .40677 .47378 .40665 .58224 .40439 .5801 Mtetra
.655 .752 .921 r
.40439 .5801 .40665 .58224 .41046 .58109 .4082 .57894 Mtetra
.4082 .57894 .41046 .58109 .41428 .57993 .41202 .57778 Mtetra
.41202 .57778 .41428 .57993 .4181 .57876 .41585 .57661 Mtetra
.41585 .57661 .4181 .57876 .42193 .5776 .41968 .57545 Mtetra
.41968 .57545 .42193 .5776 .42576 .57644 .42351 .57428 Mtetra
.42351 .57428 .42576 .57644 .4296 .57527 .42736 .57311 Mtetra
.42736 .57311 .4296 .57527 .43345 .5741 .4312 .57194 Mtetra
.4312 .57194 .43345 .5741 .4373 .57293 .43506 .57077 Mtetra
.43506 .57077 .4373 .57293 .44115 .57176 .43892 .56959 Mtetra
.43892 .56959 .44115 .57176 .44501 .57059 .44278 .56842 Mtetra
.44278 .56842 .44501 .57059 .44888 .56941 .44665 .56724 Mtetra
.44665 .56724 .44888 .56941 .45275 .56823 .45052 .56606 Mtetra
.45052 .56606 .45275 .56823 .45663 .56706 .45441 .56488 Mtetra
.45441 .56488 .45663 .56706 .46051 .56588 .45829 .56369 Mtetra
.956 .675 .463 r
.45829 .56369 .46051 .56588 .4644 .56469 .46029 .66464 Mtetra
.55 .327 .53 r
.46029 .66464 .4644 .56469 .46658 .66561 .46431 .6635 Mtetra
.646 .762 .934 r
.46431 .6635 .46658 .66561 .4706 .66447 .46832 .66235 Mtetra
.46832 .66235 .4706 .66447 .47462 .66332 .47235 .6612 Mtetra
.47235 .6612 .47462 .66332 .47865 .66217 .47638 .66005 Mtetra
.47638 .66005 .47865 .66217 .48268 .66102 .48042 .65889 Mtetra
.48042 .65889 .48268 .66102 .48672 .65987 .48446 .65774 Mtetra
.48446 .65774 .48672 .65987 .49077 .65872 .48851 .65658 Mtetra
.48851 .65658 .49077 .65872 .49482 .65756 .49257 .65542 Mtetra
.49257 .65542 .49482 .65756 .49888 .6564 .49663 .65426 Mtetra
.49663 .65426 .49888 .6564 .50294 .65524 .5007 .6531 Mtetra
.5007 .6531 .50294 .65524 .50701 .65408 .50477 .65193 Mtetra
.50477 .65193 .50701 .65408 .51109 .65292 .50885 .65077 Mtetra
.50885 .65077 .51109 .65292 .51517 .65176 .51294 .6496 Mtetra
.958 .702 .506 r
.51294 .6496 .51517 .65176 .51939 .56801 .51721 .56579 Mtetra
.653 .754 .924 r
.51721 .56579 .51939 .56801 .52339 .56681 .52121 .56459 Mtetra
.52121 .56459 .52339 .56681 .52739 .56561 .52522 .56338 Mtetra
.52522 .56338 .52739 .56561 .5314 .5644 .52923 .56218 Mtetra
.52923 .56218 .5314 .5644 .53541 .5632 .53325 .56097 Mtetra
.53325 .56097 .53541 .5632 .53943 .56199 .53727 .55976 Mtetra
.53727 .55976 .53943 .56199 .54346 .56078 .5413 .55855 Mtetra
.5413 .55855 .54346 .56078 .54749 .55957 .54534 .55733 Mtetra
.54534 .55733 .54749 .55957 .55153 .55836 .54938 .55612 Mtetra
.54938 .55612 .55153 .55836 .55599 .60327 .55343 .5549 Mtetra
.012 0 .442 r
.55343 .5549 .55599 .60327 .56009 .60207 .55793 .59985 Mtetra
.649 .759 .929 r
.55793 .59985 .56009 .60207 .5642 .60087 .56204 .59865 Mtetra
.56204 .59865 .5642 .60087 .56832 .59967 .56616 .59744 Mtetra
.56616 .59744 .56832 .59967 .57245 .59846 .57029 .59624 Mtetra
.57029 .59624 .57245 .59846 .57658 .59726 .57443 .59503 Mtetra
.57443 .59503 .57658 .59726 .58071 .59605 .57857 .59382 Mtetra
.57857 .59382 .58071 .59605 .58485 .59484 .58271 .5926 Mtetra
.58271 .5926 .58485 .59484 .589 .59363 .58686 .59139 Mtetra
.58686 .59139 .589 .59363 .59315 .59242 .59102 .59017 Mtetra
.59102 .59017 .59315 .59242 .59732 .5912 .59519 .58896 Mtetra
.59519 .58896 .59732 .5912 .60148 .58999 .59936 .58774 Mtetra
.59936 .58774 .60148 .58999 .60565 .58877 .60353 .58651 Mtetra
.60353 .58651 .60565 .58877 .60983 .58755 .60772 .58529 Mtetra
.60772 .58529 .60983 .58755 .61402 .58633 .61191 .58407 Mtetra
.61191 .58407 .61402 .58633 .61821 .5851 .6161 .58284 Mtetra
.6161 .58284 .61821 .5851 .62241 .58388 .62031 .58161 Mtetra
.62031 .58161 .62241 .58388 .62661 .58265 .62451 .58038 Mtetra
.62451 .58038 .62661 .58265 .63082 .58142 .62873 .57915 Mtetra
.62873 .57915 .63082 .58142 .63504 .58019 .63295 .57791 Mtetra
.63295 .57791 .63504 .58019 .63926 .57896 .63718 .57668 Mtetra
.63718 .57668 .63926 .57896 .64349 .57772 .64141 .57544 Mtetra
.64141 .57544 .64349 .57772 .64773 .57649 .64565 .5742 Mtetra
.64565 .5742 .64773 .57649 .65197 .57525 .6499 .57296 Mtetra
.6499 .57296 .65197 .57525 .65622 .57401 .65415 .57171 Mtetra
.971 .709 .477 r
.65415 .57171 .65622 .57401 .65801 .51097 .65598 .50862 Mtetra
.655 .753 .922 r
.65598 .50862 .65801 .51097 .66219 .5097 .66016 .50735 Mtetra
.66016 .50735 .66219 .5097 .66638 .50843 .66436 .50608 Mtetra
.66436 .50608 .66638 .50843 .67057 .50716 .66856 .50481 Mtetra
.66856 .50481 .67057 .50716 .67477 .50589 .67276 .50353 Mtetra
.67276 .50353 .67477 .50589 .67898 .50461 .67697 .50225 Mtetra
.67697 .50225 .67898 .50461 .68319 .50333 .68119 .50097 Mtetra
.68119 .50097 .68319 .50333 .68741 .50206 .68541 .49969 Mtetra
.68541 .49969 .68741 .50206 .69164 .50078 .68964 .49841 Mtetra
.68964 .49841 .69164 .50078 .69587 .49949 .69388 .49712 Mtetra
.69388 .49712 .69587 .49949 .70011 .49821 .69812 .49583 Mtetra
.69812 .49583 .70011 .49821 .70436 .49692 .70237 .49454 Mtetra
.70237 .49454 .70436 .49692 .70861 .49563 .70663 .49325 Mtetra
.967 .746 .552 r
.70663 .49325 .70861 .49563 .71172 .47415 .70976 .47175 Mtetra
.656 .751 .919 r
.70976 .47175 .71172 .47415 .71596 .47285 .714 .47045 Mtetra
.714 .47045 .71596 .47285 .7202 .47155 .71825 .46914 Mtetra
.71825 .46914 .7202 .47155 .72445 .47024 .7225 .46783 Mtetra
.7225 .46783 .72445 .47024 .72871 .46894 .72676 .46653 Mtetra
.72676 .46653 .72871 .46894 .73297 .46763 .73103 .46521 Mtetra
.73103 .46521 .73297 .46763 .73724 .46632 .7353 .4639 Mtetra
.7353 .4639 .73724 .46632 .74152 .46501 .73958 .46259 Mtetra
.73958 .46259 .74152 .46501 .7458 .4637 .74387 .46127 Mtetra
.956 .612 .256 r
.74387 .46127 .7458 .4637 .75009 .46239 .75059 .4956 Mtetra
.537 .297 .5 r
.75059 .4956 .75009 .46239 .75438 .46107 .75493 .49429 Mtetra
.75493 .49429 .75438 .46107 .76122 .4954 .75929 .49298 Mtetra
.653 .754 .924 r
.75929 .49298 .76122 .4954 .76558 .49409 .76365 .49167 Mtetra
.76365 .49167 .76558 .49409 .76994 .49278 .76802 .49035 Mtetra
.76802 .49035 .76994 .49278 .76462 .36269 .77239 .48904 Mtetra
.551 .33 .533 r
.77239 .48904 .76462 .36269 .76882 .36133 .77677 .48772 Mtetra
.77677 .48772 .76882 .36133 .77302 .35997 .78116 .4864 Mtetra
.06 0 .435 r
.78116 .4864 .77302 .35997 .77723 .35861 .77539 .35609 Mtetra
.663 .742 .908 r
.77539 .35609 .77723 .35861 .78145 .35725 .77961 .35472 Mtetra
.77961 .35472 .78145 .35725 .78567 .35588 .78384 .35335 Mtetra
.78384 .35335 .78567 .35588 .7899 .35451 .78807 .35198 Mtetra
.78807 .35198 .7899 .35451 .79414 .35314 .79231 .35061 Mtetra
.79231 .35061 .79414 .35314 .79838 .35177 .79656 .34924 Mtetra
.79656 .34924 .79838 .35177 .80263 .3504 .80081 .34786 Mtetra
.80081 .34786 .80263 .3504 .80688 .34902 .80507 .34648 Mtetra
.80507 .34648 .80688 .34902 .81115 .34765 .80934 .3451 Mtetra
.80934 .3451 .81115 .34765 .81541 .34627 .81361 .34372 Mtetra
.81361 .34372 .81541 .34627 .81969 .34489 .81789 .34233 Mtetra
.892 .798 .748 r
.81789 .34233 .81969 .34489 .82352 .33873 .82172 .33617 Mtetra
.664 .741 .908 r
.82172 .33617 .82352 .33873 .82779 .33734 .82601 .33478 Mtetra
.82601 .33478 .82779 .33734 .83208 .33595 .8303 .33338 Mtetra
.8303 .33338 .83208 .33595 .83637 .33456 .83459 .33199 Mtetra
.83459 .33199 .83637 .33456 .84067 .33317 .8389 .33059 Mtetra
.8389 .33059 .84067 .33317 .84498 .33178 .84321 .32919 Mtetra
.84321 .32919 .84498 .33178 .84929 .33038 .84752 .32779 Mtetra
.84752 .32779 .84929 .33038 .8536 .32898 .85184 .32639 Mtetra
.85184 .32639 .8536 .32898 .85793 .32758 .85617 .32499 Mtetra
.85617 .32499 .85793 .32758 .86226 .32617 .86051 .32358 Mtetra
.86051 .32358 .86226 .32617 .8666 .32477 .86485 .32217 Mtetra
.86485 .32217 .8666 .32477 .87094 .32336 .8692 .32076 Mtetra
.8692 .32076 .87094 .32336 .87529 .32195 .87355 .31934 Mtetra
.87355 .31934 .87529 .32195 .87965 .32054 .87791 .31793 Mtetra
.87791 .31793 .87965 .32054 .88401 .31913 .88228 .31651 Mtetra
.88228 .31651 .88401 .31913 .88838 .31771 .88665 .31509 Mtetra
.88665 .31509 .88838 .31771 .89275 .31629 .89103 .31367 Mtetra
.29746 .50347 .29975 .5056 .30329 .50445 .30101 .50232 Mtetra
.30101 .50232 .30329 .50445 .30685 .50329 .30457 .50116 Mtetra
.30457 .50116 .30685 .50329 .3104 .50214 .30813 .5 Mtetra
.30813 .5 .3104 .50214 .31396 .50098 .31169 .49884 Mtetra
.31169 .49884 .31396 .50098 .31753 .49983 .31526 .49768 Mtetra
.31526 .49768 .31753 .49983 .3211 .49867 .31883 .49652 Mtetra
.31883 .49652 .3211 .49867 .32468 .49751 .32241 .49536 Mtetra
.32241 .49536 .32468 .49751 .32826 .49634 .326 .49419 Mtetra
.326 .49419 .32826 .49634 .33184 .49518 .32958 .49303 Mtetra
.32958 .49303 .33184 .49518 .33543 .49401 .33318 .49186 Mtetra
.33318 .49186 .33543 .49401 .33903 .49285 .33678 .49069 Mtetra
.33678 .49069 .33903 .49285 .34263 .49168 .34038 .48952 Mtetra
.34038 .48952 .34263 .49168 .34623 .49051 .34399 .48834 Mtetra
.34399 .48834 .34623 .49051 .34984 .48934 .3476 .48717 Mtetra
.3476 .48717 .34984 .48934 .35346 .48816 .35122 .48599 Mtetra
.35122 .48599 .35346 .48816 .35708 .48699 .35484 .48482 Mtetra
.35484 .48482 .35708 .48699 .3607 .48581 .35847 .48364 Mtetra
.35847 .48364 .3607 .48581 .36433 .48463 .3621 .48245 Mtetra
.3621 .48245 .36433 .48463 .36796 .48345 .36574 .48127 Mtetra
.36574 .48127 .36796 .48345 .3716 .48227 .36938 .48009 Mtetra
.36938 .48009 .3716 .48227 .37525 .48109 .37303 .4789 Mtetra
.37303 .4789 .37525 .48109 .3789 .47991 .37668 .47771 Mtetra
.37668 .47771 .3789 .47991 .38255 .47872 .38034 .47653 Mtetra
.38034 .47653 .38255 .47872 .38621 .47753 .384 .47533 Mtetra
.384 .47533 .38621 .47753 .38988 .47634 .38767 .47414 Mtetra
.38767 .47414 .38988 .47634 .39354 .47515 .39134 .47295 Mtetra
.39134 .47295 .39354 .47515 .39722 .47396 .39502 .47175 Mtetra
.39502 .47175 .39722 .47396 .4009 .47276 .3987 .47056 Mtetra
.3987 .47056 .4009 .47276 .40458 .47157 .40239 .46936 Mtetra
.951 .677 .483 r
.40239 .46936 .40458 .47157 .40439 .5801 .40211 .57796 Mtetra
.655 .752 .921 r
.40211 .57796 .40439 .5801 .4082 .57894 .40593 .57679 Mtetra
.40593 .57679 .4082 .57894 .41202 .57778 .40976 .57563 Mtetra
.40976 .57563 .41202 .57778 .41585 .57661 .41359 .57446 Mtetra
.41359 .57446 .41585 .57661 .41968 .57545 .41742 .57329 Mtetra
.41742 .57329 .41968 .57545 .42351 .57428 .42126 .57212 Mtetra
.42126 .57212 .42351 .57428 .42736 .57311 .42511 .57095 Mtetra
.42511 .57095 .42736 .57311 .4312 .57194 .42896 .56977 Mtetra
.42896 .56977 .4312 .57194 .43506 .57077 .43281 .5686 Mtetra
.43281 .5686 .43506 .57077 .43892 .56959 .43668 .56742 Mtetra
.43668 .56742 .43892 .56959 .44278 .56842 .44054 .56624 Mtetra
.44054 .56624 .44278 .56842 .44665 .56724 .44442 .56506 Mtetra
.44442 .56506 .44665 .56724 .45052 .56606 .44829 .56388 Mtetra
.44829 .56388 .45052 .56606 .45441 .56488 .45218 .56269 Mtetra
.45218 .56269 .45441 .56488 .45829 .56369 .45607 .5615 Mtetra
.956 .675 .463 r
.45607 .5615 .45829 .56369 .46029 .66464 .458 .66253 Mtetra
.646 .762 .934 r
.458 .66253 .46029 .66464 .46431 .6635 .46202 .66138 Mtetra
.46202 .66138 .46431 .6635 .46832 .66235 .46604 .66022 Mtetra
.46604 .66022 .46832 .66235 .47235 .6612 .47007 .65907 Mtetra
.47007 .65907 .47235 .6612 .47638 .66005 .47411 .65792 Mtetra
.47411 .65792 .47638 .66005 .48042 .65889 .47815 .65676 Mtetra
.47815 .65676 .48042 .65889 .48446 .65774 .4822 .6556 Mtetra
.4822 .6556 .48446 .65774 .48851 .65658 .48625 .65444 Mtetra
.48625 .65444 .48851 .65658 .49257 .65542 .49031 .65328 Mtetra
.49031 .65328 .49257 .65542 .49663 .65426 .49437 .65211 Mtetra
.49437 .65211 .49663 .65426 .5007 .6531 .49845 .65095 Mtetra
.49845 .65095 .5007 .6531 .50477 .65193 .50252 .64978 Mtetra
.50252 .64978 .50477 .65193 .50885 .65077 .50661 .64861 Mtetra
.50661 .64861 .50885 .65077 .51294 .6496 .5107 .64744 Mtetra
.958 .702 .506 r
.5107 .64744 .51294 .6496 .51721 .56579 .51503 .56357 Mtetra
.653 .754 .924 r
.51503 .56357 .51721 .56579 .52121 .56459 .51904 .56236 Mtetra
.51904 .56236 .52121 .56459 .52522 .56338 .52305 .56115 Mtetra
.52305 .56115 .52522 .56338 .52923 .56218 .52706 .55994 Mtetra
.52706 .55994 .52923 .56218 .53325 .56097 .53108 .55873 Mtetra
.53108 .55873 .53325 .56097 .53727 .55976 .53511 .55752 Mtetra
.53511 .55752 .53727 .55976 .5413 .55855 .53915 .5563 Mtetra
.53915 .5563 .5413 .55855 .54534 .55733 .54319 .55509 Mtetra
.54319 .55509 .54534 .55733 .54938 .55612 .54723 .55387 Mtetra
.54723 .55387 .54938 .55612 .55343 .5549 .55128 .55265 Mtetra
.55128 .55265 .55343 .5549 .55793 .59985 .55534 .55142 Mtetra
.568 .37 .574 r
.55534 .55142 .55793 .59985 .56204 .59865 .5594 .5502 Mtetra
.015 0 .444 r
.5594 .5502 .56204 .59865 .56616 .59744 .564 .59521 Mtetra
.649 .759 .929 r
.564 .59521 .56616 .59744 .57029 .59624 .56813 .594 Mtetra
.56813 .594 .57029 .59624 .57443 .59503 .57227 .59279 Mtetra
.57227 .59279 .57443 .59503 .57857 .59382 .57641 .59158 Mtetra
.57641 .59158 .57857 .59382 .58271 .5926 .58056 .59036 Mtetra
.58056 .59036 .58271 .5926 .58686 .59139 .58472 .58914 Mtetra
.58472 .58914 .58686 .59139 .59102 .59017 .58888 .58792 Mtetra
.58888 .58792 .59102 .59017 .59519 .58896 .59305 .5867 Mtetra
.59305 .5867 .59519 .58896 .59936 .58774 .59723 .58548 Mtetra
.59723 .58548 .59936 .58774 .60353 .58651 .60141 .58425 Mtetra
.60141 .58425 .60353 .58651 .60772 .58529 .6056 .58303 Mtetra
.6056 .58303 .60772 .58529 .61191 .58407 .60979 .5818 Mtetra
.60979 .5818 .61191 .58407 .6161 .58284 .61399 .58057 Mtetra
.61399 .58057 .6161 .58284 .62031 .58161 .6182 .57934 Mtetra
.6182 .57934 .62031 .58161 .62451 .58038 .62241 .5781 Mtetra
.62241 .5781 .62451 .58038 .62873 .57915 .62663 .57687 Mtetra
.62663 .57687 .62873 .57915 .63295 .57791 .63085 .57563 Mtetra
.63085 .57563 .63295 .57791 .63718 .57668 .63508 .57439 Mtetra
.63508 .57439 .63718 .57668 .64141 .57544 .63932 .57315 Mtetra
.63932 .57315 .64141 .57544 .64565 .5742 .64357 .5719 Mtetra
.64357 .5719 .64565 .5742 .6499 .57296 .64782 .57066 Mtetra
.64782 .57066 .6499 .57296 .65415 .57171 .65208 .56941 Mtetra
.65208 .56941 .65415 .57171 .65598 .50862 .65634 .56816 Mtetra
0 0 .369 r
.65634 .56816 .65598 .50862 .66016 .50735 .65813 .505 Mtetra
.655 .753 .922 r
.65813 .505 .66016 .50735 .66436 .50608 .66233 .50373 Mtetra
.66233 .50373 .66436 .50608 .66856 .50481 .66653 .50245 Mtetra
.66653 .50245 .66856 .50481 .67276 .50353 .67074 .50117 Mtetra
.67074 .50117 .67276 .50353 .67697 .50225 .67496 .49989 Mtetra
.67496 .49989 .67697 .50225 .68119 .50097 .67918 .4986 Mtetra
.67918 .4986 .68119 .50097 .68541 .49969 .68341 .49732 Mtetra
.68341 .49732 .68541 .49969 .68964 .49841 .68764 .49603 Mtetra
.68764 .49603 .68964 .49841 .69388 .49712 .69188 .49474 Mtetra
.69188 .49474 .69388 .49712 .69812 .49583 .69613 .49345 Mtetra
.968 .65 .341 r
.69613 .49345 .69812 .49583 .70237 .49454 .70367 .5543 Mtetra
.545 .316 .519 r
.70367 .5543 .70237 .49454 .70663 .49325 .70802 .55303 Mtetra
.70802 .55303 .70663 .49325 .70976 .47175 .71237 .55175 Mtetra
.011 0 .401 r
.71237 .55175 .70976 .47175 .714 .47045 .71203 .46803 Mtetra
.656 .751 .919 r
.71203 .46803 .714 .47045 .71825 .46914 .71629 .46673 Mtetra
.71629 .46673 .71825 .46914 .7225 .46783 .72054 .46542 Mtetra
.72054 .46542 .7225 .46783 .72676 .46653 .72481 .4641 Mtetra
.72481 .4641 .72676 .46653 .73103 .46521 .72908 .46279 Mtetra
.72908 .46279 .73103 .46521 .7353 .4639 .73336 .46147 Mtetra
.957 .614 .261 r
.73336 .46147 .7353 .4639 .73958 .46259 .73995 .4958 Mtetra
.536 .297 .499 r
.73995 .4958 .73958 .46259 .74387 .46127 .74429 .49449 Mtetra
.74429 .49449 .74387 .46127 .75059 .4956 .74864 .49318 Mtetra
.653 .754 .924 r
.74864 .49318 .75059 .4956 .75493 .49429 .75299 .49187 Mtetra
.75299 .49187 .75493 .49429 .75929 .49298 .75735 .49056 Mtetra
.75735 .49056 .75929 .49298 .76365 .49167 .76172 .48924 Mtetra
.76172 .48924 .76365 .49167 .76802 .49035 .76609 .48792 Mtetra
.76609 .48792 .76802 .49035 .77239 .48904 .77047 .4866 Mtetra
.77047 .4866 .77239 .48904 .77677 .48772 .77485 .48528 Mtetra
.77485 .48528 .77677 .48772 .78116 .4864 .77924 .48396 Mtetra
.77924 .48396 .78116 .4864 .77539 .35609 .78364 .48263 Mtetra
.551 .33 .533 r
.78364 .48263 .77539 .35609 .77961 .35472 .78805 .48131 Mtetra
.78805 .48131 .77961 .35472 .78384 .35335 .79246 .47998 Mtetra
.064 0 .438 r
.79246 .47998 .78384 .35335 .78807 .35198 .78624 .34945 Mtetra
.663 .742 .908 r
.78624 .34945 .78807 .35198 .79231 .35061 .79048 .34807 Mtetra
.79048 .34807 .79231 .35061 .79656 .34924 .79473 .34669 Mtetra
.79473 .34669 .79656 .34924 .80081 .34786 .79899 .34531 Mtetra
.79899 .34531 .80081 .34786 .80507 .34648 .80325 .34393 Mtetra
.80325 .34393 .80507 .34648 .80934 .3451 .80752 .34254 Mtetra
.80752 .34254 .80934 .3451 .81361 .34372 .8118 .34116 Mtetra
.8118 .34116 .81361 .34372 .81789 .34233 .81608 .33977 Mtetra
.892 .798 .748 r
.81608 .33977 .81789 .34233 .82172 .33617 .81992 .3336 Mtetra
.664 .741 .908 r
.81992 .3336 .82172 .33617 .82601 .33478 .82421 .3322 Mtetra
.82421 .3322 .82601 .33478 .8303 .33338 .82851 .33081 Mtetra
.82851 .33081 .8303 .33338 .83459 .33199 .83281 .32941 Mtetra
.83281 .32941 .83459 .33199 .8389 .33059 .83712 .32801 Mtetra
.83712 .32801 .8389 .33059 .84321 .32919 .84143 .32661 Mtetra
.84143 .32661 .84321 .32919 .84752 .32779 .84575 .3252 Mtetra
.84575 .3252 .84752 .32779 .85184 .32639 .85008 .3238 Mtetra
.85008 .3238 .85184 .32639 .85617 .32499 .85441 .32239 Mtetra
.85441 .32239 .85617 .32499 .86051 .32358 .85875 .32098 Mtetra
.85875 .32098 .86051 .32358 .86485 .32217 .8631 .31956 Mtetra
.8631 .31956 .86485 .32217 .8692 .32076 .86745 .31815 Mtetra
.86745 .31815 .8692 .32076 .87355 .31934 .87181 .31673 Mtetra
.87181 .31673 .87355 .31934 .87791 .31793 .87617 .31531 Mtetra
.87617 .31531 .87791 .31793 .88228 .31651 .88055 .31389 Mtetra
.88055 .31389 .88228 .31651 .88665 .31509 .88493 .31247 Mtetra
.88493 .31247 .88665 .31509 .89103 .31367 .88931 .31104 Mtetra
.29517 .50134 .29746 .50347 .30101 .50232 .29873 .50018 Mtetra
.29873 .50018 .30101 .50232 .30457 .50116 .30228 .49902 Mtetra
.30228 .49902 .30457 .50116 .30813 .5 .30585 .49786 Mtetra
.30585 .49786 .30813 .5 .31169 .49884 .30941 .4967 Mtetra
.30941 .4967 .31169 .49884 .31526 .49768 .31298 .49554 Mtetra
.31298 .49554 .31526 .49768 .31883 .49652 .31656 .49437 Mtetra
.31656 .49437 .31883 .49652 .32241 .49536 .32014 .49321 Mtetra
.32014 .49321 .32241 .49536 .326 .49419 .32373 .49204 Mtetra
.32373 .49204 .326 .49419 .32958 .49303 .32732 .49087 Mtetra
.32732 .49087 .32958 .49303 .33318 .49186 .33092 .4897 Mtetra
.33092 .4897 .33318 .49186 .33678 .49069 .33452 .48852 Mtetra
.33452 .48852 .33678 .49069 .34038 .48952 .33812 .48735 Mtetra
.33812 .48735 .34038 .48952 .34399 .48834 .34174 .48617 Mtetra
.34174 .48617 .34399 .48834 .3476 .48717 .34535 .485 Mtetra
.34535 .485 .3476 .48717 .35122 .48599 .34897 .48382 Mtetra
.34897 .48382 .35122 .48599 .35484 .48482 .3526 .48264 Mtetra
.3526 .48264 .35484 .48482 .35847 .48364 .35623 .48145 Mtetra
.35623 .48145 .35847 .48364 .3621 .48245 .35986 .48027 Mtetra
.35986 .48027 .3621 .48245 .36574 .48127 .3635 .47908 Mtetra
.3635 .47908 .36574 .48127 .36938 .48009 .36715 .4779 Mtetra
.36715 .4779 .36938 .48009 .37303 .4789 .3708 .47671 Mtetra
.3708 .47671 .37303 .4789 .37668 .47771 .37446 .47552 Mtetra
.37446 .47552 .37668 .47771 .38034 .47653 .37812 .47433 Mtetra
.37812 .47433 .38034 .47653 .384 .47533 .38178 .47313 Mtetra
.38178 .47313 .384 .47533 .38767 .47414 .38545 .47194 Mtetra
.38545 .47194 .38767 .47414 .39134 .47295 .38913 .47074 Mtetra
.38913 .47074 .39134 .47295 .39502 .47175 .39281 .46954 Mtetra
.39281 .46954 .39502 .47175 .3987 .47056 .39649 .46834 Mtetra
.95 .68 .491 r
.39649 .46834 .3987 .47056 .40239 .46936 .39412 .62705 Mtetra
.551 .331 .535 r
.39412 .62705 .40239 .46936 .40211 .57796 .39799 .6259 Mtetra
.542 .31 .513 r
.39799 .6259 .40211 .57796 .40593 .57679 .40187 .62475 Mtetra
0 0 .23 r
.40187 .62475 .40593 .57679 .40976 .57563 .40749 .57347 Mtetra
.655 .752 .921 r
.40749 .57347 .40976 .57563 .41359 .57446 .41132 .5723 Mtetra
.41132 .5723 .41359 .57446 .41742 .57329 .41516 .57113 Mtetra
.41516 .57113 .41742 .57329 .42126 .57212 .419 .56995 Mtetra
.419 .56995 .42126 .57212 .42511 .57095 .42285 .56878 Mtetra
.42285 .56878 .42511 .57095 .42896 .56977 .4267 .5676 Mtetra
.4267 .5676 .42896 .56977 .43281 .5686 .43056 .56642 Mtetra
.43056 .56642 .43281 .5686 .43668 .56742 .43443 .56524 Mtetra
.43443 .56524 .43668 .56742 .44054 .56624 .4383 .56406 Mtetra
.4383 .56406 .44054 .56624 .44442 .56506 .44218 .56287 Mtetra
.44218 .56287 .44442 .56506 .44829 .56388 .44606 .56169 Mtetra
.44606 .56169 .44829 .56388 .45218 .56269 .44995 .5605 Mtetra
.956 .675 .465 r
.44995 .5605 .45218 .56269 .45607 .5615 .45169 .66155 Mtetra
.549 .326 .529 r
.45169 .66155 .45607 .5615 .458 .66253 .45571 .6604 Mtetra
.646 .762 .934 r
.45571 .6604 .458 .66253 .46202 .66138 .45973 .65925 Mtetra
.45973 .65925 .46202 .66138 .46604 .66022 .46375 .65809 Mtetra
.46375 .65809 .46604 .66022 .47007 .65907 .46779 .65694 Mtetra
.46779 .65694 .47007 .65907 .47411 .65792 .47183 .65578 Mtetra
.47183 .65578 .47411 .65792 .47815 .65676 .47587 .65462 Mtetra
.47587 .65462 .47815 .65676 .4822 .6556 .47992 .65346 Mtetra
.47992 .65346 .4822 .6556 .48625 .65444 .48398 .65229 Mtetra
.48398 .65229 .48625 .65444 .49031 .65328 .48804 .65113 Mtetra
.48804 .65113 .49031 .65328 .49437 .65211 .49211 .64996 Mtetra
.49211 .64996 .49437 .65211 .49845 .65095 .49619 .64879 Mtetra
.49619 .64879 .49845 .65095 .50252 .64978 .50027 .64762 Mtetra
.50027 .64762 .50252 .64978 .50661 .64861 .50436 .64645 Mtetra
.50436 .64645 .50661 .64861 .5107 .64744 .50845 .64528 Mtetra
.958 .702 .506 r
.50845 .64528 .5107 .64744 .51503 .56357 .51285 .56134 Mtetra
.653 .754 .924 r
.51285 .56134 .51503 .56357 .51904 .56236 .51685 .56013 Mtetra
.51685 .56013 .51904 .56236 .52305 .56115 .52087 .55892 Mtetra
.52087 .55892 .52305 .56115 .52706 .55994 .52489 .55771 Mtetra
.52489 .55771 .52706 .55994 .53108 .55873 .52891 .55649 Mtetra
.52891 .55649 .53108 .55873 .53511 .55752 .53294 .55527 Mtetra
.53294 .55527 .53511 .55752 .53915 .5563 .53698 .55405 Mtetra
.53698 .55405 .53915 .5563 .54319 .55509 .54102 .55283 Mtetra
.54102 .55283 .54319 .55509 .54723 .55387 .54507 .55161 Mtetra
.54507 .55161 .54723 .55387 .55128 .55265 .54913 .55039 Mtetra
.54913 .55039 .55128 .55265 .55534 .55142 .55319 .54916 Mtetra
.55319 .54916 .55534 .55142 .5594 .5502 .55726 .54793 Mtetra
.55726 .54793 .5594 .5502 .564 .59521 .56133 .54671 Mtetra
.567 .37 .573 r
.56133 .54671 .564 .59521 .56813 .594 .56541 .54547 Mtetra
.017 0 .445 r
.56541 .54547 .56813 .594 .57227 .59279 .57011 .59055 Mtetra
.649 .759 .929 r
.57011 .59055 .57227 .59279 .57641 .59158 .57426 .58933 Mtetra
.57426 .58933 .57641 .59158 .58056 .59036 .57841 .58811 Mtetra
.57841 .58811 .58056 .59036 .58472 .58914 .58257 .58689 Mtetra
.58257 .58689 .58472 .58914 .58888 .58792 .58674 .58567 Mtetra
.58674 .58567 .58888 .58792 .59305 .5867 .59091 .58444 Mtetra
.59091 .58444 .59305 .5867 .59723 .58548 .59509 .58322 Mtetra
.59509 .58322 .59723 .58548 .60141 .58425 .59928 .58199 Mtetra
.59928 .58199 .60141 .58425 .6056 .58303 .60347 .58076 Mtetra
.60347 .58076 .6056 .58303 .60979 .5818 .60767 .57953 Mtetra
.60767 .57953 .60979 .5818 .61399 .58057 .61187 .57829 Mtetra
.61187 .57829 .61399 .58057 .6182 .57934 .61608 .57706 Mtetra
.61608 .57706 .6182 .57934 .62241 .5781 .6203 .57582 Mtetra
.6203 .57582 .62241 .5781 .62663 .57687 .62452 .57458 Mtetra
.62452 .57458 .62663 .57687 .63085 .57563 .62875 .57334 Mtetra
.62875 .57334 .63085 .57563 .63508 .57439 .63299 .5721 Mtetra
.63299 .5721 .63508 .57439 .63932 .57315 .63723 .57085 Mtetra
.63723 .57085 .63932 .57315 .64357 .5719 .64148 .5696 Mtetra
.64148 .5696 .64357 .5719 .64782 .57066 .64573 .56836 Mtetra
.64573 .56836 .64782 .57066 .65208 .56941 .65 .56711 Mtetra
.65 .56711 .65208 .56941 .65634 .56816 .65426 .56585 Mtetra
.65426 .56585 .65634 .56816 .65813 .505 .65854 .5646 Mtetra
.545 .316 .519 r
.65854 .5646 .65813 .505 .66233 .50373 .66282 .56334 Mtetra
.66282 .56334 .66233 .50373 .66653 .50245 .66711 .56208 Mtetra
.66711 .56208 .66653 .50245 .67074 .50117 .6714 .56082 Mtetra
.6714 .56082 .67074 .50117 .67496 .49989 .6757 .55956 Mtetra
.6757 .55956 .67496 .49989 .67918 .4986 .68001 .5583 Mtetra
.68001 .5583 .67918 .4986 .68341 .49732 .68433 .55703 Mtetra
.68433 .55703 .68341 .49732 .68764 .49603 .68865 .55576 Mtetra
.68865 .55576 .68764 .49603 .69188 .49474 .69297 .55449 Mtetra
.69297 .55449 .69188 .49474 .69613 .49345 .69731 .55322 Mtetra
.69731 .55322 .69613 .49345 .70367 .5543 .70165 .55195 Mtetra
.649 .759 .929 r
.70165 .55195 .70367 .5543 .70802 .55303 .70599 .55067 Mtetra
.70599 .55067 .70802 .55303 .71237 .55175 .71035 .54939 Mtetra
.71035 .54939 .71237 .55175 .71203 .46803 .71471 .54812 Mtetra
.011 0 .401 r
.71471 .54812 .71203 .46803 .71629 .46673 .71432 .46431 Mtetra
.656 .751 .919 r
.71432 .46431 .71629 .46673 .72054 .46542 .71858 .46299 Mtetra
.71858 .46299 .72054 .46542 .72481 .4641 .72285 .46168 Mtetra
.957 .615 .267 r
.72285 .46168 .72481 .4641 .72908 .46279 .72932 .496 Mtetra
.536 .296 .499 r
.72932 .496 .72908 .46279 .73336 .46147 .73365 .49469 Mtetra
.73365 .49469 .73336 .46147 .73995 .4958 .73799 .49338 Mtetra
.653 .754 .924 r
.73799 .49338 .73995 .4958 .74429 .49449 .74234 .49207 Mtetra
.74234 .49207 .74429 .49449 .74864 .49318 .74669 .49076 Mtetra
.74669 .49076 .74864 .49318 .75299 .49187 .75104 .48944 Mtetra
.75104 .48944 .75299 .49187 .75735 .49056 .75541 .48813 Mtetra
.75541 .48813 .75735 .49056 .76172 .48924 .75978 .48681 Mtetra
.75978 .48681 .76172 .48924 .76609 .48792 .76415 .48549 Mtetra
.76415 .48549 .76609 .48792 .77047 .4866 .76854 .48416 Mtetra
.76854 .48416 .77047 .4866 .77485 .48528 .77293 .48284 Mtetra
.77293 .48284 .77485 .48528 .77924 .48396 .77732 .48151 Mtetra
.77732 .48151 .77924 .48396 .78364 .48263 .78173 .48018 Mtetra
.78173 .48018 .78364 .48263 .78805 .48131 .78614 .47885 Mtetra
.78614 .47885 .78805 .48131 .79246 .47998 .79056 .47752 Mtetra
.79056 .47752 .79246 .47998 .78624 .34945 .79498 .47618 Mtetra
.55 .329 .532 r
.79498 .47618 .78624 .34945 .79048 .34807 .79941 .47485 Mtetra
.79941 .47485 .79048 .34807 .79473 .34669 .80385 .47351 Mtetra
.80385 .47351 .79473 .34669 .79899 .34531 .80829 .47216 Mtetra
.07 0 .441 r
.80829 .47216 .79899 .34531 .80325 .34393 .80143 .34137 Mtetra
.663 .742 .908 r
.80143 .34137 .80325 .34393 .80752 .34254 .8057 .33998 Mtetra
.8057 .33998 .80752 .34254 .8118 .34116 .80999 .33859 Mtetra
.80999 .33859 .8118 .34116 .81608 .33977 .81427 .3372 Mtetra
.892 .798 .748 r
.81427 .3372 .81608 .33977 .81992 .3336 .81812 .33102 Mtetra
.664 .741 .908 r
.81812 .33102 .81992 .3336 .82421 .3322 .82241 .32963 Mtetra
.82241 .32963 .82421 .3322 .82851 .33081 .82671 .32823 Mtetra
.82671 .32823 .82851 .33081 .83281 .32941 .83102 .32682 Mtetra
.83102 .32682 .83281 .32941 .83712 .32801 .83533 .32542 Mtetra
.83533 .32542 .83712 .32801 .84143 .32661 .83965 .32401 Mtetra
.83965 .32401 .84143 .32661 .84575 .3252 .84398 .3226 Mtetra
.84398 .3226 .84575 .3252 .85008 .3238 .84831 .32119 Mtetra
.84831 .32119 .85008 .3238 .85441 .32239 .85265 .31978 Mtetra
.85265 .31978 .85441 .32239 .85875 .32098 .85699 .31836 Mtetra
.85699 .31836 .85875 .32098 .8631 .31956 .86134 .31695 Mtetra
.86134 .31695 .8631 .31956 .86745 .31815 .8657 .31553 Mtetra
.8657 .31553 .86745 .31815 .87181 .31673 .87006 .31411 Mtetra
.87006 .31411 .87181 .31673 .87617 .31531 .87443 .31268 Mtetra
.87443 .31268 .87617 .31531 .88055 .31389 .87881 .31126 Mtetra
.87881 .31126 .88055 .31389 .88493 .31247 .88319 .30983 Mtetra
.88319 .30983 .88493 .31247 .88931 .31104 .88758 .3084 Mtetra
.29288 .4992 .29517 .50134 .29873 .50018 .29643 .49804 Mtetra
.29643 .49804 .29873 .50018 .30228 .49902 .29999 .49688 Mtetra
.29999 .49688 .30228 .49902 .30585 .49786 .30356 .49572 Mtetra
.30356 .49572 .30585 .49786 .30941 .4967 .30713 .49455 Mtetra
.30713 .49455 .30941 .4967 .31298 .49554 .3107 .49339 Mtetra
.3107 .49339 .31298 .49554 .31656 .49437 .31428 .49222 Mtetra
.31428 .49222 .31656 .49437 .32014 .49321 .31787 .49105 Mtetra
.31787 .49105 .32014 .49321 .32373 .49204 .32146 .48988 Mtetra
.32146 .48988 .32373 .49204 .32732 .49087 .32505 .48871 Mtetra
.32505 .48871 .32732 .49087 .33092 .4897 .32865 .48753 Mtetra
.32865 .48753 .33092 .4897 .33452 .48852 .33225 .48636 Mtetra
.33225 .48636 .33452 .48852 .33812 .48735 .33586 .48518 Mtetra
.33586 .48518 .33812 .48735 .34174 .48617 .33948 .484 Mtetra
.33948 .484 .34174 .48617 .34535 .485 .3431 .48282 Mtetra
.3431 .48282 .34535 .485 .34897 .48382 .34672 .48164 Mtetra
.34672 .48164 .34897 .48382 .3526 .48264 .35035 .48045 Mtetra
.35035 .48045 .3526 .48264 .35623 .48145 .35398 .47927 Mtetra
.35398 .47927 .35623 .48145 .35986 .48027 .35762 .47808 Mtetra
.35762 .47808 .35986 .48027 .3635 .47908 .36126 .47689 Mtetra
.36126 .47689 .3635 .47908 .36715 .4779 .36491 .4757 Mtetra
.36491 .4757 .36715 .4779 .3708 .47671 .36857 .47451 Mtetra
.36857 .47451 .3708 .47671 .37446 .47552 .37223 .47332 Mtetra
.37223 .47332 .37446 .47552 .37812 .47433 .37589 .47212 Mtetra
.37589 .47212 .37812 .47433 .38178 .47313 .37956 .47092 Mtetra
.37956 .47092 .38178 .47313 .38545 .47194 .38323 .46973 Mtetra
.38323 .46973 .38545 .47194 .38913 .47074 .38691 .46853 Mtetra
.38691 .46853 .38913 .47074 .39281 .46954 .39059 .46732 Mtetra
.949 .68 .492 r
.39059 .46732 .39281 .46954 .39649 .46834 .38793 .62608 Mtetra
.551 .331 .534 r
.38793 .62608 .39649 .46834 .39412 .62705 .3918 .62493 Mtetra
.651 .757 .927 r
.3918 .62493 .39412 .62705 .39799 .6259 .39567 .62378 Mtetra
.39567 .62378 .39799 .6259 .40187 .62475 .39955 .62263 Mtetra
.39955 .62263 .40187 .62475 .40749 .57347 .40344 .62148 Mtetra
.542 .31 .513 r
.40344 .62148 .40749 .57347 .41132 .5723 .40733 .62032 Mtetra
0 0 .232 r
.40733 .62032 .41132 .5723 .41516 .57113 .41289 .56896 Mtetra
.655 .752 .921 r
.41289 .56896 .41516 .57113 .419 .56995 .41673 .56778 Mtetra
.41673 .56778 .419 .56995 .42285 .56878 .42059 .5666 Mtetra
.42059 .5666 .42285 .56878 .4267 .5676 .42444 .56542 Mtetra
.42444 .56542 .4267 .5676 .43056 .56642 .42831 .56424 Mtetra
.42831 .56424 .43056 .56642 .43443 .56524 .43218 .56306 Mtetra
.43218 .56306 .43443 .56524 .4383 .56406 .43605 .56187 Mtetra
.43605 .56187 .4383 .56406 .44218 .56287 .43993 .56068 Mtetra
.43993 .56068 .44218 .56287 .44606 .56169 .44382 .55949 Mtetra
.44382 .55949 .44606 .56169 .44995 .5605 .44771 .5583 Mtetra
.956 .675 .465 r
.44771 .5583 .44995 .5605 .45169 .66155 .44939 .65943 Mtetra
.646 .762 .934 r
.44939 .65943 .45169 .66155 .45571 .6604 .4534 .65827 Mtetra
.4534 .65827 .45571 .6604 .45973 .65925 .45743 .65711 Mtetra
.45743 .65711 .45973 .65925 .46375 .65809 .46146 .65596 Mtetra
.46146 .65596 .46375 .65809 .46779 .65694 .4655 .6548 Mtetra
.4655 .6548 .46779 .65694 .47183 .65578 .46954 .65364 Mtetra
.46954 .65364 .47183 .65578 .47587 .65462 .47359 .65247 Mtetra
.47359 .65247 .47587 .65462 .47992 .65346 .47764 .65131 Mtetra
.47764 .65131 .47992 .65346 .48398 .65229 .48171 .65014 Mtetra
.48171 .65014 .48398 .65229 .48804 .65113 .48577 .64897 Mtetra
.48577 .64897 .48804 .65113 .49211 .64996 .48985 .6478 Mtetra
.48985 .6478 .49211 .64996 .49619 .64879 .49393 .64663 Mtetra
.49393 .64663 .49619 .64879 .50027 .64762 .49801 .64546 Mtetra
.49801 .64546 .50027 .64762 .50436 .64645 .5021 .64428 Mtetra
.5021 .64428 .50436 .64645 .50845 .64528 .5062 .6431 Mtetra
.958 .702 .506 r
.5062 .6431 .50845 .64528 .51285 .56134 .51065 .5591 Mtetra
.653 .754 .924 r
.51065 .5591 .51285 .56134 .51685 .56013 .51466 .55789 Mtetra
.51466 .55789 .51685 .56013 .52087 .55892 .51868 .55668 Mtetra
.51868 .55668 .52087 .55892 .52489 .55771 .5227 .55546 Mtetra
.5227 .55546 .52489 .55771 .52891 .55649 .52673 .55424 Mtetra
.52673 .55424 .52891 .55649 .53294 .55527 .53077 .55302 Mtetra
.53077 .55302 .53294 .55527 .53698 .55405 .53481 .5518 Mtetra
.53481 .5518 .53698 .55405 .54102 .55283 .53886 .55058 Mtetra
.53886 .55058 .54102 .55283 .54507 .55161 .54291 .54935 Mtetra
.54291 .54935 .54507 .55161 .54913 .55039 .54697 .54812 Mtetra
.54697 .54812 .54913 .55039 .55319 .54916 .55104 .54689 Mtetra
.55104 .54689 .55319 .54916 .55726 .54793 .55511 .54566 Mtetra
.55511 .54566 .55726 .54793 .56133 .54671 .55918 .54443 Mtetra
.55918 .54443 .56133 .54671 .56541 .54547 .56327 .5432 Mtetra
.56327 .5432 .56541 .54547 .57011 .59055 .56736 .54196 Mtetra
.017 0 .445 r
.56736 .54196 .57011 .59055 .57426 .58933 .57209 .58708 Mtetra
.649 .759 .929 r
.57209 .58708 .57426 .58933 .57841 .58811 .57625 .58586 Mtetra
.57625 .58586 .57841 .58811 .58257 .58689 .58042 .58463 Mtetra
.58042 .58463 .58257 .58689 .58674 .58567 .58459 .58341 Mtetra
.58459 .58341 .58674 .58567 .59091 .58444 .58876 .58218 Mtetra
.58876 .58218 .59091 .58444 .59509 .58322 .59295 .58095 Mtetra
.59295 .58095 .59509 .58322 .59928 .58199 .59714 .57972 Mtetra
.59714 .57972 .59928 .58199 .60347 .58076 .60133 .57848 Mtetra
.60133 .57848 .60347 .58076 .60767 .57953 .60554 .57725 Mtetra
.60554 .57725 .60767 .57953 .61187 .57829 .60974 .57601 Mtetra
.60974 .57601 .61187 .57829 .61608 .57706 .61396 .57477 Mtetra
.61396 .57477 .61608 .57706 .6203 .57582 .61818 .57353 Mtetra
.61818 .57353 .6203 .57582 .62452 .57458 .62241 .57229 Mtetra
.62241 .57229 .62452 .57458 .62875 .57334 .62664 .57104 Mtetra
.62664 .57104 .62875 .57334 .63299 .5721 .63088 .5698 Mtetra
.63088 .5698 .63299 .5721 .63723 .57085 .63513 .56855 Mtetra
.63513 .56855 .63723 .57085 .64148 .5696 .63938 .5673 Mtetra
.63938 .5673 .64148 .5696 .64573 .56836 .64364 .56605 Mtetra
.64364 .56605 .64573 .56836 .65 .56711 .64791 .56479 Mtetra
.64791 .56479 .65 .56711 .65426 .56585 .65218 .56354 Mtetra
.65218 .56354 .65426 .56585 .65854 .5646 .65646 .56228 Mtetra
.65646 .56228 .65854 .5646 .66282 .56334 .66075 .56102 Mtetra
.66075 .56102 .66282 .56334 .66711 .56208 .66504 .55976 Mtetra
.66504 .55976 .66711 .56208 .6714 .56082 .66934 .55849 Mtetra
.66934 .55849 .6714 .56082 .6757 .55956 .67364 .55723 Mtetra
.67364 .55723 .6757 .55956 .68001 .5583 .67796 .55596 Mtetra
.67796 .55596 .68001 .5583 .68433 .55703 .68227 .55469 Mtetra
.68227 .55469 .68433 .55703 .68865 .55576 .6866 .55342 Mtetra
.6866 .55342 .68865 .55576 .69297 .55449 .69093 .55214 Mtetra
.69093 .55214 .69297 .55449 .69731 .55322 .69527 .55087 Mtetra
.69527 .55087 .69731 .55322 .70165 .55195 .69961 .54959 Mtetra
.69961 .54959 .70165 .55195 .70599 .55067 .70397 .54831 Mtetra
.70397 .54831 .70599 .55067 .71035 .54939 .70833 .54703 Mtetra
.70833 .54703 .71035 .54939 .71471 .54812 .71269 .54575 Mtetra
.71269 .54575 .71471 .54812 .71432 .46431 .71706 .54446 Mtetra
.294 .132 .483 r
.71706 .54446 .71432 .46431 .71858 .46299 .7187 .4962 Mtetra
.535 .295 .498 r
.7187 .4962 .71858 .46299 .72285 .46168 .72302 .49489 Mtetra
.72302 .49489 .72285 .46168 .72932 .496 .72735 .49358 Mtetra
.653 .754 .924 r
.72735 .49358 .72932 .496 .73365 .49469 .73168 .49227 Mtetra
.73168 .49227 .73365 .49469 .73799 .49338 .73602 .49096 Mtetra
.73602 .49096 .73799 .49338 .74234 .49207 .74037 .48965 Mtetra
.74037 .48965 .74234 .49207 .74669 .49076 .74473 .48833 Mtetra
.74473 .48833 .74669 .49076 .75104 .48944 .74909 .48701 Mtetra
.74909 .48701 .75104 .48944 .75541 .48813 .75346 .48569 Mtetra
.75346 .48569 .75541 .48813 .75978 .48681 .75783 .48437 Mtetra
.75783 .48437 .75978 .48681 .76415 .48549 .76221 .48304 Mtetra
.76221 .48304 .76415 .48549 .76854 .48416 .7666 .48172 Mtetra
.7666 .48172 .76854 .48416 .77293 .48284 .771 .48039 Mtetra
.771 .48039 .77293 .48284 .77732 .48151 .7754 .47906 Mtetra
.7754 .47906 .77732 .48151 .78173 .48018 .77981 .47772 Mtetra
.77981 .47772 .78173 .48018 .78614 .47885 .78422 .47639 Mtetra
.78422 .47639 .78614 .47885 .79056 .47752 .78865 .47505 Mtetra
.78865 .47505 .79056 .47752 .79498 .47618 .79307 .47371 Mtetra
.79307 .47371 .79498 .47618 .79941 .47485 .79751 .47237 Mtetra
.79751 .47237 .79941 .47485 .80385 .47351 .80195 .47103 Mtetra
.80195 .47103 .80385 .47351 .80829 .47216 .8064 .46968 Mtetra
.8064 .46968 .80829 .47216 .80143 .34137 .81086 .46833 Mtetra
.55 .328 .532 r
.81086 .46833 .80143 .34137 .8057 .33998 .81532 .46699 Mtetra
.81532 .46699 .8057 .33998 .80999 .33859 .81979 .46563 Mtetra
.051 0 .437 r
.81979 .46563 .80999 .33859 .81427 .3372 .81202 .32984 Mtetra
.623 .52 .717 r
.81202 .32984 .81427 .3372 .81812 .33102 .81631 .32844 Mtetra
.664 .741 .908 r
.81631 .32844 .81812 .33102 .82241 .32963 .82061 .32704 Mtetra
.82061 .32704 .82241 .32963 .82671 .32823 .82492 .32563 Mtetra
.82492 .32563 .82671 .32823 .83102 .32682 .82923 .32423 Mtetra
.82923 .32423 .83102 .32682 .83533 .32542 .83354 .32282 Mtetra
.83354 .32282 .83533 .32542 .83965 .32401 .83787 .32141 Mtetra
.83787 .32141 .83965 .32401 .84398 .3226 .8422 .32 Mtetra
.8422 .32 .84398 .3226 .84831 .32119 .84653 .31858 Mtetra
.84653 .31858 .84831 .32119 .85265 .31978 .85087 .31717 Mtetra
.85087 .31717 .85265 .31978 .85699 .31836 .85522 .31575 Mtetra
.85522 .31575 .85699 .31836 .86134 .31695 .85958 .31433 Mtetra
.85958 .31433 .86134 .31695 .8657 .31553 .86394 .3129 Mtetra
.86394 .3129 .8657 .31553 .87006 .31411 .86831 .31148 Mtetra
.86831 .31148 .87006 .31411 .87443 .31268 .87268 .31005 Mtetra
.87268 .31005 .87443 .31268 .87881 .31126 .87707 .30862 Mtetra
.87707 .30862 .87881 .31126 .88319 .30983 .88145 .30719 Mtetra
.88145 .30719 .88319 .30983 .88758 .3084 .88585 .30576 Mtetra
.29058 .49706 .29288 .4992 .29643 .49804 .29414 .4959 Mtetra
.29414 .4959 .29643 .49804 .29999 .49688 .2977 .49473 Mtetra
.2977 .49473 .29999 .49688 .30356 .49572 .30127 .49357 Mtetra
.30127 .49357 .30356 .49572 .30713 .49455 .30484 .4924 Mtetra
.30484 .4924 .30713 .49455 .3107 .49339 .30842 .49123 Mtetra
.30842 .49123 .3107 .49339 .31428 .49222 .312 .49006 Mtetra
.312 .49006 .31428 .49222 .31787 .49105 .31559 .48889 Mtetra
.31559 .48889 .31787 .49105 .32146 .48988 .31918 .48771 Mtetra
.31918 .48771 .32146 .48988 .32505 .48871 .32278 .48654 Mtetra
.32278 .48654 .32505 .48871 .32865 .48753 .32638 .48536 Mtetra
.32638 .48536 .32865 .48753 .33225 .48636 .32999 .48418 Mtetra
.32999 .48418 .33225 .48636 .33586 .48518 .3336 .483 Mtetra
.3336 .483 .33586 .48518 .33948 .484 .33721 .48182 Mtetra
.33721 .48182 .33948 .484 .3431 .48282 .34084 .48063 Mtetra
.34084 .48063 .3431 .48282 .34672 .48164 .34446 .47945 Mtetra
.34446 .47945 .34672 .48164 .35035 .48045 .3481 .47826 Mtetra
.3481 .47826 .35035 .48045 .35398 .47927 .35173 .47707 Mtetra
.35173 .47707 .35398 .47927 .35762 .47808 .35537 .47588 Mtetra
.35537 .47588 .35762 .47808 .36126 .47689 .35902 .47469 Mtetra
.35902 .47469 .36126 .47689 .36491 .4757 .36267 .4735 Mtetra
.36267 .4735 .36491 .4757 .36857 .47451 .36633 .4723 Mtetra
.36633 .4723 .36857 .47451 .37223 .47332 .36999 .47111 Mtetra
.36999 .47111 .37223 .47332 .37589 .47212 .37366 .46991 Mtetra
.37366 .46991 .37589 .47212 .37956 .47092 .37733 .46871 Mtetra
.37733 .46871 .37956 .47092 .38323 .46973 .381 .46751 Mtetra
.381 .46751 .38323 .46973 .38691 .46853 .38469 .46631 Mtetra
.949 .68 .493 r
.38469 .46631 .38691 .46853 .39059 .46732 .38173 .62511 Mtetra
.55 .33 .534 r
.38173 .62511 .39059 .46732 .38793 .62608 .3856 .62396 Mtetra
.651 .757 .927 r
.3856 .62396 .38793 .62608 .3918 .62493 .38947 .62281 Mtetra
.38947 .62281 .3918 .62493 .39567 .62378 .39335 .62165 Mtetra
.39335 .62165 .39567 .62378 .39955 .62263 .39723 .6205 Mtetra
.39723 .6205 .39955 .62263 .40344 .62148 .40112 .61934 Mtetra
.40112 .61934 .40344 .62148 .40733 .62032 .40502 .61818 Mtetra
.40502 .61818 .40733 .62032 .41289 .56896 .40892 .61702 Mtetra
.541 .309 .512 r
.40892 .61702 .41289 .56896 .41673 .56778 .41282 .61586 Mtetra
0 0 .235 r
.41282 .61586 .41673 .56778 .42059 .5666 .41832 .56442 Mtetra
.655 .752 .921 r
.41832 .56442 .42059 .5666 .42444 .56542 .42218 .56324 Mtetra
.42218 .56324 .42444 .56542 .42831 .56424 .42604 .56205 Mtetra
.42604 .56205 .42831 .56424 .43218 .56306 .42992 .56087 Mtetra
.42992 .56087 .43218 .56306 .43605 .56187 .4338 .55968 Mtetra
.4338 .55968 .43605 .56187 .43993 .56068 .43768 .55849 Mtetra
.43768 .55849 .43993 .56068 .44382 .55949 .44157 .55729 Mtetra
.44157 .55729 .44382 .55949 .44771 .5583 .44546 .5561 Mtetra
.956 .675 .465 r
.44546 .5561 .44771 .5583 .44939 .65943 .44707 .65729 Mtetra
.646 .762 .934 r
.44707 .65729 .44939 .65943 .4534 .65827 .4511 .65613 Mtetra
.4511 .65613 .4534 .65827 .45743 .65711 .45513 .65498 Mtetra
.45513 .65498 .45743 .65711 .46146 .65596 .45916 .65381 Mtetra
.45916 .65381 .46146 .65596 .4655 .6548 .4632 .65265 Mtetra
.4632 .65265 .4655 .6548 .46954 .65364 .46725 .65149 Mtetra
.46725 .65149 .46954 .65364 .47359 .65247 .4713 .65032 Mtetra
.4713 .65032 .47359 .65247 .47764 .65131 .47536 .64915 Mtetra
.47536 .64915 .47764 .65131 .48171 .65014 .47942 .64798 Mtetra
.47942 .64798 .48171 .65014 .48577 .64897 .4835 .64681 Mtetra
.4835 .64681 .48577 .64897 .48985 .6478 .48757 .64564 Mtetra
.48757 .64564 .48985 .6478 .49393 .64663 .49166 .64446 Mtetra
.49166 .64446 .49393 .64663 .49801 .64546 .49574 .64329 Mtetra
.49574 .64329 .49801 .64546 .5021 .64428 .49984 .64211 Mtetra
.958 .702 .507 r
.49984 .64211 .5021 .64428 .5062 .6431 .50444 .55808 Mtetra
.561 .356 .56 r
.50444 .55808 .5062 .6431 .51065 .5591 .50845 .55686 Mtetra
.653 .754 .924 r
.50845 .55686 .51065 .5591 .51466 .55789 .51247 .55565 Mtetra
.51247 .55565 .51466 .55789 .51868 .55668 .51649 .55443 Mtetra
.51649 .55443 .51868 .55668 .5227 .55546 .52052 .55321 Mtetra
.52052 .55321 .5227 .55546 .52673 .55424 .52455 .55199 Mtetra
.52455 .55199 .52673 .55424 .53077 .55302 .52859 .55076 Mtetra
.52859 .55076 .53077 .55302 .53481 .5518 .53263 .54954 Mtetra
.53263 .54954 .53481 .5518 .53886 .55058 .53669 .54831 Mtetra
.53669 .54831 .53886 .55058 .54291 .54935 .54074 .54708 Mtetra
.54074 .54708 .54291 .54935 .54697 .54812 .54481 .54585 Mtetra
.54481 .54585 .54697 .54812 .55104 .54689 .54888 .54462 Mtetra
.54888 .54462 .55104 .54689 .55511 .54566 .55295 .54339 Mtetra
.55295 .54339 .55511 .54566 .55918 .54443 .55703 .54215 Mtetra
.55703 .54215 .55918 .54443 .56327 .5432 .56112 .54091 Mtetra
.56112 .54091 .56327 .5432 .56736 .54196 .56521 .53967 Mtetra
.56521 .53967 .56736 .54196 .57209 .58708 .56931 .53843 Mtetra
.566 .369 .573 r
.56931 .53843 .57209 .58708 .57625 .58586 .57342 .53719 Mtetra
.02 0 .446 r
.57342 .53719 .57625 .58586 .58042 .58463 .57826 .58237 Mtetra
.649 .759 .929 r
.57826 .58237 .58042 .58463 .58459 .58341 .58243 .58114 Mtetra
.58243 .58114 .58459 .58341 .58876 .58218 .58661 .57991 Mtetra
.58661 .57991 .58876 .58218 .59295 .58095 .5908 .57867 Mtetra
.5908 .57867 .59295 .58095 .59714 .57972 .59499 .57744 Mtetra
.59499 .57744 .59714 .57972 .60133 .57848 .59919 .5762 Mtetra
.59919 .5762 .60133 .57848 .60554 .57725 .6034 .57496 Mtetra
.6034 .57496 .60554 .57725 .60974 .57601 .60761 .57372 Mtetra
.60761 .57372 .60974 .57601 .61396 .57477 .61183 .57248 Mtetra
.61183 .57248 .61396 .57477 .61818 .57353 .61606 .57123 Mtetra
.61606 .57123 .61818 .57353 .62241 .57229 .62029 .56999 Mtetra
.62029 .56999 .62241 .57229 .62664 .57104 .62453 .56874 Mtetra
.62453 .56874 .62664 .57104 .63088 .5698 .62877 .56749 Mtetra
.62877 .56749 .63088 .5698 .63513 .56855 .63302 .56624 Mtetra
.63302 .56624 .63513 .56855 .63938 .5673 .63728 .56498 Mtetra
.63728 .56498 .63938 .5673 .64364 .56605 .64155 .56373 Mtetra
.64155 .56373 .64364 .56605 .64791 .56479 .64582 .56247 Mtetra
.64582 .56247 .64791 .56479 .65218 .56354 .65009 .56121 Mtetra
.65009 .56121 .65218 .56354 .65646 .56228 .65438 .55995 Mtetra
.65438 .55995 .65646 .56228 .66075 .56102 .65867 .55869 Mtetra
.65867 .55869 .66075 .56102 .66504 .55976 .66296 .55742 Mtetra
.66296 .55742 .66504 .55976 .66934 .55849 .66727 .55615 Mtetra
.66727 .55615 .66934 .55849 .67364 .55723 .67158 .55488 Mtetra
.67158 .55488 .67364 .55723 .67796 .55596 .67589 .55361 Mtetra
.67589 .55361 .67796 .55596 .68227 .55469 .68022 .55234 Mtetra
.68022 .55234 .68227 .55469 .6866 .55342 .68455 .55107 Mtetra
.68455 .55107 .6866 .55342 .69093 .55214 .68888 .54979 Mtetra
.68888 .54979 .69093 .55214 .69527 .55087 .69323 .54851 Mtetra
.69323 .54851 .69527 .55087 .69961 .54959 .69758 .54723 Mtetra
.69758 .54723 .69961 .54959 .70397 .54831 .70193 .54595 Mtetra
.70193 .54595 .70397 .54831 .70833 .54703 .7063 .54466 Mtetra
.7063 .54466 .70833 .54703 .71269 .54575 .71067 .54337 Mtetra
.71067 .54337 .71269 .54575 .71706 .54446 .71504 .54208 Mtetra
.976 .717 .472 r
.71504 .54208 .71706 .54446 .7187 .4962 .71671 .49379 Mtetra
.653 .754 .924 r
.71671 .49379 .7187 .4962 .72302 .49489 .72103 .49248 Mtetra
.72103 .49248 .72302 .49489 .72735 .49358 .72537 .49116 Mtetra
.72537 .49116 .72735 .49358 .73168 .49227 .72971 .48985 Mtetra
.72971 .48985 .73168 .49227 .73602 .49096 .73405 .48853 Mtetra
.73405 .48853 .73602 .49096 .74037 .48965 .7384 .48721 Mtetra
.7384 .48721 .74037 .48965 .74473 .48833 .74276 .48589 Mtetra
.74276 .48589 .74473 .48833 .74909 .48701 .74713 .48457 Mtetra
.74713 .48457 .74909 .48701 .75346 .48569 .7515 .48325 Mtetra
.7515 .48325 .75346 .48569 .75783 .48437 .75588 .48192 Mtetra
.75588 .48192 .75783 .48437 .76221 .48304 .76027 .48059 Mtetra
.76027 .48059 .76221 .48304 .7666 .48172 .76466 .47926 Mtetra
.76466 .47926 .7666 .48172 .771 .48039 .76906 .47793 Mtetra
.76906 .47793 .771 .48039 .7754 .47906 .77347 .47659 Mtetra
.77347 .47659 .7754 .47906 .77981 .47772 .77788 .47526 Mtetra
.77788 .47526 .77981 .47772 .78422 .47639 .7823 .47392 Mtetra
.7823 .47392 .78422 .47639 .78865 .47505 .78673 .47258 Mtetra
.78673 .47258 .78865 .47505 .79307 .47371 .79116 .47123 Mtetra
.79116 .47123 .79307 .47371 .79751 .47237 .7956 .46989 Mtetra
.7956 .46989 .79751 .47237 .80195 .47103 .80005 .46854 Mtetra
.80005 .46854 .80195 .47103 .8064 .46968 .80451 .46719 Mtetra
.80451 .46719 .8064 .46968 .81086 .46833 .80897 .46584 Mtetra
.80897 .46584 .81086 .46833 .81532 .46699 .81343 .46449 Mtetra
.81343 .46449 .81532 .46699 .81979 .46563 .81791 .46313 Mtetra
.98 .688 .378 r
.81791 .46313 .81979 .46563 .81202 .32984 .81021 .32725 Mtetra
.664 .741 .908 r
.81021 .32725 .81202 .32984 .81631 .32844 .8145 .32585 Mtetra
.8145 .32585 .81631 .32844 .82061 .32704 .8188 .32444 Mtetra
.8188 .32444 .82061 .32704 .82492 .32563 .82311 .32304 Mtetra
.82311 .32304 .82492 .32563 .82923 .32423 .82743 .32163 Mtetra
.82743 .32163 .82923 .32423 .83354 .32282 .83175 .32021 Mtetra
.83175 .32021 .83354 .32282 .83787 .32141 .83608 .3188 Mtetra
.83608 .3188 .83787 .32141 .8422 .32 .84041 .31738 Mtetra
.84041 .31738 .8422 .32 .84653 .31858 .84475 .31597 Mtetra
.84475 .31597 .84653 .31858 .85087 .31717 .8491 .31455 Mtetra
.8491 .31455 .85087 .31717 .85522 .31575 .85345 .31312 Mtetra
.85345 .31312 .85522 .31575 .85958 .31433 .85781 .3117 Mtetra
.85781 .3117 .85958 .31433 .86394 .3129 .86218 .31027 Mtetra
.86218 .31027 .86394 .3129 .86831 .31148 .86655 .30884 Mtetra
.86655 .30884 .86831 .31148 .87268 .31005 .87093 .30741 Mtetra
.87093 .30741 .87268 .31005 .87707 .30862 .87532 .30598 Mtetra
.87532 .30598 .87707 .30862 .88145 .30719 .87971 .30454 Mtetra
.87971 .30454 .88145 .30719 .88585 .30576 .88411 .3031 Mtetra
.28827 .49491 .29058 .49706 .29414 .4959 .29183 .49374 Mtetra
.29183 .49374 .29414 .4959 .2977 .49473 .2954 .49258 Mtetra
.2954 .49258 .2977 .49473 .30127 .49357 .29897 .49141 Mtetra
.29897 .49141 .30127 .49357 .30484 .4924 .30254 .49024 Mtetra
.30254 .49024 .30484 .4924 .30842 .49123 .30612 .48907 Mtetra
.30612 .48907 .30842 .49123 .312 .49006 .30971 .48789 Mtetra
.30971 .48789 .312 .49006 .31559 .48889 .3133 .48672 Mtetra
.3133 .48672 .31559 .48889 .31918 .48771 .3169 .48554 Mtetra
.3169 .48554 .31918 .48771 .32278 .48654 .3205 .48436 Mtetra
.3205 .48436 .32278 .48654 .32638 .48536 .3241 .48318 Mtetra
.3241 .48318 .32638 .48536 .32999 .48418 .32771 .482 Mtetra
.32771 .482 .32999 .48418 .3336 .483 .33133 .48082 Mtetra
.33133 .48082 .3336 .483 .33721 .48182 .33495 .47963 Mtetra
.33495 .47963 .33721 .48182 .34084 .48063 .33857 .47845 Mtetra
.33857 .47845 .34084 .48063 .34446 .47945 .3422 .47726 Mtetra
.3422 .47726 .34446 .47945 .3481 .47826 .34584 .47607 Mtetra
.34584 .47607 .3481 .47826 .35173 .47707 .34948 .47488 Mtetra
.34948 .47488 .35173 .47707 .35537 .47588 .35312 .47368 Mtetra
.35312 .47368 .35537 .47588 .35902 .47469 .35677 .47249 Mtetra
.35677 .47249 .35902 .47469 .36267 .4735 .36042 .47129 Mtetra
.36042 .47129 .36267 .4735 .36633 .4723 .36408 .47009 Mtetra
.36408 .47009 .36633 .4723 .36999 .47111 .36775 .46889 Mtetra
.36775 .46889 .36999 .47111 .37366 .46991 .37142 .46769 Mtetra
.37142 .46769 .37366 .46991 .37733 .46871 .37509 .46649 Mtetra
.37509 .46649 .37733 .46871 .381 .46751 .37877 .46529 Mtetra
.949 .68 .494 r
.37877 .46529 .381 .46751 .38469 .46631 .37552 .62413 Mtetra
.55 .329 .533 r
.37552 .62413 .38469 .46631 .38173 .62511 .37939 .62298 Mtetra
.651 .757 .927 r
.37939 .62298 .38173 .62511 .3856 .62396 .38326 .62183 Mtetra
.38326 .62183 .3856 .62396 .38947 .62281 .38713 .62068 Mtetra
.38713 .62068 .38947 .62281 .39335 .62165 .39101 .61952 Mtetra
.39101 .61952 .39335 .62165 .39723 .6205 .3949 .61836 Mtetra
.3949 .61836 .39723 .6205 .40112 .61934 .39879 .6172 Mtetra
.39879 .6172 .40112 .61934 .40502 .61818 .40269 .61604 Mtetra
.40269 .61604 .40502 .61818 .40892 .61702 .4066 .61488 Mtetra
.4066 .61488 .40892 .61702 .41282 .61586 .41051 .61371 Mtetra
.41051 .61371 .41282 .61586 .41832 .56442 .41442 .61255 Mtetra
.541 .308 .511 r
.41442 .61255 .41832 .56442 .42218 .56324 .41834 .61138 Mtetra
0 0 .237 r
.41834 .61138 .42218 .56324 .42604 .56205 .42378 .55986 Mtetra
.655 .752 .921 r
.42378 .55986 .42604 .56205 .42992 .56087 .42765 .55867 Mtetra
.42765 .55867 .42992 .56087 .4338 .55968 .43153 .55748 Mtetra
.43153 .55748 .4338 .55968 .43768 .55849 .43542 .55628 Mtetra
.43542 .55628 .43768 .55849 .44157 .55729 .43931 .55509 Mtetra
.956 .676 .466 r
.43931 .55509 .44157 .55729 .44546 .5561 .44073 .65631 Mtetra
.548 .324 .527 r
.44073 .65631 .44546 .5561 .44707 .65729 .44476 .65515 Mtetra
.646 .762 .934 r
.44476 .65515 .44707 .65729 .4511 .65613 .44878 .65399 Mtetra
.44878 .65399 .4511 .65613 .45513 .65498 .45281 .65283 Mtetra
.45281 .65283 .45513 .65498 .45916 .65381 .45685 .65167 Mtetra
.45685 .65167 .45916 .65381 .4632 .65265 .4609 .6505 Mtetra
.4609 .6505 .4632 .65265 .46725 .65149 .46495 .64933 Mtetra
.46495 .64933 .46725 .65149 .4713 .65032 .46901 .64816 Mtetra
.46901 .64816 .4713 .65032 .47536 .64915 .47307 .64699 Mtetra
.47307 .64699 .47536 .64915 .47942 .64798 .47714 .64582 Mtetra
.47714 .64582 .47942 .64798 .4835 .64681 .48121 .64464 Mtetra
.48121 .64464 .4835 .64681 .48757 .64564 .48529 .64347 Mtetra
.48529 .64347 .48757 .64564 .49166 .64446 .48938 .64229 Mtetra
.48938 .64229 .49166 .64446 .49574 .64329 .49347 .64111 Mtetra
.49347 .64111 .49574 .64329 .49984 .64211 .49757 .63993 Mtetra
.958 .702 .507 r
.49757 .63993 .49984 .64211 .50444 .55808 .50223 .55584 Mtetra
.653 .754 .924 r
.50223 .55584 .50444 .55808 .50845 .55686 .50625 .55462 Mtetra
.50625 .55462 .50845 .55686 .51247 .55565 .51027 .5534 Mtetra
.51027 .5534 .51247 .55565 .51649 .55443 .51429 .55218 Mtetra
.51429 .55218 .51649 .55443 .52052 .55321 .51832 .55095 Mtetra
.51832 .55095 .52052 .55321 .52455 .55199 .52236 .54973 Mtetra
.52236 .54973 .52455 .55199 .52859 .55076 .5264 .5485 Mtetra
.5264 .5485 .52859 .55076 .53263 .54954 .53045 .54727 Mtetra
.53045 .54727 .53263 .54954 .53669 .54831 .53451 .54604 Mtetra
.53451 .54604 .53669 .54831 .54074 .54708 .53857 .54481 Mtetra
.53857 .54481 .54074 .54708 .54481 .54585 .54264 .54358 Mtetra
.54264 .54358 .54481 .54585 .54888 .54462 .54671 .54234 Mtetra
.54671 .54234 .54888 .54462 .55295 .54339 .55079 .5411 Mtetra
.55079 .5411 .55295 .54339 .55703 .54215 .55487 .53986 Mtetra
.55487 .53986 .55703 .54215 .56112 .54091 .55896 .53862 Mtetra
.55896 .53862 .56112 .54091 .56521 .53967 .56306 .53738 Mtetra
.56306 .53738 .56521 .53967 .56931 .53843 .56716 .53613 Mtetra
.56716 .53613 .56931 .53843 .57342 .53719 .57127 .53489 Mtetra
.964 .651 .377 r
.57127 .53489 .57342 .53719 .57826 .58237 .57609 .5801 Mtetra
.649 .759 .929 r
.57609 .5801 .57826 .58237 .58243 .58114 .58027 .57886 Mtetra
.58027 .57886 .58243 .58114 .58661 .57991 .58445 .57763 Mtetra
.58445 .57763 .58661 .57991 .5908 .57867 .58864 .57639 Mtetra
.58864 .57639 .5908 .57867 .59499 .57744 .59284 .57515 Mtetra
.59284 .57515 .59499 .57744 .59919 .5762 .59705 .57391 Mtetra
.59705 .57391 .59919 .5762 .6034 .57496 .60126 .57267 Mtetra
.60126 .57267 .6034 .57496 .60761 .57372 .60547 .57143 Mtetra
.60547 .57143 .60761 .57372 .61183 .57248 .6097 .57018 Mtetra
.6097 .57018 .61183 .57248 .61606 .57123 .61393 .56893 Mtetra
.61393 .56893 .61606 .57123 .62029 .56999 .61816 .56768 Mtetra
.61816 .56768 .62029 .56999 .62453 .56874 .62241 .56643 Mtetra
.62241 .56643 .62453 .56874 .62877 .56749 .62666 .56518 Mtetra
.62666 .56518 .62877 .56749 .63302 .56624 .63091 .56392 Mtetra
.63091 .56392 .63302 .56624 .63728 .56498 .63517 .56266 Mtetra
.63517 .56266 .63728 .56498 .64155 .56373 .63944 .56141 Mtetra
.63944 .56141 .64155 .56373 .64582 .56247 .64372 .56014 Mtetra
.64372 .56014 .64582 .56247 .65009 .56121 .648 .55888 Mtetra
.648 .55888 .65009 .56121 .65438 .55995 .65229 .55762 Mtetra
.65229 .55762 .65438 .55995 .65867 .55869 .65658 .55635 Mtetra
.65658 .55635 .65867 .55869 .66296 .55742 .66088 .55508 Mtetra
.66088 .55508 .66296 .55742 .66727 .55615 .66519 .55381 Mtetra
.66519 .55381 .66727 .55615 .67158 .55488 .66951 .55254 Mtetra
.66951 .55254 .67158 .55488 .67589 .55361 .67383 .55126 Mtetra
.67383 .55126 .67589 .55361 .68022 .55234 .67815 .54998 Mtetra
.67815 .54998 .68022 .55234 .68455 .55107 .68249 .54871 Mtetra
.68249 .54871 .68455 .55107 .68888 .54979 .68683 .54743 Mtetra
.68683 .54743 .68888 .54979 .69323 .54851 .69118 .54614 Mtetra
.69118 .54614 .69323 .54851 .69758 .54723 .69553 .54486 Mtetra
.69553 .54486 .69758 .54723 .70193 .54595 .69989 .54357 Mtetra
.69989 .54357 .70193 .54595 .7063 .54466 .70426 .54228 Mtetra
.70426 .54228 .7063 .54466 .71067 .54337 .70863 .54099 Mtetra
.70863 .54099 .71067 .54337 .71504 .54208 .71302 .5397 Mtetra
.976 .717 .472 r
.71302 .5397 .71504 .54208 .71671 .49379 .71471 .49137 Mtetra
.653 .754 .924 r
.71471 .49137 .71671 .49379 .72103 .49248 .71904 .49005 Mtetra
.71904 .49005 .72103 .49248 .72537 .49116 .72338 .48874 Mtetra
.72338 .48874 .72537 .49116 .72971 .48985 .72772 .48742 Mtetra
.72772 .48742 .72971 .48985 .73405 .48853 .73207 .4861 Mtetra
.73207 .4861 .73405 .48853 .7384 .48721 .73643 .48477 Mtetra
.73643 .48477 .7384 .48721 .74276 .48589 .7408 .48345 Mtetra
.7408 .48345 .74276 .48589 .74713 .48457 .74517 .48212 Mtetra
.74517 .48212 .74713 .48457 .7515 .48325 .74954 .4808 Mtetra
.74954 .4808 .7515 .48325 .75588 .48192 .75393 .47947 Mtetra
.75393 .47947 .75588 .48192 .76027 .48059 .75832 .47813 Mtetra
.75832 .47813 .76027 .48059 .76466 .47926 .76272 .4768 Mtetra
.76272 .4768 .76466 .47926 .76906 .47793 .76712 .47546 Mtetra
.76712 .47546 .76906 .47793 .77347 .47659 .77153 .47412 Mtetra
.77153 .47412 .77347 .47659 .77788 .47526 .77595 .47278 Mtetra
.77595 .47278 .77788 .47526 .7823 .47392 .78038 .47144 Mtetra
.78038 .47144 .7823 .47392 .78673 .47258 .78481 .4701 Mtetra
.78481 .4701 .78673 .47258 .79116 .47123 .78925 .46875 Mtetra
.78925 .46875 .79116 .47123 .7956 .46989 .79369 .4674 Mtetra
.79369 .4674 .7956 .46989 .80005 .46854 .79814 .46605 Mtetra
.79814 .46605 .80005 .46854 .80451 .46719 .8026 .4647 Mtetra
.8026 .4647 .80451 .46719 .80897 .46584 .80707 .46334 Mtetra
.80707 .46334 .80897 .46584 .81343 .46449 .81154 .46198 Mtetra
.98 .689 .38 r
.81154 .46198 .81343 .46449 .81791 .46313 .80409 .32607 Mtetra
.558 .349 .553 r
.80409 .32607 .81791 .46313 .81021 .32725 .80838 .32466 Mtetra
.664 .741 .908 r
.80838 .32466 .81021 .32725 .8145 .32585 .81268 .32325 Mtetra
.81268 .32325 .8145 .32585 .8188 .32444 .81699 .32184 Mtetra
.81699 .32184 .8188 .32444 .82311 .32304 .8213 .32043 Mtetra
.8213 .32043 .82311 .32304 .82743 .32163 .82562 .31902 Mtetra
.82562 .31902 .82743 .32163 .83175 .32021 .82995 .3176 Mtetra
.82995 .3176 .83175 .32021 .83608 .3188 .83428 .31618 Mtetra
.83428 .31618 .83608 .3188 .84041 .31738 .83862 .31476 Mtetra
.83862 .31476 .84041 .31738 .84475 .31597 .84297 .31334 Mtetra
.84297 .31334 .84475 .31597 .8491 .31455 .84732 .31192 Mtetra
.84732 .31192 .8491 .31455 .85345 .31312 .85168 .31049 Mtetra
.85168 .31049 .85345 .31312 .85781 .3117 .85604 .30906 Mtetra
.85604 .30906 .85781 .3117 .86218 .31027 .86041 .30763 Mtetra
.86041 .30763 .86218 .31027 .86655 .30884 .86479 .3062 Mtetra
.86479 .3062 .86655 .30884 .87093 .30741 .86918 .30476 Mtetra
.86918 .30476 .87093 .30741 .87532 .30598 .87357 .30333 Mtetra
.87357 .30333 .87532 .30598 .87971 .30454 .87796 .30189 Mtetra
.87796 .30189 .87971 .30454 .88411 .3031 .88237 .30044 Mtetra
.28596 .49276 .28827 .49491 .29183 .49374 .28952 .49159 Mtetra
.28952 .49159 .29183 .49374 .2954 .49258 .29309 .49042 Mtetra
.29309 .49042 .2954 .49258 .29897 .49141 .29666 .48925 Mtetra
.29666 .48925 .29897 .49141 .30254 .49024 .30024 .48807 Mtetra
.30024 .48807 .30254 .49024 .30612 .48907 .30383 .4869 Mtetra
.30383 .4869 .30612 .48907 .30971 .48789 .30742 .48572 Mtetra
.30742 .48572 .30971 .48789 .3133 .48672 .31101 .48454 Mtetra
.31101 .48454 .3133 .48672 .3169 .48554 .31461 .48336 Mtetra
.31461 .48336 .3169 .48554 .3205 .48436 .31821 .48218 Mtetra
.31821 .48218 .3205 .48436 .3241 .48318 .32182 .481 Mtetra
.32182 .481 .3241 .48318 .32771 .482 .32543 .47981 Mtetra
.32543 .47981 .32771 .482 .33133 .48082 .32905 .47863 Mtetra
.32905 .47863 .33133 .48082 .33495 .47963 .33267 .47744 Mtetra
.33267 .47744 .33495 .47963 .33857 .47845 .3363 .47625 Mtetra
.3363 .47625 .33857 .47845 .3422 .47726 .33993 .47506 Mtetra
.33993 .47506 .3422 .47726 .34584 .47607 .34357 .47387 Mtetra
.34357 .47387 .34584 .47607 .34948 .47488 .34721 .47267 Mtetra
.34721 .47267 .34948 .47488 .35312 .47368 .35086 .47148 Mtetra
.35086 .47148 .35312 .47368 .35677 .47249 .35451 .47028 Mtetra
.35451 .47028 .35677 .47249 .36042 .47129 .35817 .46908 Mtetra
.35817 .46908 .36042 .47129 .36408 .47009 .36183 .46788 Mtetra
.36183 .46788 .36408 .47009 .36775 .46889 .3655 .46668 Mtetra
.3655 .46668 .36775 .46889 .37142 .46769 .36917 .46547 Mtetra
.36917 .46547 .37142 .46769 .37509 .46649 .37285 .46427 Mtetra
.948 .68 .495 r
.37285 .46427 .37509 .46649 .37877 .46529 .36931 .62316 Mtetra
.549 .329 .533 r
.36931 .62316 .37877 .46529 .37552 .62413 .37317 .62201 Mtetra
.651 .757 .927 r
.37317 .62201 .37552 .62413 .37939 .62298 .37704 .62085 Mtetra
.37704 .62085 .37939 .62298 .38326 .62183 .38091 .6197 Mtetra
.38091 .6197 .38326 .62183 .38713 .62068 .38479 .61854 Mtetra
.38479 .61854 .38713 .62068 .39101 .61952 .38868 .61738 Mtetra
.38868 .61738 .39101 .61952 .3949 .61836 .39257 .61622 Mtetra
.39257 .61622 .3949 .61836 .39879 .6172 .39646 .61506 Mtetra
.39646 .61506 .39879 .6172 .40269 .61604 .40037 .61389 Mtetra
.40037 .61389 .40269 .61604 .4066 .61488 .40427 .61273 Mtetra
.40427 .61273 .4066 .61488 .41051 .61371 .40819 .61156 Mtetra
.40819 .61156 .41051 .61371 .41442 .61255 .41211 .61039 Mtetra
.41211 .61039 .41442 .61255 .41834 .61138 .41603 .60922 Mtetra
.41603 .60922 .41834 .61138 .42378 .55986 .41996 .60805 Mtetra
.54 .307 .511 r
.41996 .60805 .42378 .55986 .42765 .55867 .4239 .60687 Mtetra
.4239 .60687 .42765 .55867 .43153 .55748 .42784 .6057 Mtetra
0 0 .242 r
.42784 .6057 .43153 .55748 .43542 .55628 .43316 .55408 Mtetra
.655 .752 .921 r
.43316 .55408 .43542 .55628 .43931 .55509 .43705 .55288 Mtetra
.956 .676 .466 r
.43705 .55288 .43931 .55509 .44073 .65631 .43841 .65417 Mtetra
.646 .762 .934 r
.43841 .65417 .44073 .65631 .44476 .65515 .44243 .65301 Mtetra
.44243 .65301 .44476 .65515 .44878 .65399 .44646 .65185 Mtetra
.44646 .65185 .44878 .65399 .45281 .65283 .4505 .65068 Mtetra
.4505 .65068 .45281 .65283 .45685 .65167 .45454 .64951 Mtetra
.45454 .64951 .45685 .65167 .4609 .6505 .45859 .64834 Mtetra
.45859 .64834 .4609 .6505 .46495 .64933 .46264 .64717 Mtetra
.46264 .64717 .46495 .64933 .46901 .64816 .4667 .646 Mtetra
.4667 .646 .46901 .64816 .47307 .64699 .47077 .64482 Mtetra
.47077 .64482 .47307 .64699 .47714 .64582 .47484 .64365 Mtetra
.47484 .64365 .47714 .64582 .48121 .64464 .47892 .64247 Mtetra
.47892 .64247 .48121 .64464 .48529 .64347 .48301 .64129 Mtetra
.48301 .64129 .48529 .64347 .48938 .64229 .4871 .64011 Mtetra
.4871 .64011 .48938 .64229 .49347 .64111 .49119 .63892 Mtetra
.49119 .63892 .49347 .64111 .49757 .63993 .4953 .63774 Mtetra
.958 .702 .507 r
.4953 .63774 .49757 .63993 .50223 .55584 .50002 .55359 Mtetra
.653 .754 .924 r
.50002 .55359 .50223 .55584 .50625 .55462 .50404 .55236 Mtetra
.50404 .55236 .50625 .55462 .51027 .5534 .50806 .55114 Mtetra
.50806 .55114 .51027 .5534 .51429 .55218 .51209 .54992 Mtetra
.51209 .54992 .51429 .55218 .51832 .55095 .51612 .54869 Mtetra
.51612 .54869 .51832 .55095 .52236 .54973 .52016 .54746 Mtetra
.52016 .54746 .52236 .54973 .5264 .5485 .52421 .54623 Mtetra
.52421 .54623 .5264 .5485 .53045 .54727 .52826 .545 Mtetra
.52826 .545 .53045 .54727 .53451 .54604 .53232 .54377 Mtetra
.53232 .54377 .53451 .54604 .53857 .54481 .53639 .54253 Mtetra
.53639 .54253 .53857 .54481 .54264 .54358 .54046 .54129 Mtetra
.54046 .54129 .54264 .54358 .54671 .54234 .54454 .54005 Mtetra
.54454 .54005 .54671 .54234 .55079 .5411 .54862 .53881 Mtetra
.54862 .53881 .55079 .5411 .55487 .53986 .55271 .53757 Mtetra
.55271 .53757 .55487 .53986 .55896 .53862 .5568 .53633 Mtetra
.5568 .53633 .55896 .53862 .56306 .53738 .5609 .53508 Mtetra
.5609 .53508 .56306 .53738 .56716 .53613 .56501 .53383 Mtetra
.56501 .53383 .56716 .53613 .57127 .53489 .56913 .53258 Mtetra
.964 .651 .377 r
.56913 .53258 .57127 .53489 .57609 .5801 .57392 .57782 Mtetra
.649 .759 .929 r
.57392 .57782 .57609 .5801 .58027 .57886 .5781 .57658 Mtetra
.5781 .57658 .58027 .57886 .58445 .57763 .58229 .57534 Mtetra
.58229 .57534 .58445 .57763 .58864 .57639 .58648 .5741 Mtetra
.58648 .5741 .58864 .57639 .59284 .57515 .59069 .57286 Mtetra
.59069 .57286 .59284 .57515 .59705 .57391 .59489 .57162 Mtetra
.59489 .57162 .59705 .57391 .60126 .57267 .59911 .57037 Mtetra
.59911 .57037 .60126 .57267 .60547 .57143 .60333 .56912 Mtetra
.60333 .56912 .60547 .57143 .6097 .57018 .60756 .56788 Mtetra
.60756 .56788 .6097 .57018 .61393 .56893 .61179 .56662 Mtetra
.61179 .56662 .61393 .56893 .61816 .56768 .61603 .56537 Mtetra
.61603 .56537 .61816 .56768 .62241 .56643 .62028 .56412 Mtetra
.62028 .56412 .62241 .56643 .62666 .56518 .62453 .56286 Mtetra
.62453 .56286 .62666 .56518 .63091 .56392 .62879 .5616 Mtetra
.62879 .5616 .63091 .56392 .63517 .56266 .63306 .56034 Mtetra
.63306 .56034 .63517 .56266 .63944 .56141 .63733 .55908 Mtetra
.63733 .55908 .63944 .56141 .64372 .56014 .64161 .55781 Mtetra
.64161 .55781 .64372 .56014 .648 .55888 .6459 .55654 Mtetra
.6459 .55654 .648 .55888 .65229 .55762 .65019 .55528 Mtetra
.65019 .55528 .65229 .55762 .65658 .55635 .65449 .554 Mtetra
.65449 .554 .65658 .55635 .66088 .55508 .6588 .55273 Mtetra
.6588 .55273 .66088 .55508 .66519 .55381 .66311 .55146 Mtetra
.66311 .55146 .66519 .55381 .66951 .55254 .66743 .55018 Mtetra
.66743 .55018 .66951 .55254 .67383 .55126 .67175 .5489 Mtetra
.67175 .5489 .67383 .55126 .67815 .54998 .67609 .54762 Mtetra
.67609 .54762 .67815 .54998 .68249 .54871 .68043 .54634 Mtetra
.68043 .54634 .68249 .54871 .68683 .54743 .68477 .54506 Mtetra
.68477 .54506 .68683 .54743 .69118 .54614 .68912 .54377 Mtetra
.68912 .54377 .69118 .54614 .69553 .54486 .69348 .54248 Mtetra
.69348 .54248 .69553 .54486 .69989 .54357 .69785 .54119 Mtetra
.69785 .54119 .69989 .54357 .70426 .54228 .70222 .5399 Mtetra
.70222 .5399 .70426 .54228 .70863 .54099 .7066 .5386 Mtetra
.7066 .5386 .70863 .54099 .71302 .5397 .71098 .53731 Mtetra
.976 .717 .472 r
.71098 .53731 .71302 .5397 .71471 .49137 .71271 .48894 Mtetra
.653 .754 .924 r
.71271 .48894 .71471 .49137 .71904 .49005 .71704 .48762 Mtetra
.71704 .48762 .71904 .49005 .72338 .48874 .72139 .4863 Mtetra
.72139 .4863 .72338 .48874 .72772 .48742 .72573 .48498 Mtetra
.72573 .48498 .72772 .48742 .73207 .4861 .73009 .48365 Mtetra
.73009 .48365 .73207 .4861 .73643 .48477 .73445 .48233 Mtetra
.73445 .48233 .73643 .48477 .7408 .48345 .73882 .481 Mtetra
.73882 .481 .7408 .48345 .74517 .48212 .7432 .47967 Mtetra
.7432 .47967 .74517 .48212 .74954 .4808 .74758 .47834 Mtetra
.74758 .47834 .74954 .4808 .75393 .47947 .75197 .477 Mtetra
.75197 .477 .75393 .47947 .75832 .47813 .75636 .47567 Mtetra
.75636 .47567 .75832 .47813 .76272 .4768 .76077 .47433 Mtetra
.76077 .47433 .76272 .4768 .76712 .47546 .76518 .47299 Mtetra
.76518 .47299 .76712 .47546 .77153 .47412 .76959 .47165 Mtetra
.76959 .47165 .77153 .47412 .77595 .47278 .77401 .4703 Mtetra
.77401 .4703 .77595 .47278 .78038 .47144 .77844 .46896 Mtetra
.77844 .46896 .78038 .47144 .78481 .4701 .78288 .46761 Mtetra
.78288 .46761 .78481 .4701 .78925 .46875 .78732 .46626 Mtetra
.78732 .46626 .78925 .46875 .79369 .4674 .79177 .46491 Mtetra
.79177 .46491 .79369 .4674 .79814 .46605 .79623 .46355 Mtetra
.79623 .46355 .79814 .46605 .8026 .4647 .8007 .46219 Mtetra
.8007 .46219 .8026 .4647 .80707 .46334 .80517 .46083 Mtetra
.80517 .46083 .80707 .46334 .81154 .46198 .80964 .45947 Mtetra
.98 .689 .38 r
.80964 .45947 .81154 .46198 .80409 .32607 .80226 .32347 Mtetra
.664 .741 .908 r
.80226 .32347 .80409 .32607 .80838 .32466 .80656 .32206 Mtetra
.80656 .32206 .80838 .32466 .81268 .32325 .81086 .32065 Mtetra
.81086 .32065 .81268 .32325 .81699 .32184 .81517 .31924 Mtetra
.81517 .31924 .81699 .32184 .8213 .32043 .81949 .31782 Mtetra
.81949 .31782 .8213 .32043 .82562 .31902 .82381 .3164 Mtetra
.82381 .3164 .82562 .31902 .82995 .3176 .82814 .31498 Mtetra
.82814 .31498 .82995 .3176 .83428 .31618 .83248 .31356 Mtetra
.83248 .31356 .83428 .31618 .83862 .31476 .83683 .31214 Mtetra
.83683 .31214 .83862 .31476 .84297 .31334 .84118 .31071 Mtetra
.84118 .31071 .84297 .31334 .84732 .31192 .84553 .30928 Mtetra
.84553 .30928 .84732 .31192 .85168 .31049 .8499 .30785 Mtetra
.8499 .30785 .85168 .31049 .85604 .30906 .85426 .30642 Mtetra
.85426 .30642 .85604 .30906 .86041 .30763 .85864 .30498 Mtetra
.85864 .30498 .86041 .30763 .86479 .3062 .86302 .30355 Mtetra
.86302 .30355 .86479 .3062 .86918 .30476 .86741 .30211 Mtetra
.86741 .30211 .86918 .30476 .87357 .30333 .87181 .30067 Mtetra
.87181 .30067 .87357 .30333 .87796 .30189 .87621 .29922 Mtetra
.87621 .29922 .87796 .30189 .88237 .30044 .88062 .29778 Mtetra
.28364 .4906 .28596 .49276 .28952 .49159 .28721 .48943 Mtetra
.28721 .48943 .28952 .49159 .29309 .49042 .29078 .48825 Mtetra
.29078 .48825 .29309 .49042 .29666 .48925 .29435 .48708 Mtetra
.29435 .48708 .29666 .48925 .30024 .48807 .29794 .4859 Mtetra
.29794 .4859 .30024 .48807 .30383 .4869 .30152 .48472 Mtetra
.30152 .48472 .30383 .4869 .30742 .48572 .30511 .48355 Mtetra
.30511 .48355 .30742 .48572 .31101 .48454 .30871 .48236 Mtetra
.30871 .48236 .31101 .48454 .31461 .48336 .31231 .48118 Mtetra
.31231 .48118 .31461 .48336 .31821 .48218 .31592 .48 Mtetra
.31592 .48 .31821 .48218 .32182 .481 .31953 .47881 Mtetra
.31953 .47881 .32182 .481 .32543 .47981 .32314 .47762 Mtetra
.32314 .47762 .32543 .47981 .32905 .47863 .32677 .47643 Mtetra
.32677 .47643 .32905 .47863 .33267 .47744 .33039 .47524 Mtetra
.33039 .47524 .33267 .47744 .3363 .47625 .33402 .47405 Mtetra
.33402 .47405 .3363 .47625 .33993 .47506 .33766 .47286 Mtetra
.33766 .47286 .33993 .47506 .34357 .47387 .3413 .47166 Mtetra
.3413 .47166 .34357 .47387 .34721 .47267 .34494 .47046 Mtetra
.34494 .47046 .34721 .47267 .35086 .47148 .3486 .46926 Mtetra
.3486 .46926 .35086 .47148 .35451 .47028 .35225 .46806 Mtetra
.35225 .46806 .35451 .47028 .35817 .46908 .35591 .46686 Mtetra
.35591 .46686 .35817 .46908 .36183 .46788 .35958 .46566 Mtetra
.35958 .46566 .36183 .46788 .3655 .46668 .36325 .46445 Mtetra
.36325 .46445 .3655 .46668 .36917 .46547 .36693 .46324 Mtetra
.948 .68 .496 r
.36693 .46324 .36917 .46547 .37285 .46427 .36308 .62219 Mtetra
.549 .328 .532 r
.36308 .62219 .37285 .46427 .36931 .62316 .36694 .62103 Mtetra
.651 .757 .927 r
.36694 .62103 .36931 .62316 .37317 .62201 .37081 .61988 Mtetra
.37081 .61988 .37317 .62201 .37704 .62085 .37468 .61872 Mtetra
.37468 .61872 .37704 .62085 .38091 .6197 .37856 .61756 Mtetra
.37856 .61756 .38091 .6197 .38479 .61854 .38244 .6164 Mtetra
.38244 .6164 .38479 .61854 .38868 .61738 .38633 .61524 Mtetra
.38633 .61524 .38868 .61738 .39257 .61622 .39023 .61407 Mtetra
.39023 .61407 .39257 .61622 .39646 .61506 .39413 .61291 Mtetra
.39413 .61291 .39646 .61506 .40037 .61389 .39803 .61174 Mtetra
.39803 .61174 .40037 .61389 .40427 .61273 .40194 .61057 Mtetra
.40194 .61057 .40427 .61273 .40819 .61156 .40586 .6094 Mtetra
.40586 .6094 .40819 .61156 .41211 .61039 .40978 .60823 Mtetra
.40978 .60823 .41211 .61039 .41603 .60922 .41371 .60705 Mtetra
.41371 .60705 .41603 .60922 .41996 .60805 .41764 .60588 Mtetra
.41764 .60588 .41996 .60805 .4239 .60687 .42158 .6047 Mtetra
.42158 .6047 .4239 .60687 .42784 .6057 .42553 .60352 Mtetra
.42553 .60352 .42784 .6057 .43316 .55408 .42948 .60234 Mtetra
.758 .495 .536 r
.42948 .60234 .43316 .55408 .43705 .55288 .43205 .65319 Mtetra
.547 .323 .526 r
.43205 .65319 .43705 .55288 .43841 .65417 .43607 .65202 Mtetra
.646 .762 .934 r
.43607 .65202 .43841 .65417 .44243 .65301 .4401 .65086 Mtetra
.4401 .65086 .44243 .65301 .44646 .65185 .44413 .64969 Mtetra
.44413 .64969 .44646 .65185 .4505 .65068 .44817 .64852 Mtetra
.44817 .64852 .4505 .65068 .45454 .64951 .45222 .64735 Mtetra
.45222 .64735 .45454 .64951 .45859 .64834 .45627 .64618 Mtetra
.45627 .64618 .45859 .64834 .46264 .64717 .46033 .645 Mtetra
.46033 .645 .46264 .64717 .4667 .646 .4644 .64383 Mtetra
.4644 .64383 .4667 .646 .47077 .64482 .46847 .64265 Mtetra
.46847 .64265 .47077 .64482 .47484 .64365 .47254 .64147 Mtetra
.47254 .64147 .47484 .64365 .47892 .64247 .47663 .64029 Mtetra
.47663 .64029 .47892 .64247 .48301 .64129 .48071 .63911 Mtetra
.48071 .63911 .48301 .64129 .4871 .64011 .48481 .63792 Mtetra
.48481 .63792 .4871 .64011 .49119 .63892 .48891 .63673 Mtetra
.48891 .63673 .49119 .63892 .4953 .63774 .49302 .63555 Mtetra
.958 .702 .507 r
.49302 .63555 .4953 .63774 .50002 .55359 .4978 .55133 Mtetra
.653 .754 .924 r
.4978 .55133 .50002 .55359 .50404 .55236 .50182 .55011 Mtetra
.50182 .55011 .50404 .55236 .50806 .55114 .50585 .54888 Mtetra
.50585 .54888 .50806 .55114 .51209 .54992 .50988 .54765 Mtetra
.50988 .54765 .51209 .54992 .51612 .54869 .51392 .54642 Mtetra
.51392 .54642 .51612 .54869 .52016 .54746 .51796 .54519 Mtetra
.51796 .54519 .52016 .54746 .52421 .54623 .52201 .54396 Mtetra
.52201 .54396 .52421 .54623 .52826 .545 .52607 .54272 Mtetra
.52607 .54272 .52826 .545 .53232 .54377 .53013 .54148 Mtetra
.53013 .54148 .53232 .54377 .53639 .54253 .5342 .54024 Mtetra
.5342 .54024 .53639 .54253 .54046 .54129 .53828 .539 Mtetra
.53828 .539 .54046 .54129 .54454 .54005 .54236 .53776 Mtetra
.54236 .53776 .54454 .54005 .54862 .53881 .54645 .53652 Mtetra
.54645 .53652 .54862 .53881 .55271 .53757 .55054 .53527 Mtetra
.55054 .53527 .55271 .53757 .5568 .53633 .55464 .53402 Mtetra
.55464 .53402 .5568 .53633 .5609 .53508 .55874 .53277 Mtetra
.55874 .53277 .5609 .53508 .56501 .53383 .56285 .53152 Mtetra
.965 .698 .478 r
.56285 .53152 .56501 .53383 .56913 .53258 .56549 .41226 Mtetra
.558 .349 .553 r
.56549 .41226 .56913 .53258 .57392 .57782 .56947 .41096 Mtetra
.557 .346 .55 r
.56947 .41096 .57392 .57782 .5781 .57658 .57345 .40966 Mtetra
.57345 .40966 .5781 .57658 .58229 .57534 .57744 .40836 Mtetra
0 0 .403 r
.57744 .40836 .58229 .57534 .58648 .5741 .58432 .57181 Mtetra
.649 .759 .929 r
.58432 .57181 .58648 .5741 .59069 .57286 .58852 .57056 Mtetra
.58852 .57056 .59069 .57286 .59489 .57162 .59274 .56932 Mtetra
.59274 .56932 .59489 .57162 .59911 .57037 .59696 .56807 Mtetra
.59696 .56807 .59911 .57037 .60333 .56912 .60118 .56682 Mtetra
.60118 .56682 .60333 .56912 .60756 .56788 .60541 .56556 Mtetra
.60541 .56556 .60756 .56788 .61179 .56662 .60965 .56431 Mtetra
.60965 .56431 .61179 .56662 .61603 .56537 .6139 .56305 Mtetra
.6139 .56305 .61603 .56537 .62028 .56412 .61815 .56179 Mtetra
.61815 .56179 .62028 .56412 .62453 .56286 .62241 .56053 Mtetra
.62241 .56053 .62453 .56286 .62879 .5616 .62667 .55927 Mtetra
.62667 .55927 .62879 .5616 .63306 .56034 .63094 .55801 Mtetra
.63094 .55801 .63306 .56034 .63733 .55908 .63522 .55674 Mtetra
.63522 .55674 .63733 .55908 .64161 .55781 .6395 .55547 Mtetra
.6395 .55547 .64161 .55781 .6459 .55654 .64379 .5542 Mtetra
.64379 .5542 .6459 .55654 .65019 .55528 .64809 .55293 Mtetra
.64809 .55293 .65019 .55528 .65449 .554 .65239 .55165 Mtetra
.65239 .55165 .65449 .554 .6588 .55273 .6567 .55038 Mtetra
.6567 .55038 .6588 .55273 .66311 .55146 .66102 .5491 Mtetra
.66102 .5491 .66311 .55146 .66743 .55018 .66535 .54782 Mtetra
.66535 .54782 .66743 .55018 .67175 .5489 .66968 .54654 Mtetra
.66968 .54654 .67175 .5489 .67609 .54762 .67401 .54525 Mtetra
.67401 .54525 .67609 .54762 .68043 .54634 .67836 .54397 Mtetra
.67836 .54397 .68043 .54634 .68477 .54506 .68271 .54268 Mtetra
.68271 .54268 .68477 .54506 .68912 .54377 .68706 .54139 Mtetra
.68706 .54139 .68912 .54377 .69348 .54248 .69143 .5401 Mtetra
.69143 .5401 .69348 .54248 .69785 .54119 .6958 .5388 Mtetra
.6958 .5388 .69785 .54119 .70222 .5399 .70017 .53751 Mtetra
.70017 .53751 .70222 .5399 .7066 .5386 .70456 .53621 Mtetra
.70456 .53621 .7066 .5386 .71098 .53731 .70895 .53491 Mtetra
.976 .717 .472 r
.70895 .53491 .71098 .53731 .71271 .48894 .7107 .4865 Mtetra
.653 .754 .924 r
.7107 .4865 .71271 .48894 .71704 .48762 .71504 .48518 Mtetra
.71504 .48518 .71704 .48762 .72139 .4863 .71939 .48386 Mtetra
.71939 .48386 .72139 .4863 .72573 .48498 .72374 .48253 Mtetra
.72374 .48253 .72573 .48498 .73009 .48365 .7281 .48121 Mtetra
.7281 .48121 .73009 .48365 .73445 .48233 .73247 .47988 Mtetra
.73247 .47988 .73445 .48233 .73882 .481 .73684 .47854 Mtetra
.73684 .47854 .73882 .481 .7432 .47967 .74122 .47721 Mtetra
.74122 .47721 .7432 .47967 .74758 .47834 .74561 .47587 Mtetra
.74561 .47587 .74758 .47834 .75197 .477 .75 .47454 Mtetra
.75 .47454 .75197 .477 .75636 .47567 .7544 .4732 Mtetra
.7544 .4732 .75636 .47567 .76077 .47433 .75881 .47185 Mtetra
.75881 .47185 .76077 .47433 .76518 .47299 .76322 .47051 Mtetra
.76322 .47051 .76518 .47299 .76959 .47165 .76764 .46916 Mtetra
.76764 .46916 .76959 .47165 .77401 .4703 .77207 .46782 Mtetra
.77207 .46782 .77401 .4703 .77844 .46896 .77651 .46647 Mtetra
.77651 .46647 .77844 .46896 .78288 .46761 .78095 .46511 Mtetra
.78095 .46511 .78288 .46761 .78732 .46626 .7854 .46376 Mtetra
.7854 .46376 .78732 .46626 .79177 .46491 .78985 .4624 Mtetra
.78985 .4624 .79177 .46491 .79623 .46355 .79431 .46104 Mtetra
.79431 .46104 .79623 .46355 .8007 .46219 .79878 .45968 Mtetra
.79878 .45968 .8007 .46219 .80517 .46083 .80326 .45832 Mtetra
.80326 .45832 .80517 .46083 .80964 .45947 .80774 .45696 Mtetra
.98 .689 .38 r
.80774 .45696 .80964 .45947 .80226 .32347 .80042 .32087 Mtetra
.664 .741 .908 r
.80042 .32087 .80226 .32347 .80656 .32206 .80472 .31945 Mtetra
.80472 .31945 .80656 .32206 .81086 .32065 .80903 .31804 Mtetra
.80903 .31804 .81086 .32065 .81517 .31924 .81335 .31662 Mtetra
.81335 .31662 .81517 .31924 .81949 .31782 .81767 .3152 Mtetra
.81767 .3152 .81949 .31782 .82381 .3164 .822 .31378 Mtetra
.822 .31378 .82381 .3164 .82814 .31498 .82634 .31236 Mtetra
.82634 .31236 .82814 .31498 .83248 .31356 .83068 .31093 Mtetra
.83068 .31093 .83248 .31356 .83683 .31214 .83503 .3095 Mtetra
.83503 .3095 .83683 .31214 .84118 .31071 .83938 .30807 Mtetra
.83938 .30807 .84118 .31071 .84553 .30928 .84374 .30664 Mtetra
.84374 .30664 .84553 .30928 .8499 .30785 .84811 .3052 Mtetra
.84811 .3052 .8499 .30785 .85426 .30642 .85248 .30377 Mtetra
.85248 .30377 .85426 .30642 .85864 .30498 .85686 .30233 Mtetra
.85686 .30233 .85864 .30498 .86302 .30355 .86125 .30089 Mtetra
.86125 .30089 .86302 .30355 .86741 .30211 .86565 .29944 Mtetra
.86565 .29944 .86741 .30211 .87181 .30067 .87005 .298 Mtetra
.87005 .298 .87181 .30067 .87621 .29922 .87445 .29655 Mtetra
.87445 .29655 .87621 .29922 .88062 .29778 .87887 .2951 Mtetra
.28131 .48843 .28364 .4906 .28721 .48943 .28488 .48726 Mtetra
.28488 .48726 .28721 .48943 .29078 .48825 .28846 .48608 Mtetra
.28846 .48608 .29078 .48825 .29435 .48708 .29204 .48491 Mtetra
.29204 .48491 .29435 .48708 .29794 .4859 .29562 .48373 Mtetra
.29562 .48373 .29794 .4859 .30152 .48472 .29921 .48255 Mtetra
.29921 .48255 .30152 .48472 .30511 .48355 .30281 .48136 Mtetra
.30281 .48136 .30511 .48355 .30871 .48236 .30641 .48018 Mtetra
.30641 .48018 .30871 .48236 .31231 .48118 .31001 .47899 Mtetra
.31001 .47899 .31231 .48118 .31592 .48 .31362 .47781 Mtetra
.31362 .47781 .31592 .48 .31953 .47881 .31723 .47662 Mtetra
.31723 .47662 .31953 .47881 .32314 .47762 .32085 .47543 Mtetra
.32085 .47543 .32314 .47762 .32677 .47643 .32448 .47423 Mtetra
.32448 .47423 .32677 .47643 .33039 .47524 .32811 .47304 Mtetra
.32811 .47304 .33039 .47524 .33402 .47405 .33174 .47184 Mtetra
.33174 .47184 .33402 .47405 .33766 .47286 .33538 .47065 Mtetra
.33538 .47065 .33766 .47286 .3413 .47166 .33902 .46945 Mtetra
.33902 .46945 .3413 .47166 .34494 .47046 .34267 .46825 Mtetra
.34267 .46825 .34494 .47046 .3486 .46926 .34633 .46705 Mtetra
.34633 .46705 .3486 .46926 .35225 .46806 .34998 .46584 Mtetra
.34998 .46584 .35225 .46806 .35591 .46686 .35365 .46464 Mtetra
.35365 .46464 .35591 .46686 .35958 .46566 .35732 .46343 Mtetra
.35732 .46343 .35958 .46566 .36325 .46445 .36099 .46222 Mtetra
.947 .68 .497 r
.36099 .46222 .36325 .46445 .36693 .46324 .35685 .62121 Mtetra
.549 .327 .532 r
.35685 .62121 .36693 .46324 .36308 .62219 .36071 .62005 Mtetra
.651 .757 .927 r
.36071 .62005 .36308 .62219 .36694 .62103 .36458 .6189 Mtetra
.36458 .6189 .36694 .62103 .37081 .61988 .36845 .61774 Mtetra
.36845 .61774 .37081 .61988 .37468 .61872 .37232 .61658 Mtetra
.37232 .61658 .37468 .61872 .37856 .61756 .3762 .61542 Mtetra
.3762 .61542 .37856 .61756 .38244 .6164 .38009 .61425 Mtetra
.38009 .61425 .38244 .6164 .38633 .61524 .38398 .61309 Mtetra
.38398 .61309 .38633 .61524 .39023 .61407 .38788 .61192 Mtetra
.38788 .61192 .39023 .61407 .39413 .61291 .39178 .61075 Mtetra
.39178 .61075 .39413 .61291 .39803 .61174 .39569 .60958 Mtetra
.39569 .60958 .39803 .61174 .40194 .61057 .39961 .60841 Mtetra
.39961 .60841 .40194 .61057 .40586 .6094 .40353 .60723 Mtetra
.40353 .60723 .40586 .6094 .40978 .60823 .40745 .60606 Mtetra
.40745 .60606 .40978 .60823 .41371 .60705 .41138 .60488 Mtetra
.41138 .60488 .41371 .60705 .41764 .60588 .41532 .6037 Mtetra
.41532 .6037 .41764 .60588 .42158 .6047 .41927 .60252 Mtetra
.41927 .60252 .42158 .6047 .42553 .60352 .42321 .60134 Mtetra
.42321 .60134 .42553 .60352 .42948 .60234 .42717 .60015 Mtetra
.42717 .60015 .42948 .60234 .43205 .65319 .43113 .59897 Mtetra
0 0 .383 r
.43113 .59897 .43205 .65319 .43607 .65202 .43373 .64987 Mtetra
.646 .762 .934 r
.43373 .64987 .43607 .65202 .4401 .65086 .43776 .6487 Mtetra
.43776 .6487 .4401 .65086 .44413 .64969 .4418 .64753 Mtetra
.4418 .64753 .44413 .64969 .44817 .64852 .44584 .64636 Mtetra
.44584 .64636 .44817 .64852 .45222 .64735 .44989 .64519 Mtetra
.44989 .64519 .45222 .64735 .45627 .64618 .45395 .64401 Mtetra
.45395 .64401 .45627 .64618 .46033 .645 .45801 .64283 Mtetra
.45801 .64283 .46033 .645 .4644 .64383 .46208 .64165 Mtetra
.46208 .64165 .4644 .64383 .46847 .64265 .46616 .64047 Mtetra
.46616 .64047 .46847 .64265 .47254 .64147 .47024 .63929 Mtetra
.47024 .63929 .47254 .64147 .47663 .64029 .47432 .6381 Mtetra
.47432 .6381 .47663 .64029 .48071 .63911 .47842 .63692 Mtetra
.47842 .63692 .48071 .63911 .48481 .63792 .48251 .63573 Mtetra
.48251 .63573 .48481 .63792 .48891 .63673 .48662 .63454 Mtetra
.48662 .63454 .48891 .63673 .49302 .63555 .49073 .63335 Mtetra
.958 .702 .507 r
.49073 .63335 .49302 .63555 .4978 .55133 .49557 .54907 Mtetra
.653 .754 .924 r
.49557 .54907 .4978 .55133 .50182 .55011 .4996 .54784 Mtetra
.4996 .54784 .50182 .55011 .50585 .54888 .50363 .54661 Mtetra
.50363 .54661 .50585 .54888 .50988 .54765 .50766 .54538 Mtetra
.50766 .54538 .50988 .54765 .51392 .54642 .51171 .54415 Mtetra
.51171 .54415 .51392 .54642 .51796 .54519 .51576 .54291 Mtetra
.51576 .54291 .51796 .54519 .52201 .54396 .51981 .54167 Mtetra
.51981 .54167 .52201 .54396 .52607 .54272 .52387 .54044 Mtetra
.52387 .54044 .52607 .54272 .53013 .54148 .52794 .5392 Mtetra
.52794 .5392 .53013 .54148 .5342 .54024 .53201 .53795 Mtetra
.53201 .53795 .5342 .54024 .53828 .539 .53609 .53671 Mtetra
.53609 .53671 .53828 .539 .54236 .53776 .54017 .53546 Mtetra
.54017 .53546 .54236 .53776 .54645 .53652 .54426 .53421 Mtetra
.54426 .53421 .54645 .53652 .55054 .53527 .54836 .53297 Mtetra
.54836 .53297 .55054 .53527 .55464 .53402 .55247 .53171 Mtetra
.55247 .53171 .55464 .53402 .55874 .53277 .55657 .53046 Mtetra
.965 .698 .479 r
.55657 .53046 .55874 .53277 .56285 .53152 .55943 .41116 Mtetra
.558 .349 .553 r
.55943 .41116 .56285 .53152 .56549 .41226 .5634 .40986 Mtetra
.663 .743 .91 r
.5634 .40986 .56549 .41226 .56947 .41096 .56738 .40856 Mtetra
.56738 .40856 .56947 .41096 .57345 .40966 .57137 .40726 Mtetra
.57137 .40726 .57345 .40966 .57744 .40836 .57536 .40596 Mtetra
.57536 .40596 .57744 .40836 .58432 .57181 .57936 .40465 Mtetra
.556 .345 .55 r
.57936 .40465 .58432 .57181 .58852 .57056 .58337 .40335 Mtetra
0 0 .405 r
.58337 .40335 .58852 .57056 .59274 .56932 .59057 .56701 Mtetra
.649 .759 .929 r
.59057 .56701 .59274 .56932 .59696 .56807 .5948 .56576 Mtetra
.5948 .56576 .59696 .56807 .60118 .56682 .59903 .5645 Mtetra
.59903 .5645 .60118 .56682 .60541 .56556 .60326 .56325 Mtetra
.60326 .56325 .60541 .56556 .60965 .56431 .60751 .56199 Mtetra
.60751 .56199 .60965 .56431 .6139 .56305 .61175 .56073 Mtetra
.61175 .56073 .6139 .56305 .61815 .56179 .61601 .55946 Mtetra
.61601 .55946 .61815 .56179 .62241 .56053 .62027 .5582 Mtetra
.62027 .5582 .62241 .56053 .62667 .55927 .62454 .55693 Mtetra
.62454 .55693 .62667 .55927 .63094 .55801 .62882 .55567 Mtetra
.62882 .55567 .63094 .55801 .63522 .55674 .6331 .5544 Mtetra
.6331 .5544 .63522 .55674 .6395 .55547 .63739 .55312 Mtetra
.63739 .55312 .6395 .55547 .64379 .5542 .64168 .55185 Mtetra
.64168 .55185 .64379 .5542 .64809 .55293 .64598 .55057 Mtetra
.64598 .55057 .64809 .55293 .65239 .55165 .65029 .5493 Mtetra
.65029 .5493 .65239 .55165 .6567 .55038 .65461 .54802 Mtetra
.65461 .54802 .6567 .55038 .66102 .5491 .65893 .54674 Mtetra
.65893 .54674 .66102 .5491 .66535 .54782 .66326 .54545 Mtetra
.66326 .54545 .66535 .54782 .66968 .54654 .66759 .54417 Mtetra
.66759 .54417 .66968 .54654 .67401 .54525 .67193 .54288 Mtetra
.67193 .54288 .67401 .54525 .67836 .54397 .67628 .54159 Mtetra
.67628 .54159 .67836 .54397 .68271 .54268 .68063 .5403 Mtetra
.68063 .5403 .68271 .54268 .68706 .54139 .685 .539 Mtetra
.685 .539 .68706 .54139 .69143 .5401 .68936 .53771 Mtetra
.68936 .53771 .69143 .5401 .6958 .5388 .69374 .53641 Mtetra
.69374 .53641 .6958 .5388 .70017 .53751 .69812 .53511 Mtetra
.69812 .53511 .70017 .53751 .70456 .53621 .70251 .53381 Mtetra
.70251 .53381 .70456 .53621 .70895 .53491 .7069 .53251 Mtetra
.976 .717 .472 r
.7069 .53251 .70895 .53491 .7107 .4865 .70869 .48406 Mtetra
.653 .754 .924 r
.70869 .48406 .7107 .4865 .71504 .48518 .71303 .48274 Mtetra
.71303 .48274 .71504 .48518 .71939 .48386 .71738 .48141 Mtetra
.71738 .48141 .71939 .48386 .72374 .48253 .72174 .48008 Mtetra
.72174 .48008 .72374 .48253 .7281 .48121 .72611 .47875 Mtetra
.72611 .47875 .7281 .48121 .73247 .47988 .73048 .47742 Mtetra
.73048 .47742 .73247 .47988 .73684 .47854 .73485 .47608 Mtetra
.73485 .47608 .73684 .47854 .74122 .47721 .73924 .47474 Mtetra
.73924 .47474 .74122 .47721 .74561 .47587 .74363 .4734 Mtetra
.74363 .4734 .74561 .47587 .75 .47454 .74803 .47206 Mtetra
.74803 .47206 .75 .47454 .7544 .4732 .75244 .47072 Mtetra
.75244 .47072 .7544 .4732 .75881 .47185 .75685 .46937 Mtetra
.75685 .46937 .75881 .47185 .76322 .47051 .76127 .46802 Mtetra
.76127 .46802 .76322 .47051 .76764 .46916 .76569 .46667 Mtetra
.76569 .46667 .76764 .46916 .77207 .46782 .77012 .46532 Mtetra
.77012 .46532 .77207 .46782 .77651 .46647 .77456 .46397 Mtetra
.77456 .46397 .77651 .46647 .78095 .46511 .77901 .46261 Mtetra
.77901 .46261 .78095 .46511 .7854 .46376 .78346 .46125 Mtetra
.78346 .46125 .7854 .46376 .78985 .4624 .78792 .45989 Mtetra
.78792 .45989 .78985 .4624 .79431 .46104 .79239 .45853 Mtetra
.79239 .45853 .79431 .46104 .79878 .45968 .79686 .45717 Mtetra
.79686 .45717 .79878 .45968 .80326 .45832 .80134 .4558 Mtetra
.98 .689 .382 r
.80134 .4558 .80326 .45832 .80774 .45696 .79428 .31967 Mtetra
.557 .347 .552 r
.79428 .31967 .80774 .45696 .80042 .32087 .79858 .31826 Mtetra
.664 .741 .908 r
.79858 .31826 .80042 .32087 .80472 .31945 .80289 .31684 Mtetra
.80289 .31684 .80472 .31945 .80903 .31804 .8072 .31542 Mtetra
.8072 .31542 .80903 .31804 .81335 .31662 .81152 .314 Mtetra
.81152 .314 .81335 .31662 .81767 .3152 .81585 .31257 Mtetra
.81585 .31257 .81767 .3152 .822 .31378 .82018 .31115 Mtetra
.82018 .31115 .822 .31378 .82634 .31236 .82452 .30972 Mtetra
.82452 .30972 .82634 .31236 .83068 .31093 .82887 .30829 Mtetra
.82887 .30829 .83068 .31093 .83503 .3095 .83322 .30686 Mtetra
.83322 .30686 .83503 .3095 .83938 .30807 .83758 .30543 Mtetra
.83758 .30543 .83938 .30807 .84374 .30664 .84195 .30399 Mtetra
.84195 .30399 .84374 .30664 .84811 .3052 .84632 .30255 Mtetra
.84632 .30255 .84811 .3052 .85248 .30377 .8507 .30111 Mtetra
.8507 .30111 .85248 .30377 .85686 .30233 .85508 .29967 Mtetra
.85508 .29967 .85686 .30233 .86125 .30089 .85948 .29822 Mtetra
.85948 .29822 .86125 .30089 .86565 .29944 .86387 .29677 Mtetra
.86387 .29677 .86565 .29944 .87005 .298 .86828 .29532 Mtetra
.86828 .29532 .87005 .298 .87445 .29655 .87269 .29387 Mtetra
.87269 .29387 .87445 .29655 .87887 .2951 .87711 .29242 Mtetra
.27898 .48626 .28131 .48843 .28488 .48726 .28256 .48509 Mtetra
.28256 .48509 .28488 .48726 .28846 .48608 .28613 .48391 Mtetra
.28613 .48391 .28846 .48608 .29204 .48491 .28972 .48273 Mtetra
.28972 .48273 .29204 .48491 .29562 .48373 .2933 .48155 Mtetra
.2933 .48155 .29562 .48373 .29921 .48255 .2969 .48036 Mtetra
.2969 .48036 .29921 .48255 .30281 .48136 .30049 .47918 Mtetra
.30049 .47918 .30281 .48136 .30641 .48018 .3041 .47799 Mtetra
.3041 .47799 .30641 .48018 .31001 .47899 .3077 .4768 Mtetra
.3077 .4768 .31001 .47899 .31362 .47781 .31132 .47561 Mtetra
.31132 .47561 .31362 .47781 .31723 .47662 .31493 .47442 Mtetra
.31493 .47442 .31723 .47662 .32085 .47543 .31856 .47322 Mtetra
.31856 .47322 .32085 .47543 .32448 .47423 .32218 .47203 Mtetra
.32218 .47203 .32448 .47423 .32811 .47304 .32581 .47083 Mtetra
.32581 .47083 .32811 .47304 .33174 .47184 .32945 .46963 Mtetra
.32945 .46963 .33174 .47184 .33538 .47065 .33309 .46843 Mtetra
.33309 .46843 .33538 .47065 .33902 .46945 .33674 .46723 Mtetra
.33674 .46723 .33902 .46945 .34267 .46825 .34039 .46603 Mtetra
.34039 .46603 .34267 .46825 .34633 .46705 .34405 .46482 Mtetra
.34405 .46482 .34633 .46705 .34998 .46584 .34771 .46362 Mtetra
.34771 .46362 .34998 .46584 .35365 .46464 .35138 .46241 Mtetra
.35138 .46241 .35365 .46464 .35732 .46343 .35505 .4612 Mtetra
.947 .68 .498 r
.35505 .4612 .35732 .46343 .36099 .46222 .35062 .62023 Mtetra
.548 .327 .531 r
.35062 .62023 .36099 .46222 .35685 .62121 .35447 .61907 Mtetra
.651 .757 .927 r
.35447 .61907 .35685 .62121 .36071 .62005 .35833 .61792 Mtetra
.35833 .61792 .36071 .62005 .36458 .6189 .3622 .61676 Mtetra
.3622 .61676 .36458 .6189 .36845 .61774 .36607 .61559 Mtetra
.36607 .61559 .36845 .61774 .37232 .61658 .36995 .61443 Mtetra
.36995 .61443 .37232 .61658 .3762 .61542 .37384 .61327 Mtetra
.37384 .61327 .3762 .61542 .38009 .61425 .37773 .6121 Mtetra
.37773 .6121 .38009 .61425 .38398 .61309 .38162 .61093 Mtetra
.38162 .61093 .38398 .61309 .38788 .61192 .38552 .60976 Mtetra
.38552 .60976 .38788 .61192 .39178 .61075 .38943 .60859 Mtetra
.38943 .60859 .39178 .61075 .39569 .60958 .39334 .60741 Mtetra
.39334 .60741 .39569 .60958 .39961 .60841 .39726 .60624 Mtetra
.39726 .60624 .39961 .60841 .40353 .60723 .40119 .60506 Mtetra
.40119 .60506 .40353 .60723 .40745 .60606 .40512 .60388 Mtetra
.40512 .60388 .40745 .60606 .41138 .60488 .40905 .6027 Mtetra
.40905 .6027 .41138 .60488 .41532 .6037 .41299 .60152 Mtetra
.41299 .60152 .41532 .6037 .41927 .60252 .41694 .60034 Mtetra
.41694 .60034 .41927 .60252 .42321 .60134 .42089 .59915 Mtetra
.42089 .59915 .42321 .60134 .42717 .60015 .42485 .59796 Mtetra
.42485 .59796 .42717 .60015 .43113 .59897 .42882 .59677 Mtetra
.956 .662 .438 r
.42882 .59677 .43113 .59897 .43373 .64987 .43138 .64771 Mtetra
.646 .762 .934 r
.43138 .64771 .43373 .64987 .43776 .6487 .43542 .64654 Mtetra
.43542 .64654 .43776 .6487 .4418 .64753 .43946 .64537 Mtetra
.43946 .64537 .4418 .64753 .44584 .64636 .44351 .64419 Mtetra
.44351 .64419 .44584 .64636 .44989 .64519 .44756 .64301 Mtetra
.44756 .64301 .44989 .64519 .45395 .64401 .45162 .64183 Mtetra
.45162 .64183 .45395 .64401 .45801 .64283 .45569 .64065 Mtetra
.45569 .64065 .45801 .64283 .46208 .64165 .45976 .63947 Mtetra
.45976 .63947 .46208 .64165 .46616 .64047 .46384 .63829 Mtetra
.46384 .63829 .46616 .64047 .47024 .63929 .46792 .6371 Mtetra
.46792 .6371 .47024 .63929 .47432 .6381 .47201 .63591 Mtetra
.47201 .63591 .47432 .6381 .47842 .63692 .47611 .63472 Mtetra
.47611 .63472 .47842 .63692 .48251 .63573 .48021 .63353 Mtetra
.48021 .63353 .48251 .63573 .48662 .63454 .48432 .63234 Mtetra
.48432 .63234 .48662 .63454 .49073 .63335 .48844 .63114 Mtetra
.958 .702 .507 r
.48844 .63114 .49073 .63335 .49557 .54907 .49334 .5468 Mtetra
.653 .754 .924 r
.49334 .5468 .49557 .54907 .4996 .54784 .49737 .54557 Mtetra
.49737 .54557 .4996 .54784 .50363 .54661 .5014 .54434 Mtetra
.5014 .54434 .50363 .54661 .50766 .54538 .50544 .5431 Mtetra
.50544 .5431 .50766 .54538 .51171 .54415 .50949 .54186 Mtetra
.50949 .54186 .51171 .54415 .51576 .54291 .51354 .54063 Mtetra
.51354 .54063 .51576 .54291 .51981 .54167 .5176 .53939 Mtetra
.5176 .53939 .51981 .54167 .52387 .54044 .52166 .53814 Mtetra
.52166 .53814 .52387 .54044 .52794 .5392 .52574 .5369 Mtetra
.52574 .5369 .52794 .5392 .53201 .53795 .52981 .53565 Mtetra
.52981 .53565 .53201 .53795 .53609 .53671 .53389 .53441 Mtetra
.53389 .53441 .53609 .53671 .54017 .53546 .53798 .53316 Mtetra
.53798 .53316 .54017 .53546 .54426 .53421 .54208 .53191 Mtetra
.54208 .53191 .54426 .53421 .54836 .53297 .54618 .53065 Mtetra
.54618 .53065 .54836 .53297 .55247 .53171 .55029 .5294 Mtetra
.55029 .5294 .55247 .53171 .55657 .53046 .5544 .52814 Mtetra
.965 .698 .479 r
.5544 .52814 .55657 .53046 .55943 .41116 .55733 .40876 Mtetra
.663 .743 .91 r
.55733 .40876 .55943 .41116 .5634 .40986 .56131 .40746 Mtetra
.56131 .40746 .5634 .40986 .56738 .40856 .5653 .40616 Mtetra
.5653 .40616 .56738 .40856 .57137 .40726 .56929 .40485 Mtetra
.56929 .40485 .57137 .40726 .57536 .40596 .57328 .40355 Mtetra
.57328 .40355 .57536 .40596 .57936 .40465 .57729 .40224 Mtetra
.57729 .40224 .57936 .40465 .58337 .40335 .58129 .40093 Mtetra
.58129 .40093 .58337 .40335 .59057 .56701 .58531 .39962 Mtetra
.556 .345 .549 r
.58531 .39962 .59057 .56701 .5948 .56576 .58933 .3983 Mtetra
0 0 .406 r
.58933 .3983 .5948 .56576 .59903 .5645 .59686 .56218 Mtetra
.649 .759 .929 r
.59686 .56218 .59903 .5645 .60326 .56325 .60111 .56092 Mtetra
.60111 .56092 .60326 .56325 .60751 .56199 .60535 .55966 Mtetra
.60535 .55966 .60751 .56199 .61175 .56073 .60961 .55839 Mtetra
.60961 .55839 .61175 .56073 .61601 .55946 .61387 .55713 Mtetra
.61387 .55713 .61601 .55946 .62027 .5582 .61813 .55586 Mtetra
.61813 .55586 .62027 .5582 .62454 .55693 .62241 .55459 Mtetra
.62241 .55459 .62454 .55693 .62882 .55567 .62669 .55332 Mtetra
.62669 .55332 .62882 .55567 .6331 .5544 .63097 .55205 Mtetra
.63097 .55205 .6331 .5544 .63739 .55312 .63526 .55077 Mtetra
.63526 .55077 .63739 .55312 .64168 .55185 .63956 .54949 Mtetra
.63956 .54949 .64168 .55185 .64598 .55057 .64387 .54821 Mtetra
.64387 .54821 .64598 .55057 .65029 .5493 .64818 .54693 Mtetra
.64818 .54693 .65029 .5493 .65461 .54802 .6525 .54565 Mtetra
.6525 .54565 .65461 .54802 .65893 .54674 .65683 .54436 Mtetra
.65683 .54436 .65893 .54674 .66326 .54545 .66116 .54308 Mtetra
.66116 .54308 .66326 .54545 .66759 .54417 .6655 .54179 Mtetra
.6655 .54179 .66759 .54417 .67193 .54288 .66985 .5405 Mtetra
.66985 .5405 .67193 .54288 .67628 .54159 .6742 .5392 Mtetra
.6742 .5392 .67628 .54159 .68063 .5403 .67856 .53791 Mtetra
.67856 .53791 .68063 .5403 .685 .539 .68292 .53661 Mtetra
.68292 .53661 .685 .539 .68936 .53771 .6873 .53531 Mtetra
.6873 .53531 .68936 .53771 .69374 .53641 .69168 .53401 Mtetra
.69168 .53401 .69374 .53641 .69812 .53511 .69606 .53271 Mtetra
.69606 .53271 .69812 .53511 .70251 .53381 .70046 .5314 Mtetra
.70046 .5314 .70251 .53381 .7069 .53251 .70485 .53009 Mtetra
.976 .717 .472 r
.70485 .53009 .7069 .53251 .70869 .48406 .70667 .48161 Mtetra
.653 .754 .924 r
.70667 .48161 .70869 .48406 .71303 .48274 .71102 .48028 Mtetra
.71102 .48028 .71303 .48274 .71738 .48141 .71537 .47895 Mtetra
.71537 .47895 .71738 .48141 .72174 .48008 .71973 .47762 Mtetra
.71973 .47762 .72174 .48008 .72611 .47875 .7241 .47629 Mtetra
.7241 .47629 .72611 .47875 .73048 .47742 .72848 .47495 Mtetra
.72848 .47495 .73048 .47742 .73485 .47608 .73286 .47361 Mtetra
.73286 .47361 .73485 .47608 .73924 .47474 .73725 .47227 Mtetra
.73725 .47227 .73924 .47474 .74363 .4734 .74165 .47092 Mtetra
.74165 .47092 .74363 .4734 .74803 .47206 .74605 .46958 Mtetra
.74605 .46958 .74803 .47206 .75244 .47072 .75046 .46823 Mtetra
.75046 .46823 .75244 .47072 .75685 .46937 .75488 .46688 Mtetra
.75488 .46688 .75685 .46937 .76127 .46802 .7593 .46553 Mtetra
.7593 .46553 .76127 .46802 .76569 .46667 .76373 .46418 Mtetra
.76373 .46418 .76569 .46667 .77012 .46532 .76817 .46282 Mtetra
.76817 .46282 .77012 .46532 .77456 .46397 .77261 .46146 Mtetra
.77261 .46146 .77456 .46397 .77901 .46261 .77707 .4601 Mtetra
.77707 .4601 .77901 .46261 .78346 .46125 .78152 .45874 Mtetra
.78152 .45874 .78346 .46125 .78792 .45989 .78599 .45738 Mtetra
.78599 .45738 .78792 .45989 .79239 .45853 .79046 .45601 Mtetra
.79046 .45601 .79239 .45853 .79686 .45717 .79494 .45464 Mtetra
.79494 .45464 .79686 .45717 .80134 .4558 .79942 .45327 Mtetra
.98 .689 .382 r
.79942 .45327 .80134 .4558 .79428 .31967 .79243 .31706 Mtetra
.664 .741 .908 r
.79243 .31706 .79428 .31967 .79858 .31826 .79673 .31564 Mtetra
.79673 .31564 .79858 .31826 .80289 .31684 .80104 .31422 Mtetra
.80104 .31422 .80289 .31684 .8072 .31542 .80536 .31279 Mtetra
.80536 .31279 .8072 .31542 .81152 .314 .80969 .31137 Mtetra
.80969 .31137 .81152 .314 .81585 .31257 .81402 .30994 Mtetra
.81402 .30994 .81585 .31257 .82018 .31115 .81836 .30851 Mtetra
.81836 .30851 .82018 .31115 .82452 .30972 .8227 .30708 Mtetra
.8227 .30708 .82452 .30972 .82887 .30829 .82705 .30565 Mtetra
.82705 .30565 .82887 .30829 .83322 .30686 .83141 .30421 Mtetra
.83141 .30421 .83322 .30686 .83758 .30543 .83577 .30277 Mtetra
.83577 .30277 .83758 .30543 .84195 .30399 .84015 .30133 Mtetra
.84015 .30133 .84195 .30399 .84632 .30255 .84452 .29989 Mtetra
.84452 .29989 .84632 .30255 .8507 .30111 .84891 .29844 Mtetra
.84891 .29844 .8507 .30111 .85508 .29967 .8533 .297 Mtetra
.8533 .297 .85508 .29967 .85948 .29822 .85769 .29555 Mtetra
.85769 .29555 .85948 .29822 .86387 .29677 .8621 .2941 Mtetra
.8621 .2941 .86387 .29677 .86828 .29532 .86651 .29264 Mtetra
.86651 .29264 .86828 .29532 .87269 .29387 .87093 .29119 Mtetra
.87093 .29119 .87269 .29387 .87711 .29242 .87535 .28973 Mtetra
.27665 .48409 .27898 .48626 .28256 .48509 .28022 .48291 Mtetra
.28022 .48291 .28256 .48509 .28613 .48391 .2838 .48173 Mtetra
.2838 .48173 .28613 .48391 .28972 .48273 .28739 .48054 Mtetra
.28739 .48054 .28972 .48273 .2933 .48155 .29098 .47936 Mtetra
.29098 .47936 .2933 .48155 .2969 .48036 .29458 .47817 Mtetra
.29458 .47817 .2969 .48036 .30049 .47918 .29818 .47698 Mtetra
.29818 .47698 .30049 .47918 .3041 .47799 .30178 .47579 Mtetra
.30178 .47579 .3041 .47799 .3077 .4768 .30539 .4746 Mtetra
.30539 .4746 .3077 .4768 .31132 .47561 .30901 .47341 Mtetra
.30901 .47341 .31132 .47561 .31493 .47442 .31263 .47221 Mtetra
.31263 .47221 .31493 .47442 .31856 .47322 .31625 .47102 Mtetra
.31625 .47102 .31856 .47322 .32218 .47203 .31988 .46982 Mtetra
.31988 .46982 .32218 .47203 .32581 .47083 .32352 .46862 Mtetra
.32352 .46862 .32581 .47083 .32945 .46963 .32716 .46742 Mtetra
.32716 .46742 .32945 .46963 .33309 .46843 .3308 .46621 Mtetra
.3308 .46621 .33309 .46843 .33674 .46723 .33445 .46501 Mtetra
.33445 .46501 .33674 .46723 .34039 .46603 .33811 .4638 Mtetra
.33811 .4638 .34039 .46603 .34405 .46482 .34177 .46259 Mtetra
.34177 .46259 .34405 .46482 .34771 .46362 .34543 .46138 Mtetra
.34543 .46138 .34771 .46362 .35138 .46241 .3491 .46017 Mtetra
.947 .68 .499 r
.3491 .46017 .35138 .46241 .35505 .4612 .34437 .61925 Mtetra
.548 .326 .531 r
.34437 .61925 .35505 .4612 .35062 .62023 .34822 .61809 Mtetra
.651 .757 .927 r
.34822 .61809 .35062 .62023 .35447 .61907 .35208 .61694 Mtetra
.35208 .61694 .35447 .61907 .35833 .61792 .35595 .61577 Mtetra
.35595 .61577 .35833 .61792 .3622 .61676 .35982 .61461 Mtetra
.35982 .61461 .3622 .61676 .36607 .61559 .3637 .61345 Mtetra
.3637 .61345 .36607 .61559 .36995 .61443 .36758 .61228 Mtetra
.36758 .61228 .36995 .61443 .37384 .61327 .37147 .61111 Mtetra
.37147 .61111 .37384 .61327 .37773 .6121 .37536 .60994 Mtetra
.37536 .60994 .37773 .6121 .38162 .61093 .37926 .60877 Mtetra
.37926 .60877 .38162 .61093 .38552 .60976 .38316 .6076 Mtetra
.38316 .6076 .38552 .60976 .38943 .60859 .38707 .60642 Mtetra
.38707 .60642 .38943 .60859 .39334 .60741 .39099 .60524 Mtetra
.39099 .60524 .39334 .60741 .39726 .60624 .39491 .60406 Mtetra
.39491 .60406 .39726 .60624 .40119 .60506 .39884 .60288 Mtetra
.39884 .60288 .40119 .60506 .40512 .60388 .40277 .6017 Mtetra
.40277 .6017 .40512 .60388 .40905 .6027 .40671 .60052 Mtetra
.40671 .60052 .40905 .6027 .41299 .60152 .41066 .59933 Mtetra
.41066 .59933 .41299 .60152 .41694 .60034 .41461 .59815 Mtetra
.41461 .59815 .41694 .60034 .42089 .59915 .41857 .59696 Mtetra
.41857 .59696 .42089 .59915 .42485 .59796 .42253 .59577 Mtetra
.42253 .59577 .42485 .59796 .42882 .59677 .4265 .59457 Mtetra
.956 .662 .438 r
.4265 .59457 .42882 .59677 .43138 .64771 .42903 .64555 Mtetra
.646 .762 .934 r
.42903 .64555 .43138 .64771 .43542 .64654 .43307 .64437 Mtetra
.43307 .64437 .43542 .64654 .43946 .64537 .43711 .64319 Mtetra
.43711 .64319 .43946 .64537 .44351 .64419 .44116 .64202 Mtetra
.44116 .64202 .44351 .64419 .44756 .64301 .44522 .64084 Mtetra
.44522 .64084 .44756 .64301 .45162 .64183 .44929 .63965 Mtetra
.44929 .63965 .45162 .64183 .45569 .64065 .45336 .63847 Mtetra
.45336 .63847 .45569 .64065 .45976 .63947 .45743 .63728 Mtetra
.45743 .63728 .45976 .63947 .46384 .63829 .46152 .6361 Mtetra
.46152 .6361 .46384 .63829 .46792 .6371 .4656 .63491 Mtetra
.4656 .63491 .46792 .6371 .47201 .63591 .4697 .63371 Mtetra
.4697 .63371 .47201 .63591 .47611 .63472 .4738 .63252 Mtetra
.4738 .63252 .47611 .63472 .48021 .63353 .47791 .63133 Mtetra
.47791 .63133 .48021 .63353 .48432 .63234 .48202 .63013 Mtetra
.48202 .63013 .48432 .63234 .48844 .63114 .48614 .62893 Mtetra
.958 .702 .507 r
.48614 .62893 .48844 .63114 .49334 .5468 .4911 .54453 Mtetra
.653 .754 .924 r
.4911 .54453 .49334 .5468 .49737 .54557 .49513 .54329 Mtetra
.49513 .54329 .49737 .54557 .5014 .54434 .49917 .54206 Mtetra
.49917 .54206 .5014 .54434 .50544 .5431 .50321 .54082 Mtetra
.50321 .54082 .50544 .5431 .50949 .54186 .50726 .53958 Mtetra
.50726 .53958 .50949 .54186 .51354 .54063 .51132 .53834 Mtetra
.51132 .53834 .51354 .54063 .5176 .53939 .51538 .53709 Mtetra
.51538 .53709 .5176 .53939 .52166 .53814 .51945 .53585 Mtetra
.51945 .53585 .52166 .53814 .52574 .5369 .52353 .5346 Mtetra
.52353 .5346 .52574 .5369 .52981 .53565 .52761 .53335 Mtetra
.52761 .53335 .52981 .53565 .53389 .53441 .53169 .5321 Mtetra
.53169 .5321 .53389 .53441 .53798 .53316 .53579 .53085 Mtetra
.53579 .53085 .53798 .53316 .54208 .53191 .53989 .52959 Mtetra
.53989 .52959 .54208 .53191 .54618 .53065 .54399 .52833 Mtetra
.54399 .52833 .54618 .53065 .55029 .5294 .5481 .52708 Mtetra
.964 .698 .48 r
.5481 .52708 .55029 .5294 .5544 .52814 .55126 .40766 Mtetra
.557 .348 .552 r
.55126 .40766 .5544 .52814 .55733 .40876 .55523 .40636 Mtetra
.663 .743 .91 r
.55523 .40636 .55733 .40876 .56131 .40746 .55922 .40505 Mtetra
.55922 .40505 .56131 .40746 .5653 .40616 .5632 .40375 Mtetra
.5632 .40375 .5653 .40616 .56929 .40485 .5672 .40244 Mtetra
.5672 .40244 .56929 .40485 .57328 .40355 .5712 .40113 Mtetra
.5712 .40113 .57328 .40355 .57729 .40224 .5752 .39982 Mtetra
.5752 .39982 .57729 .40224 .58129 .40093 .57922 .3985 Mtetra
.57922 .3985 .58129 .40093 .58531 .39962 .58323 .39719 Mtetra
.58323 .39719 .58531 .39962 .58933 .3983 .58726 .39587 Mtetra
.58726 .39587 .58933 .3983 .59686 .56218 .59129 .39455 Mtetra
.555 .344 .549 r
.59129 .39455 .59686 .56218 .60111 .56092 .59532 .39323 Mtetra
0 0 .408 r
.59532 .39323 .60111 .56092 .60535 .55966 .60319 .55732 Mtetra
.649 .759 .929 r
.60319 .55732 .60535 .55966 .60961 .55839 .60745 .55606 Mtetra
.60745 .55606 .60961 .55839 .61387 .55713 .61172 .55479 Mtetra
.61172 .55479 .61387 .55713 .61813 .55586 .61599 .55352 Mtetra
.61599 .55352 .61813 .55586 .62241 .55459 .62026 .55224 Mtetra
.62026 .55224 .62241 .55459 .62669 .55332 .62455 .55097 Mtetra
.62455 .55097 .62669 .55332 .63097 .55205 .62884 .54969 Mtetra
.62884 .54969 .63097 .55205 .63526 .55077 .63314 .54841 Mtetra
.63314 .54841 .63526 .55077 .63956 .54949 .63744 .54713 Mtetra
.63744 .54713 .63956 .54949 .64387 .54821 .64175 .54585 Mtetra
.64175 .54585 .64387 .54821 .64818 .54693 .64607 .54456 Mtetra
.64607 .54456 .64818 .54693 .6525 .54565 .65039 .54327 Mtetra
.65039 .54327 .6525 .54565 .65683 .54436 .65472 .54199 Mtetra
.65472 .54199 .65683 .54436 .66116 .54308 .65906 .54069 Mtetra
.65906 .54069 .66116 .54308 .6655 .54179 .6634 .5394 Mtetra
.6634 .5394 .6655 .54179 .66985 .5405 .66775 .53811 Mtetra
.66775 .53811 .66985 .5405 .6742 .5392 .67211 .53681 Mtetra
.67211 .53681 .6742 .5392 .67856 .53791 .67647 .53551 Mtetra
.67647 .53551 .67856 .53791 .68292 .53661 .68085 .53421 Mtetra
.68085 .53421 .68292 .53661 .6873 .53531 .68522 .53291 Mtetra
.68522 .53291 .6873 .53531 .69168 .53401 .68961 .5316 Mtetra
.68961 .5316 .69168 .53401 .69606 .53271 .694 .53029 Mtetra
.694 .53029 .69606 .53271 .70046 .5314 .6984 .52899 Mtetra
.6984 .52899 .70046 .5314 .70485 .53009 .7028 .52767 Mtetra
.976 .717 .472 r
.7028 .52767 .70485 .53009 .70667 .48161 .70464 .47916 Mtetra
.653 .754 .924 r
.70464 .47916 .70667 .48161 .71102 .48028 .709 .47783 Mtetra
.709 .47783 .71102 .48028 .71537 .47895 .71336 .47649 Mtetra
.71336 .47649 .71537 .47895 .71973 .47762 .71772 .47515 Mtetra
.71772 .47515 .71973 .47762 .7241 .47629 .7221 .47382 Mtetra
.7221 .47382 .7241 .47629 .72848 .47495 .72648 .47247 Mtetra
.72648 .47247 .72848 .47495 .73286 .47361 .73087 .47113 Mtetra
.73087 .47113 .73286 .47361 .73725 .47227 .73526 .46979 Mtetra
.73526 .46979 .73725 .47227 .74165 .47092 .73966 .46844 Mtetra
.73966 .46844 .74165 .47092 .74605 .46958 .74407 .46709 Mtetra
.74407 .46709 .74605 .46958 .75046 .46823 .74848 .46574 Mtetra
.74848 .46574 .75046 .46823 .75488 .46688 .75291 .46438 Mtetra
.75291 .46438 .75488 .46688 .7593 .46553 .75733 .46303 Mtetra
.75733 .46303 .7593 .46553 .76373 .46418 .76177 .46167 Mtetra
.76177 .46167 .76373 .46418 .76817 .46282 .76621 .46031 Mtetra
.76621 .46031 .76817 .46282 .77261 .46146 .77066 .45895 Mtetra
.77066 .45895 .77261 .46146 .77707 .4601 .77512 .45759 Mtetra
.77512 .45759 .77707 .4601 .78152 .45874 .77958 .45622 Mtetra
.77958 .45622 .78152 .45874 .78599 .45738 .78405 .45485 Mtetra
.78405 .45485 .78599 .45738 .79046 .45601 .78853 .45348 Mtetra
.78853 .45348 .79046 .45601 .79494 .45464 .79301 .45211 Mtetra
.79301 .45211 .79494 .45464 .79942 .45327 .7975 .45073 Mtetra
.98 .689 .382 r
.7975 .45073 .79942 .45327 .79243 .31706 .79057 .31444 Mtetra
.664 .741 .908 r
.79057 .31444 .79243 .31706 .79673 .31564 .79488 .31301 Mtetra
.79488 .31301 .79673 .31564 .80104 .31422 .7992 .31159 Mtetra
.7992 .31159 .80104 .31422 .80536 .31279 .80352 .31016 Mtetra
.80352 .31016 .80536 .31279 .80969 .31137 .80785 .30873 Mtetra
.80785 .30873 .80969 .31137 .81402 .30994 .81219 .3073 Mtetra
.81219 .3073 .81402 .30994 .81836 .30851 .81653 .30587 Mtetra
.81653 .30587 .81836 .30851 .8227 .30708 .82088 .30443 Mtetra
.82088 .30443 .8227 .30708 .82705 .30565 .82523 .30299 Mtetra
.82523 .30299 .82705 .30565 .83141 .30421 .8296 .30155 Mtetra
.8296 .30155 .83141 .30421 .83577 .30277 .83396 .30011 Mtetra
.83396 .30011 .83577 .30277 .84015 .30133 .83834 .29867 Mtetra
.83834 .29867 .84015 .30133 .84452 .29989 .84272 .29722 Mtetra
.84272 .29722 .84452 .29989 .84891 .29844 .84711 .29577 Mtetra
.84711 .29577 .84891 .29844 .8533 .297 .85151 .29432 Mtetra
.85151 .29432 .8533 .297 .85769 .29555 .85591 .29287 Mtetra
.85591 .29287 .85769 .29555 .8621 .2941 .86032 .29141 Mtetra
.86032 .29141 .8621 .2941 .86651 .29264 .86473 .28995 Mtetra
.86473 .28995 .86651 .29264 .87093 .29119 .86915 .28849 Mtetra
.86915 .28849 .87093 .29119 .87535 .28973 .87358 .28703 Mtetra
.27431 .48191 .27665 .48409 .28022 .48291 .27789 .48073 Mtetra
.27789 .48073 .28022 .48291 .2838 .48173 .28147 .47954 Mtetra
.28147 .47954 .2838 .48173 .28739 .48054 .28506 .47835 Mtetra
.28506 .47835 .28739 .48054 .29098 .47936 .28865 .47717 Mtetra
.28865 .47717 .29098 .47936 .29458 .47817 .29225 .47598 Mtetra
.29225 .47598 .29458 .47817 .29818 .47698 .29585 .47478 Mtetra
.29585 .47478 .29818 .47698 .30178 .47579 .29946 .47359 Mtetra
.29946 .47359 .30178 .47579 .30539 .4746 .30307 .4724 Mtetra
.30307 .4724 .30539 .4746 .30901 .47341 .30669 .4712 Mtetra
.30669 .4712 .30901 .47341 .31263 .47221 .31031 .47 Mtetra
.31031 .47 .31263 .47221 .31625 .47102 .31394 .4688 Mtetra
.31394 .4688 .31625 .47102 .31988 .46982 .31758 .4676 Mtetra
.31758 .4676 .31988 .46982 .32352 .46862 .32121 .4664 Mtetra
.32121 .4664 .32352 .46862 .32716 .46742 .32486 .46519 Mtetra
.32486 .46519 .32716 .46742 .3308 .46621 .3285 .46399 Mtetra
.3285 .46399 .3308 .46621 .33445 .46501 .33216 .46278 Mtetra
.33216 .46278 .33445 .46501 .33811 .4638 .33582 .46157 Mtetra
.33582 .46157 .33811 .4638 .34177 .46259 .33948 .46036 Mtetra
.33948 .46036 .34177 .46259 .34543 .46138 .34315 .45915 Mtetra
.946 .68 .5 r
.34315 .45915 .34543 .46138 .3491 .46017 .33812 .61827 Mtetra
.547 .325 .53 r
.33812 .61827 .3491 .46017 .34437 .61925 .34197 .61711 Mtetra
.651 .757 .927 r
.34197 .61711 .34437 .61925 .34822 .61809 .34583 .61595 Mtetra
.34583 .61595 .34822 .61809 .35208 .61694 .34969 .61479 Mtetra
.34969 .61479 .35208 .61694 .35595 .61577 .35356 .61362 Mtetra
.35356 .61362 .35595 .61577 .35982 .61461 .35743 .61246 Mtetra
.35743 .61246 .35982 .61461 .3637 .61345 .36131 .61129 Mtetra
.36131 .61129 .3637 .61345 .36758 .61228 .3652 .61012 Mtetra
.3652 .61012 .36758 .61228 .37147 .61111 .36909 .60895 Mtetra
.36909 .60895 .37147 .61111 .37536 .60994 .37299 .60778 Mtetra
.37299 .60778 .37536 .60994 .37926 .60877 .37689 .6066 Mtetra
.37689 .6066 .37926 .60877 .38316 .6076 .3808 .60542 Mtetra
.3808 .60542 .38316 .6076 .38707 .60642 .38471 .60425 Mtetra
.38471 .60425 .38707 .60642 .39099 .60524 .38863 .60307 Mtetra
.38863 .60307 .39099 .60524 .39491 .60406 .39256 .60188 Mtetra
.39256 .60188 .39491 .60406 .39884 .60288 .39649 .6007 Mtetra
.39649 .6007 .39884 .60288 .40277 .6017 .40042 .59952 Mtetra
.40042 .59952 .40277 .6017 .40671 .60052 .40437 .59833 Mtetra
.40437 .59833 .40671 .60052 .41066 .59933 .40832 .59714 Mtetra
.40832 .59714 .41066 .59933 .41461 .59815 .41227 .59595 Mtetra
.41227 .59595 .41461 .59815 .41857 .59696 .41623 .59476 Mtetra
.41623 .59476 .41857 .59696 .42253 .59577 .4202 .59356 Mtetra
.4202 .59356 .42253 .59577 .4265 .59457 .42417 .59237 Mtetra
.42417 .59237 .4265 .59457 .42903 .64555 .42815 .59117 Mtetra
0 0 .38 r
.42815 .59117 .42903 .64555 .43307 .64437 .43071 .6422 Mtetra
.646 .762 .934 r
.43071 .6422 .43307 .64437 .43711 .64319 .43476 .64102 Mtetra
.43476 .64102 .43711 .64319 .44116 .64202 .43882 .63983 Mtetra
.43882 .63983 .44116 .64202 .44522 .64084 .44288 .63865 Mtetra
.44288 .63865 .44522 .64084 .44929 .63965 .44695 .63747 Mtetra
.44695 .63747 .44929 .63965 .45336 .63847 .45102 .63628 Mtetra
.45102 .63628 .45336 .63847 .45743 .63728 .4551 .63509 Mtetra
.4551 .63509 .45743 .63728 .46152 .6361 .45919 .6339 Mtetra
.45919 .6339 .46152 .6361 .4656 .63491 .46328 .63271 Mtetra
.46328 .63271 .4656 .63491 .4697 .63371 .46738 .63151 Mtetra
.46738 .63151 .4697 .63371 .4738 .63252 .47148 .63031 Mtetra
.47148 .63031 .4738 .63252 .47791 .63133 .47559 .62912 Mtetra
.47559 .62912 .47791 .63133 .48202 .63013 .47971 .62792 Mtetra
.47971 .62792 .48202 .63013 .48614 .62893 .48383 .62671 Mtetra
.958 .702 .507 r
.48383 .62671 .48614 .62893 .4911 .54453 .48885 .54225 Mtetra
.653 .754 .924 r
.48885 .54225 .4911 .54453 .49513 .54329 .49289 .54101 Mtetra
.49289 .54101 .49513 .54329 .49917 .54206 .49693 .53977 Mtetra
.49693 .53977 .49917 .54206 .50321 .54082 .50098 .53853 Mtetra
.50098 .53853 .50321 .54082 .50726 .53958 .50504 .53728 Mtetra
.50504 .53728 .50726 .53958 .51132 .53834 .5091 .53604 Mtetra
.5091 .53604 .51132 .53834 .51538 .53709 .51316 .53479 Mtetra
.51316 .53479 .51538 .53709 .51945 .53585 .51723 .53354 Mtetra
.51723 .53354 .51945 .53585 .52353 .5346 .52131 .53229 Mtetra
.52131 .53229 .52353 .5346 .52761 .53335 .5254 .53104 Mtetra
.5254 .53104 .52761 .53335 .53169 .5321 .52949 .52978 Mtetra
.52949 .52978 .53169 .5321 .53579 .53085 .53359 .52853 Mtetra
.53359 .52853 .53579 .53085 .53989 .52959 .53769 .52727 Mtetra
.53769 .52727 .53989 .52959 .54399 .52833 .5418 .52601 Mtetra
.964 .698 .481 r
.5418 .52601 .54399 .52833 .5481 .52708 .54517 .40656 Mtetra
.556 .347 .552 r
.54517 .40656 .5481 .52708 .55126 .40766 .54915 .40526 Mtetra
.663 .743 .91 r
.54915 .40526 .55126 .40766 .55523 .40636 .55313 .40395 Mtetra
.55313 .40395 .55523 .40636 .55922 .40505 .55711 .40264 Mtetra
.55711 .40264 .55922 .40505 .5632 .40375 .5611 .40133 Mtetra
.5611 .40133 .5632 .40375 .5672 .40244 .5651 .40002 Mtetra
.5651 .40002 .5672 .40244 .5712 .40113 .56911 .39871 Mtetra
.56911 .39871 .5712 .40113 .5752 .39982 .57312 .39739 Mtetra
.57312 .39739 .5752 .39982 .57922 .3985 .57713 .39607 Mtetra
.57713 .39607 .57922 .3985 .58323 .39719 .58115 .39475 Mtetra
.58115 .39475 .58323 .39719 .58726 .39587 .58518 .39343 Mtetra
.58518 .39343 .58726 .39587 .59129 .39455 .58921 .39211 Mtetra
.58921 .39211 .59129 .39455 .59532 .39323 .59325 .39078 Mtetra
.59325 .39078 .59532 .39323 .60319 .55732 .5973 .38946 Mtetra
.555 .344 .548 r
.5973 .38946 .60319 .55732 .60745 .55606 .60135 .38813 Mtetra
.60135 .38813 .60745 .55606 .61172 .55479 .6054 .3868 Mtetra
0 0 .41 r
.6054 .3868 .61172 .55479 .61599 .55352 .61384 .55116 Mtetra
.649 .759 .929 r
.61384 .55116 .61599 .55352 .62026 .55224 .61812 .54989 Mtetra
.61812 .54989 .62026 .55224 .62455 .55097 .62241 .54861 Mtetra
.62241 .54861 .62455 .55097 .62884 .54969 .6267 .54733 Mtetra
.6267 .54733 .62884 .54969 .63314 .54841 .631 .54604 Mtetra
.631 .54604 .63314 .54841 .63744 .54713 .63531 .54476 Mtetra
.63531 .54476 .63744 .54713 .64175 .54585 .63963 .54347 Mtetra
.63963 .54347 .64175 .54585 .64607 .54456 .64395 .54218 Mtetra
.64395 .54218 .64607 .54456 .65039 .54327 .64828 .54089 Mtetra
.64828 .54089 .65039 .54327 .65472 .54199 .65261 .5396 Mtetra
.65261 .5396 .65472 .54199 .65906 .54069 .65695 .53831 Mtetra
.65695 .53831 .65906 .54069 .6634 .5394 .6613 .53701 Mtetra
.6613 .53701 .6634 .5394 .66775 .53811 .66566 .53571 Mtetra
.66566 .53571 .66775 .53811 .67211 .53681 .67002 .53441 Mtetra
.67002 .53441 .67211 .53681 .67647 .53551 .67439 .53311 Mtetra
.67439 .53311 .67647 .53551 .68085 .53421 .67876 .5318 Mtetra
.67876 .5318 .68085 .53421 .68522 .53291 .68314 .5305 Mtetra
.68314 .5305 .68522 .53291 .68961 .5316 .68753 .52919 Mtetra
.68753 .52919 .68961 .5316 .694 .53029 .69193 .52788 Mtetra
.69193 .52788 .694 .53029 .6984 .52899 .69633 .52656 Mtetra
.69633 .52656 .6984 .52899 .7028 .52767 .70074 .52525 Mtetra
.896 .802 .748 r
.70074 .52525 .7028 .52767 .70464 .47916 .70487 .51862 Mtetra
0 0 .354 r
.70487 .51862 .70464 .47916 .709 .47783 .70697 .47536 Mtetra
.653 .754 .924 r
.70697 .47536 .709 .47783 .71336 .47649 .71133 .47402 Mtetra
.71133 .47402 .71336 .47649 .71772 .47515 .71571 .47268 Mtetra
.71571 .47268 .71772 .47515 .7221 .47382 .72009 .47134 Mtetra
.72009 .47134 .7221 .47382 .72648 .47247 .72447 .46999 Mtetra
.72447 .46999 .72648 .47247 .73087 .47113 .72886 .46865 Mtetra
.72886 .46865 .73087 .47113 .73526 .46979 .73326 .4673 Mtetra
.73326 .4673 .73526 .46979 .73966 .46844 .73767 .46595 Mtetra
.73767 .46595 .73966 .46844 .74407 .46709 .74208 .46459 Mtetra
.74208 .46459 .74407 .46709 .74848 .46574 .7465 .46324 Mtetra
.7465 .46324 .74848 .46574 .75291 .46438 .75093 .46188 Mtetra
.75093 .46188 .75291 .46438 .75733 .46303 .75536 .46052 Mtetra
.75536 .46052 .75733 .46303 .76177 .46167 .7598 .45916 Mtetra
.7598 .45916 .76177 .46167 .76621 .46031 .76425 .4578 Mtetra
.76425 .4578 .76621 .46031 .77066 .45895 .7687 .45643 Mtetra
.7687 .45643 .77066 .45895 .77512 .45759 .77316 .45506 Mtetra
.77316 .45506 .77512 .45759 .77958 .45622 .77763 .45369 Mtetra
.77763 .45369 .77958 .45622 .78405 .45485 .7821 .45232 Mtetra
.7821 .45232 .78405 .45485 .78853 .45348 .78659 .45095 Mtetra
.78659 .45095 .78853 .45348 .79301 .45211 .79107 .44957 Mtetra
.98 .689 .384 r
.79107 .44957 .79301 .45211 .7975 .45073 .7844 .31323 Mtetra
.556 .346 .55 r
.7844 .31323 .7975 .45073 .79057 .31444 .78871 .31181 Mtetra
.664 .741 .908 r
.78871 .31181 .79057 .31444 .79488 .31301 .79302 .31038 Mtetra
.79302 .31038 .79488 .31301 .7992 .31159 .79735 .30895 Mtetra
.79735 .30895 .7992 .31159 .80352 .31016 .80167 .30752 Mtetra
.80167 .30752 .80352 .31016 .80785 .30873 .80601 .30609 Mtetra
.80601 .30609 .80785 .30873 .81219 .3073 .81035 .30465 Mtetra
.81035 .30465 .81219 .3073 .81653 .30587 .81469 .30321 Mtetra
.81469 .30321 .81653 .30587 .82088 .30443 .81905 .30177 Mtetra
.81905 .30177 .82088 .30443 .82523 .30299 .82341 .30033 Mtetra
.82341 .30033 .82523 .30299 .8296 .30155 .82778 .29889 Mtetra
.82778 .29889 .8296 .30155 .83396 .30011 .83215 .29744 Mtetra
.83215 .29744 .83396 .30011 .83834 .29867 .83653 .29599 Mtetra
.83653 .29599 .83834 .29867 .84272 .29722 .84092 .29454 Mtetra
.84092 .29454 .84272 .29722 .84711 .29577 .84531 .29309 Mtetra
.84531 .29309 .84711 .29577 .85151 .29432 .84971 .29164 Mtetra
.84971 .29164 .85151 .29432 .85591 .29287 .85412 .29018 Mtetra
.85412 .29018 .85591 .29287 .86032 .29141 .85853 .28872 Mtetra
.85853 .28872 .86032 .29141 .86473 .28995 .86295 .28726 Mtetra
.86295 .28726 .86473 .28995 .86915 .28849 .86738 .28579 Mtetra
.86738 .28579 .86915 .28849 .87358 .28703 .87181 .28433 Mtetra
.27196 .47972 .27431 .48191 .27789 .48073 .27554 .47854 Mtetra
.27554 .47854 .27789 .48073 .28147 .47954 .27913 .47735 Mtetra
.27913 .47735 .28147 .47954 .28506 .47835 .28272 .47616 Mtetra
.28272 .47616 .28506 .47835 .28865 .47717 .28631 .47497 Mtetra
.28631 .47497 .28865 .47717 .29225 .47598 .28992 .47378 Mtetra
.28992 .47378 .29225 .47598 .29585 .47478 .29352 .47258 Mtetra
.29352 .47258 .29585 .47478 .29946 .47359 .29713 .47138 Mtetra
.29713 .47138 .29946 .47359 .30307 .4724 .30075 .47019 Mtetra
.30075 .47019 .30307 .4724 .30669 .4712 .30437 .46899 Mtetra
.30437 .46899 .30669 .4712 .31031 .47 .308 .46779 Mtetra
.308 .46779 .31031 .47 .31394 .4688 .31163 .46658 Mtetra
.31163 .46658 .31394 .4688 .31758 .4676 .31526 .46538 Mtetra
.31526 .46538 .31758 .4676 .32121 .4664 .3189 .46417 Mtetra
.3189 .46417 .32121 .4664 .32486 .46519 .32255 .46297 Mtetra
.32255 .46297 .32486 .46519 .3285 .46399 .3262 .46176 Mtetra
.3262 .46176 .3285 .46399 .33216 .46278 .32986 .46054 Mtetra
.32986 .46054 .33216 .46278 .33582 .46157 .33352 .45933 Mtetra
.33352 .45933 .33582 .46157 .33948 .46036 .33718 .45812 Mtetra
.33718 .45812 .33948 .46036 .34315 .45915 .34086 .4569 Mtetra
.34086 .4569 .34315 .45915 .33812 .61827 .34453 .45568 Mtetra
0 0 .285 r
.34453 .45568 .33812 .61827 .34197 .61711 .33956 .61497 Mtetra
.651 .757 .927 r
.33956 .61497 .34197 .61711 .34583 .61595 .34342 .6138 Mtetra
.34342 .6138 .34583 .61595 .34969 .61479 .34729 .61264 Mtetra
.34729 .61264 .34969 .61479 .35356 .61362 .35116 .61147 Mtetra
.35116 .61147 .35356 .61362 .35743 .61246 .35504 .6103 Mtetra
.35504 .6103 .35743 .61246 .36131 .61129 .35892 .60913 Mtetra
.35892 .60913 .36131 .61129 .3652 .61012 .36281 .60796 Mtetra
.36281 .60796 .3652 .61012 .36909 .60895 .36671 .60678 Mtetra
.36671 .60678 .36909 .60895 .37299 .60778 .37061 .60561 Mtetra
.37061 .60561 .37299 .60778 .37689 .6066 .37451 .60443 Mtetra
.37451 .60443 .37689 .6066 .3808 .60542 .37842 .60325 Mtetra
.37842 .60325 .3808 .60542 .38471 .60425 .38234 .60207 Mtetra
.38234 .60207 .38471 .60425 .38863 .60307 .38626 .60088 Mtetra
.38626 .60088 .38863 .60307 .39256 .60188 .39019 .5997 Mtetra
.39019 .5997 .39256 .60188 .39649 .6007 .39413 .59851 Mtetra
.39413 .59851 .39649 .6007 .40042 .59952 .39807 .59732 Mtetra
.39807 .59732 .40042 .59952 .40437 .59833 .40202 .59613 Mtetra
.40202 .59613 .40437 .59833 .40832 .59714 .40597 .59494 Mtetra
.40597 .59494 .40832 .59714 .41227 .59595 .40993 .59375 Mtetra
.40993 .59375 .41227 .59595 .41623 .59476 .41389 .59255 Mtetra
.41389 .59255 .41623 .59476 .4202 .59356 .41786 .59135 Mtetra
.41786 .59135 .4202 .59356 .42417 .59237 .42184 .59016 Mtetra
.42184 .59016 .42417 .59237 .42815 .59117 .42582 .58896 Mtetra
.956 .662 .437 r
.42582 .58896 .42815 .59117 .43071 .6422 .42835 .64002 Mtetra
.646 .762 .934 r
.42835 .64002 .43071 .6422 .43476 .64102 .4324 .63883 Mtetra
.4324 .63883 .43476 .64102 .43882 .63983 .43646 .63765 Mtetra
.43646 .63765 .43882 .63983 .44288 .63865 .44053 .63646 Mtetra
.44053 .63646 .44288 .63865 .44695 .63747 .4446 .63527 Mtetra
.4446 .63527 .44695 .63747 .45102 .63628 .44867 .63408 Mtetra
.44867 .63408 .45102 .63628 .4551 .63509 .45276 .63289 Mtetra
.45276 .63289 .4551 .63509 .45919 .6339 .45685 .63169 Mtetra
.45685 .63169 .45919 .6339 .46328 .63271 .46095 .6305 Mtetra
.46095 .6305 .46328 .63271 .46738 .63151 .46505 .6293 Mtetra
.46505 .6293 .46738 .63151 .47148 .63031 .46916 .6281 Mtetra
.46916 .6281 .47148 .63031 .47559 .62912 .47327 .6269 Mtetra
.47327 .6269 .47559 .62912 .47971 .62792 .47739 .6257 Mtetra
.47739 .6257 .47971 .62792 .48383 .62671 .48152 .62449 Mtetra
.958 .702 .507 r
.48152 .62449 .48383 .62671 .48885 .54225 .4866 .53996 Mtetra
.653 .754 .924 r
.4866 .53996 .48885 .54225 .49289 .54101 .49064 .53872 Mtetra
.49064 .53872 .49289 .54101 .49693 .53977 .49469 .53747 Mtetra
.49469 .53747 .49693 .53977 .50098 .53853 .49874 .53623 Mtetra
.49874 .53623 .50098 .53853 .50504 .53728 .5028 .53498 Mtetra
.5028 .53498 .50504 .53728 .5091 .53604 .50686 .53373 Mtetra
.50686 .53373 .5091 .53604 .51316 .53479 .51093 .53248 Mtetra
.51093 .53248 .51316 .53479 .51723 .53354 .51501 .53123 Mtetra
.51501 .53123 .51723 .53354 .52131 .53229 .51909 .52998 Mtetra
.51909 .52998 .52131 .53229 .5254 .53104 .52318 .52872 Mtetra
.52318 .52872 .5254 .53104 .52949 .52978 .52728 .52746 Mtetra
.52728 .52746 .52949 .52978 .53359 .52853 .53138 .5262 Mtetra
.53138 .5262 .53359 .52853 .53769 .52727 .53548 .52494 Mtetra
.53548 .52494 .53769 .52727 .5418 .52601 .5396 .52368 Mtetra
.964 .698 .481 r
.5396 .52368 .5418 .52601 .54517 .40656 .54305 .40415 Mtetra
.663 .743 .91 r
.54305 .40415 .54517 .40656 .54915 .40526 .54703 .40284 Mtetra
.54703 .40284 .54915 .40526 .55313 .40395 .55101 .40153 Mtetra
.55101 .40153 .55313 .40395 .55711 .40264 .555 .40022 Mtetra
.555 .40022 .55711 .40264 .5611 .40133 .559 .39891 Mtetra
.559 .39891 .5611 .40133 .5651 .40002 .563 .39759 Mtetra
.563 .39759 .5651 .40002 .56911 .39871 .56701 .39628 Mtetra
.56701 .39628 .56911 .39871 .57312 .39739 .57102 .39496 Mtetra
.57102 .39496 .57312 .39739 .57713 .39607 .57504 .39364 Mtetra
.57504 .39364 .57713 .39607 .58115 .39475 .57907 .39231 Mtetra
.57907 .39231 .58115 .39475 .58518 .39343 .5831 .39099 Mtetra
.5831 .39099 .58518 .39343 .58921 .39211 .58714 .38966 Mtetra
.58714 .38966 .58921 .39211 .59325 .39078 .59118 .38833 Mtetra
.59118 .38833 .59325 .39078 .5973 .38946 .59523 .387 Mtetra
.59523 .387 .5973 .38946 .60135 .38813 .59928 .38567 Mtetra
.59928 .38567 .60135 .38813 .6054 .3868 .60334 .38433 Mtetra
.60334 .38433 .6054 .3868 .61384 .55116 .60741 .383 Mtetra
.555 .343 .548 r
.60741 .383 .61384 .55116 .61812 .54989 .61148 .38166 Mtetra
0 0 .412 r
.61148 .38166 .61812 .54989 .62241 .54861 .62026 .54624 Mtetra
.649 .759 .929 r
.62026 .54624 .62241 .54861 .6267 .54733 .62456 .54496 Mtetra
.62456 .54496 .6267 .54733 .631 .54604 .62886 .54367 Mtetra
.62886 .54367 .631 .54604 .63531 .54476 .63317 .54238 Mtetra
.63317 .54238 .63531 .54476 .63963 .54347 .63749 .54109 Mtetra
.63749 .54109 .63963 .54347 .64395 .54218 .64182 .5398 Mtetra
.64182 .5398 .64395 .54218 .64828 .54089 .64615 .53851 Mtetra
.64615 .53851 .64828 .54089 .65261 .5396 .65049 .53721 Mtetra
.65049 .53721 .65261 .5396 .65695 .53831 .65484 .53591 Mtetra
.65484 .53591 .65695 .53831 .6613 .53701 .65919 .53461 Mtetra
.65919 .53461 .6613 .53701 .66566 .53571 .66355 .53331 Mtetra
.66355 .53331 .66566 .53571 .67002 .53441 .66792 .532 Mtetra
.66792 .532 .67002 .53441 .67439 .53311 .67229 .5307 Mtetra
.67229 .5307 .67439 .53311 .67876 .5318 .67667 .52939 Mtetra
.67667 .52939 .67876 .5318 .68314 .5305 .68106 .52808 Mtetra
.68106 .52808 .68314 .5305 .68753 .52919 .68545 .52677 Mtetra
.68545 .52677 .68753 .52919 .69193 .52788 .68985 .52545 Mtetra
.895 .801 .748 r
.68985 .52545 .69193 .52788 .69633 .52656 .69399 .51882 Mtetra
.616 .516 .717 r
.69399 .51882 .69633 .52656 .70074 .52525 .6984 .5175 Mtetra
.6984 .5175 .70074 .52525 .70487 .51862 .70281 .51618 Mtetra
.65 .758 .929 r
.70281 .51618 .70487 .51862 .70697 .47536 .70723 .51485 Mtetra
0 0 .354 r
.70723 .51485 .70697 .47536 .71133 .47402 .70931 .47154 Mtetra
.653 .754 .924 r
.70931 .47154 .71133 .47402 .71571 .47268 .71368 .4702 Mtetra
.71368 .4702 .71571 .47268 .72009 .47134 .71807 .46885 Mtetra
.71807 .46885 .72009 .47134 .72447 .46999 .72246 .4675 Mtetra
.72246 .4675 .72447 .46999 .72886 .46865 .72686 .46615 Mtetra
.72686 .46615 .72886 .46865 .73326 .4673 .73126 .4648 Mtetra
.73126 .4648 .73326 .4673 .73767 .46595 .73567 .46345 Mtetra
.73567 .46345 .73767 .46595 .74208 .46459 .74009 .46209 Mtetra
.74009 .46209 .74208 .46459 .7465 .46324 .74451 .46073 Mtetra
.74451 .46073 .7465 .46324 .75093 .46188 .74894 .45937 Mtetra
.74894 .45937 .75093 .46188 .75536 .46052 .75338 .45801 Mtetra
.75338 .45801 .75536 .46052 .7598 .45916 .75783 .45664 Mtetra
.75783 .45664 .7598 .45916 .76425 .4578 .76228 .45527 Mtetra
.76228 .45527 .76425 .4578 .7687 .45643 .76674 .4539 Mtetra
.76674 .4539 .7687 .45643 .77316 .45506 .7712 .45253 Mtetra
.7712 .45253 .77316 .45506 .77763 .45369 .77567 .45116 Mtetra
.77567 .45116 .77763 .45369 .7821 .45232 .78015 .44978 Mtetra
.78015 .44978 .7821 .45232 .78659 .45095 .78464 .4484 Mtetra
.78464 .4484 .78659 .45095 .79107 .44957 .78913 .44702 Mtetra
.98 .689 .384 r
.78913 .44702 .79107 .44957 .7844 .31323 .78253 .3106 Mtetra
.664 .741 .908 r
.78253 .3106 .7844 .31323 .78871 .31181 .78684 .30917 Mtetra
.78684 .30917 .78871 .31181 .79302 .31038 .79116 .30774 Mtetra
.79116 .30774 .79302 .31038 .79735 .30895 .79549 .30631 Mtetra
.79549 .30631 .79735 .30895 .80167 .30752 .79982 .30487 Mtetra
.79982 .30487 .80167 .30752 .80601 .30609 .80416 .30344 Mtetra
.80416 .30344 .80601 .30609 .81035 .30465 .8085 .302 Mtetra
.8085 .302 .81035 .30465 .81469 .30321 .81286 .30055 Mtetra
.81286 .30055 .81469 .30321 .81905 .30177 .81721 .29911 Mtetra
.81721 .29911 .81905 .30177 .82341 .30033 .82158 .29767 Mtetra
.82158 .29767 .82341 .30033 .82778 .29889 .82595 .29622 Mtetra
.82595 .29622 .82778 .29889 .83215 .29744 .83033 .29477 Mtetra
.83033 .29477 .83215 .29744 .83653 .29599 .83471 .29331 Mtetra
.83471 .29331 .83653 .29599 .84092 .29454 .83911 .29186 Mtetra
.83911 .29186 .84092 .29454 .84531 .29309 .8435 .2904 Mtetra
.8435 .2904 .84531 .29309 .84971 .29164 .84791 .28894 Mtetra
.84791 .28894 .84971 .29164 .85412 .29018 .85232 .28748 Mtetra
.85232 .28748 .85412 .29018 .85853 .28872 .85674 .28602 Mtetra
.85674 .28602 .85853 .28872 .86295 .28726 .86116 .28455 Mtetra
.86116 .28455 .86295 .28726 .86738 .28579 .86559 .28309 Mtetra
.86559 .28309 .86738 .28579 .87181 .28433 .87003 .28162 Mtetra
.2696 .47753 .27196 .47972 .27554 .47854 .27319 .47634 Mtetra
.27319 .47634 .27554 .47854 .27913 .47735 .27678 .47515 Mtetra
.27678 .47515 .27913 .47735 .28272 .47616 .28037 .47396 Mtetra
.28037 .47396 .28272 .47616 .28631 .47497 .28397 .47276 Mtetra
.28397 .47276 .28631 .47497 .28992 .47378 .28758 .47157 Mtetra
.28758 .47157 .28992 .47378 .29352 .47258 .29119 .47037 Mtetra
.29119 .47037 .29352 .47258 .29713 .47138 .2948 .46917 Mtetra
.2948 .46917 .29713 .47138 .30075 .47019 .29842 .46797 Mtetra
.29842 .46797 .30075 .47019 .30437 .46899 .30204 .46677 Mtetra
.30204 .46677 .30437 .46899 .308 .46779 .30567 .46556 Mtetra
.30567 .46556 .308 .46779 .31163 .46658 .30931 .46436 Mtetra
.30931 .46436 .31163 .46658 .31526 .46538 .31295 .46315 Mtetra
.31295 .46315 .31526 .46538 .3189 .46417 .31659 .46194 Mtetra
.31659 .46194 .3189 .46417 .32255 .46297 .32024 .46073 Mtetra
.32024 .46073 .32255 .46297 .3262 .46176 .32389 .45952 Mtetra
.32389 .45952 .3262 .46176 .32986 .46054 .32755 .4583 Mtetra
.32755 .4583 .32986 .46054 .33352 .45933 .33122 .45709 Mtetra
.33122 .45709 .33352 .45933 .33718 .45812 .33489 .45587 Mtetra
.33489 .45587 .33718 .45812 .34086 .4569 .33856 .45465 Mtetra
.33856 .45465 .34086 .4569 .34453 .45568 .34224 .45343 Mtetra
.947 .68 .499 r
.34224 .45343 .34453 .45568 .33956 .61497 .33715 .61282 Mtetra
.651 .757 .927 r
.33715 .61282 .33956 .61497 .34342 .6138 .34101 .61165 Mtetra
.34101 .61165 .34342 .6138 .34729 .61264 .34488 .61048 Mtetra
.34488 .61048 .34729 .61264 .35116 .61147 .34876 .60931 Mtetra
.34876 .60931 .35116 .61147 .35504 .6103 .35264 .60814 Mtetra
.35264 .60814 .35504 .6103 .35892 .60913 .35652 .60696 Mtetra
.35652 .60696 .35892 .60913 .36281 .60796 .36042 .60579 Mtetra
.36042 .60579 .36281 .60796 .36671 .60678 .36432 .60461 Mtetra
.36432 .60461 .36671 .60678 .37061 .60561 .36822 .60343 Mtetra
.36822 .60343 .37061 .60561 .37451 .60443 .37213 .60225 Mtetra
.37213 .60225 .37451 .60443 .37842 .60325 .37604 .60107 Mtetra
.37604 .60107 .37842 .60325 .38234 .60207 .37997 .59988 Mtetra
.37997 .59988 .38234 .60207 .38626 .60088 .38389 .59869 Mtetra
.38389 .59869 .38626 .60088 .39019 .5997 .38783 .59751 Mtetra
.38783 .59751 .39019 .5997 .39413 .59851 .39176 .59632 Mtetra
.39176 .59632 .39413 .59851 .39807 .59732 .39571 .59512 Mtetra
.39571 .59512 .39807 .59732 .40202 .59613 .39966 .59393 Mtetra
.39966 .59393 .40202 .59613 .40597 .59494 .40361 .59274 Mtetra
.40361 .59274 .40597 .59494 .40993 .59375 .40758 .59154 Mtetra
.40758 .59154 .40993 .59375 .41389 .59255 .41154 .59034 Mtetra
.41154 .59034 .41389 .59255 .41786 .59135 .41552 .58914 Mtetra
.41552 .58914 .41786 .59135 .42184 .59016 .4195 .58794 Mtetra
.4195 .58794 .42184 .59016 .42582 .58896 .42348 .58673 Mtetra
.956 .662 .437 r
.42348 .58673 .42582 .58896 .42835 .64002 .42598 .63783 Mtetra
.646 .762 .934 r
.42598 .63783 .42835 .64002 .4324 .63883 .43003 .63664 Mtetra
.43003 .63664 .4324 .63883 .43646 .63765 .4341 .63546 Mtetra
.4341 .63546 .43646 .63765 .44053 .63646 .43817 .63426 Mtetra
.43817 .63426 .44053 .63646 .4446 .63527 .44224 .63307 Mtetra
.44224 .63307 .4446 .63527 .44867 .63408 .44632 .63188 Mtetra
.44632 .63188 .44867 .63408 .45276 .63289 .45041 .63068 Mtetra
.45041 .63068 .45276 .63289 .45685 .63169 .45451 .62949 Mtetra
.45451 .62949 .45685 .63169 .46095 .6305 .45861 .62829 Mtetra
.45861 .62829 .46095 .6305 .46505 .6293 .46271 .62708 Mtetra
.46271 .62708 .46505 .6293 .46916 .6281 .46683 .62588 Mtetra
.46683 .62588 .46916 .6281 .47327 .6269 .47094 .62468 Mtetra
.47094 .62468 .47327 .6269 .47739 .6257 .47507 .62347 Mtetra
.47507 .62347 .47739 .6257 .48152 .62449 .4792 .62226 Mtetra
.958 .702 .507 r
.4792 .62226 .48152 .62449 .4866 .53996 .48434 .53767 Mtetra
.653 .754 .924 r
.48434 .53767 .4866 .53996 .49064 .53872 .48839 .53642 Mtetra
.48839 .53642 .49064 .53872 .49469 .53747 .49244 .53517 Mtetra
.49244 .53517 .49469 .53747 .49874 .53623 .49649 .53393 Mtetra
.49649 .53393 .49874 .53623 .5028 .53498 .50056 .53268 Mtetra
.50056 .53268 .5028 .53498 .50686 .53373 .50463 .53142 Mtetra
.50463 .53142 .50686 .53373 .51093 .53248 .5087 .53017 Mtetra
.5087 .53017 .51093 .53248 .51501 .53123 .51278 .52891 Mtetra
.51278 .52891 .51501 .53123 .51909 .52998 .51687 .52766 Mtetra
.51687 .52766 .51909 .52998 .52318 .52872 .52096 .5264 Mtetra
.963 .697 .484 r
.52096 .5264 .52318 .52872 .52728 .52746 .52505 .39277 Mtetra
.555 .344 .549 r
.52505 .39277 .52728 .52746 .53138 .5262 .52899 .39146 Mtetra
.52899 .39146 .53138 .5262 .53548 .52494 .53294 .39015 Mtetra
.53294 .39015 .53548 .52494 .5396 .52368 .5369 .38884 Mtetra
.514 .313 .545 r
.5369 .38884 .5396 .52368 .54305 .40415 .54093 .40173 Mtetra
.663 .743 .91 r
.54093 .40173 .54305 .40415 .54703 .40284 .54491 .40042 Mtetra
.54491 .40042 .54703 .40284 .55101 .40153 .5489 .39911 Mtetra
.5489 .39911 .55101 .40153 .555 .40022 .55289 .39779 Mtetra
.55289 .39779 .555 .40022 .559 .39891 .55689 .39648 Mtetra
.55689 .39648 .559 .39891 .563 .39759 .5609 .39516 Mtetra
.5609 .39516 .563 .39759 .56701 .39628 .56491 .39384 Mtetra
.56491 .39384 .56701 .39628 .57102 .39496 .56893 .39252 Mtetra
.56893 .39252 .57102 .39496 .57504 .39364 .57295 .39119 Mtetra
.57295 .39119 .57504 .39364 .57907 .39231 .57698 .38986 Mtetra
.57698 .38986 .57907 .39231 .5831 .39099 .58101 .38854 Mtetra
.58101 .38854 .5831 .39099 .58714 .38966 .58505 .38721 Mtetra
.58505 .38721 .58714 .38966 .59118 .38833 .5891 .38587 Mtetra
.5891 .38587 .59118 .38833 .59523 .387 .59315 .38454 Mtetra
.59315 .38454 .59523 .387 .59928 .38567 .59721 .3832 Mtetra
.59721 .3832 .59928 .38567 .60334 .38433 .60128 .38187 Mtetra
.60128 .38187 .60334 .38433 .60741 .383 .60535 .38053 Mtetra
.60535 .38053 .60741 .383 .61148 .38166 .60942 .37918 Mtetra
.60942 .37918 .61148 .38166 .62026 .54624 .6135 .37784 Mtetra
0 0 .412 r
.6135 .37784 .62026 .54624 .62456 .54496 .62241 .54258 Mtetra
.649 .759 .929 r
.62241 .54258 .62456 .54496 .62886 .54367 .62672 .54129 Mtetra
.62672 .54129 .62886 .54367 .63317 .54238 .63103 .54 Mtetra
.63103 .54 .63317 .54238 .63749 .54109 .63536 .5387 Mtetra
.63536 .5387 .63749 .54109 .64182 .5398 .63969 .53741 Mtetra
.63969 .53741 .64182 .5398 .64615 .53851 .64402 .53611 Mtetra
.64402 .53611 .64615 .53851 .65049 .53721 .64837 .53481 Mtetra
.64837 .53481 .65049 .53721 .65484 .53591 .65272 .53351 Mtetra
.65272 .53351 .65484 .53591 .65919 .53461 .65708 .5322 Mtetra
.65708 .5322 .65919 .53461 .66355 .53331 .66144 .5309 Mtetra
.66144 .5309 .66355 .53331 .66792 .532 .66581 .52959 Mtetra
.66581 .52959 .66792 .532 .67229 .5307 .67019 .52828 Mtetra
.67019 .52828 .67229 .5307 .67667 .52939 .67457 .52697 Mtetra
.67457 .52697 .67667 .52939 .68106 .52808 .67897 .52565 Mtetra
.67897 .52565 .68106 .52808 .68545 .52677 .68336 .52434 Mtetra
.895 .801 .748 r
.68336 .52434 .68545 .52677 .68985 .52545 .68751 .5177 Mtetra
.616 .516 .717 r
.68751 .5177 .68985 .52545 .69399 .51882 .69191 .51638 Mtetra
.65 .758 .929 r
.69191 .51638 .69399 .51882 .6984 .5175 .69633 .51506 Mtetra
.69633 .51506 .6984 .5175 .70281 .51618 .70074 .51373 Mtetra
.70074 .51373 .70281 .51618 .70723 .51485 .70517 .5124 Mtetra
.70517 .5124 .70723 .51485 .70931 .47154 .7096 .51107 Mtetra
0 0 .354 r
.7096 .51107 .70931 .47154 .71368 .4702 .71166 .46771 Mtetra
.653 .754 .924 r
.71166 .46771 .71368 .4702 .71807 .46885 .71604 .46636 Mtetra
.71604 .46636 .71807 .46885 .72246 .4675 .72044 .46501 Mtetra
.72044 .46501 .72246 .4675 .72686 .46615 .72484 .46365 Mtetra
.72484 .46365 .72686 .46615 .73126 .4648 .72925 .4623 Mtetra
.72925 .4623 .73126 .4648 .73567 .46345 .73366 .46094 Mtetra
.73366 .46094 .73567 .46345 .74009 .46209 .73809 .45958 Mtetra
.73809 .45958 .74009 .46209 .74451 .46073 .74252 .45822 Mtetra
.74252 .45822 .74451 .46073 .74894 .45937 .74695 .45685 Mtetra
.74695 .45685 .74894 .45937 .75338 .45801 .75139 .45548 Mtetra
.75139 .45548 .75338 .45801 .75783 .45664 .75584 .45411 Mtetra
.75584 .45411 .75783 .45664 .76228 .45527 .7603 .45274 Mtetra
.7603 .45274 .76228 .45527 .76674 .4539 .76476 .45137 Mtetra
.76476 .45137 .76674 .4539 .7712 .45253 .76924 .44999 Mtetra
.76924 .44999 .7712 .45253 .77567 .45116 .77371 .44861 Mtetra
.77371 .44861 .77567 .45116 .78015 .44978 .7782 .44723 Mtetra
.7782 .44723 .78015 .44978 .78464 .4484 .78269 .44585 Mtetra
.98 .69 .387 r
.78269 .44585 .78464 .4484 .78913 .44702 .77634 .30939 Mtetra
.555 .344 .549 r
.77634 .30939 .78913 .44702 .78253 .3106 .78065 .30796 Mtetra
.664 .741 .908 r
.78065 .30796 .78253 .3106 .78684 .30917 .78497 .30653 Mtetra
.78497 .30653 .78684 .30917 .79116 .30774 .78929 .30509 Mtetra
.78929 .30509 .79116 .30774 .79549 .30631 .79362 .30366 Mtetra
.79362 .30366 .79549 .30631 .79982 .30487 .79796 .30222 Mtetra
.79796 .30222 .79982 .30487 .80416 .30344 .80231 .30078 Mtetra
.80231 .30078 .80416 .30344 .8085 .302 .80666 .29933 Mtetra
.80666 .29933 .8085 .302 .81286 .30055 .81101 .29789 Mtetra
.81101 .29789 .81286 .30055 .81721 .29911 .81537 .29644 Mtetra
.81537 .29644 .81721 .29911 .82158 .29767 .81974 .29499 Mtetra
.81974 .29499 .82158 .29767 .82595 .29622 .82412 .29354 Mtetra
.82412 .29354 .82595 .29622 .83033 .29477 .8285 .29208 Mtetra
.8285 .29208 .83033 .29477 .83471 .29331 .83289 .29063 Mtetra
.83289 .29063 .83471 .29331 .83911 .29186 .83729 .28917 Mtetra
.83729 .28917 .83911 .29186 .8435 .2904 .84169 .28771 Mtetra
.84169 .28771 .8435 .2904 .84791 .28894 .8461 .28624 Mtetra
.8461 .28624 .84791 .28894 .85232 .28748 .85052 .28478 Mtetra
.85052 .28478 .85232 .28748 .85674 .28602 .85494 .28331 Mtetra
.85494 .28331 .85674 .28602 .86116 .28455 .85937 .28184 Mtetra
.85937 .28184 .86116 .28455 .86559 .28309 .86381 .28037 Mtetra
.86381 .28037 .86559 .28309 .87003 .28162 .86825 .2789 Mtetra
.26725 .47533 .2696 .47753 .27319 .47634 .27083 .47414 Mtetra
.27083 .47414 .27319 .47634 .27678 .47515 .27443 .47295 Mtetra
.27443 .47295 .27678 .47515 .28037 .47396 .27802 .47175 Mtetra
.27802 .47175 .28037 .47396 .28397 .47276 .28162 .47056 Mtetra
.28162 .47056 .28397 .47276 .28758 .47157 .28523 .46936 Mtetra
.28523 .46936 .28758 .47157 .29119 .47037 .28884 .46816 Mtetra
.28884 .46816 .29119 .47037 .2948 .46917 .29246 .46695 Mtetra
.29246 .46695 .2948 .46917 .29842 .46797 .29608 .46575 Mtetra
.29608 .46575 .29842 .46797 .30204 .46677 .29971 .46454 Mtetra
.29971 .46454 .30204 .46677 .30567 .46556 .30334 .46334 Mtetra
.30334 .46334 .30567 .46556 .30931 .46436 .30698 .46213 Mtetra
.30698 .46213 .30931 .46436 .31295 .46315 .31062 .46092 Mtetra
.31062 .46092 .31295 .46315 .31659 .46194 .31427 .45971 Mtetra
.31427 .45971 .31659 .46194 .32024 .46073 .31792 .45849 Mtetra
.31792 .45849 .32024 .46073 .32389 .45952 .32158 .45728 Mtetra
.32158 .45728 .32389 .45952 .32755 .4583 .32524 .45606 Mtetra
.32524 .45606 .32755 .4583 .33122 .45709 .32891 .45484 Mtetra
.32891 .45484 .33122 .45709 .33489 .45587 .33258 .45362 Mtetra
.33258 .45362 .33489 .45587 .33856 .45465 .33626 .4524 Mtetra
.33626 .4524 .33856 .45465 .34224 .45343 .33994 .45117 Mtetra
.947 .68 .499 r
.33994 .45117 .34224 .45343 .33715 .61282 .33473 .61066 Mtetra
.651 .757 .927 r
.33473 .61066 .33715 .61282 .34101 .61165 .33859 .60949 Mtetra
.33859 .60949 .34101 .61165 .34488 .61048 .34247 .60832 Mtetra
.34247 .60832 .34488 .61048 .34876 .60931 .34635 .60714 Mtetra
.34635 .60714 .34876 .60931 .35264 .60814 .35023 .60597 Mtetra
.35023 .60597 .35264 .60814 .35652 .60696 .35412 .60479 Mtetra
.35412 .60479 .35652 .60696 .36042 .60579 .35802 .60361 Mtetra
.35802 .60361 .36042 .60579 .36432 .60461 .36192 .60243 Mtetra
.36192 .60243 .36432 .60461 .36822 .60343 .36583 .60125 Mtetra
.36583 .60125 .36822 .60343 .37213 .60225 .36974 .60006 Mtetra
.36974 .60006 .37213 .60225 .37604 .60107 .37366 .59888 Mtetra
.37366 .59888 .37604 .60107 .37997 .59988 .37758 .59769 Mtetra
.37758 .59769 .37997 .59988 .38389 .59869 .38151 .5965 Mtetra
.38151 .5965 .38389 .59869 .38783 .59751 .38545 .59531 Mtetra
.38545 .59531 .38783 .59751 .39176 .59632 .38939 .59411 Mtetra
.38939 .59411 .39176 .59632 .39571 .59512 .39334 .59292 Mtetra
.39334 .59292 .39571 .59512 .39966 .59393 .39729 .59172 Mtetra
.39729 .59172 .39966 .59393 .40361 .59274 .40125 .59052 Mtetra
.40125 .59052 .40361 .59274 .40758 .59154 .40522 .58932 Mtetra
.40522 .58932 .40758 .59154 .41154 .59034 .40919 .58812 Mtetra
.40919 .58812 .41154 .59034 .41552 .58914 .41317 .58692 Mtetra
.41317 .58692 .41552 .58914 .4195 .58794 .41715 .58571 Mtetra
.41715 .58571 .4195 .58794 .42348 .58673 .42114 .58451 Mtetra
.947 .715 .555 r
.42114 .58451 .42348 .58673 .42598 .63783 .42618 .54759 Mtetra
.557 .349 .555 r
.42618 .54759 .42598 .63783 .43003 .63664 .43014 .54637 Mtetra
.43014 .54637 .43003 .63664 .4341 .63546 .4341 .54514 Mtetra
.4341 .54514 .4341 .63546 .43817 .63426 .43808 .54391 Mtetra
.43808 .54391 .43817 .63426 .44224 .63307 .44205 .54268 Mtetra
.44205 .54268 .44224 .63307 .44632 .63188 .44603 .54145 Mtetra
.44603 .54145 .44632 .63188 .45041 .63068 .45002 .54022 Mtetra
.45002 .54022 .45041 .63068 .45451 .62949 .45402 .53898 Mtetra
.45402 .53898 .45451 .62949 .45861 .62829 .45802 .53775 Mtetra
.45802 .53775 .45861 .62829 .46271 .62708 .46202 .53651 Mtetra
.46202 .53651 .46271 .62708 .46683 .62588 .46604 .53527 Mtetra
.46604 .53527 .46683 .62588 .47094 .62468 .47006 .53402 Mtetra
.47006 .53402 .47094 .62468 .47507 .62347 .47408 .53278 Mtetra
.47408 .53278 .47507 .62347 .4792 .62226 .47811 .53153 Mtetra
.47811 .53153 .4792 .62226 .48434 .53767 .48215 .53029 Mtetra
.289 .309 .709 r
.48215 .53029 .48434 .53767 .48839 .53642 .48613 .53412 Mtetra
.653 .754 .924 r
.48613 .53412 .48839 .53642 .49244 .53517 .49018 .53287 Mtetra
.49018 .53287 .49244 .53517 .49649 .53393 .49424 .53162 Mtetra
.49424 .53162 .49649 .53393 .50056 .53268 .49831 .53036 Mtetra
.961 .697 .489 r
.49831 .53036 .50056 .53268 .50463 .53142 .50327 .39689 Mtetra
.555 .344 .549 r
.50327 .39689 .50463 .53142 .5087 .53017 .50719 .39558 Mtetra
.50719 .39558 .5087 .53017 .51278 .52891 .51111 .39428 Mtetra
.51111 .39428 .51278 .52891 .51687 .52766 .51504 .39297 Mtetra
.51504 .39297 .51687 .52766 .52096 .5264 .51897 .39167 Mtetra
.51897 .39167 .52096 .5264 .52505 .39277 .52291 .39036 Mtetra
.664 .741 .908 r
.52291 .39036 .52505 .39277 .52899 .39146 .52686 .38904 Mtetra
.52686 .38904 .52899 .39146 .53294 .39015 .53081 .38773 Mtetra
.53081 .38773 .53294 .39015 .5369 .38884 .53477 .38642 Mtetra
.923 .533 .163 r
.53477 .38642 .5369 .38884 .54093 .40173 .53879 .39931 Mtetra
.663 .743 .91 r
.53879 .39931 .54093 .40173 .54491 .40042 .54278 .398 Mtetra
.54278 .398 .54491 .40042 .5489 .39911 .54677 .39668 Mtetra
.54677 .39668 .5489 .39911 .55289 .39779 .55077 .39536 Mtetra
.55077 .39536 .55289 .39779 .55689 .39648 .55477 .39404 Mtetra
.55477 .39404 .55689 .39648 .5609 .39516 .55878 .39272 Mtetra
.55878 .39272 .5609 .39516 .56491 .39384 .5628 .3914 Mtetra
.5628 .3914 .56491 .39384 .56893 .39252 .56682 .39007 Mtetra
.56682 .39007 .56893 .39252 .57295 .39119 .57085 .38874 Mtetra
.57085 .38874 .57295 .39119 .57698 .38986 .57488 .38741 Mtetra
.57488 .38741 .57698 .38986 .58101 .38854 .57892 .38608 Mtetra
.57892 .38608 .58101 .38854 .58505 .38721 .58296 .38474 Mtetra
.58296 .38474 .58505 .38721 .5891 .38587 .58701 .38341 Mtetra
.58701 .38341 .5891 .38587 .59315 .38454 .59107 .38207 Mtetra
.59107 .38207 .59315 .38454 .59721 .3832 .59513 .38073 Mtetra
.59513 .38073 .59721 .3832 .60128 .38187 .5992 .37939 Mtetra
.5992 .37939 .60128 .38187 .60535 .38053 .60328 .37805 Mtetra
.60328 .37805 .60535 .38053 .60942 .37918 .60736 .3767 Mtetra
.60736 .3767 .60942 .37918 .6135 .37784 .61144 .37535 Mtetra
.971 .675 .407 r
.61144 .37535 .6135 .37784 .62241 .54258 .62025 .5402 Mtetra
.649 .759 .929 r
.62025 .5402 .62241 .54258 .62672 .54129 .62456 .5389 Mtetra
.62456 .5389 .62672 .54129 .63103 .54 .62888 .53761 Mtetra
.62888 .53761 .63103 .54 .63536 .5387 .63321 .53631 Mtetra
.63321 .53631 .63536 .5387 .63969 .53741 .63755 .53501 Mtetra
.63755 .53501 .63969 .53741 .64402 .53611 .64189 .53371 Mtetra
.64189 .53371 .64402 .53611 .64837 .53481 .64624 .53241 Mtetra
.64624 .53241 .64837 .53481 .65272 .53351 .65059 .5311 Mtetra
.65059 .5311 .65272 .53351 .65708 .5322 .65496 .52979 Mtetra
.65496 .52979 .65708 .5322 .66144 .5309 .65932 .52848 Mtetra
.65932 .52848 .66144 .5309 .66581 .52959 .6637 .52717 Mtetra
.6637 .52717 .66581 .52959 .67019 .52828 .66808 .52586 Mtetra
.66808 .52586 .67019 .52828 .67457 .52697 .67247 .52454 Mtetra
.894 .8 .748 r
.67247 .52454 .67457 .52697 .67897 .52565 .67663 .51791 Mtetra
.616 .516 .717 r
.67663 .51791 .67897 .52565 .68336 .52434 .68102 .51658 Mtetra
.68102 .51658 .68336 .52434 .68751 .5177 .68543 .51526 Mtetra
.65 .758 .929 r
.68543 .51526 .68751 .5177 .69191 .51638 .68983 .51393 Mtetra
.68983 .51393 .69191 .51638 .69633 .51506 .69425 .5126 Mtetra
.69425 .5126 .69633 .51506 .70074 .51373 .69867 .51127 Mtetra
.69867 .51127 .70074 .51373 .70517 .5124 .7031 .50994 Mtetra
.7031 .50994 .70517 .5124 .7096 .51107 .70754 .50861 Mtetra
.70754 .50861 .7096 .51107 .71166 .46771 .71198 .50727 Mtetra
0 0 .354 r
.71198 .50727 .71166 .46771 .71604 .46636 .71401 .46386 Mtetra
.653 .754 .924 r
.71401 .46386 .71604 .46636 .72044 .46501 .71841 .46251 Mtetra
.71841 .46251 .72044 .46501 .72484 .46365 .72282 .46115 Mtetra
.72282 .46115 .72484 .46365 .72925 .4623 .72723 .45979 Mtetra
.72723 .45979 .72925 .4623 .73366 .46094 .73165 .45843 Mtetra
.73165 .45843 .73366 .46094 .73809 .45958 .73608 .45706 Mtetra
.73608 .45706 .73809 .45958 .74252 .45822 .74052 .45569 Mtetra
.74052 .45569 .74252 .45822 .74695 .45685 .74496 .45432 Mtetra
.74496 .45432 .74695 .45685 .75139 .45548 .7494 .45295 Mtetra
.7494 .45295 .75139 .45548 .75584 .45411 .75386 .45158 Mtetra
.75386 .45158 .75584 .45411 .7603 .45274 .75832 .4502 Mtetra
.75832 .4502 .7603 .45274 .76476 .45137 .76279 .44883 Mtetra
.76279 .44883 .76476 .45137 .76924 .44999 .76726 .44745 Mtetra
.76726 .44745 .76924 .44999 .77371 .44861 .77175 .44607 Mtetra
.77175 .44607 .77371 .44861 .7782 .44723 .77624 .44468 Mtetra
.77624 .44468 .7782 .44723 .78269 .44585 .78073 .4433 Mtetra
.98 .69 .387 r
.78073 .4433 .78269 .44585 .77634 .30939 .77446 .30675 Mtetra
.664 .741 .908 r
.77446 .30675 .77634 .30939 .78065 .30796 .77877 .30531 Mtetra
.77877 .30531 .78065 .30796 .78497 .30653 .78309 .30388 Mtetra
.78309 .30388 .78497 .30653 .78929 .30509 .78742 .30244 Mtetra
.78742 .30244 .78929 .30509 .79362 .30366 .79176 .301 Mtetra
.79176 .301 .79362 .30366 .79796 .30222 .7961 .29956 Mtetra
.7961 .29956 .79796 .30222 .80231 .30078 .80045 .29811 Mtetra
.80045 .29811 .80231 .30078 .80666 .29933 .8048 .29666 Mtetra
.8048 .29666 .80666 .29933 .81101 .29789 .80916 .29521 Mtetra
.80916 .29521 .81101 .29789 .81537 .29644 .81353 .29376 Mtetra
.81353 .29376 .81537 .29644 .81974 .29499 .8179 .29231 Mtetra
.8179 .29231 .81974 .29499 .82412 .29354 .82229 .29085 Mtetra
.82229 .29085 .82412 .29354 .8285 .29208 .82667 .28939 Mtetra
.82667 .28939 .8285 .29208 .83289 .29063 .83107 .28793 Mtetra
.83107 .28793 .83289 .29063 .83729 .28917 .83547 .28647 Mtetra
.83547 .28647 .83729 .28917 .84169 .28771 .83988 .285 Mtetra
.83988 .285 .84169 .28771 .8461 .28624 .84429 .28354 Mtetra
.84429 .28354 .8461 .28624 .85052 .28478 .84871 .28207 Mtetra
.84871 .28207 .85052 .28478 .85494 .28331 .85314 .2806 Mtetra
.85314 .2806 .85494 .28331 .85937 .28184 .85757 .27912 Mtetra
.85757 .27912 .85937 .28184 .86381 .28037 .86202 .27765 Mtetra
.86202 .27765 .86381 .28037 .86825 .2789 .86646 .27617 Mtetra
.26488 .47313 .26725 .47533 .27083 .47414 .26847 .47194 Mtetra
.26847 .47194 .27083 .47414 .27443 .47295 .27207 .47074 Mtetra
.27207 .47074 .27443 .47295 .27802 .47175 .27567 .46954 Mtetra
.27567 .46954 .27802 .47175 .28162 .47056 .27927 .46834 Mtetra
.27927 .46834 .28162 .47056 .28523 .46936 .28288 .46714 Mtetra
.28288 .46714 .28523 .46936 .28884 .46816 .2865 .46593 Mtetra
.2865 .46593 .28884 .46816 .29246 .46695 .29012 .46473 Mtetra
.29012 .46473 .29246 .46695 .29608 .46575 .29374 .46352 Mtetra
.29374 .46352 .29608 .46575 .29971 .46454 .29737 .46231 Mtetra
.29737 .46231 .29971 .46454 .30334 .46334 .30101 .4611 Mtetra
.30101 .4611 .30334 .46334 .30698 .46213 .30465 .45989 Mtetra
.30465 .45989 .30698 .46213 .31062 .46092 .30829 .45868 Mtetra
.30829 .45868 .31062 .46092 .31427 .45971 .31194 .45746 Mtetra
.31194 .45746 .31427 .45971 .31792 .45849 .3156 .45625 Mtetra
.3156 .45625 .31792 .45849 .32158 .45728 .31926 .45503 Mtetra
.31926 .45503 .32158 .45728 .32524 .45606 .32292 .45381 Mtetra
.32292 .45381 .32524 .45606 .32891 .45484 .32659 .45258 Mtetra
.32659 .45258 .32891 .45484 .33258 .45362 .33027 .45136 Mtetra
.33027 .45136 .33258 .45362 .33626 .4524 .33395 .45014 Mtetra
.33395 .45014 .33626 .4524 .33994 .45117 .33763 .44891 Mtetra
.33763 .44891 .33994 .45117 .33473 .61066 .34133 .44768 Mtetra
0 0 .281 r
.34133 .44768 .33473 .61066 .33859 .60949 .33617 .60732 Mtetra
.651 .757 .927 r
.33617 .60732 .33859 .60949 .34247 .60832 .34005 .60615 Mtetra
.34005 .60615 .34247 .60832 .34635 .60714 .34393 .60497 Mtetra
.34393 .60497 .34635 .60714 .35023 .60597 .34782 .60379 Mtetra
.34782 .60379 .35023 .60597 .35412 .60479 .35171 .60261 Mtetra
.35171 .60261 .35412 .60479 .35802 .60361 .35561 .60143 Mtetra
.35561 .60143 .35802 .60361 .36192 .60243 .35952 .60025 Mtetra
.35952 .60025 .36192 .60243 .36583 .60125 .36343 .59906 Mtetra
.36343 .59906 .36583 .60125 .36974 .60006 .36734 .59787 Mtetra
.36734 .59787 .36974 .60006 .37366 .59888 .37127 .59668 Mtetra
.37127 .59668 .37366 .59888 .37758 .59769 .37519 .59549 Mtetra
.37519 .59549 .37758 .59769 .38151 .5965 .37913 .5943 Mtetra
.37913 .5943 .38151 .5965 .38545 .59531 .38307 .5931 Mtetra
.38307 .5931 .38545 .59531 .38939 .59411 .38701 .59191 Mtetra
.38701 .59191 .38939 .59411 .39334 .59292 .39097 .59071 Mtetra
.39097 .59071 .39334 .59292 .39729 .59172 .39492 .58951 Mtetra
.39492 .58951 .39729 .59172 .40125 .59052 .39889 .58831 Mtetra
.39889 .58831 .40125 .59052 .40522 .58932 .40286 .5871 Mtetra
.40286 .5871 .40522 .58932 .40919 .58812 .40683 .5859 Mtetra
.40683 .5859 .40919 .58812 .41317 .58692 .41081 .58469 Mtetra
.41081 .58469 .41317 .58692 .41715 .58571 .4148 .58348 Mtetra
.946 .715 .556 r
.4148 .58348 .41715 .58571 .42114 .58451 .4199 .54656 Mtetra
.566 .371 .577 r
.4199 .54656 .42114 .58451 .42618 .54759 .42386 .54533 Mtetra
.654 .754 .923 r
.42386 .54533 .42618 .54759 .43014 .54637 .42782 .5441 Mtetra
.42782 .5441 .43014 .54637 .4341 .54514 .43179 .54287 Mtetra
.43179 .54287 .4341 .54514 .43808 .54391 .43577 .54164 Mtetra
.43577 .54164 .43808 .54391 .44205 .54268 .43975 .54041 Mtetra
.43975 .54041 .44205 .54268 .44603 .54145 .44373 .53917 Mtetra
.44373 .53917 .44603 .54145 .45002 .54022 .44773 .53794 Mtetra
.44773 .53794 .45002 .54022 .45402 .53898 .45173 .5367 Mtetra
.45173 .5367 .45402 .53898 .45802 .53775 .45573 .53546 Mtetra
.45573 .53546 .45802 .53775 .46202 .53651 .45974 .53422 Mtetra
.45974 .53422 .46202 .53651 .46604 .53527 .46376 .53297 Mtetra
.46376 .53297 .46604 .53527 .47006 .53402 .46778 .53173 Mtetra
.46778 .53173 .47006 .53402 .47408 .53278 .47181 .53048 Mtetra
.47181 .53048 .47408 .53278 .47811 .53153 .47584 .52923 Mtetra
.47584 .52923 .47811 .53153 .48215 .53029 .47988 .52798 Mtetra
.47988 .52798 .48215 .53029 .48613 .53412 .48392 .52672 Mtetra
.949 .686 .502 r
.48392 .52672 .48613 .53412 .49018 .53287 .48938 .39839 Mtetra
.554 .343 .548 r
.48938 .39839 .49018 .53287 .49424 .53162 .49328 .39709 Mtetra
.49328 .39709 .49424 .53162 .49831 .53036 .49719 .39578 Mtetra
.49719 .39578 .49831 .53036 .50327 .39689 .50111 .39448 Mtetra
.664 .741 .908 r
.50111 .39448 .50327 .39689 .50719 .39558 .50503 .39317 Mtetra
.50503 .39317 .50719 .39558 .51111 .39428 .50896 .39187 Mtetra
.50896 .39187 .51111 .39428 .51504 .39297 .51289 .39056 Mtetra
.51289 .39056 .51504 .39297 .51897 .39167 .51683 .38925 Mtetra
.51683 .38925 .51897 .39167 .52291 .39036 .52077 .38793 Mtetra
.52077 .38793 .52291 .39036 .52686 .38904 .52472 .38662 Mtetra
.52472 .38662 .52686 .38904 .53081 .38773 .52868 .3853 Mtetra
.52868 .3853 .53081 .38773 .53477 .38642 .53264 .38398 Mtetra
.53264 .38398 .53477 .38642 .53879 .39931 .53661 .38266 Mtetra
.113 .083 .541 r
.53661 .38266 .53879 .39931 .54278 .398 .54065 .39557 Mtetra
.663 .743 .91 r
.54065 .39557 .54278 .398 .54677 .39668 .54464 .39425 Mtetra
.54464 .39425 .54677 .39668 .55077 .39536 .54865 .39292 Mtetra
.54865 .39292 .55077 .39536 .55477 .39404 .55265 .3916 Mtetra
.55265 .3916 .55477 .39404 .55878 .39272 .55667 .39027 Mtetra
.55667 .39027 .55878 .39272 .5628 .3914 .56069 .38895 Mtetra
.56069 .38895 .5628 .3914 .56682 .39007 .56471 .38762 Mtetra
.56471 .38762 .56682 .39007 .57085 .38874 .56874 .38628 Mtetra
.56874 .38628 .57085 .38874 .57488 .38741 .57278 .38495 Mtetra
.57278 .38495 .57488 .38741 .57892 .38608 .57682 .38361 Mtetra
.57682 .38361 .57892 .38608 .58296 .38474 .58087 .38228 Mtetra
.58087 .38228 .58296 .38474 .58701 .38341 .58492 .38094 Mtetra
.58492 .38094 .58701 .38341 .59107 .38207 .58898 .3796 Mtetra
.58898 .3796 .59107 .38207 .59513 .38073 .59305 .37825 Mtetra
.59305 .37825 .59513 .38073 .5992 .37939 .59712 .37691 Mtetra
.59712 .37691 .5992 .37939 .60328 .37805 .6012 .37556 Mtetra
.6012 .37556 .60328 .37805 .60736 .3767 .60529 .37421 Mtetra
.60529 .37421 .60736 .3767 .61144 .37535 .60938 .37286 Mtetra
.60938 .37286 .61144 .37535 .62025 .5402 .61347 .37151 Mtetra
0 0 .41 r
.61347 .37151 .62025 .5402 .62456 .5389 .6224 .53651 Mtetra
.649 .759 .929 r
.6224 .53651 .62456 .5389 .62888 .53761 .62673 .53521 Mtetra
.62673 .53521 .62888 .53761 .63321 .53631 .63106 .53391 Mtetra
.63106 .53391 .63321 .53631 .63755 .53501 .6354 .53261 Mtetra
.6354 .53261 .63755 .53501 .64189 .53371 .63975 .5313 Mtetra
.63975 .5313 .64189 .53371 .64624 .53241 .6441 .52999 Mtetra
.6441 .52999 .64624 .53241 .65059 .5311 .64846 .52868 Mtetra
.64846 .52868 .65059 .5311 .65496 .52979 .65283 .52737 Mtetra
.65283 .52737 .65496 .52979 .65932 .52848 .6572 .52606 Mtetra
.6572 .52606 .65932 .52848 .6637 .52717 .66158 .52474 Mtetra
.893 .799 .748 r
.66158 .52474 .6637 .52717 .66808 .52586 .66575 .51811 Mtetra
.616 .516 .717 r
.66575 .51811 .66808 .52586 .67247 .52454 .67013 .51679 Mtetra
.67013 .51679 .67247 .52454 .67663 .51791 .67453 .51546 Mtetra
.65 .758 .929 r
.67453 .51546 .67663 .51791 .68102 .51658 .67893 .51414 Mtetra
.67893 .51414 .68102 .51658 .68543 .51526 .68333 .51281 Mtetra
.68333 .51281 .68543 .51526 .68983 .51393 .68775 .51148 Mtetra
.68775 .51148 .68983 .51393 .69425 .5126 .69217 .51015 Mtetra
.69217 .51015 .69425 .5126 .69867 .51127 .6966 .50881 Mtetra
.6966 .50881 .69867 .51127 .7031 .50994 .70103 .50748 Mtetra
.70103 .50748 .7031 .50994 .70754 .50861 .70547 .50614 Mtetra
.70547 .50614 .70754 .50861 .71198 .50727 .70992 .5048 Mtetra
.70992 .5048 .71198 .50727 .71401 .46386 .71438 .50346 Mtetra
0 0 .354 r
.71438 .50346 .71401 .46386 .71841 .46251 .71638 .46 Mtetra
.653 .754 .924 r
.71638 .46 .71841 .46251 .72282 .46115 .7208 .45864 Mtetra
.7208 .45864 .72282 .46115 .72723 .45979 .72521 .45727 Mtetra
.72521 .45727 .72723 .45979 .73165 .45843 .72964 .4559 Mtetra
.72964 .4559 .73165 .45843 .73608 .45706 .73407 .45454 Mtetra
.73407 .45454 .73608 .45706 .74052 .45569 .73851 .45316 Mtetra
.73851 .45316 .74052 .45569 .74496 .45432 .74295 .45179 Mtetra
.74295 .45179 .74496 .45432 .7494 .45295 .74741 .45042 Mtetra
.74741 .45042 .7494 .45295 .75386 .45158 .75187 .44904 Mtetra
.75187 .44904 .75386 .45158 .75832 .4502 .75633 .44766 Mtetra
.75633 .44766 .75832 .4502 .76279 .44883 .76081 .44628 Mtetra
.76081 .44628 .76279 .44883 .76726 .44745 .76529 .44489 Mtetra
0 .219 .73 r
.76529 .44489 .76726 .44745 .77175 .44607 .77017 .44874 Mtetra
.238 0 0 r
.77017 .44874 .77175 .44607 .77624 .44468 .77467 .44735 Mtetra
.77467 .44735 .77624 .44468 .78073 .4433 .77918 .44596 Mtetra
.983 .695 .364 r
.77918 .44596 .78073 .4433 .77446 .30675 .77256 .3041 Mtetra
.664 .741 .908 r
.77256 .3041 .77446 .30675 .77877 .30531 .77688 .30266 Mtetra
.77688 .30266 .77877 .30531 .78309 .30388 .78121 .30122 Mtetra
.78121 .30122 .78309 .30388 .78742 .30244 .78554 .29978 Mtetra
.78554 .29978 .78742 .30244 .79176 .301 .78988 .29833 Mtetra
.78988 .29833 .79176 .301 .7961 .29956 .79423 .29689 Mtetra
.79423 .29689 .7961 .29956 .80045 .29811 .79858 .29544 Mtetra
.79858 .29544 .80045 .29811 .8048 .29666 .80294 .29399 Mtetra
.80294 .29399 .8048 .29666 .80916 .29521 .80731 .29253 Mtetra
.80731 .29253 .80916 .29521 .81353 .29376 .81168 .29108 Mtetra
.81168 .29108 .81353 .29376 .8179 .29231 .81606 .28962 Mtetra
.81606 .28962 .8179 .29231 .82229 .29085 .82045 .28816 Mtetra
.82045 .28816 .82229 .29085 .82667 .28939 .82484 .28669 Mtetra
.82484 .28669 .82667 .28939 .83107 .28793 .82924 .28523 Mtetra
.82924 .28523 .83107 .28793 .83547 .28647 .83364 .28376 Mtetra
.83364 .28376 .83547 .28647 .83988 .285 .83805 .28229 Mtetra
.83805 .28229 .83988 .285 .84429 .28354 .84247 .28082 Mtetra
.84247 .28082 .84429 .28354 .84871 .28207 .8469 .27935 Mtetra
.8469 .27935 .84871 .28207 .85314 .2806 .85133 .27787 Mtetra
.85133 .27787 .85314 .2806 .85757 .27912 .85577 .2764 Mtetra
.85577 .2764 .85757 .27912 .86202 .27765 .86022 .27492 Mtetra
.86022 .27492 .86202 .27765 .86646 .27617 .86467 .27343 Mtetra
.26251 .47092 .26488 .47313 .26847 .47194 .2661 .46973 Mtetra
.2661 .46973 .26847 .47194 .27207 .47074 .2697 .46853 Mtetra
.2697 .46853 .27207 .47074 .27567 .46954 .2733 .46732 Mtetra
.2733 .46732 .27567 .46954 .27927 .46834 .27691 .46612 Mtetra
.27691 .46612 .27927 .46834 .28288 .46714 .28052 .46492 Mtetra
.28052 .46492 .28288 .46714 .2865 .46593 .28414 .46371 Mtetra
.28414 .46371 .2865 .46593 .29012 .46473 .28777 .4625 Mtetra
.28777 .4625 .29012 .46473 .29374 .46352 .29139 .46129 Mtetra
.29139 .46129 .29374 .46352 .29737 .46231 .29503 .46008 Mtetra
.29503 .46008 .29737 .46231 .30101 .4611 .29866 .45886 Mtetra
.29866 .45886 .30101 .4611 .30465 .45989 .30231 .45765 Mtetra
.30231 .45765 .30465 .45989 .30829 .45868 .30596 .45643 Mtetra
.30596 .45643 .30829 .45868 .31194 .45746 .30961 .45521 Mtetra
.30961 .45521 .31194 .45746 .3156 .45625 .31327 .45399 Mtetra
.31327 .45399 .3156 .45625 .31926 .45503 .31693 .45277 Mtetra
.31693 .45277 .31926 .45503 .32292 .45381 .3206 .45155 Mtetra
.3206 .45155 .32292 .45381 .32659 .45258 .32427 .45032 Mtetra
.32427 .45032 .32659 .45258 .33027 .45136 .32795 .4491 Mtetra
.32795 .4491 .33027 .45136 .33395 .45014 .33163 .44787 Mtetra
.33163 .44787 .33395 .45014 .33763 .44891 .33532 .44664 Mtetra
.33532 .44664 .33763 .44891 .34133 .44768 .33902 .44541 Mtetra
.947 .68 .498 r
.33902 .44541 .34133 .44768 .33617 .60732 .33374 .60515 Mtetra
.651 .757 .927 r
.33374 .60515 .33617 .60732 .34005 .60615 .33762 .60397 Mtetra
.33762 .60397 .34005 .60615 .34393 .60497 .34151 .60279 Mtetra
.34151 .60279 .34393 .60497 .34782 .60379 .3454 .60161 Mtetra
.3454 .60161 .34782 .60379 .35171 .60261 .34929 .60043 Mtetra
.34929 .60043 .35171 .60261 .35561 .60143 .3532 .59924 Mtetra
.3532 .59924 .35561 .60143 .35952 .60025 .35711 .59805 Mtetra
.35711 .59805 .35952 .60025 .36343 .59906 .36102 .59687 Mtetra
.36102 .59687 .36343 .59906 .36734 .59787 .36494 .59567 Mtetra
.36494 .59567 .36734 .59787 .37127 .59668 .36887 .59448 Mtetra
.36887 .59448 .37127 .59668 .37519 .59549 .3728 .59329 Mtetra
.3728 .59329 .37519 .59549 .37913 .5943 .37674 .59209 Mtetra
.37674 .59209 .37913 .5943 .38307 .5931 .38068 .59089 Mtetra
.38068 .59089 .38307 .5931 .38701 .59191 .38463 .58969 Mtetra
.38463 .58969 .38701 .59191 .39097 .59071 .38858 .58849 Mtetra
.38858 .58849 .39097 .59071 .39492 .58951 .39255 .58729 Mtetra
.39255 .58729 .39492 .58951 .39889 .58831 .39651 .58608 Mtetra
.39651 .58608 .39889 .58831 .40286 .5871 .40049 .58488 Mtetra
.40049 .58488 .40286 .5871 .40683 .5859 .40446 .58367 Mtetra
.40446 .58367 .40683 .5859 .41081 .58469 .40845 .58246 Mtetra
.40845 .58246 .41081 .58469 .4148 .58348 .41244 .58125 Mtetra
.946 .715 .556 r
.41244 .58125 .4148 .58348 .4199 .54656 .41757 .54429 Mtetra
.654 .754 .923 r
.41757 .54429 .4199 .54656 .42386 .54533 .42154 .54306 Mtetra
.42154 .54306 .42386 .54533 .42782 .5441 .4255 .54183 Mtetra
.4255 .54183 .42782 .5441 .43179 .54287 .42947 .5406 Mtetra
.42947 .5406 .43179 .54287 .43577 .54164 .43345 .53936 Mtetra
.43345 .53936 .43577 .54164 .43975 .54041 .43744 .53813 Mtetra
.43744 .53813 .43975 .54041 .44373 .53917 .44143 .53689 Mtetra
.44143 .53689 .44373 .53917 .44773 .53794 .44542 .53565 Mtetra
.44542 .53565 .44773 .53794 .45173 .5367 .44943 .53441 Mtetra
.44943 .53441 .45173 .5367 .45573 .53546 .45343 .53316 Mtetra
.45343 .53316 .45573 .53546 .45974 .53422 .45745 .53192 Mtetra
.45745 .53192 .45974 .53422 .46376 .53297 .46147 .53067 Mtetra
.46147 .53067 .46376 .53297 .46778 .53173 .46549 .52942 Mtetra
.46549 .52942 .46778 .53173 .47181 .53048 .46952 .52817 Mtetra
.46952 .52817 .47181 .53048 .47584 .52923 .47356 .52692 Mtetra
.47356 .52692 .47584 .52923 .47988 .52798 .47761 .52566 Mtetra
.47761 .52566 .47988 .52798 .48392 .52672 .48166 .5244 Mtetra
.959 .697 .494 r
.48166 .5244 .48392 .52672 .48938 .39839 .4872 .39598 Mtetra
.664 .741 .908 r
.4872 .39598 .48938 .39839 .49328 .39709 .49111 .39468 Mtetra
.49111 .39468 .49328 .39709 .49719 .39578 .49502 .39338 Mtetra
.49502 .39338 .49719 .39578 .50111 .39448 .49894 .39207 Mtetra
.49894 .39207 .50111 .39448 .50503 .39317 .50287 .39076 Mtetra
.50287 .39076 .50503 .39317 .50896 .39187 .5068 .38945 Mtetra
.5068 .38945 .50896 .39187 .51289 .39056 .51073 .38814 Mtetra
.51073 .38814 .51289 .39056 .51683 .38925 .51468 .38682 Mtetra
.51468 .38682 .51683 .38925 .52077 .38793 .51862 .3855 Mtetra
.51862 .3855 .52077 .38793 .52472 .38662 .52258 .38419 Mtetra
.52258 .38419 .52472 .38662 .52868 .3853 .52654 .38286 Mtetra
.52654 .38286 .52868 .3853 .53264 .38398 .5305 .38154 Mtetra
.5305 .38154 .53264 .38398 .53661 .38266 .53447 .38022 Mtetra
.922 .532 .16 r
.53447 .38022 .53661 .38266 .54065 .39557 .53851 .39313 Mtetra
.663 .743 .91 r
.53851 .39313 .54065 .39557 .54464 .39425 .54251 .3918 Mtetra
.54251 .3918 .54464 .39425 .54865 .39292 .54651 .39048 Mtetra
.54651 .39048 .54865 .39292 .55265 .3916 .55053 .38915 Mtetra
.55053 .38915 .55265 .3916 .55667 .39027 .55454 .38782 Mtetra
.55454 .38782 .55667 .39027 .56069 .38895 .55857 .38649 Mtetra
.55857 .38649 .56069 .38895 .56471 .38762 .5626 .38516 Mtetra
.5626 .38516 .56471 .38762 .56874 .38628 .56663 .38382 Mtetra
.56663 .38382 .56874 .38628 .57278 .38495 .57067 .38248 Mtetra
.57067 .38248 .57278 .38495 .57682 .38361 .57472 .38114 Mtetra
.57472 .38114 .57682 .38361 .58087 .38228 .57877 .3798 Mtetra
.57877 .3798 .58087 .38228 .58492 .38094 .58283 .37846 Mtetra
.58283 .37846 .58492 .38094 .58898 .3796 .58689 .37711 Mtetra
.58689 .37711 .58898 .3796 .59305 .37825 .59096 .37577 Mtetra
.59096 .37577 .59305 .37825 .59712 .37691 .59504 .37442 Mtetra
.59504 .37442 .59712 .37691 .6012 .37556 .59912 .37307 Mtetra
.59912 .37307 .6012 .37556 .60529 .37421 .60321 .37171 Mtetra
.60321 .37171 .60529 .37421 .60938 .37286 .6073 .37036 Mtetra
.6073 .37036 .60938 .37286 .61347 .37151 .6114 .369 Mtetra
.971 .675 .405 r
.6114 .369 .61347 .37151 .6224 .53651 .62024 .53411 Mtetra
.649 .759 .929 r
.62024 .53411 .6224 .53651 .62673 .53521 .62457 .53281 Mtetra
.62457 .53281 .62673 .53521 .63106 .53391 .62891 .5315 Mtetra
.62891 .5315 .63106 .53391 .6354 .53261 .63325 .53019 Mtetra
.63325 .53019 .6354 .53261 .63975 .5313 .6376 .52888 Mtetra
.6376 .52888 .63975 .5313 .6441 .52999 .64196 .52757 Mtetra
.64196 .52757 .6441 .52999 .64846 .52868 .64633 .52626 Mtetra
.64633 .52626 .64846 .52868 .65283 .52737 .6507 .52495 Mtetra
.6507 .52495 .65283 .52737 .6572 .52606 .65507 .52363 Mtetra
.893 .798 .748 r
.65507 .52363 .6572 .52606 .66158 .52474 .65925 .51699 Mtetra
.616 .515 .717 r
.65925 .51699 .66158 .52474 .66575 .51811 .66363 .51567 Mtetra
.65 .758 .929 r
.66363 .51567 .66575 .51811 .67013 .51679 .66802 .51434 Mtetra
.66802 .51434 .67013 .51679 .67453 .51546 .67242 .51301 Mtetra
.67242 .51301 .67453 .51546 .67893 .51414 .67682 .51168 Mtetra
.67682 .51168 .67893 .51414 .68333 .51281 .68124 .51035 Mtetra
.68124 .51035 .68333 .51281 .68775 .51148 .68566 .50902 Mtetra
.68566 .50902 .68775 .51148 .69217 .51015 .69008 .50768 Mtetra
.69008 .50768 .69217 .51015 .6966 .50881 .69451 .50634 Mtetra
.69451 .50634 .6966 .50881 .70103 .50748 .69895 .505 Mtetra
.69895 .505 .70103 .50748 .70547 .50614 .7034 .50366 Mtetra
.7034 .50366 .70547 .50614 .70992 .5048 .70785 .50232 Mtetra
.70785 .50232 .70992 .5048 .71438 .50346 .71231 .50097 Mtetra
.71231 .50097 .71438 .50346 .71638 .46 .71678 .49962 Mtetra
.531 .291 .496 r
.71678 .49962 .71638 .46 .7208 .45864 .72126 .49827 Mtetra
0 0 .355 r
.72126 .49827 .7208 .45864 .72521 .45727 .72319 .45475 Mtetra
.653 .754 .924 r
.72319 .45475 .72521 .45727 .72964 .4559 .72762 .45338 Mtetra
.72762 .45338 .72964 .4559 .73407 .45454 .73205 .452 Mtetra
.73205 .452 .73407 .45454 .73851 .45316 .7365 .45063 Mtetra
.7365 .45063 .73851 .45316 .74295 .45179 .74095 .44925 Mtetra
.74095 .44925 .74295 .45179 .74741 .45042 .7454 .44787 Mtetra
0 .209 .721 r
.7454 .44787 .74741 .45042 .75187 .44904 .75023 .45172 Mtetra
.236 0 0 r
.75023 .45172 .75187 .44904 .75633 .44766 .75471 .45033 Mtetra
.75471 .45033 .75633 .44766 .76081 .44628 .75919 .44895 Mtetra
.75919 .44895 .76081 .44628 .76529 .44489 .76368 .44756 Mtetra
.76368 .44756 .76529 .44489 .77017 .44874 .76818 .44618 Mtetra
.653 .755 .924 r
.76818 .44618 .77017 .44874 .77467 .44735 .77269 .44479 Mtetra
.77269 .44479 .77467 .44735 .77918 .44596 .7772 .44339 Mtetra
.7772 .44339 .77918 .44596 .77256 .3041 .78173 .442 Mtetra
.042 0 .425 r
.78173 .442 .77256 .3041 .77688 .30266 .77499 .3 Mtetra
.664 .741 .908 r
.77499 .3 .77688 .30266 .78121 .30122 .77932 .29856 Mtetra
.77932 .29856 .78121 .30122 .78554 .29978 .78366 .29711 Mtetra
.78366 .29711 .78554 .29978 .78988 .29833 .78801 .29566 Mtetra
.78801 .29566 .78988 .29833 .79423 .29689 .79236 .29421 Mtetra
.79236 .29421 .79423 .29689 .79858 .29544 .79671 .29276 Mtetra
.79671 .29276 .79858 .29544 .80294 .29399 .80108 .2913 Mtetra
.80108 .2913 .80294 .29399 .80731 .29253 .80545 .28984 Mtetra
.80545 .28984 .80731 .29253 .81168 .29108 .80983 .28838 Mtetra
.80983 .28838 .81168 .29108 .81606 .28962 .81421 .28692 Mtetra
.81421 .28692 .81606 .28962 .82045 .28816 .8186 .28546 Mtetra
.8186 .28546 .82045 .28816 .82484 .28669 .823 .28399 Mtetra
.823 .28399 .82484 .28669 .82924 .28523 .8274 .28252 Mtetra
.8274 .28252 .82924 .28523 .83364 .28376 .83181 .28105 Mtetra
.83181 .28105 .83364 .28376 .83805 .28229 .83623 .27958 Mtetra
.83623 .27958 .83805 .28229 .84247 .28082 .84065 .2781 Mtetra
.84065 .2781 .84247 .28082 .8469 .27935 .84508 .27662 Mtetra
.84508 .27662 .8469 .27935 .85133 .27787 .84952 .27514 Mtetra
.84952 .27514 .85133 .27787 .85577 .2764 .85396 .27366 Mtetra
.85396 .27366 .85577 .2764 .86022 .27492 .85842 .27218 Mtetra
.85842 .27218 .86022 .27492 .86467 .27343 .86287 .27069 Mtetra
.26013 .46871 .26251 .47092 .2661 .46973 .26373 .46751 Mtetra
.26373 .46751 .2661 .46973 .2697 .46853 .26733 .46631 Mtetra
.26733 .46631 .2697 .46853 .2733 .46732 .27093 .4651 Mtetra
.27093 .4651 .2733 .46732 .27691 .46612 .27455 .46389 Mtetra
.27455 .46389 .27691 .46612 .28052 .46492 .27816 .46269 Mtetra
.27816 .46269 .28052 .46492 .28414 .46371 .28178 .46148 Mtetra
.28178 .46148 .28414 .46371 .28777 .4625 .28541 .46026 Mtetra
.28541 .46026 .28777 .4625 .29139 .46129 .28904 .45905 Mtetra
.28904 .45905 .29139 .46129 .29503 .46008 .29268 .45784 Mtetra
.29268 .45784 .29503 .46008 .29866 .45886 .29632 .45662 Mtetra
.29632 .45662 .29866 .45886 .30231 .45765 .29996 .4554 Mtetra
.29996 .4554 .30231 .45765 .30596 .45643 .30361 .45418 Mtetra
.30361 .45418 .30596 .45643 .30961 .45521 .30727 .45296 Mtetra
.30727 .45296 .30961 .45521 .31327 .45399 .31093 .45174 Mtetra
.31093 .45174 .31327 .45399 .31693 .45277 .3146 .45051 Mtetra
.3146 .45051 .31693 .45277 .3206 .45155 .31827 .44929 Mtetra
.31827 .44929 .3206 .45155 .32427 .45032 .32195 .44806 Mtetra
.32195 .44806 .32427 .45032 .32795 .4491 .32563 .44683 Mtetra
.32563 .44683 .32795 .4491 .33163 .44787 .32931 .4456 Mtetra
.32931 .4456 .33163 .44787 .33532 .44664 .33301 .44436 Mtetra
.33301 .44436 .33532 .44664 .33902 .44541 .3367 .44313 Mtetra
.947 .679 .497 r
.3367 .44313 .33902 .44541 .33374 .60515 .33217 .58768 Mtetra
.582 .414 .619 r
.33217 .58768 .33374 .60515 .33762 .60397 .33603 .58649 Mtetra
.33603 .58649 .33762 .60397 .34151 .60279 .33991 .5853 Mtetra
.33991 .5853 .34151 .60279 .3454 .60161 .34378 .58411 Mtetra
.34378 .58411 .3454 .60161 .34929 .60043 .34767 .58292 Mtetra
.34767 .58292 .34929 .60043 .3532 .59924 .35156 .58172 Mtetra
.35156 .58172 .3532 .59924 .35711 .59805 .35545 .58052 Mtetra
.35545 .58052 .35711 .59805 .36102 .59687 .35935 .57933 Mtetra
0 0 .483 r
.35935 .57933 .36102 .59687 .36494 .59567 .36253 .59347 Mtetra
.651 .757 .927 r
.36253 .59347 .36494 .59567 .36887 .59448 .36646 .59228 Mtetra
.36646 .59228 .36887 .59448 .3728 .59329 .3704 .59108 Mtetra
.3704 .59108 .3728 .59329 .37674 .59209 .37434 .58988 Mtetra
.37434 .58988 .37674 .59209 .38068 .59089 .37829 .58868 Mtetra
.37829 .58868 .38068 .59089 .38463 .58969 .38224 .58747 Mtetra
.38224 .58747 .38463 .58969 .38858 .58849 .3862 .58627 Mtetra
.3862 .58627 .38858 .58849 .39255 .58729 .39016 .58506 Mtetra
.39016 .58506 .39255 .58729 .39651 .58608 .39413 .58386 Mtetra
.39413 .58386 .39651 .58608 .40049 .58488 .39811 .58265 Mtetra
.39811 .58265 .40049 .58488 .40446 .58367 .40209 .58143 Mtetra
.40209 .58143 .40446 .58367 .40845 .58246 .40608 .58022 Mtetra
.946 .715 .557 r
.40608 .58022 .40845 .58246 .41244 .58125 .41128 .54325 Mtetra
.565 .37 .576 r
.41128 .54325 .41244 .58125 .41757 .54429 .41524 .54202 Mtetra
.654 .754 .923 r
.41524 .54202 .41757 .54429 .42154 .54306 .4192 .54079 Mtetra
.4192 .54079 .42154 .54306 .4255 .54183 .42317 .53955 Mtetra
.42317 .53955 .4255 .54183 .42947 .5406 .42715 .53832 Mtetra
.42715 .53832 .42947 .5406 .43345 .53936 .43113 .53708 Mtetra
.43113 .53708 .43345 .53936 .43744 .53813 .43512 .53584 Mtetra
.43512 .53584 .43744 .53813 .44143 .53689 .43911 .5346 Mtetra
.43911 .5346 .44143 .53689 .44542 .53565 .44311 .53335 Mtetra
.44311 .53335 .44542 .53565 .44943 .53441 .44712 .53211 Mtetra
.44712 .53211 .44943 .53441 .45343 .53316 .45113 .53086 Mtetra
.45113 .53086 .45343 .53316 .45745 .53192 .45515 .52961 Mtetra
.45515 .52961 .45745 .53192 .46147 .53067 .45917 .52836 Mtetra
.45917 .52836 .46147 .53067 .46549 .52942 .4632 .52711 Mtetra
.4632 .52711 .46549 .52942 .46952 .52817 .46724 .52585 Mtetra
.46724 .52585 .46952 .52817 .47356 .52692 .47128 .5246 Mtetra
.47128 .5246 .47356 .52692 .47761 .52566 .47533 .52334 Mtetra
.47533 .52334 .47761 .52566 .48166 .5244 .47938 .52208 Mtetra
.959 .697 .494 r
.47938 .52208 .48166 .5244 .4872 .39598 .48502 .39358 Mtetra
.664 .741 .908 r
.48502 .39358 .4872 .39598 .49111 .39468 .48893 .39227 Mtetra
.48893 .39227 .49111 .39468 .49502 .39338 .49285 .39096 Mtetra
.49285 .39096 .49502 .39338 .49894 .39207 .49677 .38965 Mtetra
.49677 .38965 .49894 .39207 .50287 .39076 .5007 .38834 Mtetra
.5007 .38834 .50287 .39076 .5068 .38945 .50463 .38702 Mtetra
.50463 .38702 .5068 .38945 .51073 .38814 .50857 .38571 Mtetra
.50857 .38571 .51073 .38814 .51468 .38682 .51252 .38439 Mtetra
.51252 .38439 .51468 .38682 .51862 .3855 .51647 .38307 Mtetra
.51647 .38307 .51862 .3855 .52258 .38419 .52043 .38175 Mtetra
.52043 .38175 .52258 .38419 .52654 .38286 .52439 .38042 Mtetra
.52439 .38042 .52654 .38286 .5305 .38154 .52836 .3791 Mtetra
.52836 .3791 .5305 .38154 .53447 .38022 .53233 .37777 Mtetra
.53233 .37777 .53447 .38022 .53851 .39313 .53631 .37644 Mtetra
.111 .081 .541 r
.53631 .37644 .53851 .39313 .54251 .3918 .54037 .38935 Mtetra
.663 .743 .91 r
.54037 .38935 .54251 .3918 .54651 .39048 .54438 .38802 Mtetra
.54438 .38802 .54651 .39048 .55053 .38915 .54839 .38669 Mtetra
.54839 .38669 .55053 .38915 .55454 .38782 .55241 .38536 Mtetra
.55241 .38536 .55454 .38782 .55857 .38649 .55644 .38403 Mtetra
.55644 .38403 .55857 .38649 .5626 .38516 .56047 .38269 Mtetra
.56047 .38269 .5626 .38516 .56663 .38382 .56451 .38135 Mtetra
.56451 .38135 .56663 .38382 .57067 .38248 .56856 .38001 Mtetra
.56856 .38001 .57067 .38248 .57472 .38114 .57261 .37867 Mtetra
.57261 .37867 .57472 .38114 .57877 .3798 .57666 .37732 Mtetra
.57666 .37732 .57877 .3798 .58283 .37846 .58073 .37597 Mtetra
.58073 .37597 .58283 .37846 .58689 .37711 .5848 .37463 Mtetra
.5848 .37463 .58689 .37711 .59096 .37577 .58887 .37328 Mtetra
.58887 .37328 .59096 .37577 .59504 .37442 .59295 .37192 Mtetra
.59295 .37192 .59504 .37442 .59912 .37307 .59704 .37057 Mtetra
.59704 .37057 .59912 .37307 .60321 .37171 .60113 .36921 Mtetra
.60113 .36921 .60321 .37171 .6073 .37036 .60523 .36785 Mtetra
.60523 .36785 .6073 .37036 .6114 .369 .60933 .36649 Mtetra
.60933 .36649 .6114 .369 .62024 .53411 .61344 .36513 Mtetra
0 0 .409 r
.61344 .36513 .62024 .53411 .62457 .53281 .6224 .5304 Mtetra
.649 .759 .929 r
.6224 .5304 .62457 .53281 .62891 .5315 .62675 .52909 Mtetra
.62675 .52909 .62891 .5315 .63325 .53019 .63109 .52778 Mtetra
.63109 .52778 .63325 .53019 .6376 .52888 .63545 .52646 Mtetra
.63545 .52646 .6376 .52888 .64196 .52757 .63981 .52515 Mtetra
.63981 .52515 .64196 .52757 .64633 .52626 .64418 .52383 Mtetra
.892 .798 .748 r
.64418 .52383 .64633 .52626 .6507 .52495 .64836 .51719 Mtetra
.615 .515 .717 r
.64836 .51719 .6507 .52495 .65507 .52363 .65274 .51587 Mtetra
.65274 .51587 .65507 .52363 .65925 .51699 .65712 .51455 Mtetra
.65 .758 .929 r
.65712 .51455 .65925 .51699 .66363 .51567 .66151 .51322 Mtetra
.66151 .51322 .66363 .51567 .66802 .51434 .6659 .51189 Mtetra
.6659 .51189 .66802 .51434 .67242 .51301 .67031 .51056 Mtetra
.67031 .51056 .67242 .51301 .67682 .51168 .67472 .50922 Mtetra
.67472 .50922 .67682 .51168 .68124 .51035 .67913 .50789 Mtetra
.67913 .50789 .68124 .51035 .68566 .50902 .68356 .50655 Mtetra
.68356 .50655 .68566 .50902 .69008 .50768 .68799 .50521 Mtetra
.68799 .50521 .69008 .50768 .69451 .50634 .69242 .50387 Mtetra
.69242 .50387 .69451 .50634 .69895 .505 .69687 .50252 Mtetra
.69687 .50252 .69895 .505 .7034 .50366 .70132 .50118 Mtetra
.70132 .50118 .7034 .50366 .70785 .50232 .70578 .49983 Mtetra
.70578 .49983 .70785 .50232 .71231 .50097 .71024 .49848 Mtetra
.71024 .49848 .71231 .50097 .71678 .49962 .71472 .49713 Mtetra
.71472 .49713 .71678 .49962 .72126 .49827 .7192 .49577 Mtetra
.7192 .49577 .72126 .49827 .72319 .45475 .72368 .49442 Mtetra
.052 0 .386 r
.72368 .49442 .72319 .45475 .72762 .45338 .72591 .45606 Mtetra
.234 0 0 r
.72591 .45606 .72762 .45338 .73205 .452 .73036 .45468 Mtetra
.73036 .45468 .73205 .452 .7365 .45063 .73481 .45331 Mtetra
.73481 .45331 .7365 .45063 .74095 .44925 .73927 .45193 Mtetra
.73927 .45193 .74095 .44925 .7454 .44787 .74374 .45055 Mtetra
.74374 .45055 .7454 .44787 .75023 .45172 .74822 .44916 Mtetra
.653 .755 .924 r
.74822 .44916 .75023 .45172 .75471 .45033 .7527 .44778 Mtetra
.7527 .44778 .75471 .45033 .75919 .44895 .7572 .44639 Mtetra
.7572 .44639 .75919 .44895 .76368 .44756 .76169 .445 Mtetra
.76169 .445 .76368 .44756 .76818 .44618 .7662 .44361 Mtetra
.7662 .44361 .76818 .44618 .77269 .44479 .77071 .44221 Mtetra
.77071 .44221 .77269 .44479 .7772 .44339 .77523 .44082 Mtetra
.77523 .44082 .7772 .44339 .78173 .442 .77975 .43942 Mtetra
.98 .689 .383 r
.77975 .43942 .78173 .442 .77499 .3 .77309 .29733 Mtetra
.664 .741 .908 r
.77309 .29733 .77499 .3 .77932 .29856 .77743 .29588 Mtetra
.77743 .29588 .77932 .29856 .78366 .29711 .78177 .29443 Mtetra
.78177 .29443 .78366 .29711 .78801 .29566 .78612 .29298 Mtetra
.78612 .29298 .78801 .29566 .79236 .29421 .79048 .29152 Mtetra
.79048 .29152 .79236 .29421 .79671 .29276 .79484 .29007 Mtetra
.79484 .29007 .79671 .29276 .80108 .2913 .79921 .28861 Mtetra
.79921 .28861 .80108 .2913 .80545 .28984 .80358 .28715 Mtetra
.80358 .28715 .80545 .28984 .80983 .28838 .80797 .28568 Mtetra
.80797 .28568 .80983 .28838 .81421 .28692 .81235 .28421 Mtetra
.81235 .28421 .81421 .28692 .8186 .28546 .81675 .28275 Mtetra
.81675 .28275 .8186 .28546 .823 .28399 .82115 .28128 Mtetra
.82115 .28128 .823 .28399 .8274 .28252 .82556 .2798 Mtetra
.82556 .2798 .8274 .28252 .83181 .28105 .82997 .27833 Mtetra
.82997 .27833 .83181 .28105 .83623 .27958 .8344 .27685 Mtetra
.8344 .27685 .83623 .27958 .84065 .2781 .83883 .27537 Mtetra
.83883 .27537 .84065 .2781 .84508 .27662 .84326 .27389 Mtetra
.84326 .27389 .84508 .27662 .84952 .27514 .8477 .2724 Mtetra
.8477 .2724 .84952 .27514 .85396 .27366 .85215 .27092 Mtetra
.85215 .27092 .85396 .27366 .85842 .27218 .85661 .26943 Mtetra
.85661 .26943 .85842 .27218 .86287 .27069 .86107 .26794 Mtetra
.25775 .46649 .26013 .46871 .26373 .46751 .26135 .46529 Mtetra
.26135 .46529 .26373 .46751 .26733 .46631 .26495 .46408 Mtetra
.26495 .46408 .26733 .46631 .27093 .4651 .26856 .46287 Mtetra
.26856 .46287 .27093 .4651 .27455 .46389 .27217 .46166 Mtetra
.27217 .46166 .27455 .46389 .27816 .46269 .27579 .46045 Mtetra
.27579 .46045 .27816 .46269 .28178 .46148 .27942 .45924 Mtetra
.27942 .45924 .28178 .46148 .28541 .46026 .28305 .45802 Mtetra
.28305 .45802 .28541 .46026 .28904 .45905 .28668 .45681 Mtetra
.28668 .45681 .28904 .45905 .29268 .45784 .29032 .45559 Mtetra
.29032 .45559 .29268 .45784 .29632 .45662 .29396 .45437 Mtetra
.29396 .45437 .29632 .45662 .29996 .4554 .29761 .45315 Mtetra
.29761 .45315 .29996 .4554 .30361 .45418 .30127 .45193 Mtetra
.30127 .45193 .30361 .45418 .30727 .45296 .30493 .4507 Mtetra
.30493 .4507 .30727 .45296 .31093 .45174 .30859 .44948 Mtetra
.30859 .44948 .31093 .45174 .3146 .45051 .31226 .44825 Mtetra
.31226 .44825 .3146 .45051 .31827 .44929 .31593 .44702 Mtetra
.31593 .44702 .31827 .44929 .32195 .44806 .31961 .44579 Mtetra
.31961 .44579 .32195 .44806 .32563 .44683 .3233 .44455 Mtetra
.3233 .44455 .32563 .44683 .32931 .4456 .32699 .44332 Mtetra
.32699 .44332 .32931 .4456 .33301 .44436 .33068 .44208 Mtetra
.33068 .44208 .33301 .44436 .3367 .44313 .33438 .44084 Mtetra
.947 .679 .497 r
.33438 .44084 .3367 .44313 .33217 .58768 .32974 .58548 Mtetra
.652 .756 .925 r
.32974 .58548 .33217 .58768 .33603 .58649 .33361 .58429 Mtetra
.33361 .58429 .33603 .58649 .33991 .5853 .33748 .5831 Mtetra
.33748 .5831 .33991 .5853 .34378 .58411 .34136 .58191 Mtetra
.34136 .58191 .34378 .58411 .34767 .58292 .34525 .58071 Mtetra
.34525 .58071 .34767 .58292 .35156 .58172 .34914 .57951 Mtetra
.34914 .57951 .35156 .58172 .35545 .58052 .35304 .57831 Mtetra
.35304 .57831 .35545 .58052 .35935 .57933 .35695 .57711 Mtetra
.35695 .57711 .35935 .57933 .36253 .59347 .36086 .57591 Mtetra
.581 .414 .619 r
.36086 .57591 .36253 .59347 .36646 .59228 .36477 .5747 Mtetra
.36477 .5747 .36646 .59228 .3704 .59108 .3687 .5735 Mtetra
.3687 .5735 .3704 .59108 .37434 .58988 .37262 .57229 Mtetra
.37262 .57229 .37434 .58988 .37829 .58868 .37656 .57108 Mtetra
.37656 .57108 .37829 .58868 .38224 .58747 .3805 .56986 Mtetra
.3805 .56986 .38224 .58747 .3862 .58627 .38444 .56865 Mtetra
.38444 .56865 .3862 .58627 .39016 .58506 .38839 .56743 Mtetra
.38839 .56743 .39016 .58506 .39413 .58386 .39235 .56622 Mtetra
.39235 .56622 .39413 .58386 .39811 .58265 .39631 .565 Mtetra
.39631 .565 .39811 .58265 .40209 .58143 .40028 .56378 Mtetra
.40028 .56378 .40209 .58143 .40608 .58022 .40425 .56255 Mtetra
.791 .567 .597 r
.40425 .56255 .40608 .58022 .41128 .54325 .40893 .54098 Mtetra
.654 .754 .923 r
.40893 .54098 .41128 .54325 .41524 .54202 .4129 .53974 Mtetra
.4129 .53974 .41524 .54202 .4192 .54079 .41687 .53851 Mtetra
.41687 .53851 .4192 .54079 .42317 .53955 .42084 .53727 Mtetra
.42084 .53727 .42317 .53955 .42715 .53832 .42482 .53603 Mtetra
.42482 .53603 .42715 .53832 .43113 .53708 .42881 .53479 Mtetra
.42881 .53479 .43113 .53708 .43512 .53584 .4328 .53355 Mtetra
.4328 .53355 .43512 .53584 .43911 .5346 .4368 .5323 Mtetra
.4368 .5323 .43911 .5346 .44311 .53335 .4408 .53105 Mtetra
.4408 .53105 .44311 .53335 .44712 .53211 .44481 .52981 Mtetra
.44481 .52981 .44712 .53211 .45113 .53086 .44882 .52855 Mtetra
.44882 .52855 .45113 .53086 .45515 .52961 .45285 .5273 Mtetra
.45285 .5273 .45515 .52961 .45917 .52836 .45687 .52605 Mtetra
.45687 .52605 .45917 .52836 .4632 .52711 .46091 .52479 Mtetra
.46091 .52479 .4632 .52711 .46724 .52585 .46495 .52353 Mtetra
.46495 .52353 .46724 .52585 .47128 .5246 .46899 .52227 Mtetra
.46899 .52227 .47128 .5246 .47533 .52334 .47304 .52101 Mtetra
.47304 .52101 .47533 .52334 .47938 .52208 .4771 .51975 Mtetra
.959 .697 .494 r
.4771 .51975 .47938 .52208 .48502 .39358 .48283 .39116 Mtetra
.664 .741 .908 r
.48283 .39116 .48502 .39358 .48893 .39227 .48674 .38985 Mtetra
.48674 .38985 .48893 .39227 .49285 .39096 .49067 .38854 Mtetra
.49067 .38854 .49285 .39096 .49677 .38965 .49459 .38723 Mtetra
.49459 .38723 .49677 .38965 .5007 .38834 .49853 .38591 Mtetra
.49853 .38591 .5007 .38834 .50463 .38702 .50246 .38459 Mtetra
.50246 .38459 .50463 .38702 .50857 .38571 .50641 .38327 Mtetra
.50641 .38327 .50857 .38571 .51252 .38439 .51036 .38195 Mtetra
.51036 .38195 .51252 .38439 .51647 .38307 .51431 .38063 Mtetra
.51431 .38063 .51647 .38307 .52043 .38175 .51827 .3793 Mtetra
.51827 .3793 .52043 .38175 .52439 .38042 .52224 .37797 Mtetra
.52224 .37797 .52439 .38042 .52836 .3791 .52621 .37664 Mtetra
.52621 .37664 .52836 .3791 .53233 .37777 .53019 .37531 Mtetra
.53019 .37531 .53233 .37777 .53631 .37644 .53417 .37398 Mtetra
.921 .531 .157 r
.53417 .37398 .53631 .37644 .54037 .38935 .53822 .3869 Mtetra
.663 .743 .91 r
.53822 .3869 .54037 .38935 .54438 .38802 .54224 .38557 Mtetra
.54224 .38557 .54438 .38802 .54839 .38669 .54625 .38423 Mtetra
.54625 .38423 .54839 .38669 .55241 .38536 .55028 .38289 Mtetra
.55028 .38289 .55241 .38536 .55644 .38403 .55431 .38156 Mtetra
.55431 .38156 .55644 .38403 .56047 .38269 .55835 .38022 Mtetra
.55835 .38022 .56047 .38269 .56451 .38135 .56239 .37887 Mtetra
.56239 .37887 .56451 .38135 .56856 .38001 .56644 .37753 Mtetra
.56644 .37753 .56856 .38001 .57261 .37867 .57049 .37618 Mtetra
.57049 .37618 .57261 .37867 .57666 .37732 .57455 .37483 Mtetra
.57455 .37483 .57666 .37732 .58073 .37597 .57862 .37348 Mtetra
.57862 .37348 .58073 .37597 .5848 .37463 .58269 .37213 Mtetra
.58269 .37213 .5848 .37463 .58887 .37328 .58677 .37078 Mtetra
.58677 .37078 .58887 .37328 .59295 .37192 .59085 .36942 Mtetra
.59085 .36942 .59295 .37192 .59704 .37057 .59494 .36806 Mtetra
.59494 .36806 .59704 .37057 .60113 .36921 .59904 .3667 Mtetra
.59904 .3667 .60113 .36921 .60523 .36785 .60314 .36534 Mtetra
.60314 .36534 .60523 .36785 .60933 .36649 .60725 .36398 Mtetra
.60725 .36398 .60933 .36649 .61344 .36513 .61137 .36261 Mtetra
.971 .675 .403 r
.61137 .36261 .61344 .36513 .6224 .5304 .62023 .52798 Mtetra
.649 .759 .929 r
.62023 .52798 .6224 .5304 .62675 .52909 .62458 .52666 Mtetra
.62458 .52666 .62675 .52909 .63109 .52778 .62893 .52535 Mtetra
.62893 .52535 .63109 .52778 .63545 .52646 .63329 .52403 Mtetra
.892 .797 .748 r
.63329 .52403 .63545 .52646 .63981 .52515 .63748 .5174 Mtetra
.615 .515 .717 r
.63748 .5174 .63981 .52515 .64418 .52383 .64185 .51607 Mtetra
.64185 .51607 .64418 .52383 .64836 .51719 .64622 .51475 Mtetra
.65 .758 .929 r
.64622 .51475 .64836 .51719 .65274 .51587 .6506 .51342 Mtetra
.6506 .51342 .65274 .51587 .65712 .51455 .65499 .51209 Mtetra
.65499 .51209 .65712 .51455 .66151 .51322 .65938 .51076 Mtetra
.65938 .51076 .66151 .51322 .6659 .51189 .66378 .50943 Mtetra
.66378 .50943 .6659 .51189 .67031 .51056 .66819 .50809 Mtetra
.66819 .50809 .67031 .51056 .67472 .50922 .6726 .50676 Mtetra
.6726 .50676 .67472 .50922 .67913 .50789 .67702 .50542 Mtetra
.67702 .50542 .67913 .50789 .68356 .50655 .68145 .50408 Mtetra
.68145 .50408 .68356 .50655 .68799 .50521 .68589 .50273 Mtetra
.68589 .50273 .68799 .50521 .69242 .50387 .69033 .50139 Mtetra
.69033 .50139 .69242 .50387 .69687 .50252 .69478 .50004 Mtetra
.69478 .50004 .69687 .50252 .70132 .50118 .69924 .49869 Mtetra
.69924 .49869 .70132 .50118 .70578 .49983 .7037 .49734 Mtetra
.7037 .49734 .70578 .49983 .71024 .49848 .70817 .49598 Mtetra
.70817 .49598 .71024 .49848 .71472 .49713 .71265 .49462 Mtetra
.71265 .49462 .71472 .49713 .7192 .49577 .71713 .49327 Mtetra
.71713 .49327 .7192 .49577 .72368 .49442 .72162 .49191 Mtetra
.978 .725 .48 r
.72162 .49191 .72368 .49442 .72591 .45606 .72387 .45352 Mtetra
.653 .755 .924 r
.72387 .45352 .72591 .45606 .73036 .45468 .72833 .45214 Mtetra
.72833 .45214 .73036 .45468 .73481 .45331 .73279 .45076 Mtetra
.73279 .45076 .73481 .45331 .73927 .45193 .73725 .44938 Mtetra
.73725 .44938 .73927 .45193 .74374 .45055 .74173 .44799 Mtetra
.74173 .44799 .74374 .45055 .74822 .44916 .74621 .4466 Mtetra
.74621 .4466 .74822 .44916 .7527 .44778 .7507 .44521 Mtetra
.7507 .44521 .7527 .44778 .7572 .44639 .75519 .44382 Mtetra
.75519 .44382 .7572 .44639 .76169 .445 .7597 .44243 Mtetra
.7597 .44243 .76169 .445 .7662 .44361 .76421 .44103 Mtetra
.76421 .44103 .7662 .44361 .77071 .44221 .76872 .43963 Mtetra
.76872 .43963 .77071 .44221 .77523 .44082 .77325 .43823 Mtetra
.77325 .43823 .77523 .44082 .77975 .43942 .77778 .43683 Mtetra
.77778 .43683 .77975 .43942 .77309 .29733 .78232 .43543 Mtetra
.039 0 .424 r
.78232 .43543 .77309 .29733 .77743 .29588 .77553 .2932 Mtetra
.664 .741 .908 r
.77553 .2932 .77743 .29588 .78177 .29443 .77988 .29175 Mtetra
.77988 .29175 .78177 .29443 .78612 .29298 .78423 .29029 Mtetra
.78423 .29029 .78612 .29298 .79048 .29152 .78859 .28883 Mtetra
.78859 .28883 .79048 .29152 .79484 .29007 .79296 .28737 Mtetra
.79296 .28737 .79484 .29007 .79921 .28861 .79733 .28591 Mtetra
.79733 .28591 .79921 .28861 .80358 .28715 .80171 .28444 Mtetra
.80171 .28444 .80358 .28715 .80797 .28568 .8061 .28297 Mtetra
.8061 .28297 .80797 .28568 .81235 .28421 .81049 .2815 Mtetra
.81049 .2815 .81235 .28421 .81675 .28275 .81489 .28003 Mtetra
.81489 .28003 .81675 .28275 .82115 .28128 .8193 .27855 Mtetra
.8193 .27855 .82115 .28128 .82556 .2798 .82371 .27708 Mtetra
.82371 .27708 .82556 .2798 .82997 .27833 .82813 .2756 Mtetra
.82813 .2756 .82997 .27833 .8344 .27685 .83256 .27412 Mtetra
.83256 .27412 .8344 .27685 .83883 .27537 .83699 .27263 Mtetra
.83699 .27263 .83883 .27537 .84326 .27389 .84143 .27115 Mtetra
.84143 .27115 .84326 .27389 .8477 .2724 .84588 .26966 Mtetra
.84588 .26966 .8477 .2724 .85215 .27092 .85034 .26817 Mtetra
.85034 .26817 .85215 .27092 .85661 .26943 .8548 .26668 Mtetra
.8548 .26668 .85661 .26943 .86107 .26794 .85926 .26518 Mtetra
.25536 .46427 .25775 .46649 .26135 .46529 .25896 .46306 Mtetra
.25896 .46306 .26135 .46529 .26495 .46408 .26257 .46185 Mtetra
.26257 .46185 .26495 .46408 .26856 .46287 .26618 .46064 Mtetra
.26618 .46064 .26856 .46287 .27217 .46166 .2698 .45943 Mtetra
.2698 .45943 .27217 .46166 .27579 .46045 .27342 .45821 Mtetra
.27342 .45821 .27579 .46045 .27942 .45924 .27704 .45699 Mtetra
.27704 .45699 .27942 .45924 .28305 .45802 .28068 .45578 Mtetra
.28068 .45578 .28305 .45802 .28668 .45681 .28431 .45456 Mtetra
.28431 .45456 .28668 .45681 .29032 .45559 .28796 .45334 Mtetra
.28796 .45334 .29032 .45559 .29396 .45437 .2916 .45211 Mtetra
.2916 .45211 .29396 .45437 .29761 .45315 .29525 .45089 Mtetra
.29525 .45089 .29761 .45315 .30127 .45193 .29891 .44966 Mtetra
.29891 .44966 .30127 .45193 .30493 .4507 .30257 .44844 Mtetra
.30257 .44844 .30493 .4507 .30859 .44948 .30624 .44721 Mtetra
.30624 .44721 .30859 .44948 .31226 .44825 .30991 .44598 Mtetra
.30991 .44598 .31226 .44825 .31593 .44702 .31359 .44474 Mtetra
.31359 .44474 .31593 .44702 .31961 .44579 .31727 .44351 Mtetra
.31727 .44351 .31961 .44579 .3233 .44455 .32096 .44227 Mtetra
.32096 .44227 .3233 .44455 .32699 .44332 .32466 .44103 Mtetra
.32466 .44103 .32699 .44332 .33068 .44208 .32835 .43979 Mtetra
.947 .679 .498 r
.32835 .43979 .33068 .44208 .33438 .44084 .32343 .58448 Mtetra
.543 .319 .525 r
.32343 .58448 .33438 .44084 .32974 .58548 .3273 .58328 Mtetra
.652 .756 .925 r
.3273 .58328 .32974 .58548 .33361 .58429 .33117 .58209 Mtetra
.33117 .58209 .33361 .58429 .33748 .5831 .33505 .58089 Mtetra
.33505 .58089 .33748 .5831 .34136 .58191 .33894 .5797 Mtetra
.33894 .5797 .34136 .58191 .34525 .58071 .34283 .5785 Mtetra
.34283 .5785 .34525 .58071 .34914 .57951 .34672 .57729 Mtetra
.34672 .57729 .34914 .57951 .35304 .57831 .35063 .57609 Mtetra
.35063 .57609 .35304 .57831 .35695 .57711 .35453 .57489 Mtetra
.35453 .57489 .35695 .57711 .36086 .57591 .35845 .57368 Mtetra
.35845 .57368 .36086 .57591 .36477 .5747 .36237 .57247 Mtetra
.36237 .57247 .36477 .5747 .3687 .5735 .36629 .57126 Mtetra
.36629 .57126 .3687 .5735 .37262 .57229 .37022 .57005 Mtetra
.37022 .57005 .37262 .57229 .37656 .57108 .37416 .56884 Mtetra
.37416 .56884 .37656 .57108 .3805 .56986 .3781 .56762 Mtetra
.3781 .56762 .3805 .56986 .38444 .56865 .38205 .5664 Mtetra
.38205 .5664 .38444 .56865 .38839 .56743 .38601 .56519 Mtetra
.38601 .56519 .38839 .56743 .39235 .56622 .38997 .56396 Mtetra
.38997 .56396 .39235 .56622 .39631 .565 .39393 .56274 Mtetra
.39393 .56274 .39631 .565 .40028 .56378 .3979 .56152 Mtetra
.3979 .56152 .40028 .56378 .40425 .56255 .40188 .56029 Mtetra
.938 .73 .596 r
.40188 .56029 .40425 .56255 .40893 .54098 .40658 .5387 Mtetra
.654 .754 .923 r
.40658 .5387 .40893 .54098 .4129 .53974 .41055 .53746 Mtetra
.41055 .53746 .4129 .53974 .41687 .53851 .41452 .53622 Mtetra
.41452 .53622 .41687 .53851 .42084 .53727 .4185 .53498 Mtetra
.4185 .53498 .42084 .53727 .42482 .53603 .42248 .53374 Mtetra
.42248 .53374 .42482 .53603 .42881 .53479 .42647 .53249 Mtetra
.42647 .53249 .42881 .53479 .4328 .53355 .43047 .53125 Mtetra
.43047 .53125 .4328 .53355 .4368 .5323 .43447 .53 Mtetra
.43447 .53 .4368 .5323 .4408 .53105 .43848 .52875 Mtetra
.43848 .52875 .4408 .53105 .44481 .52981 .44249 .52749 Mtetra
.44249 .52749 .44481 .52981 .44882 .52855 .44651 .52624 Mtetra
.44651 .52624 .44882 .52855 .45285 .5273 .45053 .52499 Mtetra
.45053 .52499 .45285 .5273 .45687 .52605 .45457 .52373 Mtetra
.45457 .52373 .45687 .52605 .46091 .52479 .4586 .52247 Mtetra
.4586 .52247 .46091 .52479 .46495 .52353 .46265 .52121 Mtetra
.46265 .52121 .46495 .52353 .46899 .52227 .4667 .51994 Mtetra
.4667 .51994 .46899 .52227 .47304 .52101 .47075 .51868 Mtetra
.47075 .51868 .47304 .52101 .4771 .51975 .47481 .51741 Mtetra
.959 .697 .494 r
.47481 .51741 .4771 .51975 .48283 .39116 .48064 .38874 Mtetra
.664 .741 .908 r
.48064 .38874 .48283 .39116 .48674 .38985 .48455 .38743 Mtetra
.48455 .38743 .48674 .38985 .49067 .38854 .48848 .38611 Mtetra
.48848 .38611 .49067 .38854 .49459 .38723 .49241 .38479 Mtetra
.49241 .38479 .49459 .38723 .49853 .38591 .49635 .38347 Mtetra
.49635 .38347 .49853 .38591 .50246 .38459 .50029 .38215 Mtetra
.50029 .38215 .50246 .38459 .50641 .38327 .50423 .38083 Mtetra
.50423 .38083 .50641 .38327 .51036 .38195 .50819 .3795 Mtetra
.50819 .3795 .51036 .38195 .51431 .38063 .51215 .37818 Mtetra
.51215 .37818 .51431 .38063 .51827 .3793 .51611 .37685 Mtetra
.51611 .37685 .51827 .3793 .52224 .37797 .52008 .37552 Mtetra
.52008 .37552 .52224 .37797 .52621 .37664 .52406 .37418 Mtetra
.52406 .37418 .52621 .37664 .53019 .37531 .52804 .37285 Mtetra
.52804 .37285 .53019 .37531 .53417 .37398 .53203 .37151 Mtetra
.53203 .37151 .53417 .37398 .53822 .3869 .53602 .37017 Mtetra
.109 .079 .54 r
.53602 .37017 .53822 .3869 .54224 .38557 .54009 .3831 Mtetra
.663 .743 .91 r
.54009 .3831 .54224 .38557 .54625 .38423 .54411 .38176 Mtetra
.54411 .38176 .54625 .38423 .55028 .38289 .54814 .38042 Mtetra
.54814 .38042 .55028 .38289 .55431 .38156 .55217 .37908 Mtetra
.55217 .37908 .55431 .38156 .55835 .38022 .55621 .37774 Mtetra
.55621 .37774 .55835 .38022 .56239 .37887 .56026 .37639 Mtetra
.56026 .37639 .56239 .37887 .56644 .37753 .56431 .37504 Mtetra
.56431 .37504 .56644 .37753 .57049 .37618 .56837 .37369 Mtetra
.56837 .37369 .57049 .37618 .57455 .37483 .57244 .37234 Mtetra
.57244 .37234 .57455 .37483 .57862 .37348 .57651 .37099 Mtetra
.57651 .37099 .57862 .37348 .58269 .37213 .58058 .36963 Mtetra
.58058 .36963 .58269 .37213 .58677 .37078 .58466 .36827 Mtetra
.58466 .36827 .58677 .37078 .59085 .36942 .58875 .36691 Mtetra
.58875 .36691 .59085 .36942 .59494 .36806 .59285 .36555 Mtetra
.59285 .36555 .59494 .36806 .59904 .3667 .59695 .36419 Mtetra
.59695 .36419 .59904 .3667 .60314 .36534 .60105 .36282 Mtetra
.60105 .36282 .60314 .36534 .60725 .36398 .60517 .36145 Mtetra
.60517 .36145 .60725 .36398 .61137 .36261 .60929 .36008 Mtetra
.971 .675 .403 r
.60929 .36008 .61137 .36261 .62023 .52798 .61805 .52555 Mtetra
.649 .759 .929 r
.61805 .52555 .62023 .52798 .62458 .52666 .6224 .52424 Mtetra
.6224 .52424 .62458 .52666 .62893 .52535 .62676 .52292 Mtetra
.891 .796 .748 r
.62676 .52292 .62893 .52535 .63329 .52403 .63096 .51628 Mtetra
.615 .515 .717 r
.63096 .51628 .63329 .52403 .63748 .5174 .63532 .51495 Mtetra
.65 .758 .929 r
.63532 .51495 .63748 .5174 .64185 .51607 .63969 .51363 Mtetra
.63969 .51363 .64185 .51607 .64622 .51475 .64407 .5123 Mtetra
.64407 .5123 .64622 .51475 .6506 .51342 .64846 .51097 Mtetra
.64846 .51097 .6506 .51342 .65499 .51209 .65285 .50963 Mtetra
.65285 .50963 .65499 .51209 .65938 .51076 .65725 .5083 Mtetra
.65725 .5083 .65938 .51076 .66378 .50943 .66165 .50696 Mtetra
.66165 .50696 .66378 .50943 .66819 .50809 .66606 .50562 Mtetra
.66606 .50562 .66819 .50809 .6726 .50676 .67048 .50428 Mtetra
.67048 .50428 .6726 .50676 .67702 .50542 .67491 .50294 Mtetra
.67491 .50294 .67702 .50542 .68145 .50408 .67934 .50159 Mtetra
.67934 .50159 .68145 .50408 .68589 .50273 .68378 .50025 Mtetra
.68378 .50025 .68589 .50273 .69033 .50139 .68823 .4989 Mtetra
.68823 .4989 .69033 .50139 .69478 .50004 .69268 .49754 Mtetra
.69268 .49754 .69478 .50004 .69924 .49869 .69714 .49619 Mtetra
.69714 .49619 .69924 .49869 .7037 .49734 .70161 .49483 Mtetra
.70161 .49483 .7037 .49734 .70817 .49598 .70609 .49348 Mtetra
.70609 .49348 .70817 .49598 .71265 .49462 .71057 .49212 Mtetra
.71057 .49212 .71265 .49462 .71713 .49327 .71506 .49075 Mtetra
.978 .725 .481 r
.71506 .49075 .71713 .49327 .72162 .49191 .71738 .45235 Mtetra
.564 .369 .575 r
.71738 .45235 .72162 .49191 .72387 .45352 .72183 .45097 Mtetra
.653 .755 .924 r
.72183 .45097 .72387 .45352 .72833 .45214 .72629 .44959 Mtetra
.72629 .44959 .72833 .45214 .73279 .45076 .73075 .4482 Mtetra
.73075 .4482 .73279 .45076 .73725 .44938 .73523 .44682 Mtetra
.73523 .44682 .73725 .44938 .74173 .44799 .7397 .44543 Mtetra
.7397 .44543 .74173 .44799 .74621 .4466 .74419 .44404 Mtetra
.74419 .44404 .74621 .4466 .7507 .44521 .74868 .44264 Mtetra
.74868 .44264 .7507 .44521 .75519 .44382 .75318 .44125 Mtetra
.75318 .44125 .75519 .44382 .7597 .44243 .75769 .43985 Mtetra
.75769 .43985 .7597 .44243 .76421 .44103 .76221 .43845 Mtetra
.76221 .43845 .76421 .44103 .76872 .43963 .76673 .43705 Mtetra
.76673 .43705 .76872 .43963 .77325 .43823 .77126 .43564 Mtetra
.77126 .43564 .77325 .43823 .77778 .43683 .77579 .43424 Mtetra
.77579 .43424 .77778 .43683 .78232 .43543 .78034 .43283 Mtetra
.98 .688 .381 r
.78034 .43283 .78232 .43543 .77553 .2932 .77363 .29052 Mtetra
.664 .741 .908 r
.77363 .29052 .77553 .2932 .77988 .29175 .77798 .28906 Mtetra
.77798 .28906 .77988 .29175 .78423 .29029 .78234 .2876 Mtetra
.78234 .2876 .78423 .29029 .78859 .28883 .7867 .28613 Mtetra
.7867 .28613 .78859 .28883 .79296 .28737 .79108 .28467 Mtetra
.79108 .28467 .79296 .28737 .79733 .28591 .79545 .2832 Mtetra
.79545 .2832 .79733 .28591 .80171 .28444 .79984 .28173 Mtetra
.79984 .28173 .80171 .28444 .8061 .28297 .80423 .28026 Mtetra
.80423 .28026 .8061 .28297 .81049 .2815 .80863 .27878 Mtetra
.80863 .27878 .81049 .2815 .81489 .28003 .81303 .27731 Mtetra
.81303 .27731 .81489 .28003 .8193 .27855 .81744 .27583 Mtetra
.81744 .27583 .8193 .27855 .82371 .27708 .82186 .27435 Mtetra
.82186 .27435 .82371 .27708 .82813 .2756 .82629 .27286 Mtetra
.82629 .27286 .82813 .2756 .83256 .27412 .83072 .27138 Mtetra
.83072 .27138 .83256 .27412 .83699 .27263 .83516 .26989 Mtetra
.83516 .26989 .83699 .27263 .84143 .27115 .8396 .2684 Mtetra
.8396 .2684 .84143 .27115 .84588 .26966 .84405 .26691 Mtetra
.84405 .26691 .84588 .26966 .85034 .26817 .84851 .26541 Mtetra
.84851 .26541 .85034 .26817 .8548 .26668 .85298 .26391 Mtetra
.85298 .26391 .8548 .26668 .85926 .26518 .85745 .26241 Mtetra
.25296 .46203 .25536 .46427 .25896 .46306 .25657 .46082 Mtetra
.25657 .46082 .25896 .46306 .26257 .46185 .26018 .45961 Mtetra
.26018 .45961 .26257 .46185 .26618 .46064 .26379 .4584 Mtetra
.26379 .4584 .26618 .46064 .2698 .45943 .26741 .45718 Mtetra
.26741 .45718 .2698 .45943 .27342 .45821 .27104 .45596 Mtetra
.27104 .45596 .27342 .45821 .27704 .45699 .27467 .45475 Mtetra
.27467 .45475 .27704 .45699 .28068 .45578 .2783 .45352 Mtetra
.2783 .45352 .28068 .45578 .28431 .45456 .28194 .4523 Mtetra
.28194 .4523 .28431 .45456 .28796 .45334 .28559 .45108 Mtetra
.28559 .45108 .28796 .45334 .2916 .45211 .28924 .44985 Mtetra
.28924 .44985 .2916 .45211 .29525 .45089 .29289 .44863 Mtetra
.29289 .44863 .29525 .45089 .29891 .44966 .29655 .4474 Mtetra
.29655 .4474 .29891 .44966 .30257 .44844 .30022 .44616 Mtetra
.30022 .44616 .30257 .44844 .30624 .44721 .30389 .44493 Mtetra
.30389 .44493 .30624 .44721 .30991 .44598 .30756 .4437 Mtetra
.30756 .4437 .30991 .44598 .31359 .44474 .31124 .44246 Mtetra
.31124 .44246 .31359 .44474 .31727 .44351 .31493 .44122 Mtetra
.31493 .44122 .31727 .44351 .32096 .44227 .31862 .43998 Mtetra
.31862 .43998 .32096 .44227 .32466 .44103 .32232 .43874 Mtetra
.32232 .43874 .32466 .44103 .32835 .43979 .32602 .4375 Mtetra
.947 .679 .498 r
.32602 .4375 .32835 .43979 .32343 .58448 .32098 .58227 Mtetra
.652 .756 .925 r
.32098 .58227 .32343 .58448 .3273 .58328 .32485 .58108 Mtetra
.32485 .58108 .3273 .58328 .33117 .58209 .32873 .57988 Mtetra
.32873 .57988 .33117 .58209 .33505 .58089 .33261 .57868 Mtetra
.33261 .57868 .33505 .58089 .33894 .5797 .3365 .57748 Mtetra
.3365 .57748 .33894 .5797 .34283 .5785 .3404 .57628 Mtetra
.3404 .57628 .34283 .5785 .34672 .57729 .3443 .57507 Mtetra
.3443 .57507 .34672 .57729 .35063 .57609 .3482 .57387 Mtetra
.3482 .57387 .35063 .57609 .35453 .57489 .35211 .57266 Mtetra
.35211 .57266 .35453 .57489 .35845 .57368 .35603 .57145 Mtetra
.35603 .57145 .35845 .57368 .36237 .57247 .35995 .57024 Mtetra
.35995 .57024 .36237 .57247 .36629 .57126 .36388 .56902 Mtetra
.36388 .56902 .36629 .57126 .37022 .57005 .36782 .56781 Mtetra
.36782 .56781 .37022 .57005 .37416 .56884 .37176 .56659 Mtetra
.37176 .56659 .37416 .56884 .3781 .56762 .3757 .56537 Mtetra
.3757 .56537 .3781 .56762 .38205 .5664 .37966 .56415 Mtetra
.37966 .56415 .38205 .5664 .38601 .56519 .38362 .56293 Mtetra
.38362 .56293 .38601 .56519 .38997 .56396 .38758 .56171 Mtetra
.38758 .56171 .38997 .56396 .39393 .56274 .39155 .56048 Mtetra
.39155 .56048 .39393 .56274 .3979 .56152 .39552 .55925 Mtetra
.39552 .55925 .3979 .56152 .40188 .56029 .39951 .55802 Mtetra
.938 .73 .596 r
.39951 .55802 .40188 .56029 .40658 .5387 .40423 .53641 Mtetra
.654 .754 .923 r
.40423 .53641 .40658 .5387 .41055 .53746 .4082 .53517 Mtetra
.4082 .53517 .41055 .53746 .41452 .53622 .41217 .53393 Mtetra
.41217 .53393 .41452 .53622 .4185 .53498 .41615 .53268 Mtetra
.41615 .53268 .4185 .53498 .42248 .53374 .42014 .53144 Mtetra
.42014 .53144 .42248 .53374 .42647 .53249 .42413 .53019 Mtetra
.42413 .53019 .42647 .53249 .43047 .53125 .42813 .52894 Mtetra
.42813 .52894 .43047 .53125 .43447 .53 .43214 .52769 Mtetra
.43214 .52769 .43447 .53 .43848 .52875 .43615 .52643 Mtetra
.43615 .52643 .43848 .52875 .44249 .52749 .44017 .52518 Mtetra
.44017 .52518 .44249 .52749 .44651 .52624 .44419 .52392 Mtetra
.44419 .52392 .44651 .52624 .45053 .52499 .44822 .52266 Mtetra
.44822 .52266 .45053 .52499 .45457 .52373 .45225 .5214 Mtetra
.45225 .5214 .45457 .52373 .4586 .52247 .45629 .52014 Mtetra
.45629 .52014 .4586 .52247 .46265 .52121 .46034 .51887 Mtetra
.46034 .51887 .46265 .52121 .4667 .51994 .46439 .51761 Mtetra
.46439 .51761 .4667 .51994 .47075 .51868 .46845 .51634 Mtetra
.46845 .51634 .47075 .51868 .47481 .51741 .47252 .51507 Mtetra
.959 .697 .494 r
.47252 .51507 .47481 .51741 .48064 .38874 .47843 .38631 Mtetra
.664 .741 .908 r
.47843 .38631 .48064 .38874 .48455 .38743 .48236 .385 Mtetra
.48236 .385 .48455 .38743 .48848 .38611 .48629 .38368 Mtetra
.48629 .38368 .48848 .38611 .49241 .38479 .49022 .38236 Mtetra
.49022 .38236 .49241 .38479 .49635 .38347 .49416 .38103 Mtetra
.49416 .38103 .49635 .38347 .50029 .38215 .49811 .37971 Mtetra
.49811 .37971 .50029 .38215 .50423 .38083 .50206 .37838 Mtetra
.50206 .37838 .50423 .38083 .50819 .3795 .50601 .37705 Mtetra
.50601 .37705 .50819 .3795 .51215 .37818 .50998 .37572 Mtetra
.50998 .37572 .51215 .37818 .51611 .37685 .51394 .37439 Mtetra
.51394 .37439 .51611 .37685 .52008 .37552 .51792 .37305 Mtetra
.51792 .37305 .52008 .37552 .52406 .37418 .5219 .37172 Mtetra
.5219 .37172 .52406 .37418 .52804 .37285 .52588 .37038 Mtetra
.52588 .37038 .52804 .37285 .53203 .37151 .52988 .36904 Mtetra
.52988 .36904 .53203 .37151 .53602 .37017 .53387 .3677 Mtetra
.92 .529 .154 r
.53387 .3677 .53602 .37017 .54009 .3831 .53793 .38063 Mtetra
.663 .743 .91 r
.53793 .38063 .54009 .3831 .54411 .38176 .54196 .37929 Mtetra
.54196 .37929 .54411 .38176 .54814 .38042 .54599 .37794 Mtetra
.54599 .37794 .54814 .38042 .55217 .37908 .55003 .3766 Mtetra
.55003 .3766 .55217 .37908 .55621 .37774 .55408 .37525 Mtetra
.55408 .37525 .55621 .37774 .56026 .37639 .55813 .3739 Mtetra
.55813 .3739 .56026 .37639 .56431 .37504 .56218 .37255 Mtetra
.56218 .37255 .56431 .37504 .56837 .37369 .56625 .37119 Mtetra
.56625 .37119 .56837 .37369 .57244 .37234 .57031 .36984 Mtetra
.57031 .36984 .57244 .37234 .57651 .37099 .57439 .36848 Mtetra
.57439 .36848 .57651 .37099 .58058 .36963 .57847 .36712 Mtetra
.57847 .36712 .58058 .36963 .58466 .36827 .58255 .36576 Mtetra
.58255 .36576 .58466 .36827 .58875 .36691 .58665 .3644 Mtetra
.58665 .3644 .58875 .36691 .59285 .36555 .59074 .36303 Mtetra
.59074 .36303 .59285 .36555 .59695 .36419 .59485 .36166 Mtetra
.59485 .36166 .59695 .36419 .60105 .36282 .59896 .36029 Mtetra
.59896 .36029 .60105 .36282 .60517 .36145 .60308 .35892 Mtetra
.88 .782 .748 r
.60308 .35892 .60517 .36145 .60929 .36008 .60707 .35275 Mtetra
.62 .519 .717 r
.60707 .35275 .60929 .36008 .61805 .52555 .6112 .35137 Mtetra
.005 0 .414 r
.6112 .35137 .61805 .52555 .6224 .52424 .62007 .51648 Mtetra
.615 .515 .717 r
.62007 .51648 .6224 .52424 .62676 .52292 .62443 .51516 Mtetra
.62443 .51516 .62676 .52292 .63096 .51628 .62879 .51383 Mtetra
.65 .758 .929 r
.62879 .51383 .63096 .51628 .63532 .51495 .63316 .5125 Mtetra
.63316 .5125 .63532 .51495 .63969 .51363 .63753 .51117 Mtetra
.63753 .51117 .63969 .51363 .64407 .5123 .64192 .50984 Mtetra
.64192 .50984 .64407 .5123 .64846 .51097 .64631 .5085 Mtetra
.64631 .5085 .64846 .51097 .65285 .50963 .6507 .50717 Mtetra
.6507 .50717 .65285 .50963 .65725 .5083 .6551 .50583 Mtetra
.6551 .50583 .65725 .5083 .66165 .50696 .65952 .50449 Mtetra
.65952 .50449 .66165 .50696 .66606 .50562 .66393 .50315 Mtetra
.66393 .50315 .66606 .50562 .67048 .50428 .66836 .5018 Mtetra
.66836 .5018 .67048 .50428 .67491 .50294 .67279 .50045 Mtetra
.67279 .50045 .67491 .50294 .67934 .50159 .67722 .4991 Mtetra
.67722 .4991 .67934 .50159 .68378 .50025 .68167 .49775 Mtetra
.68167 .49775 .68378 .50025 .68823 .4989 .68612 .4964 Mtetra
.68612 .4964 .68823 .4989 .69268 .49754 .69058 .49504 Mtetra
.69058 .49504 .69268 .49754 .69714 .49619 .69505 .49368 Mtetra
.69505 .49368 .69714 .49619 .70161 .49483 .69952 .49232 Mtetra
.69952 .49232 .70161 .49483 .70609 .49348 .704 .49096 Mtetra
.704 .49096 .70609 .49348 .71057 .49212 .70849 .4896 Mtetra
.70849 .4896 .71057 .49212 .71506 .49075 .71298 .48823 Mtetra
.978 .725 .481 r
.71298 .48823 .71506 .49075 .71738 .45235 .71532 .4498 Mtetra
.653 .755 .924 r
.71532 .4498 .71738 .45235 .72183 .45097 .71978 .44842 Mtetra
.71978 .44842 .72183 .45097 .72629 .44959 .72424 .44703 Mtetra
.72424 .44703 .72629 .44959 .73075 .4482 .72871 .44564 Mtetra
.72871 .44564 .73075 .4482 .73523 .44682 .73319 .44425 Mtetra
.73319 .44425 .73523 .44682 .7397 .44543 .73768 .44286 Mtetra
.73768 .44286 .7397 .44543 .74419 .44404 .74217 .44146 Mtetra
.74217 .44146 .74419 .44404 .74868 .44264 .74667 .44006 Mtetra
.74667 .44006 .74868 .44264 .75318 .44125 .75117 .43866 Mtetra
.75117 .43866 .75318 .44125 .75769 .43985 .75568 .43726 Mtetra
.75568 .43726 .75769 .43985 .76221 .43845 .7602 .43586 Mtetra
.7602 .43586 .76221 .43845 .76673 .43705 .76473 .43445 Mtetra
.76473 .43445 .76673 .43705 .77126 .43564 .76926 .43304 Mtetra
.76926 .43304 .77126 .43564 .77579 .43424 .7738 .43163 Mtetra
.7738 .43163 .77579 .43424 .78034 .43283 .77835 .43022 Mtetra
.77835 .43022 .78034 .43283 .77363 .29052 .78291 .4288 Mtetra
.037 0 .423 r
.78291 .4288 .77363 .29052 .77798 .28906 .77608 .28636 Mtetra
.664 .741 .908 r
.77608 .28636 .77798 .28906 .78234 .2876 .78044 .28489 Mtetra
.78044 .28489 .78234 .2876 .7867 .28613 .78481 .28342 Mtetra
.78481 .28342 .7867 .28613 .79108 .28467 .78919 .28195 Mtetra
.78919 .28195 .79108 .28467 .79545 .2832 .79357 .28048 Mtetra
.79357 .28048 .79545 .2832 .79984 .28173 .79796 .27901 Mtetra
.79796 .27901 .79984 .28173 .80423 .28026 .80235 .27753 Mtetra
.80235 .27753 .80423 .28026 .80863 .27878 .80676 .27605 Mtetra
.80676 .27605 .80863 .27878 .81303 .27731 .81117 .27457 Mtetra
.81117 .27457 .81303 .27731 .81744 .27583 .81558 .27309 Mtetra
.81558 .27309 .81744 .27583 .82186 .27435 .82001 .2716 Mtetra
.82001 .2716 .82186 .27435 .82629 .27286 .82443 .27012 Mtetra
.82443 .27012 .82629 .27286 .83072 .27138 .82887 .26863 Mtetra
.82887 .26863 .83072 .27138 .83516 .26989 .83331 .26713 Mtetra
.83331 .26713 .83516 .26989 .8396 .2684 .83776 .26564 Mtetra
.83776 .26564 .8396 .2684 .84405 .26691 .84222 .26414 Mtetra
.84222 .26414 .84405 .26691 .84851 .26541 .84669 .26264 Mtetra
.84669 .26264 .84851 .26541 .85298 .26391 .85116 .26114 Mtetra
.85116 .26114 .85298 .26391 .85745 .26241 .85563 .25964 Mtetra
.25056 .4598 .25296 .46203 .25657 .46082 .25417 .45858 Mtetra
.25417 .45858 .25657 .46082 .26018 .45961 .25778 .45737 Mtetra
.25778 .45737 .26018 .45961 .26379 .4584 .2614 .45615 Mtetra
.2614 .45615 .26379 .4584 .26741 .45718 .26502 .45493 Mtetra
.26502 .45493 .26741 .45718 .27104 .45596 .26865 .45371 Mtetra
.26865 .45371 .27104 .45596 .27467 .45475 .27228 .45249 Mtetra
.27228 .45249 .27467 .45475 .2783 .45352 .27592 .45127 Mtetra
.27592 .45127 .2783 .45352 .28194 .4523 .27956 .45004 Mtetra
.27956 .45004 .28194 .4523 .28559 .45108 .28321 .44881 Mtetra
.28321 .44881 .28559 .45108 .28924 .44985 .28686 .44759 Mtetra
.28686 .44759 .28924 .44985 .29289 .44863 .29052 .44635 Mtetra
.29052 .44635 .29289 .44863 .29655 .4474 .29419 .44512 Mtetra
.29419 .44512 .29655 .4474 .30022 .44616 .29785 .44389 Mtetra
.29785 .44389 .30022 .44616 .30389 .44493 .30153 .44265 Mtetra
.30153 .44265 .30389 .44493 .30756 .4437 .30521 .44141 Mtetra
.30521 .44141 .30756 .4437 .31124 .44246 .30889 .44018 Mtetra
.30889 .44018 .31124 .44246 .31493 .44122 .31258 .43893 Mtetra
.31258 .43893 .31493 .44122 .31862 .43998 .31627 .43769 Mtetra
.31627 .43769 .31862 .43998 .32232 .43874 .31997 .43645 Mtetra
.31997 .43645 .32232 .43874 .32602 .4375 .32368 .4352 Mtetra
.947 .679 .498 r
.32368 .4352 .32602 .4375 .32098 .58227 .31853 .58006 Mtetra
.652 .756 .925 r
.31853 .58006 .32098 .58227 .32485 .58108 .3224 .57887 Mtetra
.3224 .57887 .32485 .58108 .32873 .57988 .32628 .57766 Mtetra
.32628 .57766 .32873 .57988 .33261 .57868 .33017 .57646 Mtetra
.33017 .57646 .33261 .57868 .3365 .57748 .33406 .57526 Mtetra
.33406 .57526 .3365 .57748 .3404 .57628 .33796 .57405 Mtetra
.33796 .57405 .3404 .57628 .3443 .57507 .34186 .57284 Mtetra
.34186 .57284 .3443 .57507 .3482 .57387 .34577 .57164 Mtetra
.34577 .57164 .3482 .57387 .35211 .57266 .34969 .57042 Mtetra
.34969 .57042 .35211 .57266 .35603 .57145 .35361 .56921 Mtetra
.35361 .56921 .35603 .57145 .35995 .57024 .35753 .568 Mtetra
.35753 .568 .35995 .57024 .36388 .56902 .36147 .56678 Mtetra
.36147 .56678 .36388 .56902 .36782 .56781 .36541 .56556 Mtetra
.36541 .56556 .36782 .56781 .37176 .56659 .36935 .56434 Mtetra
.36935 .56434 .37176 .56659 .3757 .56537 .3733 .56312 Mtetra
.3733 .56312 .3757 .56537 .37966 .56415 .37726 .56189 Mtetra
.37726 .56189 .37966 .56415 .38362 .56293 .38122 .56067 Mtetra
.38122 .56067 .38362 .56293 .38758 .56171 .38518 .55944 Mtetra
.38518 .55944 .38758 .56171 .39155 .56048 .38916 .55821 Mtetra
.38916 .55821 .39155 .56048 .39552 .55925 .39314 .55698 Mtetra
.39314 .55698 .39552 .55925 .39951 .55802 .39712 .55575 Mtetra
.938 .73 .596 r
.39712 .55575 .39951 .55802 .40423 .53641 .40186 .53412 Mtetra
.654 .754 .923 r
.40186 .53412 .40423 .53641 .4082 .53517 .40583 .53288 Mtetra
.40583 .53288 .4082 .53517 .41217 .53393 .40981 .53163 Mtetra
.40981 .53163 .41217 .53393 .41615 .53268 .4138 .53038 Mtetra
.4138 .53038 .41615 .53268 .42014 .53144 .41779 .52913 Mtetra
.41779 .52913 .42014 .53144 .42413 .53019 .42179 .52788 Mtetra
.42179 .52788 .42413 .53019 .42813 .52894 .42579 .52663 Mtetra
.42579 .52663 .42813 .52894 .43214 .52769 .4298 .52537 Mtetra
.4298 .52537 .43214 .52769 .43615 .52643 .43381 .52411 Mtetra
.43381 .52411 .43615 .52643 .44017 .52518 .43783 .52286 Mtetra
.43783 .52286 .44017 .52518 .44419 .52392 .44186 .52159 Mtetra
.44186 .52159 .44419 .52392 .44822 .52266 .44589 .52033 Mtetra
.44589 .52033 .44822 .52266 .45225 .5214 .44993 .51907 Mtetra
.44993 .51907 .45225 .5214 .45629 .52014 .45398 .5178 Mtetra
.45398 .5178 .45629 .52014 .46034 .51887 .45803 .51653 Mtetra
.45803 .51653 .46034 .51887 .46439 .51761 .46209 .51526 Mtetra
.46209 .51526 .46439 .51761 .46845 .51634 .46615 .51399 Mtetra
.46615 .51399 .46845 .51634 .47252 .51507 .47022 .51272 Mtetra
.959 .697 .494 r
.47022 .51272 .47252 .51507 .47843 .38631 .47623 .38388 Mtetra
.664 .741 .908 r
.47623 .38388 .47843 .38631 .48236 .385 .48016 .38256 Mtetra
.48016 .38256 .48236 .385 .48629 .38368 .48409 .38124 Mtetra
.48409 .38124 .48629 .38368 .49022 .38236 .48803 .37991 Mtetra
.48803 .37991 .49022 .38236 .49416 .38103 .49197 .37859 Mtetra
.49197 .37859 .49416 .38103 .49811 .37971 .49592 .37726 Mtetra
.49592 .37726 .49811 .37971 .50206 .37838 .49987 .37593 Mtetra
.49987 .37593 .50206 .37838 .50601 .37705 .50383 .37459 Mtetra
.50383 .37459 .50601 .37705 .50998 .37572 .5078 .37326 Mtetra
.5078 .37326 .50998 .37572 .51394 .37439 .51177 .37192 Mtetra
.51177 .37192 .51394 .37439 .51792 .37305 .51575 .37059 Mtetra
.51575 .37059 .51792 .37305 .5219 .37172 .51973 .36925 Mtetra
.51973 .36925 .5219 .37172 .52588 .37038 .52372 .3679 Mtetra
.52372 .3679 .52588 .37038 .52988 .36904 .52772 .36656 Mtetra
.52772 .36656 .52988 .36904 .53387 .3677 .53172 .36521 Mtetra
.53172 .36521 .53387 .3677 .53793 .38063 .53573 .36387 Mtetra
.107 .078 .539 r
.53573 .36387 .53793 .38063 .54196 .37929 .5398 .3768 Mtetra
.663 .743 .91 r
.5398 .3768 .54196 .37929 .54599 .37794 .54384 .37546 Mtetra
.54384 .37546 .54599 .37794 .55003 .3766 .54788 .37411 Mtetra
.54788 .37411 .55003 .3766 .55408 .37525 .55193 .37276 Mtetra
.55193 .37276 .55408 .37525 .55813 .3739 .55599 .3714 Mtetra
.55599 .3714 .55813 .3739 .56218 .37255 .56005 .37005 Mtetra
.56005 .37005 .56218 .37255 .56625 .37119 .56411 .36869 Mtetra
.56411 .36869 .56625 .37119 .57031 .36984 .56818 .36733 Mtetra
.56818 .36733 .57031 .36984 .57439 .36848 .57226 .36597 Mtetra
.57226 .36597 .57439 .36848 .57847 .36712 .57635 .36461 Mtetra
.57635 .36461 .57847 .36712 .58255 .36576 .58044 .36324 Mtetra
.58044 .36324 .58255 .36576 .58665 .3644 .58453 .36187 Mtetra
.58453 .36187 .58665 .3644 .59074 .36303 .58864 .3605 Mtetra
.879 .781 .748 r
.58864 .3605 .59074 .36303 .59485 .36166 .59264 .35434 Mtetra
.62 .518 .717 r
.59264 .35434 .59485 .36166 .59896 .36029 .59675 .35296 Mtetra
.59675 .35296 .59896 .36029 .60308 .35892 .60086 .35158 Mtetra
.60086 .35158 .60308 .35892 .60707 .35275 .60499 .3502 Mtetra
.663 .742 .909 r
.60499 .3502 .60707 .35275 .6112 .35137 .60911 .34882 Mtetra
.60911 .34882 .6112 .35137 .62007 .51648 .61324 .34744 Mtetra
0 0 .406 r
.61324 .34744 .62007 .51648 .62443 .51516 .62225 .51271 Mtetra
.65 .758 .929 r
.62225 .51271 .62443 .51516 .62879 .51383 .62661 .51138 Mtetra
.62661 .51138 .62879 .51383 .63316 .5125 .63099 .51004 Mtetra
.63099 .51004 .63316 .5125 .63753 .51117 .63537 .50871 Mtetra
.63537 .50871 .63753 .51117 .64192 .50984 .63976 .50737 Mtetra
.63976 .50737 .64192 .50984 .64631 .5085 .64415 .50604 Mtetra
.64415 .50604 .64631 .5085 .6507 .50717 .64855 .50469 Mtetra
.64855 .50469 .6507 .50717 .6551 .50583 .65296 .50335 Mtetra
.65296 .50335 .6551 .50583 .65952 .50449 .65737 .50201 Mtetra
.65737 .50201 .65952 .50449 .66393 .50315 .66179 .50066 Mtetra
.66179 .50066 .66393 .50315 .66836 .5018 .66622 .49931 Mtetra
.66622 .49931 .66836 .5018 .67279 .50045 .67066 .49796 Mtetra
.67066 .49796 .67279 .50045 .67722 .4991 .6751 .49661 Mtetra
.6751 .49661 .67722 .4991 .68167 .49775 .67955 .49525 Mtetra
.67955 .49525 .68167 .49775 .68612 .4964 .68401 .49389 Mtetra
.68401 .49389 .68612 .4964 .69058 .49504 .68847 .49253 Mtetra
.68847 .49253 .69058 .49504 .69505 .49368 .69294 .49117 Mtetra
.69294 .49117 .69505 .49368 .69952 .49232 .69742 .48981 Mtetra
.69742 .48981 .69952 .49232 .704 .49096 .70191 .48844 Mtetra
.70191 .48844 .704 .49096 .70849 .4896 .7064 .48707 Mtetra
.7064 .48707 .70849 .4896 .71298 .48823 .7109 .4857 Mtetra
.978 .725 .481 r
.7109 .4857 .71298 .48823 .71532 .4498 .71327 .44724 Mtetra
.653 .755 .924 r
.71327 .44724 .71532 .4498 .71978 .44842 .71773 .44586 Mtetra
.71773 .44586 .71978 .44842 .72424 .44703 .72219 .44446 Mtetra
.72219 .44446 .72424 .44703 .72871 .44564 .72667 .44307 Mtetra
.72667 .44307 .72871 .44564 .73319 .44425 .73115 .44168 Mtetra
.73115 .44168 .73319 .44425 .73768 .44286 .73564 .44028 Mtetra
.73564 .44028 .73768 .44286 .74217 .44146 .74014 .43888 Mtetra
.74014 .43888 .74217 .44146 .74667 .44006 .74464 .43748 Mtetra
.74464 .43748 .74667 .44006 .75117 .43866 .74915 .43607 Mtetra
.74915 .43607 .75117 .43866 .75568 .43726 .75367 .43467 Mtetra
.75367 .43467 .75568 .43726 .7602 .43586 .75819 .43326 Mtetra
.75819 .43326 .7602 .43586 .76473 .43445 .76272 .43185 Mtetra
.76272 .43185 .76473 .43445 .76926 .43304 .76726 .43044 Mtetra
.76726 .43044 .76926 .43304 .7738 .43163 .77181 .42902 Mtetra
.77181 .42902 .7738 .43163 .77835 .43022 .77636 .4276 Mtetra
.77636 .4276 .77835 .43022 .78291 .4288 .78092 .42618 Mtetra
.98 .688 .379 r
.78092 .42618 .78291 .4288 .77608 .28636 .77417 .28365 Mtetra
.664 .741 .908 r
.77417 .28365 .77608 .28636 .78044 .28489 .77853 .28218 Mtetra
.77853 .28218 .78044 .28489 .78481 .28342 .78291 .28071 Mtetra
.78291 .28071 .78481 .28342 .78919 .28195 .78729 .27924 Mtetra
.78729 .27924 .78919 .28195 .79357 .28048 .79168 .27776 Mtetra
.79168 .27776 .79357 .28048 .79796 .27901 .79607 .27628 Mtetra
.79607 .27628 .79796 .27901 .80235 .27753 .80047 .2748 Mtetra
.80047 .2748 .80235 .27753 .80676 .27605 .80488 .27332 Mtetra
.80488 .27332 .80676 .27605 .81117 .27457 .80929 .27183 Mtetra
.80929 .27183 .81117 .27457 .81558 .27309 .81372 .27035 Mtetra
.81372 .27035 .81558 .27309 .82001 .2716 .81814 .26886 Mtetra
.81814 .26886 .82001 .2716 .82443 .27012 .82258 .26736 Mtetra
.82258 .26736 .82443 .27012 .82887 .26863 .82702 .26587 Mtetra
.82702 .26587 .82887 .26863 .83331 .26713 .83147 .26437 Mtetra
.83147 .26437 .83331 .26713 .83776 .26564 .83592 .26288 Mtetra
.83592 .26288 .83776 .26564 .84222 .26414 .84038 .26137 Mtetra
.84038 .26137 .84222 .26414 .84669 .26264 .84485 .25987 Mtetra
.84485 .25987 .84669 .26264 .85116 .26114 .84933 .25837 Mtetra
.84933 .25837 .85116 .26114 .85563 .25964 .85381 .25686 Mtetra
.24815 .45756 .25056 .4598 .25417 .45858 .25176 .45634 Mtetra
.25176 .45634 .25417 .45858 .25778 .45737 .25538 .45512 Mtetra
.25538 .45512 .25778 .45737 .2614 .45615 .259 .4539 Mtetra
.259 .4539 .2614 .45615 .26502 .45493 .26263 .45268 Mtetra
.26263 .45268 .26502 .45493 .26865 .45371 .26626 .45146 Mtetra
.26626 .45146 .26865 .45371 .27228 .45249 .26989 .45023 Mtetra
.26989 .45023 .27228 .45249 .27592 .45127 .27353 .449 Mtetra
.27353 .449 .27592 .45127 .27956 .45004 .27718 .44777 Mtetra
.27718 .44777 .27956 .45004 .28321 .44881 .28083 .44654 Mtetra
.28083 .44654 .28321 .44881 .28686 .44759 .28449 .44531 Mtetra
.28449 .44531 .28686 .44759 .29052 .44635 .28815 .44408 Mtetra
.28815 .44408 .29052 .44635 .29419 .44512 .29181 .44284 Mtetra
.29181 .44284 .29419 .44512 .29785 .44389 .29549 .4416 Mtetra
.29549 .4416 .29785 .44389 .30153 .44265 .29916 .44037 Mtetra
.29916 .44037 .30153 .44265 .30521 .44141 .30284 .43913 Mtetra
.30284 .43913 .30521 .44141 .30889 .44018 .30653 .43788 Mtetra
.30653 .43788 .30889 .44018 .31258 .43893 .31022 .43664 Mtetra
.31022 .43664 .31258 .43893 .31627 .43769 .31392 .43539 Mtetra
.31392 .43539 .31627 .43769 .31997 .43645 .31762 .43414 Mtetra
.946 .679 .499 r
.31762 .43414 .31997 .43645 .32368 .4352 .31219 .57905 Mtetra
.541 .316 .523 r
.31219 .57905 .32368 .4352 .31853 .58006 .31606 .57785 Mtetra
.652 .756 .925 r
.31606 .57785 .31853 .58006 .3224 .57887 .31994 .57665 Mtetra
.31994 .57665 .3224 .57887 .32628 .57766 .32383 .57544 Mtetra
.32383 .57544 .32628 .57766 .33017 .57646 .32772 .57424 Mtetra
.32772 .57424 .33017 .57646 .33406 .57526 .33161 .57303 Mtetra
.33161 .57303 .33406 .57526 .33796 .57405 .33551 .57182 Mtetra
.33551 .57182 .33796 .57405 .34186 .57284 .33942 .57061 Mtetra
.33942 .57061 .34186 .57284 .34577 .57164 .34333 .5694 Mtetra
.34333 .5694 .34577 .57164 .34969 .57042 .34725 .56818 Mtetra
.34725 .56818 .34969 .57042 .35361 .56921 .35118 .56697 Mtetra
.35118 .56697 .35361 .56921 .35753 .568 .35511 .56575 Mtetra
.35511 .56575 .35753 .568 .36147 .56678 .35904 .56453 Mtetra
.35904 .56453 .36147 .56678 .36541 .56556 .36299 .56331 Mtetra
.36299 .56331 .36541 .56556 .36935 .56434 .36693 .56208 Mtetra
.36693 .56208 .36935 .56434 .3733 .56312 .37089 .56086 Mtetra
.37089 .56086 .3733 .56312 .37726 .56189 .37485 .55963 Mtetra
.37485 .55963 .37726 .56189 .38122 .56067 .37881 .5584 Mtetra
.37881 .5584 .38122 .56067 .38518 .55944 .38278 .55717 Mtetra
.38278 .55717 .38518 .55944 .38916 .55821 .38676 .55594 Mtetra
.38676 .55594 .38916 .55821 .39314 .55698 .39074 .5547 Mtetra
.39074 .5547 .39314 .55698 .39712 .55575 .39473 .55347 Mtetra
.938 .73 .596 r
.39473 .55347 .39712 .55575 .40186 .53412 .39949 .53182 Mtetra
.654 .754 .923 r
.39949 .53182 .40186 .53412 .40583 .53288 .40347 .53057 Mtetra
.40347 .53057 .40583 .53288 .40981 .53163 .40745 .52932 Mtetra
.40745 .52932 .40981 .53163 .4138 .53038 .41144 .52807 Mtetra
.41144 .52807 .4138 .53038 .41779 .52913 .41543 .52682 Mtetra
.41543 .52682 .41779 .52913 .42179 .52788 .41943 .52556 Mtetra
.41943 .52556 .42179 .52788 .42579 .52663 .42344 .52431 Mtetra
.42344 .52431 .42579 .52663 .4298 .52537 .42745 .52305 Mtetra
.42745 .52305 .4298 .52537 .43381 .52411 .43147 .52179 Mtetra
.43147 .52179 .43381 .52411 .43783 .52286 .4355 .52053 Mtetra
.4355 .52053 .43783 .52286 .44186 .52159 .43953 .51926 Mtetra
.43953 .51926 .44186 .52159 .44589 .52033 .44356 .518 Mtetra
.44356 .518 .44589 .52033 .44993 .51907 .44761 .51673 Mtetra
.44761 .51673 .44993 .51907 .45398 .5178 .45166 .51546 Mtetra
.45166 .51546 .45398 .5178 .45803 .51653 .45571 .51419 Mtetra
.45571 .51419 .45803 .51653 .46209 .51526 .45977 .51291 Mtetra
.45977 .51291 .46209 .51526 .46615 .51399 .46384 .51164 Mtetra
.46384 .51164 .46615 .51399 .47022 .51272 .46791 .51036 Mtetra
.959 .697 .494 r
.46791 .51036 .47022 .51272 .47623 .38388 .47402 .38144 Mtetra
.664 .741 .908 r
.47402 .38144 .47623 .38388 .48016 .38256 .47795 .38012 Mtetra
.47795 .38012 .48016 .38256 .48409 .38124 .48188 .37879 Mtetra
.48188 .37879 .48409 .38124 .48803 .37991 .48582 .37746 Mtetra
.48582 .37746 .48803 .37991 .49197 .37859 .48977 .37613 Mtetra
.48977 .37613 .49197 .37859 .49592 .37726 .49372 .3748 Mtetra
.49372 .3748 .49592 .37726 .49987 .37593 .49768 .37347 Mtetra
.49768 .37347 .49987 .37593 .50383 .37459 .50165 .37213 Mtetra
.50165 .37213 .50383 .37459 .5078 .37326 .50562 .37079 Mtetra
.50562 .37079 .5078 .37326 .51177 .37192 .50959 .36945 Mtetra
.50959 .36945 .51177 .37192 .51575 .37059 .51357 .36811 Mtetra
.51357 .36811 .51575 .37059 .51973 .36925 .51756 .36677 Mtetra
.51756 .36677 .51973 .36925 .52372 .3679 .52155 .36542 Mtetra
.52155 .36542 .52372 .3679 .52772 .36656 .52555 .36407 Mtetra
.52555 .36407 .52772 .36656 .53172 .36521 .52956 .36272 Mtetra
.52956 .36272 .53172 .36521 .53573 .36387 .53357 .36137 Mtetra
.92 .528 .15 r
.53357 .36137 .53573 .36387 .5398 .3768 .53764 .37431 Mtetra
.663 .743 .91 r
.53764 .37431 .5398 .3768 .54384 .37546 .54168 .37296 Mtetra
.54168 .37296 .54384 .37546 .54788 .37411 .54573 .37161 Mtetra
.54573 .37161 .54788 .37411 .55193 .37276 .54978 .37026 Mtetra
.54978 .37026 .55193 .37276 .55599 .3714 .55384 .3689 Mtetra
.55384 .3689 .55599 .3714 .56005 .37005 .5579 .36754 Mtetra
.5579 .36754 .56005 .37005 .56411 .36869 .56197 .36618 Mtetra
.56197 .36618 .56411 .36869 .56818 .36733 .56605 .36482 Mtetra
.56605 .36482 .56818 .36733 .57226 .36597 .57013 .36345 Mtetra
.878 .779 .748 r
.57013 .36345 .57226 .36597 .57635 .36461 .57415 .35729 Mtetra
.62 .518 .717 r
.57415 .35729 .57635 .36461 .58044 .36324 .57823 .35592 Mtetra
.57823 .35592 .58044 .36324 .58453 .36187 .58233 .35455 Mtetra
.58233 .35455 .58453 .36187 .58864 .3605 .58643 .35317 Mtetra
.58643 .35317 .58864 .3605 .59264 .35434 .59054 .3518 Mtetra
.663 .742 .909 r
.59054 .3518 .59264 .35434 .59675 .35296 .59465 .35042 Mtetra
.59465 .35042 .59675 .35296 .60086 .35158 .59877 .34904 Mtetra
.59877 .34904 .60086 .35158 .60499 .3502 .60289 .34765 Mtetra
.60289 .34765 .60499 .3502 .60911 .34882 .60702 .34627 Mtetra
.60702 .34627 .60911 .34882 .61324 .34744 .61116 .34488 Mtetra
.971 .674 .4 r
.61116 .34488 .61324 .34744 .62225 .51271 .62006 .51025 Mtetra
.65 .758 .929 r
.62006 .51025 .62225 .51271 .62661 .51138 .62443 .50892 Mtetra
.62443 .50892 .62661 .51138 .63099 .51004 .62881 .50758 Mtetra
.62881 .50758 .63099 .51004 .63537 .50871 .6332 .50624 Mtetra
.6332 .50624 .63537 .50871 .63976 .50737 .63759 .5049 Mtetra
.63759 .5049 .63976 .50737 .64415 .50604 .64199 .50356 Mtetra
.64199 .50356 .64415 .50604 .64855 .50469 .64639 .50221 Mtetra
.64639 .50221 .64855 .50469 .65296 .50335 .65081 .50087 Mtetra
.65081 .50087 .65296 .50335 .65737 .50201 .65522 .49952 Mtetra
.65522 .49952 .65737 .50201 .66179 .50066 .65965 .49817 Mtetra
.65965 .49817 .66179 .50066 .66622 .49931 .66408 .49682 Mtetra
.66408 .49682 .66622 .49931 .67066 .49796 .66853 .49546 Mtetra
.66853 .49546 .67066 .49796 .6751 .49661 .67297 .4941 Mtetra
.67297 .4941 .6751 .49661 .67955 .49525 .67743 .49274 Mtetra
.67743 .49274 .67955 .49525 .68401 .49389 .68189 .49138 Mtetra
.68189 .49138 .68401 .49389 .68847 .49253 .68636 .49002 Mtetra
.68636 .49002 .68847 .49253 .69294 .49117 .69083 .48865 Mtetra
.69083 .48865 .69294 .49117 .69742 .48981 .69532 .48728 Mtetra
.69532 .48728 .69742 .48981 .70191 .48844 .69981 .48591 Mtetra
.69981 .48591 .70191 .48844 .7064 .48707 .7043 .48454 Mtetra
.978 .725 .483 r
.7043 .48454 .7064 .48707 .7109 .4857 .70674 .44607 Mtetra
.563 .367 .574 r
.70674 .44607 .7109 .4857 .71327 .44724 .7112 .44468 Mtetra
.653 .755 .924 r
.7112 .44468 .71327 .44724 .71773 .44586 .71567 .44329 Mtetra
.71567 .44329 .71773 .44586 .72219 .44446 .72014 .44189 Mtetra
.72014 .44189 .72219 .44446 .72667 .44307 .72462 .44049 Mtetra
.72462 .44049 .72667 .44307 .73115 .44168 .72911 .4391 Mtetra
.72911 .4391 .73115 .44168 .73564 .44028 .7336 .43769 Mtetra
.7336 .43769 .73564 .44028 .74014 .43888 .7381 .43629 Mtetra
.7381 .43629 .74014 .43888 .74464 .43748 .74261 .43488 Mtetra
.74261 .43488 .74464 .43748 .74915 .43607 .74713 .43348 Mtetra
.74713 .43348 .74915 .43607 .75367 .43467 .75165 .43207 Mtetra
.75165 .43207 .75367 .43467 .75819 .43326 .75618 .43065 Mtetra
.75618 .43065 .75819 .43326 .76272 .43185 .76071 .42924 Mtetra
.76071 .42924 .76272 .43185 .76726 .43044 .76526 .42782 Mtetra
.76526 .42782 .76726 .43044 .77181 .42902 .76981 .4264 Mtetra
.76981 .4264 .77181 .42902 .77636 .4276 .77437 .42498 Mtetra
.77437 .42498 .77636 .4276 .78092 .42618 .77893 .42356 Mtetra
.77893 .42356 .78092 .42618 .77417 .28365 .78351 .42213 Mtetra
.035 0 .421 r
.78351 .42213 .77417 .28365 .77853 .28218 .77662 .27946 Mtetra
.664 .741 .908 r
.77662 .27946 .77853 .28218 .78291 .28071 .781 .27799 Mtetra
.781 .27799 .78291 .28071 .78729 .27924 .78539 .27651 Mtetra
.78539 .27651 .78729 .27924 .79168 .27776 .78978 .27503 Mtetra
.78978 .27503 .79168 .27776 .79607 .27628 .79418 .27355 Mtetra
.79418 .27355 .79607 .27628 .80047 .2748 .79859 .27206 Mtetra
.79859 .27206 .80047 .2748 .80488 .27332 .803 .27057 Mtetra
.803 .27057 .80488 .27332 .80929 .27183 .80742 .26909 Mtetra
.80742 .26909 .80929 .27183 .81372 .27035 .81184 .26759 Mtetra
.81184 .26759 .81372 .27035 .81814 .26886 .81628 .2661 Mtetra
.81628 .2661 .81814 .26886 .82258 .26736 .82072 .2646 Mtetra
.82072 .2646 .82258 .26736 .82702 .26587 .82516 .26311 Mtetra
.82516 .26311 .82702 .26587 .83147 .26437 .82961 .26161 Mtetra
.82961 .26161 .83147 .26437 .83592 .26288 .83407 .2601 Mtetra
.83407 .2601 .83592 .26288 .84038 .26137 .83854 .2586 Mtetra
.83854 .2586 .84038 .26137 .84485 .25987 .84301 .25709 Mtetra
.84301 .25709 .84485 .25987 .84933 .25837 .8475 .25558 Mtetra
.8475 .25558 .84933 .25837 .85381 .25686 .85198 .25407 Mtetra
.24574 .45531 .24815 .45756 .25176 .45634 .24935 .45409 Mtetra
.24935 .45409 .25176 .45634 .25538 .45512 .25297 .45287 Mtetra
.25297 .45287 .25538 .45512 .259 .4539 .25659 .45164 Mtetra
.25659 .45164 .259 .4539 .26263 .45268 .26022 .45042 Mtetra
.26022 .45042 .26263 .45268 .26626 .45146 .26386 .44919 Mtetra
.26386 .44919 .26626 .45146 .26989 .45023 .2675 .44796 Mtetra
.2675 .44796 .26989 .45023 .27353 .449 .27114 .44673 Mtetra
.27114 .44673 .27353 .449 .27718 .44777 .27479 .4455 Mtetra
.27479 .4455 .27718 .44777 .28083 .44654 .27844 .44427 Mtetra
.27844 .44427 .28083 .44654 .28449 .44531 .2821 .44303 Mtetra
.2821 .44303 .28449 .44531 .28815 .44408 .28577 .4418 Mtetra
.28577 .4418 .28815 .44408 .29181 .44284 .28944 .44056 Mtetra
.28944 .44056 .29181 .44284 .29549 .4416 .29311 .43932 Mtetra
.29311 .43932 .29549 .4416 .29916 .44037 .29679 .43807 Mtetra
.29679 .43807 .29916 .44037 .30284 .43913 .30048 .43683 Mtetra
.30048 .43683 .30284 .43913 .30653 .43788 .30417 .43558 Mtetra
.30417 .43558 .30653 .43788 .31022 .43664 .30786 .43434 Mtetra
.30786 .43434 .31022 .43664 .31392 .43539 .31156 .43309 Mtetra
.31156 .43309 .31392 .43539 .31762 .43414 .31527 .43184 Mtetra
.946 .679 .499 r
.31527 .43184 .31762 .43414 .31219 .57905 .30972 .57683 Mtetra
.652 .756 .925 r
.30972 .57683 .31219 .57905 .31606 .57785 .3136 .57563 Mtetra
.3136 .57563 .31606 .57785 .31994 .57665 .31748 .57442 Mtetra
.31748 .57442 .31994 .57665 .32383 .57544 .32137 .57322 Mtetra
.32137 .57322 .32383 .57544 .32772 .57424 .32526 .57201 Mtetra
.32526 .57201 .32772 .57424 .33161 .57303 .32916 .5708 Mtetra
.32916 .5708 .33161 .57303 .33551 .57182 .33306 .56958 Mtetra
.33306 .56958 .33551 .57182 .33942 .57061 .33697 .56837 Mtetra
.33697 .56837 .33942 .57061 .34333 .5694 .34089 .56715 Mtetra
.34089 .56715 .34333 .5694 .34725 .56818 .34481 .56594 Mtetra
.34481 .56594 .34725 .56818 .35118 .56697 .34874 .56472 Mtetra
.34874 .56472 .35118 .56697 .35511 .56575 .35268 .56349 Mtetra
.35268 .56349 .35511 .56575 .35904 .56453 .35662 .56227 Mtetra
.35662 .56227 .35904 .56453 .36299 .56331 .36056 .56105 Mtetra
.36056 .56105 .36299 .56331 .36693 .56208 .36451 .55982 Mtetra
.36451 .55982 .36693 .56208 .37089 .56086 .36847 .55859 Mtetra
.36847 .55859 .37089 .56086 .37485 .55963 .37243 .55736 Mtetra
.37243 .55736 .37485 .55963 .37881 .5584 .3764 .55613 Mtetra
.3764 .55613 .37881 .5584 .38278 .55717 .38038 .55489 Mtetra
.38038 .55489 .38278 .55717 .38676 .55594 .38436 .55366 Mtetra
.38436 .55366 .38676 .55594 .39074 .5547 .38834 .55242 Mtetra
.38834 .55242 .39074 .5547 .39473 .55347 .39234 .55118 Mtetra
.938 .73 .596 r
.39234 .55118 .39473 .55347 .39949 .53182 .39711 .52952 Mtetra
.654 .754 .923 r
.39711 .52952 .39949 .53182 .40347 .53057 .40109 .52827 Mtetra
.40109 .52827 .40347 .53057 .40745 .52932 .40508 .52701 Mtetra
.40508 .52701 .40745 .52932 .41144 .52807 .40907 .52576 Mtetra
.40907 .52576 .41144 .52807 .41543 .52682 .41307 .5245 Mtetra
.41307 .5245 .41543 .52682 .41943 .52556 .41708 .52324 Mtetra
.41708 .52324 .41943 .52556 .42344 .52431 .42109 .52198 Mtetra
.42109 .52198 .42344 .52431 .42745 .52305 .4251 .52072 Mtetra
.4251 .52072 .42745 .52305 .43147 .52179 .42913 .51946 Mtetra
.42913 .51946 .43147 .52179 .4355 .52053 .43315 .51819 Mtetra
.43315 .51819 .4355 .52053 .43953 .51926 .43719 .51692 Mtetra
.43719 .51692 .43953 .51926 .44356 .518 .44123 .51565 Mtetra
.44123 .51565 .44356 .518 .44761 .51673 .44528 .51438 Mtetra
.44528 .51438 .44761 .51673 .45166 .51546 .44933 .51311 Mtetra
.44933 .51311 .45166 .51546 .45571 .51419 .45339 .51183 Mtetra
.45339 .51183 .45571 .51419 .45977 .51291 .45745 .51055 Mtetra
.45745 .51055 .45977 .51291 .46384 .51164 .46152 .50928 Mtetra
.46152 .50928 .46384 .51164 .46791 .51036 .4656 .50799 Mtetra
.959 .697 .494 r
.4656 .50799 .46791 .51036 .47402 .38144 .4718 .37899 Mtetra
.664 .741 .908 r
.4718 .37899 .47402 .38144 .47795 .38012 .47573 .37767 Mtetra
.47573 .37767 .47795 .38012 .48188 .37879 .47967 .37634 Mtetra
.47967 .37634 .48188 .37879 .48582 .37746 .48362 .375 Mtetra
.48362 .375 .48582 .37746 .48977 .37613 .48757 .37367 Mtetra
.48757 .37367 .48977 .37613 .49372 .3748 .49152 .37233 Mtetra
.49152 .37233 .49372 .3748 .49768 .37347 .49549 .371 Mtetra
.49549 .371 .49768 .37347 .50165 .37213 .49946 .36966 Mtetra
.49946 .36966 .50165 .37213 .50562 .37079 .50343 .36832 Mtetra
.50343 .36832 .50562 .37079 .50959 .36945 .50741 .36697 Mtetra
.50741 .36697 .50959 .36945 .51357 .36811 .51139 .36563 Mtetra
.51139 .36563 .51357 .36811 .51756 .36677 .51538 .36428 Mtetra
.51538 .36428 .51756 .36677 .52155 .36542 .51938 .36293 Mtetra
.51938 .36293 .52155 .36542 .52555 .36407 .52338 .36158 Mtetra
.52338 .36158 .52555 .36407 .52956 .36272 .52739 .36023 Mtetra
.52739 .36023 .52956 .36272 .53357 .36137 .53141 .35887 Mtetra
.53141 .35887 .53357 .36137 .53764 .37431 .53543 .35751 Mtetra
.105 .076 .538 r
.53543 .35751 .53764 .37431 .54168 .37296 .53952 .37046 Mtetra
.663 .743 .91 r
.53952 .37046 .54168 .37296 .54573 .37161 .54357 .36911 Mtetra
.54357 .36911 .54573 .37161 .54978 .37026 .54763 .36775 Mtetra
.54763 .36775 .54978 .37026 .55384 .3689 .55169 .36639 Mtetra
.877 .778 .748 r
.55169 .36639 .55384 .3689 .5579 .36754 .55571 .36024 Mtetra
.62 .518 .717 r
.55571 .36024 .5579 .36754 .56197 .36618 .55978 .35887 Mtetra
.55978 .35887 .56197 .36618 .56605 .36482 .56385 .3575 Mtetra
.56385 .3575 .56605 .36482 .57013 .36345 .56793 .35613 Mtetra
.56793 .35613 .57013 .36345 .57415 .35729 .57202 .35476 Mtetra
.663 .742 .909 r
.57202 .35476 .57415 .35729 .57823 .35592 .57611 .35338 Mtetra
.57611 .35338 .57823 .35592 .58233 .35455 .58021 .35201 Mtetra
.58021 .35201 .58233 .35455 .58643 .35317 .58431 .35063 Mtetra
.58431 .35063 .58643 .35317 .59054 .3518 .58842 .34925 Mtetra
.58842 .34925 .59054 .3518 .59465 .35042 .59254 .34787 Mtetra
.59254 .34787 .59465 .35042 .59877 .34904 .59666 .34648 Mtetra
.59666 .34648 .59877 .34904 .60289 .34765 .60079 .3451 Mtetra
.60079 .3451 .60289 .34765 .60702 .34627 .60492 .34371 Mtetra
.60492 .34371 .60702 .34627 .61116 .34488 .60906 .34232 Mtetra
.971 .674 .4 r
.60906 .34232 .61116 .34488 .62006 .51025 .61787 .50779 Mtetra
.65 .758 .929 r
.61787 .50779 .62006 .51025 .62443 .50892 .62225 .50645 Mtetra
.62225 .50645 .62443 .50892 .62881 .50758 .62663 .50511 Mtetra
.62663 .50511 .62881 .50758 .6332 .50624 .63102 .50377 Mtetra
.63102 .50377 .6332 .50624 .63759 .5049 .63542 .50242 Mtetra
.63542 .50242 .63759 .5049 .64199 .50356 .63982 .50107 Mtetra
.63982 .50107 .64199 .50356 .64639 .50221 .64423 .49973 Mtetra
.64423 .49973 .64639 .50221 .65081 .50087 .64865 .49838 Mtetra
.64865 .49838 .65081 .50087 .65522 .49952 .65307 .49702 Mtetra
.65307 .49702 .65522 .49952 .65965 .49817 .6575 .49567 Mtetra
.6575 .49567 .65965 .49817 .66408 .49682 .66194 .49431 Mtetra
.66194 .49431 .66408 .49682 .66853 .49546 .66639 .49295 Mtetra
.66639 .49295 .66853 .49546 .67297 .4941 .67084 .49159 Mtetra
.67084 .49159 .67297 .4941 .67743 .49274 .6753 .49023 Mtetra
.6753 .49023 .67743 .49274 .68189 .49138 .67976 .48886 Mtetra
.67976 .48886 .68189 .49138 .68636 .49002 .68424 .48749 Mtetra
.68424 .48749 .68636 .49002 .69083 .48865 .68872 .48612 Mtetra
.68872 .48612 .69083 .48865 .69532 .48728 .6932 .48475 Mtetra
.6932 .48475 .69532 .48728 .69981 .48591 .6977 .48338 Mtetra
.6977 .48338 .69981 .48591 .7043 .48454 .7022 .482 Mtetra
.978 .725 .483 r
.7022 .482 .7043 .48454 .70674 .44607 .70467 .4435 Mtetra
.653 .755 .924 r
.70467 .4435 .70674 .44607 .7112 .44468 .70913 .44211 Mtetra
.70913 .44211 .7112 .44468 .71567 .44329 .7136 .44071 Mtetra
.7136 .44071 .71567 .44329 .72014 .44189 .71808 .43931 Mtetra
.71808 .43931 .72014 .44189 .72462 .44049 .72256 .43791 Mtetra
.72256 .43791 .72462 .44049 .72911 .4391 .72705 .43651 Mtetra
.72705 .43651 .72911 .4391 .7336 .43769 .73155 .4351 Mtetra
.73155 .4351 .7336 .43769 .7381 .43629 .73606 .43369 Mtetra
.73606 .43369 .7381 .43629 .74261 .43488 .74057 .43228 Mtetra
.74057 .43228 .74261 .43488 .74713 .43348 .74509 .43087 Mtetra
.74509 .43087 .74713 .43348 .75165 .43207 .74962 .42946 Mtetra
.74962 .42946 .75165 .43207 .75618 .43065 .75416 .42804 Mtetra
.75416 .42804 .75618 .43065 .76071 .42924 .7587 .42662 Mtetra
.7587 .42662 .76071 .42924 .76526 .42782 .76325 .4252 Mtetra
.76325 .4252 .76526 .42782 .76981 .4264 .7678 .42378 Mtetra
.7678 .42378 .76981 .4264 .77437 .42498 .77237 .42235 Mtetra
.77237 .42235 .77437 .42498 .77893 .42356 .77694 .42092 Mtetra
.77694 .42092 .77893 .42356 .78351 .42213 .78152 .41949 Mtetra
.98 .688 .377 r
.78152 .41949 .78351 .42213 .77662 .27946 .77471 .27674 Mtetra
.664 .741 .908 r
.77471 .27674 .77662 .27946 .781 .27799 .77909 .27526 Mtetra
.77909 .27526 .781 .27799 .78539 .27651 .78348 .27377 Mtetra
.78348 .27377 .78539 .27651 .78978 .27503 .78788 .27229 Mtetra
.78788 .27229 .78978 .27503 .79418 .27355 .79228 .2708 Mtetra
.79228 .2708 .79418 .27355 .79859 .27206 .79669 .26932 Mtetra
.79669 .26932 .79859 .27206 .803 .27057 .80111 .26782 Mtetra
.80111 .26782 .803 .27057 .80742 .26909 .80554 .26633 Mtetra
.80554 .26633 .80742 .26909 .81184 .26759 .80997 .26483 Mtetra
.80997 .26483 .81184 .26759 .81628 .2661 .8144 .26334 Mtetra
.8144 .26334 .81628 .2661 .82072 .2646 .81885 .26184 Mtetra
.81885 .26184 .82072 .2646 .82516 .26311 .8233 .26033 Mtetra
.8233 .26033 .82516 .26311 .82961 .26161 .82776 .25883 Mtetra
.82776 .25883 .82961 .26161 .83407 .2601 .83222 .25732 Mtetra
.83222 .25732 .83407 .2601 .83854 .2586 .83669 .25581 Mtetra
.83669 .25581 .83854 .2586 .84301 .25709 .84117 .2543 Mtetra
.84117 .2543 .84301 .25709 .8475 .25558 .84566 .25279 Mtetra
.84566 .25279 .8475 .25558 .85198 .25407 .85015 .25127 Mtetra
.24332 .45306 .24574 .45531 .24935 .45409 .24693 .45183 Mtetra
.24693 .45183 .24935 .45409 .25297 .45287 .25056 .45061 Mtetra
.25056 .45061 .25297 .45287 .25659 .45164 .25418 .44938 Mtetra
.25418 .44938 .25659 .45164 .26022 .45042 .25781 .44815 Mtetra
.25781 .44815 .26022 .45042 .26386 .44919 .26145 .44692 Mtetra
.26145 .44692 .26386 .44919 .2675 .44796 .26509 .44569 Mtetra
.26509 .44569 .2675 .44796 .27114 .44673 .26874 .44446 Mtetra
.26874 .44446 .27114 .44673 .27479 .4455 .27239 .44322 Mtetra
.27239 .44322 .27479 .4455 .27844 .44427 .27605 .44199 Mtetra
.27605 .44199 .27844 .44427 .2821 .44303 .27971 .44075 Mtetra
.27971 .44075 .2821 .44303 .28577 .4418 .28338 .43951 Mtetra
.28338 .43951 .28577 .4418 .28944 .44056 .28705 .43827 Mtetra
.28705 .43827 .28944 .44056 .29311 .43932 .29073 .43702 Mtetra
.29073 .43702 .29311 .43932 .29679 .43807 .29441 .43578 Mtetra
.29441 .43578 .29679 .43807 .30048 .43683 .2981 .43453 Mtetra
.2981 .43453 .30048 .43683 .30417 .43558 .30179 .43328 Mtetra
.30179 .43328 .30417 .43558 .30786 .43434 .30549 .43203 Mtetra
.30549 .43203 .30786 .43434 .31156 .43309 .3092 .43078 Mtetra
.3092 .43078 .31156 .43309 .31527 .43184 .3129 .42952 Mtetra
.946 .679 .499 r
.3129 .42952 .31527 .43184 .30972 .57683 .30724 .57461 Mtetra
.652 .756 .925 r
.30724 .57461 .30972 .57683 .3136 .57563 .31112 .5734 Mtetra
.31112 .5734 .3136 .57563 .31748 .57442 .31501 .57219 Mtetra
.31501 .57219 .31748 .57442 .32137 .57322 .3189 .57098 Mtetra
.3189 .57098 .32137 .57322 .32526 .57201 .3228 .56977 Mtetra
.3228 .56977 .32526 .57201 .32916 .5708 .3267 .56856 Mtetra
.3267 .56856 .32916 .5708 .33306 .56958 .33061 .56734 Mtetra
.33061 .56734 .33306 .56958 .33697 .56837 .33452 .56612 Mtetra
.33452 .56612 .33697 .56837 .34089 .56715 .33844 .5649 Mtetra
.33844 .5649 .34089 .56715 .34481 .56594 .34237 .56368 Mtetra
.34237 .56368 .34481 .56594 .34874 .56472 .3463 .56246 Mtetra
.3463 .56246 .34874 .56472 .35268 .56349 .35024 .56124 Mtetra
.35024 .56124 .35268 .56349 .35662 .56227 .35418 .56001 Mtetra
.35418 .56001 .35662 .56227 .36056 .56105 .35813 .55878 Mtetra
.35813 .55878 .36056 .56105 .36451 .55982 .36208 .55755 Mtetra
.36208 .55755 .36451 .55982 .36847 .55859 .36604 .55632 Mtetra
.36604 .55632 .36847 .55859 .37243 .55736 .37001 .55508 Mtetra
.37001 .55508 .37243 .55736 .3764 .55613 .37398 .55385 Mtetra
.37398 .55385 .3764 .55613 .38038 .55489 .37796 .55261 Mtetra
.37796 .55261 .38038 .55489 .38436 .55366 .38195 .55137 Mtetra
.38195 .55137 .38436 .55366 .38834 .55242 .38594 .55013 Mtetra
.38594 .55013 .38834 .55242 .39234 .55118 .38993 .54889 Mtetra
.897 .477 .116 r
.38993 .54889 .39234 .55118 .39711 .52952 .39353 .55795 Mtetra
0 0 .144 r
.39353 .55795 .39711 .52952 .40109 .52827 .39871 .52595 Mtetra
.654 .754 .923 r
.39871 .52595 .40109 .52827 .40508 .52701 .4027 .52469 Mtetra
.4027 .52469 .40508 .52701 .40907 .52576 .4067 .52344 Mtetra
.4067 .52344 .40907 .52576 .41307 .5245 .4107 .52218 Mtetra
.4107 .52218 .41307 .5245 .41708 .52324 .41471 .52091 Mtetra
.41471 .52091 .41708 .52324 .42109 .52198 .41872 .51965 Mtetra
.41872 .51965 .42109 .52198 .4251 .52072 .42275 .51839 Mtetra
.42275 .51839 .4251 .52072 .42913 .51946 .42677 .51712 Mtetra
.42677 .51712 .42913 .51946 .43315 .51819 .4308 .51585 Mtetra
.4308 .51585 .43315 .51819 .43719 .51692 .43484 .51458 Mtetra
.43484 .51458 .43719 .51692 .44123 .51565 .43889 .5133 Mtetra
.43889 .5133 .44123 .51565 .44528 .51438 .44294 .51203 Mtetra
.44294 .51203 .44528 .51438 .44933 .51311 .44699 .51075 Mtetra
.44699 .51075 .44933 .51311 .45339 .51183 .45106 .50947 Mtetra
.45106 .50947 .45339 .51183 .45745 .51055 .45512 .50819 Mtetra
.45512 .50819 .45745 .51055 .46152 .50928 .4592 .50691 Mtetra
.4592 .50691 .46152 .50928 .4656 .50799 .46328 .50562 Mtetra
.46328 .50562 .4656 .50799 .4718 .37899 .46737 .50434 Mtetra
0 0 .293 r
.46737 .50434 .4718 .37899 .47573 .37767 .47351 .37521 Mtetra
.664 .741 .908 r
.47351 .37521 .47573 .37767 .47967 .37634 .47746 .37388 Mtetra
.47746 .37388 .47967 .37634 .48362 .375 .4814 .37254 Mtetra
.4814 .37254 .48362 .375 .48757 .37367 .48536 .3712 Mtetra
.48536 .3712 .48757 .37367 .49152 .37233 .48932 .36986 Mtetra
.48932 .36986 .49152 .37233 .49549 .371 .49329 .36852 Mtetra
.49329 .36852 .49549 .371 .49946 .36966 .49726 .36718 Mtetra
.49726 .36718 .49946 .36966 .50343 .36832 .50123 .36583 Mtetra
.50123 .36583 .50343 .36832 .50741 .36697 .50522 .36449 Mtetra
.50522 .36449 .50741 .36697 .51139 .36563 .50921 .36314 Mtetra
.50921 .36314 .51139 .36563 .51538 .36428 .5132 .36179 Mtetra
.5132 .36179 .51538 .36428 .51938 .36293 .5172 .36043 Mtetra
.5172 .36043 .51938 .36293 .52338 .36158 .52121 .35908 Mtetra
.52121 .35908 .52338 .36158 .52739 .36023 .52522 .35772 Mtetra
.52522 .35772 .52739 .36023 .53141 .35887 .52924 .35636 Mtetra
.52924 .35636 .53141 .35887 .53543 .35751 .53326 .355 Mtetra
.919 .527 .147 r
.53326 .355 .53543 .35751 .53952 .37046 .53735 .36796 Mtetra
.876 .777 .748 r
.53735 .36796 .53952 .37046 .54357 .36911 .54138 .36181 Mtetra
.62 .518 .717 r
.54138 .36181 .54357 .36911 .54763 .36775 .54543 .36045 Mtetra
.54543 .36045 .54763 .36775 .55169 .36639 .54949 .35908 Mtetra
.54949 .35908 .55169 .36639 .55571 .36024 .55356 .35771 Mtetra
.663 .742 .909 r
.55356 .35771 .55571 .36024 .55978 .35887 .55763 .35634 Mtetra
.55763 .35634 .55978 .35887 .56385 .3575 .56171 .35497 Mtetra
.56171 .35497 .56385 .3575 .56793 .35613 .56579 .3536 Mtetra
.56579 .3536 .56793 .35613 .57202 .35476 .56988 .35222 Mtetra
.56988 .35222 .57202 .35476 .57611 .35338 .57398 .35084 Mtetra
.57398 .35084 .57611 .35338 .58021 .35201 .57808 .34946 Mtetra
.57808 .34946 .58021 .35201 .58431 .35063 .58219 .34808 Mtetra
.58219 .34808 .58431 .35063 .58842 .34925 .5863 .34669 Mtetra
.5863 .34669 .58842 .34925 .59254 .34787 .59042 .34531 Mtetra
.59042 .34531 .59254 .34787 .59666 .34648 .59455 .34392 Mtetra
.59455 .34392 .59666 .34648 .60079 .3451 .59868 .34253 Mtetra
.59868 .34253 .60079 .3451 .60492 .34371 .60282 .34114 Mtetra
.60282 .34114 .60492 .34371 .60906 .34232 .60697 .33974 Mtetra
.971 .675 .402 r
.60697 .33974 .60906 .34232 .61787 .50779 .61611 .52137 Mtetra
.488 .203 .407 r
.61611 .52137 .61787 .50779 .62225 .50645 .62051 .52004 Mtetra
0 0 .151 r
.62051 .52004 .62225 .50645 .62663 .50511 .62444 .50263 Mtetra
.65 .758 .929 r
.62444 .50263 .62663 .50511 .63102 .50377 .62883 .50128 Mtetra
.62883 .50128 .63102 .50377 .63542 .50242 .63324 .49993 Mtetra
.63324 .49993 .63542 .50242 .63982 .50107 .63764 .49858 Mtetra
.63764 .49858 .63982 .50107 .64423 .49973 .64206 .49723 Mtetra
.64206 .49723 .64423 .49973 .64865 .49838 .64648 .49588 Mtetra
.64648 .49588 .64865 .49838 .65307 .49702 .65091 .49452 Mtetra
.65091 .49452 .65307 .49702 .6575 .49567 .65535 .49316 Mtetra
.65535 .49316 .6575 .49567 .66194 .49431 .65979 .4918 Mtetra
.65979 .4918 .66194 .49431 .66639 .49295 .66424 .49044 Mtetra
.66424 .49044 .66639 .49295 .67084 .49159 .6687 .48907 Mtetra
.6687 .48907 .67084 .49159 .6753 .49023 .67316 .48771 Mtetra
.67316 .48771 .6753 .49023 .67976 .48886 .67763 .48634 Mtetra
.67763 .48634 .67976 .48886 .68424 .48749 .68211 .48496 Mtetra
.68211 .48496 .68424 .48749 .68872 .48612 .68659 .48359 Mtetra
.68659 .48359 .68872 .48612 .6932 .48475 .69109 .48221 Mtetra
.69109 .48221 .6932 .48475 .6977 .48338 .69559 .48084 Mtetra
.69559 .48084 .6977 .48338 .7022 .482 .70009 .47946 Mtetra
.978 .725 .483 r
.70009 .47946 .7022 .482 .70467 .4435 .70258 .44092 Mtetra
.653 .755 .924 r
.70258 .44092 .70467 .4435 .70913 .44211 .70705 .43953 Mtetra
.70705 .43953 .70913 .44211 .7136 .44071 .71153 .43813 Mtetra
.71153 .43813 .7136 .44071 .71808 .43931 .71601 .43672 Mtetra
.71601 .43672 .71808 .43931 .72256 .43791 .7205 .43532 Mtetra
.7205 .43532 .72256 .43791 .72705 .43651 .725 .43391 Mtetra
.725 .43391 .72705 .43651 .73155 .4351 .7295 .4325 Mtetra
.7295 .4325 .73155 .4351 .73606 .43369 .73401 .43109 Mtetra
.73401 .43109 .73606 .43369 .74057 .43228 .73853 .42968 Mtetra
.73853 .42968 .74057 .43228 .74509 .43087 .74306 .42826 Mtetra
.74306 .42826 .74509 .43087 .74962 .42946 .74759 .42684 Mtetra
.74759 .42684 .74962 .42946 .75416 .42804 .75213 .42542 Mtetra
.75213 .42542 .75416 .42804 .7587 .42662 .75668 .424 Mtetra
.75668 .424 .7587 .42662 .76325 .4252 .76123 .42257 Mtetra
.76123 .42257 .76325 .4252 .7678 .42378 .76579 .42114 Mtetra
.76579 .42114 .7678 .42378 .77237 .42235 .77036 .41971 Mtetra
.77036 .41971 .77237 .42235 .77694 .42092 .77494 .41828 Mtetra
.98 .688 .379 r
.77494 .41828 .77694 .42092 .78152 .41949 .76841 .27548 Mtetra
.55 .337 .544 r
.76841 .27548 .78152 .41949 .77471 .27674 .77279 .274 Mtetra
.664 .741 .908 r
.77279 .274 .77471 .27674 .77909 .27526 .77718 .27252 Mtetra
.77718 .27252 .77909 .27526 .78348 .27377 .78157 .27103 Mtetra
.78157 .27103 .78348 .27377 .78788 .27229 .78597 .26954 Mtetra
.78597 .26954 .78788 .27229 .79228 .2708 .79038 .26805 Mtetra
.79038 .26805 .79228 .2708 .79669 .26932 .7948 .26656 Mtetra
.7948 .26656 .79669 .26932 .80111 .26782 .79922 .26506 Mtetra
.79922 .26506 .80111 .26782 .80554 .26633 .80365 .26357 Mtetra
.80365 .26357 .80554 .26633 .80997 .26483 .80808 .26207 Mtetra
.80808 .26207 .80997 .26483 .8144 .26334 .81253 .26057 Mtetra
.81253 .26057 .8144 .26334 .81885 .26184 .81697 .25906 Mtetra
.81697 .25906 .81885 .26184 .8233 .26033 .82143 .25755 Mtetra
.82143 .25755 .8233 .26033 .82776 .25883 .82589 .25604 Mtetra
.82589 .25604 .82776 .25883 .83222 .25732 .83036 .25453 Mtetra
.83036 .25453 .83222 .25732 .83669 .25581 .83484 .25302 Mtetra
.83484 .25302 .83669 .25581 .84117 .2543 .83932 .2515 Mtetra
.83932 .2515 .84117 .2543 .84566 .25279 .84381 .24998 Mtetra
.84381 .24998 .84566 .25279 .85015 .25127 .84831 .24846 Mtetra
.24089 .4508 .24332 .45306 .24693 .45183 .24451 .44957 Mtetra
.24451 .44957 .24693 .45183 .25056 .45061 .24814 .44834 Mtetra
.24814 .44834 .25056 .45061 .25418 .44938 .25176 .44711 Mtetra
.25176 .44711 .25418 .44938 .25781 .44815 .2554 .44588 Mtetra
.2554 .44588 .25781 .44815 .26145 .44692 .25904 .44465 Mtetra
.25904 .44465 .26145 .44692 .26509 .44569 .26268 .44341 Mtetra
.26268 .44341 .26509 .44569 .26874 .44446 .26633 .44218 Mtetra
.26633 .44218 .26874 .44446 .27239 .44322 .26999 .44094 Mtetra
.26999 .44094 .27239 .44322 .27605 .44199 .27365 .4397 Mtetra
.27365 .4397 .27605 .44199 .27971 .44075 .27732 .43846 Mtetra
.27732 .43846 .27971 .44075 .28338 .43951 .28099 .43721 Mtetra
.28099 .43721 .28338 .43951 .28705 .43827 .28466 .43597 Mtetra
.28466 .43597 .28705 .43827 .29073 .43702 .28834 .43472 Mtetra
.28834 .43472 .29073 .43702 .29441 .43578 .29203 .43347 Mtetra
.29203 .43347 .29441 .43578 .2981 .43453 .29572 .43222 Mtetra
.29572 .43222 .2981 .43453 .30179 .43328 .29942 .43097 Mtetra
.29942 .43097 .30179 .43328 .30549 .43203 .30312 .42972 Mtetra
.30312 .42972 .30549 .43203 .3092 .43078 .30682 .42846 Mtetra
.946 .679 .5 r
.30682 .42846 .3092 .43078 .3129 .42952 .30088 .57359 Mtetra
.54 .314 .521 r
.30088 .57359 .3129 .42952 .30724 .57461 .30476 .57238 Mtetra
.652 .756 .925 r
.30476 .57238 .30724 .57461 .31112 .5734 .30864 .57117 Mtetra
.30864 .57117 .31112 .5734 .31501 .57219 .31253 .56996 Mtetra
.31253 .56996 .31501 .57219 .3189 .57098 .31642 .56874 Mtetra
.31642 .56874 .3189 .57098 .3228 .56977 .32032 .56753 Mtetra
.32032 .56753 .3228 .56977 .3267 .56856 .32423 .56631 Mtetra
.32423 .56631 .3267 .56856 .33061 .56734 .32814 .56509 Mtetra
.32814 .56509 .33061 .56734 .33452 .56612 .33206 .56387 Mtetra
.33206 .56387 .33452 .56612 .33844 .5649 .33598 .56265 Mtetra
.33598 .56265 .33844 .5649 .34237 .56368 .33991 .56142 Mtetra
.33991 .56142 .34237 .56368 .3463 .56246 .34385 .5602 Mtetra
.34385 .5602 .3463 .56246 .35024 .56124 .34779 .55897 Mtetra
.34779 .55897 .35024 .56124 .35418 .56001 .35174 .55774 Mtetra
.35174 .55774 .35418 .56001 .35813 .55878 .35569 .55651 Mtetra
.35569 .55651 .35813 .55878 .36208 .55755 .35965 .55527 Mtetra
.35965 .55527 .36208 .55755 .36604 .55632 .36361 .55404 Mtetra
.36361 .55404 .36604 .55632 .37001 .55508 .36758 .5528 Mtetra
.36758 .5528 .37001 .55508 .37398 .55385 .37156 .55156 Mtetra
.37156 .55156 .37398 .55385 .37796 .55261 .37554 .55032 Mtetra
.37554 .55032 .37796 .55261 .38195 .55137 .37953 .54908 Mtetra
.37953 .54908 .38195 .55137 .38594 .55013 .38352 .54783 Mtetra
.897 .479 .119 r
.38352 .54783 .38594 .55013 .38993 .54889 .3871 .5569 Mtetra
.442 .116 .316 r
.3871 .5569 .38993 .54889 .39353 .55795 .39112 .55566 Mtetra
.651 .757 .927 r
.39112 .55566 .39353 .55795 .39871 .52595 .39514 .55441 Mtetra
.519 .268 .475 r
.39514 .55441 .39871 .52595 .4027 .52469 .39917 .55316 Mtetra
0 0 .147 r
.39917 .55316 .4027 .52469 .4067 .52344 .40432 .52111 Mtetra
.654 .754 .923 r
.40432 .52111 .4067 .52344 .4107 .52218 .40833 .51985 Mtetra
.40833 .51985 .4107 .52218 .41471 .52091 .41234 .51858 Mtetra
.41234 .51858 .41471 .52091 .41872 .51965 .41636 .51731 Mtetra
.41636 .51731 .41872 .51965 .42275 .51839 .42038 .51604 Mtetra
.42038 .51604 .42275 .51839 .42677 .51712 .42441 .51477 Mtetra
.42441 .51477 .42677 .51712 .4308 .51585 .42845 .5135 Mtetra
.42845 .5135 .4308 .51585 .43484 .51458 .43249 .51222 Mtetra
.43249 .51222 .43484 .51458 .43889 .5133 .43654 .51095 Mtetra
.43654 .51095 .43889 .5133 .44294 .51203 .44059 .50967 Mtetra
.44059 .50967 .44294 .51203 .44699 .51075 .44465 .50839 Mtetra
.44465 .50839 .44699 .51075 .45106 .50947 .44872 .50711 Mtetra
.44872 .50711 .45106 .50947 .45512 .50819 .45279 .50582 Mtetra
.45279 .50582 .45512 .50819 .4592 .50691 .45687 .50454 Mtetra
.45687 .50454 .4592 .50691 .46328 .50562 .46095 .50325 Mtetra
.46095 .50325 .46328 .50562 .46737 .50434 .46504 .50196 Mtetra
.96 .697 .492 r
.46504 .50196 .46737 .50434 .47351 .37521 .47129 .37275 Mtetra
.664 .741 .908 r
.47129 .37275 .47351 .37521 .47746 .37388 .47523 .37141 Mtetra
.47523 .37141 .47746 .37388 .4814 .37254 .47919 .37007 Mtetra
.47919 .37007 .4814 .37254 .48536 .3712 .48314 .36873 Mtetra
.48314 .36873 .48536 .3712 .48932 .36986 .48711 .36739 Mtetra
.48711 .36739 .48932 .36986 .49329 .36852 .49108 .36604 Mtetra
.49108 .36604 .49329 .36852 .49726 .36718 .49505 .3647 Mtetra
.49505 .3647 .49726 .36718 .50123 .36583 .49903 .36335 Mtetra
.49903 .36335 .50123 .36583 .50522 .36449 .50302 .362 Mtetra
.50302 .362 .50522 .36449 .50921 .36314 .50701 .36064 Mtetra
.50701 .36064 .50921 .36314 .5132 .36179 .51101 .35929 Mtetra
.51101 .35929 .5132 .36179 .5172 .36043 .51502 .35793 Mtetra
.51502 .35793 .5172 .36043 .52121 .35908 .51903 .35657 Mtetra
.51903 .35657 .52121 .35908 .52522 .35772 .52304 .35521 Mtetra
.52304 .35521 .52522 .35772 .52924 .35636 .52707 .35385 Mtetra
.52707 .35385 .52924 .35636 .53326 .355 .53109 .35249 Mtetra
.825 .381 0 r
.53109 .35249 .53326 .355 .53735 .36796 .53516 .36066 Mtetra
.619 .518 .717 r
.53516 .36066 .53735 .36796 .54138 .36181 .53921 .35929 Mtetra
.663 .742 .909 r
.53921 .35929 .54138 .36181 .54543 .36045 .54327 .35792 Mtetra
.54327 .35792 .54543 .36045 .54949 .35908 .54733 .35655 Mtetra
.54733 .35655 .54949 .35908 .55356 .35771 .5514 .35518 Mtetra
.5514 .35518 .55356 .35771 .55763 .35634 .55548 .35381 Mtetra
.55548 .35381 .55763 .35634 .56171 .35497 .55956 .35243 Mtetra
.55956 .35243 .56171 .35497 .56579 .3536 .56365 .35105 Mtetra
.56365 .35105 .56579 .3536 .56988 .35222 .56774 .34967 Mtetra
.56774 .34967 .56988 .35222 .57398 .35084 .57184 .34829 Mtetra
.57184 .34829 .57398 .35084 .57808 .34946 .57595 .34691 Mtetra
.57595 .34691 .57808 .34946 .58219 .34808 .58006 .34552 Mtetra
.58006 .34552 .58219 .34808 .5863 .34669 .58418 .34413 Mtetra
.58418 .34413 .5863 .34669 .59042 .34531 .5883 .34274 Mtetra
.5883 .34274 .59042 .34531 .59455 .34392 .59243 .34135 Mtetra
.59243 .34135 .59455 .34392 .59868 .34253 .59657 .33996 Mtetra
.59657 .33996 .59868 .34253 .60282 .34114 .60071 .33856 Mtetra
.60071 .33856 .60282 .34114 .60697 .33974 .60486 .33716 Mtetra
.971 .675 .402 r
.60486 .33716 .60697 .33974 .61611 .52137 .6139 .5189 Mtetra
.648 .76 .931 r
.6139 .5189 .61611 .52137 .62051 .52004 .6183 .51756 Mtetra
.6183 .51756 .62051 .52004 .62444 .50263 .62272 .51622 Mtetra
0 0 .151 r
.62272 .51622 .62444 .50263 .62883 .50128 .62664 .49879 Mtetra
.65 .758 .929 r
.62664 .49879 .62883 .50128 .63324 .49993 .63105 .49744 Mtetra
.63105 .49744 .63324 .49993 .63764 .49858 .63546 .49609 Mtetra
.63546 .49609 .63764 .49858 .64206 .49723 .63988 .49473 Mtetra
.63988 .49473 .64206 .49723 .64648 .49588 .64431 .49337 Mtetra
.64431 .49337 .64648 .49588 .65091 .49452 .64874 .49201 Mtetra
.64874 .49201 .65091 .49452 .65535 .49316 .65318 .49065 Mtetra
.65318 .49065 .65535 .49316 .65979 .4918 .65763 .48928 Mtetra
.65763 .48928 .65979 .4918 .66424 .49044 .66209 .48792 Mtetra
.66209 .48792 .66424 .49044 .6687 .48907 .66655 .48655 Mtetra
.66655 .48655 .6687 .48907 .67316 .48771 .67102 .48518 Mtetra
.67102 .48518 .67316 .48771 .67763 .48634 .67549 .4838 Mtetra
.67549 .4838 .67763 .48634 .68211 .48496 .67998 .48243 Mtetra
.67998 .48243 .68211 .48496 .68659 .48359 .68447 .48105 Mtetra
.68447 .48105 .68659 .48359 .69109 .48221 .68896 .47967 Mtetra
.68896 .47967 .69109 .48221 .69559 .48084 .69347 .47829 Mtetra
.977 .725 .484 r
.69347 .47829 .69559 .48084 .70009 .47946 .69603 .43974 Mtetra
.562 .366 .573 r
.69603 .43974 .70009 .47946 .70258 .44092 .7005 .43834 Mtetra
.653 .755 .924 r
.7005 .43834 .70258 .44092 .70705 .43953 .70497 .43694 Mtetra
.70497 .43694 .70705 .43953 .71153 .43813 .70945 .43553 Mtetra
.70945 .43553 .71153 .43813 .71601 .43672 .71394 .43413 Mtetra
.71394 .43413 .71601 .43672 .7205 .43532 .71843 .43272 Mtetra
.71843 .43272 .7205 .43532 .725 .43391 .72293 .43131 Mtetra
.72293 .43131 .725 .43391 .7295 .4325 .72744 .42989 Mtetra
.72744 .42989 .7295 .4325 .73401 .43109 .73196 .42848 Mtetra
.73196 .42848 .73401 .43109 .73853 .42968 .73648 .42706 Mtetra
.73648 .42706 .73853 .42968 .74306 .42826 .74101 .42564 Mtetra
.74101 .42564 .74306 .42826 .74759 .42684 .74555 .42422 Mtetra
.74555 .42422 .74759 .42684 .75213 .42542 .75009 .42279 Mtetra
.75009 .42279 .75213 .42542 .75668 .424 .75465 .42136 Mtetra
.75465 .42136 .75668 .424 .76123 .42257 .75921 .41993 Mtetra
.75921 .41993 .76123 .42257 .76579 .42114 .76377 .4185 Mtetra
.76377 .4185 .76579 .42114 .77036 .41971 .76835 .41707 Mtetra
.76835 .41707 .77036 .41971 .77494 .41828 .77293 .41563 Mtetra
.98 .688 .379 r
.77293 .41563 .77494 .41828 .76841 .27548 .76648 .27275 Mtetra
.664 .741 .908 r
.76648 .27275 .76841 .27548 .77279 .274 .77086 .27126 Mtetra
.77086 .27126 .77279 .274 .77718 .27252 .77525 .26977 Mtetra
.77525 .26977 .77718 .27252 .78157 .27103 .77965 .26828 Mtetra
.77965 .26828 .78157 .27103 .78597 .26954 .78406 .26679 Mtetra
.78406 .26679 .78597 .26954 .79038 .26805 .78847 .2653 Mtetra
.78847 .2653 .79038 .26805 .7948 .26656 .79289 .2638 Mtetra
.79289 .2638 .7948 .26656 .79922 .26506 .79732 .2623 Mtetra
.79732 .2623 .79922 .26506 .80365 .26357 .80175 .2608 Mtetra
.80175 .2608 .80365 .26357 .80808 .26207 .80619 .25929 Mtetra
.80619 .25929 .80808 .26207 .81253 .26057 .81064 .25779 Mtetra
.81064 .25779 .81253 .26057 .81697 .25906 .8151 .25628 Mtetra
.8151 .25628 .81697 .25906 .82143 .25755 .81956 .25477 Mtetra
.81956 .25477 .82143 .25755 .82589 .25604 .82402 .25325 Mtetra
.82402 .25325 .82589 .25604 .83036 .25453 .8285 .25174 Mtetra
.8285 .25174 .83036 .25453 .83484 .25302 .83298 .25022 Mtetra
.83298 .25022 .83484 .25302 .83932 .2515 .83747 .2487 Mtetra
.83747 .2487 .83932 .2515 .84381 .24998 .84197 .24717 Mtetra
.84197 .24717 .84381 .24998 .84831 .24846 .84647 .24565 Mtetra
.23846 .44853 .24089 .4508 .24451 .44957 .24208 .4473 Mtetra
.24208 .4473 .24451 .44957 .24814 .44834 .24571 .44607 Mtetra
.24571 .44607 .24814 .44834 .25176 .44711 .24934 .44484 Mtetra
.24934 .44484 .25176 .44711 .2554 .44588 .25298 .4436 Mtetra
.25298 .4436 .2554 .44588 .25904 .44465 .25662 .44237 Mtetra
.25662 .44237 .25904 .44465 .26268 .44341 .26027 .44113 Mtetra
.26027 .44113 .26268 .44341 .26633 .44218 .26392 .43989 Mtetra
.26392 .43989 .26633 .44218 .26999 .44094 .26758 .43865 Mtetra
.26758 .43865 .26999 .44094 .27365 .4397 .27124 .4374 Mtetra
.27124 .4374 .27365 .4397 .27732 .43846 .27491 .43616 Mtetra
.27491 .43616 .27732 .43846 .28099 .43721 .27859 .43491 Mtetra
.27859 .43491 .28099 .43721 .28466 .43597 .28226 .43366 Mtetra
.28226 .43366 .28466 .43597 .28834 .43472 .28595 .43241 Mtetra
.28595 .43241 .28834 .43472 .29203 .43347 .28964 .43116 Mtetra
.28964 .43116 .29203 .43347 .29572 .43222 .29333 .42991 Mtetra
.29333 .42991 .29572 .43222 .29942 .43097 .29703 .42865 Mtetra
.29703 .42865 .29942 .43097 .30312 .42972 .30074 .4274 Mtetra
.30074 .4274 .30312 .42972 .30682 .42846 .30445 .42614 Mtetra
.946 .679 .5 r
.30445 .42614 .30682 .42846 .30088 .57359 .29838 .57136 Mtetra
.652 .756 .925 r
.29838 .57136 .30088 .57359 .30476 .57238 .30227 .57014 Mtetra
.30227 .57014 .30476 .57238 .30864 .57117 .30615 .56893 Mtetra
.30615 .56893 .30864 .57117 .31253 .56996 .31005 .56772 Mtetra
.31005 .56772 .31253 .56996 .31642 .56874 .31394 .5665 Mtetra
.31394 .5665 .31642 .56874 .32032 .56753 .31785 .56528 Mtetra
.31785 .56528 .32032 .56753 .32423 .56631 .32176 .56406 Mtetra
.32176 .56406 .32423 .56631 .32814 .56509 .32567 .56284 Mtetra
.32567 .56284 .32814 .56509 .33206 .56387 .32959 .56161 Mtetra
.32959 .56161 .33206 .56387 .33598 .56265 .33352 .56039 Mtetra
.33352 .56039 .33598 .56265 .33991 .56142 .33745 .55916 Mtetra
.33745 .55916 .33991 .56142 .34385 .5602 .34139 .55793 Mtetra
.34139 .55793 .34385 .5602 .34779 .55897 .34534 .5567 Mtetra
.34534 .5567 .34779 .55897 .35174 .55774 .34929 .55546 Mtetra
.34929 .55546 .35174 .55774 .35569 .55651 .35324 .55423 Mtetra
.35324 .55423 .35569 .55651 .35965 .55527 .35721 .55299 Mtetra
.35721 .55299 .35965 .55527 .36361 .55404 .36117 .55175 Mtetra
.36117 .55175 .36361 .55404 .36758 .5528 .36515 .55051 Mtetra
.36515 .55051 .36758 .5528 .37156 .55156 .36913 .54927 Mtetra
.36913 .54927 .37156 .55156 .37554 .55032 .37311 .54803 Mtetra
.37311 .54803 .37554 .55032 .37953 .54908 .3771 .54678 Mtetra
.3771 .54678 .37953 .54908 .38352 .54783 .3811 .54553 Mtetra
.897 .479 .119 r
.3811 .54553 .38352 .54783 .3871 .5569 .38468 .5546 Mtetra
.651 .757 .927 r
.38468 .5546 .3871 .5569 .39112 .55566 .3887 .55336 Mtetra
.3887 .55336 .39112 .55566 .39514 .55441 .39273 .55211 Mtetra
.39273 .55211 .39514 .55441 .39917 .55316 .39676 .55085 Mtetra
.39676 .55085 .39917 .55316 .40432 .52111 .4008 .5496 Mtetra
0 0 .147 r
.4008 .5496 .40432 .52111 .40833 .51985 .40594 .51751 Mtetra
.654 .754 .923 r
.40594 .51751 .40833 .51985 .41234 .51858 .40996 .51624 Mtetra
.40996 .51624 .41234 .51858 .41636 .51731 .41398 .51497 Mtetra
.41398 .51497 .41636 .51731 .42038 .51604 .41801 .5137 Mtetra
.41801 .5137 .42038 .51604 .42441 .51477 .42204 .51242 Mtetra
.42204 .51242 .42441 .51477 .42845 .5135 .42608 .51114 Mtetra
.42608 .51114 .42845 .5135 .43249 .51222 .43013 .50987 Mtetra
.43013 .50987 .43249 .51222 .43654 .51095 .43418 .50859 Mtetra
.43418 .50859 .43654 .51095 .44059 .50967 .43824 .5073 Mtetra
.43824 .5073 .44059 .50967 .44465 .50839 .4423 .50602 Mtetra
.4423 .50602 .44465 .50839 .44872 .50711 .44637 .50473 Mtetra
.44637 .50473 .44872 .50711 .45279 .50582 .45045 .50345 Mtetra
.45045 .50345 .45279 .50582 .45687 .50454 .45453 .50216 Mtetra
.45453 .50216 .45687 .50454 .46095 .50325 .45862 .50086 Mtetra
.45862 .50086 .46095 .50325 .46504 .50196 .46272 .49957 Mtetra
.96 .697 .492 r
.46272 .49957 .46504 .50196 .47129 .37275 .46906 .37028 Mtetra
.664 .741 .908 r
.46906 .37028 .47129 .37275 .47523 .37141 .47301 .36894 Mtetra
.47301 .36894 .47523 .37141 .47919 .37007 .47696 .36759 Mtetra
.47696 .36759 .47919 .37007 .48314 .36873 .48092 .36625 Mtetra
.48092 .36625 .48314 .36873 .48711 .36739 .48489 .3649 Mtetra
.48489 .3649 .48711 .36739 .49108 .36604 .48886 .36355 Mtetra
.48886 .36355 .49108 .36604 .49505 .3647 .49284 .3622 Mtetra
.49284 .3622 .49505 .3647 .49903 .36335 .49683 .36085 Mtetra
.49683 .36085 .49903 .36335 .50302 .362 .50082 .3595 Mtetra
.50082 .3595 .50302 .362 .50701 .36064 .50482 .35814 Mtetra
.50482 .35814 .50701 .36064 .51101 .35929 .50882 .35678 Mtetra
.50882 .35678 .51101 .35929 .51502 .35793 .51283 .35542 Mtetra
.51283 .35542 .51502 .35793 .51903 .35657 .51684 .35406 Mtetra
.51684 .35406 .51903 .35657 .52304 .35521 .52086 .3527 Mtetra
.52086 .3527 .52304 .35521 .52707 .35385 .52489 .35133 Mtetra
.52489 .35133 .52707 .35385 .53109 .35249 .52892 .34996 Mtetra
.825 .381 0 r
.52892 .34996 .53109 .35249 .53516 .36066 .53298 .35813 Mtetra
.663 .742 .909 r
.53298 .35813 .53516 .36066 .53921 .35929 .53704 .35676 Mtetra
.53704 .35676 .53921 .35929 .54327 .35792 .5411 .35539 Mtetra
.5411 .35539 .54327 .35792 .54733 .35655 .54517 .35402 Mtetra
.54517 .35402 .54733 .35655 .5514 .35518 .54924 .35264 Mtetra
.54924 .35264 .5514 .35518 .55548 .35381 .55332 .35127 Mtetra
.55332 .35127 .55548 .35381 .55956 .35243 .55741 .34989 Mtetra
.55741 .34989 .55956 .35243 .56365 .35105 .5615 .3485 Mtetra
.5615 .3485 .56365 .35105 .56774 .34967 .5656 .34712 Mtetra
.5656 .34712 .56774 .34967 .57184 .34829 .5697 .34574 Mtetra
.5697 .34574 .57184 .34829 .57595 .34691 .57381 .34435 Mtetra
.57381 .34435 .57595 .34691 .58006 .34552 .57793 .34296 Mtetra
.57793 .34296 .58006 .34552 .58418 .34413 .58205 .34157 Mtetra
.58205 .34157 .58418 .34413 .5883 .34274 .58618 .34017 Mtetra
.58618 .34017 .5883 .34274 .59243 .34135 .59031 .33878 Mtetra
.59031 .33878 .59243 .34135 .59657 .33996 .59445 .33738 Mtetra
.59445 .33738 .59657 .33996 .60071 .33856 .5986 .33598 Mtetra
.5986 .33598 .60071 .33856 .60486 .33716 .60275 .33458 Mtetra
.971 .675 .402 r
.60275 .33458 .60486 .33716 .6139 .5189 .61168 .51643 Mtetra
.648 .76 .931 r
.61168 .51643 .6139 .5189 .6183 .51756 .61609 .51509 Mtetra
.61609 .51509 .6183 .51756 .62272 .51622 .6205 .51374 Mtetra
.6205 .51374 .62272 .51622 .62664 .49879 .62493 .51239 Mtetra
.487 .201 .405 r
.62493 .51239 .62664 .49879 .63105 .49744 .62936 .51104 Mtetra
0 0 .154 r
.62936 .51104 .63105 .49744 .63546 .49609 .63328 .49358 Mtetra
.65 .758 .929 r
.63328 .49358 .63546 .49609 .63988 .49473 .6377 .49222 Mtetra
.6377 .49222 .63988 .49473 .64431 .49337 .64213 .49086 Mtetra
.64213 .49086 .64431 .49337 .64874 .49201 .64657 .48949 Mtetra
.64657 .48949 .64874 .49201 .65318 .49065 .65102 .48813 Mtetra
.65102 .48813 .65318 .49065 .65763 .48928 .65547 .48676 Mtetra
.65547 .48676 .65763 .48928 .66209 .48792 .65993 .48539 Mtetra
.65993 .48539 .66209 .48792 .66655 .48655 .66439 .48401 Mtetra
.66439 .48401 .66655 .48655 .67102 .48518 .66887 .48264 Mtetra
.66887 .48264 .67102 .48518 .67549 .4838 .67335 .48126 Mtetra
.67335 .48126 .67549 .4838 .67998 .48243 .67784 .47988 Mtetra
.67784 .47988 .67998 .48243 .68447 .48105 .68233 .4785 Mtetra
.68233 .4785 .68447 .48105 .68896 .47967 .68683 .47711 Mtetra
.68683 .47711 .68896 .47967 .69347 .47829 .69134 .47573 Mtetra
.977 .725 .484 r
.69134 .47573 .69347 .47829 .69603 .43974 .69393 .43715 Mtetra
.653 .755 .924 r
.69393 .43715 .69603 .43974 .7005 .43834 .6984 .43575 Mtetra
.6984 .43575 .7005 .43834 .70497 .43694 .70288 .43434 Mtetra
.70288 .43434 .70497 .43694 .70945 .43553 .70737 .43293 Mtetra
.70737 .43293 .70945 .43553 .71394 .43413 .71186 .43152 Mtetra
.71186 .43152 .71394 .43413 .71843 .43272 .71636 .43011 Mtetra
.71636 .43011 .71843 .43272 .72293 .43131 .72086 .42869 Mtetra
.72086 .42869 .72293 .43131 .72744 .42989 .72538 .42728 Mtetra
.72538 .42728 .72744 .42989 .73196 .42848 .7299 .42586 Mtetra
.7299 .42586 .73196 .42848 .73648 .42706 .73443 .42443 Mtetra
.73443 .42443 .73648 .42706 .74101 .42564 .73896 .42301 Mtetra
.73896 .42301 .74101 .42564 .74555 .42422 .74351 .42158 Mtetra
.74351 .42158 .74555 .42422 .75009 .42279 .74806 .42015 Mtetra
.74806 .42015 .75009 .42279 .75465 .42136 .75261 .41872 Mtetra
.75261 .41872 .75465 .42136 .75921 .41993 .75718 .41729 Mtetra
.75718 .41729 .75921 .41993 .76377 .4185 .76175 .41585 Mtetra
.76175 .41585 .76377 .4185 .76835 .41707 .76633 .41442 Mtetra
.76633 .41442 .76835 .41707 .77293 .41563 .77091 .41297 Mtetra
.98 .688 .379 r
.77091 .41297 .77293 .41563 .76648 .27275 .76454 .27 Mtetra
.664 .741 .908 r
.76454 .27 .76648 .27275 .77086 .27126 .76893 .26851 Mtetra
.76893 .26851 .77086 .27126 .77525 .26977 .77333 .26702 Mtetra
.77333 .26702 .77525 .26977 .77965 .26828 .77773 .26553 Mtetra
.77773 .26553 .77965 .26828 .78406 .26679 .78214 .26403 Mtetra
.78214 .26403 .78406 .26679 .78847 .2653 .78656 .26253 Mtetra
.78656 .26253 .78847 .2653 .79289 .2638 .79099 .26103 Mtetra
.79099 .26103 .79289 .2638 .79732 .2623 .79542 .25952 Mtetra
.79542 .25952 .79732 .2623 .80175 .2608 .79986 .25802 Mtetra
.79986 .25802 .80175 .2608 .80619 .25929 .8043 .25651 Mtetra
.8043 .25651 .80619 .25929 .81064 .25779 .80875 .255 Mtetra
.80875 .255 .81064 .25779 .8151 .25628 .81321 .25348 Mtetra
.81321 .25348 .8151 .25628 .81956 .25477 .81768 .25197 Mtetra
.81768 .25197 .81956 .25477 .82402 .25325 .82215 .25045 Mtetra
.82215 .25045 .82402 .25325 .8285 .25174 .82663 .24893 Mtetra
.82663 .24893 .8285 .25174 .83298 .25022 .83112 .24741 Mtetra
.83112 .24741 .83298 .25022 .83747 .2487 .83561 .24588 Mtetra
.83561 .24588 .83747 .2487 .84197 .24717 .84011 .24436 Mtetra
.84011 .24436 .84197 .24717 .84647 .24565 .84462 .24283 Mtetra
.23602 .44626 .23846 .44853 .24208 .4473 .23964 .44503 Mtetra
.23964 .44503 .24208 .4473 .24571 .44607 .24328 .44379 Mtetra
.24328 .44379 .24571 .44607 .24934 .44484 .24691 .44256 Mtetra
.24691 .44256 .24934 .44484 .25298 .4436 .25055 .44132 Mtetra
.25055 .44132 .25298 .4436 .25662 .44237 .2542 .44008 Mtetra
.2542 .44008 .25662 .44237 .26027 .44113 .25785 .43884 Mtetra
.25785 .43884 .26027 .44113 .26392 .43989 .2615 .4376 Mtetra
.2615 .4376 .26392 .43989 .26758 .43865 .26517 .43635 Mtetra
.26517 .43635 .26758 .43865 .27124 .4374 .26883 .4351 Mtetra
.26883 .4351 .27124 .4374 .27491 .43616 .2725 .43386 Mtetra
.2725 .43386 .27491 .43616 .27859 .43491 .27618 .43261 Mtetra
.27618 .43261 .27859 .43491 .28226 .43366 .27986 .43136 Mtetra
.27986 .43136 .28226 .43366 .28595 .43241 .28355 .4301 Mtetra
.28355 .4301 .28595 .43241 .28964 .43116 .28724 .42885 Mtetra
.28724 .42885 .28964 .43116 .29333 .42991 .29094 .42759 Mtetra
.29094 .42759 .29333 .42991 .29703 .42865 .29464 .42633 Mtetra
.29464 .42633 .29703 .42865 .30074 .4274 .29835 .42507 Mtetra
.29835 .42507 .30074 .4274 .30445 .42614 .30206 .42381 Mtetra
.946 .679 .5 r
.30206 .42381 .30445 .42614 .29838 .57136 .29588 .56912 Mtetra
.652 .756 .925 r
.29588 .56912 .29838 .57136 .30227 .57014 .29977 .5679 Mtetra
.29977 .5679 .30227 .57014 .30615 .56893 .30366 .56669 Mtetra
.30366 .56669 .30615 .56893 .31005 .56772 .30755 .56547 Mtetra
.30755 .56547 .31005 .56772 .31394 .5665 .31146 .56425 Mtetra
.31146 .56425 .31394 .5665 .31785 .56528 .31536 .56302 Mtetra
.31536 .56302 .31785 .56528 .32176 .56406 .31928 .5618 Mtetra
.31928 .5618 .32176 .56406 .32567 .56284 .32319 .56057 Mtetra
.32319 .56057 .32567 .56284 .32959 .56161 .32712 .55935 Mtetra
.32712 .55935 .32959 .56161 .33352 .56039 .33105 .55812 Mtetra
.33105 .55812 .33352 .56039 .33745 .55916 .33499 .55689 Mtetra
.33499 .55689 .33745 .55916 .34139 .55793 .33893 .55565 Mtetra
.33893 .55565 .34139 .55793 .34534 .5567 .34288 .55442 Mtetra
.34288 .55442 .34534 .5567 .34929 .55546 .34683 .55318 Mtetra
.34683 .55318 .34929 .55546 .35324 .55423 .35079 .55194 Mtetra
.35079 .55194 .35324 .55423 .35721 .55299 .35476 .5507 Mtetra
.35476 .5507 .35721 .55299 .36117 .55175 .35873 .54946 Mtetra
.35873 .54946 .36117 .55175 .36515 .55051 .36271 .54822 Mtetra
.36271 .54822 .36515 .55051 .36913 .54927 .36669 .54697 Mtetra
.36669 .54697 .36913 .54927 .37311 .54803 .37068 .54572 Mtetra
.37068 .54572 .37311 .54803 .3771 .54678 .37467 .54447 Mtetra
.898 .48 .122 r
.37467 .54447 .3771 .54678 .3811 .54553 .37823 .55355 Mtetra
.44 .113 .313 r
.37823 .55355 .3811 .54553 .38468 .5546 .38225 .5523 Mtetra
.651 .757 .927 r
.38225 .5523 .38468 .5546 .3887 .55336 .38627 .55105 Mtetra
.38627 .55105 .3887 .55336 .39273 .55211 .3903 .54979 Mtetra
.3903 .54979 .39273 .55211 .39676 .55085 .39434 .54854 Mtetra
.39434 .54854 .39676 .55085 .4008 .5496 .39838 .54728 Mtetra
.39838 .54728 .4008 .5496 .40594 .51751 .40243 .54602 Mtetra
.518 .266 .473 r
.40243 .54602 .40594 .51751 .40996 .51624 .40649 .54476 Mtetra
0 0 .15 r
.40649 .54476 .40996 .51624 .41398 .51497 .4116 .51262 Mtetra
.654 .754 .923 r
.4116 .51262 .41398 .51497 .41801 .5137 .41563 .51134 Mtetra
.41563 .51134 .41801 .5137 .42204 .51242 .41967 .51006 Mtetra
.41967 .51006 .42204 .51242 .42608 .51114 .42371 .50878 Mtetra
.42371 .50878 .42608 .51114 .43013 .50987 .42776 .5075 Mtetra
.42776 .5075 .43013 .50987 .43418 .50859 .43182 .50622 Mtetra
.43182 .50622 .43418 .50859 .43824 .5073 .43588 .50493 Mtetra
.43588 .50493 .43824 .5073 .4423 .50602 .43995 .50364 Mtetra
.43995 .50364 .4423 .50602 .44637 .50473 .44402 .50235 Mtetra
.44402 .50235 .44637 .50473 .45045 .50345 .4481 .50106 Mtetra
.4481 .50106 .45045 .50345 .45453 .50216 .45219 .49977 Mtetra
.45219 .49977 .45453 .50216 .45862 .50086 .45628 .49847 Mtetra
.45628 .49847 .45862 .50086 .46272 .49957 .46038 .49718 Mtetra
.96 .697 .492 r
.46038 .49718 .46272 .49957 .46906 .37028 .46682 .3678 Mtetra
.664 .741 .908 r
.46682 .3678 .46906 .37028 .47301 .36894 .47077 .36646 Mtetra
.47077 .36646 .47301 .36894 .47696 .36759 .47473 .36511 Mtetra
.47473 .36511 .47696 .36759 .48092 .36625 .4787 .36376 Mtetra
.4787 .36376 .48092 .36625 .48489 .3649 .48267 .36241 Mtetra
.48267 .36241 .48489 .3649 .48886 .36355 .48665 .36106 Mtetra
.48665 .36106 .48886 .36355 .49284 .3622 .49063 .35971 Mtetra
.49063 .35971 .49284 .3622 .49683 .36085 .49462 .35835 Mtetra
.49462 .35835 .49683 .36085 .50082 .3595 .49861 .35699 Mtetra
.49861 .35699 .50082 .3595 .50482 .35814 .50261 .35563 Mtetra
.50261 .35563 .50482 .35814 .50882 .35678 .50662 .35427 Mtetra
.50662 .35427 .50882 .35678 .51283 .35542 .51063 .35291 Mtetra
.51063 .35291 .51283 .35542 .51684 .35406 .51465 .35154 Mtetra
.51465 .35154 .51684 .35406 .52086 .3527 .51867 .35017 Mtetra
.51867 .35017 .52086 .3527 .52489 .35133 .5227 .3488 Mtetra
.827 .384 0 r
.5227 .3488 .52489 .35133 .52892 .34996 .52674 .35697 Mtetra
.422 .087 .289 r
.52674 .35697 .52892 .34996 .53298 .35813 .5308 .3556 Mtetra
.663 .742 .909 r
.5308 .3556 .53298 .35813 .53704 .35676 .53486 .35423 Mtetra
.53486 .35423 .53704 .35676 .5411 .35539 .53892 .35285 Mtetra
.53892 .35285 .5411 .35539 .54517 .35402 .54299 .35148 Mtetra
.54299 .35148 .54517 .35402 .54924 .35264 .54707 .3501 Mtetra
.54707 .3501 .54924 .35264 .55332 .35127 .55116 .34872 Mtetra
.55116 .34872 .55332 .35127 .55741 .34989 .55525 .34733 Mtetra
.55525 .34733 .55741 .34989 .5615 .3485 .55934 .34595 Mtetra
.55934 .34595 .5615 .3485 .5656 .34712 .56344 .34456 Mtetra
.56344 .34456 .5656 .34712 .5697 .34574 .56755 .34317 Mtetra
.56755 .34317 .5697 .34574 .57381 .34435 .57167 .34178 Mtetra
.57167 .34178 .57381 .34435 .57793 .34296 .57579 .34039 Mtetra
.57579 .34039 .57793 .34296 .58205 .34157 .57991 .33899 Mtetra
.57991 .33899 .58205 .34157 .58618 .34017 .58404 .33759 Mtetra
.58404 .33759 .58618 .34017 .59031 .33878 .58818 .33619 Mtetra
.58818 .33619 .59031 .33878 .59445 .33738 .59233 .33479 Mtetra
.59233 .33479 .59445 .33738 .5986 .33598 .59648 .33339 Mtetra
.971 .676 .403 r
.59648 .33339 .5986 .33598 .60275 .33458 .60504 .51529 Mtetra
.54 .315 .522 r
.60504 .51529 .60275 .33458 .61168 .51643 .60945 .51395 Mtetra
.648 .76 .931 r
.60945 .51395 .61168 .51643 .61609 .51509 .61386 .5126 Mtetra
.61386 .5126 .61609 .51509 .6205 .51374 .61829 .51125 Mtetra
.61829 .51125 .6205 .51374 .62493 .51239 .62272 .5099 Mtetra
.62272 .5099 .62493 .51239 .62936 .51104 .62715 .50855 Mtetra
.62715 .50855 .62936 .51104 .63328 .49358 .6316 .50719 Mtetra
.486 .199 .404 r
.6316 .50719 .63328 .49358 .6377 .49222 .63605 .50583 Mtetra
0 0 .156 r
.63605 .50583 .6377 .49222 .64213 .49086 .63995 .48834 Mtetra
.65 .758 .929 r
.63995 .48834 .64213 .49086 .64657 .48949 .64439 .48697 Mtetra
.64439 .48697 .64657 .48949 .65102 .48813 .64884 .4856 Mtetra
.64884 .4856 .65102 .48813 .65547 .48676 .6533 .48422 Mtetra
.6533 .48422 .65547 .48676 .65993 .48539 .65776 .48285 Mtetra
.65776 .48285 .65993 .48539 .66439 .48401 .66223 .48147 Mtetra
.66223 .48147 .66439 .48401 .66887 .48264 .66671 .48009 Mtetra
.66671 .48009 .66887 .48264 .67335 .48126 .6712 .47871 Mtetra
.6712 .47871 .67335 .48126 .67784 .47988 .67569 .47733 Mtetra
.67569 .47733 .67784 .47988 .68233 .4785 .68019 .47594 Mtetra
.68019 .47594 .68233 .4785 .68683 .47711 .6847 .47455 Mtetra
.6847 .47455 .68683 .47711 .69134 .47573 .68921 .47316 Mtetra
.977 .725 .484 r
.68921 .47316 .69134 .47573 .69393 .43715 .69183 .43456 Mtetra
.653 .755 .924 r
.69183 .43456 .69393 .43715 .6984 .43575 .6963 .43315 Mtetra
.6963 .43315 .6984 .43575 .70288 .43434 .70079 .43174 Mtetra
.70079 .43174 .70288 .43434 .70737 .43293 .70528 .43033 Mtetra
.70528 .43033 .70737 .43293 .71186 .43152 .70977 .42891 Mtetra
.70977 .42891 .71186 .43152 .71636 .43011 .71428 .4275 Mtetra
.71428 .4275 .71636 .43011 .72086 .42869 .71879 .42608 Mtetra
.71879 .42608 .72086 .42869 .72538 .42728 .72331 .42465 Mtetra
.72331 .42465 .72538 .42728 .7299 .42586 .72783 .42323 Mtetra
.72783 .42323 .7299 .42586 .73443 .42443 .73237 .4218 Mtetra
.73237 .4218 .73443 .42443 .73896 .42301 .73691 .42037 Mtetra
.73691 .42037 .73896 .42301 .74351 .42158 .74146 .41894 Mtetra
.74146 .41894 .74351 .42158 .74806 .42015 .74601 .41751 Mtetra
.74601 .41751 .74806 .42015 .75261 .41872 .75057 .41607 Mtetra
.75057 .41607 .75261 .41872 .75718 .41729 .75514 .41464 Mtetra
.75514 .41464 .75718 .41729 .76175 .41585 .75972 .4132 Mtetra
.75972 .4132 .76175 .41585 .76633 .41442 .7643 .41175 Mtetra
.98 .688 .381 r
.7643 .41175 .76633 .41442 .77091 .41297 .75821 .26874 Mtetra
.549 .335 .542 r
.75821 .26874 .77091 .41297 .76454 .27 .7626 .26725 Mtetra
.664 .741 .908 r
.7626 .26725 .76454 .27 .76893 .26851 .76699 .26576 Mtetra
.76699 .26576 .76893 .26851 .77333 .26702 .7714 .26426 Mtetra
.7714 .26426 .77333 .26702 .77773 .26553 .7758 .26276 Mtetra
.7758 .26276 .77773 .26553 .78214 .26403 .78022 .26126 Mtetra
.78022 .26126 .78214 .26403 .78656 .26253 .78464 .25976 Mtetra
.78464 .25976 .78656 .26253 .79099 .26103 .78907 .25825 Mtetra
.78907 .25825 .79099 .26103 .79542 .25952 .79351 .25674 Mtetra
.79351 .25674 .79542 .25952 .79986 .25802 .79795 .25523 Mtetra
.79795 .25523 .79986 .25802 .8043 .25651 .8024 .25372 Mtetra
.8024 .25372 .8043 .25651 .80875 .255 .80686 .2522 Mtetra
.80686 .2522 .80875 .255 .81321 .25348 .81132 .25069 Mtetra
.81132 .25069 .81321 .25348 .81768 .25197 .81579 .24917 Mtetra
.81579 .24917 .81768 .25197 .82215 .25045 .82027 .24764 Mtetra
.82027 .24764 .82215 .25045 .82663 .24893 .82476 .24612 Mtetra
.82476 .24612 .82663 .24893 .83112 .24741 .82925 .24459 Mtetra
.82925 .24459 .83112 .24741 .83561 .24588 .83375 .24306 Mtetra
.83375 .24306 .83561 .24588 .84011 .24436 .83825 .24153 Mtetra
.83825 .24153 .84011 .24436 .84462 .24283 .84276 .24 Mtetra
.23357 .44398 .23602 .44626 .23964 .44503 .2372 .44275 Mtetra
.2372 .44275 .23964 .44503 .24328 .44379 .24084 .44151 Mtetra
.24084 .44151 .24328 .44379 .24691 .44256 .24447 .44027 Mtetra
.24447 .44027 .24691 .44256 .25055 .44132 .24812 .43903 Mtetra
.24812 .43903 .25055 .44132 .2542 .44008 .25177 .43779 Mtetra
.25177 .43779 .2542 .44008 .25785 .43884 .25542 .43654 Mtetra
.25542 .43654 .25785 .43884 .2615 .4376 .25908 .4353 Mtetra
.25908 .4353 .2615 .4376 .26517 .43635 .26274 .43405 Mtetra
.26274 .43405 .26517 .43635 .26883 .4351 .26641 .4328 Mtetra
.26641 .4328 .26883 .4351 .2725 .43386 .27009 .43155 Mtetra
.27009 .43155 .2725 .43386 .27618 .43261 .27377 .43029 Mtetra
.27377 .43029 .27618 .43261 .27986 .43136 .27745 .42904 Mtetra
.27745 .42904 .27986 .43136 .28355 .4301 .28114 .42778 Mtetra
.28114 .42778 .28355 .4301 .28724 .42885 .28484 .42652 Mtetra
.28484 .42652 .28724 .42885 .29094 .42759 .28854 .42526 Mtetra
.28854 .42526 .29094 .42759 .29464 .42633 .29224 .424 Mtetra
.29224 .424 .29464 .42633 .29835 .42507 .29596 .42274 Mtetra
.945 .679 .501 r
.29596 .42274 .29835 .42507 .30206 .42381 .28949 .56809 Mtetra
.538 .312 .52 r
.28949 .56809 .30206 .42381 .29588 .56912 .29337 .56687 Mtetra
.652 .756 .925 r
.29337 .56687 .29588 .56912 .29977 .5679 .29726 .56565 Mtetra
.29726 .56565 .29977 .5679 .30366 .56669 .30116 .56443 Mtetra
.30116 .56443 .30366 .56669 .30755 .56547 .30506 .56321 Mtetra
.30506 .56321 .30755 .56547 .31146 .56425 .30896 .56199 Mtetra
.30896 .56199 .31146 .56425 .31536 .56302 .31287 .56076 Mtetra
.31287 .56076 .31536 .56302 .31928 .5618 .31679 .55954 Mtetra
.31679 .55954 .31928 .5618 .32319 .56057 .32071 .55831 Mtetra
.32071 .55831 .32319 .56057 .32712 .55935 .32464 .55708 Mtetra
.32464 .55708 .32712 .55935 .33105 .55812 .32857 .55584 Mtetra
.32857 .55584 .33105 .55812 .33499 .55689 .33251 .55461 Mtetra
.33251 .55461 .33499 .55689 .33893 .55565 .33646 .55337 Mtetra
.33646 .55337 .33893 .55565 .34288 .55442 .34041 .55213 Mtetra
.34041 .55213 .34288 .55442 .34683 .55318 .34437 .55089 Mtetra
.34437 .55089 .34683 .55318 .35079 .55194 .34833 .54965 Mtetra
.34833 .54965 .35079 .55194 .35476 .5507 .3523 .54841 Mtetra
.3523 .54841 .35476 .5507 .35873 .54946 .35628 .54716 Mtetra
.35628 .54716 .35873 .54946 .36271 .54822 .36026 .54591 Mtetra
.36026 .54591 .36271 .54822 .36669 .54697 .36424 .54467 Mtetra
.36424 .54467 .36669 .54697 .37068 .54572 .36824 .54341 Mtetra
.899 .482 .125 r
.36824 .54341 .37068 .54572 .37467 .54447 .37177 .55249 Mtetra
.439 .111 .311 r
.37177 .55249 .37467 .54447 .37823 .55355 .37579 .55124 Mtetra
.651 .757 .927 r
.37579 .55124 .37823 .55355 .38225 .5523 .37981 .54999 Mtetra
.37981 .54999 .38225 .5523 .38627 .55105 .38384 .54873 Mtetra
.38384 .54873 .38627 .55105 .3903 .54979 .38787 .54747 Mtetra
.38787 .54747 .3903 .54979 .39434 .54854 .39191 .54622 Mtetra
.39191 .54622 .39434 .54854 .39838 .54728 .39596 .54496 Mtetra
.39596 .54496 .39838 .54728 .40243 .54602 .40002 .54369 Mtetra
.40002 .54369 .40243 .54602 .40649 .54476 .40408 .54243 Mtetra
.40408 .54243 .40649 .54476 .4116 .51262 .40814 .54116 Mtetra
0 0 .15 r
.40814 .54116 .4116 .51262 .41563 .51134 .41325 .50898 Mtetra
.654 .754 .923 r
.41325 .50898 .41563 .51134 .41967 .51006 .41729 .5077 Mtetra
.41729 .5077 .41967 .51006 .42371 .50878 .42134 .50642 Mtetra
.42134 .50642 .42371 .50878 .42776 .5075 .42539 .50513 Mtetra
.42539 .50513 .42776 .5075 .43182 .50622 .42945 .50384 Mtetra
.42945 .50384 .43182 .50622 .43588 .50493 .43352 .50255 Mtetra
.43352 .50255 .43588 .50493 .43995 .50364 .43759 .50126 Mtetra
.43759 .50126 .43995 .50364 .44402 .50235 .44167 .49997 Mtetra
.44167 .49997 .44402 .50235 .4481 .50106 .44575 .49867 Mtetra
.44575 .49867 .4481 .50106 .45219 .49977 .44984 .49738 Mtetra
.44984 .49738 .45219 .49977 .45628 .49847 .45394 .49608 Mtetra
.45394 .49608 .45628 .49847 .46038 .49718 .45804 .49478 Mtetra
.96 .697 .492 r
.45804 .49478 .46038 .49718 .46682 .3678 .46457 .36532 Mtetra
.664 .741 .908 r
.46457 .36532 .46682 .3678 .47077 .36646 .46853 .36397 Mtetra
.46853 .36397 .47077 .36646 .47473 .36511 .47249 .36262 Mtetra
.47249 .36262 .47473 .36511 .4787 .36376 .47646 .36127 Mtetra
.47646 .36127 .4787 .36376 .48267 .36241 .48044 .35991 Mtetra
.48044 .35991 .48267 .36241 .48665 .36106 .48442 .35856 Mtetra
.48442 .35856 .48665 .36106 .49063 .35971 .48841 .3572 Mtetra
.48841 .3572 .49063 .35971 .49462 .35835 .4924 .35584 Mtetra
.4924 .35584 .49462 .35835 .49861 .35699 .4964 .35448 Mtetra
.4964 .35448 .49861 .35699 .50261 .35563 .5004 .35312 Mtetra
.5004 .35312 .50261 .35563 .50662 .35427 .50441 .35175 Mtetra
.50441 .35175 .50662 .35427 .51063 .35291 .50843 .35038 Mtetra
.50843 .35038 .51063 .35291 .51465 .35154 .51245 .34901 Mtetra
.51245 .34901 .51465 .35154 .51867 .35017 .51648 .34764 Mtetra
.829 .386 0 r
.51648 .34764 .51867 .35017 .5227 .3488 .5205 .35581 Mtetra
.421 .085 .287 r
.5205 .35581 .5227 .3488 .52674 .35697 .52455 .35444 Mtetra
.663 .742 .909 r
.52455 .35444 .52674 .35697 .5308 .3556 .52861 .35307 Mtetra
.52861 .35307 .5308 .3556 .53486 .35423 .53267 .35169 Mtetra
.53267 .35169 .53486 .35423 .53892 .35285 .53674 .35031 Mtetra
.53674 .35031 .53892 .35285 .54299 .35148 .54082 .34893 Mtetra
.54082 .34893 .54299 .35148 .54707 .3501 .5449 .34755 Mtetra
.5449 .34755 .54707 .3501 .55116 .34872 .54899 .34616 Mtetra
.54899 .34616 .55116 .34872 .55525 .34733 .55308 .34477 Mtetra
.55308 .34477 .55525 .34733 .55934 .34595 .55718 .34339 Mtetra
.55718 .34339 .55934 .34595 .56344 .34456 .56129 .34199 Mtetra
.56129 .34199 .56344 .34456 .56755 .34317 .5654 .3406 Mtetra
.5654 .3406 .56755 .34317 .57167 .34178 .56952 .33921 Mtetra
.56952 .33921 .57167 .34178 .57579 .34039 .57364 .33781 Mtetra
.57364 .33781 .57579 .34039 .57991 .33899 .57777 .33641 Mtetra
.57777 .33641 .57991 .33899 .58404 .33759 .58191 .33501 Mtetra
.58191 .33501 .58404 .33759 .58818 .33619 .58605 .3336 Mtetra
.58605 .3336 .58818 .33619 .59233 .33479 .5902 .3322 Mtetra
.5902 .3322 .59233 .33479 .59648 .33339 .59435 .33079 Mtetra
.971 .676 .403 r
.59435 .33079 .59648 .33339 .60504 .51529 .6028 .51281 Mtetra
.648 .76 .931 r
.6028 .51281 .60504 .51529 .60945 .51395 .60721 .51146 Mtetra
.60721 .51146 .60945 .51395 .61386 .5126 .61163 .51011 Mtetra
.61163 .51011 .61386 .5126 .61829 .51125 .61606 .50875 Mtetra
.61606 .50875 .61829 .51125 .62272 .5099 .6205 .5074 Mtetra
.6205 .5074 .62272 .5099 .62715 .50855 .62494 .50604 Mtetra
.62494 .50604 .62715 .50855 .6316 .50719 .62939 .50468 Mtetra
.62939 .50468 .6316 .50719 .63605 .50583 .63384 .50332 Mtetra
.63384 .50332 .63605 .50583 .63995 .48834 .63831 .50195 Mtetra
.485 .198 .403 r
.63831 .50195 .63995 .48834 .64439 .48697 .64278 .50059 Mtetra
0 0 .159 r
.64278 .50059 .64439 .48697 .64884 .4856 .64666 .48306 Mtetra
.65 .758 .929 r
.64666 .48306 .64884 .4856 .6533 .48422 .65112 .48168 Mtetra
.65112 .48168 .6533 .48422 .65776 .48285 .65559 .48031 Mtetra
.65559 .48031 .65776 .48285 .66223 .48147 .66007 .47892 Mtetra
.66007 .47892 .66223 .48147 .66671 .48009 .66455 .47754 Mtetra
.66455 .47754 .66671 .48009 .6712 .47871 .66904 .47616 Mtetra
.66904 .47616 .6712 .47871 .67569 .47733 .67354 .47477 Mtetra
.67354 .47477 .67569 .47733 .68019 .47594 .67804 .47338 Mtetra
.67804 .47338 .68019 .47594 .6847 .47455 .68256 .47198 Mtetra
.977 .725 .485 r
.68256 .47198 .6847 .47455 .68921 .47316 .68524 .43337 Mtetra
.56 .364 .572 r
.68524 .43337 .68921 .47316 .69183 .43456 .68972 .43196 Mtetra
.653 .755 .924 r
.68972 .43196 .69183 .43456 .6963 .43315 .6942 .43055 Mtetra
.6942 .43055 .6963 .43315 .70079 .43174 .69868 .42913 Mtetra
.69868 .42913 .70079 .43174 .70528 .43033 .70318 .42771 Mtetra
.70318 .42771 .70528 .43033 .70977 .42891 .70768 .42629 Mtetra
.70768 .42629 .70977 .42891 .71428 .4275 .71219 .42487 Mtetra
.71219 .42487 .71428 .4275 .71879 .42608 .71671 .42345 Mtetra
.71671 .42345 .71879 .42608 .72331 .42465 .72123 .42202 Mtetra
.72123 .42202 .72331 .42465 .72783 .42323 .72576 .42059 Mtetra
.72576 .42059 .72783 .42323 .73237 .4218 .7303 .41916 Mtetra
.7303 .41916 .73237 .4218 .73691 .42037 .73485 .41773 Mtetra
.73485 .41773 .73691 .42037 .74146 .41894 .7394 .4163 Mtetra
.7394 .4163 .74146 .41894 .74601 .41751 .74396 .41486 Mtetra
.74396 .41486 .74601 .41751 .75057 .41607 .74853 .41342 Mtetra
.74853 .41342 .75057 .41607 .75514 .41464 .7531 .41198 Mtetra
.7531 .41198 .75514 .41464 .75972 .4132 .75768 .41053 Mtetra
.75768 .41053 .75972 .4132 .7643 .41175 .76227 .40909 Mtetra
.98 .688 .381 r
.76227 .40909 .7643 .41175 .75821 .26874 .75626 .26599 Mtetra
.664 .741 .908 r
.75626 .26599 .75821 .26874 .7626 .26725 .76065 .26449 Mtetra
.76065 .26449 .7626 .26725 .76699 .26576 .76505 .26299 Mtetra
.76505 .26299 .76699 .26576 .7714 .26426 .76946 .26149 Mtetra
.76946 .26149 .7714 .26426 .7758 .26276 .77387 .25999 Mtetra
.77387 .25999 .7758 .26276 .78022 .26126 .77829 .25848 Mtetra
.77829 .25848 .78022 .26126 .78464 .25976 .78272 .25697 Mtetra
.78272 .25697 .78464 .25976 .78907 .25825 .78715 .25546 Mtetra
.78715 .25546 .78907 .25825 .79351 .25674 .7916 .25395 Mtetra
.7916 .25395 .79351 .25674 .79795 .25523 .79604 .25244 Mtetra
.79604 .25244 .79795 .25523 .8024 .25372 .8005 .25092 Mtetra
.8005 .25092 .8024 .25372 .80686 .2522 .80496 .2494 Mtetra
.80496 .2494 .80686 .2522 .81132 .25069 .80943 .24788 Mtetra
.80943 .24788 .81132 .25069 .81579 .24917 .8139 .24635 Mtetra
.8139 .24635 .81579 .24917 .82027 .24764 .81839 .24483 Mtetra
.81839 .24483 .82027 .24764 .82476 .24612 .82288 .2433 Mtetra
.82288 .2433 .82476 .24612 .82925 .24459 .82737 .24177 Mtetra
.82737 .24177 .82925 .24459 .83375 .24306 .83188 .24023 Mtetra
.83188 .24023 .83375 .24306 .83825 .24153 .83639 .2387 Mtetra
.83639 .2387 .83825 .24153 .84276 .24 .8409 .23716 Mtetra
.23112 .4417 .23357 .44398 .2372 .44275 .23475 .44046 Mtetra
.23475 .44046 .2372 .44275 .24084 .44151 .23839 .43922 Mtetra
.23839 .43922 .24084 .44151 .24447 .44027 .24203 .43798 Mtetra
.24203 .43798 .24447 .44027 .24812 .43903 .24568 .43673 Mtetra
.24568 .43673 .24812 .43903 .25177 .43779 .24933 .43549 Mtetra
.24933 .43549 .25177 .43779 .25542 .43654 .25299 .43424 Mtetra
.25299 .43424 .25542 .43654 .25908 .4353 .25665 .43299 Mtetra
.25665 .43299 .25908 .4353 .26274 .43405 .26032 .43174 Mtetra
.26032 .43174 .26274 .43405 .26641 .4328 .26399 .43049 Mtetra
.26399 .43049 .26641 .4328 .27009 .43155 .26767 .42923 Mtetra
.26767 .42923 .27009 .43155 .27377 .43029 .27135 .42798 Mtetra
.27135 .42798 .27377 .43029 .27745 .42904 .27504 .42672 Mtetra
.27504 .42672 .27745 .42904 .28114 .42778 .27873 .42546 Mtetra
.27873 .42546 .28114 .42778 .28484 .42652 .28243 .4242 Mtetra
.28243 .4242 .28484 .42652 .28854 .42526 .28613 .42293 Mtetra
.28613 .42293 .28854 .42526 .29224 .424 .28984 .42167 Mtetra
.28984 .42167 .29224 .424 .29596 .42274 .29356 .4204 Mtetra
.945 .679 .501 r
.29356 .4204 .29596 .42274 .28949 .56809 .28697 .56584 Mtetra
.652 .756 .925 r
.28697 .56584 .28949 .56809 .29337 .56687 .29086 .56462 Mtetra
.29086 .56462 .29337 .56687 .29726 .56565 .29475 .5634 Mtetra
.29475 .5634 .29726 .56565 .30116 .56443 .29865 .56218 Mtetra
.29865 .56218 .30116 .56443 .30506 .56321 .30255 .56095 Mtetra
.30255 .56095 .30506 .56321 .30896 .56199 .30646 .55973 Mtetra
.30646 .55973 .30896 .56199 .31287 .56076 .31037 .5585 Mtetra
.31037 .5585 .31287 .56076 .31679 .55954 .31429 .55727 Mtetra
.31429 .55727 .31679 .55954 .32071 .55831 .31822 .55603 Mtetra
.31822 .55603 .32071 .55831 .32464 .55708 .32215 .5548 Mtetra
.32215 .5548 .32464 .55708 .32857 .55584 .32609 .55356 Mtetra
.32609 .55356 .32857 .55584 .33251 .55461 .33003 .55232 Mtetra
.33003 .55232 .33251 .55461 .33646 .55337 .33398 .55108 Mtetra
.33398 .55108 .33646 .55337 .34041 .55213 .33794 .54984 Mtetra
.33794 .54984 .34041 .55213 .34437 .55089 .3419 .5486 Mtetra
.3419 .5486 .34437 .55089 .34833 .54965 .34587 .54735 Mtetra
.34587 .54735 .34833 .54965 .3523 .54841 .34984 .54611 Mtetra
.34984 .54611 .3523 .54841 .35628 .54716 .35382 .54486 Mtetra
.35382 .54486 .35628 .54716 .36026 .54591 .3578 .54361 Mtetra
.3578 .54361 .36026 .54591 .36424 .54467 .36179 .54235 Mtetra
.36179 .54235 .36424 .54467 .36824 .54341 .36579 .5411 Mtetra
.899 .482 .125 r
.36579 .5411 .36824 .54341 .37177 .55249 .36932 .55018 Mtetra
.651 .757 .927 r
.36932 .55018 .37177 .55249 .37579 .55124 .37334 .54892 Mtetra
.37334 .54892 .37579 .55124 .37981 .54999 .37736 .54767 Mtetra
.37736 .54767 .37981 .54999 .38384 .54873 .3814 .54641 Mtetra
.3814 .54641 .38384 .54873 .38787 .54747 .38544 .54515 Mtetra
.38544 .54515 .38787 .54747 .39191 .54622 .38948 .54389 Mtetra
.38948 .54389 .39191 .54622 .39596 .54496 .39353 .54262 Mtetra
.39353 .54262 .39596 .54496 .40002 .54369 .39759 .54136 Mtetra
.39759 .54136 .40002 .54369 .40408 .54243 .40165 .54009 Mtetra
.40165 .54009 .40408 .54243 .40814 .54116 .40572 .53882 Mtetra
.40572 .53882 .40814 .54116 .41325 .50898 .4098 .53755 Mtetra
.516 .264 .472 r
.4098 .53755 .41325 .50898 .41729 .5077 .41388 .53627 Mtetra
0 0 .153 r
.41388 .53627 .41729 .5077 .42134 .50642 .41895 .50404 Mtetra
.654 .754 .923 r
.41895 .50404 .42134 .50642 .42539 .50513 .42301 .50275 Mtetra
.42301 .50275 .42539 .50513 .42945 .50384 .42708 .50146 Mtetra
.42708 .50146 .42945 .50384 .43352 .50255 .43115 .50017 Mtetra
.43115 .50017 .43352 .50255 .43759 .50126 .43522 .49887 Mtetra
.43522 .49887 .43759 .50126 .44167 .49997 .4393 .49758 Mtetra
.4393 .49758 .44167 .49997 .44575 .49867 .44339 .49628 Mtetra
.44339 .49628 .44575 .49867 .44984 .49738 .44749 .49498 Mtetra
.44749 .49498 .44984 .49738 .45394 .49608 .45159 .49367 Mtetra
.45159 .49367 .45394 .49608 .45804 .49478 .45569 .49237 Mtetra
.96 .697 .492 r
.45569 .49237 .45804 .49478 .46457 .36532 .46232 .36283 Mtetra
.664 .741 .908 r
.46232 .36283 .46457 .36532 .46853 .36397 .46628 .36148 Mtetra
.46628 .36148 .46853 .36397 .47249 .36262 .47025 .36012 Mtetra
.47025 .36012 .47249 .36262 .47646 .36127 .47423 .35877 Mtetra
.47423 .35877 .47646 .36127 .48044 .35991 .4782 .35741 Mtetra
.4782 .35741 .48044 .35991 .48442 .35856 .48219 .35605 Mtetra
.48219 .35605 .48442 .35856 .48841 .3572 .48618 .35469 Mtetra
.48618 .35469 .48841 .3572 .4924 .35584 .49018 .35333 Mtetra
.49018 .35333 .4924 .35584 .4964 .35448 .49418 .35196 Mtetra
.49418 .35196 .4964 .35448 .5004 .35312 .49819 .35059 Mtetra
.49819 .35059 .5004 .35312 .50441 .35175 .5022 .34922 Mtetra
.5022 .34922 .50441 .35175 .50843 .35038 .50622 .34785 Mtetra
.50622 .34785 .50843 .35038 .51245 .34901 .51024 .34648 Mtetra
.51024 .34648 .51245 .34901 .51648 .34764 .51428 .3451 Mtetra
.51428 .3451 .51648 .34764 .5205 .35581 .51831 .34373 Mtetra
.166 .152 .596 r
.51831 .34373 .5205 .35581 .52455 .35444 .52235 .3519 Mtetra
.663 .742 .909 r
.52235 .3519 .52455 .35444 .52861 .35307 .52641 .35052 Mtetra
.52641 .35052 .52861 .35307 .53267 .35169 .53048 .34914 Mtetra
.53048 .34914 .53267 .35169 .53674 .35031 .53455 .34776 Mtetra
.53455 .34776 .53674 .35031 .54082 .34893 .53863 .34637 Mtetra
.53863 .34637 .54082 .34893 .5449 .34755 .54272 .34499 Mtetra
.54272 .34499 .5449 .34755 .54899 .34616 .54681 .3436 Mtetra
.54681 .3436 .54899 .34616 .55308 .34477 .55091 .34221 Mtetra
.55091 .34221 .55308 .34477 .55718 .34339 .55501 .34082 Mtetra
.55501 .34082 .55718 .34339 .56129 .34199 .55912 .33942 Mtetra
.55912 .33942 .56129 .34199 .5654 .3406 .56324 .33802 Mtetra
.56324 .33802 .5654 .3406 .56952 .33921 .56736 .33662 Mtetra
.56736 .33662 .56952 .33921 .57364 .33781 .57149 .33522 Mtetra
.57149 .33522 .57364 .33781 .57777 .33641 .57562 .33382 Mtetra
.57562 .33382 .57777 .33641 .58191 .33501 .57976 .33241 Mtetra
.57976 .33241 .58191 .33501 .58605 .3336 .58391 .33101 Mtetra
.58391 .33101 .58605 .3336 .5902 .3322 .58806 .3296 Mtetra
.58806 .3296 .5902 .3322 .59435 .33079 .59222 .32819 Mtetra
.971 .676 .403 r
.59222 .32819 .59435 .33079 .6028 .51281 .60056 .51032 Mtetra
.648 .76 .931 r
.60056 .51032 .6028 .51281 .60721 .51146 .60497 .50896 Mtetra
.60497 .50896 .60721 .51146 .61163 .51011 .6094 .50761 Mtetra
.6094 .50761 .61163 .51011 .61606 .50875 .61383 .50625 Mtetra
.61383 .50625 .61606 .50875 .6205 .5074 .61827 .50489 Mtetra
.61827 .50489 .6205 .5074 .62494 .50604 .62272 .50353 Mtetra
.62272 .50353 .62494 .50604 .62939 .50468 .62717 .50216 Mtetra
.62717 .50216 .62939 .50468 .63384 .50332 .63163 .5008 Mtetra
.63163 .5008 .63384 .50332 .63831 .50195 .6361 .49943 Mtetra
.6361 .49943 .63831 .50195 .64278 .50059 .64057 .49806 Mtetra
.64057 .49806 .64278 .50059 .64666 .48306 .64506 .49669 Mtetra
.484 .197 .401 r
.64506 .49669 .64666 .48306 .65112 .48168 .64955 .49531 Mtetra
0 0 .161 r
.64955 .49531 .65112 .48168 .65559 .48031 .65341 .47775 Mtetra
.65 .758 .929 r
.65341 .47775 .65559 .48031 .66007 .47892 .65789 .47637 Mtetra
.65789 .47637 .66007 .47892 .66455 .47754 .66238 .47498 Mtetra
.66238 .47498 .66455 .47754 .66904 .47616 .66688 .47359 Mtetra
.66688 .47359 .66904 .47616 .67354 .47477 .67138 .4722 Mtetra
.67138 .4722 .67354 .47477 .67804 .47338 .67589 .4708 Mtetra
.67589 .4708 .67804 .47338 .68256 .47198 .68041 .46941 Mtetra
.977 .725 .485 r
.68041 .46941 .68256 .47198 .68524 .43337 .68312 .43076 Mtetra
.653 .755 .924 r
.68312 .43076 .68524 .43337 .68972 .43196 .6876 .42935 Mtetra
.6876 .42935 .68972 .43196 .6942 .43055 .69208 .42793 Mtetra
.69208 .42793 .6942 .43055 .69868 .42913 .69658 .42651 Mtetra
.69658 .42651 .69868 .42913 .70318 .42771 .70108 .42509 Mtetra
.70108 .42509 .70318 .42771 .70768 .42629 .70558 .42367 Mtetra
.70558 .42367 .70768 .42629 .71219 .42487 .7101 .42224 Mtetra
.7101 .42224 .71219 .42487 .71671 .42345 .71462 .42081 Mtetra
.71462 .42081 .71671 .42345 .72123 .42202 .71915 .41938 Mtetra
.71915 .41938 .72123 .42202 .72576 .42059 .72368 .41795 Mtetra
.72368 .41795 .72576 .42059 .7303 .41916 .72823 .41652 Mtetra
.72823 .41652 .7303 .41916 .73485 .41773 .73278 .41508 Mtetra
.73278 .41508 .73485 .41773 .7394 .4163 .73734 .41364 Mtetra
.73734 .41364 .7394 .4163 .74396 .41486 .7419 .4122 Mtetra
.7419 .4122 .74396 .41486 .74853 .41342 .74647 .41075 Mtetra
.74647 .41075 .74853 .41342 .7531 .41198 .75105 .40931 Mtetra
.75105 .40931 .7531 .41198 .75768 .41053 .75564 .40786 Mtetra
.98 .689 .383 r
.75564 .40786 .75768 .41053 .76227 .40909 .74991 .26472 Mtetra
.548 .334 .542 r
.74991 .26472 .76227 .40909 .75626 .26599 .7543 .26322 Mtetra
.664 .741 .908 r
.7543 .26322 .75626 .26599 .76065 .26449 .7587 .26172 Mtetra
.7587 .26172 .76065 .26449 .76505 .26299 .7631 .26022 Mtetra
.7631 .26022 .76505 .26299 .76946 .26149 .76751 .25871 Mtetra
.76751 .25871 .76946 .26149 .77387 .25999 .77193 .25721 Mtetra
.77193 .25721 .77387 .25999 .77829 .25848 .77636 .2557 Mtetra
.77636 .2557 .77829 .25848 .78272 .25697 .78079 .25418 Mtetra
.78079 .25418 .78272 .25697 .78715 .25546 .78523 .25267 Mtetra
.78523 .25267 .78715 .25546 .7916 .25395 .78968 .25115 Mtetra
.78968 .25115 .7916 .25395 .79604 .25244 .79413 .24963 Mtetra
.79413 .24963 .79604 .25244 .8005 .25092 .79859 .24811 Mtetra
.79859 .24811 .8005 .25092 .80496 .2494 .80306 .24659 Mtetra
.80306 .24659 .80496 .2494 .80943 .24788 .80753 .24506 Mtetra
.80753 .24506 .80943 .24788 .8139 .24635 .81201 .24353 Mtetra
.81201 .24353 .8139 .24635 .81839 .24483 .8165 .242 Mtetra
.8165 .242 .81839 .24483 .82288 .2433 .82099 .24047 Mtetra
.82099 .24047 .82288 .2433 .82737 .24177 .82549 .23893 Mtetra
.82549 .23893 .82737 .24177 .83188 .24023 .83 .2374 Mtetra
.83 .2374 .83188 .24023 .83639 .2387 .83452 .23586 Mtetra
.83452 .23586 .83639 .2387 .8409 .23716 .83904 .23431 Mtetra
.22866 .43941 .23112 .4417 .23475 .44046 .2323 .43817 Mtetra
.2323 .43817 .23475 .44046 .23839 .43922 .23594 .43693 Mtetra
.23594 .43693 .23839 .43922 .24203 .43798 .23958 .43568 Mtetra
.23958 .43568 .24203 .43798 .24568 .43673 .24323 .43443 Mtetra
.24323 .43443 .24568 .43673 .24933 .43549 .24689 .43318 Mtetra
.24689 .43318 .24933 .43549 .25299 .43424 .25055 .43193 Mtetra
.25055 .43193 .25299 .43424 .25665 .43299 .25421 .43068 Mtetra
.25421 .43068 .25665 .43299 .26032 .43174 .25788 .42943 Mtetra
.25788 .42943 .26032 .43174 .26399 .43049 .26156 .42817 Mtetra
.26156 .42817 .26399 .43049 .26767 .42923 .26524 .42691 Mtetra
.26524 .42691 .26767 .42923 .27135 .42798 .26893 .42565 Mtetra
.26893 .42565 .27135 .42798 .27504 .42672 .27262 .42439 Mtetra
.27262 .42439 .27504 .42672 .27873 .42546 .27631 .42313 Mtetra
.27631 .42313 .27873 .42546 .28243 .4242 .28001 .42186 Mtetra
.28001 .42186 .28243 .4242 .28613 .42293 .28372 .4206 Mtetra
.28372 .4206 .28613 .42293 .28984 .42167 .28743 .41933 Mtetra
.28743 .41933 .28984 .42167 .29356 .4204 .29115 .41806 Mtetra
.945 .679 .501 r
.29115 .41806 .29356 .4204 .28697 .56584 .28445 .56359 Mtetra
.652 .756 .925 r
.28445 .56359 .28697 .56584 .29086 .56462 .28834 .56237 Mtetra
.28834 .56237 .29086 .56462 .29475 .5634 .29223 .56114 Mtetra
.29223 .56114 .29475 .5634 .29865 .56218 .29613 .55991 Mtetra
.29613 .55991 .29865 .56218 .30255 .56095 .30004 .55869 Mtetra
.30004 .55869 .30255 .56095 .30646 .55973 .30395 .55746 Mtetra
.30395 .55746 .30646 .55973 .31037 .5585 .30787 .55622 Mtetra
.30787 .55622 .31037 .5585 .31429 .55727 .31179 .55499 Mtetra
.31179 .55499 .31429 .55727 .31822 .55603 .31572 .55375 Mtetra
.31572 .55375 .31822 .55603 .32215 .5548 .31966 .55252 Mtetra
.31966 .55252 .32215 .5548 .32609 .55356 .3236 .55128 Mtetra
.3236 .55128 .32609 .55356 .33003 .55232 .32755 .55003 Mtetra
.32755 .55003 .33003 .55232 .33398 .55108 .3315 .54879 Mtetra
.3315 .54879 .33398 .55108 .33794 .54984 .33546 .54755 Mtetra
.33546 .54755 .33794 .54984 .3419 .5486 .33942 .5463 Mtetra
.33942 .5463 .3419 .5486 .34587 .54735 .34339 .54505 Mtetra
.34339 .54505 .34587 .54735 .34984 .54611 .34737 .5438 Mtetra
.34737 .5438 .34984 .54611 .35382 .54486 .35135 .54255 Mtetra
.35135 .54255 .35382 .54486 .3578 .54361 .35534 .54129 Mtetra
.35534 .54129 .3578 .54361 .36179 .54235 .35934 .54004 Mtetra
.9 .483 .129 r
.35934 .54004 .36179 .54235 .36579 .5411 .36284 .54912 Mtetra
.437 .108 .308 r
.36284 .54912 .36579 .5411 .36932 .55018 .36686 .54786 Mtetra
.651 .757 .927 r
.36686 .54786 .36932 .55018 .37334 .54892 .37088 .5466 Mtetra
.37088 .5466 .37334 .54892 .37736 .54767 .37491 .54534 Mtetra
.37491 .54534 .37736 .54767 .3814 .54641 .37895 .54408 Mtetra
.37895 .54408 .3814 .54641 .38544 .54515 .38299 .54282 Mtetra
.38299 .54282 .38544 .54515 .38948 .54389 .38704 .54155 Mtetra
.38704 .54155 .38948 .54389 .39353 .54262 .3911 .54028 Mtetra
.3911 .54028 .39353 .54262 .39759 .54136 .39516 .53901 Mtetra
.39516 .53901 .39759 .54136 .40165 .54009 .39922 .53774 Mtetra
.39922 .53774 .40165 .54009 .40572 .53882 .4033 .53647 Mtetra
.4033 .53647 .40572 .53882 .4098 .53755 .40738 .53519 Mtetra
.40738 .53519 .4098 .53755 .41388 .53627 .41146 .53392 Mtetra
.41146 .53392 .41388 .53627 .41895 .50404 .41556 .53264 Mtetra
0 0 .153 r
.41556 .53264 .41895 .50404 .42301 .50275 .42063 .50037 Mtetra
.654 .754 .923 r
.42063 .50037 .42301 .50275 .42708 .50146 .42469 .49907 Mtetra
.42469 .49907 .42708 .50146 .43115 .50017 .42877 .49778 Mtetra
.42877 .49778 .43115 .50017 .43522 .49887 .43285 .49648 Mtetra
.43285 .49648 .43522 .49887 .4393 .49758 .43693 .49518 Mtetra
.43693 .49518 .4393 .49758 .44339 .49628 .44102 .49387 Mtetra
.44102 .49387 .44339 .49628 .44749 .49498 .44512 .49257 Mtetra
.44512 .49257 .44749 .49498 .45159 .49367 .44923 .49126 Mtetra
.44923 .49126 .45159 .49367 .45569 .49237 .45334 .48995 Mtetra
.96 .697 .492 r
.45334 .48995 .45569 .49237 .46232 .36283 .46007 .36033 Mtetra
.664 .741 .908 r
.46007 .36033 .46232 .36283 .46628 .36148 .46403 .35898 Mtetra
.46403 .35898 .46628 .36148 .47025 .36012 .468 .35762 Mtetra
.468 .35762 .47025 .36012 .47423 .35877 .47198 .35626 Mtetra
.47198 .35626 .47423 .35877 .4782 .35741 .47596 .3549 Mtetra
.47596 .3549 .4782 .35741 .48219 .35605 .47995 .35354 Mtetra
.47995 .35354 .48219 .35605 .48618 .35469 .48395 .35217 Mtetra
.48395 .35217 .48618 .35469 .49018 .35333 .48795 .3508 Mtetra
.48795 .3508 .49018 .35333 .49418 .35196 .49195 .34943 Mtetra
.49195 .34943 .49418 .35196 .49819 .35059 .49596 .34806 Mtetra
.49596 .34806 .49819 .35059 .5022 .34922 .49998 .34669 Mtetra
.49998 .34669 .5022 .34922 .50622 .34785 .504 .34532 Mtetra
.504 .34532 .50622 .34785 .51024 .34648 .50803 .34394 Mtetra
.50803 .34394 .51024 .34648 .51428 .3451 .51207 .34256 Mtetra
.51207 .34256 .51428 .3451 .51831 .34373 .51611 .34118 Mtetra
.827 .384 0 r
.51611 .34118 .51831 .34373 .52235 .3519 .52014 .34935 Mtetra
.663 .742 .909 r
.52014 .34935 .52235 .3519 .52641 .35052 .52421 .34797 Mtetra
.52421 .34797 .52641 .35052 .53048 .34914 .52828 .34659 Mtetra
.52828 .34659 .53048 .34914 .53455 .34776 .53236 .3452 Mtetra
.53236 .3452 .53455 .34776 .53863 .34637 .53644 .34381 Mtetra
.53644 .34381 .53863 .34637 .54272 .34499 .54053 .34242 Mtetra
.54053 .34242 .54272 .34499 .54681 .3436 .54463 .34103 Mtetra
.54463 .34103 .54681 .3436 .55091 .34221 .54873 .33964 Mtetra
.54873 .33964 .55091 .34221 .55501 .34082 .55284 .33824 Mtetra
.55284 .33824 .55501 .34082 .55912 .33942 .55695 .33684 Mtetra
.55695 .33684 .55912 .33942 .56324 .33802 .56107 .33544 Mtetra
.56107 .33544 .56324 .33802 .56736 .33662 .5652 .33404 Mtetra
.5652 .33404 .56736 .33662 .57149 .33522 .56933 .33263 Mtetra
.56933 .33263 .57149 .33522 .57562 .33382 .57347 .33122 Mtetra
.57347 .33122 .57562 .33382 .57976 .33241 .57761 .32981 Mtetra
.57761 .32981 .57976 .33241 .58391 .33101 .58176 .3284 Mtetra
.58176 .3284 .58391 .33101 .58806 .3296 .58592 .32699 Mtetra
.971 .676 .405 r
.58592 .32699 .58806 .3296 .59222 .32819 .59389 .50917 Mtetra
.538 .312 .521 r
.59389 .50917 .59222 .32819 .60056 .51032 .5983 .50782 Mtetra
.648 .76 .931 r
.5983 .50782 .60056 .51032 .60497 .50896 .60273 .50646 Mtetra
.60273 .50646 .60497 .50896 .6094 .50761 .60716 .5051 Mtetra
.60716 .5051 .6094 .50761 .61383 .50625 .61159 .50374 Mtetra
.61159 .50374 .61383 .50625 .61827 .50489 .61604 .50237 Mtetra
.61604 .50237 .61827 .50489 .62272 .50353 .62049 .50101 Mtetra
.62049 .50101 .62272 .50353 .62717 .50216 .62495 .49964 Mtetra
.62495 .49964 .62717 .50216 .63163 .5008 .62941 .49827 Mtetra
.62941 .49827 .63163 .5008 .6361 .49943 .63389 .4969 Mtetra
.63389 .4969 .6361 .49943 .64057 .49806 .63837 .49552 Mtetra
.63837 .49552 .64057 .49806 .64506 .49669 .64285 .49415 Mtetra
.64285 .49415 .64506 .49669 .64955 .49531 .64735 .49277 Mtetra
.64735 .49277 .64955 .49531 .65341 .47775 .65185 .49139 Mtetra
.483 .196 .4 r
.65185 .49139 .65341 .47775 .65789 .47637 .65636 .49 Mtetra
0 0 .164 r
.65636 .49 .65789 .47637 .66238 .47498 .66021 .47241 Mtetra
.65 .758 .929 r
.66021 .47241 .66238 .47498 .66688 .47359 .66471 .47102 Mtetra
.66471 .47102 .66688 .47359 .67138 .4722 .66921 .46962 Mtetra
.66921 .46962 .67138 .4722 .67589 .4708 .67373 .46823 Mtetra
.977 .725 .487 r
.67373 .46823 .67589 .4708 .68041 .46941 .67651 .42957 Mtetra
.56 .363 .571 r
.67651 .42957 .68041 .46941 .68312 .43076 .68099 .42815 Mtetra
.653 .755 .924 r
.68099 .42815 .68312 .43076 .6876 .42935 .68547 .42673 Mtetra
.68547 .42673 .6876 .42935 .69208 .42793 .68997 .42531 Mtetra
.68997 .42531 .69208 .42793 .69658 .42651 .69446 .42389 Mtetra
.69446 .42389 .69658 .42651 .70108 .42509 .69897 .42246 Mtetra
.69897 .42246 .70108 .42509 .70558 .42367 .70348 .42103 Mtetra
.70348 .42103 .70558 .42367 .7101 .42224 .708 .4196 Mtetra
.708 .4196 .7101 .42224 .71462 .42081 .71253 .41817 Mtetra
.71253 .41817 .71462 .42081 .71915 .41938 .71706 .41674 Mtetra
.71706 .41674 .71915 .41938 .72368 .41795 .7216 .4153 Mtetra
.7216 .4153 .72368 .41795 .72823 .41652 .72615 .41386 Mtetra
.72615 .41386 .72823 .41652 .73278 .41508 .7307 .41242 Mtetra
.7307 .41242 .73278 .41508 .73734 .41364 .73527 .41098 Mtetra
.73527 .41098 .73734 .41364 .7419 .4122 .73984 .40953 Mtetra
.73984 .40953 .7419 .4122 .74647 .41075 .74441 .40808 Mtetra
.74441 .40808 .74647 .41075 .75105 .40931 .749 .40663 Mtetra
.749 .40663 .75105 .40931 .75564 .40786 .75359 .40518 Mtetra
.98 .689 .383 r
.75359 .40518 .75564 .40786 .74991 .26472 .74794 .26195 Mtetra
.664 .741 .908 r
.74794 .26195 .74991 .26472 .7543 .26322 .75234 .26045 Mtetra
.75234 .26045 .7543 .26322 .7587 .26172 .75674 .25894 Mtetra
.75674 .25894 .7587 .26172 .7631 .26022 .76115 .25744 Mtetra
.76115 .25744 .7631 .26022 .76751 .25871 .76557 .25593 Mtetra
.76557 .25593 .76751 .25871 .77193 .25721 .76999 .25442 Mtetra
.76999 .25442 .77193 .25721 .77636 .2557 .77442 .2529 Mtetra
.77442 .2529 .77636 .2557 .78079 .25418 .77886 .25139 Mtetra
.77886 .25139 .78079 .25418 .78523 .25267 .7833 .24987 Mtetra
.7833 .24987 .78523 .25267 .78968 .25115 .78775 .24835 Mtetra
.78775 .24835 .78968 .25115 .79413 .24963 .79221 .24682 Mtetra
.79221 .24682 .79413 .24963 .79859 .24811 .79667 .2453 Mtetra
.79667 .2453 .79859 .24811 .80306 .24659 .80115 .24377 Mtetra
.80115 .24377 .80306 .24659 .80753 .24506 .80562 .24224 Mtetra
.80562 .24224 .80753 .24506 .81201 .24353 .81011 .24071 Mtetra
.81011 .24071 .81201 .24353 .8165 .242 .8146 .23917 Mtetra
.8146 .23917 .8165 .242 .82099 .24047 .8191 .23763 Mtetra
.8191 .23763 .82099 .24047 .82549 .23893 .82361 .23609 Mtetra
.82361 .23609 .82549 .23893 .83 .2374 .82812 .23455 Mtetra
.82812 .23455 .83 .2374 .83452 .23586 .83264 .23301 Mtetra
.83264 .23301 .83452 .23586 .83904 .23431 .83717 .23146 Mtetra
.2262 .43712 .22866 .43941 .2323 .43817 .22984 .43587 Mtetra
.22984 .43587 .2323 .43817 .23594 .43693 .23348 .43462 Mtetra
.23348 .43462 .23594 .43693 .23958 .43568 .23713 .43338 Mtetra
.23713 .43338 .23958 .43568 .24323 .43443 .24078 .43213 Mtetra
.24078 .43213 .24323 .43443 .24689 .43318 .24444 .43087 Mtetra
.24444 .43087 .24689 .43318 .25055 .43193 .2481 .42962 Mtetra
.2481 .42962 .25055 .43193 .25421 .43068 .25177 .42836 Mtetra
.25177 .42836 .25421 .43068 .25788 .42943 .25544 .42711 Mtetra
.25544 .42711 .25788 .42943 .26156 .42817 .25912 .42585 Mtetra
.25912 .42585 .26156 .42817 .26524 .42691 .26281 .42459 Mtetra
.26281 .42459 .26524 .42691 .26893 .42565 .26649 .42332 Mtetra
.26649 .42332 .26893 .42565 .27262 .42439 .27019 .42206 Mtetra
.27019 .42206 .27262 .42439 .27631 .42313 .27389 .42079 Mtetra
.27389 .42079 .27631 .42313 .28001 .42186 .27759 .41952 Mtetra
.27759 .41952 .28001 .42186 .28372 .4206 .2813 .41825 Mtetra
.526 .02 0 r
.2813 .41825 .28372 .4206 .28743 .41933 .28467 .42167 Mtetra
.124 0 0 r
.28467 .42167 .28743 .41933 .29115 .41806 .2884 .4204 Mtetra
.934 .662 .501 r
.2884 .4204 .29115 .41806 .28445 .56359 .28518 .51588 Mtetra
.556 .354 .562 r
.28518 .51588 .28445 .56359 .28834 .56237 .28902 .51464 Mtetra
.28902 .51464 .28834 .56237 .29223 .56114 .29287 .51339 Mtetra
.29287 .51339 .29223 .56114 .29613 .55991 .29672 .51214 Mtetra
.29672 .51214 .29613 .55991 .30004 .55869 .30058 .5109 Mtetra
.30058 .5109 .30004 .55869 .30395 .55746 .30445 .50965 Mtetra
.30445 .50965 .30395 .55746 .30787 .55622 .30832 .50839 Mtetra
0 0 .313 r
.30832 .50839 .30787 .55622 .31179 .55499 .30928 .55271 Mtetra
.652 .756 .925 r
.30928 .55271 .31179 .55499 .31572 .55375 .31322 .55147 Mtetra
.31322 .55147 .31572 .55375 .31966 .55252 .31716 .55023 Mtetra
.31716 .55023 .31966 .55252 .3236 .55128 .3211 .54898 Mtetra
.3211 .54898 .3236 .55128 .32755 .55003 .32505 .54774 Mtetra
.32505 .54774 .32755 .55003 .3315 .54879 .32901 .54649 Mtetra
.32901 .54649 .3315 .54879 .33546 .54755 .33297 .54524 Mtetra
.33297 .54524 .33546 .54755 .33942 .5463 .33694 .54399 Mtetra
.33694 .54399 .33942 .5463 .34339 .54505 .34091 .54274 Mtetra
.34091 .54274 .34339 .54505 .34737 .5438 .34489 .54149 Mtetra
.34489 .54149 .34737 .5438 .35135 .54255 .34888 .54023 Mtetra
.34888 .54023 .35135 .54255 .35534 .54129 .35287 .53897 Mtetra
.9 .484 .132 r
.35287 .53897 .35534 .54129 .35934 .54004 .35635 .54805 Mtetra
.436 .106 .307 r
.35635 .54805 .35934 .54004 .36284 .54912 .36037 .5468 Mtetra
.651 .757 .927 r
.36037 .5468 .36284 .54912 .36686 .54786 .36439 .54554 Mtetra
.36439 .54554 .36686 .54786 .37088 .5466 .36842 .54428 Mtetra
.36842 .54428 .37088 .5466 .37491 .54534 .37245 .54301 Mtetra
.37245 .54301 .37491 .54534 .37895 .54408 .37649 .54175 Mtetra
.37649 .54175 .37895 .54408 .38299 .54282 .38054 .54048 Mtetra
.38054 .54048 .38299 .54282 .38704 .54155 .38459 .53921 Mtetra
.38459 .53921 .38704 .54155 .3911 .54028 .38865 .53794 Mtetra
.38865 .53794 .3911 .54028 .39516 .53901 .39272 .53667 Mtetra
.39272 .53667 .39516 .53901 .39922 .53774 .39679 .53539 Mtetra
.39679 .53539 .39922 .53774 .4033 .53647 .40087 .53411 Mtetra
.40087 .53411 .4033 .53647 .40738 .53519 .40495 .53283 Mtetra
.40495 .53283 .40738 .53519 .41146 .53392 .40904 .53155 Mtetra
.40904 .53155 .41146 .53392 .41556 .53264 .41314 .53027 Mtetra
.41314 .53027 .41556 .53264 .42063 .50037 .41724 .52899 Mtetra
.515 .262 .47 r
.41724 .52899 .42063 .50037 .42469 .49907 .42135 .5277 Mtetra
0 0 .155 r
.42135 .5277 .42469 .49907 .42877 .49778 .42638 .49538 Mtetra
.654 .754 .923 r
.42638 .49538 .42877 .49778 .43285 .49648 .43047 .49407 Mtetra
.43047 .49407 .43285 .49648 .43693 .49518 .43456 .49277 Mtetra
.43456 .49277 .43693 .49518 .44102 .49387 .43865 .49146 Mtetra
.43865 .49146 .44102 .49387 .44512 .49257 .44275 .49016 Mtetra
.44275 .49016 .44512 .49257 .44923 .49126 .44686 .48885 Mtetra
.44686 .48885 .44923 .49126 .45334 .48995 .45098 .48753 Mtetra
.96 .697 .492 r
.45098 .48753 .45334 .48995 .46007 .36033 .45781 .35783 Mtetra
.664 .741 .908 r
.45781 .35783 .46007 .36033 .46403 .35898 .46177 .35647 Mtetra
.46177 .35647 .46403 .35898 .468 .35762 .46575 .35511 Mtetra
.46575 .35511 .468 .35762 .47198 .35626 .46973 .35375 Mtetra
.46973 .35375 .47198 .35626 .47596 .3549 .47372 .35238 Mtetra
.47372 .35238 .47596 .3549 .47995 .35354 .47771 .35101 Mtetra
.47771 .35101 .47995 .35354 .48395 .35217 .48171 .34965 Mtetra
.48171 .34965 .48395 .35217 .48795 .3508 .48571 .34827 Mtetra
.48571 .34827 .48795 .3508 .49195 .34943 .48972 .3469 Mtetra
.48972 .3469 .49195 .34943 .49596 .34806 .49373 .34553 Mtetra
.49373 .34553 .49596 .34806 .49998 .34669 .49776 .34415 Mtetra
.49776 .34415 .49998 .34669 .504 .34532 .50178 .34277 Mtetra
.50178 .34277 .504 .34532 .50803 .34394 .50582 .34139 Mtetra
.50582 .34139 .50803 .34394 .51207 .34256 .50986 .34001 Mtetra
.50986 .34001 .51207 .34256 .51611 .34118 .5139 .33862 Mtetra
.5139 .33862 .51611 .34118 .52014 .34935 .51795 .33724 Mtetra
.164 .15 .595 r
.51795 .33724 .52014 .34935 .52421 .34797 .522 .34542 Mtetra
.663 .742 .909 r
.522 .34542 .52421 .34797 .52828 .34659 .52608 .34403 Mtetra
.52608 .34403 .52828 .34659 .53236 .3452 .53016 .34264 Mtetra
.53016 .34264 .53236 .3452 .53644 .34381 .53425 .34124 Mtetra
.53425 .34124 .53644 .34381 .54053 .34242 .53834 .33985 Mtetra
.53834 .33985 .54053 .34242 .54463 .34103 .54244 .33845 Mtetra
.54244 .33845 .54463 .34103 .54873 .33964 .54654 .33706 Mtetra
.54654 .33706 .54873 .33964 .55284 .33824 .55066 .33565 Mtetra
.55066 .33565 .55284 .33824 .55695 .33684 .55477 .33425 Mtetra
.55477 .33425 .55695 .33684 .56107 .33544 .5589 .33285 Mtetra
.5589 .33285 .56107 .33544 .5652 .33404 .56303 .33144 Mtetra
.56303 .33144 .5652 .33404 .56933 .33263 .56717 .33003 Mtetra
.56717 .33003 .56933 .33263 .57347 .33122 .57131 .32862 Mtetra
.57131 .32862 .57347 .33122 .57761 .32981 .57546 .32721 Mtetra
.57546 .32721 .57761 .32981 .58176 .3284 .57961 .32579 Mtetra
.57961 .32579 .58176 .3284 .58592 .32699 .58377 .32437 Mtetra
.971 .676 .405 r
.58377 .32437 .58592 .32699 .59389 .50917 .59162 .50667 Mtetra
.648 .76 .931 r
.59162 .50667 .59389 .50917 .5983 .50782 .59605 .50531 Mtetra
.59605 .50531 .5983 .50782 .60273 .50646 .60047 .50395 Mtetra
.60047 .50395 .60273 .50646 .60716 .5051 .60491 .50258 Mtetra
.60491 .50258 .60716 .5051 .61159 .50374 .60935 .50122 Mtetra
.60935 .50122 .61159 .50374 .61604 .50237 .6138 .49985 Mtetra
.6138 .49985 .61604 .50237 .62049 .50101 .61825 .49848 Mtetra
.61825 .49848 .62049 .50101 .62495 .49964 .62272 .49711 Mtetra
.62272 .49711 .62495 .49964 .62941 .49827 .62719 .49574 Mtetra
.62719 .49574 .62941 .49827 .63389 .4969 .63167 .49436 Mtetra
.63167 .49436 .63389 .4969 .63837 .49552 .63615 .49298 Mtetra
.63615 .49298 .63837 .49552 .64285 .49415 .64064 .4916 Mtetra
.64064 .4916 .64285 .49415 .64735 .49277 .64514 .49022 Mtetra
.64514 .49022 .64735 .49277 .65185 .49139 .64965 .48883 Mtetra
.64965 .48883 .65185 .49139 .65636 .49 .65416 .48745 Mtetra
.65416 .48745 .65636 .49 .66021 .47241 .65868 .48606 Mtetra
.482 .194 .399 r
.65868 .48606 .66021 .47241 .66471 .47102 .66321 .48466 Mtetra
0 0 .166 r
.66321 .48466 .66471 .47102 .66921 .46962 .66704 .46704 Mtetra
.977 .72 .478 r
.66704 .46704 .66921 .46962 .67373 .46823 .66967 .42311 Mtetra
.557 .358 .566 r
.66967 .42311 .67373 .46823 .67651 .42957 .67413 .42169 Mtetra
.614 .515 .718 r
.67413 .42169 .67651 .42957 .68099 .42815 .67861 .42027 Mtetra
.67861 .42027 .68099 .42815 .68547 .42673 .68309 .41885 Mtetra
.68309 .41885 .68547 .42673 .68997 .42531 .68758 .41742 Mtetra
.326 .334 .715 r
.68758 .41742 .68997 .42531 .69446 .42389 .69234 .42125 Mtetra
.653 .755 .924 r
.69234 .42125 .69446 .42389 .69897 .42246 .69685 .41982 Mtetra
.69685 .41982 .69897 .42246 .70348 .42103 .70137 .41839 Mtetra
.70137 .41839 .70348 .42103 .708 .4196 .70589 .41696 Mtetra
.70589 .41696 .708 .4196 .71253 .41817 .71043 .41552 Mtetra
.71043 .41552 .71253 .41817 .71706 .41674 .71496 .41408 Mtetra
.71496 .41408 .71706 .41674 .7216 .4153 .71951 .41264 Mtetra
.71951 .41264 .7216 .4153 .72615 .41386 .72406 .4112 Mtetra
.72406 .4112 .72615 .41386 .7307 .41242 .72862 .40975 Mtetra
.72862 .40975 .7307 .41242 .73527 .41098 .73319 .40831 Mtetra
.73319 .40831 .73527 .41098 .73984 .40953 .73777 .40685 Mtetra
.73777 .40685 .73984 .40953 .74441 .40808 .74235 .4054 Mtetra
.74235 .4054 .74441 .40808 .749 .40663 .74694 .40395 Mtetra
.979 .689 .385 r
.74694 .40395 .749 .40663 .75359 .40518 .74157 .26068 Mtetra
.547 .332 .541 r
.74157 .26068 .75359 .40518 .74794 .26195 .74597 .25918 Mtetra
.664 .741 .908 r
.74597 .25918 .74794 .26195 .75234 .26045 .75037 .25767 Mtetra
.75037 .25767 .75234 .26045 .75674 .25894 .75477 .25616 Mtetra
.75477 .25616 .75674 .25894 .76115 .25744 .75919 .25465 Mtetra
.75919 .25465 .76115 .25744 .76557 .25593 .76361 .25314 Mtetra
.76361 .25314 .76557 .25593 .76999 .25442 .76804 .25162 Mtetra
.76804 .25162 .76999 .25442 .77442 .2529 .77247 .2501 Mtetra
.77247 .2501 .77442 .2529 .77886 .25139 .77692 .24858 Mtetra
.77692 .24858 .77886 .25139 .7833 .24987 .78137 .24706 Mtetra
.78137 .24706 .7833 .24987 .78775 .24835 .78582 .24553 Mtetra
.78582 .24553 .78775 .24835 .79221 .24682 .79028 .244 Mtetra
.79028 .244 .79221 .24682 .79667 .2453 .79475 .24247 Mtetra
.79475 .24247 .79667 .2453 .80115 .24377 .79923 .24094 Mtetra
.79923 .24094 .80115 .24377 .80562 .24224 .80371 .23941 Mtetra
.80371 .23941 .80562 .24224 .81011 .24071 .8082 .23787 Mtetra
.8082 .23787 .81011 .24071 .8146 .23917 .8127 .23633 Mtetra
.8127 .23633 .8146 .23917 .8191 .23763 .81721 .23479 Mtetra
.81721 .23479 .8191 .23763 .82361 .23609 .82172 .23324 Mtetra
.82172 .23324 .82361 .23609 .82812 .23455 .82624 .2317 Mtetra
.82624 .2317 .82812 .23455 .83264 .23301 .83076 .23015 Mtetra
.83076 .23015 .83264 .23301 .83717 .23146 .83529 .22859 Mtetra
.22373 .43482 .2262 .43712 .22984 .43587 .22737 .43357 Mtetra
.22737 .43357 .22984 .43587 .23348 .43462 .23102 .43232 Mtetra
.23102 .43232 .23348 .43462 .23713 .43338 .23467 .43107 Mtetra
.23467 .43107 .23713 .43338 .24078 .43213 .23832 .42981 Mtetra
.23832 .42981 .24078 .43213 .24444 .43087 .24198 .42856 Mtetra
.24198 .42856 .24444 .43087 .2481 .42962 .24565 .4273 Mtetra
.24565 .4273 .2481 .42962 .25177 .42836 .24932 .42604 Mtetra
.24932 .42604 .25177 .42836 .25544 .42711 .253 .42478 Mtetra
.253 .42478 .25544 .42711 .25912 .42585 .25668 .42352 Mtetra
.25668 .42352 .25912 .42585 .26281 .42459 .26037 .42225 Mtetra
.26037 .42225 .26281 .42459 .26649 .42332 .26406 .42099 Mtetra
.26406 .42099 .26649 .42332 .27019 .42206 .26775 .41972 Mtetra
.537 .029 0 r
.26775 .41972 .27019 .42206 .27389 .42079 .27109 .42313 Mtetra
.121 0 0 r
.27109 .42313 .27389 .42079 .27759 .41952 .2748 .42186 Mtetra
.2748 .42186 .27759 .41952 .2813 .41825 .27852 .42059 Mtetra
.27852 .42059 .2813 .41825 .28467 .42167 .28224 .41932 Mtetra
.663 .742 .908 r
.28224 .41932 .28467 .42167 .2884 .4204 .28597 .41804 Mtetra
.28597 .41804 .2884 .4204 .28518 .51588 .28971 .41677 Mtetra
0 0 .25 r
.28971 .41677 .28518 .51588 .28902 .51464 .28652 .51234 Mtetra
.656 .751 .92 r
.28652 .51234 .28902 .51464 .29287 .51339 .29037 .51109 Mtetra
.29037 .51109 .29287 .51339 .29672 .51214 .29423 .50984 Mtetra
.29423 .50984 .29672 .51214 .30058 .5109 .29809 .50859 Mtetra
.29809 .50859 .30058 .5109 .30445 .50965 .30196 .50733 Mtetra
.30196 .50733 .30445 .50965 .30832 .50839 .30584 .50608 Mtetra
.30584 .50608 .30832 .50839 .30928 .55271 .30972 .50482 Mtetra
.555 .354 .562 r
.30972 .50482 .30928 .55271 .31322 .55147 .3136 .50356 Mtetra
.3136 .50356 .31322 .55147 .31716 .55023 .31749 .5023 Mtetra
.31749 .5023 .31716 .55023 .3211 .54898 .32139 .50103 Mtetra
.32139 .50103 .3211 .54898 .32505 .54774 .32529 .49977 Mtetra
.32529 .49977 .32505 .54774 .32901 .54649 .3292 .4985 Mtetra
.3292 .4985 .32901 .54649 .33297 .54524 .33312 .49723 Mtetra
.33312 .49723 .33297 .54524 .33694 .54399 .33704 .49596 Mtetra
.33704 .49596 .33694 .54399 .34091 .54274 .34096 .49469 Mtetra
.34096 .49469 .34091 .54274 .34489 .54149 .34489 .49342 Mtetra
.34489 .49342 .34489 .54149 .34888 .54023 .34883 .49214 Mtetra
.34883 .49214 .34888 .54023 .35287 .53897 .35277 .49086 Mtetra
0 0 .217 r
.35277 .49086 .35287 .53897 .35635 .54805 .35387 .54573 Mtetra
.651 .757 .927 r
.35387 .54573 .35635 .54805 .36037 .5468 .35789 .54447 Mtetra
.35789 .54447 .36037 .5468 .36439 .54554 .36192 .54321 Mtetra
.36192 .54321 .36439 .54554 .36842 .54428 .36595 .54194 Mtetra
.36595 .54194 .36842 .54428 .37245 .54301 .36999 .54067 Mtetra
.36999 .54067 .37245 .54301 .37649 .54175 .37403 .53941 Mtetra
.37403 .53941 .37649 .54175 .38054 .54048 .37808 .53813 Mtetra
.37808 .53813 .38054 .54048 .38459 .53921 .38214 .53686 Mtetra
.38214 .53686 .38459 .53921 .38865 .53794 .3862 .53559 Mtetra
.3862 .53559 .38865 .53794 .39272 .53667 .39027 .53431 Mtetra
.39027 .53431 .39272 .53667 .39679 .53539 .39435 .53303 Mtetra
.39435 .53303 .39679 .53539 .40087 .53411 .39843 .53175 Mtetra
.39843 .53175 .40087 .53411 .40495 .53283 .40252 .53047 Mtetra
.40252 .53047 .40495 .53283 .40904 .53155 .40661 .52918 Mtetra
.40661 .52918 .40904 .53155 .41314 .53027 .41071 .5279 Mtetra
.41071 .5279 .41314 .53027 .41724 .52899 .41482 .52661 Mtetra
.41482 .52661 .41724 .52899 .42135 .5277 .41893 .52532 Mtetra
.41893 .52532 .42135 .5277 .42638 .49538 .42305 .52403 Mtetra
0 0 .155 r
.42305 .52403 .42638 .49538 .43047 .49407 .42808 .49167 Mtetra
.654 .754 .923 r
.42808 .49167 .43047 .49407 .43456 .49277 .43217 .49036 Mtetra
.43217 .49036 .43456 .49277 .43865 .49146 .43627 .48905 Mtetra
.43627 .48905 .43865 .49146 .44275 .49016 .44038 .48774 Mtetra
.44038 .48774 .44275 .49016 .44686 .48885 .44449 .48642 Mtetra
.938 .744 .614 r
.44449 .48642 .44686 .48885 .45098 .48753 .44896 .46976 Mtetra
.578 .409 .616 r
.44896 .46976 .45098 .48753 .45781 .35783 .45307 .46844 Mtetra
0 0 .273 r
.45307 .46844 .45781 .35783 .46177 .35647 .45951 .35396 Mtetra
.664 .741 .908 r
.45951 .35396 .46177 .35647 .46575 .35511 .46349 .35259 Mtetra
.46349 .35259 .46575 .35511 .46973 .35375 .46747 .35122 Mtetra
.46747 .35122 .46973 .35375 .47372 .35238 .47146 .34986 Mtetra
.47146 .34986 .47372 .35238 .47771 .35101 .47546 .34849 Mtetra
.47546 .34849 .47771 .35101 .48171 .34965 .47946 .34711 Mtetra
.47946 .34711 .48171 .34965 .48571 .34827 .48347 .34574 Mtetra
.48347 .34574 .48571 .34827 .48972 .3469 .48748 .34436 Mtetra
.48748 .34436 .48972 .3469 .49373 .34553 .4915 .34298 Mtetra
.4915 .34298 .49373 .34553 .49776 .34415 .49553 .3416 Mtetra
.49553 .3416 .49776 .34415 .50178 .34277 .49956 .34022 Mtetra
.49956 .34022 .50178 .34277 .50582 .34139 .50359 .33884 Mtetra
.50359 .33884 .50582 .34139 .50986 .34001 .50764 .33745 Mtetra
.50764 .33745 .50986 .34001 .5139 .33862 .51169 .33606 Mtetra
.51169 .33606 .5139 .33862 .51795 .33724 .51574 .33467 Mtetra
.51574 .33467 .51795 .33724 .522 .34542 .5198 .33328 Mtetra
.164 .15 .595 r
.5198 .33328 .522 .34542 .52608 .34403 .52387 .34146 Mtetra
.663 .742 .909 r
.52387 .34146 .52608 .34403 .53016 .34264 .52795 .34006 Mtetra
.52795 .34006 .53016 .34264 .53425 .34124 .53204 .33867 Mtetra
.53204 .33867 .53425 .34124 .53834 .33985 .53614 .33727 Mtetra
.53614 .33727 .53834 .33985 .54244 .33845 .54024 .33587 Mtetra
.54024 .33587 .54244 .33845 .54654 .33706 .54435 .33447 Mtetra
.54435 .33447 .54654 .33706 .55066 .33565 .54847 .33306 Mtetra
.54847 .33306 .55066 .33565 .55477 .33425 .55259 .33166 Mtetra
.55259 .33166 .55477 .33425 .5589 .33285 .55672 .33025 Mtetra
.55672 .33025 .5589 .33285 .56303 .33144 .56086 .32884 Mtetra
.56086 .32884 .56303 .33144 .56717 .33003 .565 .32742 Mtetra
.565 .32742 .56717 .33003 .57131 .32862 .56914 .32601 Mtetra
.56914 .32601 .57131 .32862 .57546 .32721 .5733 .32459 Mtetra
.5733 .32459 .57546 .32721 .57961 .32579 .57746 .32317 Mtetra
.971 .676 .407 r
.57746 .32317 .57961 .32579 .58377 .32437 .58494 .50552 Mtetra
.537 .311 .519 r
.58494 .50552 .58377 .32437 .59162 .50667 .58935 .50416 Mtetra
.648 .76 .931 r
.58935 .50416 .59162 .50667 .59605 .50531 .59378 .50279 Mtetra
.59378 .50279 .59605 .50531 .60047 .50395 .59821 .50143 Mtetra
.59821 .50143 .60047 .50395 .60491 .50258 .60265 .50006 Mtetra
.60265 .50006 .60491 .50258 .60935 .50122 .6071 .49869 Mtetra
.6071 .49869 .60935 .50122 .6138 .49985 .61155 .49732 Mtetra
.61155 .49732 .6138 .49985 .61825 .49848 .61601 .49595 Mtetra
.61601 .49595 .61825 .49848 .62272 .49711 .62048 .49457 Mtetra
.62048 .49457 .62272 .49711 .62719 .49574 .62496 .49319 Mtetra
.62496 .49319 .62719 .49574 .63167 .49436 .62944 .49181 Mtetra
.62944 .49181 .63167 .49436 .63615 .49298 .63393 .49043 Mtetra
.63393 .49043 .63615 .49298 .64064 .4916 .63843 .48905 Mtetra
.63843 .48905 .64064 .4916 .64514 .49022 .64293 .48766 Mtetra
.64293 .48766 .64514 .49022 .64965 .48883 .64744 .48627 Mtetra
.64744 .48627 .64965 .48883 .65416 .48745 .65196 .48488 Mtetra
.65196 .48488 .65416 .48745 .65868 .48606 .65648 .48348 Mtetra
.65648 .48348 .65868 .48606 .66321 .48466 .66102 .48209 Mtetra
.977 .711 .458 r
.66102 .48209 .66321 .48466 .66704 .46704 .66305 .42191 Mtetra
.557 .357 .565 r
.66305 .42191 .66704 .46704 .66967 .42311 .66752 .42049 Mtetra
.653 .754 .924 r
.66752 .42049 .66967 .42311 .67413 .42169 .67199 .41906 Mtetra
.67199 .41906 .67413 .42169 .67861 .42027 .67647 .41764 Mtetra
.67647 .41764 .67861 .42027 .68309 .41885 .68096 .41621 Mtetra
.68096 .41621 .68309 .41885 .68758 .41742 .68545 .41478 Mtetra
.68545 .41478 .68758 .41742 .69234 .42125 .68995 .41334 Mtetra
.614 .515 .718 r
.68995 .41334 .69234 .42125 .69685 .41982 .69446 .41191 Mtetra
.69446 .41191 .69685 .41982 .70137 .41839 .69897 .41047 Mtetra
.69897 .41047 .70137 .41839 .70589 .41696 .70349 .40903 Mtetra
.329 .336 .716 r
.70349 .40903 .70589 .41696 .71043 .41552 .70832 .41286 Mtetra
.653 .755 .924 r
.70832 .41286 .71043 .41552 .71496 .41408 .71286 .41142 Mtetra
.71286 .41142 .71496 .41408 .71951 .41264 .71741 .40998 Mtetra
.71741 .40998 .71951 .41264 .72406 .4112 .72197 .40853 Mtetra
.72197 .40853 .72406 .4112 .72862 .40975 .72654 .40708 Mtetra
.72654 .40708 .72862 .40975 .73319 .40831 .73111 .40563 Mtetra
.73111 .40563 .73319 .40831 .73777 .40685 .73569 .40417 Mtetra
.73569 .40417 .73777 .40685 .74235 .4054 .74028 .40271 Mtetra
.74028 .40271 .74235 .4054 .74694 .40395 .74487 .40126 Mtetra
.979 .689 .385 r
.74487 .40126 .74694 .40395 .74157 .26068 .73959 .2579 Mtetra
.664 .741 .908 r
.73959 .2579 .74157 .26068 .74597 .25918 .74399 .25639 Mtetra
.74399 .25639 .74597 .25918 .75037 .25767 .74839 .25488 Mtetra
.74839 .25488 .75037 .25767 .75477 .25616 .7528 .25337 Mtetra
.7528 .25337 .75477 .25616 .75919 .25465 .75722 .25185 Mtetra
.75722 .25185 .75919 .25465 .76361 .25314 .76165 .25033 Mtetra
.76165 .25033 .76361 .25314 .76804 .25162 .76608 .24881 Mtetra
.76608 .24881 .76804 .25162 .77247 .2501 .77052 .24729 Mtetra
.77052 .24729 .77247 .2501 .77692 .24858 .77497 .24577 Mtetra
.77497 .24577 .77692 .24858 .78137 .24706 .77942 .24424 Mtetra
.77942 .24424 .78137 .24706 .78582 .24553 .78389 .24271 Mtetra
.78389 .24271 .78582 .24553 .79028 .244 .78835 .24118 Mtetra
.78835 .24118 .79028 .244 .79475 .24247 .79283 .23964 Mtetra
.79283 .23964 .79475 .24247 .79923 .24094 .79731 .23811 Mtetra
.79731 .23811 .79923 .24094 .80371 .23941 .8018 .23657 Mtetra
.8018 .23657 .80371 .23941 .8082 .23787 .80629 .23502 Mtetra
.80629 .23502 .8082 .23787 .8127 .23633 .81079 .23348 Mtetra
.81079 .23348 .8127 .23633 .81721 .23479 .8153 .23193 Mtetra
.8153 .23193 .81721 .23479 .82172 .23324 .81982 .23039 Mtetra
.81982 .23039 .82172 .23324 .82624 .2317 .82434 .22883 Mtetra
.82434 .22883 .82624 .2317 .83076 .23015 .82887 .22728 Mtetra
.82887 .22728 .83076 .23015 .83529 .22859 .83341 .22572 Mtetra
.22125 .43251 .22373 .43482 .22737 .43357 .2249 .43126 Mtetra
.2249 .43126 .22737 .43357 .23102 .43232 .22854 .43001 Mtetra
.22854 .43001 .23102 .43232 .23467 .43107 .2322 .42875 Mtetra
.2322 .42875 .23467 .43107 .23832 .42981 .23586 .42749 Mtetra
.23586 .42749 .23832 .42981 .24198 .42856 .23952 .42623 Mtetra
.23952 .42623 .24198 .42856 .24565 .4273 .24319 .42497 Mtetra
.24319 .42497 .24565 .4273 .24932 .42604 .24686 .42371 Mtetra
.24686 .42371 .24932 .42604 .253 .42478 .25054 .42245 Mtetra
.25054 .42245 .253 .42478 .25668 .42352 .25423 .42118 Mtetra
.548 .038 0 r
.25423 .42118 .25668 .42352 .26037 .42225 .25753 .4246 Mtetra
.118 0 0 r
.25753 .4246 .26037 .42225 .26406 .42099 .26123 .42333 Mtetra
.26123 .42333 .26406 .42099 .26775 .41972 .26494 .42206 Mtetra
.26494 .42206 .26775 .41972 .27109 .42313 .26865 .42079 Mtetra
.663 .742 .908 r
.26865 .42079 .27109 .42313 .2748 .42186 .27236 .41952 Mtetra
.27236 .41952 .2748 .42186 .27852 .42059 .27609 .41824 Mtetra
.27609 .41824 .27852 .42059 .28224 .41932 .27981 .41696 Mtetra
.27981 .41696 .28224 .41932 .28597 .41804 .28354 .41568 Mtetra
.28354 .41568 .28597 .41804 .28971 .41677 .28728 .4144 Mtetra
.28728 .4144 .28971 .41677 .28652 .51234 .29102 .41312 Mtetra
0 0 .25 r
.29102 .41312 .28652 .51234 .29037 .51109 .28787 .50878 Mtetra
.656 .751 .92 r
.28787 .50878 .29037 .51109 .29423 .50984 .29173 .50752 Mtetra
.29173 .50752 .29423 .50984 .29809 .50859 .2956 .50627 Mtetra
.2956 .50627 .29809 .50859 .30196 .50733 .29947 .50501 Mtetra
.29947 .50501 .30196 .50733 .30584 .50608 .30335 .50375 Mtetra
.30335 .50375 .30584 .50608 .30972 .50482 .30723 .50249 Mtetra
.30723 .50249 .30972 .50482 .3136 .50356 .31112 .50123 Mtetra
.31112 .50123 .3136 .50356 .31749 .5023 .31502 .49996 Mtetra
.31502 .49996 .31749 .5023 .32139 .50103 .31892 .4987 Mtetra
.31892 .4987 .32139 .50103 .32529 .49977 .32282 .49743 Mtetra
.32282 .49743 .32529 .49977 .3292 .4985 .32674 .49616 Mtetra
.32674 .49616 .3292 .4985 .33312 .49723 .33065 .49489 Mtetra
.33065 .49489 .33312 .49723 .33704 .49596 .33458 .49361 Mtetra
.33458 .49361 .33704 .49596 .34096 .49469 .33851 .49234 Mtetra
.33851 .49234 .34096 .49469 .34489 .49342 .34244 .49106 Mtetra
.34244 .49106 .34489 .49342 .34883 .49214 .34638 .48978 Mtetra
.34638 .48978 .34883 .49214 .35277 .49086 .35033 .4885 Mtetra
.954 .665 .45 r
.35033 .4885 .35277 .49086 .35387 .54573 .35139 .5434 Mtetra
.651 .757 .927 r
.35139 .5434 .35387 .54573 .35789 .54447 .35541 .54214 Mtetra
.35541 .54214 .35789 .54447 .36192 .54321 .35944 .54087 Mtetra
.35944 .54087 .36192 .54321 .36595 .54194 .36347 .5396 Mtetra
.36347 .5396 .36595 .54194 .36999 .54067 .36752 .53833 Mtetra
.36752 .53833 .36999 .54067 .37403 .53941 .37156 .53706 Mtetra
.37156 .53706 .37403 .53941 .37808 .53813 .37562 .53578 Mtetra
.37562 .53578 .37808 .53813 .38214 .53686 .37968 .53451 Mtetra
.37968 .53451 .38214 .53686 .3862 .53559 .38375 .53323 Mtetra
.38375 .53323 .3862 .53559 .39027 .53431 .38782 .53195 Mtetra
.38782 .53195 .39027 .53431 .39435 .53303 .3919 .53067 Mtetra
.3919 .53067 .39435 .53303 .39843 .53175 .39598 .52938 Mtetra
.39598 .52938 .39843 .53175 .40252 .53047 .40007 .5281 Mtetra
.40007 .5281 .40252 .53047 .40661 .52918 .40417 .52681 Mtetra
.40417 .52681 .40661 .52918 .41071 .5279 .40828 .52552 Mtetra
.40828 .52552 .41071 .5279 .41482 .52661 .41239 .52423 Mtetra
.41239 .52423 .41482 .52661 .41893 .52532 .4165 .52293 Mtetra
.4165 .52293 .41893 .52532 .42305 .52403 .42062 .52164 Mtetra
.42062 .52164 .42305 .52403 .42808 .49167 .42475 .52034 Mtetra
.514 .26 .468 r
.42475 .52034 .42808 .49167 .43217 .49036 .42889 .51904 Mtetra
.713 .646 .088 r
.42889 .51904 .43217 .49036 .43627 .48905 .43431 .47129 Mtetra
.577 .409 .616 r
.43431 .47129 .43627 .48905 .44038 .48774 .4384 .46996 Mtetra
.4384 .46996 .44038 .48774 .44449 .48642 .4425 .46864 Mtetra
.4425 .46864 .44449 .48642 .44896 .46976 .4466 .46732 Mtetra
.655 .752 .921 r
.4466 .46732 .44896 .46976 .45307 .46844 .45071 .46599 Mtetra
.96 .698 .494 r
.45071 .46599 .45307 .46844 .45951 .35396 .45724 .35143 Mtetra
.664 .741 .908 r
.45724 .35143 .45951 .35396 .46349 .35259 .46122 .35007 Mtetra
.46122 .35007 .46349 .35259 .46747 .35122 .46521 .3487 Mtetra
.46521 .3487 .46747 .35122 .47146 .34986 .4692 .34732 Mtetra
.4692 .34732 .47146 .34986 .47546 .34849 .4732 .34595 Mtetra
.4732 .34595 .47546 .34849 .47946 .34711 .47721 .34457 Mtetra
.47721 .34457 .47946 .34711 .48347 .34574 .48122 .3432 Mtetra
.48122 .3432 .48347 .34574 .48748 .34436 .48524 .34182 Mtetra
.48524 .34182 .48748 .34436 .4915 .34298 .48926 .34043 Mtetra
.48926 .34043 .4915 .34298 .49553 .3416 .49329 .33905 Mtetra
.49329 .33905 .49553 .3416 .49956 .34022 .49732 .33766 Mtetra
.49732 .33766 .49956 .34022 .50359 .33884 .50136 .33627 Mtetra
.50136 .33627 .50359 .33884 .50764 .33745 .50541 .33488 Mtetra
.50541 .33488 .50764 .33745 .51169 .33606 .50946 .33349 Mtetra
.50946 .33349 .51169 .33606 .51574 .33467 .51352 .3321 Mtetra
.51352 .3321 .51574 .33467 .5198 .33328 .51759 .3307 Mtetra
.823 .379 0 r
.51759 .3307 .5198 .33328 .52387 .34146 .52165 .33888 Mtetra
.663 .742 .909 r
.52165 .33888 .52387 .34146 .52795 .34006 .52574 .33749 Mtetra
.52574 .33749 .52795 .34006 .53204 .33867 .52983 .33609 Mtetra
.52983 .33609 .53204 .33867 .53614 .33727 .53394 .33468 Mtetra
.53394 .33468 .53614 .33727 .54024 .33587 .53804 .33328 Mtetra
.53804 .33328 .54024 .33587 .54435 .33447 .54216 .33187 Mtetra
.54216 .33187 .54435 .33447 .54847 .33306 .54628 .33047 Mtetra
.54628 .33047 .54847 .33306 .55259 .33166 .5504 .32905 Mtetra
.5504 .32905 .55259 .33166 .55672 .33025 .55454 .32764 Mtetra
.55454 .32764 .55672 .33025 .56086 .32884 .55868 .32623 Mtetra
.55868 .32623 .56086 .32884 .565 .32742 .56282 .32481 Mtetra
.56282 .32481 .565 .32742 .56914 .32601 .56697 .32339 Mtetra
.56697 .32339 .56914 .32601 .5733 .32459 .57113 .32197 Mtetra
.57113 .32197 .5733 .32459 .57746 .32317 .57529 .32055 Mtetra
.971 .676 .407 r
.57529 .32055 .57746 .32317 .58494 .50552 .58266 .503 Mtetra
.648 .76 .931 r
.58266 .503 .58494 .50552 .58935 .50416 .58708 .50164 Mtetra
.58708 .50164 .58935 .50416 .59378 .50279 .59151 .50027 Mtetra
.59151 .50027 .59378 .50279 .59821 .50143 .59595 .4989 Mtetra
.59595 .4989 .59821 .50143 .60265 .50006 .60039 .49753 Mtetra
.60039 .49753 .60265 .50006 .6071 .49869 .60484 .49616 Mtetra
.60484 .49616 .6071 .49869 .61155 .49732 .6093 .49478 Mtetra
.6093 .49478 .61155 .49732 .61601 .49595 .61377 .49341 Mtetra
.61377 .49341 .61601 .49595 .62048 .49457 .61824 .49203 Mtetra
.61824 .49203 .62048 .49457 .62496 .49319 .62272 .49064 Mtetra
.62272 .49064 .62496 .49319 .62944 .49181 .62721 .48926 Mtetra
.62721 .48926 .62944 .49181 .63393 .49043 .6317 .48787 Mtetra
.6317 .48787 .63393 .49043 .63843 .48905 .6362 .48648 Mtetra
.6362 .48648 .63843 .48905 .64293 .48766 .64071 .48509 Mtetra
.64071 .48509 .64293 .48766 .64744 .48627 .64523 .4837 Mtetra
.64523 .4837 .64744 .48627 .65196 .48488 .64975 .4823 Mtetra
.64975 .4823 .65196 .48488 .65648 .48348 .65428 .48091 Mtetra
.65428 .48091 .65648 .48348 .66102 .48209 .65882 .47951 Mtetra
.977 .711 .458 r
.65882 .47951 .66102 .48209 .66305 .42191 .6609 .41928 Mtetra
.653 .754 .924 r
.6609 .41928 .66305 .42191 .66752 .42049 .66537 .41786 Mtetra
.66537 .41786 .66752 .42049 .67199 .41906 .66984 .41643 Mtetra
.66984 .41643 .67199 .41906 .67647 .41764 .67433 .415 Mtetra
.67433 .415 .67647 .41764 .68096 .41621 .67882 .41357 Mtetra
.67882 .41357 .68096 .41621 .68545 .41478 .68331 .41213 Mtetra
.68331 .41213 .68545 .41478 .68995 .41334 .68782 .41069 Mtetra
.68782 .41069 .68995 .41334 .69446 .41191 .69233 .40925 Mtetra
.69233 .40925 .69446 .41191 .69897 .41047 .69685 .40781 Mtetra
.69685 .40781 .69897 .41047 .70349 .40903 .70138 .40637 Mtetra
.70138 .40637 .70349 .40903 .70832 .41286 .70591 .40492 Mtetra
.614 .514 .718 r
.70591 .40492 .70832 .41286 .71286 .41142 .71045 .40347 Mtetra
.71045 .40347 .71286 .41142 .71741 .40998 .715 .40202 Mtetra
.715 .40202 .71741 .40998 .72197 .40853 .71956 .40056 Mtetra
.331 .338 .716 r
.71956 .40056 .72197 .40853 .72654 .40708 .72445 .4044 Mtetra
.653 .755 .924 r
.72445 .4044 .72654 .40708 .73111 .40563 .72902 .40294 Mtetra
.72902 .40294 .73111 .40563 .73569 .40417 .73361 .40148 Mtetra
.73361 .40148 .73569 .40417 .74028 .40271 .7382 .40002 Mtetra
.7382 .40002 .74028 .40271 .74487 .40126 .7428 .39855 Mtetra
.979 .689 .385 r
.7428 .39855 .74487 .40126 .73959 .2579 .7376 .25511 Mtetra
.664 .741 .908 r
.7376 .25511 .73959 .2579 .74399 .25639 .742 .2536 Mtetra
.742 .2536 .74399 .25639 .74839 .25488 .74641 .25209 Mtetra
.74641 .25209 .74839 .25488 .7528 .25337 .75083 .25057 Mtetra
.75083 .25057 .7528 .25337 .75722 .25185 .75525 .24905 Mtetra
.75525 .24905 .75722 .25185 .76165 .25033 .75968 .24753 Mtetra
.75968 .24753 .76165 .25033 .76608 .24881 .76412 .246 Mtetra
.76412 .246 .76608 .24881 .77052 .24729 .76857 .24447 Mtetra
.76857 .24447 .77052 .24729 .77497 .24577 .77302 .24294 Mtetra
.77302 .24294 .77497 .24577 .77942 .24424 .77748 .24141 Mtetra
.77748 .24141 .77942 .24424 .78389 .24271 .78194 .23988 Mtetra
.78194 .23988 .78389 .24271 .78835 .24118 .78642 .23834 Mtetra
.78642 .23834 .78835 .24118 .79283 .23964 .7909 .2368 Mtetra
.7909 .2368 .79283 .23964 .79731 .23811 .79538 .23526 Mtetra
.79538 .23526 .79731 .23811 .8018 .23657 .79988 .23372 Mtetra
.79988 .23372 .8018 .23657 .80629 .23502 .80438 .23217 Mtetra
.80438 .23217 .80629 .23502 .81079 .23348 .80888 .23062 Mtetra
.80888 .23062 .81079 .23348 .8153 .23193 .8134 .22907 Mtetra
.8134 .22907 .8153 .23193 .81982 .23039 .81792 .22752 Mtetra
.81792 .22752 .81982 .23039 .82434 .22883 .82245 .22596 Mtetra
.82245 .22596 .82434 .22883 .82887 .22728 .82698 .22441 Mtetra
.82698 .22441 .82887 .22728 .83341 .22572 .83153 .22284 Mtetra
.21877 .4302 .22125 .43251 .2249 .43126 .22242 .42894 Mtetra
.22242 .42894 .2249 .43126 .22854 .43001 .22607 .42769 Mtetra
.22607 .42769 .22854 .43001 .2322 .42875 .22972 .42643 Mtetra
.22972 .42643 .2322 .42875 .23586 .42749 .23339 .42517 Mtetra
.23339 .42517 .23586 .42749 .23952 .42623 .23705 .42391 Mtetra
.23705 .42391 .23952 .42623 .24319 .42497 .24072 .42264 Mtetra
.558 .047 0 r
.24072 .42264 .24319 .42497 .24686 .42371 .244 .42606 Mtetra
.115 0 0 r
.244 .42606 .24686 .42371 .25054 .42245 .24768 .42479 Mtetra
.24768 .42479 .25054 .42245 .25423 .42118 .25138 .42353 Mtetra
.25138 .42353 .25423 .42118 .25753 .4246 .25508 .42226 Mtetra
.663 .742 .908 r
.25508 .42226 .25753 .4246 .26123 .42333 .25878 .42098 Mtetra
.25878 .42098 .26123 .42333 .26494 .42206 .26249 .41971 Mtetra
.26249 .41971 .26494 .42206 .26865 .42079 .2662 .41844 Mtetra
.2662 .41844 .26865 .42079 .27236 .41952 .26992 .41716 Mtetra
.26992 .41716 .27236 .41952 .27609 .41824 .27364 .41588 Mtetra
.27364 .41588 .27609 .41824 .27981 .41696 .27737 .4146 Mtetra
.27737 .4146 .27981 .41696 .28354 .41568 .28111 .41332 Mtetra
.28111 .41332 .28354 .41568 .28728 .4144 .28485 .41203 Mtetra
.28485 .41203 .28728 .4144 .29102 .41312 .28859 .41075 Mtetra
.947 .676 .49 r
.28859 .41075 .29102 .41312 .28787 .50878 .28537 .50646 Mtetra
.656 .751 .92 r
.28537 .50646 .28787 .50878 .29173 .50752 .28923 .50521 Mtetra
.28923 .50521 .29173 .50752 .2956 .50627 .2931 .50395 Mtetra
.2931 .50395 .2956 .50627 .29947 .50501 .29697 .50269 Mtetra
.29697 .50269 .29947 .50501 .30335 .50375 .30086 .50142 Mtetra
.30086 .50142 .30335 .50375 .30723 .50249 .30474 .50016 Mtetra
.30474 .50016 .30723 .50249 .31112 .50123 .30863 .49889 Mtetra
.30863 .49889 .31112 .50123 .31502 .49996 .31253 .49762 Mtetra
.31253 .49762 .31502 .49996 .31892 .4987 .31644 .49635 Mtetra
.31644 .49635 .31892 .4987 .32282 .49743 .32035 .49508 Mtetra
.32035 .49508 .32282 .49743 .32674 .49616 .32426 .49381 Mtetra
.32426 .49381 .32674 .49616 .33065 .49489 .32818 .49253 Mtetra
.32818 .49253 .33065 .49489 .33458 .49361 .33211 .49126 Mtetra
.33211 .49126 .33458 .49361 .33851 .49234 .33604 .48998 Mtetra
.33604 .48998 .33851 .49234 .34244 .49106 .33998 .4887 Mtetra
.33998 .4887 .34244 .49106 .34638 .48978 .34393 .48741 Mtetra
.34393 .48741 .34638 .48978 .35033 .4885 .34788 .48613 Mtetra
.34788 .48613 .35033 .4885 .35139 .5434 .35183 .48484 Mtetra
0 0 .319 r
.35183 .48484 .35139 .5434 .35541 .54214 .35292 .5398 Mtetra
.651 .757 .927 r
.35292 .5398 .35541 .54214 .35944 .54087 .35695 .53853 Mtetra
.35695 .53853 .35944 .54087 .36347 .5396 .36099 .53725 Mtetra
.36099 .53725 .36347 .5396 .36752 .53833 .36504 .53598 Mtetra
.36504 .53598 .36752 .53833 .37156 .53706 .36909 .5347 Mtetra
.36909 .5347 .37156 .53706 .37562 .53578 .37315 .53343 Mtetra
.37315 .53343 .37562 .53578 .37968 .53451 .37721 .53215 Mtetra
.37721 .53215 .37968 .53451 .38375 .53323 .38128 .53086 Mtetra
.38128 .53086 .38375 .53323 .38782 .53195 .38536 .52958 Mtetra
.38536 .52958 .38782 .53195 .3919 .53067 .38944 .52829 Mtetra
.38944 .52829 .3919 .53067 .39598 .52938 .39353 .52701 Mtetra
.39353 .52701 .39598 .52938 .40007 .5281 .39763 .52572 Mtetra
.39763 .52572 .40007 .5281 .40417 .52681 .40173 .52442 Mtetra
.40173 .52442 .40417 .52681 .40828 .52552 .40583 .52313 Mtetra
.40583 .52313 .40828 .52552 .41239 .52423 .40995 .52184 Mtetra
.40995 .52184 .41239 .52423 .4165 .52293 .41407 .52054 Mtetra
.41407 .52054 .4165 .52293 .42062 .52164 .4182 .51924 Mtetra
.4182 .51924 .42062 .52164 .42475 .52034 .42233 .51794 Mtetra
.954 .712 .532 r
.42233 .51794 .42475 .52034 .42889 .51904 .42784 .47017 Mtetra
.554 .352 .561 r
.42784 .47017 .42889 .51904 .43431 .47129 .43193 .46885 Mtetra
.655 .752 .921 r
.43193 .46885 .43431 .47129 .4384 .46996 .43602 .46752 Mtetra
.43602 .46752 .4384 .46996 .4425 .46864 .44012 .46619 Mtetra
.44012 .46619 .4425 .46864 .4466 .46732 .44423 .46487 Mtetra
.44423 .46487 .4466 .46732 .45071 .46599 .44834 .46353 Mtetra
.44834 .46353 .45071 .46599 .45724 .35143 .45246 .4622 Mtetra
0 0 .271 r
.45246 .4622 .45724 .35143 .46122 .35007 .45895 .34754 Mtetra
.664 .741 .908 r
.45895 .34754 .46122 .35007 .46521 .3487 .46294 .34616 Mtetra
.46294 .34616 .46521 .3487 .4692 .34732 .46694 .34479 Mtetra
.46694 .34479 .4692 .34732 .4732 .34595 .47094 .34341 Mtetra
.47094 .34341 .4732 .34595 .47721 .34457 .47495 .34203 Mtetra
.47495 .34203 .47721 .34457 .48122 .3432 .47896 .34065 Mtetra
.47896 .34065 .48122 .3432 .48524 .34182 .48299 .33926 Mtetra
.48299 .33926 .48524 .34182 .48926 .34043 .48701 .33788 Mtetra
.48701 .33788 .48926 .34043 .49329 .33905 .49105 .33649 Mtetra
.49105 .33649 .49329 .33905 .49732 .33766 .49508 .3351 Mtetra
.49508 .3351 .49732 .33766 .50136 .33627 .49913 .33371 Mtetra
.49913 .33371 .50136 .33627 .50541 .33488 .50318 .33231 Mtetra
.50318 .33231 .50541 .33488 .50946 .33349 .50724 .33092 Mtetra
.50724 .33092 .50946 .33349 .51352 .3321 .5113 .32952 Mtetra
.5113 .32952 .51352 .3321 .51759 .3307 .51537 .32812 Mtetra
.51537 .32812 .51759 .3307 .52165 .33888 .51944 .32671 Mtetra
.163 .149 .594 r
.51944 .32671 .52165 .33888 .52574 .33749 .52352 .3349 Mtetra
.663 .742 .909 r
.52352 .3349 .52574 .33749 .52983 .33609 .52762 .3335 Mtetra
.52762 .3335 .52983 .33609 .53394 .33468 .53173 .33209 Mtetra
.53173 .33209 .53394 .33468 .53804 .33328 .53584 .33068 Mtetra
.53584 .33068 .53804 .33328 .54216 .33187 .53996 .32927 Mtetra
.53996 .32927 .54216 .33187 .54628 .33047 .54408 .32786 Mtetra
.54408 .32786 .54628 .33047 .5504 .32905 .54821 .32645 Mtetra
.54821 .32645 .5504 .32905 .55454 .32764 .55235 .32503 Mtetra
.55235 .32503 .55454 .32764 .55868 .32623 .55649 .32361 Mtetra
.55649 .32361 .55868 .32623 .56282 .32481 .56064 .32219 Mtetra
.56064 .32219 .56282 .32481 .56697 .32339 .56479 .32077 Mtetra
.56479 .32077 .56697 .32339 .57113 .32197 .56895 .31934 Mtetra
.56895 .31934 .57113 .32197 .57529 .32055 .57312 .31791 Mtetra
.971 .676 .407 r
.57312 .31791 .57529 .32055 .58266 .503 .58037 .50048 Mtetra
.648 .76 .931 r
.58037 .50048 .58266 .503 .58708 .50164 .5848 .49911 Mtetra
.5848 .49911 .58708 .50164 .59151 .50027 .58923 .49774 Mtetra
.58923 .49774 .59151 .50027 .59595 .4989 .59367 .49637 Mtetra
.59367 .49637 .59595 .4989 .60039 .49753 .59812 .495 Mtetra
.59812 .495 .60039 .49753 .60484 .49616 .60258 .49362 Mtetra
.60258 .49362 .60484 .49616 .6093 .49478 .60704 .49224 Mtetra
.60704 .49224 .6093 .49478 .61377 .49341 .61151 .49086 Mtetra
.61151 .49086 .61377 .49341 .61824 .49203 .61599 .48947 Mtetra
.61599 .48947 .61824 .49203 .62272 .49064 .62047 .48809 Mtetra
.62047 .48809 .62272 .49064 .62721 .48926 .62497 .4867 Mtetra
.62497 .4867 .62721 .48926 .6317 .48787 .62946 .48531 Mtetra
.62946 .48531 .6317 .48787 .6362 .48648 .63397 .48391 Mtetra
.63397 .48391 .6362 .48648 .64071 .48509 .63849 .48252 Mtetra
.63849 .48252 .64071 .48509 .64523 .4837 .64301 .48112 Mtetra
.64301 .48112 .64523 .4837 .64975 .4823 .64753 .47972 Mtetra
.64753 .47972 .64975 .4823 .65428 .48091 .65207 .47832 Mtetra
.65207 .47832 .65428 .48091 .65882 .47951 .65661 .47691 Mtetra
.977 .711 .458 r
.65661 .47691 .65882 .47951 .6609 .41928 .65873 .41665 Mtetra
.653 .754 .924 r
.65873 .41665 .6609 .41928 .66537 .41786 .66321 .41522 Mtetra
.66321 .41522 .66537 .41786 .66984 .41643 .66769 .41379 Mtetra
.66769 .41379 .66984 .41643 .67433 .415 .67217 .41235 Mtetra
.67217 .41235 .67433 .415 .67882 .41357 .67667 .41091 Mtetra
.67667 .41091 .67882 .41357 .68331 .41213 .68117 .40947 Mtetra
.68117 .40947 .68331 .41213 .68782 .41069 .68568 .40803 Mtetra
.68568 .40803 .68782 .41069 .69233 .40925 .6902 .40659 Mtetra
.6902 .40659 .69233 .40925 .69685 .40781 .69472 .40514 Mtetra
.69472 .40514 .69685 .40781 .70138 .40637 .69926 .40369 Mtetra
.69926 .40369 .70138 .40637 .70591 .40492 .7038 .40224 Mtetra
.7038 .40224 .70591 .40492 .71045 .40347 .70834 .40079 Mtetra
.70834 .40079 .71045 .40347 .715 .40202 .71289 .39933 Mtetra
.71289 .39933 .715 .40202 .71956 .40056 .71746 .39787 Mtetra
.71746 .39787 .71956 .40056 .72445 .4044 .72202 .39641 Mtetra
.614 .514 .718 r
.72202 .39641 .72445 .4044 .72902 .40294 .7266 .39495 Mtetra
.7266 .39495 .72902 .40294 .73361 .40148 .73118 .39349 Mtetra
.73118 .39349 .73361 .40148 .7382 .40002 .73577 .39202 Mtetra
.974 .682 .406 r
.73577 .39202 .7382 .40002 .7428 .39855 .7312 .25383 Mtetra
.545 .33 .539 r
.7312 .25383 .7428 .39855 .7376 .25511 .7356 .25232 Mtetra
.664 .741 .908 r
.7356 .25232 .7376 .25511 .742 .2536 .74001 .2508 Mtetra
.74001 .2508 .742 .2536 .74641 .25209 .74443 .24928 Mtetra
.74443 .24928 .74641 .25209 .75083 .25057 .74885 .24776 Mtetra
.74885 .24776 .75083 .25057 .75525 .24905 .75328 .24624 Mtetra
.75328 .24624 .75525 .24905 .75968 .24753 .75771 .24471 Mtetra
.75771 .24471 .75968 .24753 .76412 .246 .76216 .24318 Mtetra
.76216 .24318 .76412 .246 .76857 .24447 .76661 .24165 Mtetra
.76661 .24165 .76857 .24447 .77302 .24294 .77106 .24012 Mtetra
.77106 .24012 .77302 .24294 .77748 .24141 .77553 .23858 Mtetra
.77553 .23858 .77748 .24141 .78194 .23988 .78 .23704 Mtetra
.78 .23704 .78194 .23988 .78642 .23834 .78447 .2355 Mtetra
.78447 .2355 .78642 .23834 .7909 .2368 .78896 .23396 Mtetra
.78896 .23396 .7909 .2368 .79538 .23526 .79345 .23241 Mtetra
.79345 .23241 .79538 .23526 .79988 .23372 .79795 .23086 Mtetra
.79795 .23086 .79988 .23372 .80438 .23217 .80245 .22931 Mtetra
.80245 .22931 .80438 .23217 .80888 .23062 .80697 .22776 Mtetra
.80697 .22776 .80888 .23062 .8134 .22907 .81149 .2262 Mtetra
.81149 .2262 .8134 .22907 .81792 .22752 .81601 .22464 Mtetra
.81601 .22464 .81792 .22752 .82245 .22596 .82055 .22308 Mtetra
.82055 .22308 .82245 .22596 .82698 .22441 .82509 .22152 Mtetra
.82509 .22152 .82698 .22441 .83153 .22284 .82963 .21996 Mtetra
.21628 .42788 .21877 .4302 .22242 .42894 .21993 .42662 Mtetra
.21993 .42662 .22242 .42894 .22607 .42769 .22358 .42536 Mtetra
.22358 .42536 .22607 .42769 .22972 .42643 .22724 .4241 Mtetra
.22724 .4241 .22972 .42643 .23339 .42517 .23091 .42284 Mtetra
.23091 .42284 .23339 .42517 .23705 .42391 .23458 .42157 Mtetra
.23458 .42157 .23705 .42391 .24072 .42264 .23825 .4203 Mtetra
.558 .047 0 r
.23825 .4203 .24072 .42264 .244 .42606 .24152 .42372 Mtetra
.663 .742 .908 r
.24152 .42372 .244 .42606 .24768 .42479 .24522 .42245 Mtetra
.24522 .42245 .24768 .42479 .25138 .42353 .24891 .42118 Mtetra
.24891 .42118 .25138 .42353 .25508 .42226 .25261 .41991 Mtetra
.25261 .41991 .25508 .42226 .25878 .42098 .25632 .41863 Mtetra
.25632 .41863 .25878 .42098 .26249 .41971 .26003 .41736 Mtetra
.26003 .41736 .26249 .41971 .2662 .41844 .26375 .41608 Mtetra
.26375 .41608 .2662 .41844 .26992 .41716 .26747 .4148 Mtetra
.26747 .4148 .26992 .41716 .27364 .41588 .2712 .41352 Mtetra
.2712 .41352 .27364 .41588 .27737 .4146 .27493 .41223 Mtetra
.27493 .41223 .27737 .4146 .28111 .41332 .27867 .41095 Mtetra
.27867 .41095 .28111 .41332 .28485 .41203 .28241 .40966 Mtetra
.28241 .40966 .28485 .41203 .28859 .41075 .28616 .40837 Mtetra
.28616 .40837 .28859 .41075 .28537 .50646 .28991 .40708 Mtetra
0 0 .247 r
.28991 .40708 .28537 .50646 .28923 .50521 .28672 .50288 Mtetra
.656 .751 .92 r
.28672 .50288 .28923 .50521 .2931 .50395 .29059 .50162 Mtetra
.29059 .50162 .2931 .50395 .29697 .50269 .29447 .50035 Mtetra
.29447 .50035 .29697 .50269 .30086 .50142 .29835 .49909 Mtetra
.29835 .49909 .30086 .50142 .30474 .50016 .30225 .49782 Mtetra
.30225 .49782 .30474 .50016 .30863 .49889 .30614 .49655 Mtetra
.30614 .49655 .30863 .49889 .31253 .49762 .31004 .49528 Mtetra
.31004 .49528 .31253 .49762 .31644 .49635 .31395 .49401 Mtetra
.31395 .49401 .31644 .49635 .32035 .49508 .31786 .49273 Mtetra
.31786 .49273 .32035 .49508 .32426 .49381 .32178 .49145 Mtetra
.32178 .49145 .32426 .49381 .32818 .49253 .32571 .49017 Mtetra
.32571 .49017 .32818 .49253 .33211 .49126 .32964 .48889 Mtetra
.32964 .48889 .33211 .49126 .33604 .48998 .33357 .48761 Mtetra
.33357 .48761 .33604 .48998 .33998 .4887 .33752 .48632 Mtetra
.33752 .48632 .33998 .4887 .34393 .48741 .34146 .48504 Mtetra
.34146 .48504 .34393 .48741 .34788 .48613 .34542 .48375 Mtetra
.34542 .48375 .34788 .48613 .35183 .48484 .34938 .48246 Mtetra
.954 .665 .449 r
.34938 .48246 .35183 .48484 .35292 .5398 .35042 .53745 Mtetra
.651 .757 .927 r
.35042 .53745 .35292 .5398 .35695 .53853 .35446 .53618 Mtetra
.35446 .53618 .35695 .53853 .36099 .53725 .3585 .5349 Mtetra
.3585 .5349 .36099 .53725 .36504 .53598 .36255 .53362 Mtetra
.36255 .53362 .36504 .53598 .36909 .5347 .36661 .53234 Mtetra
.36661 .53234 .36909 .5347 .37315 .53343 .37067 .53106 Mtetra
.37067 .53106 .37315 .53343 .37721 .53215 .37474 .52978 Mtetra
.37474 .52978 .37721 .53215 .38128 .53086 .37881 .52849 Mtetra
.37881 .52849 .38128 .53086 .38536 .52958 .38289 .5272 Mtetra
.38289 .5272 .38536 .52958 .38944 .52829 .38698 .52591 Mtetra
.38698 .52591 .38944 .52829 .39353 .52701 .39107 .52462 Mtetra
.39107 .52462 .39353 .52701 .39763 .52572 .39517 .52333 Mtetra
.39517 .52333 .39763 .52572 .40173 .52442 .39928 .52203 Mtetra
.39928 .52203 .40173 .52442 .40583 .52313 .40339 .52074 Mtetra
.40339 .52074 .40583 .52313 .40995 .52184 .40751 .51944 Mtetra
.40751 .51944 .40995 .52184 .41407 .52054 .41163 .51814 Mtetra
.41163 .51814 .41407 .52054 .4182 .51924 .41576 .51683 Mtetra
.41576 .51683 .4182 .51924 .42233 .51794 .4199 .51553 Mtetra
.954 .712 .532 r
.4199 .51553 .42233 .51794 .42784 .47017 .42545 .46772 Mtetra
.655 .752 .921 r
.42545 .46772 .42784 .47017 .43193 .46885 .42954 .4664 Mtetra
.42954 .4664 .43193 .46885 .43602 .46752 .43364 .46507 Mtetra
.43364 .46507 .43602 .46752 .44012 .46619 .43774 .46374 Mtetra
.43774 .46374 .44012 .46619 .44423 .46487 .44185 .46241 Mtetra
.44185 .46241 .44423 .46487 .44834 .46353 .44597 .46107 Mtetra
.44597 .46107 .44834 .46353 .45246 .4622 .4501 .45974 Mtetra
.96 .698 .493 r
.4501 .45974 .45246 .4622 .45895 .34754 .45667 .345 Mtetra
.664 .741 .908 r
.45667 .345 .45895 .34754 .46294 .34616 .46066 .34362 Mtetra
.46066 .34362 .46294 .34616 .46694 .34479 .46467 .34224 Mtetra
.46467 .34224 .46694 .34479 .47094 .34341 .46867 .34086 Mtetra
.46867 .34086 .47094 .34341 .47495 .34203 .47269 .33948 Mtetra
.47269 .33948 .47495 .34203 .47896 .34065 .4767 .33809 Mtetra
.4767 .33809 .47896 .34065 .48299 .33926 .48073 .3367 Mtetra
.48073 .3367 .48299 .33926 .48701 .33788 .48476 .33531 Mtetra
.48476 .33531 .48701 .33788 .49105 .33649 .4888 .33392 Mtetra
.4888 .33392 .49105 .33649 .49508 .3351 .49284 .33253 Mtetra
.49284 .33253 .49508 .3351 .49913 .33371 .49689 .33113 Mtetra
.49689 .33113 .49913 .33371 .50318 .33231 .50094 .32973 Mtetra
.50094 .32973 .50318 .33231 .50724 .33092 .505 .32833 Mtetra
.505 .32833 .50724 .33092 .5113 .32952 .50907 .32693 Mtetra
.50907 .32693 .5113 .32952 .51537 .32812 .51314 .32553 Mtetra
.51314 .32553 .51537 .32812 .51944 .32671 .51722 .32412 Mtetra
.821 .376 0 r
.51722 .32412 .51944 .32671 .52352 .3349 .5213 .33231 Mtetra
.663 .742 .909 r
.5213 .33231 .52352 .3349 .52762 .3335 .5254 .3309 Mtetra
.5254 .3309 .52762 .3335 .53173 .33209 .52951 .32949 Mtetra
.52951 .32949 .53173 .33209 .53584 .33068 .53363 .32808 Mtetra
.53363 .32808 .53584 .33068 .53996 .32927 .53775 .32666 Mtetra
.53775 .32666 .53996 .32927 .54408 .32786 .54188 .32525 Mtetra
.54188 .32525 .54408 .32786 .54821 .32645 .54601 .32383 Mtetra
.54601 .32383 .54821 .32645 .55235 .32503 .55015 .32241 Mtetra
.55015 .32241 .55235 .32503 .55649 .32361 .5543 .32099 Mtetra
.5543 .32099 .55649 .32361 .56064 .32219 .55845 .31956 Mtetra
.55845 .31956 .56064 .32219 .56479 .32077 .56261 .31813 Mtetra
.56261 .31813 .56479 .32077 .56895 .31934 .56677 .31671 Mtetra
.971 .676 .409 r
.56677 .31671 .56895 .31934 .57312 .31791 .57365 .49933 Mtetra
.535 .309 .518 r
.57365 .49933 .57312 .31791 .58037 .50048 .57807 .49795 Mtetra
.648 .76 .931 r
.57807 .49795 .58037 .50048 .5848 .49911 .58251 .49658 Mtetra
.58251 .49658 .5848 .49911 .58923 .49774 .58695 .49521 Mtetra
.58695 .49521 .58923 .49774 .59367 .49637 .59139 .49383 Mtetra
.59139 .49383 .59367 .49637 .59812 .495 .59585 .49245 Mtetra
.59585 .49245 .59812 .495 .60258 .49362 .60031 .49107 Mtetra
.60031 .49107 .60258 .49362 .60704 .49224 .60478 .48969 Mtetra
.60478 .48969 .60704 .49224 .61151 .49086 .60925 .4883 Mtetra
.60925 .4883 .61151 .49086 .61599 .48947 .61373 .48691 Mtetra
.61373 .48691 .61599 .48947 .62047 .48809 .61822 .48552 Mtetra
.61822 .48552 .62047 .48809 .62497 .4867 .62272 .48413 Mtetra
.62272 .48413 .62497 .4867 .62946 .48531 .62722 .48273 Mtetra
.62722 .48273 .62946 .48531 .63397 .48391 .63173 .48134 Mtetra
.63173 .48134 .63397 .48391 .63849 .48252 .63625 .47994 Mtetra
.63625 .47994 .63849 .48252 .64301 .48112 .64078 .47853 Mtetra
.64078 .47853 .64301 .48112 .64753 .47972 .64531 .47713 Mtetra
.64531 .47713 .64753 .47972 .65207 .47832 .64985 .47572 Mtetra
.64985 .47572 .65207 .47832 .65661 .47691 .6544 .47432 Mtetra
.977 .711 .458 r
.6544 .47432 .65661 .47691 .65873 .41665 .65656 .41401 Mtetra
.653 .754 .924 r
.65656 .41401 .65873 .41665 .66321 .41522 .66104 .41257 Mtetra
.66104 .41257 .66321 .41522 .66769 .41379 .66553 .41114 Mtetra
.66553 .41114 .66769 .41379 .67217 .41235 .67002 .4097 Mtetra
.67002 .4097 .67217 .41235 .67667 .41091 .67452 .40825 Mtetra
.67452 .40825 .67667 .41091 .68117 .40947 .67903 .40681 Mtetra
.67903 .40681 .68117 .40947 .68568 .40803 .68354 .40536 Mtetra
.68354 .40536 .68568 .40803 .6902 .40659 .68806 .40392 Mtetra
.68806 .40392 .6902 .40659 .69472 .40514 .69259 .40247 Mtetra
.69259 .40247 .69472 .40514 .69926 .40369 .69713 .40101 Mtetra
.69713 .40101 .69926 .40369 .7038 .40224 .70167 .39956 Mtetra
.70167 .39956 .7038 .40224 .70834 .40079 .70622 .3981 Mtetra
.70622 .3981 .70834 .40079 .71289 .39933 .71078 .39664 Mtetra
.71078 .39664 .71289 .39933 .71746 .39787 .71535 .39518 Mtetra
.71535 .39518 .71746 .39787 .72202 .39641 .71992 .39371 Mtetra
.71992 .39371 .72202 .39641 .7266 .39495 .7245 .39225 Mtetra
.7245 .39225 .7266 .39495 .73118 .39349 .72909 .39078 Mtetra
.72909 .39078 .73118 .39349 .73577 .39202 .73369 .3893 Mtetra
.979 .69 .389 r
.73369 .3893 .73577 .39202 .7312 .25383 .7292 .25104 Mtetra
.664 .741 .908 r
.7292 .25104 .7312 .25383 .7356 .25232 .7336 .24952 Mtetra
.7336 .24952 .7356 .25232 .74001 .2508 .73802 .24799 Mtetra
.73802 .24799 .74001 .2508 .74443 .24928 .74244 .24647 Mtetra
.74244 .24647 .74443 .24928 .74885 .24776 .74686 .24494 Mtetra
.74686 .24494 .74885 .24776 .75328 .24624 .7513 .24342 Mtetra
.7513 .24342 .75328 .24624 .75771 .24471 .75574 .24188 Mtetra
.75574 .24188 .75771 .24471 .76216 .24318 .76018 .24035 Mtetra
.76018 .24035 .76216 .24318 .76661 .24165 .76464 .23882 Mtetra
.76464 .23882 .76661 .24165 .77106 .24012 .7691 .23728 Mtetra
.7691 .23728 .77106 .24012 .77553 .23858 .77357 .23574 Mtetra
.77357 .23574 .77553 .23858 .78 .23704 .77804 .23419 Mtetra
.77804 .23419 .78 .23704 .78447 .2355 .78253 .23265 Mtetra
.78253 .23265 .78447 .2355 .78896 .23396 .78702 .2311 Mtetra
.78702 .2311 .78896 .23396 .79345 .23241 .79151 .22955 Mtetra
.79151 .22955 .79345 .23241 .79795 .23086 .79602 .228 Mtetra
.79602 .228 .79795 .23086 .80245 .22931 .80053 .22644 Mtetra
.80053 .22644 .80245 .22931 .80697 .22776 .80504 .22488 Mtetra
.80504 .22488 .80697 .22776 .81149 .2262 .80957 .22332 Mtetra
.80957 .22332 .81149 .2262 .81601 .22464 .8141 .22176 Mtetra
.8141 .22176 .81601 .22464 .82055 .22308 .81864 .2202 Mtetra
.81864 .2202 .82055 .22308 .82509 .22152 .82318 .21863 Mtetra
.82318 .21863 .82509 .22152 .82963 .21996 .82774 .21706 Mtetra
.21378 .42556 .21628 .42788 .21993 .42662 .21744 .42429 Mtetra
.21744 .42429 .21993 .42662 .22358 .42536 .22109 .42303 Mtetra
.22109 .42303 .22358 .42536 .22724 .4241 .22476 .42177 Mtetra
.22476 .42177 .22724 .4241 .23091 .42284 .22842 .4205 Mtetra
.22842 .4205 .23091 .42284 .23458 .42157 .2321 .41923 Mtetra
.2321 .41923 .23458 .42157 .23825 .4203 .23577 .41796 Mtetra
.23577 .41796 .23825 .4203 .24152 .42372 .23946 .41669 Mtetra
.234 .272 .697 r
.23946 .41669 .24152 .42372 .24522 .42245 .24274 .4201 Mtetra
.663 .742 .908 r
.24274 .4201 .24522 .42245 .24891 .42118 .24644 .41883 Mtetra
.24644 .41883 .24891 .42118 .25261 .41991 .25014 .41755 Mtetra
.25014 .41755 .25261 .41991 .25632 .41863 .25385 .41627 Mtetra
.25385 .41627 .25632 .41863 .26003 .41736 .25757 .41499 Mtetra
.25757 .41499 .26003 .41736 .26375 .41608 .26129 .41371 Mtetra
.26129 .41371 .26375 .41608 .26747 .4148 .26501 .41243 Mtetra
.26501 .41243 .26747 .4148 .2712 .41352 .26874 .41114 Mtetra
.26874 .41114 .2712 .41352 .27493 .41223 .27248 .40986 Mtetra
.27248 .40986 .27493 .41223 .27867 .41095 .27622 .40857 Mtetra
.27622 .40857 .27867 .41095 .28241 .40966 .27997 .40728 Mtetra
.27997 .40728 .28241 .40966 .28616 .40837 .28372 .40599 Mtetra
.28372 .40599 .28616 .40837 .28991 .40708 .28747 .40469 Mtetra
.947 .676 .489 r
.28747 .40469 .28991 .40708 .28672 .50288 .2842 .50055 Mtetra
.656 .751 .92 r
.2842 .50055 .28672 .50288 .29059 .50162 .28808 .49928 Mtetra
.28808 .49928 .29059 .50162 .29447 .50035 .29196 .49802 Mtetra
.29196 .49802 .29447 .50035 .29835 .49909 .29585 .49675 Mtetra
.29585 .49675 .29835 .49909 .30225 .49782 .29974 .49547 Mtetra
.29974 .49547 .30225 .49782 .30614 .49655 .30364 .4942 Mtetra
.30364 .4942 .30614 .49655 .31004 .49528 .30755 .49293 Mtetra
.30755 .49293 .31004 .49528 .31395 .49401 .31146 .49165 Mtetra
.31146 .49165 .31395 .49401 .31786 .49273 .31537 .49037 Mtetra
.31537 .49037 .31786 .49273 .32178 .49145 .3193 .48909 Mtetra
.3193 .48909 .32178 .49145 .32571 .49017 .32322 .48781 Mtetra
.32322 .48781 .32571 .49017 .32964 .48889 .32716 .48652 Mtetra
.32716 .48652 .32964 .48889 .33357 .48761 .3311 .48524 Mtetra
.3311 .48524 .33357 .48761 .33752 .48632 .33504 .48395 Mtetra
.33504 .48395 .33752 .48632 .34146 .48504 .339 .48266 Mtetra
.339 .48266 .34146 .48504 .34542 .48375 .34295 .48137 Mtetra
.34295 .48137 .34542 .48375 .34938 .48246 .34692 .48007 Mtetra
.954 .665 .449 r
.34692 .48007 .34938 .48246 .35042 .53745 .34792 .5351 Mtetra
.651 .757 .927 r
.34792 .5351 .35042 .53745 .35446 .53618 .35196 .53382 Mtetra
.35196 .53382 .35446 .53618 .3585 .5349 .35601 .53254 Mtetra
.35601 .53254 .3585 .5349 .36255 .53362 .36006 .53126 Mtetra
.36006 .53126 .36255 .53362 .36661 .53234 .36412 .52997 Mtetra
.36412 .52997 .36661 .53234 .37067 .53106 .36818 .52869 Mtetra
.36818 .52869 .37067 .53106 .37474 .52978 .37226 .5274 Mtetra
.37226 .5274 .37474 .52978 .37881 .52849 .37633 .52611 Mtetra
.37633 .52611 .37881 .52849 .38289 .5272 .38042 .52482 Mtetra
.38042 .52482 .38289 .5272 .38698 .52591 .38451 .52353 Mtetra
.38451 .52353 .38698 .52591 .39107 .52462 .38861 .52223 Mtetra
.38861 .52223 .39107 .52462 .39517 .52333 .39271 .52094 Mtetra
.39271 .52094 .39517 .52333 .39928 .52203 .39682 .51964 Mtetra
.39682 .51964 .39928 .52203 .40339 .52074 .40093 .51834 Mtetra
.40093 .51834 .40339 .52074 .40751 .51944 .40506 .51703 Mtetra
.40506 .51703 .40751 .51944 .41163 .51814 .40918 .51573 Mtetra
.40918 .51573 .41163 .51814 .41576 .51683 .41332 .51442 Mtetra
.954 .711 .533 r
.41332 .51442 .41576 .51683 .4199 .51553 .41896 .4666 Mtetra
.554 .351 .56 r
.41896 .4666 .4199 .51553 .42545 .46772 .42305 .46527 Mtetra
.655 .752 .921 r
.42305 .46527 .42545 .46772 .42954 .4664 .42714 .46394 Mtetra
.42714 .46394 .42954 .4664 .43364 .46507 .43125 .46261 Mtetra
.43125 .46261 .43364 .46507 .43774 .46374 .43536 .46128 Mtetra
.43536 .46128 .43774 .46374 .44185 .46241 .43947 .45994 Mtetra
.43947 .45994 .44185 .46241 .44597 .46107 .44359 .4586 Mtetra
.44359 .4586 .44597 .46107 .4501 .45974 .44772 .45726 Mtetra
.44772 .45726 .4501 .45974 .45667 .345 .45186 .45592 Mtetra
0 0 .269 r
.45186 .45592 .45667 .345 .46066 .34362 .45838 .34107 Mtetra
.664 .741 .908 r
.45838 .34107 .46066 .34362 .46467 .34224 .46239 .33969 Mtetra
.46239 .33969 .46467 .34224 .46867 .34086 .4664 .3383 Mtetra
.4664 .3383 .46867 .34086 .47269 .33948 .47042 .33692 Mtetra
.47042 .33692 .47269 .33948 .4767 .33809 .47444 .33553 Mtetra
.47444 .33553 .4767 .33809 .48073 .3367 .47847 .33414 Mtetra
.47847 .33414 .48073 .3367 .48476 .33531 .4825 .33274 Mtetra
.4825 .33274 .48476 .33531 .4888 .33392 .48654 .33135 Mtetra
.48654 .33135 .4888 .33392 .49284 .33253 .49059 .32995 Mtetra
.49059 .32995 .49284 .33253 .49689 .33113 .49464 .32855 Mtetra
.49464 .32855 .49689 .33113 .50094 .32973 .4987 .32715 Mtetra
.4987 .32715 .50094 .32973 .505 .32833 .50276 .32574 Mtetra
.50276 .32574 .505 .32833 .50907 .32693 .50684 .32434 Mtetra
.50684 .32434 .50907 .32693 .51314 .32553 .51091 .32293 Mtetra
.51091 .32293 .51314 .32553 .51722 .32412 .51499 .32152 Mtetra
.51499 .32152 .51722 .32412 .5213 .33231 .51908 .32011 Mtetra
.161 .148 .594 r
.51908 .32011 .5213 .33231 .5254 .3309 .52317 .32829 Mtetra
.663 .742 .909 r
.52317 .32829 .5254 .3309 .52951 .32949 .52729 .32688 Mtetra
.52729 .32688 .52951 .32949 .53363 .32808 .53141 .32547 Mtetra
.53141 .32547 .53363 .32808 .53775 .32666 .53553 .32405 Mtetra
.53553 .32405 .53775 .32666 .54188 .32525 .53967 .32263 Mtetra
.53967 .32263 .54188 .32525 .54601 .32383 .5438 .32121 Mtetra
.5438 .32121 .54601 .32383 .55015 .32241 .54795 .31978 Mtetra
.54795 .31978 .55015 .32241 .5543 .32099 .5521 .31835 Mtetra
.5521 .31835 .5543 .32099 .55845 .31956 .55626 .31693 Mtetra
.55626 .31693 .55845 .31956 .56261 .31813 .56042 .3155 Mtetra
.56042 .3155 .56261 .31813 .56677 .31671 .56459 .31406 Mtetra
.971 .676 .409 r
.56459 .31406 .56677 .31671 .57365 .49933 .57134 .49679 Mtetra
.648 .76 .931 r
.57134 .49679 .57365 .49933 .57807 .49795 .57577 .49542 Mtetra
.57577 .49542 .57807 .49795 .58251 .49658 .58021 .49404 Mtetra
.58021 .49404 .58251 .49658 .58695 .49521 .58465 .49266 Mtetra
.58465 .49266 .58695 .49521 .59139 .49383 .58911 .49128 Mtetra
.58911 .49128 .59139 .49383 .59585 .49245 .59356 .4899 Mtetra
.59356 .4899 .59585 .49245 .60031 .49107 .59803 .48851 Mtetra
.59803 .48851 .60031 .49107 .60478 .48969 .6025 .48712 Mtetra
.6025 .48712 .60478 .48969 .60925 .4883 .60698 .48573 Mtetra
.60698 .48573 .60925 .4883 .61373 .48691 .61147 .48434 Mtetra
.61147 .48434 .61373 .48691 .61822 .48552 .61596 .48295 Mtetra
.61596 .48295 .61822 .48552 .62272 .48413 .62047 .48155 Mtetra
.62047 .48155 .62272 .48413 .62722 .48273 .62497 .48015 Mtetra
.62497 .48015 .62722 .48273 .63173 .48134 .62949 .47875 Mtetra
.62949 .47875 .63173 .48134 .63625 .47994 .63401 .47735 Mtetra
.63401 .47735 .63625 .47994 .64078 .47853 .63855 .47594 Mtetra
.63855 .47594 .64078 .47853 .64531 .47713 .64308 .47453 Mtetra
.64308 .47453 .64531 .47713 .64985 .47572 .64763 .47312 Mtetra
.977 .711 .459 r
.64763 .47312 .64985 .47572 .6544 .47432 .64991 .41279 Mtetra
.551 .345 .554 r
.64991 .41279 .6544 .47432 .65656 .41401 .65438 .41136 Mtetra
.653 .754 .924 r
.65438 .41136 .65656 .41401 .66104 .41257 .65887 .40992 Mtetra
.65887 .40992 .66104 .41257 .66553 .41114 .66336 .40848 Mtetra
.66336 .40848 .66553 .41114 .67002 .4097 .66786 .40703 Mtetra
.66786 .40703 .67002 .4097 .67452 .40825 .67236 .40559 Mtetra
.67236 .40559 .67452 .40825 .67903 .40681 .67687 .40414 Mtetra
.67687 .40414 .67903 .40681 .68354 .40536 .68139 .40269 Mtetra
.68139 .40269 .68354 .40536 .68806 .40392 .68592 .40124 Mtetra
.68592 .40124 .68806 .40392 .69259 .40247 .69045 .39978 Mtetra
.69045 .39978 .69259 .40247 .69713 .40101 .695 .39832 Mtetra
.695 .39832 .69713 .40101 .70167 .39956 .69955 .39686 Mtetra
.69955 .39686 .70167 .39956 .70622 .3981 .7041 .3954 Mtetra
.7041 .3954 .70622 .3981 .71078 .39664 .70867 .39394 Mtetra
.70867 .39394 .71078 .39664 .71535 .39518 .71324 .39247 Mtetra
.71324 .39247 .71535 .39518 .71992 .39371 .71781 .391 Mtetra
.71781 .391 .71992 .39371 .7245 .39225 .7224 .38953 Mtetra
.7224 .38953 .7245 .39225 .72909 .39078 .72699 .38806 Mtetra
.72699 .38806 .72909 .39078 .73369 .3893 .73159 .38658 Mtetra
.73159 .38658 .73369 .3893 .7292 .25104 .7362 .3851 Mtetra
0 0 .395 r
.7362 .3851 .7292 .25104 .7336 .24952 .7316 .24671 Mtetra
.664 .741 .908 r
.7316 .24671 .7336 .24952 .73802 .24799 .73601 .24518 Mtetra
.73601 .24518 .73802 .24799 .74244 .24647 .74044 .24365 Mtetra
.74044 .24365 .74244 .24647 .74686 .24494 .74487 .24212 Mtetra
.74487 .24212 .74686 .24494 .7513 .24342 .74931 .24059 Mtetra
.74931 .24059 .7513 .24342 .75574 .24188 .75375 .23905 Mtetra
.75375 .23905 .75574 .24188 .76018 .24035 .75821 .23751 Mtetra
.75821 .23751 .76018 .24035 .76464 .23882 .76267 .23597 Mtetra
.76267 .23597 .76464 .23882 .7691 .23728 .76713 .23443 Mtetra
.76713 .23443 .7691 .23728 .77357 .23574 .77161 .23289 Mtetra
.77161 .23289 .77357 .23574 .77804 .23419 .77609 .23134 Mtetra
.77609 .23134 .77804 .23419 .78253 .23265 .78057 .22979 Mtetra
.78057 .22979 .78253 .23265 .78702 .2311 .78507 .22824 Mtetra
.78507 .22824 .78702 .2311 .79151 .22955 .78957 .22668 Mtetra
.78957 .22668 .79151 .22955 .79602 .228 .79408 .22512 Mtetra
.79408 .22512 .79602 .228 .80053 .22644 .79859 .22356 Mtetra
.79859 .22356 .80053 .22644 .80504 .22488 .80311 .222 Mtetra
.80311 .222 .80504 .22488 .80957 .22332 .80764 .22044 Mtetra
.80764 .22044 .80957 .22332 .8141 .22176 .81218 .21887 Mtetra
.81218 .21887 .8141 .22176 .81864 .2202 .81672 .2173 Mtetra
.81672 .2173 .81864 .2202 .82318 .21863 .82128 .21573 Mtetra
.82128 .21573 .82318 .21863 .82774 .21706 .82583 .21416 Mtetra
.21128 .42323 .21378 .42556 .21744 .42429 .21494 .42196 Mtetra
.21494 .42196 .21744 .42429 .22109 .42303 .2186 .42069 Mtetra
.2186 .42069 .22109 .42303 .22476 .42177 .22226 .41943 Mtetra
.22226 .41943 .22476 .42177 .22842 .4205 .22593 .41816 Mtetra
.22593 .41816 .22842 .4205 .2321 .41923 .22961 .41688 Mtetra
.22961 .41688 .2321 .41923 .23577 .41796 .23329 .41561 Mtetra
.23329 .41561 .23577 .41796 .23946 .41669 .23698 .41433 Mtetra
.555 .044 0 r
.23698 .41433 .23946 .41669 .24274 .4201 .24026 .41775 Mtetra
.663 .742 .908 r
.24026 .41775 .24274 .4201 .24644 .41883 .24396 .41647 Mtetra
.24396 .41647 .24644 .41883 .25014 .41755 .24767 .41519 Mtetra
.24767 .41519 .25014 .41755 .25385 .41627 .25138 .41391 Mtetra
.25138 .41391 .25385 .41627 .25757 .41499 .2551 .41263 Mtetra
.2551 .41263 .25757 .41499 .26129 .41371 .25882 .41134 Mtetra
.25882 .41134 .26129 .41371 .26501 .41243 .26255 .41006 Mtetra
.26255 .41006 .26501 .41243 .26874 .41114 .26628 .40877 Mtetra
.26628 .40877 .26874 .41114 .27248 .40986 .27002 .40748 Mtetra
.27002 .40748 .27248 .40986 .27622 .40857 .27376 .40618 Mtetra
.27376 .40618 .27622 .40857 .27997 .40728 .27751 .40489 Mtetra
.27751 .40489 .27997 .40728 .28372 .40599 .28127 .40359 Mtetra
.28127 .40359 .28372 .40599 .28747 .40469 .28503 .4023 Mtetra
.28503 .4023 .28747 .40469 .2842 .50055 .2888 .401 Mtetra
0 0 .245 r
.2888 .401 .2842 .50055 .28808 .49928 .28556 .49694 Mtetra
.656 .751 .92 r
.28556 .49694 .28808 .49928 .29196 .49802 .28944 .49567 Mtetra
.28944 .49567 .29196 .49802 .29585 .49675 .29333 .4944 Mtetra
.29333 .4944 .29585 .49675 .29974 .49547 .29723 .49312 Mtetra
.29723 .49312 .29974 .49547 .30364 .4942 .30113 .49185 Mtetra
.30113 .49185 .30364 .4942 .30755 .49293 .30504 .49057 Mtetra
.30504 .49057 .30755 .49293 .31146 .49165 .30896 .48929 Mtetra
.30896 .48929 .31146 .49165 .31537 .49037 .31288 .488 Mtetra
.31288 .488 .31537 .49037 .3193 .48909 .3168 .48672 Mtetra
.3168 .48672 .3193 .48909 .32322 .48781 .32073 .48543 Mtetra
.32073 .48543 .32322 .48781 .32716 .48652 .32467 .48415 Mtetra
.32467 .48415 .32716 .48652 .3311 .48524 .32861 .48286 Mtetra
.32861 .48286 .3311 .48524 .33504 .48395 .33256 .48156 Mtetra
.33256 .48156 .33504 .48395 .339 .48266 .33652 .48027 Mtetra
.33652 .48027 .339 .48266 .34295 .48137 .34048 .47897 Mtetra
.34048 .47897 .34295 .48137 .34692 .48007 .34445 .47768 Mtetra
.34445 .47768 .34692 .48007 .34792 .5351 .34842 .47638 Mtetra
0 0 .315 r
.34842 .47638 .34792 .5351 .35196 .53382 .34945 .53146 Mtetra
.651 .757 .927 r
.34945 .53146 .35196 .53382 .35601 .53254 .3535 .53017 Mtetra
.3535 .53017 .35601 .53254 .36006 .53126 .35756 .52889 Mtetra
.35756 .52889 .36006 .53126 .36412 .52997 .36162 .5276 Mtetra
.36162 .5276 .36412 .52997 .36818 .52869 .36569 .52631 Mtetra
.36569 .52631 .36818 .52869 .37226 .5274 .36977 .52502 Mtetra
.36977 .52502 .37226 .5274 .37633 .52611 .37385 .52373 Mtetra
.37385 .52373 .37633 .52611 .38042 .52482 .37794 .52243 Mtetra
.37794 .52243 .38042 .52482 .38451 .52353 .38203 .52114 Mtetra
.38203 .52114 .38451 .52353 .38861 .52223 .38613 .51984 Mtetra
.38613 .51984 .38861 .52223 .39271 .52094 .39024 .51854 Mtetra
.39024 .51854 .39271 .52094 .39682 .51964 .39435 .51723 Mtetra
.39435 .51723 .39682 .51964 .40093 .51834 .39847 .51593 Mtetra
.39847 .51593 .40093 .51834 .40506 .51703 .4026 .51462 Mtetra
.4026 .51462 .40506 .51703 .40918 .51573 .40673 .51331 Mtetra
.953 .711 .534 r
.40673 .51331 .40918 .51573 .41332 .51442 .41246 .46548 Mtetra
.553 .35 .56 r
.41246 .46548 .41332 .51442 .41896 .4666 .41655 .46415 Mtetra
.655 .752 .921 r
.41655 .46415 .41896 .4666 .42305 .46527 .42064 .46282 Mtetra
.42064 .46282 .42305 .46527 .42714 .46394 .42474 .46148 Mtetra
.42474 .46148 .42714 .46394 .43125 .46261 .42885 .46015 Mtetra
.42885 .46015 .43125 .46261 .43536 .46128 .43296 .45881 Mtetra
.43296 .45881 .43536 .46128 .43947 .45994 .43708 .45747 Mtetra
.43708 .45747 .43947 .45994 .44359 .4586 .44121 .45613 Mtetra
.44121 .45613 .44359 .4586 .44772 .45726 .44534 .45478 Mtetra
.44534 .45478 .44772 .45726 .45186 .45592 .44948 .45344 Mtetra
.961 .698 .492 r
.44948 .45344 .45186 .45592 .45838 .34107 .45609 .33852 Mtetra
.664 .741 .908 r
.45609 .33852 .45838 .34107 .46239 .33969 .4601 .33713 Mtetra
.4601 .33713 .46239 .33969 .4664 .3383 .46412 .33574 Mtetra
.46412 .33574 .4664 .3383 .47042 .33692 .46814 .33435 Mtetra
.46814 .33435 .47042 .33692 .47444 .33553 .47217 .33296 Mtetra
.47217 .33296 .47444 .33553 .47847 .33414 .4762 .33156 Mtetra
.4762 .33156 .47847 .33414 .4825 .33274 .48024 .33016 Mtetra
.48024 .33016 .4825 .33274 .48654 .33135 .48428 .32876 Mtetra
.48428 .32876 .48654 .33135 .49059 .32995 .48833 .32736 Mtetra
.48833 .32736 .49059 .32995 .49464 .32855 .49239 .32596 Mtetra
.49239 .32596 .49464 .32855 .4987 .32715 .49645 .32455 Mtetra
.49645 .32455 .4987 .32715 .50276 .32574 .50052 .32315 Mtetra
.50052 .32315 .50276 .32574 .50684 .32434 .50459 .32174 Mtetra
.50459 .32174 .50684 .32434 .51091 .32293 .50867 .32032 Mtetra
.50867 .32032 .51091 .32293 .51499 .32152 .51276 .31891 Mtetra
.51276 .31891 .51499 .32152 .51908 .32011 .51685 .31749 Mtetra
.51685 .31749 .51908 .32011 .52317 .32829 .52095 .31607 Mtetra
.161 .148 .594 r
.52095 .31607 .52317 .32829 .52729 .32688 .52506 .32427 Mtetra
.663 .742 .909 r
.52506 .32427 .52729 .32688 .53141 .32547 .52918 .32285 Mtetra
.52918 .32285 .53141 .32547 .53553 .32405 .53331 .32142 Mtetra
.53331 .32142 .53553 .32405 .53967 .32263 .53745 .32 Mtetra
.53745 .32 .53967 .32263 .5438 .32121 .54159 .31857 Mtetra
.54159 .31857 .5438 .32121 .54795 .31978 .54574 .31715 Mtetra
.54574 .31715 .54795 .31978 .5521 .31835 .54989 .31572 Mtetra
.54989 .31572 .5521 .31835 .55626 .31693 .55406 .31428 Mtetra
.55406 .31428 .55626 .31693 .56042 .3155 .55822 .31285 Mtetra
.55822 .31285 .56042 .3155 .56459 .31406 .5624 .31141 Mtetra
.971 .676 .409 r
.5624 .31141 .56459 .31406 .57134 .49679 .56903 .49425 Mtetra
.648 .76 .931 r
.56903 .49425 .57134 .49679 .57577 .49542 .57346 .49288 Mtetra
.57346 .49288 .57577 .49542 .58021 .49404 .57791 .49149 Mtetra
.57791 .49149 .58021 .49404 .58465 .49266 .58236 .49011 Mtetra
.58236 .49011 .58465 .49266 .58911 .49128 .58681 .48873 Mtetra
.58681 .48873 .58911 .49128 .59356 .4899 .59127 .48734 Mtetra
.59127 .48734 .59356 .4899 .59803 .48851 .59575 .48595 Mtetra
.59575 .48595 .59803 .48851 .6025 .48712 .60022 .48456 Mtetra
.60022 .48456 .6025 .48712 .60698 .48573 .60471 .48316 Mtetra
.60471 .48316 .60698 .48573 .61147 .48434 .6092 .48177 Mtetra
.6092 .48177 .61147 .48434 .61596 .48295 .6137 .48037 Mtetra
.6137 .48037 .61596 .48295 .62047 .48155 .61821 .47897 Mtetra
.61821 .47897 .62047 .48155 .62497 .48015 .62272 .47756 Mtetra
.62272 .47756 .62497 .48015 .62949 .47875 .62724 .47616 Mtetra
.62724 .47616 .62949 .47875 .63401 .47735 .63177 .47475 Mtetra
.63177 .47475 .63401 .47735 .63855 .47594 .63631 .47334 Mtetra
.63631 .47334 .63855 .47594 .64308 .47453 .64085 .47193 Mtetra
.64085 .47193 .64308 .47453 .64763 .47312 .6454 .47051 Mtetra
.977 .711 .459 r
.6454 .47051 .64763 .47312 .64991 .41279 .64772 .41014 Mtetra
.653 .754 .924 r
.64772 .41014 .64991 .41279 .65438 .41136 .6522 .4087 Mtetra
.6522 .4087 .65438 .41136 .65887 .40992 .65669 .40726 Mtetra
.65669 .40726 .65887 .40992 .66336 .40848 .66118 .40581 Mtetra
.66118 .40581 .66336 .40848 .66786 .40703 .66569 .40436 Mtetra
.66569 .40436 .66786 .40703 .67236 .40559 .6702 .40291 Mtetra
.6702 .40291 .67236 .40559 .67687 .40414 .67471 .40146 Mtetra
.67471 .40146 .67687 .40414 .68139 .40269 .67924 .40001 Mtetra
.67924 .40001 .68139 .40269 .68592 .40124 .68377 .39855 Mtetra
.68377 .39855 .68592 .40124 .69045 .39978 .68831 .39709 Mtetra
.68831 .39709 .69045 .39978 .695 .39832 .69286 .39563 Mtetra
.69286 .39563 .695 .39832 .69955 .39686 .69741 .39416 Mtetra
.69741 .39416 .69955 .39686 .7041 .3954 .70197 .3927 Mtetra
.70197 .3927 .7041 .3954 .70867 .39394 .70654 .39123 Mtetra
.70654 .39123 .70867 .39394 .71324 .39247 .71112 .38976 Mtetra
.71112 .38976 .71324 .39247 .71781 .391 .7157 .38828 Mtetra
.7157 .38828 .71781 .391 .7224 .38953 .72029 .38681 Mtetra
.72029 .38681 .7224 .38953 .72699 .38806 .72489 .38533 Mtetra
.72489 .38533 .72699 .38806 .73159 .38658 .72949 .38385 Mtetra
.72949 .38385 .73159 .38658 .7362 .3851 .73411 .38237 Mtetra
.98 .69 .387 r
.73411 .38237 .7362 .3851 .7316 .24671 .72958 .24389 Mtetra
.664 .741 .908 r
.72958 .24389 .7316 .24671 .73601 .24518 .73401 .24236 Mtetra
.73401 .24236 .73601 .24518 .74044 .24365 .73844 .24082 Mtetra
.73844 .24082 .74044 .24365 .74487 .24212 .74287 .23929 Mtetra
.74287 .23929 .74487 .24212 .74931 .24059 .74732 .23775 Mtetra
.74732 .23775 .74931 .24059 .75375 .23905 .75177 .23621 Mtetra
.75177 .23621 .75375 .23905 .75821 .23751 .75622 .23467 Mtetra
.75622 .23467 .75821 .23751 .76267 .23597 .76069 .23312 Mtetra
.76069 .23312 .76267 .23597 .76713 .23443 .76516 .23158 Mtetra
.76516 .23158 .76713 .23443 .77161 .23289 .76964 .23003 Mtetra
.76964 .23003 .77161 .23289 .77609 .23134 .77412 .22848 Mtetra
.77412 .22848 .77609 .23134 .78057 .22979 .77861 .22692 Mtetra
.77861 .22692 .78057 .22979 .78507 .22824 .78311 .22536 Mtetra
.78311 .22536 .78507 .22824 .78957 .22668 .78762 .22381 Mtetra
.78762 .22381 .78957 .22668 .79408 .22512 .79213 .22224 Mtetra
.79213 .22224 .79408 .22512 .79859 .22356 .79665 .22068 Mtetra
.79665 .22068 .79859 .22356 .80311 .222 .80118 .21911 Mtetra
.80118 .21911 .80311 .222 .80764 .22044 .80572 .21754 Mtetra
.80572 .21754 .80764 .22044 .81218 .21887 .81026 .21597 Mtetra
.81026 .21597 .81218 .21887 .81672 .2173 .81481 .2144 Mtetra
.81481 .2144 .81672 .2173 .82128 .21573 .81936 .21282 Mtetra
.81936 .21282 .82128 .21573 .82583 .21416 .82392 .21124 Mtetra
.20877 .42089 .21128 .42323 .21494 .42196 .21243 .41962 Mtetra
.21243 .41962 .21494 .42196 .2186 .42069 .21609 .41835 Mtetra
.21609 .41835 .2186 .42069 .22226 .41943 .21976 .41708 Mtetra
.21976 .41708 .22226 .41943 .22593 .41816 .22344 .41581 Mtetra
.22344 .41581 .22593 .41816 .22961 .41688 .22711 .41453 Mtetra
.22711 .41453 .22961 .41688 .23329 .41561 .2308 .41325 Mtetra
.2308 .41325 .23329 .41561 .23698 .41433 .23449 .41197 Mtetra
.23449 .41197 .23698 .41433 .24026 .41775 .23818 .41069 Mtetra
.233 .271 .697 r
.23818 .41069 .24026 .41775 .24396 .41647 .24147 .41411 Mtetra
.663 .742 .908 r
.24147 .41411 .24396 .41647 .24767 .41519 .24518 .41282 Mtetra
.24518 .41282 .24767 .41519 .25138 .41391 .2489 .41154 Mtetra
.2489 .41154 .25138 .41391 .2551 .41263 .25262 .41025 Mtetra
.25262 .41025 .2551 .41263 .25882 .41134 .25635 .40897 Mtetra
.25635 .40897 .25882 .41134 .26255 .41006 .26008 .40768 Mtetra
.26008 .40768 .26255 .41006 .26628 .40877 .26381 .40638 Mtetra
.26381 .40638 .26628 .40877 .27002 .40748 .26756 .40509 Mtetra
.26756 .40509 .27002 .40748 .27376 .40618 .2713 .40379 Mtetra
.2713 .40379 .27376 .40618 .27751 .40489 .27506 .4025 Mtetra
.27506 .4025 .27751 .40489 .28127 .40359 .27881 .4012 Mtetra
.27881 .4012 .28127 .40359 .28503 .4023 .28258 .3999 Mtetra
.28258 .3999 .28503 .4023 .2888 .401 .28635 .39859 Mtetra
.28635 .39859 .2888 .401 .28556 .49694 .29012 .39729 Mtetra
0 0 .245 r
.29012 .39729 .28556 .49694 .28944 .49567 .28692 .49332 Mtetra
.656 .751 .92 r
.28692 .49332 .28944 .49567 .29333 .4944 .29081 .49204 Mtetra
.29081 .49204 .29333 .4944 .29723 .49312 .29471 .49076 Mtetra
.29471 .49076 .29723 .49312 .30113 .49185 .29862 .48948 Mtetra
.29862 .48948 .30113 .49185 .30504 .49057 .30253 .4882 Mtetra
.30253 .4882 .30504 .49057 .30896 .48929 .30645 .48692 Mtetra
.30645 .48692 .30896 .48929 .31288 .488 .31037 .48563 Mtetra
.31037 .48563 .31288 .488 .3168 .48672 .3143 .48434 Mtetra
.3143 .48434 .3168 .48672 .32073 .48543 .31824 .48305 Mtetra
.31824 .48305 .32073 .48543 .32467 .48415 .32218 .48176 Mtetra
.32218 .48176 .32467 .48415 .32861 .48286 .32612 .48047 Mtetra
.32612 .48047 .32861 .48286 .33256 .48156 .33008 .47917 Mtetra
.33008 .47917 .33256 .48156 .33652 .48027 .33404 .47788 Mtetra
.33404 .47788 .33652 .48027 .34048 .47897 .338 .47658 Mtetra
.338 .47658 .34048 .47897 .34445 .47768 .34197 .47528 Mtetra
.34197 .47528 .34445 .47768 .34842 .47638 .34595 .47397 Mtetra
.955 .665 .448 r
.34595 .47397 .34842 .47638 .34945 .53146 .34694 .52909 Mtetra
.651 .757 .927 r
.34694 .52909 .34945 .53146 .3535 .53017 .35099 .5278 Mtetra
.35099 .5278 .3535 .53017 .35756 .52889 .35505 .52651 Mtetra
.35505 .52651 .35756 .52889 .36162 .5276 .35912 .52522 Mtetra
.35912 .52522 .36162 .5276 .36569 .52631 .36319 .52393 Mtetra
.36319 .52393 .36569 .52631 .36977 .52502 .36727 .52263 Mtetra
.36727 .52263 .36977 .52502 .37385 .52373 .37136 .52134 Mtetra
.37136 .52134 .37385 .52373 .37794 .52243 .37545 .52004 Mtetra
.37545 .52004 .37794 .52243 .38203 .52114 .37955 .51874 Mtetra
.37955 .51874 .38203 .52114 .38613 .51984 .38365 .51744 Mtetra
.38365 .51744 .38613 .51984 .39024 .51854 .38776 .51613 Mtetra
.38776 .51613 .39024 .51854 .39435 .51723 .39188 .51482 Mtetra
.39188 .51482 .39435 .51723 .39847 .51593 .396 .51352 Mtetra
.396 .51352 .39847 .51593 .4026 .51462 .40013 .51221 Mtetra
.953 .711 .535 r
.40013 .51221 .4026 .51462 .40673 .51331 .40595 .46435 Mtetra
.553 .35 .559 r
.40595 .46435 .40673 .51331 .41246 .46548 .41004 .46302 Mtetra
.655 .752 .921 r
.41004 .46302 .41246 .46548 .41655 .46415 .41413 .46169 Mtetra
.41413 .46169 .41655 .46415 .42064 .46282 .41823 .46035 Mtetra
.41823 .46035 .42064 .46282 .42474 .46148 .42233 .45902 Mtetra
.42233 .45902 .42474 .46148 .42885 .46015 .42645 .45768 Mtetra
.42645 .45768 .42885 .46015 .43296 .45881 .43056 .45633 Mtetra
.43056 .45633 .43296 .45881 .43708 .45747 .43469 .45499 Mtetra
.43469 .45499 .43708 .45747 .44121 .45613 .43882 .45365 Mtetra
.43882 .45365 .44121 .45613 .44534 .45478 .44295 .4523 Mtetra
.44295 .4523 .44534 .45478 .44948 .45344 .44709 .45095 Mtetra
.44709 .45095 .44948 .45344 .45609 .33852 .45124 .4496 Mtetra
0 0 .266 r
.45124 .4496 .45609 .33852 .4601 .33713 .45781 .33456 Mtetra
.664 .741 .908 r
.45781 .33456 .4601 .33713 .46412 .33574 .46183 .33317 Mtetra
.46183 .33317 .46412 .33574 .46814 .33435 .46586 .33178 Mtetra
.46586 .33178 .46814 .33435 .47217 .33296 .46989 .33038 Mtetra
.46989 .33038 .47217 .33296 .4762 .33156 .47392 .32898 Mtetra
.47392 .32898 .4762 .33156 .48024 .33016 .47797 .32758 Mtetra
.47797 .32758 .48024 .33016 .48428 .32876 .48201 .32617 Mtetra
.48201 .32617 .48428 .32876 .48833 .32736 .48607 .32477 Mtetra
.48607 .32477 .48833 .32736 .49239 .32596 .49013 .32336 Mtetra
.49013 .32336 .49239 .32596 .49645 .32455 .49419 .32195 Mtetra
.49419 .32195 .49645 .32455 .50052 .32315 .49827 .32054 Mtetra
.49827 .32054 .50052 .32315 .50459 .32174 .50235 .31913 Mtetra
.50235 .31913 .50459 .32174 .50867 .32032 .50643 .31771 Mtetra
.50643 .31771 .50867 .32032 .51276 .31891 .51052 .31629 Mtetra
.51052 .31629 .51276 .31891 .51685 .31749 .51462 .31487 Mtetra
.51462 .31487 .51685 .31749 .52095 .31607 .51872 .31345 Mtetra
.816 .371 0 r
.51872 .31345 .52095 .31607 .52506 .32427 .52282 .32164 Mtetra
.663 .742 .909 r
.52282 .32164 .52506 .32427 .52918 .32285 .52695 .32022 Mtetra
.52695 .32022 .52918 .32285 .53331 .32142 .53109 .31879 Mtetra
.53109 .31879 .53331 .32142 .53745 .32 .53523 .31737 Mtetra
.53523 .31737 .53745 .32 .54159 .31857 .53937 .31594 Mtetra
.53937 .31594 .54159 .31857 .54574 .31715 .54353 .3145 Mtetra
.54353 .3145 .54574 .31715 .54989 .31572 .54768 .31307 Mtetra
.54768 .31307 .54989 .31572 .55406 .31428 .55185 .31163 Mtetra
.55185 .31163 .55406 .31428 .55822 .31285 .55602 .31019 Mtetra
.97 .676 .41 r
.55602 .31019 .55822 .31285 .5624 .31141 .56228 .49309 Mtetra
.534 .306 .516 r
.56228 .49309 .5624 .31141 .56903 .49425 .56671 .49171 Mtetra
.648 .76 .931 r
.56671 .49171 .56903 .49425 .57346 .49288 .57115 .49032 Mtetra
.57115 .49032 .57346 .49288 .57791 .49149 .5756 .48894 Mtetra
.5756 .48894 .57791 .49149 .58236 .49011 .58005 .48755 Mtetra
.58005 .48755 .58236 .49011 .58681 .48873 .58451 .48616 Mtetra
.58451 .48616 .58681 .48873 .59127 .48734 .58898 .48477 Mtetra
.58898 .48477 .59127 .48734 .59575 .48595 .59345 .48338 Mtetra
.59345 .48338 .59575 .48595 .60022 .48456 .59794 .48198 Mtetra
.59794 .48198 .60022 .48456 .60471 .48316 .60243 .48058 Mtetra
.60243 .48058 .60471 .48316 .6092 .48177 .60692 .47918 Mtetra
.60692 .47918 .6092 .48177 .6137 .48037 .61143 .47778 Mtetra
.61143 .47778 .6137 .48037 .61821 .47897 .61594 .47637 Mtetra
.61594 .47637 .61821 .47897 .62272 .47756 .62046 .47497 Mtetra
.62046 .47497 .62272 .47756 .62724 .47616 .62498 .47356 Mtetra
.62498 .47356 .62724 .47616 .63177 .47475 .62952 .47215 Mtetra
.62952 .47215 .63177 .47475 .63631 .47334 .63406 .47073 Mtetra
.63406 .47073 .63631 .47334 .64085 .47193 .63861 .46931 Mtetra
.63861 .46931 .64085 .47193 .6454 .47051 .64316 .4679 Mtetra
.977 .711 .459 r
.64316 .4679 .6454 .47051 .64772 .41014 .64552 .40748 Mtetra
.653 .754 .924 r
.64552 .40748 .64772 .41014 .6522 .4087 .65001 .40603 Mtetra
.65001 .40603 .6522 .4087 .65669 .40726 .6545 .40458 Mtetra
.6545 .40458 .65669 .40726 .66118 .40581 .659 .40314 Mtetra
.659 .40314 .66118 .40581 .66569 .40436 .66351 .40168 Mtetra
.66351 .40168 .66569 .40436 .6702 .40291 .66803 .40023 Mtetra
.66803 .40023 .6702 .40291 .67471 .40146 .67255 .39877 Mtetra
.67255 .39877 .67471 .40146 .67924 .40001 .67708 .39731 Mtetra
.67708 .39731 .67924 .40001 .68377 .39855 .68161 .39585 Mtetra
.68161 .39585 .68377 .39855 .68831 .39709 .68616 .39439 Mtetra
.68616 .39439 .68831 .39709 .69286 .39563 .69071 .39292 Mtetra
.69071 .39292 .69286 .39563 .69741 .39416 .69527 .39145 Mtetra
.69527 .39145 .69741 .39416 .70197 .3927 .69984 .38998 Mtetra
.69984 .38998 .70197 .3927 .70654 .39123 .70441 .38851 Mtetra
.70441 .38851 .70654 .39123 .71112 .38976 .70899 .38703 Mtetra
.70899 .38703 .71112 .38976 .7157 .38828 .71358 .38556 Mtetra
.71358 .38556 .7157 .38828 .72029 .38681 .71818 .38408 Mtetra
.71818 .38408 .72029 .38681 .72489 .38533 .72278 .38259 Mtetra
.72278 .38259 .72489 .38533 .72949 .38385 .72739 .38111 Mtetra
.72739 .38111 .72949 .38385 .73411 .38237 .73201 .37962 Mtetra
.98 .69 .387 r
.73201 .37962 .73411 .38237 .72958 .24389 .72756 .24106 Mtetra
.664 .741 .908 r
.72756 .24106 .72958 .24389 .73401 .24236 .73199 .23952 Mtetra
.73199 .23952 .73401 .24236 .73844 .24082 .73643 .23799 Mtetra
.73643 .23799 .73844 .24082 .74287 .23929 .74087 .23645 Mtetra
.74087 .23645 .74287 .23929 .74732 .23775 .74532 .23491 Mtetra
.74532 .23491 .74732 .23775 .75177 .23621 .74977 .23336 Mtetra
.74977 .23336 .75177 .23621 .75622 .23467 .75423 .23182 Mtetra
.75423 .23182 .75622 .23467 .76069 .23312 .7587 .23027 Mtetra
.7587 .23027 .76069 .23312 .76516 .23158 .76318 .22871 Mtetra
.76318 .22871 .76516 .23158 .76964 .23003 .76766 .22716 Mtetra
.76766 .22716 .76964 .23003 .77412 .22848 .77215 .2256 Mtetra
.77215 .2256 .77412 .22848 .77861 .22692 .77665 .22405 Mtetra
.77665 .22405 .77861 .22692 .78311 .22536 .78115 .22248 Mtetra
.78115 .22248 .78311 .22536 .78762 .22381 .78566 .22092 Mtetra
.78566 .22092 .78762 .22381 .79213 .22224 .79018 .21935 Mtetra
.79018 .21935 .79213 .22224 .79665 .22068 .79471 .21779 Mtetra
.79471 .21779 .79665 .22068 .80118 .21911 .79924 .21621 Mtetra
.79924 .21621 .80118 .21911 .80572 .21754 .80378 .21464 Mtetra
.80378 .21464 .80572 .21754 .81026 .21597 .80833 .21306 Mtetra
.80833 .21306 .81026 .21597 .81481 .2144 .81288 .21149 Mtetra
.81288 .21149 .81481 .2144 .81936 .21282 .81744 .20991 Mtetra
.81744 .20991 .81936 .21282 .82392 .21124 .82201 .20832 Mtetra
.20626 .41855 .20877 .42089 .21243 .41962 .20992 .41728 Mtetra
.20992 .41728 .21243 .41962 .21609 .41835 .21358 .416 Mtetra
.21358 .416 .21609 .41835 .21976 .41708 .21726 .41473 Mtetra
.21726 .41473 .21976 .41708 .22344 .41581 .22093 .41345 Mtetra
.22093 .41345 .22344 .41581 .22711 .41453 .22461 .41217 Mtetra
.22461 .41217 .22711 .41453 .2308 .41325 .2283 .41089 Mtetra
.2283 .41089 .2308 .41325 .23449 .41197 .23199 .40961 Mtetra
.23199 .40961 .23449 .41197 .23818 .41069 .23569 .40832 Mtetra
.551 .041 0 r
.23569 .40832 .23818 .41069 .24147 .41411 .23898 .41174 Mtetra
.663 .742 .908 r
.23898 .41174 .24147 .41411 .24518 .41282 .24269 .41045 Mtetra
.24269 .41045 .24518 .41282 .2489 .41154 .24641 .40916 Mtetra
.24641 .40916 .2489 .41154 .25262 .41025 .25014 .40787 Mtetra
.25014 .40787 .25262 .41025 .25635 .40897 .25387 .40658 Mtetra
.25387 .40658 .25635 .40897 .26008 .40768 .2576 .40529 Mtetra
.2576 .40529 .26008 .40768 .26381 .40638 .26134 .40399 Mtetra
.26134 .40399 .26381 .40638 .26756 .40509 .26509 .4027 Mtetra
.26509 .4027 .26756 .40509 .2713 .40379 .26884 .4014 Mtetra
.26884 .4014 .2713 .40379 .27506 .4025 .27259 .4001 Mtetra
.27259 .4001 .27506 .4025 .27881 .4012 .27635 .39879 Mtetra
.27635 .39879 .27881 .4012 .28258 .3999 .28012 .39749 Mtetra
.28012 .39749 .28258 .3999 .28635 .39859 .28389 .39618 Mtetra
.28389 .39618 .28635 .39859 .29012 .39729 .28767 .39487 Mtetra
.948 .676 .487 r
.28767 .39487 .29012 .39729 .28692 .49332 .28438 .49096 Mtetra
.656 .751 .92 r
.28438 .49096 .28692 .49332 .29081 .49204 .28828 .48968 Mtetra
.28828 .48968 .29081 .49204 .29471 .49076 .29219 .4884 Mtetra
.29219 .4884 .29471 .49076 .29862 .48948 .2961 .48712 Mtetra
.2961 .48712 .29862 .48948 .30253 .4882 .30001 .48583 Mtetra
.30001 .48583 .30253 .4882 .30645 .48692 .30393 .48454 Mtetra
.30393 .48454 .30645 .48692 .31037 .48563 .30786 .48325 Mtetra
.30786 .48325 .31037 .48563 .3143 .48434 .31179 .48196 Mtetra
.31179 .48196 .3143 .48434 .31824 .48305 .31573 .48067 Mtetra
.31573 .48067 .31824 .48305 .32218 .48176 .31968 .47937 Mtetra
.31968 .47937 .32218 .48176 .32612 .48047 .32363 .47808 Mtetra
.32363 .47808 .32612 .48047 .33008 .47917 .32758 .47678 Mtetra
.32758 .47678 .33008 .47917 .33404 .47788 .33155 .47548 Mtetra
.33155 .47548 .33404 .47788 .338 .47658 .33552 .47417 Mtetra
.33552 .47417 .338 .47658 .34197 .47528 .33949 .47287 Mtetra
.33949 .47287 .34197 .47528 .34595 .47397 .34347 .47156 Mtetra
.955 .665 .448 r
.34347 .47156 .34595 .47397 .34694 .52909 .34441 .52671 Mtetra
.651 .757 .927 r
.34441 .52671 .34694 .52909 .35099 .5278 .34847 .52542 Mtetra
.34847 .52542 .35099 .5278 .35505 .52651 .35254 .52413 Mtetra
.35254 .52413 .35505 .52651 .35912 .52522 .35661 .52283 Mtetra
.35661 .52283 .35912 .52522 .36319 .52393 .36069 .52154 Mtetra
.36069 .52154 .36319 .52393 .36727 .52263 .36477 .52024 Mtetra
.36477 .52024 .36727 .52263 .37136 .52134 .36886 .51894 Mtetra
.36886 .51894 .37136 .52134 .37545 .52004 .37295 .51764 Mtetra
.37295 .51764 .37545 .52004 .37955 .51874 .37706 .51633 Mtetra
.37706 .51633 .37955 .51874 .38365 .51744 .38117 .51503 Mtetra
.38117 .51503 .38365 .51744 .38776 .51613 .38528 .51372 Mtetra
.38528 .51372 .38776 .51613 .39188 .51482 .3894 .51241 Mtetra
.3894 .51241 .39188 .51482 .396 .51352 .39353 .5111 Mtetra
.39353 .5111 .396 .51352 .40013 .51221 .39766 .50978 Mtetra
.953 .711 .535 r
.39766 .50978 .40013 .51221 .40595 .46435 .40352 .46189 Mtetra
.655 .752 .921 r
.40352 .46189 .40595 .46435 .41004 .46302 .40761 .46056 Mtetra
.40761 .46056 .41004 .46302 .41413 .46169 .41171 .45922 Mtetra
.41171 .45922 .41413 .46169 .41823 .46035 .41581 .45788 Mtetra
.41581 .45788 .41823 .46035 .42233 .45902 .41992 .45654 Mtetra
.41992 .45654 .42233 .45902 .42645 .45768 .42403 .4552 Mtetra
.42403 .4552 .42645 .45768 .43056 .45633 .42816 .45385 Mtetra
.42816 .45385 .43056 .45633 .43469 .45499 .43228 .45251 Mtetra
.43228 .45251 .43469 .45499 .43882 .45365 .43642 .45116 Mtetra
.43642 .45116 .43882 .45365 .44295 .4523 .44056 .4498 Mtetra
.44056 .4498 .44295 .4523 .44709 .45095 .4447 .44845 Mtetra
.4447 .44845 .44709 .45095 .45124 .4496 .44886 .44709 Mtetra
.44886 .44709 .45124 .4496 .45781 .33456 .45302 .44574 Mtetra
0 0 .266 r
.45302 .44574 .45781 .33456 .46183 .33317 .45954 .33059 Mtetra
.664 .741 .908 r
.45954 .33059 .46183 .33317 .46586 .33178 .46357 .32919 Mtetra
.46357 .32919 .46586 .33178 .46989 .33038 .4676 .32779 Mtetra
.4676 .32779 .46989 .33038 .47392 .32898 .47164 .32639 Mtetra
.47164 .32639 .47392 .32898 .47797 .32758 .47569 .32499 Mtetra
.47569 .32499 .47797 .32758 .48201 .32617 .47974 .32358 Mtetra
.47974 .32358 .48201 .32617 .48607 .32477 .4838 .32217 Mtetra
.4838 .32217 .48607 .32477 .49013 .32336 .48786 .32076 Mtetra
.48786 .32076 .49013 .32336 .49419 .32195 .49193 .31934 Mtetra
.49193 .31934 .49419 .32195 .49827 .32054 .49601 .31793 Mtetra
.49601 .31793 .49827 .32054 .50235 .31913 .50009 .31651 Mtetra
.50009 .31651 .50235 .31913 .50643 .31771 .50418 .31509 Mtetra
.50418 .31509 .50643 .31771 .51052 .31629 .50827 .31367 Mtetra
.50827 .31367 .51052 .31629 .51462 .31487 .51238 .31225 Mtetra
.51238 .31225 .51462 .31487 .51872 .31345 .51648 .31082 Mtetra
.51648 .31082 .51872 .31345 .52282 .32164 .5206 .30939 Mtetra
.159 .146 .593 r
.5206 .30939 .52282 .32164 .52695 .32022 .52471 .31759 Mtetra
.663 .742 .909 r
.52471 .31759 .52695 .32022 .53109 .31879 .52885 .31616 Mtetra
.52885 .31616 .53109 .31879 .53523 .31737 .533 .31472 Mtetra
.533 .31472 .53523 .31737 .53937 .31594 .53715 .31329 Mtetra
.53715 .31329 .53937 .31594 .54353 .3145 .5413 .31185 Mtetra
.5413 .31185 .54353 .3145 .54768 .31307 .54547 .31042 Mtetra
.54547 .31042 .54768 .31307 .55185 .31163 .54964 .30897 Mtetra
.54964 .30897 .55185 .31163 .55602 .31019 .55381 .30753 Mtetra
.97 .676 .41 r
.55381 .30753 .55602 .31019 .56228 .49309 .55995 .49054 Mtetra
.648 .76 .931 r
.55995 .49054 .56228 .49309 .56671 .49171 .56438 .48915 Mtetra
.56438 .48915 .56671 .49171 .57115 .49032 .56883 .48777 Mtetra
.56883 .48777 .57115 .49032 .5756 .48894 .57328 .48638 Mtetra
.57328 .48638 .5756 .48894 .58005 .48755 .57774 .48499 Mtetra
.57774 .48499 .58005 .48755 .58451 .48616 .5822 .48359 Mtetra
.5822 .48359 .58451 .48616 .58898 .48477 .58668 .4822 Mtetra
.58668 .4822 .58898 .48477 .59345 .48338 .59116 .4808 Mtetra
.59116 .4808 .59345 .48338 .59794 .48198 .59564 .4794 Mtetra
.59564 .4794 .59794 .48198 .60243 .48058 .60014 .478 Mtetra
.60014 .478 .60243 .48058 .60692 .47918 .60464 .47659 Mtetra
.60464 .47659 .60692 .47918 .61143 .47778 .60915 .47518 Mtetra
.60915 .47518 .61143 .47778 .61594 .47637 .61367 .47377 Mtetra
.61367 .47377 .61594 .47637 .62046 .47497 .61819 .47236 Mtetra
.61819 .47236 .62046 .47497 .62498 .47356 .62272 .47095 Mtetra
.62272 .47095 .62498 .47356 .62952 .47215 .62726 .46953 Mtetra
.62726 .46953 .62952 .47215 .63406 .47073 .6318 .46811 Mtetra
.6318 .46811 .63406 .47073 .63861 .46931 .63636 .46669 Mtetra
.63636 .46669 .63861 .46931 .64316 .4679 .64092 .46527 Mtetra
.977 .711 .459 r
.64092 .46527 .64316 .4679 .64552 .40748 .64332 .40481 Mtetra
.653 .754 .924 r
.64332 .40481 .64552 .40748 .65001 .40603 .64781 .40336 Mtetra
.64781 .40336 .65001 .40603 .6545 .40458 .65231 .40191 Mtetra
.65231 .40191 .6545 .40458 .659 .40314 .65682 .40045 Mtetra
.65682 .40045 .659 .40314 .66351 .40168 .66133 .399 Mtetra
.66133 .399 .66351 .40168 .66803 .40023 .66585 .39754 Mtetra
.66585 .39754 .66803 .40023 .67255 .39877 .67038 .39608 Mtetra
.67038 .39608 .67255 .39877 .67708 .39731 .67491 .39461 Mtetra
.67491 .39461 .67708 .39731 .68161 .39585 .67945 .39315 Mtetra
.67945 .39315 .68161 .39585 .68616 .39439 .684 .39168 Mtetra
.684 .39168 .68616 .39439 .69071 .39292 .68856 .39021 Mtetra
.68856 .39021 .69071 .39292 .69527 .39145 .69312 .38874 Mtetra
.69312 .38874 .69527 .39145 .69984 .38998 .69769 .38726 Mtetra
.69769 .38726 .69984 .38998 .70441 .38851 .70227 .38578 Mtetra
.70227 .38578 .70441 .38851 .70899 .38703 .70686 .3843 Mtetra
.70686 .3843 .70899 .38703 .71358 .38556 .71145 .38282 Mtetra
.71145 .38282 .71358 .38556 .71818 .38408 .71605 .38134 Mtetra
.71605 .38134 .71818 .38408 .72278 .38259 .72066 .37985 Mtetra
.72066 .37985 .72278 .38259 .72739 .38111 .72528 .37836 Mtetra
.72528 .37836 .72739 .38111 .73201 .37962 .7299 .37687 Mtetra
.7299 .37687 .73201 .37962 .72756 .24106 .73453 .37537 Mtetra
0 0 .392 r
.73453 .37537 .72756 .24106 .73199 .23952 .72997 .23668 Mtetra
.664 .741 .908 r
.72997 .23668 .73199 .23952 .73643 .23799 .73441 .23514 Mtetra
.73441 .23514 .73643 .23799 .74087 .23645 .73886 .2336 Mtetra
.73886 .2336 .74087 .23645 .74532 .23491 .74331 .23205 Mtetra
.74331 .23205 .74532 .23491 .74977 .23336 .74777 .2305 Mtetra
.74777 .2305 .74977 .23336 .75423 .23182 .75224 .22895 Mtetra
.75224 .22895 .75423 .23182 .7587 .23027 .75671 .2274 Mtetra
.75671 .2274 .7587 .23027 .76318 .22871 .76119 .22584 Mtetra
.76119 .22584 .76318 .22871 .76766 .22716 .76568 .22429 Mtetra
.76568 .22429 .76766 .22716 .77215 .2256 .77018 .22272 Mtetra
.77018 .22272 .77215 .2256 .77665 .22405 .77468 .22116 Mtetra
.77468 .22116 .77665 .22405 .78115 .22248 .77919 .2196 Mtetra
.77919 .2196 .78115 .22248 .78566 .22092 .7837 .21803 Mtetra
.7837 .21803 .78566 .22092 .79018 .21935 .78823 .21646 Mtetra
.78823 .21646 .79018 .21935 .79471 .21779 .79276 .21488 Mtetra
.79276 .21488 .79471 .21779 .79924 .21621 .7973 .21331 Mtetra
.7973 .21331 .79924 .21621 .80378 .21464 .80184 .21173 Mtetra
.80184 .21173 .80378 .21464 .80833 .21306 .80639 .21015 Mtetra
.80639 .21015 .80833 .21306 .81288 .21149 .81095 .20857 Mtetra
.81095 .20857 .81288 .21149 .81744 .20991 .81552 .20698 Mtetra
.81552 .20698 .81744 .20991 .82201 .20832 .82009 .20539 Mtetra
.20373 .4162 .20626 .41855 .20992 .41728 .2074 .41492 Mtetra
.2074 .41492 .20992 .41728 .21358 .416 .21107 .41365 Mtetra
.21107 .41365 .21358 .416 .21726 .41473 .21474 .41237 Mtetra
.21474 .41237 .21726 .41473 .22093 .41345 .21842 .41109 Mtetra
.21842 .41109 .22093 .41345 .22461 .41217 .22211 .40981 Mtetra
.22211 .40981 .22461 .41217 .2283 .41089 .2258 .40852 Mtetra
.2258 .40852 .2283 .41089 .23199 .40961 .22949 .40724 Mtetra
.22949 .40724 .23199 .40961 .23569 .40832 .23319 .40595 Mtetra
.551 .041 0 r
.23319 .40595 .23569 .40832 .23898 .41174 .23648 .40936 Mtetra
.663 .742 .908 r
.23648 .40936 .23898 .41174 .24269 .41045 .2402 .40807 Mtetra
.2402 .40807 .24269 .41045 .24641 .40916 .24392 .40678 Mtetra
.24392 .40678 .24641 .40916 .25014 .40787 .24765 .40549 Mtetra
.24765 .40549 .25014 .40787 .25387 .40658 .25138 .40419 Mtetra
.25138 .40419 .25387 .40658 .2576 .40529 .25512 .4029 Mtetra
.25512 .4029 .2576 .40529 .26134 .40399 .25886 .4016 Mtetra
.25886 .4016 .26134 .40399 .26509 .4027 .26261 .4003 Mtetra
.26261 .4003 .26509 .4027 .26884 .4014 .26636 .39899 Mtetra
.26636 .39899 .26884 .4014 .27259 .4001 .27012 .39769 Mtetra
.27012 .39769 .27259 .4001 .27635 .39879 .27389 .39638 Mtetra
.27389 .39638 .27635 .39879 .28012 .39749 .27766 .39507 Mtetra
.27766 .39507 .28012 .39749 .28389 .39618 .28143 .39376 Mtetra
.28143 .39376 .28389 .39618 .28767 .39487 .28521 .39245 Mtetra
.28521 .39245 .28767 .39487 .28438 .49096 .289 .39114 Mtetra
0 0 .242 r
.289 .39114 .28438 .49096 .28828 .48968 .28575 .48731 Mtetra
.656 .751 .92 r
.28575 .48731 .28828 .48968 .29219 .4884 .28965 .48603 Mtetra
.28965 .48603 .29219 .4884 .2961 .48712 .29357 .48474 Mtetra
.29357 .48474 .2961 .48712 .30001 .48583 .29749 .48345 Mtetra
.29749 .48345 .30001 .48583 .30393 .48454 .30141 .48216 Mtetra
.30141 .48216 .30393 .48454 .30786 .48325 .30534 .48087 Mtetra
.30534 .48087 .30786 .48325 .31179 .48196 .30928 .47957 Mtetra
.30928 .47957 .31179 .48196 .31573 .48067 .31322 .47828 Mtetra
.31322 .47828 .31573 .48067 .31968 .47937 .31717 .47698 Mtetra
.31717 .47698 .31968 .47937 .32363 .47808 .32112 .47568 Mtetra
.32112 .47568 .32363 .47808 .32758 .47678 .32508 .47437 Mtetra
.32508 .47437 .32758 .47678 .33155 .47548 .32905 .47307 Mtetra
.32905 .47307 .33155 .47548 .33552 .47417 .33302 .47176 Mtetra
.33302 .47176 .33552 .47417 .33949 .47287 .337 .47045 Mtetra
.337 .47045 .33949 .47287 .34347 .47156 .34099 .46914 Mtetra
.34099 .46914 .34347 .47156 .34441 .52671 .34498 .46783 Mtetra
0 0 .311 r
.34498 .46783 .34441 .52671 .34847 .52542 .34595 .52303 Mtetra
.651 .757 .927 r
.34595 .52303 .34847 .52542 .35254 .52413 .35002 .52174 Mtetra
.35002 .52174 .35254 .52413 .35661 .52283 .35409 .52044 Mtetra
.35409 .52044 .35661 .52283 .36069 .52154 .35817 .51914 Mtetra
.35817 .51914 .36069 .52154 .36477 .52024 .36226 .51784 Mtetra
.36226 .51784 .36477 .52024 .36886 .51894 .36635 .51653 Mtetra
.36635 .51653 .36886 .51894 .37295 .51764 .37045 .51523 Mtetra
.37045 .51523 .37295 .51764 .37706 .51633 .37456 .51392 Mtetra
.37456 .51392 .37706 .51633 .38117 .51503 .37867 .51261 Mtetra
.37867 .51261 .38117 .51503 .38528 .51372 .38279 .5113 Mtetra
.38279 .5113 .38528 .51372 .3894 .51241 .38691 .50998 Mtetra
.38691 .50998 .3894 .51241 .39353 .5111 .39105 .50867 Mtetra
.952 .711 .536 r
.39105 .50867 .39353 .5111 .39766 .50978 .397 .46076 Mtetra
.552 .348 .558 r
.397 .46076 .39766 .50978 .40352 .46189 .40109 .45943 Mtetra
.655 .752 .921 r
.40109 .45943 .40352 .46189 .40761 .46056 .40518 .45809 Mtetra
.40518 .45809 .40761 .46056 .41171 .45922 .40928 .45675 Mtetra
.40928 .45675 .41171 .45922 .41581 .45788 .41339 .4554 Mtetra
.41339 .4554 .41581 .45788 .41992 .45654 .4175 .45406 Mtetra
.4175 .45406 .41992 .45654 .42403 .4552 .42162 .45271 Mtetra
.42162 .45271 .42403 .4552 .42816 .45385 .42574 .45136 Mtetra
.42574 .45136 .42816 .45385 .43228 .45251 .42987 .45001 Mtetra
.42987 .45001 .43228 .45251 .43642 .45116 .43401 .44866 Mtetra
.43401 .44866 .43642 .45116 .44056 .4498 .43816 .4473 Mtetra
.43816 .4473 .44056 .4498 .4447 .44845 .44231 .44595 Mtetra
.44231 .44595 .4447 .44845 .44886 .44709 .44646 .44459 Mtetra
.44646 .44459 .44886 .44709 .45302 .44574 .45063 .44323 Mtetra
.962 .698 .49 r
.45063 .44323 .45302 .44574 .45954 .33059 .45724 .32801 Mtetra
.664 .741 .908 r
.45724 .32801 .45954 .33059 .46357 .32919 .46127 .32661 Mtetra
.46127 .32661 .46357 .32919 .4676 .32779 .46531 .3252 Mtetra
.46531 .3252 .4676 .32779 .47164 .32639 .46935 .3238 Mtetra
.46935 .3238 .47164 .32639 .47569 .32499 .4734 .32239 Mtetra
.4734 .32239 .47569 .32499 .47974 .32358 .47746 .32098 Mtetra
.47746 .32098 .47974 .32358 .4838 .32217 .48152 .31956 Mtetra
.48152 .31956 .4838 .32217 .48786 .32076 .48559 .31815 Mtetra
.48559 .31815 .48786 .32076 .49193 .31934 .48966 .31673 Mtetra
.48966 .31673 .49193 .31934 .49601 .31793 .49374 .31531 Mtetra
.49374 .31531 .49601 .31793 .50009 .31651 .49783 .31389 Mtetra
.49783 .31389 .50009 .31651 .50418 .31509 .50192 .31247 Mtetra
.50192 .31247 .50418 .31509 .50827 .31367 .50602 .31104 Mtetra
.50602 .31104 .50827 .31367 .51238 .31225 .51013 .30961 Mtetra
.51013 .30961 .51238 .31225 .51648 .31082 .51424 .30818 Mtetra
.51424 .30818 .51648 .31082 .5206 .30939 .51836 .30675 Mtetra
.51836 .30675 .5206 .30939 .52471 .31759 .52248 .30531 Mtetra
.159 .146 .593 r
.52248 .30531 .52471 .31759 .52885 .31616 .52661 .31351 Mtetra
.663 .742 .909 r
.52661 .31351 .52885 .31616 .533 .31472 .53076 .31207 Mtetra
.53076 .31207 .533 .31472 .53715 .31329 .53492 .31064 Mtetra
.53492 .31064 .53715 .31329 .5413 .31185 .53908 .3092 Mtetra
.53908 .3092 .5413 .31185 .54547 .31042 .54325 .30775 Mtetra
.54325 .30775 .54547 .31042 .54964 .30897 .54742 .30631 Mtetra
.54742 .30631 .54964 .30897 .55381 .30753 .5516 .30486 Mtetra
.97 .676 .41 r
.5516 .30486 .55381 .30753 .55995 .49054 .55761 .48798 Mtetra
.648 .76 .931 r
.55761 .48798 .55995 .49054 .56438 .48915 .56205 .48659 Mtetra
.56205 .48659 .56438 .48915 .56883 .48777 .5665 .4852 Mtetra
.5665 .4852 .56883 .48777 .57328 .48638 .57096 .48381 Mtetra
.57096 .48381 .57328 .48638 .57774 .48499 .57542 .48241 Mtetra
.57542 .48241 .57774 .48499 .5822 .48359 .57989 .48101 Mtetra
.57989 .48101 .5822 .48359 .58668 .4822 .58437 .47961 Mtetra
.58437 .47961 .58668 .4822 .59116 .4808 .58885 .47821 Mtetra
.58885 .47821 .59116 .4808 .59564 .4794 .59334 .47681 Mtetra
.59334 .47681 .59564 .4794 .60014 .478 .59784 .4754 Mtetra
.59784 .4754 .60014 .478 .60464 .47659 .60235 .47399 Mtetra
.60235 .47399 .60464 .47659 .60915 .47518 .60686 .47258 Mtetra
.60686 .47258 .60915 .47518 .61367 .47377 .61139 .47117 Mtetra
.61139 .47117 .61367 .47377 .61819 .47236 .61591 .46975 Mtetra
.61591 .46975 .61819 .47236 .62272 .47095 .62045 .46833 Mtetra
.62045 .46833 .62272 .47095 .62726 .46953 .62499 .46691 Mtetra
.62499 .46691 .62726 .46953 .6318 .46811 .62954 .46549 Mtetra
.62954 .46549 .6318 .46811 .63636 .46669 .6341 .46406 Mtetra
.6341 .46406 .63636 .46669 .64092 .46527 .63867 .46264 Mtetra
.977 .711 .459 r
.63867 .46264 .64092 .46527 .64332 .40481 .64111 .40213 Mtetra
.653 .754 .924 r
.64111 .40213 .64332 .40481 .64781 .40336 .64561 .40068 Mtetra
.64561 .40068 .64781 .40336 .65231 .40191 .65011 .39922 Mtetra
.65011 .39922 .65231 .40191 .65682 .40045 .65462 .39776 Mtetra
.65462 .39776 .65682 .40045 .66133 .399 .65914 .3963 Mtetra
.65914 .3963 .66133 .399 .66585 .39754 .66366 .39484 Mtetra
.66366 .39484 .66585 .39754 .67038 .39608 .6682 .39337 Mtetra
.6682 .39337 .67038 .39608 .67491 .39461 .67274 .39191 Mtetra
.67274 .39191 .67491 .39461 .67945 .39315 .67728 .39044 Mtetra
.67728 .39044 .67945 .39315 .684 .39168 .68184 .38896 Mtetra
.68184 .38896 .684 .39168 .68856 .39021 .6864 .38749 Mtetra
.6864 .38749 .68856 .39021 .69312 .38874 .69097 .38601 Mtetra
.69097 .38601 .69312 .38874 .69769 .38726 .69555 .38453 Mtetra
.69555 .38453 .69769 .38726 .70227 .38578 .70013 .38305 Mtetra
.70013 .38305 .70227 .38578 .70686 .3843 .70472 .38157 Mtetra
.70472 .38157 .70686 .3843 .71145 .38282 .70932 .38008 Mtetra
.70932 .38008 .71145 .38282 .71605 .38134 .71393 .37859 Mtetra
.71393 .37859 .71605 .38134 .72066 .37985 .71854 .3771 Mtetra
.71854 .3771 .72066 .37985 .72528 .37836 .72316 .37561 Mtetra
.72316 .37561 .72528 .37836 .7299 .37687 .72779 .37411 Mtetra
.72779 .37411 .7299 .37687 .73453 .37537 .73242 .37261 Mtetra
.98 .689 .384 r
.73242 .37261 .73453 .37537 .72997 .23668 .72795 .23384 Mtetra
.664 .741 .908 r
.72795 .23384 .72997 .23668 .73441 .23514 .73239 .23229 Mtetra
.73239 .23229 .73441 .23514 .73886 .2336 .73684 .23074 Mtetra
.73684 .23074 .73886 .2336 .74331 .23205 .7413 .22919 Mtetra
.7413 .22919 .74331 .23205 .74777 .2305 .74577 .22764 Mtetra
.74577 .22764 .74777 .2305 .75224 .22895 .75024 .22608 Mtetra
.75024 .22608 .75224 .22895 .75671 .2274 .75472 .22453 Mtetra
.75472 .22453 .75671 .2274 .76119 .22584 .7592 .22296 Mtetra
.7592 .22296 .76119 .22584 .76568 .22429 .7637 .2214 Mtetra
.7637 .2214 .76568 .22429 .77018 .22272 .7682 .21984 Mtetra
.7682 .21984 .77018 .22272 .77468 .22116 .7727 .21827 Mtetra
.7727 .21827 .77468 .22116 .77919 .2196 .77722 .2167 Mtetra
.77722 .2167 .77919 .2196 .7837 .21803 .78174 .21513 Mtetra
.78174 .21513 .7837 .21803 .78823 .21646 .78627 .21355 Mtetra
.78627 .21355 .78823 .21646 .79276 .21488 .7908 .21197 Mtetra
.7908 .21197 .79276 .21488 .7973 .21331 .79534 .21039 Mtetra
.79534 .21039 .7973 .21331 .80184 .21173 .79989 .20881 Mtetra
.79989 .20881 .80184 .21173 .80639 .21015 .80445 .20722 Mtetra
.80445 .20722 .80639 .21015 .81095 .20857 .80902 .20564 Mtetra
.80902 .20564 .81095 .20857 .81552 .20698 .81359 .20405 Mtetra
.81359 .20405 .81552 .20698 .82009 .20539 .81817 .20245 Mtetra
.2012 .41384 .20373 .4162 .2074 .41492 .20487 .41257 Mtetra
.20487 .41257 .2074 .41492 .21107 .41365 .20854 .41129 Mtetra
.20854 .41129 .21107 .41365 .21474 .41237 .21222 .41 Mtetra
.21222 .41 .21474 .41237 .21842 .41109 .2159 .40872 Mtetra
.2159 .40872 .21842 .41109 .22211 .40981 .21959 .40743 Mtetra
.21959 .40743 .22211 .40981 .2258 .40852 .22329 .40615 Mtetra
.22329 .40615 .2258 .40852 .22949 .40724 .22699 .40486 Mtetra
.22699 .40486 .22949 .40724 .23319 .40595 .23069 .40357 Mtetra
.23069 .40357 .23319 .40595 .23648 .40936 .2344 .40227 Mtetra
.23 .269 .696 r
.2344 .40227 .23648 .40936 .2402 .40807 .23769 .40569 Mtetra
.663 .742 .908 r
.23769 .40569 .2402 .40807 .24392 .40678 .24142 .40439 Mtetra
.24142 .40439 .24392 .40678 .24765 .40549 .24515 .40309 Mtetra
.24515 .40309 .24765 .40549 .25138 .40419 .24889 .4018 Mtetra
.24889 .4018 .25138 .40419 .25512 .4029 .25263 .4005 Mtetra
.25263 .4005 .25512 .4029 .25886 .4016 .25637 .39919 Mtetra
.25637 .39919 .25886 .4016 .26261 .4003 .26012 .39789 Mtetra
.26012 .39789 .26261 .4003 .26636 .39899 .26388 .39658 Mtetra
.26388 .39658 .26636 .39899 .27012 .39769 .26764 .39528 Mtetra
.26764 .39528 .27012 .39769 .27389 .39638 .27141 .39397 Mtetra
.27141 .39397 .27389 .39638 .27766 .39507 .27519 .39265 Mtetra
.27519 .39265 .27766 .39507 .28143 .39376 .27896 .39134 Mtetra
.27896 .39134 .28143 .39376 .28521 .39245 .28275 .39002 Mtetra
.28275 .39002 .28521 .39245 .289 .39114 .28654 .38871 Mtetra
.28654 .38871 .289 .39114 .28575 .48731 .29033 .38739 Mtetra
0 0 .242 r
.29033 .38739 .28575 .48731 .28965 .48603 .28712 .48365 Mtetra
.656 .751 .92 r
.28712 .48365 .28965 .48603 .29357 .48474 .29103 .48236 Mtetra
.29103 .48236 .29357 .48474 .29749 .48345 .29496 .48107 Mtetra
.29496 .48107 .29749 .48345 .30141 .48216 .29888 .47977 Mtetra
.29888 .47977 .30141 .48216 .30534 .48087 .30282 .47848 Mtetra
.30282 .47848 .30534 .48087 .30928 .47957 .30676 .47718 Mtetra
.30676 .47718 .30928 .47957 .31322 .47828 .3107 .47588 Mtetra
.3107 .47588 .31322 .47828 .31717 .47698 .31466 .47457 Mtetra
.31466 .47457 .31717 .47698 .32112 .47568 .31861 .47327 Mtetra
.31861 .47327 .32112 .47568 .32508 .47437 .32258 .47196 Mtetra
.32258 .47196 .32508 .47437 .32905 .47307 .32655 .47066 Mtetra
.32655 .47066 .32905 .47307 .33302 .47176 .33052 .46935 Mtetra
.33052 .46935 .33302 .47176 .337 .47045 .3345 .46803 Mtetra
.3345 .46803 .337 .47045 .34099 .46914 .33849 .46672 Mtetra
.33849 .46672 .34099 .46914 .34498 .46783 .34249 .4654 Mtetra
.955 .665 .446 r
.34249 .4654 .34498 .46783 .34595 .52303 .34342 .52064 Mtetra
.651 .757 .927 r
.34342 .52064 .34595 .52303 .35002 .52174 .34749 .51934 Mtetra
.34749 .51934 .35002 .52174 .35409 .52044 .35157 .51804 Mtetra
.35157 .51804 .35409 .52044 .35817 .51914 .35565 .51673 Mtetra
.35565 .51673 .35817 .51914 .36226 .51784 .35974 .51543 Mtetra
.35974 .51543 .36226 .51784 .36635 .51653 .36384 .51412 Mtetra
.36384 .51412 .36635 .51653 .37045 .51523 .36794 .51281 Mtetra
.36794 .51281 .37045 .51523 .37456 .51392 .37205 .5115 Mtetra
.37205 .5115 .37456 .51392 .37867 .51261 .37617 .51019 Mtetra
.37617 .51019 .37867 .51261 .38279 .5113 .38029 .50887 Mtetra
.38029 .50887 .38279 .5113 .38691 .50998 .38442 .50755 Mtetra
.952 .711 .537 r
.38442 .50755 .38691 .50998 .39105 .50867 .39047 .45963 Mtetra
.551 .348 .558 r
.39047 .45963 .39105 .50867 .397 .46076 .39455 .45829 Mtetra
.655 .752 .921 r
.39455 .45829 .397 .46076 .40109 .45943 .39864 .45695 Mtetra
.39864 .45695 .40109 .45943 .40518 .45809 .40274 .45561 Mtetra
.40274 .45561 .40518 .45809 .40928 .45675 .40684 .45427 Mtetra
.40684 .45427 .40928 .45675 .41339 .4554 .41095 .45292 Mtetra
.41095 .45292 .41339 .4554 .4175 .45406 .41507 .45157 Mtetra
.41507 .45157 .4175 .45406 .42162 .45271 .41919 .45022 Mtetra
.41919 .45022 .42162 .45271 .42574 .45136 .42332 .44887 Mtetra
.42332 .44887 .42574 .45136 .42987 .45001 .42746 .44751 Mtetra
.42746 .44751 .42987 .45001 .43401 .44866 .4316 .44616 Mtetra
.4316 .44616 .43401 .44866 .43816 .4473 .43575 .4448 Mtetra
.43575 .4448 .43816 .4473 .44231 .44595 .4399 .44343 Mtetra
.4399 .44343 .44231 .44595 .44646 .44459 .44406 .44207 Mtetra
.44406 .44207 .44646 .44459 .45063 .44323 .44823 .44071 Mtetra
.44823 .44071 .45063 .44323 .45724 .32801 .4524 .43934 Mtetra
0 0 .264 r
.4524 .43934 .45724 .32801 .46127 .32661 .45897 .32401 Mtetra
.664 .741 .908 r
.45897 .32401 .46127 .32661 .46531 .3252 .46301 .3226 Mtetra
.46301 .3226 .46531 .3252 .46935 .3238 .46706 .32119 Mtetra
.46706 .32119 .46935 .3238 .4734 .32239 .47111 .31978 Mtetra
.47111 .31978 .4734 .32239 .47746 .32098 .47517 .31836 Mtetra
.47517 .31836 .47746 .32098 .48152 .31956 .47924 .31695 Mtetra
.47924 .31695 .48152 .31956 .48559 .31815 .48331 .31553 Mtetra
.48331 .31553 .48559 .31815 .48966 .31673 .48739 .31411 Mtetra
.48739 .31411 .48966 .31673 .49374 .31531 .49147 .31268 Mtetra
.49147 .31268 .49374 .31531 .49783 .31389 .49556 .31126 Mtetra
.49556 .31126 .49783 .31389 .50192 .31247 .49966 .30983 Mtetra
.49966 .30983 .50192 .31247 .50602 .31104 .50376 .3084 Mtetra
.50376 .3084 .50602 .31104 .51013 .30961 .50787 .30697 Mtetra
.50787 .30697 .51013 .30961 .51424 .30818 .51199 .30554 Mtetra
.968 .679 .427 r
.51199 .30554 .51424 .30818 .51836 .30675 .51555 .50327 Mtetra
.532 .305 .515 r
.51555 .50327 .51836 .30675 .52248 .30531 .51994 .5019 Mtetra
.51994 .5019 .52248 .30531 .52661 .31351 .52434 .50053 Mtetra
.532 .304 .514 r
.52434 .50053 .52661 .31351 .53076 .31207 .52874 .49915 Mtetra
.52874 .49915 .53076 .31207 .53492 .31064 .53315 .49778 Mtetra
.53315 .49778 .53492 .31064 .53908 .3092 .53757 .4964 Mtetra
.53757 .4964 .53908 .3092 .54325 .30775 .542 .49501 Mtetra
.542 .49501 .54325 .30775 .54742 .30631 .54643 .49363 Mtetra
.54643 .49363 .54742 .30631 .5516 .30486 .55087 .49224 Mtetra
.521 .296 .513 r
.55087 .49224 .5516 .30486 .55761 .48798 .55526 .48541 Mtetra
.648 .76 .931 r
.55526 .48541 .55761 .48798 .56205 .48659 .55971 .48402 Mtetra
.55971 .48402 .56205 .48659 .5665 .4852 .56416 .48263 Mtetra
.56416 .48263 .5665 .4852 .57096 .48381 .56863 .48123 Mtetra
.56863 .48123 .57096 .48381 .57542 .48241 .57309 .47983 Mtetra
.57309 .47983 .57542 .48241 .57989 .48101 .57757 .47843 Mtetra
.57757 .47843 .57989 .48101 .58437 .47961 .58205 .47702 Mtetra
.58205 .47702 .58437 .47961 .58885 .47821 .58654 .47562 Mtetra
.58654 .47562 .58885 .47821 .59334 .47681 .59104 .47421 Mtetra
.59104 .47421 .59334 .47681 .59784 .4754 .59554 .4728 Mtetra
.59554 .4728 .59784 .4754 .60235 .47399 .60005 .47138 Mtetra
.60005 .47138 .60235 .47399 .60686 .47258 .60457 .46997 Mtetra
.60457 .46997 .60686 .47258 .61139 .47117 .6091 .46855 Mtetra
.6091 .46855 .61139 .47117 .61591 .46975 .61363 .46713 Mtetra
.61363 .46713 .61591 .46975 .62045 .46833 .61817 .46571 Mtetra
.61817 .46571 .62045 .46833 .62499 .46691 .62272 .46428 Mtetra
.62272 .46428 .62499 .46691 .62954 .46549 .62728 .46286 Mtetra
.976 .717 .474 r
.62728 .46286 .62954 .46549 .6341 .46406 .63026 .41294 Mtetra
.551 .347 .558 r
.63026 .41294 .6341 .46406 .63867 .46264 .63476 .41149 Mtetra
.63476 .41149 .63867 .46264 .64111 .40213 .63927 .41003 Mtetra
0 0 0 r
.63927 .41003 .64111 .40213 .64561 .40068 .6434 .39799 Mtetra
.653 .754 .924 r
.6434 .39799 .64561 .40068 .65011 .39922 .64791 .39653 Mtetra
.64791 .39653 .65011 .39922 .65462 .39776 .65242 .39506 Mtetra
.65242 .39506 .65462 .39776 .65914 .3963 .65694 .3936 Mtetra
.65694 .3936 .65914 .3963 .66366 .39484 .66147 .39213 Mtetra
.66147 .39213 .66366 .39484 .6682 .39337 .66601 .39066 Mtetra
.66601 .39066 .6682 .39337 .67274 .39191 .67056 .38919 Mtetra
.67056 .38919 .67274 .39191 .67728 .39044 .67511 .38772 Mtetra
.67511 .38772 .67728 .39044 .68184 .38896 .67967 .38624 Mtetra
.67967 .38624 .68184 .38896 .6864 .38749 .68423 .38476 Mtetra
.68423 .38476 .6864 .38749 .69097 .38601 .68881 .38328 Mtetra
.68881 .38328 .69097 .38601 .69555 .38453 .69339 .38179 Mtetra
.69339 .38179 .69555 .38453 .70013 .38305 .69798 .38031 Mtetra
.69798 .38031 .70013 .38305 .70472 .38157 .70258 .37882 Mtetra
.70258 .37882 .70472 .38157 .70932 .38008 .70718 .37733 Mtetra
.70718 .37733 .70932 .38008 .71393 .37859 .71179 .37584 Mtetra
.71179 .37584 .71393 .37859 .71854 .3771 .71641 .37434 Mtetra
.71641 .37434 .71854 .3771 .72316 .37561 .72104 .37284 Mtetra
.72104 .37284 .72316 .37561 .72779 .37411 .72567 .37134 Mtetra
.72567 .37134 .72779 .37411 .73242 .37261 .73031 .36984 Mtetra
.98 .689 .384 r
.73031 .36984 .73242 .37261 .72795 .23384 .72592 .23098 Mtetra
.664 .741 .908 r
.72592 .23098 .72795 .23384 .73239 .23229 .73037 .22943 Mtetra
.73037 .22943 .73239 .23229 .73684 .23074 .73482 .22788 Mtetra
.73482 .22788 .73684 .23074 .7413 .22919 .73929 .22632 Mtetra
.73929 .22632 .7413 .22919 .74577 .22764 .74376 .22476 Mtetra
.74376 .22476 .74577 .22764 .75024 .22608 .74823 .2232 Mtetra
.74823 .2232 .75024 .22608 .75472 .22453 .75272 .22164 Mtetra
.75272 .22164 .75472 .22453 .7592 .22296 .75721 .22008 Mtetra
.75721 .22008 .7592 .22296 .7637 .2214 .7617 .21851 Mtetra
.7617 .21851 .7637 .2214 .7682 .21984 .76621 .21694 Mtetra
.76621 .21694 .7682 .21984 .7727 .21827 .77072 .21537 Mtetra
.77072 .21537 .7727 .21827 .77722 .2167 .77524 .21379 Mtetra
.77524 .21379 .77722 .2167 .78174 .21513 .77977 .21221 Mtetra
.77977 .21221 .78174 .21513 .78627 .21355 .7843 .21064 Mtetra
.7843 .21064 .78627 .21355 .7908 .21197 .78884 .20905 Mtetra
.78884 .20905 .7908 .21197 .79534 .21039 .79339 .20747 Mtetra
.79339 .20747 .79534 .21039 .79989 .20881 .79794 .20588 Mtetra
.79794 .20588 .79989 .20881 .80445 .20722 .80251 .20429 Mtetra
.80251 .20429 .80445 .20722 .80902 .20564 .80707 .2027 Mtetra
.80707 .2027 .80902 .20564 .81359 .20405 .81165 .2011 Mtetra
.81165 .2011 .81359 .20405 .81817 .20245 .81623 .19951 Mtetra
.19867 .41148 .2012 .41384 .20487 .41257 .20234 .4102 Mtetra
.20234 .4102 .20487 .41257 .20854 .41129 .20601 .40892 Mtetra
.20601 .40892 .20854 .41129 .21222 .41 .2097 .40763 Mtetra
.2097 .40763 .21222 .41 .2159 .40872 .21338 .40635 Mtetra
.21338 .40635 .2159 .40872 .21959 .40743 .21707 .40506 Mtetra
.21707 .40506 .21959 .40743 .22329 .40615 .22077 .40377 Mtetra
.22077 .40377 .22329 .40615 .22699 .40486 .22447 .40247 Mtetra
.22447 .40247 .22699 .40486 .23069 .40357 .22818 .40118 Mtetra
.22818 .40118 .23069 .40357 .2344 .40227 .23189 .39988 Mtetra
.548 .038 0 r
.23189 .39988 .2344 .40227 .23769 .40569 .23518 .40329 Mtetra
.663 .742 .908 r
.23518 .40329 .23769 .40569 .24142 .40439 .23891 .402 Mtetra
.23891 .402 .24142 .40439 .24515 .40309 .24265 .4007 Mtetra
.24265 .4007 .24515 .40309 .24889 .4018 .24639 .39939 Mtetra
.24639 .39939 .24889 .4018 .25263 .4005 .25013 .39809 Mtetra
.25013 .39809 .25263 .4005 .25637 .39919 .25388 .39678 Mtetra
.25388 .39678 .25637 .39919 .26012 .39789 .25763 .39548 Mtetra
.25763 .39548 .26012 .39789 .26388 .39658 .26139 .39417 Mtetra
.26139 .39417 .26388 .39658 .26764 .39528 .26516 .39286 Mtetra
.26516 .39286 .26764 .39528 .27141 .39397 .26893 .39154 Mtetra
.26893 .39154 .27141 .39397 .27519 .39265 .27271 .39023 Mtetra
.27271 .39023 .27519 .39265 .27896 .39134 .27649 .38891 Mtetra
.27649 .38891 .27896 .39134 .28275 .39002 .28028 .38759 Mtetra
.28028 .38759 .28275 .39002 .28654 .38871 .28407 .38627 Mtetra
.28407 .38627 .28654 .38871 .29033 .38739 .28787 .38495 Mtetra
.949 .676 .485 r
.28787 .38495 .29033 .38739 .28712 .48365 .28457 .48127 Mtetra
.656 .751 .92 r
.28457 .48127 .28712 .48365 .29103 .48236 .28849 .47997 Mtetra
.28849 .47997 .29103 .48236 .29496 .48107 .29242 .47868 Mtetra
.29242 .47868 .29496 .48107 .29888 .47977 .29635 .47738 Mtetra
.29635 .47738 .29888 .47977 .30282 .47848 .30029 .47608 Mtetra
.30029 .47608 .30282 .47848 .30676 .47718 .30423 .47477 Mtetra
.30423 .47477 .30676 .47718 .3107 .47588 .30818 .47347 Mtetra
.30818 .47347 .3107 .47588 .31466 .47457 .31214 .47216 Mtetra
.31214 .47216 .31466 .47457 .31861 .47327 .3161 .47086 Mtetra
.3161 .47086 .31861 .47327 .32258 .47196 .32006 .46955 Mtetra
.32006 .46955 .32258 .47196 .32655 .47066 .32404 .46824 Mtetra
.32404 .46824 .32655 .47066 .33052 .46935 .32802 .46692 Mtetra
.32802 .46692 .33052 .46935 .3345 .46803 .332 .46561 Mtetra
.332 .46561 .3345 .46803 .33849 .46672 .33599 .46429 Mtetra
.33599 .46429 .33849 .46672 .34249 .4654 .33999 .46297 Mtetra
.955 .667 .451 r
.33999 .46297 .34249 .4654 .34342 .52064 .34059 .52348 Mtetra
.183 0 0 r
.34059 .52348 .34342 .52064 .34749 .51934 .34467 .52218 Mtetra
.34467 .52218 .34749 .51934 .35157 .51804 .34876 .52087 Mtetra
.34876 .52087 .35157 .51804 .35565 .51673 .35285 .51957 Mtetra
.35285 .51957 .35565 .51673 .35974 .51543 .35696 .51826 Mtetra
.35696 .51826 .35974 .51543 .36384 .51412 .36106 .51695 Mtetra
.36106 .51695 .36384 .51412 .36794 .51281 .36518 .51564 Mtetra
.36518 .51564 .36794 .51281 .37205 .5115 .3693 .51433 Mtetra
.3693 .51433 .37205 .5115 .37617 .51019 .37342 .51301 Mtetra
.37342 .51301 .37617 .51019 .38029 .50887 .37756 .5117 Mtetra
.37756 .5117 .38029 .50887 .38442 .50755 .3817 .51038 Mtetra
.976 .739 .513 r
.3817 .51038 .38442 .50755 .39047 .45963 .38801 .45716 Mtetra
.655 .752 .921 r
.38801 .45716 .39047 .45963 .39455 .45829 .3921 .45582 Mtetra
.3921 .45582 .39455 .45829 .39864 .45695 .39619 .45447 Mtetra
.39619 .45447 .39864 .45695 .40274 .45561 .40029 .45313 Mtetra
.40029 .45313 .40274 .45561 .40684 .45427 .4044 .45178 Mtetra
.4044 .45178 .40684 .45427 .41095 .45292 .40851 .45043 Mtetra
.40851 .45043 .41095 .45292 .41507 .45157 .41263 .44908 Mtetra
.41263 .44908 .41507 .45157 .41919 .45022 .41676 .44772 Mtetra
.41676 .44772 .41919 .45022 .42332 .44887 .42089 .44636 Mtetra
.42089 .44636 .42332 .44887 .42746 .44751 .42503 .44501 Mtetra
.42503 .44501 .42746 .44751 .4316 .44616 .42918 .44364 Mtetra
.42918 .44364 .4316 .44616 .43575 .4448 .43333 .44228 Mtetra
.43333 .44228 .43575 .4448 .4399 .44343 .43749 .44092 Mtetra
.43749 .44092 .4399 .44343 .44406 .44207 .44166 .43955 Mtetra
.44166 .43955 .44406 .44207 .44823 .44071 .44583 .43818 Mtetra
.44583 .43818 .44823 .44071 .4524 .43934 .45 .43681 Mtetra
.962 .698 .488 r
.45 .43681 .4524 .43934 .45897 .32401 .45666 .32141 Mtetra
.664 .741 .908 r
.45666 .32141 .45897 .32401 .46301 .3226 .46071 .32 Mtetra
.46071 .32 .46301 .3226 .46706 .32119 .46476 .31858 Mtetra
.46476 .31858 .46706 .32119 .47111 .31978 .46882 .31717 Mtetra
.46882 .31717 .47111 .31978 .47517 .31836 .47288 .31575 Mtetra
.47288 .31575 .47517 .31836 .47924 .31695 .47695 .31433 Mtetra
.47695 .31433 .47924 .31695 .48331 .31553 .48103 .3129 Mtetra
.48103 .3129 .48331 .31553 .48739 .31411 .48511 .31148 Mtetra
.48511 .31148 .48739 .31411 .49147 .31268 .4892 .31005 Mtetra
.4892 .31005 .49147 .31268 .49556 .31126 .49329 .30862 Mtetra
.49329 .30862 .49556 .31126 .49966 .30983 .49739 .30719 Mtetra
.49739 .30719 .49966 .30983 .50376 .3084 .5015 .30576 Mtetra
.5015 .30576 .50376 .3084 .50787 .30697 .50561 .30432 Mtetra
.968 .679 .428 r
.50561 .30432 .50787 .30697 .51199 .30554 .50876 .50211 Mtetra
.532 .304 .514 r
.50876 .50211 .51199 .30554 .51555 .50327 .51315 .50074 Mtetra
.648 .76 .931 r
.51315 .50074 .51555 .50327 .51994 .5019 .51755 .49937 Mtetra
.51755 .49937 .51994 .5019 .52434 .50053 .52195 .49799 Mtetra
.52195 .49799 .52434 .50053 .52874 .49915 .52636 .49661 Mtetra
.52636 .49661 .52874 .49915 .53315 .49778 .53077 .49523 Mtetra
.53077 .49523 .53315 .49778 .53757 .4964 .5352 .49384 Mtetra
.5352 .49384 .53757 .4964 .542 .49501 .53963 .49246 Mtetra
.53963 .49246 .542 .49501 .54643 .49363 .54406 .49107 Mtetra
.54406 .49107 .54643 .49363 .55087 .49224 .54851 .48968 Mtetra
.939 .772 .649 r
.54851 .48968 .55087 .49224 .55526 .48541 .55287 .47741 Mtetra
.611 .512 .718 r
.55287 .47741 .55526 .48541 .55971 .48402 .55731 .47601 Mtetra
.55731 .47601 .55971 .48402 .56416 .48263 .56176 .47461 Mtetra
.56176 .47461 .56416 .48263 .56863 .48123 .56622 .47321 Mtetra
.56622 .47321 .56863 .48123 .57309 .47983 .57068 .4718 Mtetra
.286 .307 .708 r
.57068 .4718 .57309 .47983 .57757 .47843 .57524 .47583 Mtetra
.648 .76 .931 r
.57524 .47583 .57757 .47843 .58205 .47702 .57973 .47442 Mtetra
.57973 .47442 .58205 .47702 .58654 .47562 .58422 .47301 Mtetra
.58422 .47301 .58654 .47562 .59104 .47421 .58872 .4716 Mtetra
.58872 .4716 .59104 .47421 .59554 .4728 .59323 .47019 Mtetra
.59323 .47019 .59554 .4728 .60005 .47138 .59775 .46877 Mtetra
.59775 .46877 .60005 .47138 .60457 .46997 .60227 .46735 Mtetra
.60227 .46735 .60457 .46997 .6091 .46855 .6068 .46593 Mtetra
.6068 .46593 .6091 .46855 .61363 .46713 .61134 .4645 Mtetra
.61134 .4645 .61363 .46713 .61817 .46571 .61589 .46308 Mtetra
.61589 .46308 .61817 .46571 .62272 .46428 .62044 .46165 Mtetra
.975 .717 .476 r
.62044 .46165 .62272 .46428 .62728 .46286 .62352 .41171 Mtetra
.551 .347 .557 r
.62352 .41171 .62728 .46286 .63026 .41294 .62802 .41026 Mtetra
.653 .755 .925 r
.62802 .41026 .63026 .41294 .63476 .41149 .63253 .4088 Mtetra
.63253 .4088 .63476 .41149 .63927 .41003 .63704 .40735 Mtetra
.63704 .40735 .63927 .41003 .6434 .39799 .64156 .40589 Mtetra
.421 .084 .287 r
.64156 .40589 .6434 .39799 .64791 .39653 .64609 .40443 Mtetra
0 0 0 r
.64609 .40443 .64791 .39653 .65242 .39506 .65021 .39236 Mtetra
.653 .754 .924 r
.65021 .39236 .65242 .39506 .65694 .3936 .65474 .39089 Mtetra
.65474 .39089 .65694 .3936 .66147 .39213 .65928 .38942 Mtetra
.65928 .38942 .66147 .39213 .66601 .39066 .66382 .38794 Mtetra
.66382 .38794 .66601 .39066 .67056 .38919 .66837 .38647 Mtetra
.66837 .38647 .67056 .38919 .67511 .38772 .67293 .38499 Mtetra
.67293 .38499 .67511 .38772 .67967 .38624 .67749 .38351 Mtetra
.67749 .38351 .67967 .38624 .68423 .38476 .68206 .38202 Mtetra
.68206 .38202 .68423 .38476 .68881 .38328 .68664 .38054 Mtetra
.68664 .38054 .68881 .38328 .69339 .38179 .69123 .37905 Mtetra
.69123 .37905 .69339 .38179 .69798 .38031 .69582 .37756 Mtetra
.69582 .37756 .69798 .38031 .70258 .37882 .70042 .37606 Mtetra
.70042 .37606 .70258 .37882 .70718 .37733 .70503 .37457 Mtetra
.70503 .37457 .70718 .37733 .71179 .37584 .70965 .37307 Mtetra
.70965 .37307 .71179 .37584 .71641 .37434 .71427 .37157 Mtetra
.71427 .37157 .71641 .37434 .72104 .37284 .71891 .37007 Mtetra
.71891 .37007 .72104 .37284 .72567 .37134 .72354 .36856 Mtetra
.72354 .36856 .72567 .37134 .73031 .36984 .72819 .36705 Mtetra
.98 .689 .384 r
.72819 .36705 .73031 .36984 .72592 .23098 .72388 .22812 Mtetra
.664 .741 .908 r
.72388 .22812 .72592 .23098 .73037 .22943 .72834 .22656 Mtetra
.72834 .22656 .73037 .22943 .73482 .22788 .7328 .225 Mtetra
.7328 .225 .73482 .22788 .73929 .22632 .73726 .22344 Mtetra
.73726 .22344 .73929 .22632 .74376 .22476 .74174 .22188 Mtetra
.74174 .22188 .74376 .22476 .74823 .2232 .74622 .22032 Mtetra
.74622 .22032 .74823 .2232 .75272 .22164 .75071 .21875 Mtetra
.75071 .21875 .75272 .22164 .75721 .22008 .7552 .21718 Mtetra
.7552 .21718 .75721 .22008 .7617 .21851 .75971 .21561 Mtetra
.75971 .21561 .7617 .21851 .76621 .21694 .76422 .21403 Mtetra
.76422 .21403 .76621 .21694 .77072 .21537 .76873 .21246 Mtetra
.76873 .21246 .77072 .21537 .77524 .21379 .77326 .21088 Mtetra
.77326 .21088 .77524 .21379 .77977 .21221 .77779 .2093 Mtetra
.77779 .2093 .77977 .21221 .7843 .21064 .78233 .20771 Mtetra
.78233 .20771 .7843 .21064 .78884 .20905 .78687 .20612 Mtetra
.78687 .20612 .78884 .20905 .79339 .20747 .79143 .20454 Mtetra
.79143 .20454 .79339 .20747 .79794 .20588 .79599 .20294 Mtetra
.79599 .20294 .79794 .20588 .80251 .20429 .80055 .20135 Mtetra
.80055 .20135 .80251 .20429 .80707 .2027 .80513 .19975 Mtetra
.80513 .19975 .80707 .2027 .81165 .2011 .80971 .19815 Mtetra
.80971 .19815 .81165 .2011 .81623 .19951 .8143 .19655 Mtetra
.19613 .40912 .19867 .41148 .20234 .4102 .1998 .40783 Mtetra
.1998 .40783 .20234 .4102 .20601 .40892 .20348 .40654 Mtetra
.20348 .40654 .20601 .40892 .2097 .40763 .20716 .40526 Mtetra
.20716 .40526 .2097 .40763 .21338 .40635 .21085 .40396 Mtetra
.21085 .40396 .21338 .40635 .21707 .40506 .21455 .40267 Mtetra
.21455 .40267 .21707 .40506 .22077 .40377 .21824 .40138 Mtetra
.21824 .40138 .22077 .40377 .22447 .40247 .22195 .40008 Mtetra
.22195 .40008 .22447 .40247 .22818 .40118 .22566 .39879 Mtetra
.22566 .39879 .22818 .40118 .23189 .39988 .22938 .39749 Mtetra
.22938 .39749 .23189 .39988 .23518 .40329 .2331 .39618 Mtetra
.229 .269 .696 r
.2331 .39618 .23518 .40329 .23891 .402 .2364 .39959 Mtetra
.663 .742 .908 r
.2364 .39959 .23891 .402 .24265 .4007 .24014 .39829 Mtetra
.24014 .39829 .24265 .4007 .24639 .39939 .24388 .39699 Mtetra
.24388 .39699 .24639 .39939 .25013 .39809 .24763 .39568 Mtetra
.24763 .39568 .25013 .39809 .25388 .39678 .25138 .39437 Mtetra
.25138 .39437 .25388 .39678 .25763 .39548 .25514 .39306 Mtetra
.25514 .39306 .25763 .39548 .26139 .39417 .2589 .39174 Mtetra
.2589 .39174 .26139 .39417 .26516 .39286 .26267 .39043 Mtetra
.26267 .39043 .26516 .39286 .26893 .39154 .26644 .38911 Mtetra
.26644 .38911 .26893 .39154 .27271 .39023 .27022 .38779 Mtetra
.27022 .38779 .27271 .39023 .27649 .38891 .27401 .38647 Mtetra
.27401 .38647 .27649 .38891 .28028 .38759 .2778 .38515 Mtetra
.2778 .38515 .28028 .38759 .28407 .38627 .2816 .38383 Mtetra
.2816 .38383 .28407 .38627 .28787 .38495 .2854 .3825 Mtetra
.2854 .3825 .28787 .38495 .28457 .48127 .2892 .38117 Mtetra
0 0 .24 r
.2892 .38117 .28457 .48127 .28849 .47997 .28594 .47758 Mtetra
.656 .751 .92 r
.28594 .47758 .28849 .47997 .29242 .47868 .28987 .47628 Mtetra
.28987 .47628 .29242 .47868 .29635 .47738 .29381 .47498 Mtetra
.29381 .47498 .29635 .47738 .30029 .47608 .29775 .47367 Mtetra
.29775 .47367 .30029 .47608 .30423 .47477 .30169 .47237 Mtetra
.30169 .47237 .30423 .47477 .30818 .47347 .30565 .47106 Mtetra
.30565 .47106 .30818 .47347 .31214 .47216 .30961 .46975 Mtetra
.30961 .46975 .31214 .47216 .3161 .47086 .31357 .46844 Mtetra
.31357 .46844 .3161 .47086 .32006 .46955 .31754 .46712 Mtetra
.31754 .46712 .32006 .46955 .32404 .46824 .32152 .46581 Mtetra
.32152 .46581 .32404 .46824 .32802 .46692 .3255 .46449 Mtetra
.3255 .46449 .32802 .46692 .332 .46561 .32949 .46317 Mtetra
.32949 .46317 .332 .46561 .33599 .46429 .33349 .46185 Mtetra
.955 .667 .452 r
.33349 .46185 .33599 .46429 .33999 .46297 .33396 .52238 Mtetra
.522 .282 .493 r
.33396 .52238 .33999 .46297 .34059 .52348 .33804 .52107 Mtetra
.651 .757 .927 r
.33804 .52107 .34059 .52348 .34467 .52218 .34212 .51977 Mtetra
.34212 .51977 .34467 .52218 .34876 .52087 .34622 .51846 Mtetra
.34622 .51846 .34876 .52087 .35285 .51957 .35031 .51715 Mtetra
.35031 .51715 .35285 .51957 .35696 .51826 .35442 .51584 Mtetra
.35442 .51584 .35696 .51826 .36106 .51695 .35853 .51453 Mtetra
.35853 .51453 .36106 .51695 .36518 .51564 .36265 .51322 Mtetra
.36265 .51322 .36518 .51564 .3693 .51433 .36677 .5119 Mtetra
.36677 .5119 .3693 .51433 .37342 .51301 .3709 .51058 Mtetra
.3709 .51058 .37342 .51301 .37756 .5117 .37504 .50926 Mtetra
.37504 .50926 .37756 .5117 .3817 .51038 .37918 .50794 Mtetra
.953 .709 .532 r
.37918 .50794 .3817 .51038 .38801 .45716 .38554 .45468 Mtetra
.655 .752 .921 r
.38554 .45468 .38801 .45716 .3921 .45582 .38963 .45333 Mtetra
.38963 .45333 .3921 .45582 .39619 .45447 .39373 .45199 Mtetra
.39373 .45199 .39619 .45447 .40029 .45313 .39784 .45064 Mtetra
.39784 .45064 .40029 .45313 .4044 .45178 .40195 .44928 Mtetra
.40195 .44928 .4044 .45178 .40851 .45043 .40607 .44793 Mtetra
.40607 .44793 .40851 .45043 .41263 .44908 .41019 .44657 Mtetra
.41019 .44657 .41263 .44908 .41676 .44772 .41432 .44521 Mtetra
.41432 .44521 .41676 .44772 .42089 .44636 .41846 .44385 Mtetra
.41846 .44385 .42089 .44636 .42503 .44501 .4226 .44249 Mtetra
.4226 .44249 .42503 .44501 .42918 .44364 .42675 .44113 Mtetra
.42675 .44113 .42918 .44364 .43333 .44228 .43091 .43976 Mtetra
.43091 .43976 .43333 .44228 .43749 .44092 .43507 .43839 Mtetra
.43507 .43839 .43749 .44092 .44166 .43955 .43924 .43702 Mtetra
.43924 .43702 .44166 .43955 .44583 .43818 .44342 .43565 Mtetra
.44342 .43565 .44583 .43818 .45 .43681 .4476 .43427 Mtetra
.4476 .43427 .45 .43681 .45666 .32141 .45179 .43289 Mtetra
0 0 .262 r
.45179 .43289 .45666 .32141 .46071 .32 .4584 .31738 Mtetra
.664 .741 .908 r
.4584 .31738 .46071 .32 .46476 .31858 .46245 .31597 Mtetra
.46245 .31597 .46476 .31858 .46882 .31717 .46652 .31455 Mtetra
.46652 .31455 .46882 .31717 .47288 .31575 .47058 .31312 Mtetra
.47058 .31312 .47288 .31575 .47695 .31433 .47466 .3117 Mtetra
.47466 .3117 .47695 .31433 .48103 .3129 .47874 .31027 Mtetra
.47874 .31027 .48103 .3129 .48511 .31148 .48282 .30884 Mtetra
.48282 .30884 .48511 .31148 .4892 .31005 .48691 .30741 Mtetra
.48691 .30741 .4892 .31005 .49329 .30862 .49101 .30598 Mtetra
.49101 .30598 .49329 .30862 .49739 .30719 .49512 .30454 Mtetra
.49512 .30454 .49739 .30719 .5015 .30576 .49923 .3031 Mtetra
.968 .679 .43 r
.49923 .3031 .5015 .30576 .50561 .30432 .50197 .50095 Mtetra
.531 .303 .514 r
.50197 .50095 .50561 .30432 .50876 .50211 .50636 .49958 Mtetra
.648 .76 .931 r
.50636 .49958 .50876 .50211 .51315 .50074 .51075 .4982 Mtetra
.51075 .4982 .51315 .50074 .51755 .49937 .51515 .49682 Mtetra
.51515 .49682 .51755 .49937 .52195 .49799 .51955 .49544 Mtetra
.51955 .49544 .52195 .49799 .52636 .49661 .52397 .49406 Mtetra
.52397 .49406 .52636 .49661 .53077 .49523 .52839 .49267 Mtetra
.52839 .49267 .53077 .49523 .5352 .49384 .53281 .49128 Mtetra
.53281 .49128 .5352 .49384 .53963 .49246 .53725 .48989 Mtetra
.53725 .48989 .53963 .49246 .54406 .49107 .54169 .4885 Mtetra
.54169 .4885 .54406 .49107 .54851 .48968 .54614 .48711 Mtetra
.939 .772 .649 r
.54614 .48711 .54851 .48968 .55287 .47741 .55051 .47483 Mtetra
.649 .759 .93 r
.55051 .47483 .55287 .47741 .55731 .47601 .55496 .47342 Mtetra
.55496 .47342 .55731 .47601 .56176 .47461 .55942 .47202 Mtetra
.55942 .47202 .56176 .47461 .56622 .47321 .56388 .47061 Mtetra
.56388 .47061 .56622 .47321 .57068 .4718 .56835 .4692 Mtetra
.56835 .4692 .57068 .4718 .57524 .47583 .57283 .46779 Mtetra
.611 .512 .718 r
.57283 .46779 .57524 .47583 .57973 .47442 .57731 .46637 Mtetra
.57731 .46637 .57973 .47442 .58422 .47301 .5818 .46496 Mtetra
.5818 .46496 .58422 .47301 .58872 .4716 .5863 .46354 Mtetra
.5863 .46354 .58872 .4716 .59323 .47019 .59081 .46212 Mtetra
.59081 .46212 .59323 .47019 .59775 .46877 .59532 .46069 Mtetra
.291 .311 .709 r
.59532 .46069 .59775 .46877 .60227 .46735 .59997 .46472 Mtetra
.648 .76 .931 r
.59997 .46472 .60227 .46735 .6068 .46593 .6045 .4633 Mtetra
.6045 .4633 .6068 .46593 .61134 .4645 .60905 .46187 Mtetra
.60905 .46187 .61134 .4645 .61589 .46308 .6136 .46044 Mtetra
.975 .717 .477 r
.6136 .46044 .61589 .46308 .62044 .46165 .61678 .41048 Mtetra
.55 .346 .557 r
.61678 .41048 .62044 .46165 .62352 .41171 .62127 .40903 Mtetra
.653 .755 .925 r
.62127 .40903 .62352 .41171 .62802 .41026 .62578 .40757 Mtetra
.62578 .40757 .62802 .41026 .63253 .4088 .63029 .40611 Mtetra
.63029 .40611 .63253 .4088 .63704 .40735 .63481 .40465 Mtetra
.63481 .40465 .63704 .40735 .64156 .40589 .63933 .40319 Mtetra
.63933 .40319 .64156 .40589 .64609 .40443 .64387 .40173 Mtetra
.64387 .40173 .64609 .40443 .65021 .39236 .64841 .40026 Mtetra
0 0 0 r
.64841 .40026 .65021 .39236 .65474 .39089 .65253 .38817 Mtetra
.653 .754 .924 r
.65253 .38817 .65474 .39089 .65928 .38942 .65707 .38669 Mtetra
.65707 .38669 .65928 .38942 .66382 .38794 .66162 .38522 Mtetra
.66162 .38522 .66382 .38794 .66837 .38647 .66618 .38373 Mtetra
.66618 .38373 .66837 .38647 .67293 .38499 .67074 .38225 Mtetra
.67074 .38225 .67293 .38499 .67749 .38351 .67531 .38077 Mtetra
.67531 .38077 .67749 .38351 .68206 .38202 .67989 .37928 Mtetra
.67989 .37928 .68206 .38202 .68664 .38054 .68447 .37779 Mtetra
.68447 .37779 .68664 .38054 .69123 .37905 .68906 .37629 Mtetra
.68906 .37629 .69123 .37905 .69582 .37756 .69366 .3748 Mtetra
.69366 .3748 .69582 .37756 .70042 .37606 .69827 .3733 Mtetra
.69827 .3733 .70042 .37606 .70503 .37457 .70288 .3718 Mtetra
.70288 .3718 .70503 .37457 .70965 .37307 .7075 .3703 Mtetra
.7075 .3703 .70965 .37307 .71427 .37157 .71213 .36879 Mtetra
.71213 .36879 .71427 .37157 .71891 .37007 .71677 .36729 Mtetra
.71677 .36729 .71891 .37007 .72354 .36856 .72141 .36578 Mtetra
.98 .69 .387 r
.72141 .36578 .72354 .36856 .72819 .36705 .71739 .2268 Mtetra
.541 .324 .535 r
.71739 .2268 .72819 .36705 .72388 .22812 .72184 .22524 Mtetra
.664 .741 .908 r
.72184 .22524 .72388 .22812 .72834 .22656 .7263 .22369 Mtetra
.7263 .22369 .72834 .22656 .7328 .225 .73076 .22212 Mtetra
.73076 .22212 .7328 .225 .73726 .22344 .73524 .22056 Mtetra
.73524 .22056 .73726 .22344 .74174 .22188 .73972 .21899 Mtetra
.73972 .21899 .74174 .22188 .74622 .22032 .7442 .21742 Mtetra
.7442 .21742 .74622 .22032 .75071 .21875 .7487 .21585 Mtetra
.7487 .21585 .75071 .21875 .7552 .21718 .7532 .21428 Mtetra
.7532 .21428 .7552 .21718 .75971 .21561 .7577 .2127 Mtetra
.7577 .2127 .75971 .21561 .76422 .21403 .76222 .21112 Mtetra
.76222 .21112 .76422 .21403 .76873 .21246 .76674 .20954 Mtetra
.76674 .20954 .76873 .21246 .77326 .21088 .77127 .20796 Mtetra
.77127 .20796 .77326 .21088 .77779 .2093 .77581 .20637 Mtetra
.77581 .20637 .77779 .2093 .78233 .20771 .78035 .20478 Mtetra
.78035 .20478 .78233 .20771 .78687 .20612 .7849 .20319 Mtetra
.7849 .20319 .78687 .20612 .79143 .20454 .78946 .20159 Mtetra
.78946 .20159 .79143 .20454 .79599 .20294 .79402 .2 Mtetra
.79402 .2 .79599 .20294 .80055 .20135 .7986 .1984 Mtetra
.7986 .1984 .80055 .20135 .80513 .19975 .80317 .1968 Mtetra
.80317 .1968 .80513 .19975 .80971 .19815 .80776 .19519 Mtetra
.80776 .19519 .80971 .19815 .8143 .19655 .81236 .19359 Mtetra
.19358 .40674 .19613 .40912 .1998 .40783 .19725 .40545 Mtetra
.19725 .40545 .1998 .40783 .20348 .40654 .20094 .40416 Mtetra
.20094 .40416 .20348 .40654 .20716 .40526 .20462 .40287 Mtetra
.20462 .40287 .20716 .40526 .21085 .40396 .20831 .40158 Mtetra
.20831 .40158 .21085 .40396 .21455 .40267 .21201 .40028 Mtetra
.21201 .40028 .21455 .40267 .21824 .40138 .21571 .39899 Mtetra
.21571 .39899 .21824 .40138 .22195 .40008 .21942 .39769 Mtetra
.21942 .39769 .22195 .40008 .22566 .39879 .22314 .39638 Mtetra
.22314 .39638 .22566 .39879 .22938 .39749 .22685 .39508 Mtetra
.22685 .39508 .22938 .39749 .2331 .39618 .23058 .39378 Mtetra
.544 .035 0 r
.23058 .39378 .2331 .39618 .2364 .39959 .23388 .39719 Mtetra
.663 .742 .908 r
.23388 .39719 .2364 .39959 .24014 .39829 .23762 .39588 Mtetra
.23762 .39588 .24014 .39829 .24388 .39699 .24137 .39457 Mtetra
.24137 .39457 .24388 .39699 .24763 .39568 .24512 .39326 Mtetra
.24512 .39326 .24763 .39568 .25138 .39437 .24887 .39195 Mtetra
.24887 .39195 .25138 .39437 .25514 .39306 .25263 .39063 Mtetra
.25263 .39063 .25514 .39306 .2589 .39174 .2564 .38932 Mtetra
.2564 .38932 .2589 .39174 .26267 .39043 .26017 .388 Mtetra
.26017 .388 .26267 .39043 .26644 .38911 .26395 .38668 Mtetra
.26395 .38668 .26644 .38911 .27022 .38779 .26773 .38535 Mtetra
.26773 .38535 .27022 .38779 .27401 .38647 .27152 .38403 Mtetra
.27152 .38403 .27401 .38647 .2778 .38515 .27532 .3827 Mtetra
.27532 .3827 .2778 .38515 .2816 .38383 .27912 .38138 Mtetra
.27912 .38138 .2816 .38383 .2854 .3825 .28292 .38005 Mtetra
.28292 .38005 .2854 .3825 .2892 .38117 .28673 .37871 Mtetra
.949 .676 .484 r
.28673 .37871 .2892 .38117 .28594 .47758 .28338 .47518 Mtetra
.656 .751 .92 r
.28338 .47518 .28594 .47758 .28987 .47628 .28732 .47387 Mtetra
.28732 .47387 .28987 .47628 .29381 .47498 .29126 .47257 Mtetra
.29126 .47257 .29381 .47498 .29775 .47367 .2952 .47126 Mtetra
.2952 .47126 .29775 .47367 .30169 .47237 .29915 .46995 Mtetra
.29915 .46995 .30169 .47237 .30565 .47106 .30311 .46864 Mtetra
.30311 .46864 .30565 .47106 .30961 .46975 .30707 .46733 Mtetra
.30707 .46733 .30961 .46975 .31357 .46844 .31104 .46601 Mtetra
.31104 .46601 .31357 .46844 .31754 .46712 .31502 .46469 Mtetra
.31502 .46469 .31754 .46712 .32152 .46581 .319 .46337 Mtetra
.319 .46337 .32152 .46581 .3255 .46449 .32298 .46205 Mtetra
.32298 .46205 .3255 .46449 .32949 .46317 .32698 .46073 Mtetra
.954 .667 .453 r
.32698 .46073 .32949 .46317 .33349 .46185 .32732 .52128 Mtetra
.521 .282 .492 r
.32732 .52128 .33349 .46185 .33396 .52238 .3314 .51997 Mtetra
.651 .757 .927 r
.3314 .51997 .33396 .52238 .33804 .52107 .33548 .51866 Mtetra
.33548 .51866 .33804 .52107 .34212 .51977 .33957 .51736 Mtetra
.33957 .51736 .34212 .51977 .34622 .51846 .34367 .51605 Mtetra
.34367 .51605 .34622 .51846 .35031 .51715 .34777 .51473 Mtetra
.34777 .51473 .35031 .51715 .35442 .51584 .35188 .51342 Mtetra
.35188 .51342 .35442 .51584 .35853 .51453 .35599 .5121 Mtetra
.35599 .5121 .35853 .51453 .36265 .51322 .36011 .51078 Mtetra
.36011 .51078 .36265 .51322 .36677 .5119 .36424 .50946 Mtetra
.36424 .50946 .36677 .5119 .3709 .51058 .36838 .50814 Mtetra
.36838 .50814 .3709 .51058 .37504 .50926 .37252 .50681 Mtetra
.37252 .50681 .37504 .50926 .37918 .50794 .37666 .50549 Mtetra
.953 .709 .532 r
.37666 .50549 .37918 .50794 .38554 .45468 .38307 .45219 Mtetra
.655 .752 .921 r
.38307 .45219 .38554 .45468 .38963 .45333 .38717 .45084 Mtetra
.38717 .45084 .38963 .45333 .39373 .45199 .39127 .44949 Mtetra
.39127 .44949 .39373 .45199 .39784 .45064 .39538 .44814 Mtetra
.39538 .44814 .39784 .45064 .40195 .44928 .39949 .44678 Mtetra
.39949 .44678 .40195 .44928 .40607 .44793 .40362 .44542 Mtetra
.40362 .44542 .40607 .44793 .41019 .44657 .40774 .44406 Mtetra
.40774 .44406 .41019 .44657 .41432 .44521 .41188 .4427 Mtetra
.41188 .4427 .41432 .44521 .41846 .44385 .41602 .44134 Mtetra
.41602 .44134 .41846 .44385 .4226 .44249 .42017 .43997 Mtetra
.42017 .43997 .4226 .44249 .42675 .44113 .42432 .4386 Mtetra
.42432 .4386 .42675 .44113 .43091 .43976 .42848 .43723 Mtetra
.42848 .43723 .43091 .43976 .43507 .43839 .43265 .43586 Mtetra
.43265 .43586 .43507 .43839 .43924 .43702 .43682 .43448 Mtetra
.43682 .43448 .43924 .43702 .44342 .43565 .441 .4331 Mtetra
.441 .4331 .44342 .43565 .4476 .43427 .44519 .43173 Mtetra
.44519 .43173 .4476 .43427 .45179 .43289 .44938 .43034 Mtetra
.962 .699 .487 r
.44938 .43034 .45179 .43289 .4584 .31738 .45608 .31476 Mtetra
.664 .741 .908 r
.45608 .31476 .4584 .31738 .46245 .31597 .46014 .31334 Mtetra
.46014 .31334 .46245 .31597 .46652 .31455 .46421 .31192 Mtetra
.46421 .31192 .46652 .31455 .47058 .31312 .46828 .31049 Mtetra
.46828 .31049 .47058 .31312 .47466 .3117 .47236 .30906 Mtetra
.47236 .30906 .47466 .3117 .47874 .31027 .47644 .30763 Mtetra
.47644 .30763 .47874 .31027 .48282 .30884 .48053 .3062 Mtetra
.48053 .3062 .48282 .30884 .48691 .30741 .48463 .30476 Mtetra
.48463 .30476 .48691 .30741 .49101 .30598 .48873 .30333 Mtetra
.48873 .30333 .49101 .30598 .49512 .30454 .49284 .30189 Mtetra
.967 .679 .432 r
.49284 .30189 .49512 .30454 .49923 .3031 .49517 .49979 Mtetra
.531 .302 .513 r
.49517 .49979 .49923 .3031 .50197 .50095 .49955 .49841 Mtetra
.648 .76 .931 r
.49955 .49841 .50197 .50095 .50636 .49958 .50394 .49703 Mtetra
.50394 .49703 .50636 .49958 .51075 .4982 .50834 .49565 Mtetra
.50834 .49565 .51075 .4982 .51515 .49682 .51274 .49427 Mtetra
.51274 .49427 .51515 .49682 .51955 .49544 .51715 .49288 Mtetra
.51715 .49288 .51955 .49544 .52397 .49406 .52157 .4915 Mtetra
.52157 .4915 .52397 .49406 .52839 .49267 .52599 .49011 Mtetra
.52599 .49011 .52839 .49267 .53281 .49128 .53043 .48872 Mtetra
.53043 .48872 .53281 .49128 .53725 .48989 .53487 .48732 Mtetra
.53487 .48732 .53725 .48989 .54169 .4885 .53931 .48592 Mtetra
.53931 .48592 .54169 .4885 .54614 .48711 .54377 .48453 Mtetra
.939 .772 .649 r
.54377 .48453 .54614 .48711 .55051 .47483 .54815 .47224 Mtetra
.649 .759 .93 r
.54815 .47224 .55051 .47483 .55496 .47342 .5526 .47083 Mtetra
.5526 .47083 .55496 .47342 .55942 .47202 .55706 .46942 Mtetra
.55706 .46942 .55942 .47202 .56388 .47061 .56153 .46801 Mtetra
.56153 .46801 .56388 .47061 .56835 .4692 .56601 .46659 Mtetra
.56601 .46659 .56835 .4692 .57283 .46779 .57049 .46518 Mtetra
.57049 .46518 .57283 .46779 .57731 .46637 .57498 .46376 Mtetra
.57498 .46376 .57731 .46637 .5818 .46496 .57947 .46234 Mtetra
.57947 .46234 .5818 .46496 .5863 .46354 .58398 .46091 Mtetra
.58398 .46091 .5863 .46354 .59081 .46212 .58849 .45949 Mtetra
.58849 .45949 .59081 .46212 .59532 .46069 .59301 .45806 Mtetra
.59301 .45806 .59532 .46069 .59997 .46472 .59753 .45663 Mtetra
.61 .512 .718 r
.59753 .45663 .59997 .46472 .6045 .4633 .60207 .4552 Mtetra
.60207 .4552 .6045 .4633 .60905 .46187 .60661 .45376 Mtetra
.943 .683 .513 r
.60661 .45376 .60905 .46187 .6136 .46044 .61002 .40925 Mtetra
.55 .346 .556 r
.61002 .40925 .6136 .46044 .61678 .41048 .61452 .4078 Mtetra
.653 .755 .925 r
.61452 .4078 .61678 .41048 .62127 .40903 .61902 .40634 Mtetra
.61902 .40634 .62127 .40903 .62578 .40757 .62353 .40488 Mtetra
.62353 .40488 .62578 .40757 .63029 .40611 .62804 .40342 Mtetra
.62804 .40342 .63029 .40611 .63481 .40465 .63257 .40195 Mtetra
.63257 .40195 .63481 .40465 .63933 .40319 .6371 .40048 Mtetra
.6371 .40048 .63933 .40319 .64387 .40173 .64164 .39901 Mtetra
.64164 .39901 .64387 .40173 .64841 .40026 .64618 .39754 Mtetra
.64618 .39754 .64841 .40026 .65253 .38817 .65074 .39607 Mtetra
0 0 0 r
.65074 .39607 .65253 .38817 .65707 .38669 .65486 .38396 Mtetra
.653 .754 .924 r
.65486 .38396 .65707 .38669 .66162 .38522 .65942 .38248 Mtetra
.65942 .38248 .66162 .38522 .66618 .38373 .66398 .38099 Mtetra
.66398 .38099 .66618 .38373 .67074 .38225 .66854 .37951 Mtetra
.66854 .37951 .67074 .38225 .67531 .38077 .67312 .37802 Mtetra
.67312 .37802 .67531 .38077 .67989 .37928 .6777 .37652 Mtetra
.6777 .37652 .67989 .37928 .68447 .37779 .68229 .37503 Mtetra
.68229 .37503 .68447 .37779 .68906 .37629 .68689 .37353 Mtetra
.68689 .37353 .68906 .37629 .69366 .3748 .69149 .37203 Mtetra
.69149 .37203 .69366 .3748 .69827 .3733 .6961 .37053 Mtetra
.6961 .37053 .69827 .3733 .70288 .3718 .70072 .36903 Mtetra
.70072 .36903 .70288 .3718 .7075 .3703 .70535 .36752 Mtetra
.70535 .36752 .7075 .3703 .71213 .36879 .70998 .36601 Mtetra
.70998 .36601 .71213 .36879 .71677 .36729 .71463 .3645 Mtetra
.979 .69 .389 r
.71463 .3645 .71677 .36729 .72141 .36578 .71088 .22548 Mtetra
.54 .324 .534 r
.71088 .22548 .72141 .36578 .71739 .2268 .71533 .22393 Mtetra
.664 .741 .908 r
.71533 .22393 .71739 .2268 .72184 .22524 .71979 .22236 Mtetra
.71979 .22236 .72184 .22524 .7263 .22369 .72425 .2208 Mtetra
.72425 .2208 .7263 .22369 .73076 .22212 .72872 .21923 Mtetra
.72872 .21923 .73076 .22212 .73524 .22056 .7332 .21766 Mtetra
.7332 .21766 .73524 .22056 .73972 .21899 .73769 .21609 Mtetra
.73769 .21609 .73972 .21899 .7442 .21742 .74218 .21452 Mtetra
.74218 .21452 .7442 .21742 .7487 .21585 .74668 .21294 Mtetra
.74668 .21294 .7487 .21585 .7532 .21428 .75118 .21136 Mtetra
.75118 .21136 .7532 .21428 .7577 .2127 .75569 .20978 Mtetra
.75569 .20978 .7577 .2127 .76222 .21112 .76021 .2082 Mtetra
.76021 .2082 .76222 .21112 .76674 .20954 .76474 .20661 Mtetra
.76474 .20661 .76674 .20954 .77127 .20796 .76928 .20502 Mtetra
.76928 .20502 .77127 .20796 .77581 .20637 .77382 .20343 Mtetra
.77382 .20343 .77581 .20637 .78035 .20478 .77837 .20184 Mtetra
.77837 .20184 .78035 .20478 .7849 .20319 .78292 .20024 Mtetra
.78292 .20024 .7849 .20319 .78946 .20159 .78748 .19864 Mtetra
.78748 .19864 .78946 .20159 .79402 .2 .79205 .19704 Mtetra
.79205 .19704 .79402 .2 .7986 .1984 .79663 .19544 Mtetra
.79663 .19544 .7986 .1984 .80317 .1968 .80122 .19383 Mtetra
.80122 .19383 .80317 .1968 .80776 .19519 .80581 .19222 Mtetra
.80581 .19222 .80776 .19519 .81236 .19359 .81041 .19061 Mtetra
.19102 .40436 .19358 .40674 .19725 .40545 .1947 .40307 Mtetra
.1947 .40307 .19725 .40545 .20094 .40416 .19839 .40178 Mtetra
.19839 .40178 .20094 .40416 .20462 .40287 .20208 .40048 Mtetra
.20208 .40048 .20462 .40287 .20831 .40158 .20577 .39918 Mtetra
.20577 .39918 .20831 .40158 .21201 .40028 .20947 .39789 Mtetra
.20947 .39789 .21201 .40028 .21571 .39899 .21318 .39659 Mtetra
.21318 .39659 .21571 .39899 .21942 .39769 .21689 .39528 Mtetra
.21689 .39528 .21942 .39769 .22314 .39638 .2206 .39398 Mtetra
.2206 .39398 .22314 .39638 .22685 .39508 .22433 .39267 Mtetra
.22433 .39267 .22685 .39508 .23058 .39378 .22805 .39136 Mtetra
.22805 .39136 .23058 .39378 .23388 .39719 .23179 .39005 Mtetra
.228 .268 .696 r
.23179 .39005 .23388 .39719 .23762 .39588 .2351 .39346 Mtetra
.663 .742 .908 r
.2351 .39346 .23762 .39588 .24137 .39457 .23885 .39215 Mtetra
.23885 .39215 .24137 .39457 .24512 .39326 .2426 .39083 Mtetra
.2426 .39083 .24512 .39326 .24887 .39195 .24636 .38952 Mtetra
.24636 .38952 .24887 .39195 .25263 .39063 .25012 .3882 Mtetra
.25012 .3882 .25263 .39063 .2564 .38932 .25389 .38688 Mtetra
.25389 .38688 .2564 .38932 .26017 .388 .25767 .38556 Mtetra
.25767 .38556 .26017 .388 .26395 .38668 .26145 .38423 Mtetra
.26145 .38423 .26395 .38668 .26773 .38535 .26524 .38291 Mtetra
.26524 .38291 .26773 .38535 .27152 .38403 .26903 .38158 Mtetra
.26903 .38158 .27152 .38403 .27532 .3827 .27282 .38025 Mtetra
.27282 .38025 .27532 .3827 .27912 .38138 .27663 .37892 Mtetra
.27663 .37892 .27912 .38138 .28292 .38005 .28044 .37759 Mtetra
.28044 .37759 .28292 .38005 .28673 .37871 .28425 .37625 Mtetra
.28425 .37625 .28673 .37871 .28338 .47518 .28807 .37491 Mtetra
0 0 .237 r
.28807 .37491 .28338 .47518 .28732 .47387 .28476 .47146 Mtetra
.656 .751 .92 r
.28476 .47146 .28732 .47387 .29126 .47257 .2887 .47015 Mtetra
.2887 .47015 .29126 .47257 .2952 .47126 .29265 .46884 Mtetra
.29265 .46884 .2952 .47126 .29915 .46995 .2966 .46753 Mtetra
.2966 .46753 .29915 .46995 .30311 .46864 .30056 .46621 Mtetra
.30056 .46621 .30311 .46864 .30707 .46733 .30453 .4649 Mtetra
.30453 .4649 .30707 .46733 .31104 .46601 .3085 .46358 Mtetra
.3085 .46358 .31104 .46601 .31502 .46469 .31248 .46226 Mtetra
.31248 .46226 .31502 .46469 .319 .46337 .31646 .46093 Mtetra
.31646 .46093 .319 .46337 .32298 .46205 .32045 .45961 Mtetra
.954 .667 .454 r
.32045 .45961 .32298 .46205 .32698 .46073 .32067 .52017 Mtetra
.521 .281 .492 r
.32067 .52017 .32698 .46073 .32732 .52128 .32475 .51887 Mtetra
.651 .757 .927 r
.32475 .51887 .32732 .52128 .3314 .51997 .32883 .51756 Mtetra
.32883 .51756 .3314 .51997 .33548 .51866 .33291 .51625 Mtetra
.33291 .51625 .33548 .51866 .33957 .51736 .33701 .51493 Mtetra
.33701 .51493 .33957 .51736 .34367 .51605 .34111 .51362 Mtetra
.34111 .51362 .34367 .51605 .34777 .51473 .34521 .5123 Mtetra
.34521 .5123 .34777 .51473 .35188 .51342 .34933 .51099 Mtetra
.34933 .51099 .35188 .51342 .35599 .5121 .35345 .50967 Mtetra
.35345 .50967 .35599 .5121 .36011 .51078 .35757 .50834 Mtetra
.35757 .50834 .36011 .51078 .36424 .50946 .3617 .50702 Mtetra
.3617 .50702 .36424 .50946 .36838 .50814 .36584 .50569 Mtetra
.36584 .50569 .36838 .50814 .37252 .50681 .36999 .50436 Mtetra
.36999 .50436 .37252 .50681 .37666 .50549 .37414 .50303 Mtetra
.37414 .50303 .37666 .50549 .38307 .45219 .3783 .5017 Mtetra
0 0 .17 r
.3783 .5017 .38307 .45219 .38717 .45084 .38469 .44835 Mtetra
.655 .752 .921 r
.38469 .44835 .38717 .45084 .39127 .44949 .3888 .44699 Mtetra
.3888 .44699 .39127 .44949 .39538 .44814 .39291 .44563 Mtetra
.39291 .44563 .39538 .44814 .39949 .44678 .39703 .44427 Mtetra
.39703 .44427 .39949 .44678 .40362 .44542 .40116 .44291 Mtetra
.40116 .44291 .40362 .44542 .40774 .44406 .40529 .44155 Mtetra
.40529 .44155 .40774 .44406 .41188 .4427 .40943 .44018 Mtetra
.40943 .44018 .41188 .4427 .41602 .44134 .41357 .43881 Mtetra
.41357 .43881 .41602 .44134 .42017 .43997 .41772 .43744 Mtetra
.41772 .43744 .42017 .43997 .42432 .4386 .42188 .43607 Mtetra
.42188 .43607 .42432 .4386 .42848 .43723 .42604 .43469 Mtetra
.42604 .43469 .42848 .43723 .43265 .43586 .43022 .43332 Mtetra
.43022 .43332 .43265 .43586 .43682 .43448 .43439 .43194 Mtetra
.43439 .43194 .43682 .43448 .441 .4331 .43858 .43056 Mtetra
.43858 .43056 .441 .4331 .44519 .43173 .44277 .42917 Mtetra
.44277 .42917 .44519 .43173 .44938 .43034 .44696 .42779 Mtetra
.44696 .42779 .44938 .43034 .45608 .31476 .45117 .4264 Mtetra
0 0 .259 r
.45117 .4264 .45608 .31476 .46014 .31334 .45782 .31071 Mtetra
.664 .741 .908 r
.45782 .31071 .46014 .31334 .46421 .31192 .46189 .30928 Mtetra
.46189 .30928 .46421 .31192 .46828 .31049 .46597 .30785 Mtetra
.46597 .30785 .46828 .31049 .47236 .30906 .47005 .30642 Mtetra
.47005 .30642 .47236 .30906 .47644 .30763 .47414 .30498 Mtetra
.47414 .30498 .47644 .30763 .48053 .3062 .47823 .30355 Mtetra
.47823 .30355 .48053 .3062 .48463 .30476 .48233 .30211 Mtetra
.48233 .30211 .48463 .30476 .48873 .30333 .48644 .30067 Mtetra
.967 .679 .433 r
.48644 .30067 .48873 .30333 .49284 .30189 .48835 .49862 Mtetra
.53 .301 .512 r
.48835 .49862 .49284 .30189 .49517 .49979 .49273 .49725 Mtetra
.648 .76 .931 r
.49273 .49725 .49517 .49979 .49955 .49841 .49712 .49587 Mtetra
.49712 .49587 .49955 .49841 .50394 .49703 .50152 .49448 Mtetra
.50152 .49448 .50394 .49703 .50834 .49565 .50592 .4931 Mtetra
.50592 .4931 .50834 .49565 .51274 .49427 .51033 .49171 Mtetra
.51033 .49171 .51274 .49427 .51715 .49288 .51474 .49032 Mtetra
.51474 .49032 .51715 .49288 .52157 .4915 .51916 .48893 Mtetra
.51916 .48893 .52157 .4915 .52599 .49011 .52359 .48754 Mtetra
.52359 .48754 .52599 .49011 .53043 .48872 .52803 .48614 Mtetra
.52803 .48614 .53043 .48872 .53487 .48732 .53247 .48474 Mtetra
.53247 .48474 .53487 .48732 .53931 .48592 .53693 .48334 Mtetra
.53693 .48334 .53931 .48592 .54377 .48453 .54138 .48194 Mtetra
.939 .772 .649 r
.54138 .48194 .54377 .48453 .54815 .47224 .54578 .46964 Mtetra
.649 .759 .93 r
.54578 .46964 .54815 .47224 .5526 .47083 .55024 .46822 Mtetra
.55024 .46822 .5526 .47083 .55706 .46942 .5547 .46681 Mtetra
.5547 .46681 .55706 .46942 .56153 .46801 .55918 .46539 Mtetra
.55918 .46539 .56153 .46801 .56601 .46659 .56366 .46398 Mtetra
.56366 .46398 .56601 .46659 .57049 .46518 .56814 .46255 Mtetra
.56814 .46255 .57049 .46518 .57498 .46376 .57264 .46113 Mtetra
.57264 .46113 .57498 .46376 .57947 .46234 .57714 .45971 Mtetra
.57714 .45971 .57947 .46234 .58398 .46091 .58165 .45828 Mtetra
.58165 .45828 .58398 .46091 .58849 .45949 .58616 .45685 Mtetra
.58616 .45685 .58849 .45949 .59301 .45806 .59069 .45542 Mtetra
.59069 .45542 .59301 .45806 .59753 .45663 .59522 .45398 Mtetra
.59522 .45398 .59753 .45663 .60207 .4552 .59976 .45254 Mtetra
.59976 .45254 .60207 .4552 .60661 .45376 .6043 .45111 Mtetra
.974 .72 .487 r
.6043 .45111 .60661 .45376 .61002 .40925 .60775 .40656 Mtetra
.653 .755 .925 r
.60775 .40656 .61002 .40925 .61452 .4078 .61225 .4051 Mtetra
.61225 .4051 .61452 .4078 .61902 .40634 .61675 .40364 Mtetra
.61675 .40364 .61902 .40634 .62353 .40488 .62127 .40218 Mtetra
.62127 .40218 .62353 .40488 .62804 .40342 .62579 .40071 Mtetra
.62579 .40071 .62804 .40342 .63257 .40195 .63032 .39924 Mtetra
.63032 .39924 .63257 .40195 .6371 .40048 .63485 .39777 Mtetra
.63485 .39777 .6371 .40048 .64164 .39901 .6394 .3963 Mtetra
.6394 .3963 .64164 .39901 .64618 .39754 .64395 .39482 Mtetra
.64395 .39482 .64618 .39754 .65074 .39607 .64851 .39334 Mtetra
.64851 .39334 .65074 .39607 .65486 .38396 .65307 .39186 Mtetra
.417 .078 .282 r
.65307 .39186 .65486 .38396 .65942 .38248 .65765 .39038 Mtetra
0 0 0 r
.65765 .39038 .65942 .38248 .66398 .38099 .66177 .37825 Mtetra
.653 .754 .924 r
.66177 .37825 .66398 .38099 .66854 .37951 .66634 .37675 Mtetra
.66634 .37675 .66854 .37951 .67312 .37802 .67092 .37526 Mtetra
.67092 .37526 .67312 .37802 .6777 .37652 .67551 .37376 Mtetra
.67551 .37376 .6777 .37652 .68229 .37503 .6801 .37226 Mtetra
.6801 .37226 .68229 .37503 .68689 .37353 .68471 .37076 Mtetra
.68471 .37076 .68689 .37353 .69149 .37203 .68932 .36926 Mtetra
.68932 .36926 .69149 .37203 .6961 .37053 .69393 .36775 Mtetra
.69393 .36775 .6961 .37053 .70072 .36903 .69856 .36624 Mtetra
.69856 .36624 .70072 .36903 .70535 .36752 .70319 .36473 Mtetra
.70319 .36473 .70535 .36752 .70998 .36601 .70783 .36322 Mtetra
.70783 .36322 .70998 .36601 .71463 .3645 .71248 .3617 Mtetra
.979 .69 .389 r
.71248 .3617 .71463 .3645 .71088 .22548 .70882 .2226 Mtetra
.664 .741 .908 r
.70882 .2226 .71088 .22548 .71533 .22393 .71328 .22104 Mtetra
.71328 .22104 .71533 .22393 .71979 .22236 .71774 .21947 Mtetra
.71774 .21947 .71979 .22236 .72425 .2208 .7222 .21791 Mtetra
.7222 .21791 .72425 .2208 .72872 .21923 .72668 .21634 Mtetra
.72668 .21634 .72872 .21923 .7332 .21766 .73116 .21476 Mtetra
.73116 .21476 .7332 .21766 .73769 .21609 .73565 .21319 Mtetra
.73565 .21319 .73769 .21609 .74218 .21452 .74015 .21161 Mtetra
.74015 .21161 .74218 .21452 .74668 .21294 .74465 .21003 Mtetra
.74465 .21003 .74668 .21294 .75118 .21136 .74916 .20844 Mtetra
.74916 .20844 .75118 .21136 .75569 .20978 .75368 .20686 Mtetra
.75368 .20686 .75569 .20978 .76021 .2082 .7582 .20527 Mtetra
.7582 .20527 .76021 .2082 .76474 .20661 .76274 .20368 Mtetra
.76274 .20368 .76474 .20661 .76928 .20502 .76728 .20209 Mtetra
.76728 .20209 .76928 .20502 .77382 .20343 .77182 .20049 Mtetra
.77182 .20049 .77382 .20343 .77837 .20184 .77638 .19889 Mtetra
.77638 .19889 .77837 .20184 .78292 .20024 .78094 .19729 Mtetra
.78094 .19729 .78292 .20024 .78748 .19864 .7855 .19569 Mtetra
.7855 .19569 .78748 .19864 .79205 .19704 .79008 .19408 Mtetra
.79008 .19408 .79205 .19704 .79663 .19544 .79466 .19247 Mtetra
.79466 .19247 .79663 .19544 .80122 .19383 .79925 .19086 Mtetra
.79925 .19086 .80122 .19383 .80581 .19222 .80385 .18925 Mtetra
.80385 .18925 .80581 .19222 .81041 .19061 .80845 .18763 Mtetra
.18846 .40198 .19102 .40436 .1947 .40307 .19214 .40068 Mtetra
.19214 .40068 .1947 .40307 .19839 .40178 .19583 .39938 Mtetra
.19583 .39938 .19839 .40178 .20208 .40048 .19952 .39809 Mtetra
.19952 .39809 .20208 .40048 .20577 .39918 .20322 .39679 Mtetra
.20322 .39679 .20577 .39918 .20947 .39789 .20692 .39548 Mtetra
.20692 .39548 .20947 .39789 .21318 .39659 .21063 .39418 Mtetra
.21063 .39418 .21318 .39659 .21689 .39528 .21435 .39287 Mtetra
.21435 .39287 .21689 .39528 .2206 .39398 .21807 .39156 Mtetra
.21807 .39156 .2206 .39398 .22433 .39267 .22179 .39025 Mtetra
.22179 .39025 .22433 .39267 .22805 .39136 .22552 .38894 Mtetra
.22552 .38894 .22805 .39136 .23179 .39005 .22926 .38763 Mtetra
.541 .032 0 r
.22926 .38763 .23179 .39005 .2351 .39346 .23257 .39104 Mtetra
.663 .742 .908 r
.23257 .39104 .2351 .39346 .23885 .39215 .23632 .38972 Mtetra
.23632 .38972 .23885 .39215 .2426 .39083 .24008 .3884 Mtetra
.24008 .3884 .2426 .39083 .24636 .38952 .24384 .38708 Mtetra
.24384 .38708 .24636 .38952 .25012 .3882 .24761 .38576 Mtetra
.24761 .38576 .25012 .3882 .25389 .38688 .25138 .38444 Mtetra
.25138 .38444 .25389 .38688 .25767 .38556 .25516 .38311 Mtetra
.25516 .38311 .25767 .38556 .26145 .38423 .25894 .38179 Mtetra
.25894 .38179 .26145 .38423 .26524 .38291 .26273 .38046 Mtetra
.26273 .38046 .26524 .38291 .26903 .38158 .26653 .37912 Mtetra
.26653 .37912 .26903 .38158 .27282 .38025 .27033 .37779 Mtetra
.27033 .37779 .27282 .38025 .27663 .37892 .27413 .37646 Mtetra
.27413 .37646 .27663 .37892 .28044 .37759 .27794 .37512 Mtetra
.27794 .37512 .28044 .37759 .28425 .37625 .28176 .37378 Mtetra
.28176 .37378 .28425 .37625 .28807 .37491 .28558 .37244 Mtetra
.28558 .37244 .28807 .37491 .28476 .47146 .28941 .3711 Mtetra
0 0 .237 r
.28941 .3711 .28476 .47146 .2887 .47015 .28614 .46773 Mtetra
.656 .751 .92 r
.28614 .46773 .2887 .47015 .29265 .46884 .29009 .46642 Mtetra
.29009 .46642 .29265 .46884 .2966 .46753 .29405 .4651 Mtetra
.29405 .4651 .2966 .46753 .30056 .46621 .29801 .46378 Mtetra
.29801 .46378 .30056 .46621 .30453 .4649 .30198 .46246 Mtetra
.30198 .46246 .30453 .4649 .3085 .46358 .30596 .46114 Mtetra
.30596 .46114 .3085 .46358 .31248 .46226 .30994 .45981 Mtetra
.30994 .45981 .31248 .46226 .31646 .46093 .31393 .45849 Mtetra
.954 .667 .456 r
.31393 .45849 .31646 .46093 .32045 .45961 .31401 .51907 Mtetra
.52 .28 .491 r
.31401 .51907 .32045 .45961 .32067 .52017 .31809 .51776 Mtetra
.651 .757 .927 r
.31809 .51776 .32067 .52017 .32475 .51887 .32216 .51645 Mtetra
.32216 .51645 .32475 .51887 .32883 .51756 .32625 .51514 Mtetra
.32625 .51514 .32883 .51756 .33291 .51625 .33034 .51382 Mtetra
.33034 .51382 .33291 .51625 .33701 .51493 .33444 .51251 Mtetra
.33444 .51251 .33701 .51493 .34111 .51362 .33854 .51119 Mtetra
.33854 .51119 .34111 .51362 .34521 .5123 .34265 .50987 Mtetra
.34265 .50987 .34521 .5123 .34933 .51099 .34677 .50855 Mtetra
.34677 .50855 .34933 .51099 .35345 .50967 .35089 .50722 Mtetra
.35089 .50722 .35345 .50967 .35757 .50834 .35502 .5059 Mtetra
.35502 .5059 .35757 .50834 .3617 .50702 .35916 .50457 Mtetra
.35916 .50457 .3617 .50702 .36584 .50569 .3633 .50324 Mtetra
.3633 .50324 .36584 .50569 .36999 .50436 .36745 .5019 Mtetra
.36745 .5019 .36999 .50436 .37414 .50303 .3716 .50057 Mtetra
.3716 .50057 .37414 .50303 .3783 .5017 .37577 .49923 Mtetra
.953 .709 .531 r
.37577 .49923 .3783 .5017 .38469 .44835 .38221 .44584 Mtetra
.655 .752 .921 r
.38221 .44584 .38469 .44835 .3888 .44699 .38632 .44448 Mtetra
.38632 .44448 .3888 .44699 .39291 .44563 .39043 .44312 Mtetra
.39043 .44312 .39291 .44563 .39703 .44427 .39456 .44176 Mtetra
.39456 .44176 .39703 .44427 .40116 .44291 .39869 .44039 Mtetra
.39869 .44039 .40116 .44291 .40529 .44155 .40282 .43902 Mtetra
.40282 .43902 .40529 .44155 .40943 .44018 .40697 .43765 Mtetra
.40697 .43765 .40943 .44018 .41357 .43881 .41112 .43628 Mtetra
.41112 .43628 .41357 .43881 .41772 .43744 .41527 .43491 Mtetra
.41527 .43491 .41772 .43744 .42188 .43607 .41943 .43353 Mtetra
.41943 .43353 .42188 .43607 .42604 .43469 .4236 .43215 Mtetra
.4236 .43215 .42604 .43469 .43022 .43332 .42778 .43077 Mtetra
.42778 .43077 .43022 .43332 .43439 .43194 .43196 .42939 Mtetra
.43196 .42939 .43439 .43194 .43858 .43056 .43615 .428 Mtetra
.43615 .428 .43858 .43056 .44277 .42917 .44034 .42661 Mtetra
.44034 .42661 .44277 .42917 .44696 .42779 .44454 .42522 Mtetra
.44454 .42522 .44696 .42779 .45117 .4264 .44875 .42383 Mtetra
.963 .699 .486 r
.44875 .42383 .45117 .4264 .45782 .31071 .4555 .30807 Mtetra
.664 .741 .908 r
.4555 .30807 .45782 .31071 .46189 .30928 .45957 .30664 Mtetra
.45957 .30664 .46189 .30928 .46597 .30785 .46365 .3052 Mtetra
.46365 .3052 .46597 .30785 .47005 .30642 .46773 .30377 Mtetra
.46773 .30377 .47005 .30642 .47414 .30498 .47183 .30233 Mtetra
.47183 .30233 .47414 .30498 .47823 .30355 .47592 .30089 Mtetra
.47592 .30089 .47823 .30355 .48233 .30211 .48003 .29944 Mtetra
.967 .68 .435 r
.48003 .29944 .48233 .30211 .48644 .30067 .48153 .49746 Mtetra
.53 .3 .512 r
.48153 .49746 .48644 .30067 .48835 .49862 .48591 .49608 Mtetra
.648 .76 .931 r
.48591 .49608 .48835 .49862 .49273 .49725 .4903 .4947 Mtetra
.4903 .4947 .49273 .49725 .49712 .49587 .49469 .49331 Mtetra
.49469 .49331 .49712 .49587 .50152 .49448 .49909 .49192 Mtetra
.49909 .49192 .50152 .49448 .50592 .4931 .50349 .49054 Mtetra
.50349 .49054 .50592 .4931 .51033 .49171 .5079 .48914 Mtetra
.5079 .48914 .51033 .49171 .51474 .49032 .51232 .48775 Mtetra
.51232 .48775 .51474 .49032 .51916 .48893 .51675 .48635 Mtetra
.51675 .48635 .51916 .48893 .52359 .48754 .52119 .48496 Mtetra
.52119 .48496 .52359 .48754 .52803 .48614 .52563 .48356 Mtetra
.52563 .48356 .52803 .48614 .53247 .48474 .53008 .48215 Mtetra
.53008 .48215 .53247 .48474 .53693 .48334 .53453 .48075 Mtetra
.53453 .48075 .53693 .48334 .54138 .48194 .539 .47934 Mtetra
.939 .772 .649 r
.539 .47934 .54138 .48194 .54578 .46964 .5434 .46703 Mtetra
.649 .759 .93 r
.5434 .46703 .54578 .46964 .55024 .46822 .54787 .46561 Mtetra
.54787 .46561 .55024 .46822 .5547 .46681 .55234 .46419 Mtetra
.55234 .46419 .5547 .46681 .55918 .46539 .55681 .46277 Mtetra
.55681 .46277 .55918 .46539 .56366 .46398 .5613 .46135 Mtetra
.5613 .46135 .56366 .46398 .56814 .46255 .56579 .45993 Mtetra
.56579 .45993 .56814 .46255 .57264 .46113 .57029 .4585 Mtetra
.57029 .4585 .57264 .46113 .57714 .45971 .5748 .45707 Mtetra
.5748 .45707 .57714 .45971 .58165 .45828 .57931 .45564 Mtetra
.57931 .45564 .58165 .45828 .58616 .45685 .58383 .4542 Mtetra
.58383 .4542 .58616 .45685 .59069 .45542 .58836 .45277 Mtetra
.58836 .45277 .59069 .45542 .59522 .45398 .59289 .45133 Mtetra
.59289 .45133 .59522 .45398 .59976 .45254 .59744 .44989 Mtetra
.59744 .44989 .59976 .45254 .6043 .45111 .60199 .44844 Mtetra
.974 .72 .487 r
.60199 .44844 .6043 .45111 .60775 .40656 .60547 .40387 Mtetra
.653 .755 .925 r
.60547 .40387 .60775 .40656 .61225 .4051 .60997 .4024 Mtetra
.60997 .4024 .61225 .4051 .61675 .40364 .61449 .40094 Mtetra
.61449 .40094 .61675 .40364 .62127 .40218 .619 .39947 Mtetra
.619 .39947 .62127 .40218 .62579 .40071 .62353 .398 Mtetra
.62353 .398 .62579 .40071 .63032 .39924 .62806 .39652 Mtetra
.62806 .39652 .63032 .39924 .63485 .39777 .63261 .39505 Mtetra
.63261 .39505 .63485 .39777 .6394 .3963 .63715 .39357 Mtetra
.63715 .39357 .6394 .3963 .64395 .39482 .64171 .39209 Mtetra
.64171 .39209 .64395 .39482 .64851 .39334 .64627 .3906 Mtetra
.64627 .3906 .64851 .39334 .65307 .39186 .65084 .38912 Mtetra
.65084 .38912 .65307 .39186 .65765 .39038 .65542 .38763 Mtetra
.65542 .38763 .65765 .39038 .66177 .37825 .66001 .38614 Mtetra
0 0 0 r
.66001 .38614 .66177 .37825 .66634 .37675 .66413 .37399 Mtetra
.653 .754 .924 r
.66413 .37399 .66634 .37675 .67092 .37526 .66872 .37249 Mtetra
.66872 .37249 .67092 .37526 .67551 .37376 .67331 .37099 Mtetra
.67331 .37099 .67551 .37376 .6801 .37226 .67791 .36949 Mtetra
.67791 .36949 .6801 .37226 .68471 .37076 .68252 .36798 Mtetra
.68252 .36798 .68471 .37076 .68932 .36926 .68713 .36647 Mtetra
.68713 .36647 .68932 .36926 .69393 .36775 .69176 .36496 Mtetra
.69176 .36496 .69393 .36775 .69856 .36624 .69638 .36345 Mtetra
.69638 .36345 .69856 .36624 .70319 .36473 .70102 .36193 Mtetra
.70102 .36193 .70319 .36473 .70783 .36322 .70567 .36041 Mtetra
.979 .69 .391 r
.70567 .36041 .70783 .36322 .71248 .3617 .7023 .22128 Mtetra
.539 .322 .533 r
.7023 .22128 .71248 .3617 .70882 .2226 .70675 .21972 Mtetra
.664 .741 .908 r
.70675 .21972 .70882 .2226 .71328 .22104 .71121 .21815 Mtetra
.71121 .21815 .71328 .22104 .71774 .21947 .71568 .21658 Mtetra
.71568 .21658 .71774 .21947 .7222 .21791 .72015 .215 Mtetra
.72015 .215 .7222 .21791 .72668 .21634 .72463 .21343 Mtetra
.72463 .21343 .72668 .21634 .73116 .21476 .72912 .21185 Mtetra
.72912 .21185 .73116 .21476 .73565 .21319 .73361 .21027 Mtetra
.73361 .21027 .73565 .21319 .74015 .21161 .73811 .20869 Mtetra
.73811 .20869 .74015 .21161 .74465 .21003 .74262 .2071 Mtetra
.74262 .2071 .74465 .21003 .74916 .20844 .74714 .20551 Mtetra
.74714 .20551 .74916 .20844 .75368 .20686 .75166 .20392 Mtetra
.75166 .20392 .75368 .20686 .7582 .20527 .75619 .20233 Mtetra
.75619 .20233 .7582 .20527 .76274 .20368 .76073 .20073 Mtetra
.76073 .20073 .76274 .20368 .76728 .20209 .76527 .19914 Mtetra
.76527 .19914 .76728 .20209 .77182 .20049 .76982 .19754 Mtetra
.76982 .19754 .77182 .20049 .77638 .19889 .77438 .19593 Mtetra
.77438 .19593 .77638 .19889 .78094 .19729 .77895 .19433 Mtetra
.77895 .19433 .78094 .19729 .7855 .19569 .78352 .19272 Mtetra
.78352 .19272 .7855 .19569 .79008 .19408 .7881 .19111 Mtetra
.7881 .19111 .79008 .19408 .79466 .19247 .79269 .1895 Mtetra
.79269 .1895 .79466 .19247 .79925 .19086 .79728 .18788 Mtetra
.79728 .18788 .79925 .19086 .80385 .18925 .80189 .18626 Mtetra
.80189 .18626 .80385 .18925 .80845 .18763 .80649 .18464 Mtetra
.18589 .39958 .18846 .40198 .19214 .40068 .18958 .39829 Mtetra
.18958 .39829 .19214 .40068 .19583 .39938 .19327 .39699 Mtetra
.19327 .39699 .19583 .39938 .19952 .39809 .19696 .39568 Mtetra
.19696 .39568 .19952 .39809 .20322 .39679 .20066 .39438 Mtetra
.20066 .39438 .20322 .39679 .20692 .39548 .20437 .39307 Mtetra
.20437 .39307 .20692 .39548 .21063 .39418 .20808 .39177 Mtetra
.20808 .39177 .21063 .39418 .21435 .39287 .2118 .39046 Mtetra
.2118 .39046 .21435 .39287 .21807 .39156 .21552 .38915 Mtetra
.21552 .38915 .21807 .39156 .22179 .39025 .21925 .38783 Mtetra
.21925 .38783 .22179 .39025 .22552 .38894 .22298 .38652 Mtetra
.22298 .38652 .22552 .38894 .22926 .38763 .22672 .3852 Mtetra
.541 .032 0 r
.22672 .3852 .22926 .38763 .23257 .39104 .23003 .38861 Mtetra
.663 .742 .908 r
.23003 .38861 .23257 .39104 .23632 .38972 .23379 .38729 Mtetra
.23379 .38729 .23632 .38972 .24008 .3884 .23755 .38597 Mtetra
.23755 .38597 .24008 .3884 .24384 .38708 .24131 .38464 Mtetra
.24131 .38464 .24384 .38708 .24761 .38576 .24508 .38332 Mtetra
.24508 .38332 .24761 .38576 .25138 .38444 .24886 .38199 Mtetra
.24886 .38199 .25138 .38444 .25516 .38311 .25264 .38066 Mtetra
.25264 .38066 .25516 .38311 .25894 .38179 .25643 .37933 Mtetra
.25643 .37933 .25894 .38179 .26273 .38046 .26022 .378 Mtetra
.26022 .378 .26273 .38046 .26653 .37912 .26402 .37666 Mtetra
.26402 .37666 .26653 .37912 .27033 .37779 .26782 .37533 Mtetra
.26782 .37533 .27033 .37779 .27413 .37646 .27163 .37399 Mtetra
.27163 .37399 .27413 .37646 .27794 .37512 .27545 .37265 Mtetra
.27545 .37265 .27794 .37512 .28176 .37378 .27927 .3713 Mtetra
.27927 .3713 .28176 .37378 .28558 .37244 .28309 .36996 Mtetra
.28309 .36996 .28558 .37244 .28941 .3711 .28693 .36861 Mtetra
.95 .676 .482 r
.28693 .36861 .28941 .3711 .28614 .46773 .28357 .4653 Mtetra
.656 .751 .92 r
.28357 .4653 .28614 .46773 .29009 .46642 .28752 .46398 Mtetra
.28752 .46398 .29009 .46642 .29405 .4651 .29148 .46266 Mtetra
.29148 .46266 .29405 .4651 .29801 .46378 .29545 .46134 Mtetra
.29545 .46134 .29801 .46378 .30198 .46246 .29942 .46002 Mtetra
.29942 .46002 .30198 .46246 .30596 .46114 .3034 .45869 Mtetra
.3034 .45869 .30596 .46114 .30994 .45981 .30739 .45736 Mtetra
.953 .667 .457 r
.30739 .45736 .30994 .45981 .31393 .45849 .30735 .51796 Mtetra
.519 .279 .49 r
.30735 .51796 .31393 .45849 .31401 .51907 .31142 .51665 Mtetra
.651 .757 .927 r
.31142 .51665 .31401 .51907 .31809 .51776 .31549 .51534 Mtetra
.31549 .51534 .31809 .51776 .32216 .51645 .31958 .51402 Mtetra
.31958 .51402 .32216 .51645 .32625 .51514 .32367 .51271 Mtetra
.32367 .51271 .32625 .51514 .33034 .51382 .32776 .51139 Mtetra
.32776 .51139 .33034 .51382 .33444 .51251 .33186 .51007 Mtetra
.33186 .51007 .33444 .51251 .33854 .51119 .33597 .50875 Mtetra
.33597 .50875 .33854 .51119 .34265 .50987 .34008 .50743 Mtetra
.34008 .50743 .34265 .50987 .34677 .50855 .34421 .5061 Mtetra
.34421 .5061 .34677 .50855 .35089 .50722 .34833 .50477 Mtetra
.34833 .50477 .35089 .50722 .35502 .5059 .35247 .50344 Mtetra
.35247 .50344 .35502 .5059 .35916 .50457 .35661 .50211 Mtetra
.35661 .50211 .35916 .50457 .3633 .50324 .36075 .50078 Mtetra
.36075 .50078 .3633 .50324 .36745 .5019 .3649 .49944 Mtetra
.3649 .49944 .36745 .5019 .3716 .50057 .36906 .4981 Mtetra
.36906 .4981 .3716 .50057 .37577 .49923 .37323 .49676 Mtetra
.953 .709 .531 r
.37323 .49676 .37577 .49923 .38221 .44584 .37972 .44333 Mtetra
.655 .752 .921 r
.37972 .44333 .38221 .44584 .38632 .44448 .38383 .44197 Mtetra
.38383 .44197 .38632 .44448 .39043 .44312 .38795 .4406 Mtetra
.38795 .4406 .39043 .44312 .39456 .44176 .39208 .43923 Mtetra
.39208 .43923 .39456 .44176 .39869 .44039 .39621 .43786 Mtetra
.39621 .43786 .39869 .44039 .40282 .43902 .40035 .43649 Mtetra
.40035 .43649 .40282 .43902 .40697 .43765 .4045 .43512 Mtetra
.4045 .43512 .40697 .43765 .41112 .43628 .40865 .43374 Mtetra
.40865 .43374 .41112 .43628 .41527 .43491 .41281 .43236 Mtetra
.41281 .43236 .41527 .43491 .41943 .43353 .41698 .43098 Mtetra
.41698 .43098 .41943 .43353 .4236 .43215 .42115 .4296 Mtetra
.42115 .4296 .4236 .43215 .42778 .43077 .42533 .42821 Mtetra
.42533 .42821 .42778 .43077 .43196 .42939 .42952 .42683 Mtetra
.42952 .42683 .43196 .42939 .43615 .428 .43371 .42544 Mtetra
.43371 .42544 .43615 .428 .44034 .42661 .43791 .42405 Mtetra
.43791 .42405 .44034 .42661 .44454 .42522 .44211 .42265 Mtetra
.44211 .42265 .44454 .42522 .44875 .42383 .44632 .42126 Mtetra
.44632 .42126 .44875 .42383 .4555 .30807 .45054 .41986 Mtetra
0 0 .257 r
.45054 .41986 .4555 .30807 .45957 .30664 .45724 .30399 Mtetra
.664 .741 .908 r
.45724 .30399 .45957 .30664 .46365 .3052 .46132 .30255 Mtetra
.46132 .30255 .46365 .3052 .46773 .30377 .46541 .30111 Mtetra
.46541 .30111 .46773 .30377 .47183 .30233 .46951 .29967 Mtetra
.966 .68 .438 r
.46951 .29967 .47183 .30233 .47592 .30089 .47033 .49767 Mtetra
.529 .3 .511 r
.47033 .49767 .47592 .30089 .48003 .29944 .4747 .49629 Mtetra
.4747 .49629 .48003 .29944 .48153 .49746 .47908 .49491 Mtetra
.648 .76 .931 r
.47908 .49491 .48153 .49746 .48591 .49608 .48346 .49352 Mtetra
.48346 .49352 .48591 .49608 .4903 .4947 .48785 .49214 Mtetra
.48785 .49214 .4903 .4947 .49469 .49331 .49224 .49075 Mtetra
.49224 .49075 .49469 .49331 .49909 .49192 .49665 .48936 Mtetra
.49665 .48936 .49909 .49192 .50349 .49054 .50106 .48797 Mtetra
.50106 .48797 .50349 .49054 .5079 .48914 .50548 .48657 Mtetra
.50548 .48657 .5079 .48914 .51232 .48775 .5099 .48517 Mtetra
.5099 .48517 .51232 .48775 .51675 .48635 .51433 .48377 Mtetra
.51433 .48377 .51675 .48635 .52119 .48496 .51877 .48237 Mtetra
.51877 .48237 .52119 .48496 .52563 .48356 .52322 .48097 Mtetra
.52322 .48097 .52563 .48356 .53008 .48215 .52767 .47956 Mtetra
.52767 .47956 .53008 .48215 .53453 .48075 .53213 .47815 Mtetra
.53213 .47815 .53453 .48075 .539 .47934 .5366 .47674 Mtetra
.939 .772 .649 r
.5366 .47674 .539 .47934 .5434 .46703 .54102 .46441 Mtetra
.649 .759 .93 r
.54102 .46441 .5434 .46703 .54787 .46561 .54549 .46299 Mtetra
.54549 .46299 .54787 .46561 .55234 .46419 .54996 .46157 Mtetra
.54996 .46157 .55234 .46419 .55681 .46277 .55445 .46014 Mtetra
.55445 .46014 .55681 .46277 .5613 .46135 .55893 .45872 Mtetra
.55893 .45872 .5613 .46135 .56579 .45993 .56343 .45729 Mtetra
.56343 .45729 .56579 .45993 .57029 .4585 .56794 .45586 Mtetra
.56794 .45586 .57029 .4585 .5748 .45707 .57245 .45442 Mtetra
.57245 .45442 .5748 .45707 .57931 .45564 .57696 .45299 Mtetra
.57696 .45299 .57931 .45564 .58383 .4542 .58149 .45155 Mtetra
.58149 .45155 .58383 .4542 .58836 .45277 .58602 .45011 Mtetra
.58602 .45011 .58836 .45277 .59289 .45133 .59056 .44866 Mtetra
.59056 .44866 .59289 .45133 .59744 .44989 .59511 .44722 Mtetra
.59511 .44722 .59744 .44989 .60199 .44844 .59967 .44577 Mtetra
.974 .72 .487 r
.59967 .44577 .60199 .44844 .60547 .40387 .60318 .40116 Mtetra
.653 .755 .925 r
.60318 .40116 .60547 .40387 .60997 .4024 .60769 .39969 Mtetra
.60769 .39969 .60997 .4024 .61449 .40094 .61221 .39822 Mtetra
.61221 .39822 .61449 .40094 .619 .39947 .61673 .39675 Mtetra
.61673 .39675 .619 .39947 .62353 .398 .62126 .39527 Mtetra
.62126 .39527 .62353 .398 .62806 .39652 .6258 .3938 Mtetra
.6258 .3938 .62806 .39652 .63261 .39505 .63035 .39231 Mtetra
.63035 .39231 .63261 .39505 .63715 .39357 .6349 .39083 Mtetra
.6349 .39083 .63715 .39357 .64171 .39209 .63946 .38935 Mtetra
.63946 .38935 .64171 .39209 .64627 .3906 .64403 .38786 Mtetra
.64403 .38786 .64627 .3906 .65084 .38912 .64861 .38637 Mtetra
.64861 .38637 .65084 .38912 .65542 .38763 .65319 .38488 Mtetra
.65319 .38488 .65542 .38763 .66001 .38614 .65778 .38338 Mtetra
.65778 .38338 .66001 .38614 .66413 .37399 .66238 .38188 Mtetra
.414 .075 .278 r
.66238 .38188 .66413 .37399 .66872 .37249 .66698 .38038 Mtetra
0 0 0 r
.66698 .38038 .66872 .37249 .67331 .37099 .67111 .36821 Mtetra
.653 .754 .924 r
.67111 .36821 .67331 .37099 .67791 .36949 .67571 .36671 Mtetra
.67571 .36671 .67791 .36949 .68252 .36798 .68032 .3652 Mtetra
.68032 .3652 .68252 .36798 .68713 .36647 .68494 .36368 Mtetra
.68494 .36368 .68713 .36647 .69176 .36496 .68957 .36217 Mtetra
.68957 .36217 .69176 .36496 .69638 .36345 .69421 .36065 Mtetra
.69421 .36065 .69638 .36345 .70102 .36193 .69885 .35913 Mtetra
.979 .691 .393 r
.69885 .35913 .70102 .36193 .70567 .36041 .69577 .21996 Mtetra
.539 .321 .533 r
.69577 .21996 .70567 .36041 .7023 .22128 .70022 .21839 Mtetra
.664 .741 .908 r
.70022 .21839 .7023 .22128 .70675 .21972 .70467 .21682 Mtetra
.70467 .21682 .70675 .21972 .71121 .21815 .70914 .21525 Mtetra
.70914 .21525 .71121 .21815 .71568 .21658 .71361 .21367 Mtetra
.71361 .21367 .71568 .21658 .72015 .215 .71809 .21209 Mtetra
.71809 .21209 .72015 .215 .72463 .21343 .72257 .21051 Mtetra
.72257 .21051 .72463 .21343 .72912 .21185 .72706 .20893 Mtetra
.72706 .20893 .72912 .21185 .73361 .21027 .73156 .20735 Mtetra
.73156 .20735 .73361 .21027 .73811 .20869 .73607 .20576 Mtetra
.73607 .20576 .73811 .20869 .74262 .2071 .74058 .20417 Mtetra
.74058 .20417 .74262 .2071 .74714 .20551 .7451 .20258 Mtetra
.7451 .20258 .74714 .20551 .75166 .20392 .74963 .20098 Mtetra
.74963 .20098 .75166 .20392 .75619 .20233 .75417 .19938 Mtetra
.75417 .19938 .75619 .20233 .76073 .20073 .75871 .19778 Mtetra
.75871 .19778 .76073 .20073 .76527 .19914 .76326 .19618 Mtetra
.76326 .19618 .76527 .19914 .76982 .19754 .76782 .19457 Mtetra
.76782 .19457 .76982 .19754 .77438 .19593 .77238 .19297 Mtetra
.77238 .19297 .77438 .19593 .77895 .19433 .77695 .19136 Mtetra
.77695 .19136 .77895 .19433 .78352 .19272 .78153 .18974 Mtetra
.78153 .18974 .78352 .19272 .7881 .19111 .78611 .18813 Mtetra
.78611 .18813 .7881 .19111 .79269 .1895 .79071 .18651 Mtetra
.79071 .18651 .79269 .1895 .79728 .18788 .79531 .18489 Mtetra
.79531 .18489 .79728 .18788 .80189 .18626 .79991 .18327 Mtetra
.79991 .18327 .80189 .18626 .80649 .18464 .80453 .18164 Mtetra
.18331 .39719 .18589 .39958 .18958 .39829 .187 .39588 Mtetra
.187 .39588 .18958 .39829 .19327 .39699 .1907 .39458 Mtetra
.1907 .39458 .19327 .39699 .19696 .39568 .1944 .39327 Mtetra
.1944 .39327 .19696 .39568 .20066 .39438 .1981 .39197 Mtetra
.1981 .39197 .20066 .39438 .20437 .39307 .20181 .39066 Mtetra
.20181 .39066 .20437 .39307 .20808 .39177 .20552 .38935 Mtetra
.20552 .38935 .20808 .39177 .2118 .39046 .20924 .38803 Mtetra
.20924 .38803 .2118 .39046 .21552 .38915 .21297 .38672 Mtetra
.21297 .38672 .21552 .38915 .21925 .38783 .2167 .3854 Mtetra
.2167 .3854 .21925 .38783 .22298 .38652 .22044 .38408 Mtetra
.22044 .38408 .22298 .38652 .22672 .3852 .22418 .38276 Mtetra
.22418 .38276 .22672 .3852 .23003 .38861 .22793 .38144 Mtetra
.225 .266 .695 r
.22793 .38144 .23003 .38861 .23379 .38729 .23125 .38485 Mtetra
.663 .742 .908 r
.23125 .38485 .23379 .38729 .23755 .38597 .23501 .38352 Mtetra
.23501 .38352 .23755 .38597 .24131 .38464 .23878 .38219 Mtetra
.23878 .38219 .24131 .38464 .24508 .38332 .24255 .38087 Mtetra
.24255 .38087 .24508 .38332 .24886 .38199 .24633 .37953 Mtetra
.24633 .37953 .24886 .38199 .25264 .38066 .25012 .3782 Mtetra
.25012 .3782 .25264 .38066 .25643 .37933 .25391 .37687 Mtetra
.25391 .37687 .25643 .37933 .26022 .378 .2577 .37553 Mtetra
.2577 .37553 .26022 .378 .26402 .37666 .2615 .37419 Mtetra
.2615 .37419 .26402 .37666 .26782 .37533 .26531 .37285 Mtetra
.26531 .37285 .26782 .37533 .27163 .37399 .26912 .37151 Mtetra
.26912 .37151 .27163 .37399 .27545 .37265 .27294 .37017 Mtetra
.27294 .37017 .27545 .37265 .27927 .3713 .27677 .36882 Mtetra
.27677 .36882 .27927 .3713 .28309 .36996 .2806 .36747 Mtetra
.2806 .36747 .28309 .36996 .28693 .36861 .28443 .36612 Mtetra
.28443 .36612 .28693 .36861 .28357 .4653 .28827 .36477 Mtetra
0 0 .235 r
.28827 .36477 .28357 .4653 .28752 .46398 .28495 .46154 Mtetra
.656 .751 .92 r
.28495 .46154 .28752 .46398 .29148 .46266 .28891 .46022 Mtetra
.28891 .46022 .29148 .46266 .29545 .46134 .29288 .4589 Mtetra
.29288 .4589 .29545 .46134 .29942 .46002 .29686 .45757 Mtetra
.29686 .45757 .29942 .46002 .3034 .45869 .30084 .45624 Mtetra
.953 .667 .458 r
.30084 .45624 .3034 .45869 .30739 .45736 .30067 .51685 Mtetra
.519 .278 .489 r
.30067 .51685 .30739 .45736 .30735 .51796 .30474 .51554 Mtetra
.651 .757 .927 r
.30474 .51554 .30735 .51796 .31142 .51665 .30882 .51423 Mtetra
.30882 .51423 .31142 .51665 .31549 .51534 .3129 .51291 Mtetra
.3129 .51291 .31549 .51534 .31958 .51402 .31698 .51159 Mtetra
.31698 .51159 .31958 .51402 .32367 .51271 .32107 .51027 Mtetra
.32107 .51027 .32367 .51271 .32776 .51139 .32517 .50895 Mtetra
.32517 .50895 .32776 .51139 .33186 .51007 .32928 .50763 Mtetra
.32928 .50763 .33186 .51007 .33597 .50875 .33339 .5063 Mtetra
.33339 .5063 .33597 .50875 .34008 .50743 .33751 .50498 Mtetra
.33751 .50498 .34008 .50743 .34421 .5061 .34163 .50365 Mtetra
.34163 .50365 .34421 .5061 .34833 .50477 .34576 .50231 Mtetra
.34576 .50231 .34833 .50477 .35247 .50344 .3499 .50098 Mtetra
.3499 .50098 .35247 .50344 .35661 .50211 .35405 .49964 Mtetra
.35405 .49964 .35661 .50211 .36075 .50078 .3582 .49831 Mtetra
.3582 .49831 .36075 .50078 .3649 .49944 .36235 .49697 Mtetra
.36235 .49697 .3649 .49944 .36906 .4981 .36652 .49562 Mtetra
.36652 .49562 .36906 .4981 .37323 .49676 .37069 .49428 Mtetra
.37069 .49428 .37323 .49676 .37972 .44333 .37486 .49293 Mtetra
0 0 .165 r
.37486 .49293 .37972 .44333 .38383 .44197 .38134 .43944 Mtetra
.655 .752 .921 r
.38134 .43944 .38383 .44197 .38795 .4406 .38546 .43807 Mtetra
.38546 .43807 .38795 .4406 .39208 .43923 .3896 .4367 Mtetra
.3896 .4367 .39208 .43923 .39621 .43786 .39373 .43533 Mtetra
.39373 .43533 .39621 .43786 .40035 .43649 .39788 .43395 Mtetra
.39788 .43395 .40035 .43649 .4045 .43512 .40203 .43257 Mtetra
.40203 .43257 .4045 .43512 .40865 .43374 .40618 .43119 Mtetra
.40618 .43119 .40865 .43374 .41281 .43236 .41035 .42981 Mtetra
.41035 .42981 .41281 .43236 .41698 .43098 .41452 .42843 Mtetra
.41452 .42843 .41698 .43098 .42115 .4296 .41869 .42704 Mtetra
.41869 .42704 .42115 .4296 .42533 .42821 .42288 .42565 Mtetra
.42288 .42565 .42533 .42821 .42952 .42683 .42707 .42426 Mtetra
.42707 .42426 .42952 .42683 .43371 .42544 .43126 .42287 Mtetra
.43126 .42287 .43371 .42544 .43791 .42405 .43547 .42147 Mtetra
.43547 .42147 .43791 .42405 .44211 .42265 .43967 .42008 Mtetra
.43967 .42008 .44211 .42265 .44632 .42126 .44389 .41868 Mtetra
.44389 .41868 .44632 .42126 .45054 .41986 .44811 .41728 Mtetra
.963 .699 .485 r
.44811 .41728 .45054 .41986 .45724 .30399 .45491 .30133 Mtetra
.664 .741 .908 r
.45491 .30133 .45724 .30399 .46132 .30255 .45899 .29989 Mtetra
.45899 .29989 .46132 .30255 .46541 .30111 .46309 .29844 Mtetra
.966 .68 .439 r
.46309 .29844 .46541 .30111 .46951 .29967 .4635 .4965 Mtetra
.528 .299 .51 r
.4635 .4965 .46951 .29967 .47033 .49767 .46786 .49512 Mtetra
.648 .76 .931 r
.46786 .49512 .47033 .49767 .4747 .49629 .47223 .49374 Mtetra
.47223 .49374 .4747 .49629 .47908 .49491 .47661 .49235 Mtetra
.47661 .49235 .47908 .49491 .48346 .49352 .481 .49096 Mtetra
.481 .49096 .48346 .49352 .48785 .49214 .48539 .48957 Mtetra
.48539 .48957 .48785 .49214 .49224 .49075 .4898 .48818 Mtetra
.4898 .48818 .49224 .49075 .49665 .48936 .4942 .48678 Mtetra
.4942 .48678 .49665 .48936 .50106 .48797 .49862 .48539 Mtetra
.49862 .48539 .50106 .48797 .50548 .48657 .50304 .48399 Mtetra
.50304 .48399 .50548 .48657 .5099 .48517 .50747 .48259 Mtetra
.50747 .48259 .5099 .48517 .51433 .48377 .51191 .48118 Mtetra
.51191 .48118 .51433 .48377 .51877 .48237 .51635 .47978 Mtetra
.51635 .47978 .51877 .48237 .52322 .48097 .5208 .47837 Mtetra
.5208 .47837 .52322 .48097 .52767 .47956 .52526 .47696 Mtetra
.52526 .47696 .52767 .47956 .53213 .47815 .52972 .47554 Mtetra
.52972 .47554 .53213 .47815 .5366 .47674 .5342 .47413 Mtetra
.939 .772 .649 r
.5342 .47413 .5366 .47674 .54102 .46441 .53863 .46179 Mtetra
.649 .759 .93 r
.53863 .46179 .54102 .46441 .54549 .46299 .5431 .46036 Mtetra
.5431 .46036 .54549 .46299 .54996 .46157 .54758 .45894 Mtetra
.54758 .45894 .54996 .46157 .55445 .46014 .55207 .45751 Mtetra
.55207 .45751 .55445 .46014 .55893 .45872 .55656 .45608 Mtetra
.55656 .45608 .55893 .45872 .56343 .45729 .56106 .45464 Mtetra
.56106 .45464 .56343 .45729 .56794 .45586 .56557 .45321 Mtetra
.56557 .45321 .56794 .45586 .57245 .45442 .57009 .45177 Mtetra
.57009 .45177 .57245 .45442 .57696 .45299 .57461 .45033 Mtetra
.57461 .45033 .57696 .45299 .58149 .45155 .57914 .44889 Mtetra
.57914 .44889 .58149 .45155 .58602 .45011 .58368 .44744 Mtetra
.58368 .44744 .58602 .45011 .59056 .44866 .58823 .44599 Mtetra
.58823 .44599 .59056 .44866 .59511 .44722 .59278 .44454 Mtetra
.59278 .44454 .59511 .44722 .59967 .44577 .59734 .44309 Mtetra
.974 .72 .487 r
.59734 .44309 .59967 .44577 .60318 .40116 .60089 .39845 Mtetra
.653 .755 .925 r
.60089 .39845 .60318 .40116 .60769 .39969 .6054 .39698 Mtetra
.6054 .39698 .60769 .39969 .61221 .39822 .60993 .3955 Mtetra
.60993 .3955 .61221 .39822 .61673 .39675 .61445 .39402 Mtetra
.61445 .39402 .61673 .39675 .62126 .39527 .61899 .39254 Mtetra
.61899 .39254 .62126 .39527 .6258 .3938 .62353 .39106 Mtetra
.62353 .39106 .6258 .3938 .63035 .39231 .62809 .38958 Mtetra
.62809 .38958 .63035 .39231 .6349 .39083 .63264 .38809 Mtetra
.63264 .38809 .6349 .39083 .63946 .38935 .63721 .3866 Mtetra
.63721 .3866 .63946 .38935 .64403 .38786 .64178 .38511 Mtetra
.64178 .38511 .64403 .38786 .64861 .38637 .64636 .38361 Mtetra
.64636 .38361 .64861 .38637 .65319 .38488 .65095 .38211 Mtetra
.65095 .38211 .65319 .38488 .65778 .38338 .65555 .38062 Mtetra
.65555 .38062 .65778 .38338 .66238 .38188 .66015 .37911 Mtetra
.66015 .37911 .66238 .38188 .66698 .38038 .66476 .37761 Mtetra
.66476 .37761 .66698 .38038 .67111 .36821 .66938 .3761 Mtetra
0 0 0 r
.66938 .3761 .67111 .36821 .67571 .36671 .67351 .36392 Mtetra
.653 .754 .924 r
.67351 .36392 .67571 .36671 .68032 .3652 .67812 .3624 Mtetra
.67812 .3624 .68032 .3652 .68494 .36368 .68275 .36088 Mtetra
.68275 .36088 .68494 .36368 .68957 .36217 .68738 .35936 Mtetra
.68738 .35936 .68957 .36217 .69421 .36065 .69202 .35784 Mtetra
.979 .691 .395 r
.69202 .35784 .69421 .36065 .69885 .35913 .68923 .21863 Mtetra
.538 .321 .532 r
.68923 .21863 .69885 .35913 .69577 .21996 .69368 .21706 Mtetra
.664 .741 .908 r
.69368 .21706 .69577 .21996 .70022 .21839 .69813 .21549 Mtetra
.69813 .21549 .70022 .21839 .70467 .21682 .70259 .21391 Mtetra
.70259 .21391 .70467 .21682 .70914 .21525 .70706 .21234 Mtetra
.70706 .21234 .70914 .21525 .71361 .21367 .71154 .21076 Mtetra
.71154 .21076 .71361 .21367 .71809 .21209 .71602 .20917 Mtetra
.71602 .20917 .71809 .21209 .72257 .21051 .72051 .20759 Mtetra
.72051 .20759 .72257 .21051 .72706 .20893 .72501 .206 Mtetra
.72501 .206 .72706 .20893 .73156 .20735 .72951 .20441 Mtetra
.72951 .20441 .73156 .20735 .73607 .20576 .73402 .20282 Mtetra
.73402 .20282 .73607 .20576 .74058 .20417 .73854 .20123 Mtetra
.73854 .20123 .74058 .20417 .7451 .20258 .74307 .19963 Mtetra
.74307 .19963 .7451 .20258 .74963 .20098 .7476 .19803 Mtetra
.7476 .19803 .74963 .20098 .75417 .19938 .75214 .19643 Mtetra
.75214 .19643 .75417 .19938 .75871 .19778 .75669 .19482 Mtetra
.75669 .19482 .75871 .19778 .76326 .19618 .76124 .19321 Mtetra
.76124 .19321 .76326 .19618 .76782 .19457 .7658 .1916 Mtetra
.7658 .1916 .76782 .19457 .77238 .19297 .77037 .18999 Mtetra
.77037 .18999 .77238 .19297 .77695 .19136 .77495 .18838 Mtetra
.77495 .18838 .77695 .19136 .78153 .18974 .77953 .18676 Mtetra
.77953 .18676 .78153 .18974 .78611 .18813 .78412 .18514 Mtetra
.78412 .18514 .78611 .18813 .79071 .18651 .78872 .18352 Mtetra
.78872 .18352 .79071 .18651 .79531 .18489 .79333 .18189 Mtetra
.79333 .18189 .79531 .18489 .79991 .18327 .79794 .18026 Mtetra
.79794 .18026 .79991 .18327 .80453 .18164 .80256 .17863 Mtetra
.18073 .39478 .18331 .39719 .187 .39588 .18442 .39348 Mtetra
.18442 .39348 .187 .39588 .1907 .39458 .18812 .39217 Mtetra
.18812 .39217 .1907 .39458 .1944 .39327 .19182 .39086 Mtetra
.19182 .39086 .1944 .39327 .1981 .39197 .19553 .38955 Mtetra
.19553 .38955 .1981 .39197 .20181 .39066 .19924 .38824 Mtetra
.19924 .38824 .20181 .39066 .20552 .38935 .20296 .38692 Mtetra
.20296 .38692 .20552 .38935 .20924 .38803 .20668 .38561 Mtetra
.20668 .38561 .20924 .38803 .21297 .38672 .21041 .38429 Mtetra
.21041 .38429 .21297 .38672 .2167 .3854 .21415 .38297 Mtetra
.21415 .38297 .2167 .3854 .22044 .38408 .21789 .38164 Mtetra
.21789 .38164 .22044 .38408 .22418 .38276 .22163 .38032 Mtetra
.22163 .38032 .22418 .38276 .22793 .38144 .22538 .37899 Mtetra
.537 .029 0 r
.22538 .37899 .22793 .38144 .23125 .38485 .2287 .3824 Mtetra
.663 .742 .908 r
.2287 .3824 .23125 .38485 .23501 .38352 .23247 .38107 Mtetra
.23247 .38107 .23501 .38352 .23878 .38219 .23624 .37974 Mtetra
.23624 .37974 .23878 .38219 .24255 .38087 .24001 .37841 Mtetra
.24001 .37841 .24255 .38087 .24633 .37953 .2438 .37707 Mtetra
.2438 .37707 .24633 .37953 .25012 .3782 .24759 .37574 Mtetra
.24759 .37574 .25012 .3782 .25391 .37687 .25138 .3744 Mtetra
.25138 .3744 .25391 .37687 .2577 .37553 .25518 .37306 Mtetra
.25518 .37306 .2577 .37553 .2615 .37419 .25898 .37172 Mtetra
.25898 .37172 .2615 .37419 .26531 .37285 .26279 .37037 Mtetra
.26279 .37037 .26531 .37285 .26912 .37151 .26661 .36903 Mtetra
.26661 .36903 .26912 .37151 .27294 .37017 .27043 .36768 Mtetra
.27043 .36768 .27294 .37017 .27677 .36882 .27426 .36633 Mtetra
.27426 .36633 .27677 .36882 .2806 .36747 .27809 .36498 Mtetra
.27809 .36498 .2806 .36747 .28443 .36612 .28193 .36362 Mtetra
.28193 .36362 .28443 .36612 .28827 .36477 .28577 .36227 Mtetra
.28577 .36227 .28827 .36477 .28495 .46154 .28962 .36091 Mtetra
0 0 .235 r
.28962 .36091 .28495 .46154 .28891 .46022 .28634 .45777 Mtetra
.656 .751 .92 r
.28634 .45777 .28891 .46022 .29288 .4589 .29031 .45644 Mtetra
.29031 .45644 .29288 .4589 .29686 .45757 .29429 .45511 Mtetra
.953 .667 .459 r
.29429 .45511 .29686 .45757 .30084 .45624 .29399 .51574 Mtetra
.518 .277 .489 r
.29399 .51574 .30084 .45624 .30067 .51685 .29806 .51443 Mtetra
.651 .757 .927 r
.29806 .51443 .30067 .51685 .30474 .51554 .30213 .51311 Mtetra
.30213 .51311 .30474 .51554 .30882 .51423 .30621 .5118 Mtetra
.30621 .5118 .30882 .51423 .3129 .51291 .31029 .51048 Mtetra
.31029 .51048 .3129 .51291 .31698 .51159 .31438 .50916 Mtetra
.31438 .50916 .31698 .51159 .32107 .51027 .31848 .50783 Mtetra
.31848 .50783 .32107 .51027 .32517 .50895 .32258 .50651 Mtetra
.32258 .50651 .32517 .50895 .32928 .50763 .32669 .50518 Mtetra
.32669 .50518 .32928 .50763 .33339 .5063 .3308 .50385 Mtetra
.3308 .50385 .33339 .5063 .33751 .50498 .33493 .50252 Mtetra
.33493 .50252 .33751 .50498 .34163 .50365 .33905 .50119 Mtetra
.33905 .50119 .34163 .50365 .34576 .50231 .34319 .49985 Mtetra
.34319 .49985 .34576 .50231 .3499 .50098 .34733 .49851 Mtetra
.34733 .49851 .3499 .50098 .35405 .49964 .35148 .49717 Mtetra
.35148 .49717 .35405 .49964 .3582 .49831 .35563 .49583 Mtetra
.35563 .49583 .3582 .49831 .36235 .49697 .35979 .49449 Mtetra
.35979 .49449 .36235 .49697 .36652 .49562 .36396 .49314 Mtetra
.36396 .49314 .36652 .49562 .37069 .49428 .36813 .49179 Mtetra
.36813 .49179 .37069 .49428 .37486 .49293 .37231 .49044 Mtetra
.954 .709 .53 r
.37231 .49044 .37486 .49293 .38134 .43944 .37884 .43691 Mtetra
.655 .752 .921 r
.37884 .43691 .38134 .43944 .38546 .43807 .38297 .43554 Mtetra
.38297 .43554 .38546 .43807 .3896 .4367 .3871 .43416 Mtetra
.3871 .43416 .3896 .4367 .39373 .43533 .39124 .43279 Mtetra
.39124 .43279 .39373 .43533 .39788 .43395 .39539 .43141 Mtetra
.39539 .43141 .39788 .43395 .40203 .43257 .39955 .43003 Mtetra
.39955 .43003 .40203 .43257 .40618 .43119 .40371 .42864 Mtetra
.40371 .42864 .40618 .43119 .41035 .42981 .40788 .42725 Mtetra
.40788 .42725 .41035 .42981 .41452 .42843 .41205 .42587 Mtetra
.41205 .42587 .41452 .42843 .41869 .42704 .41623 .42448 Mtetra
.41623 .42448 .41869 .42704 .42288 .42565 .42042 .42308 Mtetra
.42042 .42308 .42288 .42565 .42707 .42426 .42461 .42169 Mtetra
.42461 .42169 .42707 .42426 .43126 .42287 .42881 .42029 Mtetra
.42881 .42029 .43126 .42287 .43547 .42147 .43302 .41889 Mtetra
.43302 .41889 .43547 .42147 .43967 .42008 .43723 .41749 Mtetra
.43723 .41749 .43967 .42008 .44389 .41868 .44145 .41609 Mtetra
.44145 .41609 .44389 .41868 .44811 .41728 .44568 .41468 Mtetra
.44568 .41468 .44811 .41728 .45491 .30133 .44991 .41327 Mtetra
0 0 .255 r
.44991 .41327 .45491 .30133 .45899 .29989 .45666 .29722 Mtetra
.965 .68 .441 r
.45666 .29722 .45899 .29989 .46309 .29844 .45665 .49533 Mtetra
.528 .298 .51 r
.45665 .49533 .46309 .29844 .4635 .4965 .46101 .49395 Mtetra
.648 .76 .931 r
.46101 .49395 .4635 .4965 .46786 .49512 .46538 .49256 Mtetra
.46538 .49256 .46786 .49512 .47223 .49374 .46976 .49118 Mtetra
.46976 .49118 .47223 .49374 .47661 .49235 .47414 .48979 Mtetra
.47414 .48979 .47661 .49235 .481 .49096 .47853 .48839 Mtetra
.47853 .48839 .481 .49096 .48539 .48957 .48293 .487 Mtetra
.48293 .487 .48539 .48957 .4898 .48818 .48734 .4856 Mtetra
.48734 .4856 .4898 .48818 .4942 .48678 .49175 .4842 Mtetra
.49175 .4842 .4942 .48678 .49862 .48539 .49617 .4828 Mtetra
.49617 .4828 .49862 .48539 .50304 .48399 .5006 .4814 Mtetra
.5006 .4814 .50304 .48399 .50747 .48259 .50503 .47999 Mtetra
.50503 .47999 .50747 .48259 .51191 .48118 .50947 .47858 Mtetra
.50947 .47858 .51191 .48118 .51635 .47978 .51392 .47717 Mtetra
.51392 .47717 .51635 .47978 .5208 .47837 .51838 .47576 Mtetra
.51838 .47576 .5208 .47837 .52526 .47696 .52284 .47434 Mtetra
.52284 .47434 .52526 .47696 .52972 .47554 .52731 .47293 Mtetra
.52731 .47293 .52972 .47554 .5342 .47413 .53179 .47151 Mtetra
.939 .772 .649 r
.53179 .47151 .5342 .47413 .53863 .46179 .53623 .45916 Mtetra
.649 .759 .93 r
.53623 .45916 .53863 .46179 .5431 .46036 .54071 .45773 Mtetra
.54071 .45773 .5431 .46036 .54758 .45894 .54519 .4563 Mtetra
.54519 .4563 .54758 .45894 .55207 .45751 .54969 .45486 Mtetra
.54969 .45486 .55207 .45751 .55656 .45608 .55419 .45343 Mtetra
.55419 .45343 .55656 .45608 .56106 .45464 .55869 .45199 Mtetra
.55869 .45199 .56106 .45464 .56557 .45321 .5632 .45055 Mtetra
.5632 .45055 .56557 .45321 .57009 .45177 .56773 .44911 Mtetra
.56773 .44911 .57009 .45177 .57461 .45033 .57225 .44766 Mtetra
.57225 .44766 .57461 .45033 .57914 .44889 .57679 .44622 Mtetra
.57679 .44622 .57914 .44889 .58368 .44744 .58133 .44477 Mtetra
.58133 .44477 .58368 .44744 .58823 .44599 .58588 .44331 Mtetra
.58588 .44331 .58823 .44599 .59278 .44454 .59044 .44186 Mtetra
.59044 .44186 .59278 .44454 .59734 .44309 .59501 .4404 Mtetra
.974 .72 .487 r
.59501 .4404 .59734 .44309 .60089 .39845 .59859 .39573 Mtetra
.653 .755 .925 r
.59859 .39573 .60089 .39845 .6054 .39698 .60311 .39425 Mtetra
.60311 .39425 .6054 .39698 .60993 .3955 .60764 .39277 Mtetra
.60764 .39277 .60993 .3955 .61445 .39402 .61217 .39129 Mtetra
.61217 .39129 .61445 .39402 .61899 .39254 .61671 .3898 Mtetra
.61671 .3898 .61899 .39254 .62353 .39106 .62126 .38832 Mtetra
.62126 .38832 .62353 .39106 .62809 .38958 .62581 .38683 Mtetra
.62581 .38683 .62809 .38958 .63264 .38809 .63038 .38534 Mtetra
.63038 .38534 .63264 .38809 .63721 .3866 .63495 .38384 Mtetra
.63495 .38384 .63721 .3866 .64178 .38511 .63953 .38235 Mtetra
.63953 .38235 .64178 .38511 .64636 .38361 .64411 .38085 Mtetra
.64411 .38085 .64636 .38361 .65095 .38211 .64871 .37934 Mtetra
.64871 .37934 .65095 .38211 .65555 .38062 .65331 .37784 Mtetra
.65331 .37784 .65555 .38062 .66015 .37911 .65791 .37633 Mtetra
.65791 .37633 .66015 .37911 .66476 .37761 .66253 .37483 Mtetra
.66253 .37483 .66476 .37761 .66938 .3761 .66715 .37331 Mtetra
.66715 .37331 .66938 .3761 .67351 .36392 .67178 .3718 Mtetra
.411 .071 .275 r
.67178 .3718 .67351 .36392 .67812 .3624 .67642 .37028 Mtetra
0 0 0 r
.67642 .37028 .67812 .3624 .68275 .36088 .68055 .35807 Mtetra
.653 .754 .924 r
.68055 .35807 .68275 .36088 .68738 .35936 .68518 .35655 Mtetra
.68518 .35655 .68738 .35936 .69202 .35784 .68983 .35502 Mtetra
.979 .691 .395 r
.68983 .35502 .69202 .35784 .68923 .21863 .68713 .21573 Mtetra
.664 .741 .908 r
.68713 .21573 .68923 .21863 .69368 .21706 .69158 .21416 Mtetra
.69158 .21416 .69368 .21706 .69813 .21549 .69604 .21258 Mtetra
.69604 .21258 .69813 .21549 .70259 .21391 .7005 .211 Mtetra
.7005 .211 .70259 .21391 .70706 .21234 .70498 .20942 Mtetra
.70498 .20942 .70706 .21234 .71154 .21076 .70946 .20783 Mtetra
.70946 .20783 .71154 .21076 .71602 .20917 .71395 .20625 Mtetra
.71395 .20625 .71602 .20917 .72051 .20759 .71844 .20466 Mtetra
.71844 .20466 .72051 .20759 .72501 .206 .72294 .20307 Mtetra
.72294 .20307 .72501 .206 .72951 .20441 .72745 .20147 Mtetra
.72745 .20147 .72951 .20441 .73402 .20282 .73197 .19987 Mtetra
.73197 .19987 .73402 .20282 .73854 .20123 .73649 .19828 Mtetra
.73649 .19828 .73854 .20123 .74307 .19963 .74102 .19667 Mtetra
.74102 .19667 .74307 .19963 .7476 .19803 .74556 .19507 Mtetra
.74556 .19507 .7476 .19803 .75214 .19643 .75011 .19346 Mtetra
.75011 .19346 .75214 .19643 .75669 .19482 .75466 .19185 Mtetra
.75466 .19185 .75669 .19482 .76124 .19321 .75922 .19024 Mtetra
.75922 .19024 .76124 .19321 .7658 .1916 .76378 .18863 Mtetra
.76378 .18863 .7658 .1916 .77037 .18999 .76836 .18701 Mtetra
.76836 .18701 .77037 .18999 .77495 .18838 .77294 .18539 Mtetra
.77294 .18539 .77495 .18838 .77953 .18676 .77753 .18377 Mtetra
.77753 .18377 .77953 .18676 .78412 .18514 .78212 .18214 Mtetra
.78212 .18214 .78412 .18514 .78872 .18352 .78673 .18051 Mtetra
.78673 .18051 .78872 .18352 .79333 .18189 .79134 .17888 Mtetra
.79134 .17888 .79333 .18189 .79794 .18026 .79596 .17725 Mtetra
.79596 .17725 .79794 .18026 .80256 .17863 .80058 .17561 Mtetra
.17814 .39237 .18073 .39478 .18442 .39348 .18184 .39106 Mtetra
.18184 .39106 .18442 .39348 .18812 .39217 .18554 .38975 Mtetra
.18554 .38975 .18812 .39217 .19182 .39086 .18924 .38844 Mtetra
.18924 .38844 .19182 .39086 .19553 .38955 .19295 .38712 Mtetra
.19295 .38712 .19553 .38955 .19924 .38824 .19667 .38581 Mtetra
.19667 .38581 .19924 .38824 .20296 .38692 .20039 .38449 Mtetra
.20039 .38449 .20296 .38692 .20668 .38561 .20412 .38317 Mtetra
.20412 .38317 .20668 .38561 .21041 .38429 .20785 .38185 Mtetra
.20785 .38185 .21041 .38429 .21415 .38297 .21158 .38052 Mtetra
.21158 .38052 .21415 .38297 .21789 .38164 .21533 .3792 Mtetra
.21533 .3792 .21789 .38164 .22163 .38032 .21908 .37787 Mtetra
.21908 .37787 .22163 .38032 .22538 .37899 .22283 .37654 Mtetra
.22283 .37654 .22538 .37899 .2287 .3824 .22659 .37521 Mtetra
.224 .265 .695 r
.22659 .37521 .2287 .3824 .23247 .38107 .22992 .37861 Mtetra
.663 .742 .908 r
.22992 .37861 .23247 .38107 .23624 .37974 .23369 .37728 Mtetra
.23369 .37728 .23624 .37974 .24001 .37841 .23747 .37594 Mtetra
.23747 .37594 .24001 .37841 .2438 .37707 .24126 .3746 Mtetra
.24126 .3746 .2438 .37707 .24759 .37574 .24505 .37327 Mtetra
.24505 .37327 .24759 .37574 .25138 .3744 .24885 .37192 Mtetra
.24885 .37192 .25138 .3744 .25518 .37306 .25265 .37058 Mtetra
.25265 .37058 .25518 .37306 .25898 .37172 .25646 .36923 Mtetra
.25646 .36923 .25898 .37172 .26279 .37037 .26027 .36789 Mtetra
.26027 .36789 .26279 .37037 .26661 .36903 .26409 .36654 Mtetra
.26409 .36654 .26661 .36903 .27043 .36768 .26791 .36519 Mtetra
.26791 .36519 .27043 .36768 .27426 .36633 .27174 .36383 Mtetra
.27174 .36383 .27426 .36633 .27809 .36498 .27558 .36248 Mtetra
.27558 .36248 .27809 .36498 .28193 .36362 .27942 .36112 Mtetra
.27942 .36112 .28193 .36362 .28577 .36227 .28327 .35976 Mtetra
.28327 .35976 .28577 .36227 .28962 .36091 .28712 .3584 Mtetra
.951 .676 .48 r
.28712 .3584 .28962 .36091 .28634 .45777 .28375 .45532 Mtetra
.656 .751 .92 r
.28375 .45532 .28634 .45777 .29031 .45644 .28773 .45398 Mtetra
.952 .667 .461 r
.28773 .45398 .29031 .45644 .29429 .45511 .2873 .51463 Mtetra
.517 .276 .488 r
.2873 .51463 .29429 .45511 .29399 .51574 .29136 .51332 Mtetra
.651 .757 .927 r
.29136 .51332 .29399 .51574 .29806 .51443 .29543 .512 Mtetra
.29543 .512 .29806 .51443 .30213 .51311 .29951 .51068 Mtetra
.29951 .51068 .30213 .51311 .30621 .5118 .30359 .50936 Mtetra
.30359 .50936 .30621 .5118 .31029 .51048 .30768 .50804 Mtetra
.30768 .50804 .31029 .51048 .31438 .50916 .31177 .50671 Mtetra
.31177 .50671 .31438 .50916 .31848 .50783 .31587 .50539 Mtetra
.31587 .50539 .31848 .50783 .32258 .50651 .31998 .50406 Mtetra
.31998 .50406 .32258 .50651 .32669 .50518 .32409 .50272 Mtetra
.32409 .50272 .32669 .50518 .3308 .50385 .32821 .50139 Mtetra
.32821 .50139 .3308 .50385 .33493 .50252 .33234 .50006 Mtetra
.33234 .50006 .33493 .50252 .33905 .50119 .33647 .49872 Mtetra
.33647 .49872 .33905 .50119 .34319 .49985 .34061 .49738 Mtetra
.34061 .49738 .34319 .49985 .34733 .49851 .34475 .49604 Mtetra
.34475 .49604 .34733 .49851 .35148 .49717 .3489 .49469 Mtetra
.3489 .49469 .35148 .49717 .35563 .49583 .35306 .49335 Mtetra
.35306 .49335 .35563 .49583 .35979 .49449 .35723 .492 Mtetra
.35723 .492 .35979 .49449 .36396 .49314 .3614 .49065 Mtetra
.3614 .49065 .36396 .49314 .36813 .49179 .36557 .4893 Mtetra
.36557 .4893 .36813 .49179 .37231 .49044 .36976 .48794 Mtetra
.954 .709 .53 r
.36976 .48794 .37231 .49044 .37884 .43691 .37633 .43438 Mtetra
.655 .752 .921 r
.37633 .43438 .37884 .43691 .38297 .43554 .38046 .433 Mtetra
.38046 .433 .38297 .43554 .3871 .43416 .3846 .43162 Mtetra
.3846 .43162 .3871 .43416 .39124 .43279 .38875 .43024 Mtetra
.38875 .43024 .39124 .43279 .39539 .43141 .3929 .42885 Mtetra
.3929 .42885 .39539 .43141 .39955 .43003 .39706 .42747 Mtetra
.39706 .42747 .39955 .43003 .40371 .42864 .40123 .42608 Mtetra
.40123 .42608 .40371 .42864 .40788 .42725 .4054 .42469 Mtetra
.4054 .42469 .40788 .42725 .41205 .42587 .40958 .4233 Mtetra
.40958 .4233 .41205 .42587 .41623 .42448 .41376 .4219 Mtetra
.41376 .4219 .41623 .42448 .42042 .42308 .41795 .42051 Mtetra
.41795 .42051 .42042 .42308 .42461 .42169 .42215 .41911 Mtetra
.42215 .41911 .42461 .42169 .42881 .42029 .42635 .41771 Mtetra
.42635 .41771 .42881 .42029 .43302 .41889 .43056 .4163 Mtetra
.43056 .4163 .43302 .41889 .43723 .41749 .43478 .4149 Mtetra
.43478 .4149 .43723 .41749 .44145 .41609 .439 .41349 Mtetra
.439 .41349 .44145 .41609 .44568 .41468 .44323 .41208 Mtetra
.44323 .41208 .44568 .41468 .44991 .41327 .44747 .41067 Mtetra
.965 .669 .419 r
.44747 .41067 .44991 .41327 .45666 .29722 .44979 .49416 Mtetra
.527 .297 .509 r
.44979 .49416 .45666 .29722 .45665 .49533 .45415 .49278 Mtetra
.648 .76 .931 r
.45415 .49278 .45665 .49533 .46101 .49395 .45852 .49139 Mtetra
.45852 .49139 .46101 .49395 .46538 .49256 .4629 .49 Mtetra
.4629 .49 .46538 .49256 .46976 .49118 .46728 .48861 Mtetra
.46728 .48861 .46976 .49118 .47414 .48979 .47167 .48721 Mtetra
.47167 .48721 .47414 .48979 .47853 .48839 .47606 .48582 Mtetra
.47606 .48582 .47853 .48839 .48293 .487 .48046 .48442 Mtetra
.48046 .48442 .48293 .487 .48734 .4856 .48487 .48302 Mtetra
.48487 .48302 .48734 .4856 .49175 .4842 .48929 .48161 Mtetra
.48929 .48161 .49175 .4842 .49617 .4828 .49372 .48021 Mtetra
.49372 .48021 .49617 .4828 .5006 .4814 .49815 .4788 Mtetra
.49815 .4788 .5006 .4814 .50503 .47999 .50259 .47739 Mtetra
.50259 .47739 .50503 .47999 .50947 .47858 .50703 .47598 Mtetra
.50703 .47598 .50947 .47858 .51392 .47717 .51148 .47456 Mtetra
.51148 .47456 .51392 .47717 .51838 .47576 .51594 .47315 Mtetra
.51594 .47315 .51838 .47576 .52284 .47434 .52041 .47173 Mtetra
.52041 .47173 .52284 .47434 .52731 .47293 .52489 .4703 Mtetra
.52489 .4703 .52731 .47293 .53179 .47151 .52937 .46888 Mtetra
.939 .772 .649 r
.52937 .46888 .53179 .47151 .53623 .45916 .53383 .45652 Mtetra
.649 .759 .93 r
.53383 .45652 .53623 .45916 .54071 .45773 .53831 .45509 Mtetra
.53831 .45509 .54071 .45773 .54519 .4563 .5428 .45365 Mtetra
.5428 .45365 .54519 .4563 .54969 .45486 .5473 .45221 Mtetra
.5473 .45221 .54969 .45486 .55419 .45343 .5518 .45077 Mtetra
.5518 .45077 .55419 .45343 .55869 .45199 .55631 .44933 Mtetra
.55631 .44933 .55869 .45199 .5632 .45055 .56083 .44789 Mtetra
.56083 .44789 .5632 .45055 .56773 .44911 .56535 .44644 Mtetra
.56535 .44644 .56773 .44911 .57225 .44766 .56989 .44499 Mtetra
.56989 .44499 .57225 .44766 .57679 .44622 .57443 .44354 Mtetra
.57443 .44354 .57679 .44622 .58133 .44477 .57898 .44208 Mtetra
.57898 .44208 .58133 .44477 .58588 .44331 .58353 .44063 Mtetra
.58353 .44063 .58588 .44331 .59044 .44186 .5881 .43917 Mtetra
.5881 .43917 .59044 .44186 .59501 .4404 .59267 .43771 Mtetra
.974 .72 .487 r
.59267 .43771 .59501 .4404 .59859 .39573 .59628 .393 Mtetra
.653 .755 .925 r
.59628 .393 .59859 .39573 .60311 .39425 .60081 .39152 Mtetra
.60081 .39152 .60311 .39425 .60764 .39277 .60534 .39003 Mtetra
.60534 .39003 .60764 .39277 .61217 .39129 .60988 .38855 Mtetra
.60988 .38855 .61217 .39129 .61671 .3898 .61442 .38706 Mtetra
.61442 .38706 .61671 .3898 .62126 .38832 .61898 .38557 Mtetra
.61898 .38557 .62126 .38832 .62581 .38683 .62354 .38407 Mtetra
.62354 .38407 .62581 .38683 .63038 .38534 .62811 .38258 Mtetra
.62811 .38258 .63038 .38534 .63495 .38384 .63268 .38108 Mtetra
.63268 .38108 .63495 .38384 .63953 .38235 .63727 .37958 Mtetra
.63727 .37958 .63953 .38235 .64411 .38085 .64186 .37807 Mtetra
.64186 .37807 .64411 .38085 .64871 .37934 .64645 .37657 Mtetra
.64645 .37657 .64871 .37934 .65331 .37784 .65106 .37506 Mtetra
.65106 .37506 .65331 .37784 .65791 .37633 .65567 .37355 Mtetra
.65567 .37355 .65791 .37633 .66253 .37483 .66029 .37203 Mtetra
.66029 .37203 .66253 .37483 .66715 .37331 .66492 .37052 Mtetra
.66492 .37052 .66715 .37331 .67178 .3718 .66956 .369 Mtetra
.66956 .369 .67178 .3718 .67642 .37028 .6742 .36748 Mtetra
.6742 .36748 .67642 .37028 .68055 .35807 .67885 .36595 Mtetra
0 0 0 r
.67885 .36595 .68055 .35807 .68518 .35655 .68298 .35373 Mtetra
.979 .691 .397 r
.68298 .35373 .68518 .35655 .68983 .35502 .68057 .2144 Mtetra
.537 .319 .531 r
.68057 .2144 .68983 .35502 .68713 .21573 .68502 .21282 Mtetra
.664 .741 .908 r
.68502 .21282 .68713 .21573 .69158 .21416 .68948 .21124 Mtetra
.68948 .21124 .69158 .21416 .69604 .21258 .69394 .20966 Mtetra
.69394 .20966 .69604 .21258 .7005 .211 .69841 .20808 Mtetra
.69841 .20808 .7005 .211 .70498 .20942 .70289 .20649 Mtetra
.70289 .20649 .70498 .20942 .70946 .20783 .70738 .2049 Mtetra
.70738 .2049 .70946 .20783 .71395 .20625 .71187 .20331 Mtetra
.71187 .20331 .71395 .20625 .71844 .20466 .71637 .20172 Mtetra
.71637 .20172 .71844 .20466 .72294 .20307 .72087 .20012 Mtetra
.72087 .20012 .72294 .20307 .72745 .20147 .72539 .19852 Mtetra
.72539 .19852 .72745 .20147 .73197 .19987 .72991 .19692 Mtetra
.72991 .19692 .73197 .19987 .73649 .19828 .73444 .19532 Mtetra
.73444 .19532 .73649 .19828 .74102 .19667 .73897 .19371 Mtetra
.73897 .19371 .74102 .19667 .74556 .19507 .74352 .1921 Mtetra
.74352 .1921 .74556 .19507 .75011 .19346 .74807 .19049 Mtetra
.74807 .19049 .75011 .19346 .75466 .19185 .75262 .18887 Mtetra
.75262 .18887 .75466 .19185 .75922 .19024 .75719 .18726 Mtetra
.75719 .18726 .75922 .19024 .76378 .18863 .76176 .18564 Mtetra
.76176 .18564 .76378 .18863 .76836 .18701 .76634 .18402 Mtetra
.76634 .18402 .76836 .18701 .77294 .18539 .77093 .18239 Mtetra
.77093 .18239 .77294 .18539 .77753 .18377 .77552 .18076 Mtetra
.77552 .18076 .77753 .18377 .78212 .18214 .78012 .17913 Mtetra
.78012 .17913 .78212 .18214 .78673 .18051 .78473 .1775 Mtetra
.78473 .1775 .78673 .18051 .79134 .17888 .78934 .17587 Mtetra
.78934 .17587 .79134 .17888 .79596 .17725 .79397 .17423 Mtetra
.79397 .17423 .79596 .17725 .80058 .17561 .7986 .17259 Mtetra
.17555 .38995 .17814 .39237 .18184 .39106 .17924 .38864 Mtetra
.17924 .38864 .18184 .39106 .18554 .38975 .18295 .38733 Mtetra
.18295 .38733 .18554 .38975 .18924 .38844 .18665 .38601 Mtetra
.18665 .38601 .18924 .38844 .19295 .38712 .19037 .38469 Mtetra
.19037 .38469 .19295 .38712 .19667 .38581 .19409 .38337 Mtetra
.19409 .38337 .19667 .38581 .20039 .38449 .19781 .38205 Mtetra
.19781 .38205 .20039 .38449 .20412 .38317 .20154 .38073 Mtetra
.20154 .38073 .20412 .38317 .20785 .38185 .20528 .3794 Mtetra
.20528 .3794 .20785 .38185 .21158 .38052 .20902 .37807 Mtetra
.20902 .37807 .21158 .38052 .21533 .3792 .21276 .37675 Mtetra
.21276 .37675 .21533 .3792 .21908 .37787 .21651 .37541 Mtetra
.21651 .37541 .21908 .37787 .22283 .37654 .22027 .37408 Mtetra
.22027 .37408 .22283 .37654 .22659 .37521 .22403 .37275 Mtetra
.533 .026 0 r
.22403 .37275 .22659 .37521 .22992 .37861 .22736 .37615 Mtetra
.663 .742 .908 r
.22736 .37615 .22992 .37861 .23369 .37728 .23114 .37481 Mtetra
.23114 .37481 .23369 .37728 .23747 .37594 .23492 .37347 Mtetra
.23492 .37347 .23747 .37594 .24126 .3746 .23871 .37213 Mtetra
.23871 .37213 .24126 .3746 .24505 .37327 .2425 .37079 Mtetra
.2425 .37079 .24505 .37327 .24885 .37192 .2463 .36944 Mtetra
.2463 .36944 .24885 .37192 .25265 .37058 .25011 .36809 Mtetra
.25011 .36809 .25265 .37058 .25646 .36923 .25392 .36674 Mtetra
.25392 .36674 .25646 .36923 .26027 .36789 .25774 .36539 Mtetra
.25774 .36539 .26027 .36789 .26409 .36654 .26156 .36404 Mtetra
.26156 .36404 .26409 .36654 .26791 .36519 .26539 .36269 Mtetra
.26539 .36269 .26791 .36519 .27174 .36383 .26922 .36133 Mtetra
.26922 .36133 .27174 .36383 .27558 .36248 .27306 .35997 Mtetra
.27306 .35997 .27558 .36248 .27942 .36112 .27691 .35861 Mtetra
.27691 .35861 .27942 .36112 .28327 .35976 .28076 .35725 Mtetra
.28076 .35725 .28327 .35976 .28712 .3584 .28461 .35588 Mtetra
.28461 .35588 .28712 .3584 .28375 .45532 .28848 .35451 Mtetra
0 0 .232 r
.28848 .35451 .28375 .45532 .28773 .45398 .28514 .45152 Mtetra
.952 .667 .461 r
.28514 .45152 .28773 .45398 .2873 .51463 .28466 .5122 Mtetra
.651 .757 .927 r
.28466 .5122 .2873 .51463 .29136 .51332 .28873 .51088 Mtetra
.28873 .51088 .29136 .51332 .29543 .512 .2928 .50956 Mtetra
.2928 .50956 .29543 .512 .29951 .51068 .29688 .50824 Mtetra
.29688 .50824 .29951 .51068 .30359 .50936 .30096 .50692 Mtetra
.30096 .50692 .30359 .50936 .30768 .50804 .30505 .50559 Mtetra
.30505 .50559 .30768 .50804 .31177 .50671 .30915 .50426 Mtetra
.30915 .50426 .31177 .50671 .31587 .50539 .31326 .50293 Mtetra
.31326 .50293 .31587 .50539 .31998 .50406 .31737 .5016 Mtetra
.31737 .5016 .31998 .50406 .32409 .50272 .32148 .50026 Mtetra
.32148 .50026 .32409 .50272 .32821 .50139 .32561 .49892 Mtetra
.32561 .49892 .32821 .50139 .33234 .50006 .32974 .49759 Mtetra
.32974 .49759 .33234 .50006 .33647 .49872 .33387 .49624 Mtetra
.33387 .49624 .33647 .49872 .34061 .49738 .33802 .4949 Mtetra
.33802 .4949 .34061 .49738 .34475 .49604 .34217 .49356 Mtetra
.34217 .49356 .34475 .49604 .3489 .49469 .34632 .49221 Mtetra
.34632 .49221 .3489 .49469 .35306 .49335 .35048 .49086 Mtetra
.35048 .49086 .35306 .49335 .35723 .492 .35465 .48951 Mtetra
.35465 .48951 .35723 .492 .3614 .49065 .35883 .48815 Mtetra
.35883 .48815 .3614 .49065 .36557 .4893 .36301 .4868 Mtetra
.36301 .4868 .36557 .4893 .36976 .48794 .3672 .48544 Mtetra
.921 .757 .662 r
.3672 .48544 .36976 .48794 .37633 .43438 .37188 .4735 Mtetra
.509 .259 .471 r
.37188 .4735 .37633 .43438 .38046 .433 .37607 .47213 Mtetra
.37607 .47213 .38046 .433 .3846 .43162 .38027 .47076 Mtetra
.38027 .47076 .3846 .43162 .38875 .43024 .38447 .46939 Mtetra
.38447 .46939 .38875 .43024 .3929 .42885 .38868 .46802 Mtetra
.38868 .46802 .3929 .42885 .39706 .42747 .39289 .46664 Mtetra
.39289 .46664 .39706 .42747 .40123 .42608 .39711 .46526 Mtetra
.39711 .46526 .40123 .42608 .4054 .42469 .40134 .46389 Mtetra
.40134 .46389 .4054 .42469 .40958 .4233 .40558 .4625 Mtetra
.40558 .4625 .40958 .4233 .41376 .4219 .40982 .46112 Mtetra
.40982 .46112 .41376 .4219 .41795 .42051 .41406 .45973 Mtetra
.41406 .45973 .41795 .42051 .42215 .41911 .41832 .45835 Mtetra
.41832 .45835 .42215 .41911 .42635 .41771 .42258 .45696 Mtetra
.42258 .45696 .42635 .41771 .43056 .4163 .42685 .45556 Mtetra
.42685 .45556 .43056 .4163 .43478 .4149 .43112 .45417 Mtetra
.43112 .45417 .43478 .4149 .439 .41349 .43541 .45277 Mtetra
.43541 .45277 .439 .41349 .44323 .41208 .43969 .45137 Mtetra
.43969 .45137 .44323 .41208 .44747 .41067 .44399 .44997 Mtetra
.761 .478 .504 r
.44399 .44997 .44747 .41067 .44979 .49416 .44728 .4916 Mtetra
.648 .76 .931 r
.44728 .4916 .44979 .49416 .45415 .49278 .45165 .49021 Mtetra
.45165 .49021 .45415 .49278 .45852 .49139 .45602 .48882 Mtetra
.45602 .48882 .45852 .49139 .4629 .49 .4604 .48743 Mtetra
.4604 .48743 .4629 .49 .46728 .48861 .46479 .48603 Mtetra
.46479 .48603 .46728 .48861 .47167 .48721 .46918 .48463 Mtetra
.46918 .48463 .47167 .48721 .47606 .48582 .47358 .48323 Mtetra
.47358 .48323 .47606 .48582 .48046 .48442 .47799 .48183 Mtetra
.47799 .48183 .48046 .48442 .48487 .48302 .4824 .48042 Mtetra
.4824 .48042 .48487 .48302 .48929 .48161 .48682 .47902 Mtetra
.48682 .47902 .48929 .48161 .49372 .48021 .49125 .47761 Mtetra
.49125 .47761 .49372 .48021 .49815 .4788 .49569 .47619 Mtetra
.49569 .47619 .49815 .4788 .50259 .47739 .50013 .47478 Mtetra
.50013 .47478 .50259 .47739 .50703 .47598 .50458 .47336 Mtetra
.50458 .47336 .50703 .47598 .51148 .47456 .50904 .47194 Mtetra
.50904 .47194 .51148 .47456 .51594 .47315 .51351 .47052 Mtetra
.51351 .47052 .51594 .47315 .52041 .47173 .51798 .4691 Mtetra
.51798 .4691 .52041 .47173 .52489 .4703 .52246 .46767 Mtetra
.52246 .46767 .52489 .4703 .52937 .46888 .52694 .46625 Mtetra
.939 .772 .649 r
.52694 .46625 .52937 .46888 .53383 .45652 .53142 .45387 Mtetra
.649 .759 .93 r
.53142 .45387 .53383 .45652 .53831 .45509 .5359 .45243 Mtetra
.5359 .45243 .53831 .45509 .5428 .45365 .5404 .45099 Mtetra
.5404 .45099 .5428 .45365 .5473 .45221 .5449 .44955 Mtetra
.5449 .44955 .5473 .45221 .5518 .45077 .54941 .44811 Mtetra
.54941 .44811 .5518 .45077 .55631 .44933 .55392 .44666 Mtetra
.55392 .44666 .55631 .44933 .56083 .44789 .55845 .44521 Mtetra
.55845 .44521 .56083 .44789 .56535 .44644 .56298 .44376 Mtetra
.56298 .44376 .56535 .44644 .56989 .44499 .56751 .44231 Mtetra
.56751 .44231 .56989 .44499 .57443 .44354 .57206 .44085 Mtetra
.57206 .44085 .57443 .44354 .57898 .44208 .57661 .43939 Mtetra
.57661 .43939 .57898 .44208 .58353 .44063 .58117 .43793 Mtetra
.58117 .43793 .58353 .44063 .5881 .43917 .58574 .43647 Mtetra
.58574 .43647 .5881 .43917 .59267 .43771 .59032 .435 Mtetra
.974 .72 .487 r
.59032 .435 .59267 .43771 .59628 .393 .59397 .39026 Mtetra
.653 .755 .925 r
.59397 .39026 .59628 .393 .60081 .39152 .5985 .38877 Mtetra
.5985 .38877 .60081 .39152 .60534 .39003 .60304 .38729 Mtetra
.60304 .38729 .60534 .39003 .60988 .38855 .60758 .3858 Mtetra
.60758 .3858 .60988 .38855 .61442 .38706 .61213 .3843 Mtetra
.61213 .3843 .61442 .38706 .61898 .38557 .61669 .38281 Mtetra
.61669 .38281 .61898 .38557 .62354 .38407 .62125 .38131 Mtetra
.62125 .38131 .62354 .38407 .62811 .38258 .62583 .37981 Mtetra
.62583 .37981 .62811 .38258 .63268 .38108 .63041 .3783 Mtetra
.63041 .3783 .63268 .38108 .63727 .37958 .635 .3768 Mtetra
.635 .3768 .63727 .37958 .64186 .37807 .63959 .37529 Mtetra
.63959 .37529 .64186 .37807 .64645 .37657 .6442 .37378 Mtetra
.6442 .37378 .64645 .37657 .65106 .37506 .64881 .37227 Mtetra
.64881 .37227 .65106 .37506 .65567 .37355 .65343 .37075 Mtetra
.65343 .37075 .65567 .37355 .66029 .37203 .65805 .36923 Mtetra
.65805 .36923 .66029 .37203 .66492 .37052 .66268 .36771 Mtetra
.66268 .36771 .66492 .37052 .66956 .369 .66733 .36619 Mtetra
.66733 .36619 .66956 .369 .6742 .36748 .67198 .36466 Mtetra
.67198 .36466 .6742 .36748 .67885 .36595 .67663 .36314 Mtetra
.67663 .36314 .67885 .36595 .68298 .35373 .6813 .3616 Mtetra
.984 .703 .359 r
.6813 .3616 .68298 .35373 .68057 .2144 .67845 .21149 Mtetra
.664 .741 .908 r
.67845 .21149 .68057 .2144 .68502 .21282 .6829 .20991 Mtetra
.6829 .20991 .68502 .21282 .68948 .21124 .68737 .20832 Mtetra
.68737 .20832 .68948 .21124 .69394 .20966 .69183 .20674 Mtetra
.69183 .20674 .69394 .20966 .69841 .20808 .69631 .20515 Mtetra
.69631 .20515 .69841 .20808 .70289 .20649 .70079 .20356 Mtetra
.70079 .20356 .70289 .20649 .70738 .2049 .70528 .20196 Mtetra
.70528 .20196 .70738 .2049 .71187 .20331 .70978 .20037 Mtetra
.70978 .20037 .71187 .20331 .71637 .20172 .71429 .19877 Mtetra
.71429 .19877 .71637 .20172 .72087 .20012 .7188 .19717 Mtetra
.7188 .19717 .72087 .20012 .72539 .19852 .72332 .19556 Mtetra
.72332 .19556 .72539 .19852 .72991 .19692 .72784 .19396 Mtetra
.72784 .19396 .72991 .19692 .73444 .19532 .73238 .19235 Mtetra
.73238 .19235 .73444 .19532 .73897 .19371 .73692 .19074 Mtetra
.73692 .19074 .73897 .19371 .74352 .1921 .74147 .18912 Mtetra
.74147 .18912 .74352 .1921 .74807 .19049 .74602 .18751 Mtetra
.74602 .18751 .74807 .19049 .75262 .18887 .75058 .18589 Mtetra
.75058 .18589 .75262 .18887 .75719 .18726 .75515 .18427 Mtetra
.75515 .18427 .75719 .18726 .76176 .18564 .75973 .18264 Mtetra
.75973 .18264 .76176 .18564 .76634 .18402 .76431 .18101 Mtetra
.76431 .18101 .76634 .18402 .77093 .18239 .76891 .17939 Mtetra
.76891 .17939 .77093 .18239 .77552 .18076 .7735 .17775 Mtetra
.7735 .17775 .77552 .18076 .78012 .17913 .77811 .17612 Mtetra
.77811 .17612 .78012 .17913 .78473 .1775 .78272 .17448 Mtetra
.78272 .17448 .78473 .1775 .78934 .17587 .78735 .17284 Mtetra
.78735 .17284 .78934 .17587 .79397 .17423 .79197 .1712 Mtetra
.79197 .1712 .79397 .17423 .7986 .17259 .79661 .16955 Mtetra
.17294 .38753 .17555 .38995 .17924 .38864 .17664 .38621 Mtetra
.17664 .38621 .17924 .38864 .18295 .38733 .18035 .3849 Mtetra
.18035 .3849 .18295 .38733 .18665 .38601 .18406 .38358 Mtetra
.18406 .38358 .18665 .38601 .19037 .38469 .18778 .38225 Mtetra
.18778 .38225 .19037 .38469 .19409 .38337 .1915 .38093 Mtetra
.1915 .38093 .19409 .38337 .19781 .38205 .19523 .37961 Mtetra
.19523 .37961 .19781 .38205 .20154 .38073 .19896 .37828 Mtetra
.19896 .37828 .20154 .38073 .20528 .3794 .2027 .37695 Mtetra
.2027 .37695 .20528 .3794 .20902 .37807 .20644 .37562 Mtetra
.20644 .37562 .20902 .37807 .21276 .37675 .21019 .37429 Mtetra
.21019 .37429 .21276 .37675 .21651 .37541 .21394 .37295 Mtetra
.21394 .37295 .21651 .37541 .22027 .37408 .2177 .37161 Mtetra
.2177 .37161 .22027 .37408 .22403 .37275 .22147 .37028 Mtetra
.22147 .37028 .22403 .37275 .22736 .37615 .22524 .36894 Mtetra
.222 .264 .694 r
.22524 .36894 .22736 .37615 .23114 .37481 .22858 .37234 Mtetra
.663 .742 .908 r
.22858 .37234 .23114 .37481 .23492 .37347 .23236 .37099 Mtetra
.23236 .37099 .23492 .37347 .23871 .37213 .23615 .36965 Mtetra
.23615 .36965 .23871 .37213 .2425 .37079 .23995 .3683 Mtetra
.23995 .3683 .2425 .37079 .2463 .36944 .24376 .36695 Mtetra
.24376 .36695 .2463 .36944 .25011 .36809 .24757 .3656 Mtetra
.24757 .3656 .25011 .36809 .25392 .36674 .25138 .36425 Mtetra
.25138 .36425 .25392 .36674 .25774 .36539 .2552 .36289 Mtetra
.2552 .36289 .25774 .36539 .26156 .36404 .25903 .36154 Mtetra
.25903 .36154 .26156 .36404 .26539 .36269 .26286 .36018 Mtetra
.26286 .36018 .26539 .36269 .26922 .36133 .26669 .35882 Mtetra
.26669 .35882 .26922 .36133 .27306 .35997 .27054 .35745 Mtetra
.27054 .35745 .27306 .35997 .27691 .35861 .27439 .35609 Mtetra
.27439 .35609 .27691 .35861 .28076 .35725 .27824 .35472 Mtetra
.27824 .35472 .28076 .35725 .28461 .35588 .2821 .35335 Mtetra
.2821 .35335 .28461 .35588 .28848 .35451 .28596 .35198 Mtetra
.951 .68 .489 r
.28596 .35198 .28848 .35451 .28514 .45152 .27795 .51109 Mtetra
.516 .274 .486 r
.27795 .51109 .28514 .45152 .28466 .5122 .28201 .50977 Mtetra
.651 .757 .927 r
.28201 .50977 .28466 .5122 .28873 .51088 .28608 .50844 Mtetra
.28608 .50844 .28873 .51088 .2928 .50956 .29016 .50712 Mtetra
.29016 .50712 .2928 .50956 .29688 .50824 .29424 .50579 Mtetra
.29424 .50579 .29688 .50824 .30096 .50692 .29833 .50447 Mtetra
.29833 .50447 .30096 .50692 .30505 .50559 .30243 .50313 Mtetra
.30243 .50313 .30505 .50559 .30915 .50426 .30653 .5018 Mtetra
.30653 .5018 .30915 .50426 .31326 .50293 .31064 .50047 Mtetra
.31064 .50047 .31326 .50293 .31737 .5016 .31475 .49913 Mtetra
.31475 .49913 .31737 .5016 .32148 .50026 .31887 .49779 Mtetra
.31887 .49779 .32148 .50026 .32561 .49892 .323 .49645 Mtetra
.323 .49645 .32561 .49892 .32974 .49759 .32713 .49511 Mtetra
.32713 .49511 .32974 .49759 .33387 .49624 .33127 .49376 Mtetra
.33127 .49376 .33387 .49624 .33802 .4949 .33542 .49242 Mtetra
.33542 .49242 .33802 .4949 .34217 .49356 .33957 .49107 Mtetra
.33957 .49107 .34217 .49356 .34632 .49221 .34373 .48971 Mtetra
.34373 .48971 .34632 .49221 .35048 .49086 .3479 .48836 Mtetra
.3479 .48836 .35048 .49086 .35465 .48951 .35207 .48701 Mtetra
.35207 .48701 .35465 .48951 .35883 .48815 .35625 .48565 Mtetra
.35625 .48565 .35883 .48815 .36301 .4868 .36044 .48429 Mtetra
.36044 .48429 .36301 .4868 .3672 .48544 .36463 .48293 Mtetra
.921 .757 .662 r
.36463 .48293 .3672 .48544 .37188 .4735 .36933 .47097 Mtetra
.652 .756 .926 r
.36933 .47097 .37188 .4735 .37607 .47213 .37352 .4696 Mtetra
.37352 .4696 .37607 .47213 .38027 .47076 .37772 .46823 Mtetra
.37772 .46823 .38027 .47076 .38447 .46939 .38192 .46685 Mtetra
.38192 .46685 .38447 .46939 .38868 .46802 .38614 .46548 Mtetra
.38614 .46548 .38868 .46802 .39289 .46664 .39036 .4641 Mtetra
.39036 .4641 .39289 .46664 .39711 .46526 .39458 .46272 Mtetra
.39458 .46272 .39711 .46526 .40134 .46389 .39881 .46133 Mtetra
.39881 .46133 .40134 .46389 .40558 .4625 .40305 .45995 Mtetra
.40305 .45995 .40558 .4625 .40982 .46112 .4073 .45856 Mtetra
.4073 .45856 .40982 .46112 .41406 .45973 .41155 .45717 Mtetra
.41155 .45717 .41406 .45973 .41832 .45835 .41581 .45578 Mtetra
.41581 .45578 .41832 .45835 .42258 .45696 .42007 .45438 Mtetra
.42007 .45438 .42258 .45696 .42685 .45556 .42435 .45299 Mtetra
.42435 .45299 .42685 .45556 .43112 .45417 .42863 .45159 Mtetra
.42863 .45159 .43112 .45417 .43541 .45277 .43291 .45019 Mtetra
.43291 .45019 .43541 .45277 .43969 .45137 .43721 .44879 Mtetra
.43721 .44879 .43969 .45137 .44399 .44997 .4415 .44738 Mtetra
.4415 .44738 .44399 .44997 .44728 .4916 .44581 .44597 Mtetra
0 0 .373 r
.44581 .44597 .44728 .4916 .45165 .49021 .44914 .48764 Mtetra
.648 .76 .931 r
.44914 .48764 .45165 .49021 .45602 .48882 .45352 .48625 Mtetra
.45352 .48625 .45602 .48882 .4604 .48743 .4579 .48485 Mtetra
.4579 .48485 .4604 .48743 .46479 .48603 .46229 .48345 Mtetra
.46229 .48345 .46479 .48603 .46918 .48463 .46669 .48205 Mtetra
.46669 .48205 .46918 .48463 .47358 .48323 .47109 .48064 Mtetra
.47109 .48064 .47358 .48323 .47799 .48183 .4755 .47923 Mtetra
.4755 .47923 .47799 .48183 .4824 .48042 .47992 .47782 Mtetra
.47992 .47782 .4824 .48042 .48682 .47902 .48435 .47641 Mtetra
.48435 .47641 .48682 .47902 .49125 .47761 .48878 .475 Mtetra
.48878 .475 .49125 .47761 .49569 .47619 .49322 .47358 Mtetra
.49322 .47358 .49569 .47619 .50013 .47478 .49767 .47216 Mtetra
.49767 .47216 .50013 .47478 .50458 .47336 .50213 .47074 Mtetra
.50213 .47074 .50458 .47336 .50904 .47194 .50659 .46932 Mtetra
.50659 .46932 .50904 .47194 .51351 .47052 .51106 .46789 Mtetra
.51106 .46789 .51351 .47052 .51798 .4691 .51554 .46646 Mtetra
.51554 .46646 .51798 .4691 .52246 .46767 .52002 .46503 Mtetra
.52002 .46503 .52246 .46767 .52694 .46625 .52451 .4636 Mtetra
.939 .772 .649 r
.52451 .4636 .52694 .46625 .53142 .45387 .529 .45122 Mtetra
.649 .759 .93 r
.529 .45122 .53142 .45387 .5359 .45243 .53349 .44977 Mtetra
.53349 .44977 .5359 .45243 .5404 .45099 .53799 .44833 Mtetra
.53799 .44833 .5404 .45099 .5449 .44955 .54249 .44688 Mtetra
.54249 .44688 .5449 .44955 .54941 .44811 .54701 .44544 Mtetra
.54701 .44544 .54941 .44811 .55392 .44666 .55153 .44398 Mtetra
.55153 .44398 .55392 .44666 .55845 .44521 .55606 .44253 Mtetra
.55606 .44253 .55845 .44521 .56298 .44376 .56059 .44108 Mtetra
.56059 .44108 .56298 .44376 .56751 .44231 .56513 .43962 Mtetra
.56513 .43962 .56751 .44231 .57206 .44085 .56969 .43816 Mtetra
.56969 .43816 .57206 .44085 .57661 .43939 .57424 .43669 Mtetra
.57424 .43669 .57661 .43939 .58117 .43793 .57881 .43523 Mtetra
.57881 .43523 .58117 .43793 .58574 .43647 .58338 .43376 Mtetra
.58338 .43376 .58574 .43647 .59032 .435 .58796 .43229 Mtetra
.974 .72 .487 r
.58796 .43229 .59032 .435 .59397 .39026 .59165 .38752 Mtetra
.653 .755 .925 r
.59165 .38752 .59397 .39026 .5985 .38877 .59618 .38602 Mtetra
.59618 .38602 .5985 .38877 .60304 .38729 .60072 .38453 Mtetra
.60072 .38453 .60304 .38729 .60758 .3858 .60527 .38304 Mtetra
.60527 .38304 .60758 .3858 .61213 .3843 .60983 .38154 Mtetra
.60983 .38154 .61213 .3843 .61669 .38281 .61439 .38004 Mtetra
.61439 .38004 .61669 .38281 .62125 .38131 .61896 .37854 Mtetra
.61896 .37854 .62125 .38131 .62583 .37981 .62354 .37703 Mtetra
.62354 .37703 .62583 .37981 .63041 .3783 .62813 .37552 Mtetra
.62813 .37552 .63041 .3783 .635 .3768 .63272 .37401 Mtetra
.63272 .37401 .635 .3768 .63959 .37529 .63732 .3725 Mtetra
.63732 .3725 .63959 .37529 .6442 .37378 .64193 .37098 Mtetra
.64193 .37098 .6442 .37378 .64881 .37227 .64655 .36947 Mtetra
.64655 .36947 .64881 .37227 .65343 .37075 .65117 .36795 Mtetra
.65117 .36795 .65343 .37075 .65805 .36923 .6558 .36642 Mtetra
.6558 .36642 .65805 .36923 .66268 .36771 .66044 .3649 Mtetra
.66044 .3649 .66268 .36771 .66733 .36619 .66509 .36337 Mtetra
.66509 .36337 .66733 .36619 .67198 .36466 .66974 .36184 Mtetra
.66974 .36184 .67198 .36466 .67663 .36314 .6744 .36031 Mtetra
.979 .691 .397 r
.6744 .36031 .67663 .36314 .6813 .3616 .67187 .21015 Mtetra
.536 .317 .529 r
.67187 .21015 .6813 .3616 .67845 .21149 .67632 .20857 Mtetra
.664 .741 .908 r
.67632 .20857 .67845 .21149 .6829 .20991 .68078 .20698 Mtetra
.68078 .20698 .6829 .20991 .68737 .20832 .68525 .20539 Mtetra
.68525 .20539 .68737 .20832 .69183 .20674 .68972 .2038 Mtetra
.68972 .2038 .69183 .20674 .69631 .20515 .6942 .20221 Mtetra
.6942 .20221 .69631 .20515 .70079 .20356 .69869 .20061 Mtetra
.69869 .20061 .70079 .20356 .70528 .20196 .70319 .19901 Mtetra
.70319 .19901 .70528 .20196 .70978 .20037 .70769 .19741 Mtetra
.70769 .19741 .70978 .20037 .71429 .19877 .7122 .19581 Mtetra
.7122 .19581 .71429 .19877 .7188 .19717 .71672 .1942 Mtetra
.71672 .1942 .7188 .19717 .72332 .19556 .72124 .1926 Mtetra
.72124 .1926 .72332 .19556 .72784 .19396 .72577 .19098 Mtetra
.72577 .19098 .72784 .19396 .73238 .19235 .73031 .18937 Mtetra
.73031 .18937 .73238 .19235 .73692 .19074 .73486 .18776 Mtetra
.73486 .18776 .73692 .19074 .74147 .18912 .73941 .18614 Mtetra
.73941 .18614 .74147 .18912 .74602 .18751 .74397 .18452 Mtetra
.74397 .18452 .74602 .18751 .75058 .18589 .74854 .18289 Mtetra
.74854 .18289 .75058 .18589 .75515 .18427 .75311 .18126 Mtetra
.75311 .18126 .75515 .18427 .75973 .18264 .75769 .17964 Mtetra
.75769 .17964 .75973 .18264 .76431 .18101 .76228 .178 Mtetra
.76228 .178 .76431 .18101 .76891 .17939 .76688 .17637 Mtetra
.76688 .17637 .76891 .17939 .7735 .17775 .77148 .17473 Mtetra
.77148 .17473 .7735 .17775 .77811 .17612 .7761 .17309 Mtetra
.7761 .17309 .77811 .17612 .78272 .17448 .78071 .17145 Mtetra
.78071 .17145 .78272 .17448 .78735 .17284 .78534 .16981 Mtetra
.78534 .16981 .78735 .17284 .79197 .1712 .78997 .16816 Mtetra
.78997 .16816 .79197 .1712 .79661 .16955 .79462 .16651 Mtetra
.17033 .3851 .17294 .38753 .17664 .38621 .17404 .38378 Mtetra
.17404 .38378 .17664 .38621 .18035 .3849 .17774 .38246 Mtetra
.17774 .38246 .18035 .3849 .18406 .38358 .18146 .38114 Mtetra
.18146 .38114 .18406 .38358 .18778 .38225 .18518 .37981 Mtetra
.18518 .37981 .18778 .38225 .1915 .38093 .1889 .37848 Mtetra
.1889 .37848 .1915 .38093 .19523 .37961 .19263 .37715 Mtetra
.19263 .37715 .19523 .37961 .19896 .37828 .19637 .37582 Mtetra
.19637 .37582 .19896 .37828 .2027 .37695 .20011 .37449 Mtetra
.20011 .37449 .2027 .37695 .20644 .37562 .20386 .37316 Mtetra
.20386 .37316 .20644 .37562 .21019 .37429 .20761 .37182 Mtetra
.20761 .37182 .21019 .37429 .21394 .37295 .21137 .37048 Mtetra
.21137 .37048 .21394 .37295 .2177 .37161 .21513 .36914 Mtetra
.21513 .36914 .2177 .37161 .22147 .37028 .2189 .3678 Mtetra
.2189 .3678 .22147 .37028 .22524 .36894 .22267 .36646 Mtetra
.53 .023 0 r
.22267 .36646 .22524 .36894 .22858 .37234 .22601 .36986 Mtetra
.663 .742 .908 r
.22601 .36986 .22858 .37234 .23236 .37099 .2298 .36851 Mtetra
.2298 .36851 .23236 .37099 .23615 .36965 .23359 .36716 Mtetra
.23359 .36716 .23615 .36965 .23995 .3683 .23739 .36581 Mtetra
.23739 .36581 .23995 .3683 .24376 .36695 .2412 .36446 Mtetra
.2412 .36446 .24376 .36695 .24757 .3656 .24501 .3631 Mtetra
.24501 .3631 .24757 .3656 .25138 .36425 .24883 .36175 Mtetra
.24883 .36175 .25138 .36425 .2552 .36289 .25266 .36039 Mtetra
.25266 .36039 .2552 .36289 .25903 .36154 .25648 .35903 Mtetra
.25648 .35903 .25903 .36154 .26286 .36018 .26032 .35766 Mtetra
.26032 .35766 .26286 .36018 .26669 .35882 .26416 .3563 Mtetra
.26416 .3563 .26669 .35882 .27054 .35745 .26801 .35493 Mtetra
.26801 .35493 .27054 .35745 .27439 .35609 .27186 .35357 Mtetra
.27186 .35357 .27439 .35609 .27824 .35472 .27571 .35219 Mtetra
.27571 .35219 .27824 .35472 .2821 .35335 .27958 .35082 Mtetra
.27958 .35082 .2821 .35335 .28596 .35198 .28345 .34945 Mtetra
.951 .68 .488 r
.28345 .34945 .28596 .35198 .27795 .51109 .27568 .50338 Mtetra
.2 .249 .689 r
.27568 .50338 .27795 .51109 .28201 .50977 .27936 .50732 Mtetra
.651 .757 .927 r
.27936 .50732 .28201 .50977 .28608 .50844 .28343 .506 Mtetra
.28343 .506 .28608 .50844 .29016 .50712 .28751 .50467 Mtetra
.28751 .50467 .29016 .50712 .29424 .50579 .2916 .50334 Mtetra
.2916 .50334 .29424 .50579 .29833 .50447 .29569 .50201 Mtetra
.29569 .50201 .29833 .50447 .30243 .50313 .29979 .50067 Mtetra
.29979 .50067 .30243 .50313 .30653 .5018 .30389 .49934 Mtetra
.30389 .49934 .30653 .5018 .31064 .50047 .30801 .498 Mtetra
.30801 .498 .31064 .50047 .31475 .49913 .31212 .49666 Mtetra
.31212 .49666 .31475 .49913 .31887 .49779 .31625 .49531 Mtetra
.31625 .49531 .31887 .49779 .323 .49645 .32038 .49397 Mtetra
.32038 .49397 .323 .49645 .32713 .49511 .32452 .49262 Mtetra
.32452 .49262 .32713 .49511 .33127 .49376 .32866 .49127 Mtetra
.32866 .49127 .33127 .49376 .33542 .49242 .33281 .48992 Mtetra
.33281 .48992 .33542 .49242 .33957 .49107 .33697 .48857 Mtetra
.33697 .48857 .33957 .49107 .34373 .48971 .34113 .48721 Mtetra
.34113 .48721 .34373 .48971 .3479 .48836 .3453 .48586 Mtetra
.3453 .48586 .3479 .48836 .35207 .48701 .34948 .4845 Mtetra
.34948 .4845 .35207 .48701 .35625 .48565 .35366 .48314 Mtetra
.35366 .48314 .35625 .48565 .36044 .48429 .35785 .48177 Mtetra
.921 .757 .662 r
.35785 .48177 .36044 .48429 .36463 .48293 .36257 .46981 Mtetra
.583 .435 .645 r
.36257 .46981 .36463 .48293 .36933 .47097 .36676 .46844 Mtetra
.652 .756 .926 r
.36676 .46844 .36933 .47097 .37352 .4696 .37096 .46707 Mtetra
.37096 .46707 .37352 .4696 .37772 .46823 .37516 .46569 Mtetra
.37516 .46569 .37772 .46823 .38192 .46685 .37937 .46431 Mtetra
.37937 .46431 .38192 .46685 .38614 .46548 .38359 .46293 Mtetra
.38359 .46293 .38614 .46548 .39036 .4641 .38781 .46155 Mtetra
.38781 .46155 .39036 .4641 .39458 .46272 .39204 .46016 Mtetra
.39204 .46016 .39458 .46272 .39881 .46133 .39628 .45877 Mtetra
.39628 .45877 .39881 .46133 .40305 .45995 .40052 .45738 Mtetra
.40052 .45738 .40305 .45995 .4073 .45856 .40477 .45599 Mtetra
.40477 .45599 .4073 .45856 .41155 .45717 .40903 .4546 Mtetra
.40903 .4546 .41155 .45717 .41581 .45578 .41329 .4532 Mtetra
.41329 .4532 .41581 .45578 .42007 .45438 .41756 .4518 Mtetra
.41756 .4518 .42007 .45438 .42435 .45299 .42184 .4504 Mtetra
.42184 .4504 .42435 .45299 .42863 .45159 .42612 .449 Mtetra
.42612 .449 .42863 .45159 .43291 .45019 .43041 .4476 Mtetra
.43041 .4476 .43291 .45019 .43721 .44879 .43471 .44619 Mtetra
.43471 .44619 .43721 .44879 .4415 .44738 .43901 .44478 Mtetra
.43901 .44478 .4415 .44738 .44581 .44597 .44332 .44337 Mtetra
.962 .647 .375 r
.44332 .44337 .44581 .44597 .44914 .48764 .44662 .48506 Mtetra
.648 .76 .931 r
.44662 .48506 .44914 .48764 .45352 .48625 .451 .48366 Mtetra
.451 .48366 .45352 .48625 .4579 .48485 .45539 .48226 Mtetra
.45539 .48226 .4579 .48485 .46229 .48345 .45978 .48086 Mtetra
.45978 .48086 .46229 .48345 .46669 .48205 .46419 .47945 Mtetra
.46419 .47945 .46669 .48205 .47109 .48064 .4686 .47804 Mtetra
.4686 .47804 .47109 .48064 .4755 .47923 .47301 .47663 Mtetra
.47301 .47663 .4755 .47923 .47992 .47782 .47744 .47522 Mtetra
.47744 .47522 .47992 .47782 .48435 .47641 .48187 .4738 Mtetra
.48187 .4738 .48435 .47641 .48878 .475 .48631 .47238 Mtetra
.48631 .47238 .48878 .475 .49322 .47358 .49075 .47096 Mtetra
.49075 .47096 .49322 .47358 .49767 .47216 .4952 .46954 Mtetra
.4952 .46954 .49767 .47216 .50213 .47074 .49966 .46811 Mtetra
.49966 .46811 .50213 .47074 .50659 .46932 .50413 .46668 Mtetra
.50413 .46668 .50659 .46932 .51106 .46789 .50861 .46525 Mtetra
.50861 .46525 .51106 .46789 .51554 .46646 .51309 .46382 Mtetra
.51309 .46382 .51554 .46646 .52002 .46503 .51758 .46239 Mtetra
.51758 .46239 .52002 .46503 .52451 .4636 .52207 .46095 Mtetra
.939 .772 .649 r
.52207 .46095 .52451 .4636 .529 .45122 .52657 .44855 Mtetra
.649 .759 .93 r
.52657 .44855 .529 .45122 .53349 .44977 .53107 .44711 Mtetra
.53107 .44711 .53349 .44977 .53799 .44833 .53557 .44566 Mtetra
.53557 .44566 .53799 .44833 .54249 .44688 .54008 .44421 Mtetra
.54008 .44421 .54249 .44688 .54701 .44544 .5446 .44276 Mtetra
.5446 .44276 .54701 .44544 .55153 .44398 .54913 .4413 Mtetra
.54913 .4413 .55153 .44398 .55606 .44253 .55366 .43984 Mtetra
.55366 .43984 .55606 .44253 .56059 .44108 .5582 .43838 Mtetra
.5582 .43838 .56059 .44108 .56513 .43962 .56275 .43692 Mtetra
.56275 .43692 .56513 .43962 .56969 .43816 .5673 .43545 Mtetra
.5673 .43545 .56969 .43816 .57424 .43669 .57187 .43399 Mtetra
.57187 .43399 .57424 .43669 .57881 .43523 .57644 .43252 Mtetra
.57644 .43252 .57881 .43523 .58338 .43376 .58101 .43105 Mtetra
.58101 .43105 .58338 .43376 .58796 .43229 .5856 .42957 Mtetra
.974 .72 .487 r
.5856 .42957 .58796 .43229 .59165 .38752 .58932 .38476 Mtetra
.653 .755 .925 r
.58932 .38476 .59165 .38752 .59618 .38602 .59386 .38327 Mtetra
.59386 .38327 .59618 .38602 .60072 .38453 .59841 .38177 Mtetra
.59841 .38177 .60072 .38453 .60527 .38304 .60296 .38027 Mtetra
.60296 .38027 .60527 .38304 .60983 .38154 .60752 .37877 Mtetra
.60752 .37877 .60983 .38154 .61439 .38004 .61209 .37726 Mtetra
.61209 .37726 .61439 .38004 .61896 .37854 .61667 .37575 Mtetra
.61667 .37575 .61896 .37854 .62354 .37703 .62125 .37424 Mtetra
.62125 .37424 .62354 .37703 .62813 .37552 .62584 .37273 Mtetra
.62584 .37273 .62813 .37552 .63272 .37401 .63044 .37122 Mtetra
.63044 .37122 .63272 .37401 .63732 .3725 .63504 .3697 Mtetra
.63504 .3697 .63732 .3725 .64193 .37098 .63966 .36818 Mtetra
.63966 .36818 .64193 .37098 .64655 .36947 .64428 .36666 Mtetra
.64428 .36666 .64655 .36947 .65117 .36795 .64891 .36513 Mtetra
.64891 .36513 .65117 .36795 .6558 .36642 .65354 .36361 Mtetra
.65354 .36361 .6558 .36642 .66044 .3649 .65819 .36208 Mtetra
.65819 .36208 .66044 .3649 .66509 .36337 .66284 .36054 Mtetra
.66284 .36054 .66509 .36337 .66974 .36184 .6675 .35901 Mtetra
.6675 .35901 .66974 .36184 .6744 .36031 .67217 .35747 Mtetra
.979 .691 .397 r
.67217 .35747 .6744 .36031 .67187 .21015 .66973 .20722 Mtetra
.664 .741 .908 r
.66973 .20722 .67187 .21015 .67632 .20857 .67419 .20564 Mtetra
.67419 .20564 .67632 .20857 .68078 .20698 .67866 .20405 Mtetra
.67866 .20405 .68078 .20698 .68525 .20539 .68313 .20245 Mtetra
.68313 .20245 .68525 .20539 .68972 .2038 .68761 .20086 Mtetra
.68761 .20086 .68972 .2038 .6942 .20221 .69209 .19926 Mtetra
.69209 .19926 .6942 .20221 .69869 .20061 .69659 .19766 Mtetra
.69659 .19766 .69869 .20061 .70319 .19901 .70109 .19606 Mtetra
.70109 .19606 .70319 .19901 .70769 .19741 .70559 .19445 Mtetra
.70559 .19445 .70769 .19741 .7122 .19581 .71011 .19284 Mtetra
.71011 .19284 .7122 .19581 .71672 .1942 .71463 .19123 Mtetra
.71463 .19123 .71672 .1942 .72124 .1926 .71916 .18962 Mtetra
.71916 .18962 .72124 .1926 .72577 .19098 .72369 .188 Mtetra
.72369 .188 .72577 .19098 .73031 .18937 .72824 .18639 Mtetra
.72824 .18639 .73031 .18937 .73486 .18776 .73279 .18476 Mtetra
.73279 .18476 .73486 .18776 .73941 .18614 .73735 .18314 Mtetra
.73735 .18314 .73941 .18614 .74397 .18452 .74191 .18152 Mtetra
.74191 .18152 .74397 .18452 .74854 .18289 .74648 .17989 Mtetra
.74648 .17989 .74854 .18289 .75311 .18126 .75106 .17826 Mtetra
.75106 .17826 .75311 .18126 .75769 .17964 .75565 .17662 Mtetra
.75565 .17662 .75769 .17964 .76228 .178 .76025 .17499 Mtetra
.76025 .17499 .76228 .178 .76688 .17637 .76485 .17335 Mtetra
.76485 .17335 .76688 .17637 .77148 .17473 .76946 .1717 Mtetra
.76946 .1717 .77148 .17473 .7761 .17309 .77407 .17006 Mtetra
.77407 .17006 .7761 .17309 .78071 .17145 .7787 .16841 Mtetra
.7787 .16841 .78071 .17145 .78534 .16981 .78333 .16676 Mtetra
.78333 .16676 .78534 .16981 .78997 .16816 .78797 .16511 Mtetra
.78797 .16511 .78997 .16816 .79462 .16651 .79262 .16346 Mtetra
.16772 .38266 .17033 .3851 .17404 .38378 .17142 .38134 Mtetra
.17142 .38134 .17404 .38378 .17774 .38246 .17513 .38001 Mtetra
.17513 .38001 .17774 .38246 .18146 .38114 .17885 .37869 Mtetra
.17885 .37869 .18146 .38114 .18518 .37981 .18257 .37736 Mtetra
.18257 .37736 .18518 .37981 .1889 .37848 .1863 .37603 Mtetra
.1863 .37603 .1889 .37848 .19263 .37715 .19004 .3747 Mtetra
.19004 .3747 .19263 .37715 .19637 .37582 .19377 .37336 Mtetra
.19377 .37336 .19637 .37582 .20011 .37449 .19752 .37203 Mtetra
.19752 .37203 .20011 .37449 .20386 .37316 .20127 .37069 Mtetra
.20127 .37069 .20386 .37316 .20761 .37182 .20502 .36935 Mtetra
.20502 .36935 .20761 .37182 .21137 .37048 .20878 .36801 Mtetra
.20878 .36801 .21137 .37048 .21513 .36914 .21255 .36666 Mtetra
.21255 .36666 .21513 .36914 .2189 .3678 .21632 .36532 Mtetra
.21632 .36532 .2189 .3678 .22267 .36646 .2201 .36397 Mtetra
.53 .023 0 r
.2201 .36397 .22267 .36646 .22601 .36986 .22343 .36737 Mtetra
.663 .742 .908 r
.22343 .36737 .22601 .36986 .2298 .36851 .22723 .36602 Mtetra
.22723 .36602 .2298 .36851 .23359 .36716 .23103 .36467 Mtetra
.23103 .36467 .23359 .36716 .23739 .36581 .23483 .36331 Mtetra
.23483 .36331 .23739 .36581 .2412 .36446 .23864 .36195 Mtetra
.23864 .36195 .2412 .36446 .24501 .3631 .24246 .3606 Mtetra
.24246 .3606 .24501 .3631 .24883 .36175 .24628 .35924 Mtetra
.24628 .35924 .24883 .36175 .25266 .36039 .2501 .35787 Mtetra
.2501 .35787 .25266 .36039 .25648 .35903 .25394 .35651 Mtetra
.25394 .35651 .25648 .35903 .26032 .35766 .25777 .35514 Mtetra
.25777 .35514 .26032 .35766 .26416 .3563 .26162 .35378 Mtetra
.26162 .35378 .26416 .3563 .26801 .35493 .26547 .35241 Mtetra
.26547 .35241 .26801 .35493 .27186 .35357 .26932 .35103 Mtetra
.26932 .35103 .27186 .35357 .27571 .35219 .27318 .34966 Mtetra
.27318 .34966 .27571 .35219 .27958 .35082 .27705 .34828 Mtetra
.95 .68 .489 r
.27705 .34828 .27958 .35082 .28345 .34945 .26896 .50226 Mtetra
.524 .291 .504 r
.26896 .50226 .28345 .34945 .27568 .50338 .27302 .50093 Mtetra
.651 .757 .927 r
.27302 .50093 .27568 .50338 .27936 .50732 .27709 .4996 Mtetra
.609 .511 .718 r
.27709 .4996 .27936 .50732 .28343 .506 .28116 .49827 Mtetra
.28116 .49827 .28343 .506 .28751 .50467 .28524 .49694 Mtetra
.28524 .49694 .28751 .50467 .2916 .50334 .28932 .4956 Mtetra
.28932 .4956 .2916 .50334 .29569 .50201 .29341 .49426 Mtetra
.29341 .49426 .29569 .50201 .29979 .50067 .29751 .49292 Mtetra
.207 .254 .691 r
.29751 .49292 .29979 .50067 .30389 .49934 .30125 .49686 Mtetra
.651 .757 .927 r
.30125 .49686 .30389 .49934 .30801 .498 .30537 .49552 Mtetra
.30537 .49552 .30801 .498 .31212 .49666 .30949 .49418 Mtetra
.30949 .49418 .31212 .49666 .31625 .49531 .31362 .49283 Mtetra
.31362 .49283 .31625 .49531 .32038 .49397 .31776 .49148 Mtetra
.31776 .49148 .32038 .49397 .32452 .49262 .3219 .49013 Mtetra
.3219 .49013 .32452 .49262 .32866 .49127 .32605 .48878 Mtetra
.32605 .48878 .32866 .49127 .33281 .48992 .3302 .48742 Mtetra
.3302 .48742 .33281 .48992 .33697 .48857 .33436 .48607 Mtetra
.33436 .48607 .33697 .48857 .34113 .48721 .33853 .48471 Mtetra
.33853 .48471 .34113 .48721 .3453 .48586 .3427 .48334 Mtetra
.3427 .48334 .3453 .48586 .34948 .4845 .34688 .48198 Mtetra
.34688 .48198 .34948 .4845 .35366 .48314 .35107 .48062 Mtetra
.35107 .48062 .35366 .48314 .35785 .48177 .35527 .47925 Mtetra
.921 .757 .662 r
.35527 .47925 .35785 .48177 .36257 .46981 .36 .46728 Mtetra
.652 .756 .926 r
.36 .46728 .36257 .46981 .36676 .46844 .36419 .4659 Mtetra
.36419 .4659 .36676 .46844 .37096 .46707 .36839 .46452 Mtetra
.36839 .46452 .37096 .46707 .37516 .46569 .3726 .46314 Mtetra
.3726 .46314 .37516 .46569 .37937 .46431 .37681 .46176 Mtetra
.37681 .46176 .37937 .46431 .38359 .46293 .38103 .46037 Mtetra
.38103 .46037 .38359 .46293 .38781 .46155 .38526 .45899 Mtetra
.38526 .45899 .38781 .46155 .39204 .46016 .38949 .4576 Mtetra
.38949 .4576 .39204 .46016 .39628 .45877 .39373 .45621 Mtetra
.39373 .45621 .39628 .45877 .40052 .45738 .39798 .45481 Mtetra
.39798 .45481 .40052 .45738 .40477 .45599 .40224 .45342 Mtetra
.40224 .45342 .40477 .45599 .40903 .4546 .4065 .45202 Mtetra
.4065 .45202 .40903 .4546 .41329 .4532 .41076 .45062 Mtetra
.41076 .45062 .41329 .4532 .41756 .4518 .41504 .44922 Mtetra
.41504 .44922 .41756 .4518 .42184 .4504 .41932 .44781 Mtetra
.41932 .44781 .42184 .4504 .42612 .449 .42361 .44641 Mtetra
.42361 .44641 .42612 .449 .43041 .4476 .4279 .445 Mtetra
.4279 .445 .43041 .4476 .43471 .44619 .4322 .44359 Mtetra
.4322 .44359 .43471 .44619 .43901 .44478 .43651 .44217 Mtetra
.43651 .44217 .43901 .44478 .44332 .44337 .44083 .44076 Mtetra
.962 .647 .375 r
.44083 .44076 .44332 .44337 .44662 .48506 .44409 .48248 Mtetra
.648 .76 .931 r
.44409 .48248 .44662 .48506 .451 .48366 .44848 .48107 Mtetra
.44848 .48107 .451 .48366 .45539 .48226 .45287 .47967 Mtetra
.45287 .47967 .45539 .48226 .45978 .48086 .45727 .47826 Mtetra
.45727 .47826 .45978 .48086 .46419 .47945 .46168 .47685 Mtetra
.46168 .47685 .46419 .47945 .4686 .47804 .46609 .47543 Mtetra
.46609 .47543 .4686 .47804 .47301 .47663 .47051 .47402 Mtetra
.47051 .47402 .47301 .47663 .47744 .47522 .47494 .4726 Mtetra
.47494 .4726 .47744 .47522 .48187 .4738 .47938 .47118 Mtetra
.47938 .47118 .48187 .4738 .48631 .47238 .48382 .46976 Mtetra
.48382 .46976 .48631 .47238 .49075 .47096 .48827 .46833 Mtetra
.48827 .46833 .49075 .47096 .4952 .46954 .49273 .4669 Mtetra
.49273 .4669 .4952 .46954 .49966 .46811 .49719 .46547 Mtetra
.49719 .46547 .49966 .46811 .50413 .46668 .50167 .46404 Mtetra
.50167 .46404 .50413 .46668 .50861 .46525 .50614 .46261 Mtetra
.50614 .46261 .50861 .46525 .51309 .46382 .51063 .46117 Mtetra
.51063 .46117 .51309 .46382 .51758 .46239 .51512 .45973 Mtetra
.51512 .45973 .51758 .46239 .52207 .46095 .51963 .45829 Mtetra
.939 .772 .649 r
.51963 .45829 .52207 .46095 .52657 .44855 .52414 .44588 Mtetra
.649 .759 .93 r
.52414 .44588 .52657 .44855 .53107 .44711 .52864 .44443 Mtetra
.52864 .44443 .53107 .44711 .53557 .44566 .53315 .44298 Mtetra
.53315 .44298 .53557 .44566 .54008 .44421 .53766 .44152 Mtetra
.53766 .44152 .54008 .44421 .5446 .44276 .54219 .44007 Mtetra
.54219 .44007 .5446 .44276 .54913 .4413 .54672 .43861 Mtetra
.54672 .43861 .54913 .4413 .55366 .43984 .55125 .43714 Mtetra
.55125 .43714 .55366 .43984 .5582 .43838 .5558 .43568 Mtetra
.5558 .43568 .5582 .43838 .56275 .43692 .56035 .43421 Mtetra
.56035 .43421 .56275 .43692 .5673 .43545 .56491 .43274 Mtetra
.56491 .43274 .5673 .43545 .57187 .43399 .56948 .43127 Mtetra
.56948 .43127 .57187 .43399 .57644 .43252 .57406 .4298 Mtetra
.57406 .4298 .57644 .43252 .58101 .43105 .57864 .42832 Mtetra
.57864 .42832 .58101 .43105 .5856 .42957 .58323 .42684 Mtetra
.974 .72 .487 r
.58323 .42684 .5856 .42957 .58932 .38476 .58699 .382 Mtetra
.653 .755 .925 r
.58699 .382 .58932 .38476 .59386 .38327 .59153 .3805 Mtetra
.59153 .3805 .59386 .38327 .59841 .38177 .59608 .379 Mtetra
.59608 .379 .59841 .38177 .60296 .38027 .60064 .37749 Mtetra
.60064 .37749 .60296 .38027 .60752 .37877 .60521 .37599 Mtetra
.60521 .37599 .60752 .37877 .61209 .37726 .60978 .37448 Mtetra
.60978 .37448 .61209 .37726 .61667 .37575 .61436 .37296 Mtetra
.61436 .37296 .61667 .37575 .62125 .37424 .61895 .37145 Mtetra
.61895 .37145 .62125 .37424 .62584 .37273 .62355 .36993 Mtetra
.62355 .36993 .62584 .37273 .63044 .37122 .62815 .36841 Mtetra
.62815 .36841 .63044 .37122 .63504 .3697 .63276 .36689 Mtetra
.63276 .36689 .63504 .3697 .63966 .36818 .63738 .36537 Mtetra
.63738 .36537 .63966 .36818 .64428 .36666 .64201 .36384 Mtetra
.64201 .36384 .64428 .36666 .64891 .36513 .64664 .36231 Mtetra
.64664 .36231 .64891 .36513 .65354 .36361 .65128 .36078 Mtetra
.65128 .36078 .65354 .36361 .65819 .36208 .65593 .35925 Mtetra
.65593 .35925 .65819 .36208 .66284 .36054 .66059 .35771 Mtetra
.66059 .35771 .66284 .36054 .6675 .35901 .66525 .35617 Mtetra
.66525 .35617 .6675 .35901 .67217 .35747 .66992 .35463 Mtetra
.979 .691 .397 r
.66992 .35463 .67217 .35747 .66973 .20722 .66759 .20429 Mtetra
.664 .741 .908 r
.66759 .20429 .66973 .20722 .67419 .20564 .67205 .2027 Mtetra
.67205 .2027 .67419 .20564 .67866 .20405 .67652 .2011 Mtetra
.67652 .2011 .67866 .20405 .68313 .20245 .681 .19951 Mtetra
.681 .19951 .68313 .20245 .68761 .20086 .68548 .19791 Mtetra
.68548 .19791 .68761 .20086 .69209 .19926 .68997 .1963 Mtetra
.68997 .1963 .69209 .19926 .69659 .19766 .69447 .1947 Mtetra
.69447 .1947 .69659 .19766 .70109 .19606 .69898 .19309 Mtetra
.69898 .19309 .70109 .19606 .70559 .19445 .70349 .19148 Mtetra
.70349 .19148 .70559 .19445 .71011 .19284 .70801 .18987 Mtetra
.70801 .18987 .71011 .19284 .71463 .19123 .71254 .18825 Mtetra
.71254 .18825 .71463 .19123 .71916 .18962 .71707 .18663 Mtetra
.71707 .18663 .71916 .18962 .72369 .188 .72161 .18501 Mtetra
.72161 .18501 .72369 .188 .72824 .18639 .72616 .18339 Mtetra
.72616 .18339 .72824 .18639 .73279 .18476 .73071 .18177 Mtetra
.73071 .18177 .73279 .18476 .73735 .18314 .73528 .18014 Mtetra
.73528 .18014 .73735 .18314 .74191 .18152 .73985 .17851 Mtetra
.73985 .17851 .74191 .18152 .74648 .17989 .74443 .17687 Mtetra
.74443 .17687 .74648 .17989 .75106 .17826 .74901 .17524 Mtetra
.74901 .17524 .75106 .17826 .75565 .17662 .7536 .1736 Mtetra
.7536 .1736 .75565 .17662 .76025 .17499 .7582 .17196 Mtetra
.7582 .17196 .76025 .17499 .76485 .17335 .76281 .17031 Mtetra
.76281 .17031 .76485 .17335 .76946 .1717 .76742 .16867 Mtetra
.76742 .16867 .76946 .1717 .77407 .17006 .77205 .16702 Mtetra
.77205 .16702 .77407 .17006 .7787 .16841 .77668 .16537 Mtetra
.77668 .16537 .7787 .16841 .78333 .16676 .78131 .16371 Mtetra
.78131 .16371 .78333 .16676 .78797 .16511 .78596 .16205 Mtetra
.78596 .16205 .78797 .16511 .79262 .16346 .79061 .16039 Mtetra
.16509 .38022 .16772 .38266 .17142 .38134 .1688 .37889 Mtetra
.1688 .37889 .17142 .38134 .17513 .38001 .17252 .37756 Mtetra
.17252 .37756 .17513 .38001 .17885 .37869 .17624 .37623 Mtetra
.17624 .37623 .17885 .37869 .18257 .37736 .17996 .3749 Mtetra
.17996 .3749 .18257 .37736 .1863 .37603 .18369 .37357 Mtetra
.18369 .37357 .1863 .37603 .19004 .3747 .18743 .37223 Mtetra
.18743 .37223 .19004 .3747 .19377 .37336 .19117 .37089 Mtetra
.19117 .37089 .19377 .37336 .19752 .37203 .19492 .36955 Mtetra
.19492 .36955 .19752 .37203 .20127 .37069 .19867 .36821 Mtetra
.19867 .36821 .20127 .37069 .20502 .36935 .20243 .36687 Mtetra
.20243 .36687 .20502 .36935 .20878 .36801 .20619 .36552 Mtetra
.20619 .36552 .20878 .36801 .21255 .36666 .20996 .36418 Mtetra
.20996 .36418 .21255 .36666 .21632 .36532 .21374 .36283 Mtetra
.21374 .36283 .21632 .36532 .2201 .36397 .21752 .36148 Mtetra
.21752 .36148 .2201 .36397 .22343 .36737 .2213 .36012 Mtetra
.22 .262 .694 r
.2213 .36012 .22343 .36737 .22723 .36602 .22465 .36352 Mtetra
.663 .742 .908 r
.22465 .36352 .22723 .36602 .23103 .36467 .22845 .36216 Mtetra
.22845 .36216 .23103 .36467 .23483 .36331 .23226 .36081 Mtetra
.23226 .36081 .23483 .36331 .23864 .36195 .23607 .35945 Mtetra
.23607 .35945 .23864 .36195 .24246 .3606 .23989 .35808 Mtetra
.23989 .35808 .24246 .3606 .24628 .35924 .24371 .35672 Mtetra
.24371 .35672 .24628 .35924 .2501 .35787 .24754 .35535 Mtetra
.24754 .35535 .2501 .35787 .25394 .35651 .25138 .35399 Mtetra
.25138 .35399 .25394 .35651 .25777 .35514 .25522 .35262 Mtetra
.25522 .35262 .25777 .35514 .26162 .35378 .25907 .35124 Mtetra
.25907 .35124 .26162 .35378 .26547 .35241 .26292 .34987 Mtetra
.26292 .34987 .26547 .35241 .26932 .35103 .26678 .3485 Mtetra
.26678 .3485 .26932 .35103 .27318 .34966 .27064 .34712 Mtetra
.27064 .34712 .27318 .34966 .27705 .34828 .27451 .34574 Mtetra
.95 .68 .489 r
.27451 .34574 .27705 .34828 .26896 .50226 .26629 .49981 Mtetra
.651 .757 .927 r
.26629 .49981 .26896 .50226 .27302 .50093 .27035 .49848 Mtetra
.27035 .49848 .27302 .50093 .27709 .4996 .27442 .49714 Mtetra
.27442 .49714 .27709 .4996 .28116 .49827 .2785 .49581 Mtetra
.2785 .49581 .28116 .49827 .28524 .49694 .28258 .49447 Mtetra
.28258 .49447 .28524 .49694 .28932 .4956 .28667 .49313 Mtetra
.28667 .49313 .28932 .4956 .29341 .49426 .29076 .49179 Mtetra
.29076 .49179 .29341 .49426 .29751 .49292 .29486 .49044 Mtetra
.29486 .49044 .29751 .49292 .30125 .49686 .29897 .4891 Mtetra
.609 .511 .718 r
.29897 .4891 .30125 .49686 .30537 .49552 .30308 .48775 Mtetra
.30308 .48775 .30537 .49552 .30949 .49418 .3072 .4864 Mtetra
.3072 .4864 .30949 .49418 .31362 .49283 .31133 .48505 Mtetra
.31133 .48505 .31362 .49283 .31776 .49148 .31546 .48369 Mtetra
.31546 .48369 .31776 .49148 .3219 .49013 .3196 .48234 Mtetra
.214 .258 .692 r
.3196 .48234 .3219 .49013 .32605 .48878 .32342 .48627 Mtetra
.651 .757 .927 r
.32342 .48627 .32605 .48878 .3302 .48742 .32758 .48492 Mtetra
.32758 .48492 .3302 .48742 .33436 .48607 .33175 .48355 Mtetra
.33175 .48355 .33436 .48607 .33853 .48471 .33592 .48219 Mtetra
.33592 .48219 .33853 .48471 .3427 .48334 .3401 .48083 Mtetra
.3401 .48083 .3427 .48334 .34688 .48198 .34428 .47946 Mtetra
.34428 .47946 .34688 .48198 .35107 .48062 .34847 .47809 Mtetra
.34847 .47809 .35107 .48062 .35527 .47925 .35267 .47672 Mtetra
.921 .757 .662 r
.35267 .47672 .35527 .47925 .36 .46728 .35741 .46473 Mtetra
.652 .756 .926 r
.35741 .46473 .36 .46728 .36419 .4659 .36161 .46335 Mtetra
.36161 .46335 .36419 .4659 .36839 .46452 .36582 .46197 Mtetra
.36582 .46197 .36839 .46452 .3726 .46314 .37003 .46059 Mtetra
.37003 .46059 .3726 .46314 .37681 .46176 .37425 .4592 Mtetra
.37425 .4592 .37681 .46176 .38103 .46037 .37847 .45781 Mtetra
.37847 .45781 .38103 .46037 .38526 .45899 .3827 .45642 Mtetra
.3827 .45642 .38526 .45899 .38949 .4576 .38694 .45503 Mtetra
.38694 .45503 .38949 .4576 .39373 .45621 .39118 .45363 Mtetra
.39118 .45363 .39373 .45621 .39798 .45481 .39544 .45224 Mtetra
.39544 .45224 .39798 .45481 .40224 .45342 .39969 .45084 Mtetra
.39969 .45084 .40224 .45342 .4065 .45202 .40396 .44943 Mtetra
.40396 .44943 .4065 .45202 .41076 .45062 .40823 .44803 Mtetra
.40823 .44803 .41076 .45062 .41504 .44922 .41251 .44662 Mtetra
.41251 .44662 .41504 .44922 .41932 .44781 .4168 .44521 Mtetra
.4168 .44521 .41932 .44781 .42361 .44641 .42109 .4438 Mtetra
.42109 .4438 .42361 .44641 .4279 .445 .42539 .44239 Mtetra
.42539 .44239 .4279 .445 .4322 .44359 .42969 .44097 Mtetra
.42969 .44097 .4322 .44359 .43651 .44217 .434 .43956 Mtetra
.434 .43956 .43651 .44217 .44083 .44076 .43832 .43814 Mtetra
.962 .647 .375 r
.43832 .43814 .44083 .44076 .44409 .48248 .44156 .47988 Mtetra
.648 .76 .931 r
.44156 .47988 .44409 .48248 .44848 .48107 .44595 .47847 Mtetra
.44595 .47847 .44848 .48107 .45287 .47967 .45035 .47706 Mtetra
.45035 .47706 .45287 .47967 .45727 .47826 .45475 .47565 Mtetra
.45475 .47565 .45727 .47826 .46168 .47685 .45916 .47424 Mtetra
.45916 .47424 .46168 .47685 .46609 .47543 .46358 .47282 Mtetra
.46358 .47282 .46609 .47543 .47051 .47402 .46801 .4714 Mtetra
.46801 .4714 .47051 .47402 .47494 .4726 .47244 .46998 Mtetra
.47244 .46998 .47494 .4726 .47938 .47118 .47688 .46855 Mtetra
.47688 .46855 .47938 .47118 .48382 .46976 .48133 .46712 Mtetra
.48133 .46712 .48382 .46976 .48827 .46833 .48578 .4657 Mtetra
.48578 .4657 .48827 .46833 .49273 .4669 .49025 .46426 Mtetra
.49025 .46426 .49273 .4669 .49719 .46547 .49472 .46283 Mtetra
.49472 .46283 .49719 .46547 .50167 .46404 .49919 .46139 Mtetra
.49919 .46139 .50167 .46404 .50614 .46261 .50368 .45995 Mtetra
.50368 .45995 .50614 .46261 .51063 .46117 .50817 .45851 Mtetra
.50817 .45851 .51063 .46117 .51512 .45973 .51267 .45707 Mtetra
.51267 .45707 .51512 .45973 .51963 .45829 .51717 .45562 Mtetra
.939 .772 .649 r
.51717 .45562 .51963 .45829 .52414 .44588 .5217 .4432 Mtetra
.649 .759 .93 r
.5217 .4432 .52414 .44588 .52864 .44443 .5262 .44175 Mtetra
.5262 .44175 .52864 .44443 .53315 .44298 .53071 .44029 Mtetra
.53071 .44029 .53315 .44298 .53766 .44152 .53524 .43883 Mtetra
.53524 .43883 .53766 .44152 .54219 .44007 .53976 .43737 Mtetra
.53976 .43737 .54219 .44007 .54672 .43861 .5443 .43591 Mtetra
.5443 .43591 .54672 .43861 .55125 .43714 .54884 .43444 Mtetra
.54884 .43444 .55125 .43714 .5558 .43568 .55339 .43297 Mtetra
.55339 .43297 .5558 .43568 .56035 .43421 .55795 .4315 Mtetra
.55795 .4315 .56035 .43421 .56491 .43274 .56252 .43002 Mtetra
.56252 .43002 .56491 .43274 .56948 .43127 .56709 .42855 Mtetra
.56709 .42855 .56948 .43127 .57406 .4298 .57167 .42707 Mtetra
.57167 .42707 .57406 .4298 .57864 .42832 .57626 .42559 Mtetra
.57626 .42559 .57864 .42832 .58323 .42684 .58085 .4241 Mtetra
.974 .72 .487 r
.58085 .4241 .58323 .42684 .58699 .382 .58465 .37923 Mtetra
.653 .755 .925 r
.58465 .37923 .58699 .382 .59153 .3805 .58919 .37772 Mtetra
.58919 .37772 .59153 .3805 .59608 .379 .59375 .37622 Mtetra
.59375 .37622 .59608 .379 .60064 .37749 .59831 .37471 Mtetra
.59831 .37471 .60064 .37749 .60521 .37599 .60288 .3732 Mtetra
.60288 .3732 .60521 .37599 .60978 .37448 .60746 .37168 Mtetra
.60746 .37168 .60978 .37448 .61436 .37296 .61205 .37017 Mtetra
.61205 .37017 .61436 .37296 .61895 .37145 .61664 .36865 Mtetra
.61664 .36865 .61895 .37145 .62355 .36993 .62124 .36713 Mtetra
.62124 .36713 .62355 .36993 .62815 .36841 .62585 .3656 Mtetra
.62585 .3656 .62815 .36841 .63276 .36689 .63047 .36408 Mtetra
.63047 .36408 .63276 .36689 .63738 .36537 .63509 .36255 Mtetra
.63509 .36255 .63738 .36537 .64201 .36384 .63972 .36102 Mtetra
.63972 .36102 .64201 .36384 .64664 .36231 .64436 .35948 Mtetra
.64436 .35948 .64664 .36231 .65128 .36078 .64901 .35794 Mtetra
.64901 .35794 .65128 .36078 .65593 .35925 .65366 .35641 Mtetra
.65366 .35641 .65593 .35925 .66059 .35771 .65833 .35486 Mtetra
.65833 .35486 .66059 .35771 .66525 .35617 .663 .35332 Mtetra
.979 .691 .399 r
.663 .35332 .66525 .35617 .66992 .35463 .66098 .20294 Mtetra
.534 .314 .527 r
.66098 .20294 .66992 .35463 .66759 .20429 .66544 .20135 Mtetra
.664 .741 .908 r
.66544 .20135 .66759 .20429 .67205 .2027 .66991 .19975 Mtetra
.66991 .19975 .67205 .2027 .67652 .2011 .67438 .19815 Mtetra
.67438 .19815 .67652 .2011 .681 .19951 .67886 .19655 Mtetra
.67886 .19655 .681 .19951 .68548 .19791 .68335 .19495 Mtetra
.68335 .19495 .68548 .19791 .68997 .1963 .68785 .19334 Mtetra
.68785 .19334 .68997 .1963 .69447 .1947 .69235 .19173 Mtetra
.69235 .19173 .69447 .1947 .69898 .19309 .69686 .19012 Mtetra
.69686 .19012 .69898 .19309 .70349 .19148 .70138 .1885 Mtetra
.70138 .1885 .70349 .19148 .70801 .18987 .7059 .18688 Mtetra
.7059 .18688 .70801 .18987 .71254 .18825 .71044 .18526 Mtetra
.71044 .18526 .71254 .18825 .71707 .18663 .71497 .18364 Mtetra
.71497 .18364 .71707 .18663 .72161 .18501 .71952 .18202 Mtetra
.71952 .18202 .72161 .18501 .72616 .18339 .72407 .18039 Mtetra
.72407 .18039 .72616 .18339 .73071 .18177 .72863 .17876 Mtetra
.72863 .17876 .73071 .18177 .73528 .18014 .7332 .17712 Mtetra
.7332 .17712 .73528 .18014 .73985 .17851 .73778 .17549 Mtetra
.73778 .17549 .73985 .17851 .74443 .17687 .74236 .17385 Mtetra
.74236 .17385 .74443 .17687 .74901 .17524 .74695 .17221 Mtetra
.74695 .17221 .74901 .17524 .7536 .1736 .75155 .17057 Mtetra
.75155 .17057 .7536 .1736 .7582 .17196 .75615 .16892 Mtetra
.75615 .16892 .7582 .17196 .76281 .17031 .76077 .16727 Mtetra
.76077 .16727 .76281 .17031 .76742 .16867 .76539 .16562 Mtetra
.76539 .16562 .76742 .16867 .77205 .16702 .77001 .16397 Mtetra
.77001 .16397 .77205 .16702 .77668 .16537 .77465 .16231 Mtetra
.77465 .16231 .77668 .16537 .78131 .16371 .77929 .16065 Mtetra
.77929 .16065 .78131 .16371 .78596 .16205 .78394 .15899 Mtetra
.78394 .15899 .78596 .16205 .79061 .16039 .7886 .15732 Mtetra
.16246 .37777 .16509 .38022 .1688 .37889 .16617 .37644 Mtetra
.16617 .37644 .1688 .37889 .17252 .37756 .16989 .37511 Mtetra
.16989 .37511 .17252 .37756 .17624 .37623 .17361 .37377 Mtetra
.17361 .37377 .17624 .37623 .17996 .3749 .17734 .37244 Mtetra
.17734 .37244 .17996 .3749 .18369 .37357 .18108 .3711 Mtetra
.18108 .3711 .18369 .37357 .18743 .37223 .18482 .36976 Mtetra
.18482 .36976 .18743 .37223 .19117 .37089 .18856 .36842 Mtetra
.18856 .36842 .19117 .37089 .19492 .36955 .19231 .36708 Mtetra
.19231 .36708 .19492 .36955 .19867 .36821 .19607 .36573 Mtetra
.19607 .36573 .19867 .36821 .20243 .36687 .19983 .36438 Mtetra
.19983 .36438 .20243 .36687 .20619 .36552 .2036 .36303 Mtetra
.2036 .36303 .20619 .36552 .20996 .36418 .20737 .36168 Mtetra
.20737 .36168 .20996 .36418 .21374 .36283 .21115 .36033 Mtetra
.21115 .36033 .21374 .36283 .21752 .36148 .21493 .35898 Mtetra
.21493 .35898 .21752 .36148 .2213 .36012 .21872 .35762 Mtetra
.526 .02 0 r
.21872 .35762 .2213 .36012 .22465 .36352 .22206 .36101 Mtetra
.663 .742 .908 r
.22206 .36101 .22465 .36352 .22845 .36216 .22587 .35966 Mtetra
.22587 .35966 .22845 .36216 .23226 .36081 .22968 .35829 Mtetra
.22968 .35829 .23226 .36081 .23607 .35945 .2335 .35693 Mtetra
.2335 .35693 .23607 .35945 .23989 .35808 .23732 .35556 Mtetra
.23732 .35556 .23989 .35808 .24371 .35672 .24115 .3542 Mtetra
.24115 .3542 .24371 .35672 .24754 .35535 .24498 .35283 Mtetra
.24498 .35283 .24754 .35535 .25138 .35399 .24882 .35146 Mtetra
.24882 .35146 .25138 .35399 .25522 .35262 .25266 .35008 Mtetra
.25266 .35008 .25522 .35262 .25907 .35124 .25651 .34871 Mtetra
.25651 .34871 .25907 .35124 .26292 .34987 .26037 .34733 Mtetra
.26037 .34733 .26292 .34987 .26678 .3485 .26423 .34595 Mtetra
.26423 .34595 .26678 .3485 .27064 .34712 .2681 .34457 Mtetra
.95 .68 .49 r
.2681 .34457 .27064 .34712 .27451 .34574 .25955 .49868 Mtetra
.522 .289 .503 r
.25955 .49868 .27451 .34574 .26629 .49981 .26361 .49735 Mtetra
.651 .757 .927 r
.26361 .49735 .26629 .49981 .27035 .49848 .26768 .49601 Mtetra
.26768 .49601 .27035 .49848 .27442 .49714 .27175 .49468 Mtetra
.27175 .49468 .27442 .49714 .2785 .49581 .27583 .49334 Mtetra
.27583 .49334 .2785 .49581 .28258 .49447 .27991 .492 Mtetra
.27991 .492 .28258 .49447 .28667 .49313 .284 .49065 Mtetra
.284 .49065 .28667 .49313 .29076 .49179 .2881 .48931 Mtetra
.2881 .48931 .29076 .49179 .29486 .49044 .29221 .48796 Mtetra
.29221 .48796 .29486 .49044 .29897 .4891 .29632 .48661 Mtetra
.29632 .48661 .29897 .4891 .30308 .48775 .30043 .48526 Mtetra
.30043 .48526 .30308 .48775 .3072 .4864 .30456 .4839 Mtetra
.30456 .4839 .3072 .4864 .31133 .48505 .30869 .48255 Mtetra
.30869 .48255 .31133 .48505 .31546 .48369 .31282 .48119 Mtetra
.31282 .48119 .31546 .48369 .3196 .48234 .31697 .47983 Mtetra
.31697 .47983 .3196 .48234 .32342 .48627 .32112 .47846 Mtetra
.609 .511 .718 r
.32112 .47846 .32342 .48627 .32758 .48492 .32527 .4771 Mtetra
.32527 .4771 .32758 .48492 .33175 .48355 .32944 .47573 Mtetra
.32944 .47573 .33175 .48355 .33592 .48219 .3336 .47436 Mtetra
.3336 .47436 .33592 .48219 .3401 .48083 .33778 .47299 Mtetra
.22 .262 .694 r
.33778 .47299 .3401 .48083 .34428 .47946 .34167 .47693 Mtetra
.651 .757 .927 r
.34167 .47693 .34428 .47946 .34847 .47809 .34586 .47555 Mtetra
.92 .757 .662 r
.34586 .47555 .34847 .47809 .35267 .47672 .35063 .46357 Mtetra
.583 .434 .645 r
.35063 .46357 .35267 .47672 .35741 .46473 .35482 .46219 Mtetra
.652 .756 .926 r
.35482 .46219 .35741 .46473 .36161 .46335 .35903 .4608 Mtetra
.35903 .4608 .36161 .46335 .36582 .46197 .36323 .45941 Mtetra
.36323 .45941 .36582 .46197 .37003 .46059 .36745 .45803 Mtetra
.36745 .45803 .37003 .46059 .37425 .4592 .37167 .45664 Mtetra
.37167 .45664 .37425 .4592 .37847 .45781 .3759 .45524 Mtetra
.3759 .45524 .37847 .45781 .3827 .45642 .38014 .45385 Mtetra
.38014 .45385 .3827 .45642 .38694 .45503 .38438 .45245 Mtetra
.38438 .45245 .38694 .45503 .39118 .45363 .38863 .45105 Mtetra
.38863 .45105 .39118 .45363 .39544 .45224 .39288 .44965 Mtetra
.39288 .44965 .39544 .45224 .39969 .45084 .39715 .44824 Mtetra
.39715 .44824 .39969 .45084 .40396 .44943 .40141 .44684 Mtetra
.40141 .44684 .40396 .44943 .40823 .44803 .40569 .44543 Mtetra
.40569 .44543 .40823 .44803 .41251 .44662 .40997 .44402 Mtetra
.40997 .44402 .41251 .44662 .4168 .44521 .41426 .44261 Mtetra
.41426 .44261 .4168 .44521 .42109 .4438 .41856 .44119 Mtetra
.41856 .44119 .42109 .4438 .42539 .44239 .42286 .43977 Mtetra
.42286 .43977 .42539 .44239 .42969 .44097 .42717 .43835 Mtetra
.42717 .43835 .42969 .44097 .434 .43956 .43149 .43693 Mtetra
.43149 .43693 .434 .43956 .43832 .43814 .43581 .43551 Mtetra
.43581 .43551 .43832 .43814 .44156 .47988 .44014 .43408 Mtetra
0 0 .367 r
.44014 .43408 .44156 .47988 .44595 .47847 .44342 .47587 Mtetra
.648 .76 .931 r
.44342 .47587 .44595 .47847 .45035 .47706 .44782 .47445 Mtetra
.44782 .47445 .45035 .47706 .45475 .47565 .45223 .47304 Mtetra
.45223 .47304 .45475 .47565 .45916 .47424 .45664 .47162 Mtetra
.45664 .47162 .45916 .47424 .46358 .47282 .46106 .47019 Mtetra
.46106 .47019 .46358 .47282 .46801 .4714 .4655 .46877 Mtetra
.4655 .46877 .46801 .4714 .47244 .46998 .46993 .46734 Mtetra
.46993 .46734 .47244 .46998 .47688 .46855 .47438 .46592 Mtetra
.47438 .46592 .47688 .46855 .48133 .46712 .47883 .46448 Mtetra
.47883 .46448 .48133 .46712 .48578 .4657 .48329 .46305 Mtetra
.48329 .46305 .48578 .4657 .49025 .46426 .48776 .46161 Mtetra
.48776 .46161 .49025 .46426 .49472 .46283 .49223 .46018 Mtetra
.49223 .46018 .49472 .46283 .49919 .46139 .49671 .45874 Mtetra
.49671 .45874 .49919 .46139 .50368 .45995 .5012 .45729 Mtetra
.5012 .45729 .50368 .45995 .50817 .45851 .5057 .45585 Mtetra
.5057 .45585 .50817 .45851 .51267 .45707 .5102 .4544 Mtetra
.5102 .4544 .51267 .45707 .51717 .45562 .51471 .45295 Mtetra
.939 .772 .649 r
.51471 .45295 .51717 .45562 .5217 .4432 .51925 .44052 Mtetra
.649 .759 .93 r
.51925 .44052 .5217 .4432 .5262 .44175 .52376 .43906 Mtetra
.52376 .43906 .5262 .44175 .53071 .44029 .52828 .43759 Mtetra
.52828 .43759 .53071 .44029 .53524 .43883 .5328 .43613 Mtetra
.5328 .43613 .53524 .43883 .53976 .43737 .53733 .43466 Mtetra
.53733 .43466 .53976 .43737 .5443 .43591 .54187 .4332 Mtetra
.54187 .4332 .5443 .43591 .54884 .43444 .54642 .43172 Mtetra
.54642 .43172 .54884 .43444 .55339 .43297 .55098 .43025 Mtetra
.55098 .43025 .55339 .43297 .55795 .4315 .55554 .42878 Mtetra
.55554 .42878 .55795 .4315 .56252 .43002 .56011 .4273 Mtetra
.56011 .4273 .56252 .43002 .56709 .42855 .56469 .42582 Mtetra
.56469 .42582 .56709 .42855 .57167 .42707 .56927 .42433 Mtetra
.975 .706 .457 r
.56927 .42433 .57167 .42707 .57626 .42559 .57273 .34767 Mtetra
.539 .325 .539 r
.57273 .34767 .57626 .42559 .58085 .4241 .57723 .34616 Mtetra
.57723 .34616 .58085 .4241 .58465 .37923 .58173 .34464 Mtetra
0 0 .446 r
.58173 .34464 .58465 .37923 .58919 .37772 .58685 .37494 Mtetra
.653 .755 .925 r
.58685 .37494 .58919 .37772 .59375 .37622 .59141 .37343 Mtetra
.59141 .37343 .59375 .37622 .59831 .37471 .59598 .37192 Mtetra
.59598 .37192 .59831 .37471 .60288 .3732 .60056 .3704 Mtetra
.60056 .3704 .60288 .3732 .60746 .37168 .60514 .36888 Mtetra
.60514 .36888 .60746 .37168 .61205 .37017 .60973 .36736 Mtetra
.60973 .36736 .61205 .37017 .61664 .36865 .61433 .36584 Mtetra
.61433 .36584 .61664 .36865 .62124 .36713 .61894 .36431 Mtetra
.61894 .36431 .62124 .36713 .62585 .3656 .62355 .36278 Mtetra
.62355 .36278 .62585 .3656 .63047 .36408 .62817 .36125 Mtetra
.62817 .36125 .63047 .36408 .63509 .36255 .6328 .35972 Mtetra
.6328 .35972 .63509 .36255 .63972 .36102 .63744 .35818 Mtetra
.63744 .35818 .63972 .36102 .64436 .35948 .64208 .35664 Mtetra
.64208 .35664 .64436 .35948 .64901 .35794 .64673 .3551 Mtetra
.64673 .3551 .64901 .35794 .65366 .35641 .65139 .35356 Mtetra
.65139 .35356 .65366 .35641 .65833 .35486 .65606 .35201 Mtetra
.979 .691 .4 r
.65606 .35201 .65833 .35486 .663 .35332 .65436 .20159 Mtetra
.534 .314 .527 r
.65436 .20159 .663 .35332 .66098 .20294 .65882 .2 Mtetra
.664 .741 .908 r
.65882 .2 .66098 .20294 .66544 .20135 .66328 .1984 Mtetra
.66328 .1984 .66544 .20135 .66991 .19975 .66776 .1968 Mtetra
.66776 .1968 .66991 .19975 .67438 .19815 .67224 .19519 Mtetra
.67224 .19519 .67438 .19815 .67886 .19655 .67672 .19359 Mtetra
.67672 .19359 .67886 .19655 .68335 .19495 .68122 .19198 Mtetra
.68122 .19198 .68335 .19495 .68785 .19334 .68572 .19036 Mtetra
.68572 .19036 .68785 .19334 .69235 .19173 .69023 .18875 Mtetra
.69023 .18875 .69235 .19173 .69686 .19012 .69474 .18713 Mtetra
.69474 .18713 .69686 .19012 .70138 .1885 .69926 .18551 Mtetra
.69926 .18551 .70138 .1885 .7059 .18688 .70379 .18389 Mtetra
.70379 .18389 .7059 .18688 .71044 .18526 .70833 .18227 Mtetra
.70833 .18227 .71044 .18526 .71497 .18364 .71287 .18064 Mtetra
.71287 .18064 .71497 .18364 .71952 .18202 .71742 .17901 Mtetra
.71742 .17901 .71952 .18202 .72407 .18039 .72198 .17738 Mtetra
.72198 .17738 .72407 .18039 .72863 .17876 .72655 .17574 Mtetra
.72655 .17574 .72863 .17876 .7332 .17712 .73112 .1741 Mtetra
.73112 .1741 .7332 .17712 .73778 .17549 .7357 .17246 Mtetra
.7357 .17246 .73778 .17549 .74236 .17385 .74029 .17082 Mtetra
.74029 .17082 .74236 .17385 .74695 .17221 .74489 .16917 Mtetra
.74489 .16917 .74695 .17221 .75155 .17057 .74949 .16752 Mtetra
.74949 .16752 .75155 .17057 .75615 .16892 .7541 .16587 Mtetra
.7541 .16587 .75615 .16892 .76077 .16727 .75872 .16422 Mtetra
.75872 .16422 .76077 .16727 .76539 .16562 .76334 .16256 Mtetra
.76334 .16256 .76539 .16562 .77001 .16397 .76797 .1609 Mtetra
.76797 .1609 .77001 .16397 .77465 .16231 .77261 .15924 Mtetra
.77261 .15924 .77465 .16231 .77929 .16065 .77726 .15758 Mtetra
.77726 .15758 .77929 .16065 .78394 .15899 .78192 .15591 Mtetra
.78192 .15591 .78394 .15899 .7886 .15732 .78658 .15424 Mtetra
.15982 .37531 .16246 .37777 .16617 .37644 .16354 .37398 Mtetra
.16354 .37398 .16617 .37644 .16989 .37511 .16726 .37264 Mtetra
.16726 .37264 .16989 .37511 .17361 .37377 .17099 .37131 Mtetra
.17099 .37131 .17361 .37377 .17734 .37244 .17472 .36997 Mtetra
.17472 .36997 .17734 .37244 .18108 .3711 .17845 .36863 Mtetra
.17845 .36863 .18108 .3711 .18482 .36976 .1822 .36728 Mtetra
.1822 .36728 .18482 .36976 .18856 .36842 .18595 .36594 Mtetra
.18595 .36594 .18856 .36842 .19231 .36708 .1897 .36459 Mtetra
.1897 .36459 .19231 .36708 .19607 .36573 .19346 .36324 Mtetra
.19346 .36324 .19607 .36573 .19983 .36438 .19722 .36189 Mtetra
.19722 .36189 .19983 .36438 .2036 .36303 .20099 .36054 Mtetra
.20099 .36054 .2036 .36303 .20737 .36168 .20477 .35918 Mtetra
.20477 .35918 .20737 .36168 .21115 .36033 .20855 .35783 Mtetra
.20855 .35783 .21115 .36033 .21493 .35898 .21234 .35647 Mtetra
.21234 .35647 .21493 .35898 .21872 .35762 .21613 .35511 Mtetra
.21613 .35511 .21872 .35762 .22206 .36101 .21993 .35375 Mtetra
.218 .261 .693 r
.21993 .35375 .22206 .36101 .22587 .35966 .22328 .35714 Mtetra
.663 .742 .908 r
.22328 .35714 .22587 .35966 .22968 .35829 .22709 .35577 Mtetra
.22709 .35577 .22968 .35829 .2335 .35693 .23091 .35441 Mtetra
.23091 .35441 .2335 .35693 .23732 .35556 .23474 .35304 Mtetra
.23474 .35304 .23732 .35556 .24115 .3542 .23857 .35167 Mtetra
.23857 .35167 .24115 .3542 .24498 .35283 .24241 .35029 Mtetra
.24241 .35029 .24498 .35283 .24882 .35146 .24625 .34892 Mtetra
.24625 .34892 .24882 .35146 .25266 .35008 .2501 .34754 Mtetra
.2501 .34754 .25266 .35008 .25651 .34871 .25395 .34616 Mtetra
.25395 .34616 .25651 .34871 .26037 .34733 .25781 .34478 Mtetra
.25781 .34478 .26037 .34733 .26423 .34595 .26168 .3434 Mtetra
.949 .68 .491 r
.26168 .3434 .26423 .34595 .2681 .34457 .2528 .49755 Mtetra
.522 .288 .502 r
.2528 .49755 .2681 .34457 .25955 .49868 .25686 .49622 Mtetra
.651 .757 .927 r
.25686 .49622 .25955 .49868 .26361 .49735 .26092 .49488 Mtetra
.26092 .49488 .26361 .49735 .26768 .49601 .26499 .49354 Mtetra
.26499 .49354 .26768 .49601 .27175 .49468 .26907 .4922 Mtetra
.26907 .4922 .27175 .49468 .27583 .49334 .27315 .49086 Mtetra
.27315 .49086 .27583 .49334 .27991 .492 .27724 .48951 Mtetra
.27724 .48951 .27991 .492 .284 .49065 .28133 .48817 Mtetra
.28133 .48817 .284 .49065 .2881 .48931 .28544 .48682 Mtetra
.28544 .48682 .2881 .48931 .29221 .48796 .28954 .48546 Mtetra
.28954 .48546 .29221 .48796 .29632 .48661 .29366 .48411 Mtetra
.29366 .48411 .29632 .48661 .30043 .48526 .29778 .48275 Mtetra
.29778 .48275 .30043 .48526 .30456 .4839 .30191 .4814 Mtetra
.30191 .4814 .30456 .4839 .30869 .48255 .30604 .48004 Mtetra
.30604 .48004 .30869 .48255 .31282 .48119 .31018 .47867 Mtetra
.31018 .47867 .31282 .48119 .31697 .47983 .31433 .47731 Mtetra
.31433 .47731 .31697 .47983 .32112 .47846 .31848 .47594 Mtetra
.31848 .47594 .32112 .47846 .32527 .4771 .32264 .47457 Mtetra
.32264 .47457 .32527 .4771 .32944 .47573 .32681 .4732 Mtetra
.32681 .4732 .32944 .47573 .3336 .47436 .33098 .47183 Mtetra
.33098 .47183 .3336 .47436 .33778 .47299 .33516 .47045 Mtetra
.33516 .47045 .33778 .47299 .34167 .47693 .33935 .46908 Mtetra
.609 .511 .718 r
.33935 .46908 .34167 .47693 .34586 .47555 .34354 .4677 Mtetra
.76 .599 .678 r
.34354 .4677 .34586 .47555 .35063 .46357 .34803 .46101 Mtetra
.652 .756 .926 r
.34803 .46101 .35063 .46357 .35482 .46219 .35223 .45963 Mtetra
.35223 .45963 .35482 .46219 .35903 .4608 .35643 .45824 Mtetra
.35643 .45824 .35903 .4608 .36323 .45941 .36064 .45685 Mtetra
.36064 .45685 .36323 .45941 .36745 .45803 .36486 .45546 Mtetra
.36486 .45546 .36745 .45803 .37167 .45664 .36909 .45406 Mtetra
.36909 .45406 .37167 .45664 .3759 .45524 .37332 .45267 Mtetra
.37332 .45267 .3759 .45524 .38014 .45385 .37756 .45127 Mtetra
.37756 .45127 .38014 .45385 .38438 .45245 .38181 .44986 Mtetra
.38181 .44986 .38438 .45245 .38863 .45105 .38606 .44846 Mtetra
.38606 .44846 .38863 .45105 .39288 .44965 .39032 .44706 Mtetra
.39032 .44706 .39288 .44965 .39715 .44824 .39459 .44565 Mtetra
.39459 .44565 .39715 .44824 .40141 .44684 .39886 .44424 Mtetra
.39886 .44424 .40141 .44684 .40569 .44543 .40314 .44282 Mtetra
.40314 .44282 .40569 .44543 .40997 .44402 .40743 .44141 Mtetra
.40743 .44141 .40997 .44402 .41426 .44261 .41172 .43999 Mtetra
.41172 .43999 .41426 .44261 .41856 .44119 .41602 .43857 Mtetra
.41602 .43857 .41856 .44119 .42286 .43977 .42033 .43715 Mtetra
.42033 .43715 .42286 .43977 .42717 .43835 .42465 .43573 Mtetra
.42465 .43573 .42717 .43835 .43149 .43693 .42897 .4343 Mtetra
.42897 .4343 .43149 .43693 .43581 .43551 .4333 .43287 Mtetra
.4333 .43287 .43581 .43551 .44014 .43408 .43763 .43144 Mtetra
.963 .647 .373 r
.43763 .43144 .44014 .43408 .44342 .47587 .44087 .47325 Mtetra
.648 .76 .931 r
.44087 .47325 .44342 .47587 .44782 .47445 .44528 .47184 Mtetra
.44528 .47184 .44782 .47445 .45223 .47304 .44969 .47041 Mtetra
.44969 .47041 .45223 .47304 .45664 .47162 .45411 .46899 Mtetra
.45411 .46899 .45664 .47162 .46106 .47019 .45854 .46756 Mtetra
.45854 .46756 .46106 .47019 .4655 .46877 .46297 .46614 Mtetra
.96 .732 .55 r
.46297 .46614 .4655 .46877 .46993 .46734 .46789 .43748 Mtetra
.554 .362 .576 r
.46789 .43748 .46993 .46734 .47438 .46592 .47231 .43604 Mtetra
.47231 .43604 .47438 .46592 .47883 .46448 .47673 .43459 Mtetra
.47673 .43459 .47883 .46448 .48329 .46305 .48115 .43314 Mtetra
.48115 .43314 .48329 .46305 .48776 .46161 .48559 .43169 Mtetra
.48559 .43169 .48776 .46161 .49223 .46018 .49003 .43024 Mtetra
.49003 .43024 .49223 .46018 .49671 .45874 .49448 .42879 Mtetra
.49448 .42879 .49671 .45874 .5012 .45729 .49893 .42733 Mtetra
.49893 .42733 .5012 .45729 .5057 .45585 .5034 .42587 Mtetra
.5034 .42587 .5057 .45585 .5102 .4544 .50787 .42441 Mtetra
.50787 .42441 .5102 .4544 .51471 .45295 .51235 .42294 Mtetra
.51235 .42294 .51471 .45295 .51925 .44052 .51683 .42147 Mtetra
.04 .022 .507 r
.51683 .42147 .51925 .44052 .52376 .43906 .52131 .43636 Mtetra
.649 .759 .93 r
.52131 .43636 .52376 .43906 .52828 .43759 .52583 .43489 Mtetra
.52583 .43489 .52828 .43759 .5328 .43613 .53036 .43342 Mtetra
.53036 .43342 .5328 .43613 .53733 .43466 .5349 .43195 Mtetra
.5349 .43195 .53733 .43466 .54187 .4332 .53944 .43048 Mtetra
.53944 .43048 .54187 .4332 .54642 .43172 .544 .429 Mtetra
.544 .429 .54642 .43172 .55098 .43025 .54856 .42752 Mtetra
.54856 .42752 .55098 .43025 .55554 .42878 .55312 .42604 Mtetra
.974 .706 .462 r
.55312 .42604 .55554 .42878 .56011 .4273 .55694 .34942 Mtetra
.538 .325 .538 r
.55694 .34942 .56011 .4273 .56469 .42582 .56142 .34791 Mtetra
.56142 .34791 .56469 .42582 .56927 .42433 .5659 .34639 Mtetra
.5659 .34639 .56927 .42433 .57273 .34767 .57039 .34488 Mtetra
.655 .752 .921 r
.57039 .34488 .57273 .34767 .57723 .34616 .57489 .34336 Mtetra
.57489 .34336 .57723 .34616 .58173 .34464 .57939 .34184 Mtetra
.57939 .34184 .58173 .34464 .58685 .37494 .58391 .34031 Mtetra
.551 .354 .567 r
.58391 .34031 .58685 .37494 .59141 .37343 .58843 .33878 Mtetra
0 0 .447 r
.58843 .33878 .59141 .37343 .59598 .37192 .59364 .36912 Mtetra
.653 .755 .925 r
.59364 .36912 .59598 .37192 .60056 .3704 .59822 .3676 Mtetra
.59822 .3676 .60056 .3704 .60514 .36888 .60281 .36607 Mtetra
.60281 .36607 .60514 .36888 .60973 .36736 .60741 .36455 Mtetra
.60741 .36455 .60973 .36736 .61433 .36584 .61201 .36302 Mtetra
.61201 .36302 .61433 .36584 .61894 .36431 .61662 .36149 Mtetra
.61662 .36149 .61894 .36431 .62355 .36278 .62124 .35995 Mtetra
.62124 .35995 .62355 .36278 .62817 .36125 .62587 .35842 Mtetra
.62587 .35842 .62817 .36125 .6328 .35972 .6305 .35688 Mtetra
.6305 .35688 .6328 .35972 .63744 .35818 .63514 .35534 Mtetra
.63514 .35534 .63744 .35818 .64208 .35664 .63979 .35379 Mtetra
.63979 .35379 .64208 .35664 .64673 .3551 .64445 .35225 Mtetra
.64445 .35225 .64673 .3551 .65139 .35356 .64911 .3507 Mtetra
.978 .691 .402 r
.64911 .3507 .65139 .35356 .65606 .35201 .64773 .20024 Mtetra
.533 .313 .526 r
.64773 .20024 .65606 .35201 .65436 .20159 .65219 .19864 Mtetra
.664 .741 .908 r
.65219 .19864 .65436 .20159 .65882 .2 .65665 .19704 Mtetra
.65665 .19704 .65882 .2 .66328 .1984 .66112 .19544 Mtetra
.66112 .19544 .66328 .1984 .66776 .1968 .6656 .19383 Mtetra
.6656 .19383 .66776 .1968 .67224 .19519 .67008 .19222 Mtetra
.67008 .19222 .67224 .19519 .67672 .19359 .67458 .19061 Mtetra
.67458 .19061 .67672 .19359 .68122 .19198 .67907 .189 Mtetra
.67907 .189 .68122 .19198 .68572 .19036 .68358 .18738 Mtetra
.68358 .18738 .68572 .19036 .69023 .18875 .68809 .18576 Mtetra
.68809 .18576 .69023 .18875 .69474 .18713 .69261 .18414 Mtetra
.69261 .18414 .69474 .18713 .69926 .18551 .69714 .18252 Mtetra
.69714 .18252 .69926 .18551 .70379 .18389 .70167 .18089 Mtetra
.70167 .18089 .70379 .18389 .70833 .18227 .70622 .17926 Mtetra
.70622 .17926 .70833 .18227 .71287 .18064 .71077 .17763 Mtetra
.71077 .17763 .71287 .18064 .71742 .17901 .71532 .17599 Mtetra
.71532 .17599 .71742 .17901 .72198 .17738 .71989 .17435 Mtetra
.71989 .17435 .72198 .17738 .72655 .17574 .72446 .17271 Mtetra
.72446 .17271 .72655 .17574 .73112 .1741 .72903 .17107 Mtetra
.72903 .17107 .73112 .1741 .7357 .17246 .73362 .16943 Mtetra
.73362 .16943 .7357 .17246 .74029 .17082 .73821 .16778 Mtetra
.73821 .16778 .74029 .17082 .74489 .16917 .74281 .16613 Mtetra
.74281 .16613 .74489 .16917 .74949 .16752 .74742 .16447 Mtetra
.74742 .16447 .74949 .16752 .7541 .16587 .75204 .16282 Mtetra
.75204 .16282 .7541 .16587 .75872 .16422 .75666 .16116 Mtetra
.75666 .16116 .75872 .16422 .76334 .16256 .76129 .1595 Mtetra
.76129 .1595 .76334 .16256 .76797 .1609 .76593 .15783 Mtetra
.76593 .15783 .76797 .1609 .77261 .15924 .77057 .15617 Mtetra
.77057 .15617 .77261 .15924 .77726 .15758 .77523 .1545 Mtetra
.77523 .1545 .77726 .15758 .78192 .15591 .77989 .15283 Mtetra
.77989 .15283 .78192 .15591 .78658 .15424 .78455 .15115 Mtetra
.15718 .37285 .15982 .37531 .16354 .37398 .1609 .37151 Mtetra
.1609 .37151 .16354 .37398 .16726 .37264 .16462 .37017 Mtetra
.16462 .37017 .16726 .37264 .17099 .37131 .16835 .36883 Mtetra
.16835 .36883 .17099 .37131 .17472 .36997 .17208 .36749 Mtetra
.17208 .36749 .17472 .36997 .17845 .36863 .17583 .36615 Mtetra
.17583 .36615 .17845 .36863 .1822 .36728 .17957 .3648 Mtetra
.17957 .3648 .1822 .36728 .18595 .36594 .18332 .36345 Mtetra
.18332 .36345 .18595 .36594 .1897 .36459 .18708 .3621 Mtetra
.18708 .3621 .1897 .36459 .19346 .36324 .19084 .36075 Mtetra
.19084 .36075 .19346 .36324 .19722 .36189 .19461 .35939 Mtetra
.19461 .35939 .19722 .36189 .20099 .36054 .19838 .35804 Mtetra
.19838 .35804 .20099 .36054 .20477 .35918 .20216 .35668 Mtetra
.20216 .35668 .20477 .35918 .20855 .35783 .20595 .35532 Mtetra
.20595 .35532 .20855 .35783 .21234 .35647 .20974 .35396 Mtetra
.20974 .35396 .21234 .35647 .21613 .35511 .21353 .35259 Mtetra
.21353 .35259 .21613 .35511 .21993 .35375 .21733 .35122 Mtetra
.523 .017 0 r
.21733 .35122 .21993 .35375 .22328 .35714 .22068 .35462 Mtetra
.663 .742 .908 r
.22068 .35462 .22328 .35714 .22709 .35577 .2245 .35325 Mtetra
.2245 .35325 .22709 .35577 .23091 .35441 .22832 .35188 Mtetra
.22832 .35188 .23091 .35441 .23474 .35304 .23215 .35051 Mtetra
.23215 .35051 .23474 .35304 .23857 .35167 .23599 .34913 Mtetra
.23599 .34913 .23857 .35167 .24241 .35029 .23983 .34775 Mtetra
.23983 .34775 .24241 .35029 .24625 .34892 .24367 .34637 Mtetra
.24367 .34637 .24625 .34892 .2501 .34754 .24752 .34499 Mtetra
.24752 .34499 .2501 .34754 .25395 .34616 .25138 .34361 Mtetra
.25138 .34361 .25395 .34616 .25781 .34478 .25524 .34222 Mtetra
.25524 .34222 .25781 .34478 .26168 .3434 .25911 .34084 Mtetra
.949 .68 .491 r
.25911 .34084 .26168 .3434 .2528 .49755 .2501 .49509 Mtetra
.651 .757 .927 r
.2501 .49509 .2528 .49755 .25686 .49622 .25416 .49375 Mtetra
.25416 .49375 .25686 .49622 .26092 .49488 .25822 .49241 Mtetra
.25822 .49241 .26092 .49488 .26499 .49354 .2623 .49107 Mtetra
.2623 .49107 .26499 .49354 .26907 .4922 .26638 .48972 Mtetra
.26638 .48972 .26907 .4922 .27315 .49086 .27046 .48837 Mtetra
.27046 .48837 .27315 .49086 .27724 .48951 .27456 .48702 Mtetra
.27456 .48702 .27724 .48951 .28133 .48817 .27866 .48567 Mtetra
.27866 .48567 .28133 .48817 .28544 .48682 .28276 .48432 Mtetra
.28276 .48432 .28544 .48682 .28954 .48546 .28687 .48296 Mtetra
.28687 .48296 .28954 .48546 .29366 .48411 .29099 .48161 Mtetra
.29099 .48161 .29366 .48411 .29778 .48275 .29512 .48025 Mtetra
.29512 .48025 .29778 .48275 .30191 .4814 .29925 .47888 Mtetra
.29925 .47888 .30191 .4814 .30604 .48004 .30339 .47752 Mtetra
.30339 .47752 .30604 .48004 .31018 .47867 .30753 .47615 Mtetra
.30753 .47615 .31018 .47867 .31433 .47731 .31168 .47478 Mtetra
.31168 .47478 .31433 .47731 .31848 .47594 .31584 .47341 Mtetra
.31584 .47341 .31848 .47594 .32264 .47457 .32 .47204 Mtetra
.32 .47204 .32264 .47457 .32681 .4732 .32417 .47067 Mtetra
.32417 .47067 .32681 .4732 .33098 .47183 .32835 .46929 Mtetra
.32835 .46929 .33098 .47183 .33516 .47045 .33254 .46791 Mtetra
.33254 .46791 .33516 .47045 .33935 .46908 .33673 .46653 Mtetra
.33673 .46653 .33935 .46908 .34354 .4677 .34092 .46514 Mtetra
.877 .777 .748 r
.34092 .46514 .34354 .4677 .34803 .46101 .34542 .45845 Mtetra
.652 .756 .926 r
.34542 .45845 .34803 .46101 .35223 .45963 .34962 .45706 Mtetra
.34962 .45706 .35223 .45963 .35643 .45824 .35383 .45567 Mtetra
.35383 .45567 .35643 .45824 .36064 .45685 .35805 .45428 Mtetra
.35805 .45428 .36064 .45685 .36486 .45546 .36227 .45288 Mtetra
.36227 .45288 .36486 .45546 .36909 .45406 .3665 .45148 Mtetra
.3665 .45148 .36909 .45406 .37332 .45267 .37074 .45008 Mtetra
.37074 .45008 .37332 .45267 .37756 .45127 .37498 .44868 Mtetra
.37498 .44868 .37756 .45127 .38181 .44986 .37923 .44727 Mtetra
.37923 .44727 .38181 .44986 .38606 .44846 .38349 .44586 Mtetra
.38349 .44586 .38606 .44846 .39032 .44706 .38775 .44445 Mtetra
.38775 .44445 .39032 .44706 .39459 .44565 .39202 .44304 Mtetra
.39202 .44304 .39459 .44565 .39886 .44424 .3963 .44163 Mtetra
.3963 .44163 .39886 .44424 .40314 .44282 .40059 .44021 Mtetra
.40059 .44021 .40314 .44282 .40743 .44141 .40488 .43879 Mtetra
.40488 .43879 .40743 .44141 .41172 .43999 .40918 .43737 Mtetra
.40918 .43737 .41172 .43999 .41602 .43857 .41348 .43595 Mtetra
.41348 .43595 .41602 .43857 .42033 .43715 .41779 .43452 Mtetra
.41779 .43452 .42033 .43715 .42465 .43573 .42211 .43309 Mtetra
.42211 .43309 .42465 .43573 .42897 .4343 .42644 .43166 Mtetra
.42644 .43166 .42897 .4343 .4333 .43287 .43077 .43023 Mtetra
.43077 .43023 .4333 .43287 .43763 .43144 .43511 .42879 Mtetra
.929 .545 .192 r
.43511 .42879 .43763 .43144 .44087 .47325 .43903 .44345 Mtetra
.554 .362 .575 r
.43903 .44345 .44087 .47325 .44528 .47184 .44341 .44202 Mtetra
.44341 .44202 .44528 .47184 .44969 .47041 .44779 .44058 Mtetra
.44779 .44058 .44969 .47041 .45411 .46899 .45218 .43914 Mtetra
.45218 .43914 .45411 .46899 .45854 .46756 .45658 .4377 Mtetra
.45658 .4377 .45854 .46756 .46297 .46614 .46098 .43626 Mtetra
.46098 .43626 .46297 .46614 .46789 .43748 .46539 .43481 Mtetra
.65 .758 .928 r
.46539 .43481 .46789 .43748 .47231 .43604 .46981 .43337 Mtetra
.46981 .43337 .47231 .43604 .47673 .43459 .47423 .43192 Mtetra
.47423 .43192 .47673 .43459 .48115 .43314 .47866 .43046 Mtetra
.47866 .43046 .48115 .43314 .48559 .43169 .4831 .42901 Mtetra
.4831 .42901 .48559 .43169 .49003 .43024 .48755 .42755 Mtetra
.48755 .42755 .49003 .43024 .49448 .42879 .492 .42609 Mtetra
.492 .42609 .49448 .42879 .49893 .42733 .49646 .42463 Mtetra
.49646 .42463 .49893 .42733 .5034 .42587 .50093 .42317 Mtetra
.50093 .42317 .5034 .42587 .50787 .42441 .50541 .4217 Mtetra
.50541 .4217 .50787 .42441 .51235 .42294 .50989 .42023 Mtetra
.50989 .42023 .51235 .42294 .51683 .42147 .51438 .41876 Mtetra
.51438 .41876 .51683 .42147 .52131 .43636 .51888 .41728 Mtetra
.04 .022 .507 r
.51888 .41728 .52131 .43636 .52583 .43489 .52338 .43218 Mtetra
.649 .759 .93 r
.52338 .43218 .52583 .43489 .53036 .43342 .52791 .43071 Mtetra
.52791 .43071 .53036 .43342 .5349 .43195 .53245 .42923 Mtetra
.53245 .42923 .5349 .43195 .53944 .43048 .537 .42775 Mtetra
.537 .42775 .53944 .43048 .544 .429 .54156 .42627 Mtetra
.973 .706 .465 r
.54156 .42627 .544 .429 .54856 .42752 .54564 .34965 Mtetra
.538 .324 .538 r
.54564 .34965 .54856 .42752 .55312 .42604 .5501 .34814 Mtetra
.5501 .34814 .55312 .42604 .55694 .34942 .55458 .34663 Mtetra
.655 .752 .921 r
.55458 .34663 .55694 .34942 .56142 .34791 .55906 .34511 Mtetra
.55906 .34511 .56142 .34791 .5659 .34639 .56354 .34359 Mtetra
.56354 .34359 .5659 .34639 .57039 .34488 .56804 .34207 Mtetra
.56804 .34207 .57039 .34488 .57489 .34336 .57254 .34055 Mtetra
.57254 .34055 .57489 .34336 .57939 .34184 .57705 .33902 Mtetra
.57705 .33902 .57939 .34184 .58391 .34031 .58157 .33749 Mtetra
.58157 .33749 .58391 .34031 .58843 .33878 .5861 .33596 Mtetra
.5861 .33596 .58843 .33878 .59364 .36912 .59063 .33443 Mtetra
0 0 .447 r
.59063 .33443 .59364 .36912 .59822 .3676 .59588 .36478 Mtetra
.653 .755 .925 r
.59588 .36478 .59822 .3676 .60281 .36607 .60047 .36325 Mtetra
.60047 .36325 .60281 .36607 .60741 .36455 .60507 .36172 Mtetra
.60507 .36172 .60741 .36455 .61201 .36302 .60968 .36019 Mtetra
.60968 .36019 .61201 .36302 .61662 .36149 .6143 .35865 Mtetra
.6143 .35865 .61662 .36149 .62124 .35995 .61892 .35712 Mtetra
.61892 .35712 .62124 .35995 .62587 .35842 .62355 .35558 Mtetra
.62355 .35558 .62587 .35842 .6305 .35688 .62819 .35403 Mtetra
.62819 .35403 .6305 .35688 .63514 .35534 .63284 .35249 Mtetra
.63284 .35249 .63514 .35534 .63979 .35379 .63749 .35094 Mtetra
.63749 .35094 .63979 .35379 .64445 .35225 .64216 .34939 Mtetra
.978 .692 .404 r
.64216 .34939 .64445 .35225 .64911 .3507 .6411 .19889 Mtetra
.532 .312 .526 r
.6411 .19889 .64911 .3507 .64773 .20024 .64555 .19729 Mtetra
.664 .741 .908 r
.64555 .19729 .64773 .20024 .65219 .19864 .65001 .19569 Mtetra
.65001 .19569 .65219 .19864 .65665 .19704 .65448 .19408 Mtetra
.65448 .19408 .65665 .19704 .66112 .19544 .65896 .19247 Mtetra
.65896 .19247 .66112 .19544 .6656 .19383 .66344 .19086 Mtetra
.66344 .19086 .6656 .19383 .67008 .19222 .66793 .18925 Mtetra
.66793 .18925 .67008 .19222 .67458 .19061 .67242 .18763 Mtetra
.67242 .18763 .67458 .19061 .67907 .189 .67693 .18601 Mtetra
.67693 .18601 .67907 .189 .68358 .18738 .68144 .18439 Mtetra
.68144 .18439 .68358 .18738 .68809 .18576 .68595 .18277 Mtetra
.68595 .18277 .68809 .18576 .69261 .18414 .69048 .18114 Mtetra
.69048 .18114 .69261 .18414 .69714 .18252 .69501 .17951 Mtetra
.69501 .17951 .69714 .18252 .70167 .18089 .69955 .17788 Mtetra
.69955 .17788 .70167 .18089 .70622 .17926 .7041 .17624 Mtetra
.7041 .17624 .70622 .17926 .71077 .17763 .70865 .17461 Mtetra
.70865 .17461 .71077 .17763 .71532 .17599 .71321 .17297 Mtetra
.71321 .17297 .71532 .17599 .71989 .17435 .71778 .17133 Mtetra
.71778 .17133 .71989 .17435 .72446 .17271 .72236 .16968 Mtetra
.72236 .16968 .72446 .17271 .72903 .17107 .72694 .16803 Mtetra
.72694 .16803 .72903 .17107 .73362 .16943 .73153 .16638 Mtetra
.73153 .16638 .73362 .16943 .73821 .16778 .73613 .16473 Mtetra
.73613 .16473 .73821 .16778 .74281 .16613 .74074 .16307 Mtetra
.74074 .16307 .74281 .16613 .74742 .16447 .74535 .16142 Mtetra
.74535 .16142 .74742 .16447 .75204 .16282 .74997 .15975 Mtetra
.74997 .15975 .75204 .16282 .75666 .16116 .7546 .15809 Mtetra
.7546 .15809 .75666 .16116 .76129 .1595 .75923 .15642 Mtetra
.75923 .15642 .76129 .1595 .76593 .15783 .76388 .15476 Mtetra
.76388 .15476 .76593 .15783 .77057 .15617 .76853 .15308 Mtetra
.76853 .15308 .77057 .15617 .77523 .1545 .77318 .15141 Mtetra
.77318 .15141 .77523 .1545 .77989 .15283 .77785 .14973 Mtetra
.77785 .14973 .77989 .15283 .78455 .15115 .78252 .14805 Mtetra
.15452 .37038 .15718 .37285 .1609 .37151 .15825 .36904 Mtetra
.15825 .36904 .1609 .37151 .16462 .37017 .16197 .3677 Mtetra
.16197 .3677 .16462 .37017 .16835 .36883 .16571 .36635 Mtetra
.16571 .36635 .16835 .36883 .17208 .36749 .16944 .36501 Mtetra
.16944 .36501 .17208 .36749 .17583 .36615 .17319 .36366 Mtetra
.17319 .36366 .17583 .36615 .17957 .3648 .17694 .36231 Mtetra
.17694 .36231 .17957 .3648 .18332 .36345 .18069 .36096 Mtetra
.18069 .36096 .18332 .36345 .18708 .3621 .18445 .3596 Mtetra
.18445 .3596 .18708 .3621 .19084 .36075 .18822 .35825 Mtetra
.18822 .35825 .19084 .36075 .19461 .35939 .19199 .35689 Mtetra
.19199 .35689 .19461 .35939 .19838 .35804 .19576 .35553 Mtetra
.19576 .35553 .19838 .35804 .20216 .35668 .19955 .35416 Mtetra
.19955 .35416 .20216 .35668 .20595 .35532 .20333 .3528 Mtetra
.20333 .3528 .20595 .35532 .20974 .35396 .20713 .35143 Mtetra
.20713 .35143 .20974 .35396 .21353 .35259 .21093 .35007 Mtetra
.21093 .35007 .21353 .35259 .21733 .35122 .21473 .3487 Mtetra
.523 .017 0 r
.21473 .3487 .21733 .35122 .22068 .35462 .21808 .35209 Mtetra
.663 .742 .908 r
.21808 .35209 .22068 .35462 .2245 .35325 .2219 .35072 Mtetra
.2219 .35072 .2245 .35325 .22832 .35188 .22573 .34934 Mtetra
.22573 .34934 .22832 .35188 .23215 .35051 .22956 .34797 Mtetra
.22956 .34797 .23215 .35051 .23599 .34913 .2334 .34659 Mtetra
.2334 .34659 .23599 .34913 .23983 .34775 .23724 .34521 Mtetra
.23724 .34521 .23983 .34775 .24367 .34637 .24109 .34382 Mtetra
.24109 .34382 .24367 .34637 .24752 .34499 .24494 .34244 Mtetra
.24494 .34244 .24752 .34499 .25138 .34361 .2488 .34105 Mtetra
.2488 .34105 .25138 .34361 .25524 .34222 .25267 .33966 Mtetra
.949 .68 .492 r
.25267 .33966 .25524 .34222 .25911 .34084 .24333 .49396 Mtetra
.52 .287 .501 r
.24333 .49396 .25911 .34084 .2501 .49509 .24738 .49261 Mtetra
.651 .757 .927 r
.24738 .49261 .2501 .49509 .25416 .49375 .25145 .49127 Mtetra
.25145 .49127 .25416 .49375 .25822 .49241 .25552 .48993 Mtetra
.25552 .48993 .25822 .49241 .2623 .49107 .2596 .48858 Mtetra
.2596 .48858 .2623 .49107 .26638 .48972 .26368 .48723 Mtetra
.26368 .48723 .26638 .48972 .27046 .48837 .26777 .48588 Mtetra
.26777 .48588 .27046 .48837 .27456 .48702 .27187 .48453 Mtetra
.27187 .48453 .27456 .48702 .27866 .48567 .27597 .48317 Mtetra
.27597 .48317 .27866 .48567 .28276 .48432 .28008 .48181 Mtetra
.28008 .48181 .28276 .48432 .28687 .48296 .2842 .48045 Mtetra
.2842 .48045 .28687 .48296 .29099 .48161 .28832 .47909 Mtetra
.28832 .47909 .29099 .48161 .29512 .48025 .29245 .47773 Mtetra
.29245 .47773 .29512 .48025 .29925 .47888 .29658 .47636 Mtetra
.29658 .47636 .29925 .47888 .30339 .47752 .30073 .47499 Mtetra
.30073 .47499 .30339 .47752 .30753 .47615 .30487 .47362 Mtetra
.30487 .47362 .30753 .47615 .31168 .47478 .30903 .47225 Mtetra
.30903 .47225 .31168 .47478 .31584 .47341 .31319 .47088 Mtetra
.31319 .47088 .31584 .47341 .32 .47204 .31736 .4695 Mtetra
.31736 .4695 .32 .47204 .32417 .47067 .32153 .46812 Mtetra
.32153 .46812 .32417 .47067 .32835 .46929 .32571 .46674 Mtetra
.32571 .46674 .32835 .46929 .33254 .46791 .3299 .46536 Mtetra
.3299 .46536 .33254 .46791 .33673 .46653 .3341 .46397 Mtetra
.3341 .46397 .33673 .46653 .34092 .46514 .3383 .46258 Mtetra
.3383 .46258 .34092 .46514 .34542 .45845 .3425 .46119 Mtetra
.837 .962 .63 r
.3425 .46119 .34542 .45845 .34962 .45706 .34701 .45449 Mtetra
.652 .756 .926 r
.34701 .45449 .34962 .45706 .35383 .45567 .35122 .4531 Mtetra
.35122 .4531 .35383 .45567 .35805 .45428 .35544 .4517 Mtetra
.35544 .4517 .35805 .45428 .36227 .45288 .35967 .4503 Mtetra
.35967 .4503 .36227 .45288 .3665 .45148 .3639 .44889 Mtetra
.3639 .44889 .3665 .45148 .37074 .45008 .36815 .44749 Mtetra
.36815 .44749 .37074 .45008 .37498 .44868 .37239 .44608 Mtetra
.37239 .44608 .37498 .44868 .37923 .44727 .37665 .44467 Mtetra
.37665 .44467 .37923 .44727 .38349 .44586 .38091 .44326 Mtetra
.38091 .44326 .38349 .44586 .38775 .44445 .38518 .44184 Mtetra
.38518 .44184 .38775 .44445 .39202 .44304 .38945 .44043 Mtetra
.38945 .44043 .39202 .44304 .3963 .44163 .39374 .43901 Mtetra
.39374 .43901 .3963 .44163 .40059 .44021 .39802 .43759 Mtetra
.39802 .43759 .40059 .44021 .40488 .43879 .40232 .43617 Mtetra
.40232 .43617 .40488 .43879 .40918 .43737 .40662 .43474 Mtetra
.40662 .43474 .40918 .43737 .41348 .43595 .41093 .43331 Mtetra
.41093 .43331 .41348 .43595 .41779 .43452 .41525 .43188 Mtetra
.41525 .43188 .41779 .43452 .42211 .43309 .41957 .43045 Mtetra
.41957 .43045 .42211 .43309 .42644 .43166 .4239 .42902 Mtetra
.4239 .42902 .42644 .43166 .43077 .43023 .42824 .42758 Mtetra
.963 .652 .385 r
.42824 .42758 .43077 .43023 .43511 .42879 .4312 .47492 Mtetra
.037 0 .327 r
.4312 .47492 .43511 .42879 .43903 .44345 .4365 .4408 Mtetra
.65 .758 .928 r
.4365 .4408 .43903 .44345 .44341 .44202 .44088 .43936 Mtetra
.44088 .43936 .44341 .44202 .44779 .44058 .44526 .43792 Mtetra
.44526 .43792 .44779 .44058 .45218 .43914 .44966 .43648 Mtetra
.44966 .43648 .45218 .43914 .45658 .4377 .45406 .43504 Mtetra
.45406 .43504 .45658 .4377 .46098 .43626 .45846 .43359 Mtetra
.45846 .43359 .46098 .43626 .46539 .43481 .46288 .43214 Mtetra
.46288 .43214 .46539 .43481 .46981 .43337 .4673 .43069 Mtetra
.4673 .43069 .46981 .43337 .47423 .43192 .47173 .42923 Mtetra
.47173 .42923 .47423 .43192 .47866 .43046 .47617 .42778 Mtetra
.47617 .42778 .47866 .43046 .4831 .42901 .48061 .42632 Mtetra
.48061 .42632 .4831 .42901 .48755 .42755 .48506 .42486 Mtetra
.48506 .42486 .48755 .42755 .492 .42609 .48952 .42339 Mtetra
.48952 .42339 .492 .42609 .49646 .42463 .49399 .42193 Mtetra
.49399 .42193 .49646 .42463 .50093 .42317 .49846 .42046 Mtetra
.49846 .42046 .50093 .42317 .50541 .4217 .50294 .41899 Mtetra
.50294 .41899 .50541 .4217 .50989 .42023 .50743 .41751 Mtetra
.50743 .41751 .50989 .42023 .51438 .41876 .51192 .41604 Mtetra
.51192 .41604 .51438 .41876 .51888 .41728 .51643 .41456 Mtetra
.51643 .41456 .51888 .41728 .52338 .43218 .52093 .41308 Mtetra
.04 .022 .507 r
.52093 .41308 .52338 .43218 .52791 .43071 .52545 .42798 Mtetra
.972 .706 .469 r
.52545 .42798 .52791 .43071 .53245 .42923 .52988 .35139 Mtetra
.537 .323 .537 r
.52988 .35139 .53245 .42923 .537 .42775 .53433 .34988 Mtetra
.53433 .34988 .537 .42775 .54156 .42627 .53879 .34837 Mtetra
.53879 .34837 .54156 .42627 .54564 .34965 .54325 .34686 Mtetra
.655 .752 .921 r
.54325 .34686 .54564 .34965 .5501 .34814 .54773 .34534 Mtetra
.54773 .34534 .5501 .34814 .55458 .34663 .5522 .34382 Mtetra
.5522 .34382 .55458 .34663 .55906 .34511 .55669 .3423 Mtetra
.55669 .3423 .55906 .34511 .56354 .34359 .56118 .34078 Mtetra
.56118 .34078 .56354 .34359 .56804 .34207 .56568 .33925 Mtetra
.56568 .33925 .56804 .34207 .57254 .34055 .57019 .33773 Mtetra
.57019 .33773 .57254 .34055 .57705 .33902 .57471 .3362 Mtetra
.57471 .3362 .57705 .33902 .58157 .33749 .57923 .33466 Mtetra
.57923 .33466 .58157 .33749 .5861 .33596 .58376 .33313 Mtetra
.58376 .33313 .5861 .33596 .59063 .33443 .5883 .33159 Mtetra
.5883 .33159 .59063 .33443 .59588 .36478 .59284 .33005 Mtetra
.55 .353 .566 r
.59284 .33005 .59588 .36478 .60047 .36325 .59739 .3285 Mtetra
0 0 .448 r
.59739 .3285 .60047 .36325 .60507 .36172 .60273 .35889 Mtetra
.653 .755 .925 r
.60273 .35889 .60507 .36172 .60968 .36019 .60735 .35735 Mtetra
.60735 .35735 .60968 .36019 .6143 .35865 .61197 .35581 Mtetra
.61197 .35581 .6143 .35865 .61892 .35712 .6166 .35427 Mtetra
.6166 .35427 .61892 .35712 .62355 .35558 .62123 .35272 Mtetra
.62123 .35272 .62355 .35558 .62819 .35403 .62588 .35118 Mtetra
.62588 .35118 .62819 .35403 .63284 .35249 .63053 .34963 Mtetra
.63053 .34963 .63284 .35249 .63749 .35094 .63519 .34807 Mtetra
.63519 .34807 .63749 .35094 .64216 .34939 .63986 .34652 Mtetra
.978 .692 .404 r
.63986 .34652 .64216 .34939 .6411 .19889 .6389 .19593 Mtetra
.664 .741 .908 r
.6389 .19593 .6411 .19889 .64555 .19729 .64336 .19433 Mtetra
.64336 .19433 .64555 .19729 .65001 .19569 .64783 .19272 Mtetra
.64783 .19272 .65001 .19569 .65448 .19408 .6523 .19111 Mtetra
.6523 .19111 .65448 .19408 .65896 .19247 .65678 .1895 Mtetra
.65678 .1895 .65896 .19247 .66344 .19086 .66127 .18788 Mtetra
.66127 .18788 .66344 .19086 .66793 .18925 .66576 .18626 Mtetra
.66576 .18626 .66793 .18925 .67242 .18763 .67026 .18464 Mtetra
.67026 .18464 .67242 .18763 .67693 .18601 .67477 .18302 Mtetra
.67477 .18302 .67693 .18601 .68144 .18439 .67929 .18139 Mtetra
.67929 .18139 .68144 .18439 .68595 .18277 .68381 .17976 Mtetra
.68381 .17976 .68595 .18277 .69048 .18114 .68834 .17813 Mtetra
.68834 .17813 .69048 .18114 .69501 .17951 .69288 .1765 Mtetra
.69288 .1765 .69501 .17951 .69955 .17788 .69742 .17486 Mtetra
.69742 .17486 .69955 .17788 .7041 .17624 .70197 .17322 Mtetra
.70197 .17322 .7041 .17624 .70865 .17461 .70653 .17158 Mtetra
.70653 .17158 .70865 .17461 .71321 .17297 .7111 .16993 Mtetra
.7111 .16993 .71321 .17297 .71778 .17133 .71567 .16829 Mtetra
.71567 .16829 .71778 .17133 .72236 .16968 .72025 .16664 Mtetra
.72025 .16664 .72236 .16968 .72694 .16803 .72484 .16498 Mtetra
.72484 .16498 .72694 .16803 .73153 .16638 .72944 .16333 Mtetra
.72944 .16333 .73153 .16638 .73613 .16473 .73404 .16167 Mtetra
.73404 .16167 .73613 .16473 .74074 .16307 .73865 .16001 Mtetra
.73865 .16001 .74074 .16307 .74535 .16142 .74327 .15835 Mtetra
.74327 .15835 .74535 .16142 .74997 .15975 .7479 .15668 Mtetra
.7479 .15668 .74997 .15975 .7546 .15809 .75253 .15501 Mtetra
.75253 .15501 .7546 .15809 .75923 .15642 .75717 .15334 Mtetra
.75717 .15334 .75923 .15642 .76388 .15476 .76182 .15167 Mtetra
.76182 .15167 .76388 .15476 .76853 .15308 .76647 .14999 Mtetra
.76647 .14999 .76853 .15308 .77318 .15141 .77114 .14831 Mtetra
.77114 .14831 .77318 .15141 .77785 .14973 .77581 .14663 Mtetra
.77581 .14663 .77785 .14973 .78252 .14805 .78049 .14494 Mtetra
.15187 .3679 .15452 .37038 .15825 .36904 .15559 .36656 Mtetra
.15559 .36656 .15825 .36904 .16197 .3677 .15932 .36521 Mtetra
.15932 .36521 .16197 .3677 .16571 .36635 .16306 .36387 Mtetra
.16306 .36387 .16571 .36635 .16944 .36501 .1668 .36252 Mtetra
.1668 .36252 .16944 .36501 .17319 .36366 .17054 .36116 Mtetra
.17054 .36116 .17319 .36366 .17694 .36231 .1743 .35981 Mtetra
.1743 .35981 .17694 .36231 .18069 .36096 .17805 .35845 Mtetra
.17805 .35845 .18069 .36096 .18445 .3596 .18182 .3571 Mtetra
.18182 .3571 .18445 .3596 .18822 .35825 .18559 .35574 Mtetra
.18559 .35574 .18822 .35825 .19199 .35689 .18936 .35437 Mtetra
.18936 .35437 .19199 .35689 .19576 .35553 .19314 .35301 Mtetra
.19314 .35301 .19576 .35553 .19955 .35416 .19692 .35165 Mtetra
.19692 .35165 .19955 .35416 .20333 .3528 .20072 .35028 Mtetra
.20072 .35028 .20333 .3528 .20713 .35143 .20451 .34891 Mtetra
.20451 .34891 .20713 .35143 .21093 .35007 .20831 .34754 Mtetra
.20831 .34754 .21093 .35007 .21473 .3487 .21212 .34616 Mtetra
.21212 .34616 .21473 .3487 .21808 .35209 .21593 .34479 Mtetra
.614 .514 .718 r
.21593 .34479 .21808 .35209 .2219 .35072 .21975 .34341 Mtetra
.21975 .34341 .2219 .35072 .22573 .34934 .22358 .34203 Mtetra
.22358 .34203 .22573 .34934 .22956 .34797 .22741 .34065 Mtetra
.22741 .34065 .22956 .34797 .2334 .34659 .23124 .33926 Mtetra
.23124 .33926 .2334 .34659 .23724 .34521 .23508 .33788 Mtetra
.23508 .33788 .23724 .34521 .24109 .34382 .23893 .33649 Mtetra
.23893 .33649 .24109 .34382 .24494 .34244 .24278 .3351 Mtetra
.24278 .3351 .24494 .34244 .2488 .34105 .24664 .33371 Mtetra
.24664 .33371 .2488 .34105 .25267 .33966 .25051 .33231 Mtetra
.956 .688 .487 r
.25051 .33231 .25267 .33966 .24333 .49396 .2406 .49148 Mtetra
.651 .757 .927 r
.2406 .49148 .24333 .49396 .24738 .49261 .24466 .49013 Mtetra
.24466 .49013 .24738 .49261 .25145 .49127 .24873 .48879 Mtetra
.24873 .48879 .25145 .49127 .25552 .48993 .25281 .48744 Mtetra
.25281 .48744 .25552 .48993 .2596 .48858 .25689 .48609 Mtetra
.25689 .48609 .2596 .48858 .26368 .48723 .26098 .48474 Mtetra
.26098 .48474 .26368 .48723 .26777 .48588 .26507 .48338 Mtetra
.26507 .48338 .26777 .48588 .27187 .48453 .26917 .48202 Mtetra
.26917 .48202 .27187 .48453 .27597 .48317 .27328 .48066 Mtetra
.27328 .48066 .27597 .48317 .28008 .48181 .27739 .4793 Mtetra
.27739 .4793 .28008 .48181 .2842 .48045 .28151 .47794 Mtetra
.28151 .47794 .2842 .48045 .28832 .47909 .28564 .47657 Mtetra
.28564 .47657 .28832 .47909 .29245 .47773 .28977 .47521 Mtetra
.28977 .47521 .29245 .47773 .29658 .47636 .29391 .47384 Mtetra
.29391 .47384 .29658 .47636 .30073 .47499 .29806 .47246 Mtetra
.29806 .47246 .30073 .47499 .30487 .47362 .30221 .47109 Mtetra
.30221 .47109 .30487 .47362 .30903 .47225 .30637 .46971 Mtetra
.30637 .46971 .30903 .47225 .31319 .47088 .31053 .46833 Mtetra
.31053 .46833 .31319 .47088 .31736 .4695 .3147 .46695 Mtetra
.3147 .46695 .31736 .4695 .32153 .46812 .31888 .46557 Mtetra
.31888 .46557 .32153 .46812 .32571 .46674 .32307 .46418 Mtetra
.32307 .46418 .32571 .46674 .3299 .46536 .32726 .4628 Mtetra
.32726 .4628 .3299 .46536 .3341 .46397 .33146 .46141 Mtetra
.33146 .46141 .3341 .46397 .3383 .46258 .33566 .46002 Mtetra
.33566 .46002 .3383 .46258 .3425 .46119 .33987 .45862 Mtetra
.877 .778 .748 r
.33987 .45862 .3425 .46119 .34701 .45449 .34439 .45191 Mtetra
.652 .756 .926 r
.34439 .45191 .34701 .45449 .35122 .4531 .3486 .45051 Mtetra
.3486 .45051 .35122 .4531 .35544 .4517 .35283 .44911 Mtetra
.35283 .44911 .35544 .4517 .35967 .4503 .35706 .4477 Mtetra
.35706 .4477 .35967 .4503 .3639 .44889 .3613 .4463 Mtetra
.3613 .4463 .3639 .44889 .36815 .44749 .36555 .44489 Mtetra
.36555 .44489 .36815 .44749 .37239 .44608 .3698 .44348 Mtetra
.3698 .44348 .37239 .44608 .37665 .44467 .37406 .44206 Mtetra
.37406 .44206 .37665 .44467 .38091 .44326 .37832 .44065 Mtetra
.37832 .44065 .38091 .44326 .38518 .44184 .38259 .43923 Mtetra
.38259 .43923 .38518 .44184 .38945 .44043 .38687 .43781 Mtetra
.38687 .43781 .38945 .44043 .39374 .43901 .39116 .43638 Mtetra
.39116 .43638 .39374 .43901 .39802 .43759 .39545 .43496 Mtetra
.39545 .43496 .39802 .43759 .40232 .43617 .39975 .43353 Mtetra
.39975 .43353 .40232 .43617 .40662 .43474 .40406 .4321 Mtetra
.40406 .4321 .40662 .43474 .41093 .43331 .40837 .43067 Mtetra
.40837 .43067 .41093 .43331 .41525 .43188 .41269 .42924 Mtetra
.41269 .42924 .41525 .43188 .41957 .43045 .41702 .4278 Mtetra
.41702 .4278 .41957 .43045 .4239 .42902 .42136 .42636 Mtetra
.963 .653 .387 r
.42136 .42636 .4239 .42902 .42824 .42758 .42421 .47372 Mtetra
.506 .256 .47 r
.42421 .47372 .42824 .42758 .4312 .47492 .42862 .47229 Mtetra
.647 .761 .932 r
.42862 .47229 .4312 .47492 .4365 .4408 .43304 .47086 Mtetra
0 0 .134 r
.43304 .47086 .4365 .4408 .44088 .43936 .43834 .4367 Mtetra
.65 .758 .928 r
.43834 .4367 .44088 .43936 .44526 .43792 .44273 .43526 Mtetra
.44273 .43526 .44526 .43792 .44966 .43648 .44713 .43381 Mtetra
.44713 .43381 .44966 .43648 .45406 .43504 .45153 .43236 Mtetra
.45153 .43236 .45406 .43504 .45846 .43359 .45594 .43091 Mtetra
.45594 .43091 .45846 .43359 .46288 .43214 .46036 .42946 Mtetra
.46036 .42946 .46288 .43214 .4673 .43069 .46479 .428 Mtetra
.46479 .428 .4673 .43069 .47173 .42923 .46922 .42654 Mtetra
.46922 .42654 .47173 .42923 .47617 .42778 .47366 .42508 Mtetra
.47366 .42508 .47617 .42778 .48061 .42632 .47811 .42362 Mtetra
.47811 .42362 .48061 .42632 .48506 .42486 .48257 .42215 Mtetra
.48257 .42215 .48506 .42486 .48952 .42339 .48703 .42068 Mtetra
.48703 .42068 .48952 .42339 .49399 .42193 .4915 .41921 Mtetra
.4915 .41921 .49399 .42193 .49846 .42046 .49598 .41774 Mtetra
.49598 .41774 .49846 .42046 .50294 .41899 .50046 .41626 Mtetra
.50046 .41626 .50294 .41899 .50743 .41751 .50496 .41479 Mtetra
.50496 .41479 .50743 .41751 .51192 .41604 .50946 .4133 Mtetra
.50946 .4133 .51192 .41604 .51643 .41456 .51396 .41182 Mtetra
.51396 .41182 .51643 .41456 .52093 .41308 .51848 .41034 Mtetra
.971 .711 .482 r
.51848 .41034 .52093 .41308 .52545 .42798 .52303 .35012 Mtetra
.536 .322 .536 r
.52303 .35012 .52545 .42798 .52988 .35139 .52748 .3486 Mtetra
.655 .752 .921 r
.52748 .3486 .52988 .35139 .53433 .34988 .53194 .34709 Mtetra
.53194 .34709 .53433 .34988 .53879 .34837 .5364 .34558 Mtetra
.5364 .34558 .53879 .34837 .54325 .34686 .54087 .34406 Mtetra
.54087 .34406 .54325 .34686 .54773 .34534 .54534 .34254 Mtetra
.54534 .34254 .54773 .34534 .5522 .34382 .54983 .34101 Mtetra
.54983 .34101 .5522 .34382 .55669 .3423 .55432 .33949 Mtetra
.55432 .33949 .55669 .3423 .56118 .34078 .55881 .33796 Mtetra
.55881 .33796 .56118 .34078 .56568 .33925 .56332 .33643 Mtetra
.56332 .33643 .56568 .33925 .57019 .33773 .56783 .3349 Mtetra
.56783 .3349 .57019 .33773 .57471 .3362 .57235 .33336 Mtetra
.57235 .33336 .57471 .3362 .57923 .33466 .57688 .33183 Mtetra
.57688 .33183 .57923 .33466 .58376 .33313 .58141 .33028 Mtetra
.58141 .33028 .58376 .33313 .5883 .33159 .58596 .32874 Mtetra
.58596 .32874 .5883 .33159 .59284 .33005 .59051 .3272 Mtetra
.59051 .3272 .59284 .33005 .59739 .3285 .59506 .32565 Mtetra
.59506 .32565 .59739 .3285 .60273 .35889 .59963 .3241 Mtetra
0 0 .448 r
.59963 .3241 .60273 .35889 .60735 .35735 .605 .35451 Mtetra
.653 .755 .925 r
.605 .35451 .60735 .35735 .61197 .35581 .60963 .35296 Mtetra
.60963 .35296 .61197 .35581 .6166 .35427 .61427 .35142 Mtetra
.61427 .35142 .6166 .35427 .62123 .35272 .61891 .34987 Mtetra
.61891 .34987 .62123 .35272 .62588 .35118 .62356 .34831 Mtetra
.62356 .34831 .62588 .35118 .63053 .34963 .62821 .34676 Mtetra
.62821 .34676 .63053 .34963 .63519 .34807 .63288 .3452 Mtetra
.978 .692 .406 r
.63288 .3452 .63519 .34807 .63986 .34652 .63225 .19457 Mtetra
.531 .31 .524 r
.63225 .19457 .63986 .34652 .6389 .19593 .6367 .19297 Mtetra
.664 .741 .908 r
.6367 .19297 .6389 .19593 .64336 .19433 .64117 .19136 Mtetra
.64117 .19136 .64336 .19433 .64783 .19272 .64564 .18974 Mtetra
.64564 .18974 .64783 .19272 .6523 .19111 .65012 .18813 Mtetra
.65012 .18813 .6523 .19111 .65678 .1895 .6546 .18651 Mtetra
.6546 .18651 .65678 .1895 .66127 .18788 .65909 .18489 Mtetra
.65909 .18489 .66127 .18788 .66576 .18626 .66359 .18327 Mtetra
.66359 .18327 .66576 .18626 .67026 .18464 .6681 .18164 Mtetra
.6681 .18164 .67026 .18464 .67477 .18302 .67261 .18001 Mtetra
.67261 .18001 .67477 .18302 .67929 .18139 .67713 .17838 Mtetra
.67713 .17838 .67929 .18139 .68381 .17976 .68166 .17675 Mtetra
.68166 .17675 .68381 .17976 .68834 .17813 .68619 .17511 Mtetra
.68619 .17511 .68834 .17813 .69288 .1765 .69073 .17347 Mtetra
.69073 .17347 .69288 .1765 .69742 .17486 .69528 .17183 Mtetra
.69528 .17183 .69742 .17486 .70197 .17322 .69984 .17019 Mtetra
.69984 .17019 .70197 .17322 .70653 .17158 .70441 .16854 Mtetra
.70441 .16854 .70653 .17158 .7111 .16993 .70898 .16689 Mtetra
.70898 .16689 .7111 .16993 .71567 .16829 .71356 .16524 Mtetra
.71356 .16524 .71567 .16829 .72025 .16664 .71814 .16358 Mtetra
.71814 .16358 .72025 .16664 .72484 .16498 .72274 .16193 Mtetra
.72274 .16193 .72484 .16498 .72944 .16333 .72734 .16027 Mtetra
.72734 .16027 .72944 .16333 .73404 .16167 .73195 .1586 Mtetra
.73195 .1586 .73404 .16167 .73865 .16001 .73656 .15694 Mtetra
.73656 .15694 .73865 .16001 .74327 .15835 .74118 .15527 Mtetra
.74118 .15527 .74327 .15835 .7479 .15668 .74582 .1536 Mtetra
.74582 .1536 .7479 .15668 .75253 .15501 .75045 .15192 Mtetra
.75045 .15192 .75253 .15501 .75717 .15334 .7551 .15025 Mtetra
.7551 .15025 .75717 .15334 .76182 .15167 .75975 .14857 Mtetra
.75975 .14857 .76182 .15167 .76647 .14999 .76441 .14689 Mtetra
.76441 .14689 .76647 .14999 .77114 .14831 .76908 .1452 Mtetra
.76908 .1452 .77114 .14831 .77581 .14663 .77376 .14352 Mtetra
.77376 .14352 .77581 .14663 .78049 .14494 .77844 .14183 Mtetra
.1492 .36542 .15187 .3679 .15559 .36656 .15293 .36407 Mtetra
.15293 .36407 .15559 .36656 .15932 .36521 .15666 .36272 Mtetra
.15666 .36272 .15932 .36521 .16306 .36387 .1604 .36137 Mtetra
.1604 .36137 .16306 .36387 .1668 .36252 .16414 .36002 Mtetra
.16414 .36002 .1668 .36252 .17054 .36116 .16789 .35866 Mtetra
.16789 .35866 .17054 .36116 .1743 .35981 .17165 .35731 Mtetra
.17165 .35731 .1743 .35981 .17805 .35845 .17541 .35595 Mtetra
.17541 .35595 .17805 .35845 .18182 .3571 .17918 .35458 Mtetra
.17918 .35458 .18182 .3571 .18559 .35574 .18295 .35322 Mtetra
.18295 .35322 .18559 .35574 .18936 .35437 .18672 .35186 Mtetra
.18672 .35186 .18936 .35437 .19314 .35301 .19051 .35049 Mtetra
.19051 .35049 .19314 .35301 .19692 .35165 .1943 .34912 Mtetra
.1943 .34912 .19692 .35165 .20072 .35028 .19809 .34775 Mtetra
.19809 .34775 .20072 .35028 .20451 .34891 .20189 .34637 Mtetra
.20189 .34637 .20451 .34891 .20831 .34754 .20569 .345 Mtetra
.20569 .345 .20831 .34754 .21212 .34616 .20951 .34362 Mtetra
.20951 .34362 .21212 .34616 .21593 .34479 .21332 .34224 Mtetra
.21332 .34224 .21593 .34479 .21975 .34341 .21714 .34086 Mtetra
.21714 .34086 .21975 .34341 .22358 .34203 .22097 .33948 Mtetra
.22097 .33948 .22358 .34203 .22741 .34065 .2248 .33809 Mtetra
.2248 .33809 .22741 .34065 .23124 .33926 .22864 .3367 Mtetra
.22864 .3367 .23124 .33926 .23508 .33788 .23249 .33531 Mtetra
.23249 .33531 .23508 .33788 .23893 .33649 .23634 .33392 Mtetra
.23634 .33392 .23893 .33649 .24278 .3351 .24019 .33253 Mtetra
.24019 .33253 .24278 .3351 .24664 .33371 .24406 .33113 Mtetra
.24406 .33113 .24664 .33371 .25051 .33231 .24792 .32973 Mtetra
.949 .68 .493 r
.24792 .32973 .25051 .33231 .2406 .49148 .23787 .489 Mtetra
.651 .757 .927 r
.23787 .489 .2406 .49148 .24466 .49013 .24194 .48765 Mtetra
.24194 .48765 .24466 .49013 .24873 .48879 .24601 .4863 Mtetra
.24601 .4863 .24873 .48879 .25281 .48744 .25009 .48494 Mtetra
.25009 .48494 .25281 .48744 .25689 .48609 .25417 .48359 Mtetra
.25417 .48359 .25689 .48609 .26098 .48474 .25827 .48223 Mtetra
.25827 .48223 .26098 .48474 .26507 .48338 .26236 .48087 Mtetra
.26236 .48087 .26507 .48338 .26917 .48202 .26647 .47951 Mtetra
.26647 .47951 .26917 .48202 .27328 .48066 .27058 .47815 Mtetra
.27058 .47815 .27328 .48066 .27739 .4793 .27469 .47678 Mtetra
.27469 .47678 .27739 .4793 .28151 .47794 .27882 .47542 Mtetra
.27882 .47542 .28151 .47794 .28564 .47657 .28295 .47405 Mtetra
.28295 .47405 .28564 .47657 .28977 .47521 .28709 .47267 Mtetra
.28709 .47267 .28977 .47521 .29391 .47384 .29123 .4713 Mtetra
.29123 .4713 .29391 .47384 .29806 .47246 .29538 .46992 Mtetra
.29538 .46992 .29806 .47246 .30221 .47109 .29953 .46855 Mtetra
.29953 .46855 .30221 .47109 .30637 .46971 .3037 .46717 Mtetra
.3037 .46717 .30637 .46971 .31053 .46833 .30787 .46578 Mtetra
.30787 .46578 .31053 .46833 .3147 .46695 .31204 .4644 Mtetra
.31204 .4644 .3147 .46695 .31888 .46557 .31622 .46301 Mtetra
.31622 .46301 .31888 .46557 .32307 .46418 .32041 .46162 Mtetra
.32041 .46162 .32307 .46418 .32726 .4628 .32461 .46023 Mtetra
.32461 .46023 .32726 .4628 .33146 .46141 .32881 .45884 Mtetra
.32881 .45884 .33146 .46141 .33566 .46002 .33302 .45744 Mtetra
.33302 .45744 .33566 .46002 .33987 .45862 .33724 .45604 Mtetra
.877 .778 .748 r
.33724 .45604 .33987 .45862 .34439 .45191 .34176 .44933 Mtetra
.652 .756 .926 r
.34176 .44933 .34439 .45191 .3486 .45051 .34598 .44792 Mtetra
.34598 .44792 .3486 .45051 .35283 .44911 .35021 .44651 Mtetra
.35021 .44651 .35283 .44911 .35706 .4477 .35445 .4451 Mtetra
.35445 .4451 .35706 .4477 .3613 .4463 .35869 .44369 Mtetra
.35869 .44369 .3613 .4463 .36555 .44489 .36294 .44228 Mtetra
.36294 .44228 .36555 .44489 .3698 .44348 .36719 .44086 Mtetra
.36719 .44086 .3698 .44348 .37406 .44206 .37146 .43945 Mtetra
.37146 .43945 .37406 .44206 .37832 .44065 .37573 .43803 Mtetra
.37573 .43803 .37832 .44065 .38259 .43923 .38 .4366 Mtetra
.38 .4366 .38259 .43923 .38687 .43781 .38429 .43518 Mtetra
.38429 .43518 .38687 .43781 .39116 .43638 .38858 .43375 Mtetra
.38858 .43375 .39116 .43638 .39545 .43496 .39287 .43232 Mtetra
.39287 .43232 .39545 .43496 .39975 .43353 .39718 .43089 Mtetra
.39718 .43089 .39975 .43353 .40406 .4321 .40149 .42946 Mtetra
.40149 .42946 .40406 .4321 .40837 .43067 .40581 .42802 Mtetra
.40581 .42802 .40837 .43067 .41269 .42924 .41013 .42658 Mtetra
.41013 .42658 .41269 .42924 .41702 .4278 .41447 .42514 Mtetra
.963 .653 .389 r
.41447 .42514 .41702 .4278 .42136 .42636 .41721 .47251 Mtetra
.505 .255 .469 r
.41721 .47251 .42136 .42636 .42421 .47372 .42162 .47108 Mtetra
.647 .761 .932 r
.42162 .47108 .42421 .47372 .42862 .47229 .42604 .46965 Mtetra
.42604 .46965 .42862 .47229 .43304 .47086 .43046 .46822 Mtetra
.43046 .46822 .43304 .47086 .43834 .4367 .43489 .46679 Mtetra
0 0 .134 r
.43489 .46679 .43834 .4367 .44273 .43526 .44018 .43259 Mtetra
.65 .758 .928 r
.44018 .43259 .44273 .43526 .44713 .43381 .44459 .43113 Mtetra
.44459 .43113 .44713 .43381 .45153 .43236 .449 .42968 Mtetra
.449 .42968 .45153 .43236 .45594 .43091 .45341 .42822 Mtetra
.45341 .42822 .45594 .43091 .46036 .42946 .45784 .42677 Mtetra
.45784 .42677 .46036 .42946 .46479 .428 .46227 .42531 Mtetra
.46227 .42531 .46479 .428 .46922 .42654 .46671 .42384 Mtetra
.46671 .42384 .46922 .42654 .47366 .42508 .47115 .42238 Mtetra
.47115 .42238 .47366 .42508 .47811 .42362 .47561 .42091 Mtetra
.47561 .42091 .47811 .42362 .48257 .42215 .48007 .41944 Mtetra
.48007 .41944 .48257 .42215 .48703 .42068 .48453 .41797 Mtetra
.48453 .41797 .48703 .42068 .4915 .41921 .48901 .41649 Mtetra
.48901 .41649 .4915 .41921 .49598 .41774 .49349 .41501 Mtetra
.49349 .41501 .49598 .41774 .50046 .41626 .49798 .41353 Mtetra
.49798 .41353 .50046 .41626 .50496 .41479 .50248 .41205 Mtetra
.50248 .41205 .50496 .41479 .50946 .4133 .50698 .41057 Mtetra
.50698 .41057 .50946 .4133 .51396 .41182 .5115 .40908 Mtetra
.5115 .40908 .51396 .41182 .51848 .41034 .51601 .40759 Mtetra
.971 .711 .482 r
.51601 .40759 .51848 .41034 .52303 .35012 .52062 .34732 Mtetra
.655 .752 .921 r
.52062 .34732 .52303 .35012 .52748 .3486 .52507 .34581 Mtetra
.52507 .34581 .52748 .3486 .53194 .34709 .52953 .34429 Mtetra
.52953 .34429 .53194 .34709 .5364 .34558 .534 .34277 Mtetra
.534 .34277 .5364 .34558 .54087 .34406 .53847 .34125 Mtetra
.53847 .34125 .54087 .34406 .54534 .34254 .54295 .33972 Mtetra
.54295 .33972 .54534 .34254 .54983 .34101 .54744 .3382 Mtetra
.54744 .3382 .54983 .34101 .55432 .33949 .55194 .33667 Mtetra
.55194 .33667 .55432 .33949 .55881 .33796 .55644 .33513 Mtetra
.55644 .33513 .55881 .33796 .56332 .33643 .56095 .3336 Mtetra
.56095 .3336 .56332 .33643 .56783 .3349 .56547 .33206 Mtetra
.56547 .33206 .56783 .3349 .57235 .33336 .56999 .33052 Mtetra
.56999 .33052 .57235 .33336 .57688 .33183 .57452 .32898 Mtetra
.57452 .32898 .57688 .33183 .58141 .33028 .57906 .32743 Mtetra
.57906 .32743 .58141 .33028 .58596 .32874 .58361 .32589 Mtetra
.58361 .32589 .58596 .32874 .59051 .3272 .58816 .32434 Mtetra
.58816 .32434 .59051 .3272 .59506 .32565 .59273 .32278 Mtetra
.59273 .32278 .59506 .32565 .59963 .3241 .59729 .32123 Mtetra
.59729 .32123 .59963 .3241 .605 .35451 .60187 .31967 Mtetra
.549 .352 .565 r
.60187 .31967 .605 .35451 .60963 .35296 .60646 .31811 Mtetra
.003 0 .45 r
.60646 .31811 .60963 .35296 .61427 .35142 .61193 .34855 Mtetra
.653 .755 .925 r
.61193 .34855 .61427 .35142 .61891 .34987 .61657 .347 Mtetra
.61657 .347 .61891 .34987 .62356 .34831 .62123 .34544 Mtetra
.62123 .34544 .62356 .34831 .62821 .34676 .62589 .34388 Mtetra
.978 .692 .408 r
.62589 .34388 .62821 .34676 .63288 .3452 .62558 .19321 Mtetra
.531 .31 .524 r
.62558 .19321 .63288 .3452 .63225 .19457 .63004 .1916 Mtetra
.664 .741 .908 r
.63004 .1916 .63225 .19457 .6367 .19297 .6345 .18999 Mtetra
.6345 .18999 .6367 .19297 .64117 .19136 .63897 .18838 Mtetra
.63897 .18838 .64117 .19136 .64564 .18974 .64344 .18676 Mtetra
.64344 .18676 .64564 .18974 .65012 .18813 .64792 .18514 Mtetra
.64792 .18514 .65012 .18813 .6546 .18651 .65241 .18352 Mtetra
.65241 .18352 .6546 .18651 .65909 .18489 .65691 .18189 Mtetra
.65691 .18189 .65909 .18489 .66359 .18327 .66141 .18026 Mtetra
.66141 .18026 .66359 .18327 .6681 .18164 .66592 .17863 Mtetra
.66592 .17863 .6681 .18164 .67261 .18001 .67044 .177 Mtetra
.67044 .177 .67261 .18001 .67713 .17838 .67497 .17536 Mtetra
.67497 .17536 .67713 .17838 .68166 .17675 .6795 .17372 Mtetra
.6795 .17372 .68166 .17675 .68619 .17511 .68404 .17208 Mtetra
.68404 .17208 .68619 .17511 .69073 .17347 .68859 .17044 Mtetra
.68859 .17044 .69073 .17347 .69528 .17183 .69314 .16879 Mtetra
.69314 .16879 .69528 .17183 .69984 .17019 .6977 .16714 Mtetra
.6977 .16714 .69984 .17019 .70441 .16854 .70227 .16549 Mtetra
.70227 .16549 .70441 .16854 .70898 .16689 .70685 .16384 Mtetra
.70685 .16384 .70898 .16689 .71356 .16524 .71143 .16218 Mtetra
.71143 .16218 .71356 .16524 .71814 .16358 .71602 .16052 Mtetra
.71602 .16052 .71814 .16358 .72274 .16193 .72062 .15886 Mtetra
.72062 .15886 .72274 .16193 .72734 .16027 .72523 .15719 Mtetra
.72523 .15719 .72734 .16027 .73195 .1586 .72984 .15553 Mtetra
.72984 .15553 .73195 .1586 .73656 .15694 .73446 .15386 Mtetra
.73446 .15386 .73656 .15694 .74118 .15527 .73909 .15218 Mtetra
.73909 .15218 .74118 .15527 .74582 .1536 .74373 .15051 Mtetra
.74373 .15051 .74582 .1536 .75045 .15192 .74837 .14883 Mtetra
.74837 .14883 .75045 .15192 .7551 .15025 .75302 .14715 Mtetra
.75302 .14715 .7551 .15025 .75975 .14857 .75768 .14546 Mtetra
.75768 .14546 .75975 .14857 .76441 .14689 .76235 .14378 Mtetra
.76235 .14378 .76441 .14689 .76908 .1452 .76702 .14209 Mtetra
.76702 .14209 .76908 .1452 .77376 .14352 .77171 .14039 Mtetra
.77171 .14039 .77376 .14352 .77844 .14183 .77639 .1387 Mtetra
.14652 .36293 .1492 .36542 .15293 .36407 .15026 .36158 Mtetra
.15026 .36158 .15293 .36407 .15666 .36272 .15399 .36023 Mtetra
.15399 .36023 .15666 .36272 .1604 .36137 .15773 .35887 Mtetra
.15773 .35887 .1604 .36137 .16414 .36002 .16148 .35751 Mtetra
.16148 .35751 .16414 .36002 .16789 .35866 .16523 .35615 Mtetra
.16523 .35615 .16789 .35866 .17165 .35731 .16899 .35479 Mtetra
.16899 .35479 .17165 .35731 .17541 .35595 .17276 .35343 Mtetra
.17276 .35343 .17541 .35595 .17918 .35458 .17653 .35207 Mtetra
.17653 .35207 .17918 .35458 .18295 .35322 .1803 .3507 Mtetra
.1803 .3507 .18295 .35322 .18672 .35186 .18408 .34933 Mtetra
.18408 .34933 .18672 .35186 .19051 .35049 .18787 .34796 Mtetra
.18787 .34796 .19051 .35049 .1943 .34912 .19166 .34658 Mtetra
.19166 .34658 .1943 .34912 .19809 .34775 .19546 .34521 Mtetra
.19546 .34521 .19809 .34775 .20189 .34637 .19926 .34383 Mtetra
.19926 .34383 .20189 .34637 .20569 .345 .20307 .34245 Mtetra
.20307 .34245 .20569 .345 .20951 .34362 .20688 .34107 Mtetra
.20688 .34107 .20951 .34362 .21332 .34224 .2107 .33969 Mtetra
.2107 .33969 .21332 .34224 .21714 .34086 .21453 .3383 Mtetra
.21453 .3383 .21714 .34086 .22097 .33948 .21836 .33692 Mtetra
.21836 .33692 .22097 .33948 .2248 .33809 .22219 .33553 Mtetra
.22219 .33553 .2248 .33809 .22864 .3367 .22604 .33414 Mtetra
.22604 .33414 .22864 .3367 .23249 .33531 .22988 .33274 Mtetra
.22988 .33274 .23249 .33531 .23634 .33392 .23374 .33135 Mtetra
.23374 .33135 .23634 .33392 .24019 .33253 .2376 .32995 Mtetra
.2376 .32995 .24019 .33253 .24406 .33113 .24146 .32855 Mtetra
.24146 .32855 .24406 .33113 .24792 .32973 .24533 .32715 Mtetra
.24533 .32715 .24792 .32973 .23787 .489 .24921 .32574 Mtetra
0 0 .176 r
.24921 .32574 .23787 .489 .24194 .48765 .2392 .48515 Mtetra
.651 .757 .927 r
.2392 .48515 .24194 .48765 .24601 .4863 .24328 .4838 Mtetra
.24328 .4838 .24601 .4863 .25009 .48494 .24736 .48244 Mtetra
.24736 .48244 .25009 .48494 .25417 .48359 .25145 .48108 Mtetra
.25145 .48108 .25417 .48359 .25827 .48223 .25555 .47972 Mtetra
.25555 .47972 .25827 .48223 .26236 .48087 .25965 .47836 Mtetra
.25965 .47836 .26236 .48087 .26647 .47951 .26375 .47699 Mtetra
.26375 .47699 .26647 .47951 .27058 .47815 .26787 .47563 Mtetra
.26787 .47563 .27058 .47815 .27469 .47678 .27199 .47426 Mtetra
.27199 .47426 .27469 .47678 .27882 .47542 .27612 .47289 Mtetra
.27612 .47289 .27882 .47542 .28295 .47405 .28025 .47151 Mtetra
.28025 .47151 .28295 .47405 .28709 .47267 .28439 .47014 Mtetra
.28439 .47014 .28709 .47267 .29123 .4713 .28854 .46876 Mtetra
.28854 .46876 .29123 .4713 .29538 .46992 .29269 .46738 Mtetra
.29269 .46738 .29538 .46992 .29953 .46855 .29685 .466 Mtetra
.29685 .466 .29953 .46855 .3037 .46717 .30102 .46461 Mtetra
.30102 .46461 .3037 .46717 .30787 .46578 .30519 .46322 Mtetra
.30519 .46322 .30787 .46578 .31204 .4644 .30937 .46184 Mtetra
.30937 .46184 .31204 .4644 .31622 .46301 .31356 .46044 Mtetra
.31356 .46044 .31622 .46301 .32041 .46162 .31775 .45905 Mtetra
.31775 .45905 .32041 .46162 .32461 .46023 .32195 .45766 Mtetra
.32195 .45766 .32461 .46023 .32881 .45884 .32616 .45626 Mtetra
.32616 .45626 .32881 .45884 .33302 .45744 .33037 .45486 Mtetra
.33037 .45486 .33302 .45744 .33724 .45604 .33459 .45346 Mtetra
.877 .778 .748 r
.33459 .45346 .33724 .45604 .34176 .44933 .33912 .44673 Mtetra
.652 .756 .926 r
.33912 .44673 .34176 .44933 .34598 .44792 .34335 .44532 Mtetra
.34335 .44532 .34598 .44792 .35021 .44651 .34758 .44391 Mtetra
.34758 .44391 .35021 .44651 .35445 .4451 .35182 .4425 Mtetra
.35182 .4425 .35445 .4451 .35869 .44369 .35607 .44108 Mtetra
.35607 .44108 .35869 .44369 .36294 .44228 .36032 .43966 Mtetra
.36032 .43966 .36294 .44228 .36719 .44086 .36458 .43825 Mtetra
.36458 .43825 .36719 .44086 .37146 .43945 .36885 .43682 Mtetra
.36885 .43682 .37146 .43945 .37573 .43803 .37312 .4354 Mtetra
.37312 .4354 .37573 .43803 .38 .4366 .3774 .43397 Mtetra
.3774 .43397 .38 .4366 .38429 .43518 .38169 .43254 Mtetra
.38169 .43254 .38429 .43518 .38858 .43375 .38599 .43111 Mtetra
.38599 .43111 .38858 .43375 .39287 .43232 .39029 .42968 Mtetra
.39029 .42968 .39287 .43232 .39718 .43089 .3946 .42824 Mtetra
.3946 .42824 .39718 .43089 .40149 .42946 .39891 .4268 Mtetra
.39891 .4268 .40149 .42946 .40581 .42802 .40324 .42536 Mtetra
.40324 .42536 .40581 .42802 .41013 .42658 .40756 .42392 Mtetra
.963 .653 .39 r
.40756 .42392 .41013 .42658 .41447 .42514 .4102 .4713 Mtetra
.505 .254 .468 r
.4102 .4713 .41447 .42514 .41721 .47251 .41461 .46987 Mtetra
.647 .761 .932 r
.41461 .46987 .41721 .47251 .42162 .47108 .41902 .46844 Mtetra
.41902 .46844 .42162 .47108 .42604 .46965 .42344 .46701 Mtetra
.42344 .46701 .42604 .46965 .43046 .46822 .42787 .46557 Mtetra
.42787 .46557 .43046 .46822 .43489 .46679 .43231 .46413 Mtetra
.43231 .46413 .43489 .46679 .44018 .43259 .43675 .46269 Mtetra
0 0 .134 r
.43675 .46269 .44018 .43259 .44459 .43113 .44204 .42845 Mtetra
.65 .758 .928 r
.44204 .42845 .44459 .43113 .449 .42968 .44645 .42699 Mtetra
.44645 .42699 .449 .42968 .45341 .42822 .45088 .42553 Mtetra
.45088 .42553 .45341 .42822 .45784 .42677 .4553 .42407 Mtetra
.4553 .42407 .45784 .42677 .46227 .42531 .45974 .4226 Mtetra
.45974 .4226 .46227 .42531 .46671 .42384 .46418 .42113 Mtetra
.46418 .42113 .46671 .42384 .47115 .42238 .46863 .41966 Mtetra
.46863 .41966 .47115 .42238 .47561 .42091 .47309 .41819 Mtetra
.47309 .41819 .47561 .42091 .48007 .41944 .47756 .41672 Mtetra
.47756 .41672 .48007 .41944 .48453 .41797 .48203 .41524 Mtetra
.48203 .41524 .48453 .41797 .48901 .41649 .48651 .41376 Mtetra
.48651 .41376 .48901 .41649 .49349 .41501 .491 .41228 Mtetra
.491 .41228 .49349 .41501 .49798 .41353 .49549 .41079 Mtetra
.49549 .41079 .49798 .41353 .50248 .41205 .49999 .40931 Mtetra
.49999 .40931 .50248 .41205 .50698 .41057 .5045 .40782 Mtetra
.5045 .40782 .50698 .41057 .5115 .40908 .50902 .40633 Mtetra
.50902 .40633 .5115 .40908 .51601 .40759 .51354 .40483 Mtetra
.971 .711 .482 r
.51354 .40483 .51601 .40759 .52062 .34732 .5182 .34453 Mtetra
.655 .752 .921 r
.5182 .34453 .52062 .34732 .52507 .34581 .52266 .34301 Mtetra
.52266 .34301 .52507 .34581 .52953 .34429 .52712 .34148 Mtetra
.52712 .34148 .52953 .34429 .534 .34277 .53159 .33996 Mtetra
.53159 .33996 .534 .34277 .53847 .34125 .53607 .33843 Mtetra
.53607 .33843 .53847 .34125 .54295 .33972 .54055 .3369 Mtetra
.54055 .3369 .54295 .33972 .54744 .3382 .54505 .33537 Mtetra
.54505 .33537 .54744 .3382 .55194 .33667 .54955 .33384 Mtetra
.54955 .33384 .55194 .33667 .55644 .33513 .55405 .3323 Mtetra
.55405 .3323 .55644 .33513 .56095 .3336 .55857 .33076 Mtetra
.55857 .33076 .56095 .3336 .56547 .33206 .56309 .32922 Mtetra
.56309 .32922 .56547 .33206 .56999 .33052 .56762 .32767 Mtetra
.56762 .32767 .56999 .33052 .57452 .32898 .57216 .32613 Mtetra
.57216 .32613 .57452 .32898 .57906 .32743 .5767 .32458 Mtetra
.5767 .32458 .57906 .32743 .58361 .32589 .58126 .32302 Mtetra
.58126 .32302 .58361 .32589 .58816 .32434 .58581 .32147 Mtetra
.58581 .32147 .58816 .32434 .59273 .32278 .59038 .31991 Mtetra
.59038 .31991 .59273 .32278 .59729 .32123 .59496 .31835 Mtetra
.59496 .31835 .59729 .32123 .60187 .31967 .59954 .31679 Mtetra
.59954 .31679 .60187 .31967 .60646 .31811 .60413 .31522 Mtetra
.60413 .31522 .60646 .31811 .61193 .34855 .60872 .31366 Mtetra
.549 .351 .565 r
.60872 .31366 .61193 .34855 .61657 .347 .61333 .31209 Mtetra
.005 0 .451 r
.61333 .31209 .61657 .347 .62123 .34544 .61889 .34256 Mtetra
.978 .692 .41 r
.61889 .34256 .62123 .34544 .62589 .34388 .61891 .19185 Mtetra
.53 .309 .523 r
.61891 .19185 .62589 .34388 .62558 .19321 .62336 .19024 Mtetra
.664 .741 .908 r
.62336 .19024 .62558 .19321 .63004 .1916 .62782 .18863 Mtetra
.62782 .18863 .63004 .1916 .6345 .18999 .63228 .18701 Mtetra
.63228 .18701 .6345 .18999 .63897 .18838 .63676 .18539 Mtetra
.63676 .18539 .63897 .18838 .64344 .18676 .64124 .18377 Mtetra
.64124 .18377 .64344 .18676 .64792 .18514 .64572 .18214 Mtetra
.64572 .18214 .64792 .18514 .65241 .18352 .65022 .18051 Mtetra
.65022 .18051 .65241 .18352 .65691 .18189 .65472 .17888 Mtetra
.65472 .17888 .65691 .18189 .66141 .18026 .65923 .17725 Mtetra
.65923 .17725 .66141 .18026 .66592 .17863 .66374 .17561 Mtetra
.66374 .17561 .66592 .17863 .67044 .177 .66827 .17398 Mtetra
.66827 .17398 .67044 .177 .67497 .17536 .6728 .17234 Mtetra
.6728 .17234 .67497 .17536 .6795 .17372 .67734 .17069 Mtetra
.67734 .17069 .6795 .17372 .68404 .17208 .68188 .16905 Mtetra
.68188 .16905 .68404 .17208 .68859 .17044 .68643 .1674 Mtetra
.68643 .1674 .68859 .17044 .69314 .16879 .69099 .16575 Mtetra
.69099 .16575 .69314 .16879 .6977 .16714 .69556 .16409 Mtetra
.69556 .16409 .6977 .16714 .70227 .16549 .70013 .16244 Mtetra
.70013 .16244 .70227 .16549 .70685 .16384 .70472 .16078 Mtetra
.70472 .16078 .70685 .16384 .71143 .16218 .7093 .15911 Mtetra
.7093 .15911 .71143 .16218 .71602 .16052 .7139 .15745 Mtetra
.7139 .15745 .71602 .16052 .72062 .15886 .7185 .15578 Mtetra
.7185 .15578 .72062 .15886 .72523 .15719 .72312 .15411 Mtetra
.72312 .15411 .72523 .15719 .72984 .15553 .72774 .15244 Mtetra
.72774 .15244 .72984 .15553 .73446 .15386 .73236 .15076 Mtetra
.73236 .15076 .73446 .15386 .73909 .15218 .737 .14909 Mtetra
.737 .14909 .73909 .15218 .74373 .15051 .74164 .14741 Mtetra
.74164 .14741 .74373 .15051 .74837 .14883 .74629 .14572 Mtetra
.74629 .14572 .74837 .14883 .75302 .14715 .75094 .14404 Mtetra
.75094 .14404 .75302 .14715 .75768 .14546 .75561 .14235 Mtetra
.75561 .14235 .75768 .14546 .76235 .14378 .76028 .14065 Mtetra
.76028 .14065 .76235 .14378 .76702 .14209 .76496 .13896 Mtetra
.76496 .13896 .76702 .14209 .77171 .14039 .76964 .13726 Mtetra
.76964 .13726 .77171 .14039 .77639 .1387 .77434 .13556 Mtetra
.14384 .36043 .14652 .36293 .15026 .36158 .14758 .35908 Mtetra
.14758 .35908 .15026 .36158 .15399 .36023 .15132 .35772 Mtetra
.15132 .35772 .15399 .36023 .15773 .35887 .15506 .35636 Mtetra
.15506 .35636 .15773 .35887 .16148 .35751 .15881 .355 Mtetra
.15881 .355 .16148 .35751 .16523 .35615 .16257 .35364 Mtetra
.16257 .35364 .16523 .35615 .16899 .35479 .16633 .35228 Mtetra
.16633 .35228 .16899 .35479 .17276 .35343 .1701 .35091 Mtetra
.1701 .35091 .17276 .35343 .17653 .35207 .17387 .34954 Mtetra
.17387 .34954 .17653 .35207 .1803 .3507 .17765 .34817 Mtetra
.17765 .34817 .1803 .3507 .18408 .34933 .18143 .3468 Mtetra
.18143 .3468 .18408 .34933 .18787 .34796 .18522 .34542 Mtetra
.18522 .34542 .18787 .34796 .19166 .34658 .18902 .34404 Mtetra
.18902 .34404 .19166 .34658 .19546 .34521 .19282 .34267 Mtetra
.19282 .34267 .19546 .34521 .19926 .34383 .19662 .34128 Mtetra
.19662 .34128 .19926 .34383 .20307 .34245 .20043 .3399 Mtetra
.20043 .3399 .20307 .34245 .20688 .34107 .20425 .33852 Mtetra
.20425 .33852 .20688 .34107 .2107 .33969 .20807 .33713 Mtetra
.20807 .33713 .2107 .33969 .21453 .3383 .2119 .33574 Mtetra
.2119 .33574 .21453 .3383 .21836 .33692 .21574 .33435 Mtetra
.21574 .33435 .21836 .33692 .22219 .33553 .21958 .33296 Mtetra
.21958 .33296 .22219 .33553 .22604 .33414 .22342 .33156 Mtetra
.22342 .33156 .22604 .33414 .22988 .33274 .22727 .33016 Mtetra
.22727 .33016 .22988 .33274 .23374 .33135 .23113 .32876 Mtetra
.23113 .32876 .23374 .33135 .2376 .32995 .23499 .32736 Mtetra
.23499 .32736 .2376 .32995 .24146 .32855 .23886 .32596 Mtetra
.23886 .32596 .24146 .32855 .24533 .32715 .24274 .32455 Mtetra
.24274 .32455 .24533 .32715 .24921 .32574 .24662 .32315 Mtetra
.949 .68 .492 r
.24662 .32315 .24921 .32574 .2392 .48515 .23646 .48265 Mtetra
.651 .757 .927 r
.23646 .48265 .2392 .48515 .24328 .4838 .24054 .48129 Mtetra
.24054 .48129 .24328 .4838 .24736 .48244 .24463 .47993 Mtetra
.24463 .47993 .24736 .48244 .25145 .48108 .24872 .47857 Mtetra
.24872 .47857 .25145 .48108 .25555 .47972 .25282 .4772 Mtetra
.25282 .4772 .25555 .47972 .25965 .47836 .25692 .47584 Mtetra
.25692 .47584 .25965 .47836 .26375 .47699 .26103 .47447 Mtetra
.26103 .47447 .26375 .47699 .26787 .47563 .26515 .4731 Mtetra
.26515 .4731 .26787 .47563 .27199 .47426 .26928 .47172 Mtetra
.26928 .47172 .27199 .47426 .27612 .47289 .27341 .47035 Mtetra
.27341 .47035 .27612 .47289 .28025 .47151 .27755 .46897 Mtetra
.27755 .46897 .28025 .47151 .28439 .47014 .28169 .46759 Mtetra
.28169 .46759 .28439 .47014 .28854 .46876 .28584 .46621 Mtetra
.28584 .46621 .28854 .46876 .29269 .46738 .29 .46482 Mtetra
.29 .46482 .29269 .46738 .29685 .466 .29416 .46344 Mtetra
.29416 .46344 .29685 .466 .30102 .46461 .29833 .46205 Mtetra
.29833 .46205 .30102 .46461 .30519 .46322 .30251 .46066 Mtetra
.30251 .46066 .30519 .46322 .30937 .46184 .3067 .45927 Mtetra
.3067 .45927 .30937 .46184 .31356 .46044 .31089 .45787 Mtetra
.31089 .45787 .31356 .46044 .31775 .45905 .31508 .45647 Mtetra
.31508 .45647 .31775 .45905 .32195 .45766 .31929 .45507 Mtetra
.31929 .45507 .32195 .45766 .32616 .45626 .3235 .45367 Mtetra
.3235 .45367 .32616 .45626 .33037 .45486 .32772 .45227 Mtetra
.32772 .45227 .33037 .45486 .33459 .45346 .33194 .45086 Mtetra
.877 .778 .748 r
.33194 .45086 .33459 .45346 .33912 .44673 .33648 .44413 Mtetra
.652 .756 .926 r
.33648 .44413 .33912 .44673 .34335 .44532 .34071 .44272 Mtetra
.34071 .44272 .34335 .44532 .34758 .44391 .34495 .4413 Mtetra
.34495 .4413 .34758 .44391 .35182 .4425 .34919 .43988 Mtetra
.34919 .43988 .35182 .4425 .35607 .44108 .35344 .43846 Mtetra
.35344 .43846 .35607 .44108 .36032 .43966 .3577 .43704 Mtetra
.3577 .43704 .36032 .43966 .36458 .43825 .36196 .43562 Mtetra
.952 .722 .554 r
.36196 .43562 .36458 .43825 .36885 .43682 .36778 .40253 Mtetra
.548 .35 .564 r
.36778 .40253 .36885 .43682 .37312 .4354 .37202 .40109 Mtetra
.37202 .40109 .37312 .4354 .3774 .43397 .37626 .39965 Mtetra
.37626 .39965 .3774 .43397 .38169 .43254 .38051 .3982 Mtetra
.38051 .3982 .38169 .43254 .38599 .43111 .38477 .39675 Mtetra
.38477 .39675 .38599 .43111 .39029 .42968 .38903 .39531 Mtetra
.38903 .39531 .39029 .42968 .3946 .42824 .39331 .39385 Mtetra
.39331 .39385 .3946 .42824 .39891 .4268 .39758 .3924 Mtetra
.39758 .3924 .39891 .4268 .40324 .42536 .40187 .39094 Mtetra
.40187 .39094 .40324 .42536 .40756 .42392 .40616 .38949 Mtetra
.901 .678 .169 r
.40616 .38949 .40756 .42392 .4102 .4713 .40759 .46866 Mtetra
.647 .761 .932 r
.40759 .46866 .4102 .4713 .41461 .46987 .412 .46723 Mtetra
.412 .46723 .41461 .46987 .41902 .46844 .41642 .46579 Mtetra
.41642 .46579 .41902 .46844 .42344 .46701 .42084 .46435 Mtetra
.42084 .46435 .42344 .46701 .42787 .46557 .42528 .46291 Mtetra
.42528 .46291 .42787 .46557 .43231 .46413 .42972 .46147 Mtetra
.42972 .46147 .43231 .46413 .43675 .46269 .43417 .46003 Mtetra
.96 .725 .538 r
.43417 .46003 .43675 .46269 .44204 .42845 .43949 .42576 Mtetra
.65 .758 .928 r
.43949 .42576 .44204 .42845 .44645 .42699 .4439 .42429 Mtetra
.4439 .42429 .44645 .42699 .45088 .42553 .44833 .42283 Mtetra
.44833 .42283 .45088 .42553 .4553 .42407 .45276 .42136 Mtetra
.45276 .42136 .4553 .42407 .45974 .4226 .4572 .41989 Mtetra
.4572 .41989 .45974 .4226 .46418 .42113 .46165 .41842 Mtetra
.46165 .41842 .46418 .42113 .46863 .41966 .46611 .41694 Mtetra
.46611 .41694 .46863 .41966 .47309 .41819 .47057 .41547 Mtetra
.47057 .41547 .47309 .41819 .47756 .41672 .47504 .41399 Mtetra
.47504 .41399 .47756 .41672 .48203 .41524 .47952 .41251 Mtetra
.47952 .41251 .48203 .41524 .48651 .41376 .484 .41102 Mtetra
.484 .41102 .48651 .41376 .491 .41228 .48849 .40954 Mtetra
.48849 .40954 .491 .41228 .49549 .41079 .49299 .40805 Mtetra
.49299 .40805 .49549 .41079 .49999 .40931 .4975 .40655 Mtetra
.4975 .40655 .49999 .40931 .5045 .40782 .50201 .40506 Mtetra
.50201 .40506 .5045 .40782 .50902 .40633 .50654 .40356 Mtetra
.50654 .40356 .50902 .40633 .51354 .40483 .51106 .40207 Mtetra
.971 .711 .482 r
.51106 .40207 .51354 .40483 .5182 .34453 .51577 .34172 Mtetra
.655 .752 .921 r
.51577 .34172 .5182 .34453 .52266 .34301 .52023 .34019 Mtetra
.52023 .34019 .52266 .34301 .52712 .34148 .5247 .33867 Mtetra
.5247 .33867 .52712 .34148 .53159 .33996 .52918 .33714 Mtetra
.52918 .33714 .53159 .33996 .53607 .33843 .53366 .33561 Mtetra
.53366 .33561 .53607 .33843 .54055 .3369 .53815 .33407 Mtetra
.53815 .33407 .54055 .3369 .54505 .33537 .54265 .33254 Mtetra
.54265 .33254 .54505 .33537 .54955 .33384 .54715 .331 Mtetra
.54715 .331 .54955 .33384 .55405 .3323 .55166 .32945 Mtetra
.55166 .32945 .55405 .3323 .55857 .33076 .55618 .32791 Mtetra
.55618 .32791 .55857 .33076 .56309 .32922 .56071 .32636 Mtetra
.56071 .32636 .56309 .32922 .56762 .32767 .56525 .32481 Mtetra
.56525 .32481 .56762 .32767 .57216 .32613 .56979 .32326 Mtetra
.56979 .32326 .57216 .32613 .5767 .32458 .57434 .32171 Mtetra
.57434 .32171 .5767 .32458 .58126 .32302 .57889 .32015 Mtetra
.57889 .32015 .58126 .32302 .58581 .32147 .58346 .31859 Mtetra
.58346 .31859 .58581 .32147 .59038 .31991 .58803 .31703 Mtetra
.58803 .31703 .59038 .31991 .59496 .31835 .59261 .31546 Mtetra
.59261 .31546 .59496 .31835 .59954 .31679 .5972 .3139 Mtetra
.5972 .3139 .59954 .31679 .60413 .31522 .60179 .31233 Mtetra
.60179 .31233 .60413 .31522 .60872 .31366 .60639 .31076 Mtetra
.60639 .31076 .60872 .31366 .61333 .31209 .611 .30918 Mtetra
.978 .696 .419 r
.611 .30918 .61333 .31209 .61889 .34256 .61223 .19049 Mtetra
.53 .308 .523 r
.61223 .19049 .61889 .34256 .61891 .19185 .61668 .18887 Mtetra
.664 .741 .908 r
.61668 .18887 .61891 .19185 .62336 .19024 .62113 .18726 Mtetra
.62113 .18726 .62336 .19024 .62782 .18863 .62559 .18564 Mtetra
.62559 .18564 .62782 .18863 .63228 .18701 .63006 .18402 Mtetra
.63006 .18402 .63228 .18701 .63676 .18539 .63454 .18239 Mtetra
.63454 .18239 .63676 .18539 .64124 .18377 .63903 .18076 Mtetra
.63903 .18076 .64124 .18377 .64572 .18214 .64352 .17913 Mtetra
.64352 .17913 .64572 .18214 .65022 .18051 .64802 .1775 Mtetra
.64802 .1775 .65022 .18051 .65472 .17888 .65252 .17587 Mtetra
.65252 .17587 .65472 .17888 .65923 .17725 .65704 .17423 Mtetra
.65704 .17423 .65923 .17725 .66374 .17561 .66156 .17259 Mtetra
.66156 .17259 .66374 .17561 .66827 .17398 .66609 .17095 Mtetra
.66609 .17095 .66827 .17398 .6728 .17234 .67062 .1693 Mtetra
.67062 .1693 .6728 .17234 .67734 .17069 .67516 .16765 Mtetra
.67516 .16765 .67734 .17069 .68188 .16905 .67971 .166 Mtetra
.67971 .166 .68188 .16905 .68643 .1674 .68427 .16435 Mtetra
.68427 .16435 .68643 .1674 .69099 .16575 .68884 .16269 Mtetra
.68884 .16269 .69099 .16575 .69556 .16409 .69341 .16103 Mtetra
.69341 .16103 .69556 .16409 .70013 .16244 .69799 .15937 Mtetra
.69799 .15937 .70013 .16244 .70472 .16078 .70257 .15771 Mtetra
.70257 .15771 .70472 .16078 .7093 .15911 .70717 .15604 Mtetra
.70717 .15604 .7093 .15911 .7139 .15745 .71177 .15437 Mtetra
.71177 .15437 .7139 .15745 .7185 .15578 .71638 .1527 Mtetra
.71638 .1527 .7185 .15578 .72312 .15411 .721 .15102 Mtetra
.721 .15102 .72312 .15411 .72774 .15244 .72562 .14934 Mtetra
.72562 .14934 .72774 .15244 .73236 .15076 .73025 .14766 Mtetra
.73025 .14766 .73236 .15076 .737 .14909 .73489 .14598 Mtetra
.73489 .14598 .737 .14909 .74164 .14741 .73954 .14429 Mtetra
.73954 .14429 .74164 .14741 .74629 .14572 .74419 .14261 Mtetra
.74419 .14261 .74629 .14572 .75094 .14404 .74885 .14091 Mtetra
.74885 .14091 .75094 .14404 .75561 .14235 .75352 .13922 Mtetra
.75352 .13922 .75561 .14235 .76028 .14065 .7582 .13752 Mtetra
.7582 .13752 .76028 .14065 .76496 .13896 .76289 .13582 Mtetra
.76289 .13582 .76496 .13896 .76964 .13726 .76758 .13412 Mtetra
.76758 .13412 .76964 .13726 .77434 .13556 .77228 .13242 Mtetra
.14116 .35793 .14384 .36043 .14758 .35908 .14489 .35657 Mtetra
.14489 .35657 .14758 .35908 .15132 .35772 .14864 .35521 Mtetra
.14864 .35521 .15132 .35772 .15506 .35636 .15238 .35385 Mtetra
.15238 .35385 .15506 .35636 .15881 .355 .15614 .35249 Mtetra
.15614 .35249 .15881 .355 .16257 .35364 .1599 .35112 Mtetra
.1599 .35112 .16257 .35364 .16633 .35228 .16366 .34975 Mtetra
.16366 .34975 .16633 .35228 .1701 .35091 .16743 .34838 Mtetra
.16743 .34838 .1701 .35091 .17387 .34954 .17121 .34701 Mtetra
.17121 .34701 .17387 .34954 .17765 .34817 .17499 .34563 Mtetra
.17499 .34563 .17765 .34817 .18143 .3468 .17878 .34426 Mtetra
.17878 .34426 .18143 .3468 .18522 .34542 .18257 .34288 Mtetra
.18257 .34288 .18522 .34542 .18902 .34404 .18637 .3415 Mtetra
.18637 .3415 .18902 .34404 .19282 .34267 .19017 .34011 Mtetra
.19017 .34011 .19282 .34267 .19662 .34128 .19398 .33873 Mtetra
.19398 .33873 .19662 .34128 .20043 .3399 .19779 .33734 Mtetra
.19779 .33734 .20043 .3399 .20425 .33852 .20161 .33595 Mtetra
.20161 .33595 .20425 .33852 .20807 .33713 .20544 .33456 Mtetra
.20544 .33456 .20807 .33713 .2119 .33574 .20927 .33317 Mtetra
.20927 .33317 .2119 .33574 .21574 .33435 .21311 .33178 Mtetra
.21311 .33178 .21574 .33435 .21958 .33296 .21695 .33038 Mtetra
.21695 .33038 .21958 .33296 .22342 .33156 .2208 .32898 Mtetra
.2208 .32898 .22342 .33156 .22727 .33016 .22466 .32758 Mtetra
.22466 .32758 .22727 .33016 .23113 .32876 .22852 .32617 Mtetra
.22852 .32617 .23113 .32876 .23499 .32736 .23238 .32477 Mtetra
.23238 .32477 .23499 .32736 .23886 .32596 .23625 .32336 Mtetra
.23625 .32336 .23886 .32596 .24274 .32455 .24013 .32195 Mtetra
.24013 .32195 .24274 .32455 .24662 .32315 .24402 .32054 Mtetra
.24402 .32054 .24662 .32315 .23646 .48265 .2479 .31913 Mtetra
0 0 .173 r
.2479 .31913 .23646 .48265 .24054 .48129 .23779 .47878 Mtetra
.651 .757 .927 r
.23779 .47878 .24054 .48129 .24463 .47993 .24188 .47741 Mtetra
.24188 .47741 .24463 .47993 .24872 .47857 .24598 .47605 Mtetra
.24598 .47605 .24872 .47857 .25282 .4772 .25008 .47468 Mtetra
.25008 .47468 .25282 .4772 .25692 .47584 .25419 .47331 Mtetra
.25419 .47331 .25692 .47584 .26103 .47447 .25831 .47193 Mtetra
.25831 .47193 .26103 .47447 .26515 .4731 .26243 .47056 Mtetra
.26243 .47056 .26515 .4731 .26928 .47172 .26656 .46918 Mtetra
.26656 .46918 .26928 .47172 .27341 .47035 .27069 .4678 Mtetra
.27069 .4678 .27341 .47035 .27755 .46897 .27483 .46642 Mtetra
.27483 .46642 .27755 .46897 .28169 .46759 .27898 .46504 Mtetra
.27898 .46504 .28169 .46759 .28584 .46621 .28314 .46365 Mtetra
.28314 .46365 .28584 .46621 .29 .46482 .2873 .46226 Mtetra
.2873 .46226 .29 .46482 .29416 .46344 .29147 .46087 Mtetra
.29147 .46087 .29416 .46344 .29833 .46205 .29564 .45948 Mtetra
.29564 .45948 .29833 .46205 .30251 .46066 .29982 .45809 Mtetra
.29982 .45809 .30251 .46066 .3067 .45927 .30401 .45669 Mtetra
.30401 .45669 .3067 .45927 .31089 .45787 .30821 .45529 Mtetra
.30821 .45529 .31089 .45787 .31508 .45647 .31241 .45389 Mtetra
.31241 .45389 .31508 .45647 .31929 .45507 .31661 .45248 Mtetra
.31661 .45248 .31929 .45507 .3235 .45367 .32083 .45108 Mtetra
.32083 .45108 .3235 .45367 .32772 .45227 .32505 .44967 Mtetra
.32505 .44967 .32772 .45227 .33194 .45086 .32928 .44826 Mtetra
.95 .717 .549 r
.32928 .44826 .33194 .45086 .33648 .44413 .33568 .40991 Mtetra
.548 .349 .564 r
.33568 .40991 .33648 .44413 .34071 .44272 .33987 .40848 Mtetra
.33987 .40848 .34071 .44272 .34495 .4413 .34407 .40705 Mtetra
.34407 .40705 .34495 .4413 .34919 .43988 .34828 .40562 Mtetra
.34828 .40562 .34919 .43988 .35344 .43846 .3525 .40419 Mtetra
.3525 .40419 .35344 .43846 .3577 .43704 .35672 .40275 Mtetra
.35672 .40275 .3577 .43704 .36196 .43562 .36095 .40131 Mtetra
.36095 .40131 .36196 .43562 .36778 .40253 .36518 .39987 Mtetra
.654 .753 .922 r
.36518 .39987 .36778 .40253 .37202 .40109 .36942 .39842 Mtetra
.36942 .39842 .37202 .40109 .37626 .39965 .37367 .39698 Mtetra
.37367 .39698 .37626 .39965 .38051 .3982 .37793 .39553 Mtetra
.37793 .39553 .38051 .3982 .38477 .39675 .38219 .39408 Mtetra
.38219 .39408 .38477 .39675 .38903 .39531 .38646 .39262 Mtetra
.38646 .39262 .38903 .39531 .39331 .39385 .39074 .39117 Mtetra
.39074 .39117 .39331 .39385 .39758 .3924 .39502 .38971 Mtetra
.39502 .38971 .39758 .3924 .40187 .39094 .39931 .38825 Mtetra
.39931 .38825 .40187 .39094 .40616 .38949 .40361 .38679 Mtetra
.964 .668 .42 r
.40361 .38679 .40616 .38949 .40759 .46866 .40497 .46601 Mtetra
.647 .761 .932 r
.40497 .46601 .40759 .46866 .412 .46723 .40938 .46458 Mtetra
.40938 .46458 .412 .46723 .41642 .46579 .41381 .46314 Mtetra
.41381 .46314 .41642 .46579 .42084 .46435 .41824 .46169 Mtetra
.41824 .46169 .42084 .46435 .42528 .46291 .42268 .46025 Mtetra
.42268 .46025 .42528 .46291 .42972 .46147 .42712 .4588 Mtetra
.42712 .4588 .42972 .46147 .43417 .46003 .43157 .45735 Mtetra
.43157 .45735 .43417 .46003 .43949 .42576 .43603 .4559 Mtetra
0 0 .131 r
.43603 .4559 .43949 .42576 .4439 .42429 .44135 .42159 Mtetra
.65 .758 .928 r
.44135 .42159 .4439 .42429 .44833 .42283 .44578 .42012 Mtetra
.44578 .42012 .44833 .42283 .45276 .42136 .45022 .41865 Mtetra
.45022 .41865 .45276 .42136 .4572 .41989 .45466 .41717 Mtetra
.45466 .41717 .4572 .41989 .46165 .41842 .45911 .41569 Mtetra
.45911 .41569 .46165 .41842 .46611 .41694 .46357 .41422 Mtetra
.46357 .41422 .46611 .41694 .47057 .41547 .46804 .41273 Mtetra
.46804 .41273 .47057 .41547 .47504 .41399 .47252 .41125 Mtetra
.47252 .41125 .47504 .41399 .47952 .41251 .477 .40976 Mtetra
.477 .40976 .47952 .41251 .484 .41102 .48149 .40828 Mtetra
.48149 .40828 .484 .41102 .48849 .40954 .48598 .40678 Mtetra
.48598 .40678 .48849 .40954 .49299 .40805 .49049 .40529 Mtetra
.49049 .40529 .49299 .40805 .4975 .40655 .495 .40379 Mtetra
.495 .40379 .4975 .40655 .50201 .40506 .49952 .4023 Mtetra
.49952 .4023 .50201 .40506 .50654 .40356 .50404 .4008 Mtetra
.50404 .4008 .50654 .40356 .51106 .40207 .50858 .39929 Mtetra
.971 .711 .482 r
.50858 .39929 .51106 .40207 .51577 .34172 .51334 .3389 Mtetra
.655 .752 .921 r
.51334 .3389 .51577 .34172 .52023 .34019 .5178 .33737 Mtetra
.5178 .33737 .52023 .34019 .5247 .33867 .52227 .33584 Mtetra
.52227 .33584 .5247 .33867 .52918 .33714 .52675 .33431 Mtetra
.52675 .33431 .52918 .33714 .53366 .33561 .53124 .33277 Mtetra
.53124 .33277 .53366 .33561 .53815 .33407 .53574 .33123 Mtetra
.53574 .33123 .53815 .33407 .54265 .33254 .54024 .32969 Mtetra
.54024 .32969 .54265 .33254 .54715 .331 .54475 .32815 Mtetra
.54475 .32815 .54715 .331 .55166 .32945 .54927 .3266 Mtetra
.54927 .3266 .55166 .32945 .55618 .32791 .55379 .32505 Mtetra
.55379 .32505 .55618 .32791 .56071 .32636 .55832 .3235 Mtetra
.55832 .3235 .56071 .32636 .56525 .32481 .56286 .32195 Mtetra
.56286 .32195 .56525 .32481 .56979 .32326 .56741 .32039 Mtetra
.56741 .32039 .56979 .32326 .57434 .32171 .57196 .31883 Mtetra
.57196 .31883 .57434 .32171 .57889 .32015 .57653 .31727 Mtetra
.57653 .31727 .57889 .32015 .58346 .31859 .5811 .31571 Mtetra
.5811 .31571 .58346 .31859 .58803 .31703 .58567 .31414 Mtetra
.58567 .31414 .58803 .31703 .59261 .31546 .59026 .31257 Mtetra
.59026 .31257 .59261 .31546 .5972 .3139 .59485 .311 Mtetra
.59485 .311 .5972 .3139 .60179 .31233 .59945 .30942 Mtetra
.59945 .30942 .60179 .31233 .60639 .31076 .60406 .30785 Mtetra
.60406 .30785 .60639 .31076 .611 .30918 .60867 .30627 Mtetra
.978 .696 .419 r
.60867 .30627 .611 .30918 .61223 .19049 .60998 .18751 Mtetra
.664 .741 .908 r
.60998 .18751 .61223 .19049 .61668 .18887 .61443 .18589 Mtetra
.61443 .18589 .61668 .18887 .62113 .18726 .6189 .18427 Mtetra
.6189 .18427 .62113 .18726 .62559 .18564 .62336 .18264 Mtetra
.62336 .18264 .62559 .18564 .63006 .18402 .62784 .18101 Mtetra
.62784 .18101 .63006 .18402 .63454 .18239 .63232 .17939 Mtetra
.63232 .17939 .63454 .18239 .63903 .18076 .63681 .17775 Mtetra
.63681 .17775 .63903 .18076 .64352 .17913 .64131 .17612 Mtetra
.64131 .17612 .64352 .17913 .64802 .1775 .64581 .17448 Mtetra
.64581 .17448 .64802 .1775 .65252 .17587 .65032 .17284 Mtetra
.65032 .17284 .65252 .17587 .65704 .17423 .65484 .1712 Mtetra
.65484 .1712 .65704 .17423 .66156 .17259 .65937 .16955 Mtetra
.65937 .16955 .66156 .17259 .66609 .17095 .6639 .16791 Mtetra
.6639 .16791 .66609 .17095 .67062 .1693 .66844 .16626 Mtetra
.66844 .16626 .67062 .1693 .67516 .16765 .67299 .1646 Mtetra
.67299 .1646 .67516 .16765 .67971 .166 .67754 .16295 Mtetra
.67754 .16295 .67971 .166 .68427 .16435 .68211 .16129 Mtetra
.68211 .16129 .68427 .16435 .68884 .16269 .68667 .15963 Mtetra
.68667 .15963 .68884 .16269 .69341 .16103 .69125 .15796 Mtetra
.69125 .15796 .69341 .16103 .69799 .15937 .69584 .1563 Mtetra
.69584 .1563 .69799 .15937 .70257 .15771 .70043 .15463 Mtetra
.70043 .15463 .70257 .15771 .70717 .15604 .70503 .15295 Mtetra
.70503 .15295 .70717 .15604 .71177 .15437 .70963 .15128 Mtetra
.70963 .15128 .71177 .15437 .71638 .1527 .71425 .1496 Mtetra
.71425 .1496 .71638 .1527 .721 .15102 .71887 .14792 Mtetra
.71887 .14792 .721 .15102 .72562 .14934 .7235 .14624 Mtetra
.7235 .14624 .72562 .14934 .73025 .14766 .72814 .14455 Mtetra
.72814 .14455 .73025 .14766 .73489 .14598 .73278 .14287 Mtetra
.73278 .14287 .73489 .14598 .73954 .14429 .73743 .14118 Mtetra
.73743 .14118 .73954 .14429 .74419 .14261 .74209 .13948 Mtetra
.74209 .13948 .74419 .14261 .74885 .14091 .74676 .13778 Mtetra
.74676 .13778 .74885 .14091 .75352 .13922 .75143 .13609 Mtetra
.75143 .13609 .75352 .13922 .7582 .13752 .75612 .13438 Mtetra
.75612 .13438 .7582 .13752 .76289 .13582 .76081 .13268 Mtetra
.76081 .13268 .76289 .13582 .76758 .13412 .7655 .13097 Mtetra
.7655 .13097 .76758 .13412 .77228 .13242 .77021 .12926 Mtetra
.13846 .35542 .14116 .35793 .14489 .35657 .1422 .35406 Mtetra
.1422 .35406 .14489 .35657 .14864 .35521 .14595 .3527 Mtetra
.14595 .3527 .14864 .35521 .15238 .35385 .1497 .35133 Mtetra
.1497 .35133 .15238 .35385 .15614 .35249 .15345 .34996 Mtetra
.15345 .34996 .15614 .35249 .1599 .35112 .15722 .34859 Mtetra
.15722 .34859 .1599 .35112 .16366 .34975 .16098 .34722 Mtetra
.16098 .34722 .16366 .34975 .16743 .34838 .16476 .34584 Mtetra
.16476 .34584 .16743 .34838 .17121 .34701 .16854 .34447 Mtetra
.16854 .34447 .17121 .34701 .17499 .34563 .17232 .34309 Mtetra
.17232 .34309 .17499 .34563 .17878 .34426 .17611 .34171 Mtetra
.17611 .34171 .17878 .34426 .18257 .34288 .17991 .34033 Mtetra
.17991 .34033 .18257 .34288 .18637 .3415 .18371 .33894 Mtetra
.18371 .33894 .18637 .3415 .19017 .34011 .18752 .33756 Mtetra
.18752 .33756 .19017 .34011 .19398 .33873 .19133 .33617 Mtetra
.19133 .33617 .19398 .33873 .19779 .33734 .19515 .33478 Mtetra
.19515 .33478 .19779 .33734 .20161 .33595 .19897 .33338 Mtetra
.19897 .33338 .20161 .33595 .20544 .33456 .2028 .33199 Mtetra
.2028 .33199 .20544 .33456 .20927 .33317 .20663 .33059 Mtetra
.20663 .33059 .20927 .33317 .21311 .33178 .21047 .32919 Mtetra
.21047 .32919 .21311 .33178 .21695 .33038 .21432 .32779 Mtetra
.21432 .32779 .21695 .33038 .2208 .32898 .21817 .32639 Mtetra
.21817 .32639 .2208 .32898 .22466 .32758 .22203 .32499 Mtetra
.22203 .32499 .22466 .32758 .22852 .32617 .2259 .32358 Mtetra
.2259 .32358 .22852 .32617 .23238 .32477 .22976 .32217 Mtetra
.22976 .32217 .23238 .32477 .23625 .32336 .23364 .32076 Mtetra
.23364 .32076 .23625 .32336 .24013 .32195 .23752 .31934 Mtetra
.23752 .31934 .24013 .32195 .24402 .32054 .24141 .31793 Mtetra
.24141 .31793 .24402 .32054 .2479 .31913 .2453 .31651 Mtetra
.95 .68 .491 r
.2453 .31651 .2479 .31913 .23779 .47878 .23504 .47626 Mtetra
.651 .757 .927 r
.23504 .47626 .23779 .47878 .24188 .47741 .23913 .47489 Mtetra
.23913 .47489 .24188 .47741 .24598 .47605 .24323 .47352 Mtetra
.24323 .47352 .24598 .47605 .25008 .47468 .24734 .47215 Mtetra
.24734 .47215 .25008 .47468 .25419 .47331 .25145 .47077 Mtetra
.25145 .47077 .25419 .47331 .25831 .47193 .25557 .46939 Mtetra
.25557 .46939 .25831 .47193 .26243 .47056 .2597 .46802 Mtetra
.2597 .46802 .26243 .47056 .26656 .46918 .26383 .46663 Mtetra
.26383 .46663 .26656 .46918 .27069 .4678 .26797 .46525 Mtetra
.26797 .46525 .27069 .4678 .27483 .46642 .27211 .46386 Mtetra
.27211 .46386 .27483 .46642 .27898 .46504 .27627 .46248 Mtetra
.27627 .46248 .27898 .46504 .28314 .46365 .28042 .46109 Mtetra
.28042 .46109 .28314 .46365 .2873 .46226 .28459 .45969 Mtetra
.28459 .45969 .2873 .46226 .29147 .46087 .28876 .4583 Mtetra
.28876 .4583 .29147 .46087 .29564 .45948 .29294 .4569 Mtetra
.29294 .4569 .29564 .45948 .29982 .45809 .29713 .4555 Mtetra
.29713 .4555 .29982 .45809 .30401 .45669 .30132 .4541 Mtetra
.30132 .4541 .30401 .45669 .30821 .45529 .30552 .4527 Mtetra
.30552 .4527 .30821 .45529 .31241 .45389 .30972 .45129 Mtetra
.30972 .45129 .31241 .45389 .31661 .45248 .31393 .44989 Mtetra
.31393 .44989 .31661 .45248 .32083 .45108 .31815 .44848 Mtetra
.31815 .44848 .32083 .45108 .32505 .44967 .32238 .44706 Mtetra
.32238 .44706 .32505 .44967 .32928 .44826 .32661 .44565 Mtetra
.95 .717 .549 r
.32661 .44565 .32928 .44826 .33568 .40991 .33304 .40727 Mtetra
.654 .753 .922 r
.33304 .40727 .33568 .40991 .33987 .40848 .33724 .40584 Mtetra
.33724 .40584 .33987 .40848 .34407 .40705 .34145 .40441 Mtetra
.34145 .40441 .34407 .40705 .34828 .40562 .34566 .40297 Mtetra
.34566 .40297 .34828 .40562 .3525 .40419 .34988 .40153 Mtetra
.34988 .40153 .3525 .40419 .35672 .40275 .35411 .40009 Mtetra
.35411 .40009 .35672 .40275 .36095 .40131 .35834 .39865 Mtetra
.35834 .39865 .36095 .40131 .36518 .39987 .36258 .3972 Mtetra
.36258 .3972 .36518 .39987 .36942 .39842 .36683 .39575 Mtetra
.36683 .39575 .36942 .39842 .37367 .39698 .37108 .3943 Mtetra
.37108 .3943 .37367 .39698 .37793 .39553 .37534 .39285 Mtetra
.37534 .39285 .37793 .39553 .38219 .39408 .37961 .39139 Mtetra
.37961 .39139 .38219 .39408 .38646 .39262 .38388 .38994 Mtetra
.38388 .38994 .38646 .39262 .39074 .39117 .38816 .38848 Mtetra
.38816 .38848 .39074 .39117 .39502 .38971 .39245 .38701 Mtetra
.39245 .38701 .39502 .38971 .39931 .38825 .39674 .38555 Mtetra
.39674 .38555 .39931 .38825 .40361 .38679 .40104 .38408 Mtetra
.964 .668 .42 r
.40104 .38408 .40361 .38679 .40497 .46601 .40234 .46336 Mtetra
.647 .761 .932 r
.40234 .46336 .40497 .46601 .40938 .46458 .40676 .46191 Mtetra
.40676 .46191 .40938 .46458 .41381 .46314 .41119 .46047 Mtetra
.41119 .46047 .41381 .46314 .41824 .46169 .41562 .45902 Mtetra
.41562 .45902 .41824 .46169 .42268 .46025 .42006 .45757 Mtetra
.42006 .45757 .42268 .46025 .42712 .4588 .42451 .45612 Mtetra
.42451 .45612 .42712 .4588 .43157 .45735 .42897 .45467 Mtetra
.42897 .45467 .43157 .45735 .43603 .4559 .43344 .45321 Mtetra
.43344 .45321 .43603 .4559 .44135 .42159 .43791 .45175 Mtetra
0 0 .131 r
.43791 .45175 .44135 .42159 .44578 .42012 .44322 .4174 Mtetra
.65 .758 .928 r
.44322 .4174 .44578 .42012 .45022 .41865 .44766 .41592 Mtetra
.44766 .41592 .45022 .41865 .45466 .41717 .45211 .41444 Mtetra
.45211 .41444 .45466 .41717 .45911 .41569 .45657 .41296 Mtetra
.45657 .41296 .45911 .41569 .46357 .41422 .46103 .41148 Mtetra
.46103 .41148 .46357 .41422 .46804 .41273 .4655 .40999 Mtetra
.4655 .40999 .46804 .41273 .47252 .41125 .46998 .4085 Mtetra
.46998 .4085 .47252 .41125 .477 .40976 .47447 .40701 Mtetra
.47447 .40701 .477 .40976 .48149 .40828 .47896 .40552 Mtetra
.47896 .40552 .48149 .40828 .48598 .40678 .48347 .40403 Mtetra
.48347 .40403 .48598 .40678 .49049 .40529 .48797 .40253 Mtetra
.48797 .40253 .49049 .40529 .495 .40379 .49249 .40103 Mtetra
.49249 .40103 .495 .40379 .49952 .4023 .49701 .39952 Mtetra
.49701 .39952 .49952 .4023 .50404 .4008 .50155 .39802 Mtetra
.50155 .39802 .50404 .4008 .50858 .39929 .50608 .39651 Mtetra
.971 .711 .482 r
.50608 .39651 .50858 .39929 .51334 .3389 .51089 .33608 Mtetra
.655 .752 .921 r
.51089 .33608 .51334 .3389 .5178 .33737 .51536 .33454 Mtetra
.51536 .33454 .5178 .33737 .52227 .33584 .51984 .33301 Mtetra
.51984 .33301 .52227 .33584 .52675 .33431 .52433 .33147 Mtetra
.52433 .33147 .52675 .33431 .53124 .33277 .52882 .32993 Mtetra
.52882 .32993 .53124 .33277 .53574 .33123 .53332 .32839 Mtetra
.53332 .32839 .53574 .33123 .54024 .32969 .53783 .32684 Mtetra
.53783 .32684 .54024 .32969 .54475 .32815 .54234 .32529 Mtetra
.54234 .32529 .54475 .32815 .54927 .3266 .54686 .32374 Mtetra
.54686 .32374 .54927 .3266 .55379 .32505 .55139 .32219 Mtetra
.55139 .32219 .55379 .32505 .55832 .3235 .55593 .32063 Mtetra
.55593 .32063 .55832 .3235 .56286 .32195 .56047 .31907 Mtetra
.56047 .31907 .56286 .32195 .56741 .32039 .56502 .31751 Mtetra
.56502 .31751 .56741 .32039 .57196 .31883 .56958 .31595 Mtetra
.56958 .31595 .57196 .31883 .57653 .31727 .57415 .31438 Mtetra
.57415 .31438 .57653 .31727 .5811 .31571 .57873 .31281 Mtetra
.57873 .31281 .5811 .31571 .58567 .31414 .58331 .31124 Mtetra
.58331 .31124 .58567 .31414 .59026 .31257 .5879 .30966 Mtetra
.5879 .30966 .59026 .31257 .59485 .311 .59249 .30809 Mtetra
.59249 .30809 .59485 .311 .59945 .30942 .5971 .30651 Mtetra
.5971 .30651 .59945 .30942 .60406 .30785 .60171 .30493 Mtetra
.60171 .30493 .60406 .30785 .60867 .30627 .60633 .30334 Mtetra
.978 .696 .419 r
.60633 .30334 .60867 .30627 .60998 .18751 .60773 .18452 Mtetra
.664 .741 .908 r
.60773 .18452 .60998 .18751 .61443 .18589 .61219 .18289 Mtetra
.61219 .18289 .61443 .18589 .6189 .18427 .61665 .18126 Mtetra
.61665 .18126 .6189 .18427 .62336 .18264 .62113 .17964 Mtetra
.62113 .17964 .62336 .18264 .62784 .18101 .62561 .178 Mtetra
.62561 .178 .62784 .18101 .63232 .17939 .63009 .17637 Mtetra
.63009 .17637 .63232 .17939 .63681 .17775 .63459 .17473 Mtetra
.63459 .17473 .63681 .17775 .64131 .17612 .63909 .17309 Mtetra
.63909 .17309 .64131 .17612 .64581 .17448 .6436 .17145 Mtetra
.6436 .17145 .64581 .17448 .65032 .17284 .64811 .16981 Mtetra
.64811 .16981 .65032 .17284 .65484 .1712 .65264 .16816 Mtetra
.65264 .16816 .65484 .1712 .65937 .16955 .65717 .16651 Mtetra
.65717 .16651 .65937 .16955 .6639 .16791 .66171 .16486 Mtetra
.66171 .16486 .6639 .16791 .66844 .16626 .66625 .1632 Mtetra
.66625 .1632 .66844 .16626 .67299 .1646 .6708 .16154 Mtetra
.6708 .16154 .67299 .1646 .67754 .16295 .67536 .15988 Mtetra
.67536 .15988 .67754 .16295 .68211 .16129 .67993 .15822 Mtetra
.67993 .15822 .68211 .16129 .68667 .15963 .68451 .15655 Mtetra
.68451 .15655 .68667 .15963 .69125 .15796 .68909 .15488 Mtetra
.68909 .15488 .69125 .15796 .69584 .1563 .69368 .15321 Mtetra
.69368 .15321 .69584 .1563 .70043 .15463 .69828 .15154 Mtetra
.69828 .15154 .70043 .15463 .70503 .15295 .70288 .14986 Mtetra
.70288 .14986 .70503 .15295 .70963 .15128 .70749 .14818 Mtetra
.70749 .14818 .70963 .15128 .71425 .1496 .71211 .1465 Mtetra
.71211 .1465 .71425 .1496 .71887 .14792 .71674 .14481 Mtetra
.71674 .14481 .71887 .14792 .7235 .14624 .72137 .14313 Mtetra
.72137 .14313 .7235 .14624 .72814 .14455 .72601 .14144 Mtetra
.72601 .14144 .72814 .14455 .73278 .14287 .73066 .13974 Mtetra
.73066 .13974 .73278 .14287 .73743 .14118 .73532 .13805 Mtetra
.73532 .13805 .73743 .14118 .74209 .13948 .73999 .13635 Mtetra
.73999 .13635 .74209 .13948 .74676 .13778 .74466 .13465 Mtetra
.74466 .13465 .74676 .13778 .75143 .13609 .74934 .13294 Mtetra
.74934 .13294 .75143 .13609 .75612 .13438 .75403 .13123 Mtetra
.75403 .13123 .75612 .13438 .76081 .13268 .75872 .12952 Mtetra
.75872 .12952 .76081 .13268 .7655 .13097 .76343 .12781 Mtetra
.76343 .12781 .7655 .13097 .77021 .12926 .76814 .12609 Mtetra
.13576 .35291 .13846 .35542 .1422 .35406 .1395 .35154 Mtetra
.1395 .35154 .1422 .35406 .14595 .3527 .14325 .35017 Mtetra
.14325 .35017 .14595 .3527 .1497 .35133 .147 .3488 Mtetra
.147 .3488 .1497 .35133 .15345 .34996 .15076 .34743 Mtetra
.15076 .34743 .15345 .34996 .15722 .34859 .15453 .34606 Mtetra
.15453 .34606 .15722 .34859 .16098 .34722 .1583 .34468 Mtetra
.1583 .34468 .16098 .34722 .16476 .34584 .16208 .3433 Mtetra
.16208 .3433 .16476 .34584 .16854 .34447 .16586 .34192 Mtetra
.16586 .34192 .16854 .34447 .17232 .34309 .16965 .34054 Mtetra
.16965 .34054 .17232 .34309 .17611 .34171 .17344 .33916 Mtetra
.17344 .33916 .17611 .34171 .17991 .34033 .17724 .33777 Mtetra
.17724 .33777 .17991 .34033 .18371 .33894 .18104 .33638 Mtetra
.18104 .33638 .18371 .33894 .18752 .33756 .18485 .33499 Mtetra
.18485 .33499 .18752 .33756 .19133 .33617 .18867 .3336 Mtetra
.18867 .3336 .19133 .33617 .19515 .33478 .19249 .3322 Mtetra
.19249 .3322 .19515 .33478 .19897 .33338 .19632 .33081 Mtetra
.19632 .33081 .19897 .33338 .2028 .33199 .20015 .32941 Mtetra
.20015 .32941 .2028 .33199 .20663 .33059 .20399 .32801 Mtetra
.20399 .32801 .20663 .33059 .21047 .32919 .20783 .32661 Mtetra
.20783 .32661 .21047 .32919 .21432 .32779 .21168 .3252 Mtetra
.21168 .3252 .21432 .32779 .21817 .32639 .21554 .3238 Mtetra
.21554 .3238 .21817 .32639 .22203 .32499 .2194 .32239 Mtetra
.2194 .32239 .22203 .32499 .2259 .32358 .22327 .32098 Mtetra
.22327 .32098 .2259 .32358 .22976 .32217 .22714 .31956 Mtetra
.22714 .31956 .22976 .32217 .23364 .32076 .23102 .31815 Mtetra
.23102 .31815 .23364 .32076 .23752 .31934 .2349 .31673 Mtetra
.2349 .31673 .23752 .31934 .24141 .31793 .23879 .31531 Mtetra
.23879 .31531 .24141 .31793 .2453 .31651 .24269 .31389 Mtetra
.24269 .31389 .2453 .31651 .23504 .47626 .24659 .31247 Mtetra
0 0 .17 r
.24659 .31247 .23504 .47626 .23913 .47489 .23637 .47236 Mtetra
.651 .757 .927 r
.23637 .47236 .23913 .47489 .24323 .47352 .24048 .47098 Mtetra
.24048 .47098 .24323 .47352 .24734 .47215 .24459 .46961 Mtetra
.24459 .46961 .24734 .47215 .25145 .47077 .2487 .46823 Mtetra
.2487 .46823 .25145 .47077 .25557 .46939 .25283 .46685 Mtetra
.25283 .46685 .25557 .46939 .2597 .46802 .25696 .46546 Mtetra
.25696 .46546 .2597 .46802 .26383 .46663 .26109 .46408 Mtetra
.26109 .46408 .26383 .46663 .26797 .46525 .26524 .46269 Mtetra
.26524 .46269 .26797 .46525 .27211 .46386 .26939 .4613 Mtetra
.26939 .4613 .27211 .46386 .27627 .46248 .27354 .45991 Mtetra
.27354 .45991 .27627 .46248 .28042 .46109 .2777 .45851 Mtetra
.2777 .45851 .28042 .46109 .28459 .45969 .28187 .45712 Mtetra
.28187 .45712 .28459 .45969 .28876 .4583 .28605 .45572 Mtetra
.28605 .45572 .28876 .4583 .29294 .4569 .29023 .45432 Mtetra
.29023 .45432 .29294 .4569 .29713 .4555 .29442 .45292 Mtetra
.29442 .45292 .29713 .4555 .30132 .4541 .29862 .45151 Mtetra
.29862 .45151 .30132 .4541 .30552 .4527 .30282 .4501 Mtetra
.30282 .4501 .30552 .4527 .30972 .45129 .30703 .44869 Mtetra
.30703 .44869 .30972 .45129 .31393 .44989 .31124 .44728 Mtetra
.31124 .44728 .31393 .44989 .31815 .44848 .31547 .44587 Mtetra
.31547 .44587 .31815 .44848 .32238 .44706 .3197 .44445 Mtetra
.95 .716 .55 r
.3197 .44445 .32238 .44706 .32661 .44565 .32621 .40606 Mtetra
.543 .341 .556 r
.32621 .40606 .32661 .44565 .33304 .40727 .33041 .40463 Mtetra
.654 .753 .922 r
.33041 .40463 .33304 .40727 .33724 .40584 .33461 .40319 Mtetra
.33461 .40319 .33724 .40584 .34145 .40441 .33882 .40175 Mtetra
.33882 .40175 .34145 .40441 .34566 .40297 .34304 .40031 Mtetra
.34304 .40031 .34566 .40297 .34988 .40153 .34726 .39887 Mtetra
.34726 .39887 .34988 .40153 .35411 .40009 .35149 .39742 Mtetra
.35149 .39742 .35411 .40009 .35834 .39865 .35573 .39597 Mtetra
.35573 .39597 .35834 .39865 .36258 .3972 .35997 .39452 Mtetra
.35997 .39452 .36258 .3972 .36683 .39575 .36422 .39307 Mtetra
.36422 .39307 .36683 .39575 .37108 .3943 .36848 .39162 Mtetra
.36848 .39162 .37108 .3943 .37534 .39285 .37274 .39016 Mtetra
.37274 .39016 .37534 .39285 .37961 .39139 .37701 .3887 Mtetra
.37701 .3887 .37961 .39139 .38388 .38994 .38129 .38724 Mtetra
.38129 .38724 .38388 .38994 .38816 .38848 .38557 .38577 Mtetra
.38557 .38577 .38816 .38848 .39245 .38701 .38987 .38431 Mtetra
.38987 .38431 .39245 .38701 .39674 .38555 .39416 .38284 Mtetra
.39416 .38284 .39674 .38555 .40104 .38408 .39847 .38137 Mtetra
.964 .668 .42 r
.39847 .38137 .40104 .38408 .40234 .46336 .3997 .46069 Mtetra
.647 .761 .932 r
.3997 .46069 .40234 .46336 .40676 .46191 .40413 .45925 Mtetra
.40413 .45925 .40676 .46191 .41119 .46047 .40856 .4578 Mtetra
.40856 .4578 .41119 .46047 .41562 .45902 .413 .45635 Mtetra
.413 .45635 .41562 .45902 .42006 .45757 .41745 .45489 Mtetra
.41745 .45489 .42006 .45757 .42451 .45612 .4219 .45343 Mtetra
.4219 .45343 .42451 .45612 .42897 .45467 .42636 .45198 Mtetra
.42636 .45198 .42897 .45467 .43344 .45321 .43083 .45052 Mtetra
.43083 .45052 .43344 .45321 .43791 .45175 .43531 .44905 Mtetra
.43531 .44905 .43791 .45175 .44322 .4174 .43979 .44759 Mtetra
0 0 .131 r
.43979 .44759 .44322 .4174 .44766 .41592 .4451 .41319 Mtetra
.65 .758 .928 r
.4451 .41319 .44766 .41592 .45211 .41444 .44955 .41171 Mtetra
.44955 .41171 .45211 .41444 .45657 .41296 .45401 .41022 Mtetra
.45401 .41022 .45657 .41296 .46103 .41148 .45848 .40873 Mtetra
.45848 .40873 .46103 .41148 .4655 .40999 .46296 .40724 Mtetra
.46296 .40724 .4655 .40999 .46998 .4085 .46744 .40575 Mtetra
.46744 .40575 .46998 .4085 .47447 .40701 .47193 .40426 Mtetra
.47193 .40426 .47447 .40701 .47896 .40552 .47643 .40276 Mtetra
.47643 .40276 .47896 .40552 .48347 .40403 .48094 .40126 Mtetra
.48094 .40126 .48347 .40403 .48797 .40253 .48545 .39975 Mtetra
.48545 .39975 .48797 .40253 .49249 .40103 .48997 .39825 Mtetra
.48997 .39825 .49249 .40103 .49701 .39952 .4945 .39674 Mtetra
.4945 .39674 .49701 .39952 .50155 .39802 .49904 .39523 Mtetra
.49904 .39523 .50155 .39802 .50608 .39651 .50358 .39372 Mtetra
.971 .711 .482 r
.50358 .39372 .50608 .39651 .51089 .33608 .50844 .33324 Mtetra
.655 .752 .921 r
.50844 .33324 .51089 .33608 .51536 .33454 .51292 .33171 Mtetra
.51292 .33171 .51536 .33454 .51984 .33301 .5174 .33017 Mtetra
.5174 .33017 .51984 .33301 .52433 .33147 .52189 .32862 Mtetra
.52189 .32862 .52433 .33147 .52882 .32993 .52639 .32708 Mtetra
.52639 .32708 .52882 .32993 .53332 .32839 .53089 .32553 Mtetra
.53089 .32553 .53332 .32839 .53783 .32684 .5354 .32398 Mtetra
.5354 .32398 .53783 .32684 .54234 .32529 .53992 .32243 Mtetra
.53992 .32243 .54234 .32529 .54686 .32374 .54445 .32087 Mtetra
.54445 .32087 .54686 .32374 .55139 .32219 .54898 .31931 Mtetra
.54898 .31931 .55139 .32219 .55593 .32063 .55353 .31775 Mtetra
.55353 .31775 .55593 .32063 .56047 .31907 .55808 .31619 Mtetra
.55808 .31619 .56047 .31907 .56502 .31751 .56263 .31462 Mtetra
.56263 .31462 .56502 .31751 .56958 .31595 .5672 .31305 Mtetra
.5672 .31305 .56958 .31595 .57415 .31438 .57177 .31148 Mtetra
.57177 .31148 .57415 .31438 .57873 .31281 .57635 .30991 Mtetra
.57635 .30991 .57873 .31281 .58331 .31124 .58093 .30833 Mtetra
.58093 .30833 .58331 .31124 .5879 .30966 .58553 .30675 Mtetra
.58553 .30675 .5879 .30966 .59249 .30809 .59013 .30517 Mtetra
.59013 .30517 .59249 .30809 .5971 .30651 .59474 .30359 Mtetra
.59474 .30359 .5971 .30651 .60171 .30493 .59936 .302 Mtetra
.59936 .302 .60171 .30493 .60633 .30334 .60398 .30041 Mtetra
.978 .696 .419 r
.60398 .30041 .60633 .30334 .60773 .18452 .60547 .18152 Mtetra
.664 .741 .908 r
.60547 .18152 .60773 .18452 .61219 .18289 .60993 .17989 Mtetra
.60993 .17989 .61219 .18289 .61665 .18126 .6144 .17826 Mtetra
.6144 .17826 .61665 .18126 .62113 .17964 .61888 .17662 Mtetra
.61888 .17662 .62113 .17964 .62561 .178 .62337 .17499 Mtetra
.62337 .17499 .62561 .178 .63009 .17637 .62786 .17335 Mtetra
.62786 .17335 .63009 .17637 .63459 .17473 .63236 .1717 Mtetra
.63236 .1717 .63459 .17473 .63909 .17309 .63686 .17006 Mtetra
.63686 .17006 .63909 .17309 .6436 .17145 .64138 .16841 Mtetra
.64138 .16841 .6436 .17145 .64811 .16981 .6459 .16676 Mtetra
.6459 .16676 .64811 .16981 .65264 .16816 .65043 .16511 Mtetra
.65043 .16511 .65264 .16816 .65717 .16651 .65496 .16346 Mtetra
.65496 .16346 .65717 .16651 .66171 .16486 .65951 .1618 Mtetra
.65951 .1618 .66171 .16486 .66625 .1632 .66406 .16014 Mtetra
.66406 .16014 .66625 .1632 .6708 .16154 .66861 .15847 Mtetra
.66861 .15847 .6708 .16154 .67536 .15988 .67318 .15681 Mtetra
.67318 .15681 .67536 .15988 .67993 .15822 .67775 .15514 Mtetra
.67775 .15514 .67993 .15822 .68451 .15655 .68233 .15347 Mtetra
.68233 .15347 .68451 .15655 .68909 .15488 .68692 .1518 Mtetra
.68692 .1518 .68909 .15488 .69368 .15321 .69151 .15012 Mtetra
.69151 .15012 .69368 .15321 .69828 .15154 .69612 .14844 Mtetra
.69612 .14844 .69828 .15154 .70288 .14986 .70073 .14676 Mtetra
.70073 .14676 .70288 .14986 .70749 .14818 .70534 .14507 Mtetra
.70534 .14507 .70749 .14818 .71211 .1465 .70997 .14339 Mtetra
.70997 .14339 .71211 .1465 .71674 .14481 .7146 .1417 Mtetra
.7146 .1417 .71674 .14481 .72137 .14313 .71924 .14 Mtetra
.71924 .14 .72137 .14313 .72601 .14144 .72389 .13831 Mtetra
.72389 .13831 .72601 .14144 .73066 .13974 .72854 .13661 Mtetra
.72854 .13661 .73066 .13974 .73532 .13805 .7332 .13491 Mtetra
.7332 .13491 .73532 .13805 .73999 .13635 .73787 .1332 Mtetra
.73787 .1332 .73999 .13635 .74466 .13465 .74255 .1315 Mtetra
.74255 .1315 .74466 .13465 .74934 .13294 .74724 .12979 Mtetra
.74724 .12979 .74934 .13294 .75403 .13123 .75193 .12807 Mtetra
.75193 .12807 .75403 .13123 .75872 .12952 .75663 .12636 Mtetra
.75663 .12636 .75872 .12952 .76343 .12781 .76134 .12464 Mtetra
.76134 .12464 .76343 .12781 .76814 .12609 .76606 .12292 Mtetra
.13305 .35038 .13576 .35291 .1395 .35154 .13679 .34901 Mtetra
.13679 .34901 .1395 .35154 .14325 .35017 .14055 .34764 Mtetra
.14055 .34764 .14325 .35017 .147 .3488 .1443 .34627 Mtetra
.1443 .34627 .147 .3488 .15076 .34743 .14807 .34489 Mtetra
.14807 .34489 .15076 .34743 .15453 .34606 .15184 .34351 Mtetra
.15184 .34351 .15453 .34606 .1583 .34468 .15561 .34213 Mtetra
.15561 .34213 .1583 .34468 .16208 .3433 .15939 .34075 Mtetra
.15939 .34075 .16208 .3433 .16586 .34192 .16317 .33937 Mtetra
.16317 .33937 .16586 .34192 .16965 .34054 .16697 .33798 Mtetra
.16697 .33798 .16965 .34054 .17344 .33916 .17076 .3366 Mtetra
.17076 .3366 .17344 .33916 .17724 .33777 .17456 .33521 Mtetra
.17456 .33521 .17724 .33777 .18104 .33638 .17837 .33381 Mtetra
.17837 .33381 .18104 .33638 .18485 .33499 .18218 .33242 Mtetra
.18218 .33242 .18485 .33499 .18867 .3336 .186 .33102 Mtetra
.186 .33102 .18867 .3336 .19249 .3322 .18983 .32963 Mtetra
.18983 .32963 .19249 .3322 .19632 .33081 .19366 .32823 Mtetra
.19366 .32823 .19632 .33081 .20015 .32941 .19749 .32682 Mtetra
.19749 .32682 .20015 .32941 .20399 .32801 .20134 .32542 Mtetra
.20134 .32542 .20399 .32801 .20783 .32661 .20518 .32401 Mtetra
.20518 .32401 .20783 .32661 .21168 .3252 .20904 .3226 Mtetra
.20904 .3226 .21168 .3252 .21554 .3238 .2129 .32119 Mtetra
.2129 .32119 .21554 .3238 .2194 .32239 .21676 .31978 Mtetra
.21676 .31978 .2194 .32239 .22327 .32098 .22063 .31836 Mtetra
.22063 .31836 .22327 .32098 .22714 .31956 .22451 .31695 Mtetra
.22451 .31695 .22714 .31956 .23102 .31815 .22839 .31553 Mtetra
.22839 .31553 .23102 .31815 .2349 .31673 .23228 .31411 Mtetra
.23228 .31411 .2349 .31673 .23879 .31531 .23617 .31268 Mtetra
.23617 .31268 .23879 .31531 .24269 .31389 .24007 .31126 Mtetra
.24007 .31126 .24269 .31389 .24659 .31247 .24397 .30983 Mtetra
.24397 .30983 .24659 .31247 .23637 .47236 .24789 .3084 Mtetra
0 0 .17 r
.24789 .3084 .23637 .47236 .24048 .47098 .23771 .46844 Mtetra
.651 .757 .927 r
.23771 .46844 .24048 .47098 .24459 .46961 .24183 .46706 Mtetra
.24183 .46706 .24459 .46961 .2487 .46823 .24595 .46568 Mtetra
.24595 .46568 .2487 .46823 .25283 .46685 .25007 .46429 Mtetra
.25007 .46429 .25283 .46685 .25696 .46546 .25421 .4629 Mtetra
.25421 .4629 .25696 .46546 .26109 .46408 .25835 .46151 Mtetra
.25835 .46151 .26109 .46408 .26524 .46269 .2625 .46012 Mtetra
.2625 .46012 .26524 .46269 .26939 .4613 .26665 .45873 Mtetra
.26665 .45873 .26939 .4613 .27354 .45991 .27081 .45733 Mtetra
.27081 .45733 .27354 .45991 .2777 .45851 .27498 .45593 Mtetra
.27498 .45593 .2777 .45851 .28187 .45712 .27915 .45453 Mtetra
.27915 .45453 .28187 .45712 .28605 .45572 .28333 .45313 Mtetra
.28333 .45313 .28605 .45572 .29023 .45432 .28751 .45173 Mtetra
.28751 .45173 .29023 .45432 .29442 .45292 .29171 .45032 Mtetra
.29171 .45032 .29442 .45292 .29862 .45151 .29591 .44891 Mtetra
.29591 .44891 .29862 .45151 .30282 .4501 .30011 .4475 Mtetra
.30011 .4475 .30282 .4501 .30703 .44869 .30433 .44608 Mtetra
.30433 .44608 .30703 .44869 .31124 .44728 .30855 .44467 Mtetra
.30855 .44467 .31124 .44728 .31547 .44587 .31277 .44325 Mtetra
.31277 .44325 .31547 .44587 .3197 .44445 .31701 .44183 Mtetra
.95 .716 .55 r
.31701 .44183 .3197 .44445 .32621 .40606 .32356 .40341 Mtetra
.654 .753 .922 r
.32356 .40341 .32621 .40606 .33041 .40463 .32776 .40197 Mtetra
.32776 .40197 .33041 .40463 .33461 .40319 .33197 .40053 Mtetra
.33197 .40053 .33461 .40319 .33882 .40175 .33618 .39909 Mtetra
.33618 .39909 .33882 .40175 .34304 .40031 .3404 .39765 Mtetra
.3404 .39765 .34304 .40031 .34726 .39887 .34463 .3962 Mtetra
.34463 .3962 .34726 .39887 .35149 .39742 .34886 .39475 Mtetra
.34886 .39475 .35149 .39742 .35573 .39597 .3531 .3933 Mtetra
.3531 .3933 .35573 .39597 .35997 .39452 .35735 .39184 Mtetra
.35735 .39184 .35997 .39452 .36422 .39307 .36161 .39038 Mtetra
.36161 .39038 .36422 .39307 .36848 .39162 .36587 .38892 Mtetra
.36587 .38892 .36848 .39162 .37274 .39016 .37014 .38746 Mtetra
.37014 .38746 .37274 .39016 .37701 .3887 .37441 .386 Mtetra
.37441 .386 .37701 .3887 .38129 .38724 .37869 .38453 Mtetra
.37869 .38453 .38129 .38724 .38557 .38577 .38298 .38306 Mtetra
.38298 .38306 .38557 .38577 .38987 .38431 .38728 .38159 Mtetra
.38728 .38159 .38987 .38431 .39416 .38284 .39158 .38012 Mtetra
.39158 .38012 .39416 .38284 .39847 .38137 .39589 .37864 Mtetra
.964 .668 .42 r
.39589 .37864 .39847 .38137 .3997 .46069 .39706 .45802 Mtetra
.647 .761 .932 r
.39706 .45802 .3997 .46069 .40413 .45925 .40149 .45657 Mtetra
.40149 .45657 .40413 .45925 .40856 .4578 .40592 .45512 Mtetra
.40592 .45512 .40856 .4578 .413 .45635 .41037 .45366 Mtetra
.41037 .45366 .413 .45635 .41745 .45489 .41482 .4522 Mtetra
.41482 .4522 .41745 .45489 .4219 .45343 .41928 .45074 Mtetra
.41928 .45074 .4219 .45343 .42636 .45198 .42375 .44928 Mtetra
.42375 .44928 .42636 .45198 .43083 .45052 .42822 .44781 Mtetra
.42822 .44781 .43083 .45052 .43531 .44905 .4327 .44634 Mtetra
.4327 .44634 .43531 .44905 .43979 .44759 .43719 .44487 Mtetra
.43719 .44487 .43979 .44759 .4451 .41319 .44169 .4434 Mtetra
0 0 .131 r
.44169 .4434 .4451 .41319 .44955 .41171 .44699 .40896 Mtetra
.65 .758 .928 r
.44699 .40896 .44955 .41171 .45401 .41022 .45145 .40747 Mtetra
.45145 .40747 .45401 .41022 .45848 .40873 .45593 .40598 Mtetra
.45593 .40598 .45848 .40873 .46296 .40724 .46041 .40449 Mtetra
.46041 .40449 .46296 .40724 .46744 .40575 .4649 .40299 Mtetra
.4649 .40299 .46744 .40575 .47193 .40426 .46939 .40149 Mtetra
.46939 .40149 .47193 .40426 .47643 .40276 .4739 .39999 Mtetra
.4739 .39999 .47643 .40276 .48094 .40126 .47841 .39848 Mtetra
.47841 .39848 .48094 .40126 .48545 .39975 .48292 .39697 Mtetra
.48292 .39697 .48545 .39975 .48997 .39825 .48745 .39546 Mtetra
.48745 .39546 .48997 .39825 .4945 .39674 .49198 .39395 Mtetra
.49198 .39395 .4945 .39674 .49904 .39523 .49653 .39244 Mtetra
.49653 .39244 .49904 .39523 .50358 .39372 .50107 .39092 Mtetra
.971 .711 .482 r
.50107 .39092 .50358 .39372 .50844 .33324 .50598 .3304 Mtetra
.655 .752 .921 r
.50598 .3304 .50844 .33324 .51292 .33171 .51046 .32886 Mtetra
.51046 .32886 .51292 .33171 .5174 .33017 .51495 .32732 Mtetra
.51495 .32732 .5174 .33017 .52189 .32862 .51945 .32577 Mtetra
.51945 .32577 .52189 .32862 .52639 .32708 .52395 .32422 Mtetra
.52395 .32422 .52639 .32708 .53089 .32553 .52846 .32266 Mtetra
.52846 .32266 .53089 .32553 .5354 .32398 .53297 .32111 Mtetra
.53297 .32111 .5354 .32398 .53992 .32243 .5375 .31955 Mtetra
.5375 .31955 .53992 .32243 .54445 .32087 .54203 .31799 Mtetra
.54203 .31799 .54445 .32087 .54898 .31931 .54657 .31643 Mtetra
.54657 .31643 .54898 .31931 .55353 .31775 .55112 .31486 Mtetra
.55112 .31486 .55353 .31775 .55808 .31619 .55567 .31329 Mtetra
.55567 .31329 .55808 .31619 .56263 .31462 .56023 .31172 Mtetra
.56023 .31172 .56263 .31462 .5672 .31305 .5648 .31015 Mtetra
.5648 .31015 .5672 .31305 .57177 .31148 .56938 .30857 Mtetra
.56938 .30857 .57177 .31148 .57635 .30991 .57396 .30699 Mtetra
.57396 .30699 .57635 .30991 .58093 .30833 .57856 .30541 Mtetra
.57856 .30541 .58093 .30833 .58553 .30675 .58315 .30383 Mtetra
.58315 .30383 .58553 .30675 .59013 .30517 .58776 .30224 Mtetra
.58776 .30224 .59013 .30517 .59474 .30359 .59238 .30065 Mtetra
.59238 .30065 .59474 .30359 .59936 .302 .597 .29906 Mtetra
.597 .29906 .59936 .302 .60398 .30041 .60163 .29747 Mtetra
.978 .696 .419 r
.60163 .29747 .60398 .30041 .60547 .18152 .6032 .17851 Mtetra
.664 .741 .908 r
.6032 .17851 .60547 .18152 .60993 .17989 .60767 .17687 Mtetra
.60767 .17687 .60993 .17989 .6144 .17826 .61215 .17524 Mtetra
.61215 .17524 .6144 .17826 .61888 .17662 .61663 .1736 Mtetra
.61663 .1736 .61888 .17662 .62337 .17499 .62112 .17196 Mtetra
.62112 .17196 .62337 .17499 .62786 .17335 .62562 .17031 Mtetra
.62562 .17031 .62786 .17335 .63236 .1717 .63012 .16867 Mtetra
.63012 .16867 .63236 .1717 .63686 .17006 .63463 .16702 Mtetra
.63463 .16702 .63686 .17006 .64138 .16841 .63915 .16537 Mtetra
.63915 .16537 .64138 .16841 .6459 .16676 .64368 .16371 Mtetra
.64368 .16371 .6459 .16676 .65043 .16511 .64821 .16205 Mtetra
.64821 .16205 .65043 .16511 .65496 .16346 .65275 .16039 Mtetra
.65275 .16039 .65496 .16346 .65951 .1618 .6573 .15873 Mtetra
.6573 .15873 .65951 .1618 .66406 .16014 .66185 .15707 Mtetra
.66185 .15707 .66406 .16014 .66861 .15847 .66642 .1554 Mtetra
.66642 .1554 .66861 .15847 .67318 .15681 .67099 .15373 Mtetra
.67099 .15373 .67318 .15681 .67775 .15514 .67557 .15205 Mtetra
.67557 .15205 .67775 .15514 .68233 .15347 .68015 .15038 Mtetra
.68015 .15038 .68233 .15347 .68692 .1518 .68474 .1487 Mtetra
.68474 .1487 .68692 .1518 .69151 .15012 .68934 .14702 Mtetra
.68934 .14702 .69151 .15012 .69612 .14844 .69395 .14533 Mtetra
.69395 .14533 .69612 .14844 .70073 .14676 .69856 .14365 Mtetra
.69856 .14365 .70073 .14676 .70534 .14507 .70319 .14196 Mtetra
.70319 .14196 .70534 .14507 .70997 .14339 .70782 .14026 Mtetra
.70782 .14026 .70997 .14339 .7146 .1417 .71245 .13857 Mtetra
.71245 .13857 .7146 .1417 .71924 .14 .7171 .13687 Mtetra
.7171 .13687 .71924 .14 .72389 .13831 .72175 .13517 Mtetra
.72175 .13517 .72389 .13831 .72854 .13661 .72641 .13347 Mtetra
.72641 .13347 .72854 .13661 .7332 .13491 .73108 .13176 Mtetra
.73108 .13176 .7332 .13491 .73787 .1332 .73576 .13005 Mtetra
.73576 .13005 .73787 .1332 .74255 .1315 .74044 .12834 Mtetra
.74044 .12834 .74255 .1315 .74724 .12979 .74513 .12662 Mtetra
.74513 .12662 .74724 .12979 .75193 .12807 .74983 .12491 Mtetra
.74983 .12491 .75193 .12807 .75663 .12636 .75453 .12318 Mtetra
.75453 .12318 .75663 .12636 .76134 .12464 .75925 .12146 Mtetra
.75925 .12146 .76134 .12464 .76606 .12292 .76397 .11974 Mtetra
.13033 .34785 .13305 .35038 .13679 .34901 .13408 .34648 Mtetra
.13408 .34648 .13679 .34901 .14055 .34764 .13784 .3451 Mtetra
.13784 .3451 .14055 .34764 .1443 .34627 .1416 .34373 Mtetra
.1416 .34373 .1443 .34627 .14807 .34489 .14536 .34235 Mtetra
.14536 .34235 .14807 .34489 .15184 .34351 .14913 .34097 Mtetra
.14913 .34097 .15184 .34351 .15561 .34213 .15291 .33958 Mtetra
.15291 .33958 .15561 .34213 .15939 .34075 .15669 .3382 Mtetra
.15669 .3382 .15939 .34075 .16317 .33937 .16048 .33681 Mtetra
.16048 .33681 .16317 .33937 .16697 .33798 .16428 .33542 Mtetra
.16428 .33542 .16697 .33798 .17076 .3366 .16808 .33403 Mtetra
.16808 .33403 .17076 .3366 .17456 .33521 .17188 .33263 Mtetra
.17188 .33263 .17456 .33521 .17837 .33381 .17569 .33124 Mtetra
.17569 .33124 .17837 .33381 .18218 .33242 .17951 .32984 Mtetra
.17951 .32984 .18218 .33242 .186 .33102 .18333 .32844 Mtetra
.18333 .32844 .186 .33102 .18983 .32963 .18716 .32704 Mtetra
.18716 .32704 .18983 .32963 .19366 .32823 .19099 .32563 Mtetra
.19099 .32563 .19366 .32823 .19749 .32682 .19483 .32423 Mtetra
.19483 .32423 .19749 .32682 .20134 .32542 .19868 .32282 Mtetra
.19868 .32282 .20134 .32542 .20518 .32401 .20253 .32141 Mtetra
.20253 .32141 .20518 .32401 .20904 .3226 .20638 .32 Mtetra
.20638 .32 .20904 .3226 .2129 .32119 .21025 .31858 Mtetra
.21025 .31858 .2129 .32119 .21676 .31978 .21411 .31717 Mtetra
.21411 .31717 .21676 .31978 .22063 .31836 .21799 .31575 Mtetra
.21799 .31575 .22063 .31836 .22451 .31695 .22187 .31433 Mtetra
.22187 .31433 .22451 .31695 .22839 .31553 .22575 .3129 Mtetra
.22575 .3129 .22839 .31553 .23228 .31411 .22964 .31148 Mtetra
.22964 .31148 .23228 .31411 .23617 .31268 .23354 .31005 Mtetra
.23354 .31005 .23617 .31268 .24007 .31126 .23744 .30862 Mtetra
.23744 .30862 .24007 .31126 .24397 .30983 .24135 .30719 Mtetra
.24135 .30719 .24397 .30983 .24789 .3084 .24527 .30576 Mtetra
.951 .68 .489 r
.24527 .30576 .24789 .3084 .23771 .46844 .23494 .46589 Mtetra
.651 .757 .927 r
.23494 .46589 .23771 .46844 .24183 .46706 .23906 .4645 Mtetra
.23906 .4645 .24183 .46706 .24595 .46568 .24318 .46312 Mtetra
.24318 .46312 .24595 .46568 .25007 .46429 .24731 .46173 Mtetra
.24731 .46173 .25007 .46429 .25421 .4629 .25145 .46034 Mtetra
.25145 .46034 .25421 .4629 .25835 .46151 .2556 .45894 Mtetra
.2556 .45894 .25835 .46151 .2625 .46012 .25975 .45755 Mtetra
.25975 .45755 .2625 .46012 .26665 .45873 .2639 .45615 Mtetra
.2639 .45615 .26665 .45873 .27081 .45733 .26807 .45475 Mtetra
.26807 .45475 .27081 .45733 .27498 .45593 .27224 .45335 Mtetra
.27224 .45335 .27498 .45593 .27915 .45453 .27642 .45194 Mtetra
.27642 .45194 .27915 .45453 .28333 .45313 .2806 .45054 Mtetra
.2806 .45054 .28333 .45313 .28751 .45173 .28479 .44913 Mtetra
.28479 .44913 .28751 .45173 .29171 .45032 .28899 .44772 Mtetra
.28899 .44772 .29171 .45032 .29591 .44891 .29319 .4463 Mtetra
.29319 .4463 .29591 .44891 .30011 .4475 .2974 .44489 Mtetra
.2974 .44489 .30011 .4475 .30433 .44608 .30162 .44347 Mtetra
.955 .695 .503 r
.30162 .44347 .30433 .44608 .30855 .44467 .31642 .28441 Mtetra
.526 .303 .519 r
.31642 .28441 .30855 .44467 .31277 .44325 .32046 .28293 Mtetra
.32046 .28293 .31277 .44325 .31701 .44183 .3245 .28146 Mtetra
.3245 .28146 .31701 .44183 .32356 .40341 .32854 .27998 Mtetra
0 0 .235 r
.32854 .27998 .32356 .40341 .32776 .40197 .3251 .39931 Mtetra
.654 .753 .922 r
.3251 .39931 .32776 .40197 .33197 .40053 .32932 .39787 Mtetra
.32932 .39787 .33197 .40053 .33618 .39909 .33353 .39642 Mtetra
.33353 .39642 .33618 .39909 .3404 .39765 .33776 .39497 Mtetra
.33776 .39497 .3404 .39765 .34463 .3962 .34199 .39352 Mtetra
.34199 .39352 .34463 .3962 .34886 .39475 .34623 .39206 Mtetra
.34623 .39206 .34886 .39475 .3531 .3933 .35047 .39061 Mtetra
.35047 .39061 .3531 .3933 .35735 .39184 .35473 .38915 Mtetra
.35473 .38915 .35735 .39184 .36161 .39038 .35899 .38769 Mtetra
.35899 .38769 .36161 .39038 .36587 .38892 .36325 .38622 Mtetra
.36325 .38622 .36587 .38892 .37014 .38746 .36752 .38476 Mtetra
.36752 .38476 .37014 .38746 .37441 .386 .3718 .38329 Mtetra
.3718 .38329 .37441 .386 .37869 .38453 .37609 .38182 Mtetra
.37609 .38182 .37869 .38453 .38298 .38306 .38038 .38035 Mtetra
.38038 .38035 .38298 .38306 .38728 .38159 .38468 .37887 Mtetra
.38468 .37887 .38728 .38159 .39158 .38012 .38899 .37739 Mtetra
.38899 .37739 .39158 .38012 .39589 .37864 .3933 .37591 Mtetra
.964 .668 .42 r
.3933 .37591 .39589 .37864 .39706 .45802 .3944 .45534 Mtetra
.647 .761 .932 r
.3944 .45534 .39706 .45802 .40149 .45657 .39884 .45388 Mtetra
.39884 .45388 .40149 .45657 .40592 .45512 .40328 .45243 Mtetra
.40328 .45243 .40592 .45512 .41037 .45366 .40773 .45096 Mtetra
.40773 .45096 .41037 .45366 .41482 .4522 .41218 .4495 Mtetra
.41218 .4495 .41482 .4522 .41928 .45074 .41665 .44804 Mtetra
.41665 .44804 .41928 .45074 .42375 .44928 .42112 .44657 Mtetra
.42112 .44657 .42375 .44928 .42822 .44781 .4256 .4451 Mtetra
.4256 .4451 .42822 .44781 .4327 .44634 .43008 .44363 Mtetra
.43008 .44363 .4327 .44634 .43719 .44487 .43458 .44215 Mtetra
.43458 .44215 .43719 .44487 .44169 .4434 .43908 .44067 Mtetra
.43908 .44067 .44169 .4434 .44699 .40896 .44359 .43919 Mtetra
0 0 .131 r
.44359 .43919 .44699 .40896 .45145 .40747 .44888 .40472 Mtetra
.65 .758 .928 r
.44888 .40472 .45145 .40747 .45593 .40598 .45336 .40322 Mtetra
.45336 .40322 .45593 .40598 .46041 .40449 .45785 .40172 Mtetra
.45785 .40172 .46041 .40449 .4649 .40299 .46234 .40022 Mtetra
.46234 .40022 .4649 .40299 .46939 .40149 .46684 .39871 Mtetra
.46684 .39871 .46939 .40149 .4739 .39999 .47135 .39721 Mtetra
.47135 .39721 .4739 .39999 .47841 .39848 .47586 .3957 Mtetra
.47586 .3957 .47841 .39848 .48292 .39697 .48039 .39418 Mtetra
.48039 .39418 .48292 .39697 .48745 .39546 .48492 .39267 Mtetra
.48492 .39267 .48745 .39546 .49198 .39395 .48946 .39115 Mtetra
.48946 .39115 .49198 .39395 .49653 .39244 .494 .38963 Mtetra
.494 .38963 .49653 .39244 .50107 .39092 .49856 .38811 Mtetra
.971 .711 .482 r
.49856 .38811 .50107 .39092 .50598 .3304 .50352 .32755 Mtetra
.655 .752 .921 r
.50352 .32755 .50598 .3304 .51046 .32886 .508 .32601 Mtetra
.508 .32601 .51046 .32886 .51495 .32732 .5125 .32446 Mtetra
.5125 .32446 .51495 .32732 .51945 .32577 .51699 .3229 Mtetra
.51699 .3229 .51945 .32577 .52395 .32422 .5215 .32135 Mtetra
.5215 .32135 .52395 .32422 .52846 .32266 .52602 .31979 Mtetra
.52602 .31979 .52846 .32266 .53297 .32111 .53054 .31823 Mtetra
.53054 .31823 .53297 .32111 .5375 .31955 .53507 .31667 Mtetra
.53507 .31667 .5375 .31955 .54203 .31799 .5396 .3151 Mtetra
.5396 .3151 .54203 .31799 .54657 .31643 .54415 .31354 Mtetra
.54415 .31354 .54657 .31643 .55112 .31486 .5487 .31196 Mtetra
.5487 .31196 .55112 .31486 .55567 .31329 .55326 .31039 Mtetra
.55326 .31039 .55567 .31329 .56023 .31172 .55783 .30882 Mtetra
.55783 .30882 .56023 .31172 .5648 .31015 .5624 .30724 Mtetra
.5624 .30724 .5648 .31015 .56938 .30857 .56698 .30566 Mtetra
.56698 .30566 .56938 .30857 .57396 .30699 .57157 .30407 Mtetra
.57157 .30407 .57396 .30699 .57856 .30541 .57617 .30249 Mtetra
.57617 .30249 .57856 .30541 .58315 .30383 .58077 .3009 Mtetra
.58077 .3009 .58315 .30383 .58776 .30224 .58539 .29931 Mtetra
.58539 .29931 .58776 .30224 .59238 .30065 .59001 .29771 Mtetra
.59001 .29771 .59238 .30065 .597 .29906 .59463 .29612 Mtetra
.59463 .29612 .597 .29906 .60163 .29747 .59927 .29452 Mtetra
.978 .696 .419 r
.59927 .29452 .60163 .29747 .6032 .17851 .60093 .17549 Mtetra
.664 .741 .908 r
.60093 .17549 .6032 .17851 .60767 .17687 .60541 .17385 Mtetra
.60541 .17385 .60767 .17687 .61215 .17524 .60989 .17221 Mtetra
.60989 .17221 .61215 .17524 .61663 .1736 .61437 .17057 Mtetra
.61437 .17057 .61663 .1736 .62112 .17196 .61887 .16892 Mtetra
.61887 .16892 .62112 .17196 .62562 .17031 .62337 .16727 Mtetra
.62337 .16727 .62562 .17031 .63012 .16867 .62788 .16562 Mtetra
.62788 .16562 .63012 .16867 .63463 .16702 .63239 .16397 Mtetra
.63239 .16397 .63463 .16702 .63915 .16537 .63692 .16231 Mtetra
.63692 .16231 .63915 .16537 .64368 .16371 .64145 .16065 Mtetra
.64145 .16065 .64368 .16371 .64821 .16205 .64599 .15899 Mtetra
.64599 .15899 .64821 .16205 .65275 .16039 .65053 .15732 Mtetra
.65053 .15732 .65275 .16039 .6573 .15873 .65509 .15565 Mtetra
.65509 .15565 .6573 .15873 .66185 .15707 .65965 .15398 Mtetra
.65965 .15398 .66185 .15707 .66642 .1554 .66421 .15231 Mtetra
.66421 .15231 .66642 .1554 .67099 .15373 .66879 .15064 Mtetra
.66879 .15064 .67099 .15373 .67557 .15205 .67337 .14896 Mtetra
.67337 .14896 .67557 .15205 .68015 .15038 .67796 .14728 Mtetra
.67796 .14728 .68015 .15038 .68474 .1487 .68256 .14559 Mtetra
.68256 .14559 .68474 .1487 .68934 .14702 .68716 .14391 Mtetra
.68716 .14391 .68934 .14702 .69395 .14533 .69178 .14222 Mtetra
.69178 .14222 .69395 .14533 .69856 .14365 .6964 .14052 Mtetra
.6964 .14052 .69856 .14365 .70319 .14196 .70102 .13883 Mtetra
.70102 .13883 .70319 .14196 .70782 .14026 .70566 .13713 Mtetra
.70566 .13713 .70782 .14026 .71245 .13857 .7103 .13543 Mtetra
.7103 .13543 .71245 .13857 .7171 .13687 .71495 .13373 Mtetra
.71495 .13373 .7171 .13687 .72175 .13517 .71961 .13202 Mtetra
.71961 .13202 .72175 .13517 .72641 .13347 .72428 .13031 Mtetra
.72428 .13031 .72641 .13347 .73108 .13176 .72895 .1286 Mtetra
.72895 .1286 .73108 .13176 .73576 .13005 .73363 .12689 Mtetra
.73363 .12689 .73576 .13005 .74044 .12834 .73832 .12517 Mtetra
.73832 .12517 .74044 .12834 .74513 .12662 .74301 .12345 Mtetra
.74301 .12345 .74513 .12662 .74983 .12491 .74772 .12173 Mtetra
.74772 .12173 .74983 .12491 .75453 .12318 .75243 .12 Mtetra
.75243 .12 .75453 .12318 .75925 .12146 .75715 .11827 Mtetra
.75715 .11827 .75925 .12146 .76397 .11974 .76188 .11654 Mtetra
.12761 .34532 .13033 .34785 .13408 .34648 .13136 .34394 Mtetra
.13136 .34394 .13408 .34648 .13784 .3451 .13512 .34256 Mtetra
.13512 .34256 .13784 .3451 .1416 .34373 .13888 .34118 Mtetra
.13888 .34118 .1416 .34373 .14536 .34235 .14265 .3398 Mtetra
.14265 .3398 .14536 .34235 .14913 .34097 .14642 .33841 Mtetra
.14642 .33841 .14913 .34097 .15291 .33958 .15021 .33702 Mtetra
.15021 .33702 .15291 .33958 .15669 .3382 .15399 .33563 Mtetra
.15399 .33563 .15669 .3382 .16048 .33681 .15778 .33424 Mtetra
.15778 .33424 .16048 .33681 .16428 .33542 .16158 .33285 Mtetra
.16158 .33285 .16428 .33542 .16808 .33403 .16538 .33145 Mtetra
.16538 .33145 .16808 .33403 .17188 .33263 .16919 .33006 Mtetra
.16919 .33006 .17188 .33263 .17569 .33124 .17301 .32866 Mtetra
.17301 .32866 .17569 .33124 .17951 .32984 .17683 .32725 Mtetra
.17683 .32725 .17951 .32984 .18333 .32844 .18065 .32585 Mtetra
.18065 .32585 .18333 .32844 .18716 .32704 .18448 .32444 Mtetra
.18448 .32444 .18716 .32704 .19099 .32563 .18832 .32304 Mtetra
.18832 .32304 .19099 .32563 .19483 .32423 .19216 .32163 Mtetra
.19216 .32163 .19483 .32423 .19868 .32282 .19601 .32021 Mtetra
.19601 .32021 .19868 .32282 .20253 .32141 .19986 .3188 Mtetra
.19986 .3188 .20253 .32141 .20638 .32 .20372 .31738 Mtetra
.20372 .31738 .20638 .32 .21025 .31858 .20759 .31597 Mtetra
.20759 .31597 .21025 .31858 .21411 .31717 .21146 .31455 Mtetra
.21146 .31455 .21411 .31717 .21799 .31575 .21534 .31312 Mtetra
.21534 .31312 .21799 .31575 .22187 .31433 .21922 .3117 Mtetra
.21922 .3117 .22187 .31433 .22575 .3129 .22311 .31027 Mtetra
.22311 .31027 .22575 .3129 .22964 .31148 .227 .30884 Mtetra
.227 .30884 .22964 .31148 .23354 .31005 .2309 .30741 Mtetra
.2309 .30741 .23354 .31005 .23744 .30862 .23481 .30598 Mtetra
.23481 .30598 .23744 .30862 .24135 .30719 .23872 .30454 Mtetra
.23872 .30454 .24135 .30719 .24527 .30576 .24264 .3031 Mtetra
.24264 .3031 .24527 .30576 .23494 .46589 .24656 .30166 Mtetra
0 0 .167 r
.24656 .30166 .23494 .46589 .23906 .4645 .23628 .46194 Mtetra
.651 .757 .927 r
.23628 .46194 .23906 .4645 .24318 .46312 .24041 .46055 Mtetra
.24041 .46055 .24318 .46312 .24731 .46173 .24455 .45916 Mtetra
.24455 .45916 .24731 .46173 .25145 .46034 .24869 .45776 Mtetra
.24869 .45776 .25145 .46034 .2556 .45894 .25284 .45637 Mtetra
.25284 .45637 .2556 .45894 .25975 .45755 .25699 .45497 Mtetra
.25699 .45497 .25975 .45755 .2639 .45615 .26115 .45356 Mtetra
.26115 .45356 .2639 .45615 .26807 .45475 .26532 .45216 Mtetra
.26532 .45216 .26807 .45475 .27224 .45335 .26949 .45075 Mtetra
.26949 .45075 .27224 .45335 .27642 .45194 .27367 .44934 Mtetra
.27367 .44934 .27642 .45194 .2806 .45054 .27786 .44793 Mtetra
.27786 .44793 .2806 .45054 .28479 .44913 .28206 .44652 Mtetra
.28206 .44652 .28479 .44913 .28899 .44772 .28626 .4451 Mtetra
.28626 .4451 .28899 .44772 .29319 .4463 .29047 .44369 Mtetra
.954 .695 .505 r
.29047 .44369 .29319 .4463 .2974 .44489 .3058 .28463 Mtetra
.526 .302 .518 r
.3058 .28463 .2974 .44489 .30162 .44347 .30982 .28316 Mtetra
.30982 .28316 .30162 .44347 .31642 .28441 .31385 .28169 Mtetra
.663 .742 .908 r
.31385 .28169 .31642 .28441 .32046 .28293 .31789 .28021 Mtetra
.31789 .28021 .32046 .28293 .3245 .28146 .32194 .27873 Mtetra
.32194 .27873 .3245 .28146 .32854 .27998 .32599 .27724 Mtetra
.959 .677 .458 r
.32599 .27724 .32854 .27998 .3251 .39931 .32244 .39664 Mtetra
.654 .753 .922 r
.32244 .39664 .3251 .39931 .32932 .39787 .32666 .39519 Mtetra
.32666 .39519 .32932 .39787 .33353 .39642 .33088 .39374 Mtetra
.33088 .39374 .33353 .39642 .33776 .39497 .33511 .39229 Mtetra
.33511 .39229 .33776 .39497 .34199 .39352 .33934 .39083 Mtetra
.33934 .39083 .34199 .39352 .34623 .39206 .34359 .38937 Mtetra
.34359 .38937 .34623 .39206 .35047 .39061 .34784 .38791 Mtetra
.34784 .38791 .35047 .39061 .35473 .38915 .35209 .38645 Mtetra
.35209 .38645 .35473 .38915 .35899 .38769 .35636 .38498 Mtetra
.35636 .38498 .35899 .38769 .36325 .38622 .36063 .38352 Mtetra
.36063 .38352 .36325 .38622 .36752 .38476 .3649 .38205 Mtetra
.3649 .38205 .36752 .38476 .3718 .38329 .36919 .38057 Mtetra
.36919 .38057 .3718 .38329 .37609 .38182 .37348 .3791 Mtetra
.37348 .3791 .37609 .38182 .38038 .38035 .37777 .37762 Mtetra
.37777 .37762 .38038 .38035 .38468 .37887 .38208 .37614 Mtetra
.38208 .37614 .38468 .37887 .38899 .37739 .38639 .37466 Mtetra
.964 .668 .421 r
.38639 .37466 .38899 .37739 .3933 .37591 .38731 .45411 Mtetra
.508 .264 .48 r
.38731 .45411 .3933 .37591 .3944 .45534 .39174 .45265 Mtetra
.647 .761 .932 r
.39174 .45265 .3944 .45534 .39884 .45388 .39618 .45119 Mtetra
.39618 .45119 .39884 .45388 .40328 .45243 .40063 .44973 Mtetra
.40063 .44973 .40328 .45243 .40773 .45096 .40508 .44826 Mtetra
.40508 .44826 .40773 .45096 .41218 .4495 .40954 .4468 Mtetra
.40954 .4468 .41218 .4495 .41665 .44804 .41401 .44533 Mtetra
.41401 .44533 .41665 .44804 .42112 .44657 .41849 .44385 Mtetra
.41849 .44385 .42112 .44657 .4256 .4451 .42297 .44238 Mtetra
.42297 .44238 .4256 .4451 .43008 .44363 .42746 .4409 Mtetra
.42746 .4409 .43008 .44363 .43458 .44215 .43196 .43942 Mtetra
.43196 .43942 .43458 .44215 .43908 .44067 .43647 .43794 Mtetra
.43647 .43794 .43908 .44067 .44359 .43919 .44098 .43646 Mtetra
.963 .726 .533 r
.44098 .43646 .44359 .43919 .44888 .40472 .4463 .40195 Mtetra
.65 .758 .928 r
.4463 .40195 .44888 .40472 .45336 .40322 .45079 .40045 Mtetra
.45079 .40045 .45336 .40322 .45785 .40172 .45528 .39894 Mtetra
.45528 .39894 .45785 .40172 .46234 .40022 .45978 .39744 Mtetra
.45978 .39744 .46234 .40022 .46684 .39871 .46428 .39593 Mtetra
.46428 .39593 .46684 .39871 .47135 .39721 .4688 .39442 Mtetra
.4688 .39442 .47135 .39721 .47586 .3957 .47332 .3929 Mtetra
.47332 .3929 .47586 .3957 .48039 .39418 .47784 .39139 Mtetra
.47784 .39139 .48039 .39418 .48492 .39267 .48238 .38987 Mtetra
.48238 .38987 .48492 .39267 .48946 .39115 .48692 .38835 Mtetra
.48692 .38835 .48946 .39115 .494 .38963 .49147 .38682 Mtetra
.49147 .38682 .494 .38963 .49856 .38811 .49603 .38529 Mtetra
.971 .711 .482 r
.49603 .38529 .49856 .38811 .50352 .32755 .50105 .32469 Mtetra
.655 .752 .921 r
.50105 .32469 .50352 .32755 .508 .32601 .50553 .32314 Mtetra
.50553 .32314 .508 .32601 .5125 .32446 .51003 .32159 Mtetra
.51003 .32159 .5125 .32446 .51699 .3229 .51454 .32003 Mtetra
.51454 .32003 .51699 .3229 .5215 .32135 .51905 .31847 Mtetra
.51905 .31847 .5215 .32135 .52602 .31979 .52357 .31691 Mtetra
.52357 .31691 .52602 .31979 .53054 .31823 .52809 .31534 Mtetra
.52809 .31534 .53054 .31823 .53507 .31667 .53263 .31378 Mtetra
.53263 .31378 .53507 .31667 .5396 .3151 .53717 .31221 Mtetra
.53717 .31221 .5396 .3151 .54415 .31354 .54172 .31063 Mtetra
.54172 .31063 .54415 .31354 .5487 .31196 .54628 .30906 Mtetra
.54628 .30906 .5487 .31196 .55326 .31039 .55084 .30748 Mtetra
.55084 .30748 .55326 .31039 .55783 .30882 .55541 .3059 Mtetra
.55541 .3059 .55783 .30882 .5624 .30724 .55999 .30432 Mtetra
.55999 .30432 .5624 .30724 .56698 .30566 .56458 .30273 Mtetra
.56458 .30273 .56698 .30566 .57157 .30407 .56917 .30114 Mtetra
.56917 .30114 .57157 .30407 .57617 .30249 .57377 .29955 Mtetra
.57377 .29955 .57617 .30249 .58077 .3009 .57838 .29796 Mtetra
.57838 .29796 .58077 .3009 .58539 .29931 .583 .29636 Mtetra
.583 .29636 .58539 .29931 .59001 .29771 .58763 .29476 Mtetra
.58763 .29476 .59001 .29771 .59463 .29612 .59226 .29316 Mtetra
.59226 .29316 .59463 .29612 .59927 .29452 .5969 .29156 Mtetra
.978 .696 .419 r
.5969 .29156 .59927 .29452 .60093 .17549 .59865 .17246 Mtetra
.664 .741 .908 r
.59865 .17246 .60093 .17549 .60541 .17385 .60313 .17082 Mtetra
.60313 .17082 .60541 .17385 .60989 .17221 .60762 .16917 Mtetra
.60762 .16917 .60989 .17221 .61437 .17057 .61211 .16752 Mtetra
.61211 .16752 .61437 .17057 .61887 .16892 .61661 .16587 Mtetra
.61661 .16587 .61887 .16892 .62337 .16727 .62112 .16422 Mtetra
.62112 .16422 .62337 .16727 .62788 .16562 .62563 .16256 Mtetra
.62563 .16256 .62788 .16562 .63239 .16397 .63015 .1609 Mtetra
.63015 .1609 .63239 .16397 .63692 .16231 .63468 .15924 Mtetra
.63468 .15924 .63692 .16231 .64145 .16065 .63921 .15758 Mtetra
.63921 .15758 .64145 .16065 .64599 .15899 .64376 .15591 Mtetra
.64376 .15591 .64599 .15899 .65053 .15732 .64831 .15424 Mtetra
.64831 .15424 .65053 .15732 .65509 .15565 .65287 .15257 Mtetra
.65287 .15257 .65509 .15565 .65965 .15398 .65743 .15089 Mtetra
.65743 .15089 .65965 .15398 .66421 .15231 .662 .14922 Mtetra
.662 .14922 .66421 .15231 .66879 .15064 .66658 .14753 Mtetra
.66658 .14753 .66879 .15064 .67337 .14896 .67117 .14585 Mtetra
.67117 .14585 .67337 .14896 .67796 .14728 .67577 .14417 Mtetra
.67577 .14417 .67796 .14728 .68256 .14559 .68037 .14248 Mtetra
.68037 .14248 .68256 .14559 .68716 .14391 .68498 .14078 Mtetra
.68498 .14078 .68716 .14391 .69178 .14222 .6896 .13909 Mtetra
.6896 .13909 .69178 .14222 .6964 .14052 .69422 .13739 Mtetra
.69422 .13739 .6964 .14052 .70102 .13883 .69886 .13569 Mtetra
.69886 .13569 .70102 .13883 .70566 .13713 .7035 .13399 Mtetra
.7035 .13399 .70566 .13713 .7103 .13543 .70814 .13228 Mtetra
.70814 .13228 .7103 .13543 .71495 .13373 .7128 .13058 Mtetra
.7128 .13058 .71495 .13373 .71961 .13202 .71746 .12886 Mtetra
.71746 .12886 .71961 .13202 .72428 .13031 .72213 .12715 Mtetra
.72213 .12715 .72428 .13031 .72895 .1286 .72681 .12543 Mtetra
.72681 .12543 .72895 .1286 .73363 .12689 .7315 .12371 Mtetra
.7315 .12371 .73363 .12689 .73832 .12517 .73619 .12199 Mtetra
.73619 .12199 .73832 .12517 .74301 .12345 .74089 .12027 Mtetra
.74089 .12027 .74301 .12345 .74772 .12173 .7456 .11854 Mtetra
.7456 .11854 .74772 .12173 .75243 .12 .75032 .11681 Mtetra
.75032 .11681 .75243 .12 .75715 .11827 .75505 .11507 Mtetra
.75505 .11507 .75715 .11827 .76188 .11654 .75978 .11334 Mtetra
.12487 .34277 .12761 .34532 .13136 .34394 .12863 .34139 Mtetra
.12863 .34139 .13136 .34394 .13512 .34256 .13239 .34001 Mtetra
.13239 .34001 .13512 .34256 .13888 .34118 .13616 .33862 Mtetra
.13616 .33862 .13888 .34118 .14265 .3398 .13993 .33724 Mtetra
.13993 .33724 .14265 .3398 .14642 .33841 .14371 .33585 Mtetra
.14371 .33585 .14642 .33841 .15021 .33702 .14749 .33446 Mtetra
.14749 .33446 .15021 .33702 .15399 .33563 .15128 .33306 Mtetra
.15128 .33306 .15399 .33563 .15778 .33424 .15508 .33167 Mtetra
.15508 .33167 .15778 .33424 .16158 .33285 .15888 .33027 Mtetra
.15888 .33027 .16158 .33285 .16538 .33145 .16268 .32887 Mtetra
.16268 .32887 .16538 .33145 .16919 .33006 .16649 .32747 Mtetra
.16649 .32747 .16919 .33006 .17301 .32866 .17031 .32607 Mtetra
.17031 .32607 .17301 .32866 .17683 .32725 .17413 .32466 Mtetra
.17413 .32466 .17683 .32725 .18065 .32585 .17796 .32325 Mtetra
.17796 .32325 .18065 .32585 .18448 .32444 .1818 .32184 Mtetra
.1818 .32184 .18448 .32444 .18832 .32304 .18564 .32043 Mtetra
.18564 .32043 .18832 .32304 .19216 .32163 .18948 .31902 Mtetra
.18948 .31902 .19216 .32163 .19601 .32021 .19333 .3176 Mtetra
.19333 .3176 .19601 .32021 .19986 .3188 .19719 .31618 Mtetra
.19719 .31618 .19986 .3188 .20372 .31738 .20105 .31476 Mtetra
.20105 .31476 .20372 .31738 .20759 .31597 .20492 .31334 Mtetra
.20492 .31334 .20759 .31597 .21146 .31455 .2088 .31192 Mtetra
.2088 .31192 .21146 .31455 .21534 .31312 .21268 .31049 Mtetra
.21268 .31049 .21534 .31312 .21922 .3117 .21657 .30906 Mtetra
.21657 .30906 .21922 .3117 .22311 .31027 .22046 .30763 Mtetra
.22046 .30763 .22311 .31027 .227 .30884 .22435 .3062 Mtetra
.22435 .3062 .227 .30884 .2309 .30741 .22826 .30476 Mtetra
.22826 .30476 .2309 .30741 .23481 .30598 .23217 .30333 Mtetra
.23217 .30333 .23481 .30598 .23872 .30454 .23608 .30189 Mtetra
.23608 .30189 .23872 .30454 .24264 .3031 .24001 .30044 Mtetra
.24001 .30044 .24264 .3031 .24656 .30166 .24393 .299 Mtetra
.951 .68 .488 r
.24393 .299 .24656 .30166 .23628 .46194 .2335 .45937 Mtetra
.651 .757 .927 r
.2335 .45937 .23628 .46194 .24041 .46055 .23763 .45798 Mtetra
.23763 .45798 .24041 .46055 .24455 .45916 .24177 .45658 Mtetra
.24177 .45658 .24455 .45916 .24869 .45776 .24591 .45518 Mtetra
.24591 .45518 .24869 .45776 .25284 .45637 .25007 .45378 Mtetra
.25007 .45378 .25284 .45637 .25699 .45497 .25423 .45238 Mtetra
.25423 .45238 .25699 .45497 .26115 .45356 .25839 .45097 Mtetra
.25839 .45097 .26115 .45356 .26532 .45216 .26256 .44956 Mtetra
.26256 .44956 .26532 .45216 .26949 .45075 .26674 .44815 Mtetra
.26674 .44815 .26949 .45075 .27367 .44934 .27093 .44674 Mtetra
.27093 .44674 .27367 .44934 .27786 .44793 .27512 .44532 Mtetra
.953 .695 .508 r
.27512 .44532 .27786 .44793 .28206 .44652 .29116 .28633 Mtetra
.525 .301 .518 r
.29116 .28633 .28206 .44652 .28626 .4451 .29517 .28486 Mtetra
.29517 .28486 .28626 .4451 .29047 .44369 .29919 .28339 Mtetra
.29919 .28339 .29047 .44369 .3058 .28463 .30321 .28191 Mtetra
.663 .742 .908 r
.30321 .28191 .3058 .28463 .30982 .28316 .30724 .28043 Mtetra
.30724 .28043 .30982 .28316 .31385 .28169 .31128 .27895 Mtetra
.31128 .27895 .31385 .28169 .31789 .28021 .31532 .27747 Mtetra
.31532 .27747 .31789 .28021 .32194 .27873 .31937 .27599 Mtetra
.31937 .27599 .32194 .27873 .32599 .27724 .32342 .2745 Mtetra
.32342 .2745 .32599 .27724 .32244 .39664 .32749 .27301 Mtetra
0 0 .232 r
.32749 .27301 .32244 .39664 .32666 .39519 .32399 .39251 Mtetra
.654 .753 .922 r
.32399 .39251 .32666 .39519 .33088 .39374 .32822 .39106 Mtetra
.32822 .39106 .33088 .39374 .33511 .39229 .33245 .3896 Mtetra
.33245 .3896 .33511 .39229 .33934 .39083 .33669 .38814 Mtetra
.33669 .38814 .33934 .39083 .34359 .38937 .34094 .38668 Mtetra
.34094 .38668 .34359 .38937 .34784 .38791 .34519 .38521 Mtetra
.34519 .38521 .34784 .38791 .35209 .38645 .34945 .38374 Mtetra
.34945 .38374 .35209 .38645 .35636 .38498 .35372 .38227 Mtetra
.35372 .38227 .35636 .38498 .36063 .38352 .35799 .3808 Mtetra
.35799 .3808 .36063 .38352 .3649 .38205 .36227 .37933 Mtetra
.36227 .37933 .3649 .38205 .36919 .38057 .36656 .37785 Mtetra
.36656 .37785 .36919 .38057 .37348 .3791 .37086 .37637 Mtetra
.37086 .37637 .37348 .3791 .37777 .37762 .37516 .37489 Mtetra
.37516 .37489 .37777 .37762 .38208 .37614 .37947 .3734 Mtetra
.37947 .3734 .38208 .37614 .38639 .37466 .38378 .37192 Mtetra
.964 .668 .421 r
.38378 .37192 .38639 .37466 .38731 .45411 .38463 .45141 Mtetra
.647 .761 .932 r
.38463 .45141 .38731 .45411 .39174 .45265 .38907 .44995 Mtetra
.38907 .44995 .39174 .45265 .39618 .45119 .39351 .44849 Mtetra
.39351 .44849 .39618 .45119 .40063 .44973 .39797 .44702 Mtetra
.39797 .44702 .40063 .44973 .40508 .44826 .40242 .44555 Mtetra
.40242 .44555 .40508 .44826 .40954 .4468 .40689 .44408 Mtetra
.40689 .44408 .40954 .4468 .41401 .44533 .41136 .44261 Mtetra
.41136 .44261 .41401 .44533 .41849 .44385 .41584 .44113 Mtetra
.41584 .44113 .41849 .44385 .42297 .44238 .42033 .43965 Mtetra
.42033 .43965 .42297 .44238 .42746 .4409 .42483 .43817 Mtetra
.42483 .43817 .42746 .4409 .43196 .43942 .42933 .43668 Mtetra
.42933 .43668 .43196 .43942 .43647 .43794 .43384 .4352 Mtetra
.43384 .4352 .43647 .43794 .44098 .43646 .43836 .43371 Mtetra
.43836 .43371 .44098 .43646 .4463 .40195 .44289 .43222 Mtetra
0 0 .128 r
.44289 .43222 .4463 .40195 .45079 .40045 .44821 .39767 Mtetra
.65 .758 .928 r
.44821 .39767 .45079 .40045 .45528 .39894 .4527 .39616 Mtetra
.4527 .39616 .45528 .39894 .45978 .39744 .45721 .39465 Mtetra
.45721 .39465 .45978 .39744 .46428 .39593 .46172 .39314 Mtetra
.46172 .39314 .46428 .39593 .4688 .39442 .46623 .39162 Mtetra
.46623 .39162 .4688 .39442 .47332 .3929 .47076 .3901 Mtetra
.47076 .3901 .47332 .3929 .47784 .39139 .47529 .38858 Mtetra
.47529 .38858 .47784 .39139 .48238 .38987 .47983 .38706 Mtetra
.47983 .38706 .48238 .38987 .48692 .38835 .48438 .38553 Mtetra
.48438 .38553 .48692 .38835 .49147 .38682 .48894 .384 Mtetra
.48894 .384 .49147 .38682 .49603 .38529 .4935 .38247 Mtetra
.971 .711 .482 r
.4935 .38247 .49603 .38529 .50105 .32469 .49857 .32183 Mtetra
.655 .752 .921 r
.49857 .32183 .50105 .32469 .50553 .32314 .50306 .32027 Mtetra
.50306 .32027 .50553 .32314 .51003 .32159 .50756 .31871 Mtetra
.50756 .31871 .51003 .32159 .51454 .32003 .51207 .31715 Mtetra
.51207 .31715 .51454 .32003 .51905 .31847 .51659 .31558 Mtetra
.51659 .31558 .51905 .31847 .52357 .31691 .52111 .31402 Mtetra
.52111 .31402 .52357 .31691 .52809 .31534 .52564 .31245 Mtetra
.52564 .31245 .52809 .31534 .53263 .31378 .53018 .31088 Mtetra
.53018 .31088 .53263 .31378 .53717 .31221 .53473 .3093 Mtetra
.53473 .3093 .53717 .31221 .54172 .31063 .53928 .30772 Mtetra
.53928 .30772 .54172 .31063 .54628 .30906 .54384 .30614 Mtetra
.54384 .30614 .54628 .30906 .55084 .30748 .54841 .30456 Mtetra
.54841 .30456 .55084 .30748 .55541 .3059 .55299 .30298 Mtetra
.55299 .30298 .55541 .3059 .55999 .30432 .55757 .30139 Mtetra
.55757 .30139 .55999 .30432 .56458 .30273 .56217 .2998 Mtetra
.56217 .2998 .56458 .30273 .56917 .30114 .56677 .2982 Mtetra
.56677 .2982 .56917 .30114 .57377 .29955 .57137 .29661 Mtetra
.57137 .29661 .57377 .29955 .57838 .29796 .57599 .29501 Mtetra
.57599 .29501 .57838 .29796 .583 .29636 .58061 .29341 Mtetra
.58061 .29341 .583 .29636 .58763 .29476 .58524 .29181 Mtetra
.58524 .29181 .58763 .29476 .59226 .29316 .58988 .2902 Mtetra
.58988 .2902 .59226 .29316 .5969 .29156 .59452 .28859 Mtetra
.978 .696 .419 r
.59452 .28859 .5969 .29156 .59865 .17246 .59637 .16943 Mtetra
.664 .741 .908 r
.59637 .16943 .59865 .17246 .60313 .17082 .60085 .16778 Mtetra
.60085 .16778 .60313 .17082 .60762 .16917 .60534 .16613 Mtetra
.60534 .16613 .60762 .16917 .61211 .16752 .60984 .16447 Mtetra
.60984 .16447 .61211 .16752 .61661 .16587 .61434 .16282 Mtetra
.61434 .16282 .61661 .16587 .62112 .16422 .61885 .16116 Mtetra
.61885 .16116 .62112 .16422 .62563 .16256 .62337 .1595 Mtetra
.62337 .1595 .62563 .16256 .63015 .1609 .6279 .15783 Mtetra
.6279 .15783 .63015 .1609 .63468 .15924 .63243 .15617 Mtetra
.63243 .15617 .63468 .15924 .63921 .15758 .63697 .1545 Mtetra
.63697 .1545 .63921 .15758 .64376 .15591 .64152 .15283 Mtetra
.64152 .15283 .64376 .15591 .64831 .15424 .64608 .15115 Mtetra
.64608 .15115 .64831 .15424 .65287 .15257 .65064 .14947 Mtetra
.65064 .14947 .65287 .15257 .65743 .15089 .65521 .14779 Mtetra
.65521 .14779 .65743 .15089 .662 .14922 .65979 .14611 Mtetra
.65979 .14611 .662 .14922 .66658 .14753 .66437 .14442 Mtetra
.66437 .14442 .66658 .14753 .67117 .14585 .66897 .14274 Mtetra
.66897 .14274 .67117 .14585 .67577 .14417 .67357 .14104 Mtetra
.67357 .14104 .67577 .14417 .68037 .14248 .67817 .13935 Mtetra
.67817 .13935 .68037 .14248 .68498 .14078 .68279 .13765 Mtetra
.68279 .13765 .68498 .14078 .6896 .13909 .68741 .13595 Mtetra
.68741 .13595 .6896 .13909 .69422 .13739 .69204 .13425 Mtetra
.69204 .13425 .69422 .13739 .69886 .13569 .69668 .13255 Mtetra
.69668 .13255 .69886 .13569 .7035 .13399 .70133 .13084 Mtetra
.70133 .13084 .7035 .13399 .70814 .13228 .70598 .12913 Mtetra
.70598 .12913 .70814 .13228 .7128 .13058 .71064 .12741 Mtetra
.71064 .12741 .7128 .13058 .71746 .12886 .71531 .1257 Mtetra
.71531 .1257 .71746 .12886 .72213 .12715 .71998 .12398 Mtetra
.71998 .12398 .72213 .12715 .72681 .12543 .72467 .12226 Mtetra
.72467 .12226 .72681 .12543 .7315 .12371 .72936 .12053 Mtetra
.72936 .12053 .7315 .12371 .73619 .12199 .73406 .1188 Mtetra
.73406 .1188 .73619 .12199 .74089 .12027 .73877 .11707 Mtetra
.73877 .11707 .74089 .12027 .7456 .11854 .74348 .11534 Mtetra
.74348 .11534 .7456 .11854 .75032 .11681 .7482 .1136 Mtetra
.7482 .1136 .75032 .11681 .75505 .11507 .75293 .11187 Mtetra
.75293 .11187 .75505 .11507 .75978 .11334 .75767 .11012 Mtetra
.12213 .34022 .12487 .34277 .12863 .34139 .12589 .33884 Mtetra
.12589 .33884 .12863 .34139 .13239 .34001 .12966 .33745 Mtetra
.12966 .33745 .13239 .34001 .13616 .33862 .13343 .33606 Mtetra
.13343 .33606 .13616 .33862 .13993 .33724 .1372 .33467 Mtetra
.1372 .33467 .13993 .33724 .14371 .33585 .14098 .33328 Mtetra
.14098 .33328 .14371 .33585 .14749 .33446 .14477 .33188 Mtetra
.14477 .33188 .14749 .33446 .15128 .33306 .14856 .33049 Mtetra
.14856 .33049 .15128 .33306 .15508 .33167 .15236 .32909 Mtetra
.15236 .32909 .15508 .33167 .15888 .33027 .15616 .32769 Mtetra
.15616 .32769 .15888 .33027 .16268 .32887 .15997 .32628 Mtetra
.15997 .32628 .16268 .32887 .16649 .32747 .16379 .32488 Mtetra
.16379 .32488 .16649 .32747 .17031 .32607 .16761 .32347 Mtetra
.16761 .32347 .17031 .32607 .17413 .32466 .17144 .32206 Mtetra
.17144 .32206 .17413 .32466 .17796 .32325 .17527 .32065 Mtetra
.17527 .32065 .17796 .32325 .1818 .32184 .17911 .31924 Mtetra
.17911 .31924 .1818 .32184 .18564 .32043 .18295 .31782 Mtetra
.18295 .31782 .18564 .32043 .18948 .31902 .1868 .3164 Mtetra
.1868 .3164 .18948 .31902 .19333 .3176 .19065 .31498 Mtetra
.19065 .31498 .19333 .3176 .19719 .31618 .19451 .31356 Mtetra
.19451 .31356 .19719 .31618 .20105 .31476 .19838 .31214 Mtetra
.19838 .31214 .20105 .31476 .20492 .31334 .20225 .31071 Mtetra
.20225 .31071 .20492 .31334 .2088 .31192 .20613 .30928 Mtetra
.20613 .30928 .2088 .31192 .21268 .31049 .21001 .30785 Mtetra
.21001 .30785 .21268 .31049 .21657 .30906 .2139 .30642 Mtetra
.2139 .30642 .21657 .30906 .22046 .30763 .2178 .30498 Mtetra
.2178 .30498 .22046 .30763 .22435 .3062 .2217 .30355 Mtetra
.2217 .30355 .22435 .3062 .22826 .30476 .22561 .30211 Mtetra
.22561 .30211 .22826 .30476 .23217 .30333 .22952 .30067 Mtetra
.22952 .30067 .23217 .30333 .23608 .30189 .23344 .29922 Mtetra
.23344 .29922 .23608 .30189 .24001 .30044 .23736 .29778 Mtetra
.23736 .29778 .24001 .30044 .24393 .299 .24129 .29633 Mtetra
.24129 .29633 .24393 .299 .2335 .45937 .24523 .29488 Mtetra
0 0 .165 r
.24523 .29488 .2335 .45937 .23763 .45798 .23484 .4554 Mtetra
.651 .757 .927 r
.23484 .4554 .23763 .45798 .24177 .45658 .23899 .454 Mtetra
.23899 .454 .24177 .45658 .24591 .45518 .24313 .45259 Mtetra
.24313 .45259 .24591 .45518 .25007 .45378 .24729 .45119 Mtetra
.24729 .45119 .25007 .45378 .25423 .45238 .25145 .44978 Mtetra
.25145 .44978 .25423 .45238 .25839 .45097 .25562 .44837 Mtetra
.25562 .44837 .25839 .45097 .26256 .44956 .2598 .44695 Mtetra
.951 .694 .511 r
.2598 .44695 .26256 .44956 .26674 .44815 .27655 .28803 Mtetra
.524 .3 .517 r
.27655 .28803 .26674 .44815 .27093 .44674 .28055 .28656 Mtetra
.28055 .28656 .27093 .44674 .27512 .44532 .28455 .28509 Mtetra
.28455 .28509 .27512 .44532 .29116 .28633 .28856 .28361 Mtetra
.663 .742 .908 r
.28856 .28361 .29116 .28633 .29517 .28486 .29258 .28214 Mtetra
.29258 .28214 .29517 .28486 .29919 .28339 .2966 .28066 Mtetra
.2966 .28066 .29919 .28339 .30321 .28191 .30063 .27918 Mtetra
.30063 .27918 .30321 .28191 .30724 .28043 .30466 .2777 Mtetra
.30466 .2777 .30724 .28043 .31128 .27895 .3087 .27622 Mtetra
.3087 .27622 .31128 .27895 .31532 .27747 .31274 .27473 Mtetra
.31274 .27473 .31532 .27747 .31937 .27599 .3168 .27324 Mtetra
.3168 .27324 .31937 .27599 .32342 .2745 .32085 .27175 Mtetra
.32085 .27175 .32342 .2745 .32749 .27301 .32492 .27026 Mtetra
.32492 .27026 .32749 .27301 .32399 .39251 .32899 .26876 Mtetra
0 0 .232 r
.32899 .26876 .32399 .39251 .32822 .39106 .32555 .38836 Mtetra
.654 .753 .922 r
.32555 .38836 .32822 .39106 .33245 .3896 .32979 .3869 Mtetra
.32979 .3869 .33245 .3896 .33669 .38814 .33403 .38544 Mtetra
.33403 .38544 .33669 .38814 .34094 .38668 .33828 .38397 Mtetra
.33828 .38397 .34094 .38668 .34519 .38521 .34254 .3825 Mtetra
.34254 .3825 .34519 .38521 .34945 .38374 .3468 .38103 Mtetra
.3468 .38103 .34945 .38374 .35372 .38227 .35107 .37955 Mtetra
.35107 .37955 .35372 .38227 .35799 .3808 .35535 .37808 Mtetra
.35535 .37808 .35799 .3808 .36227 .37933 .35964 .3766 Mtetra
.35964 .3766 .36227 .37933 .36656 .37785 .36393 .37512 Mtetra
.36393 .37512 .36656 .37785 .37086 .37637 .36823 .37363 Mtetra
.36823 .37363 .37086 .37637 .37516 .37489 .37253 .37215 Mtetra
.37253 .37215 .37516 .37489 .37947 .3734 .37685 .37066 Mtetra
.37685 .37066 .37947 .3734 .38378 .37192 .38117 .36917 Mtetra
.964 .668 .421 r
.38117 .36917 .38378 .37192 .38463 .45141 .38195 .44871 Mtetra
.647 .761 .932 r
.38195 .44871 .38463 .45141 .38907 .44995 .38639 .44725 Mtetra
.38639 .44725 .38907 .44995 .39351 .44849 .39084 .44578 Mtetra
.39084 .44578 .39351 .44849 .39797 .44702 .3953 .44431 Mtetra
.3953 .44431 .39797 .44702 .40242 .44555 .39976 .44283 Mtetra
.39976 .44283 .40242 .44555 .40689 .44408 .40423 .44136 Mtetra
.40423 .44136 .40689 .44408 .41136 .44261 .40871 .43988 Mtetra
.40871 .43988 .41136 .44261 .41584 .44113 .41319 .4384 Mtetra
.41319 .4384 .41584 .44113 .42033 .43965 .41769 .43691 Mtetra
.41769 .43691 .42033 .43965 .42483 .43817 .42219 .43543 Mtetra
.42219 .43543 .42483 .43817 .42933 .43668 .4267 .43394 Mtetra
.4267 .43394 .42933 .43668 .43384 .4352 .43121 .43245 Mtetra
.43121 .43245 .43384 .4352 .43836 .43371 .43573 .43095 Mtetra
.43573 .43095 .43836 .43371 .44289 .43222 .44027 .42946 Mtetra
.44027 .42946 .44289 .43222 .44821 .39767 .4448 .42796 Mtetra
0 0 .128 r
.4448 .42796 .44821 .39767 .4527 .39616 .45012 .39337 Mtetra
.65 .758 .928 r
.45012 .39337 .4527 .39616 .45721 .39465 .45463 .39185 Mtetra
.45463 .39185 .45721 .39465 .46172 .39314 .45914 .39033 Mtetra
.45914 .39033 .46172 .39314 .46623 .39162 .46366 .38881 Mtetra
.46366 .38881 .46623 .39162 .47076 .3901 .46819 .38729 Mtetra
.46819 .38729 .47076 .3901 .47529 .38858 .47273 .38576 Mtetra
.47273 .38576 .47529 .38858 .47983 .38706 .47728 .38424 Mtetra
.47728 .38424 .47983 .38706 .48438 .38553 .48183 .3827 Mtetra
.48183 .3827 .48438 .38553 .48894 .384 .48639 .38117 Mtetra
.48639 .38117 .48894 .384 .4935 .38247 .49096 .37964 Mtetra
.971 .711 .482 r
.49096 .37964 .4935 .38247 .49857 .32183 .49608 .31895 Mtetra
.655 .752 .921 r
.49608 .31895 .49857 .32183 .50306 .32027 .50058 .31739 Mtetra
.50058 .31739 .50306 .32027 .50756 .31871 .50508 .31583 Mtetra
.50508 .31583 .50756 .31871 .51207 .31715 .5096 .31426 Mtetra
.5096 .31426 .51207 .31715 .51659 .31558 .51412 .31269 Mtetra
.51412 .31269 .51659 .31558 .52111 .31402 .51865 .31112 Mtetra
.51865 .31112 .52111 .31402 .52564 .31245 .52318 .30954 Mtetra
.52318 .30954 .52564 .31245 .53018 .31088 .52773 .30797 Mtetra
.52773 .30797 .53018 .31088 .53473 .3093 .53228 .30639 Mtetra
.53228 .30639 .53473 .3093 .53928 .30772 .53684 .3048 Mtetra
.53684 .3048 .53928 .30772 .54384 .30614 .5414 .30322 Mtetra
.5414 .30322 .54384 .30614 .54841 .30456 .54598 .30163 Mtetra
.54598 .30163 .54841 .30456 .55299 .30298 .55056 .30004 Mtetra
.55056 .30004 .55299 .30298 .55757 .30139 .55515 .29845 Mtetra
.55515 .29845 .55757 .30139 .56217 .2998 .55975 .29685 Mtetra
.55975 .29685 .56217 .2998 .56677 .2982 .56435 .29526 Mtetra
.56435 .29526 .56677 .2982 .57137 .29661 .56896 .29366 Mtetra
.56896 .29366 .57137 .29661 .57599 .29501 .57358 .29205 Mtetra
.57358 .29205 .57599 .29501 .58061 .29341 .57821 .29045 Mtetra
.57821 .29045 .58061 .29341 .58524 .29181 .58285 .28884 Mtetra
.58285 .28884 .58524 .29181 .58988 .2902 .58749 .28723 Mtetra
.58749 .28723 .58988 .2902 .59452 .28859 .59214 .28561 Mtetra
.978 .696 .419 r
.59214 .28561 .59452 .28859 .59637 .16943 .59408 .16638 Mtetra
.664 .741 .908 r
.59408 .16638 .59637 .16943 .60085 .16778 .59856 .16473 Mtetra
.59856 .16473 .60085 .16778 .60534 .16613 .60306 .16307 Mtetra
.60306 .16307 .60534 .16613 .60984 .16447 .60756 .16142 Mtetra
.60756 .16142 .60984 .16447 .61434 .16282 .61207 .15975 Mtetra
.61207 .15975 .61434 .16282 .61885 .16116 .61659 .15809 Mtetra
.61659 .15809 .61885 .16116 .62337 .1595 .62111 .15642 Mtetra
.62111 .15642 .62337 .1595 .6279 .15783 .62564 .15476 Mtetra
.62564 .15476 .6279 .15783 .63243 .15617 .63018 .15308 Mtetra
.63018 .15308 .63243 .15617 .63697 .1545 .63472 .15141 Mtetra
.63472 .15141 .63697 .1545 .64152 .15283 .63928 .14973 Mtetra
.63928 .14973 .64152 .15283 .64608 .15115 .64384 .14805 Mtetra
.64384 .14805 .64608 .15115 .65064 .14947 .64841 .14637 Mtetra
.64841 .14637 .65064 .14947 .65521 .14779 .65298 .14468 Mtetra
.65298 .14468 .65521 .14779 .65979 .14611 .65757 .143 Mtetra
.65757 .143 .65979 .14611 .66437 .14442 .66216 .14131 Mtetra
.66216 .14131 .66437 .14442 .66897 .14274 .66675 .13961 Mtetra
.66675 .13961 .66897 .14274 .67357 .14104 .67136 .13792 Mtetra
.67136 .13792 .67357 .14104 .67817 .13935 .67597 .13622 Mtetra
.67597 .13622 .67817 .13935 .68279 .13765 .68059 .13451 Mtetra
.68059 .13451 .68279 .13765 .68741 .13595 .68522 .13281 Mtetra
.68522 .13281 .68741 .13595 .69204 .13425 .68986 .1311 Mtetra
.68986 .1311 .69204 .13425 .69668 .13255 .6945 .12939 Mtetra
.6945 .12939 .69668 .13255 .70133 .13084 .69915 .12768 Mtetra
.69915 .12768 .70133 .13084 .70598 .12913 .70381 .12596 Mtetra
.70381 .12596 .70598 .12913 .71064 .12741 .70847 .12424 Mtetra
.70847 .12424 .71064 .12741 .71531 .1257 .71315 .12252 Mtetra
.71315 .12252 .71531 .1257 .71998 .12398 .71783 .1208 Mtetra
.71783 .1208 .71998 .12398 .72467 .12226 .72252 .11907 Mtetra
.72252 .11907 .72467 .12226 .72936 .12053 .72722 .11734 Mtetra
.72722 .11734 .72936 .12053 .73406 .1188 .73192 .11561 Mtetra
.73192 .11561 .73406 .1188 .73877 .11707 .73663 .11387 Mtetra
.73663 .11387 .73877 .11707 .74348 .11534 .74135 .11213 Mtetra
.74135 .11213 .74348 .11534 .7482 .1136 .74608 .11039 Mtetra
.74608 .11039 .7482 .1136 .75293 .11187 .75082 .10865 Mtetra
.75082 .10865 .75293 .11187 .75767 .11012 .75556 .1069 Mtetra
.11939 .33766 .12213 .34022 .12589 .33884 .12315 .33627 Mtetra
.12315 .33627 .12589 .33884 .12966 .33745 .12692 .33488 Mtetra
.12692 .33488 .12966 .33745 .13343 .33606 .13069 .33349 Mtetra
.13069 .33349 .13343 .33606 .1372 .33467 .13447 .3321 Mtetra
.13447 .3321 .1372 .33467 .14098 .33328 .13825 .3307 Mtetra
.13825 .3307 .14098 .33328 .14477 .33188 .14204 .3293 Mtetra
.14204 .3293 .14477 .33188 .14856 .33049 .14584 .3279 Mtetra
.14584 .3279 .14856 .33049 .15236 .32909 .14964 .3265 Mtetra
.14964 .3265 .15236 .32909 .15616 .32769 .15345 .32509 Mtetra
.15345 .32509 .15616 .32769 .15997 .32628 .15726 .32369 Mtetra
.15726 .32369 .15997 .32628 .16379 .32488 .16108 .32228 Mtetra
.16108 .32228 .16379 .32488 .16761 .32347 .1649 .32087 Mtetra
.1649 .32087 .16761 .32347 .17144 .32206 .16873 .31945 Mtetra
.16873 .31945 .17144 .32206 .17527 .32065 .17257 .31804 Mtetra
.17257 .31804 .17527 .32065 .17911 .31924 .17641 .31662 Mtetra
.17641 .31662 .17911 .31924 .18295 .31782 .18025 .3152 Mtetra
.18025 .3152 .18295 .31782 .1868 .3164 .18411 .31378 Mtetra
.18411 .31378 .1868 .3164 .19065 .31498 .18796 .31236 Mtetra
.18796 .31236 .19065 .31498 .19451 .31356 .19183 .31093 Mtetra
.19183 .31093 .19451 .31356 .19838 .31214 .1957 .3095 Mtetra
.1957 .3095 .19838 .31214 .20225 .31071 .19957 .30807 Mtetra
.19957 .30807 .20225 .31071 .20613 .30928 .20345 .30664 Mtetra
.20345 .30664 .20613 .30928 .21001 .30785 .20734 .3052 Mtetra
.20734 .3052 .21001 .30785 .2139 .30642 .21123 .30377 Mtetra
.21123 .30377 .2139 .30642 .2178 .30498 .21513 .30233 Mtetra
.21513 .30233 .2178 .30498 .2217 .30355 .21904 .30089 Mtetra
.21904 .30089 .2217 .30355 .22561 .30211 .22295 .29944 Mtetra
.22295 .29944 .22561 .30211 .22952 .30067 .22686 .298 Mtetra
.22686 .298 .22952 .30067 .23344 .29922 .23079 .29655 Mtetra
.23079 .29655 .23344 .29922 .23736 .29778 .23472 .2951 Mtetra
.23472 .2951 .23736 .29778 .24129 .29633 .23865 .29365 Mtetra
.23865 .29365 .24129 .29633 .24523 .29488 .24259 .2922 Mtetra
.951 .68 .487 r
.24259 .2922 .24523 .29488 .23484 .4554 .23205 .45281 Mtetra
.651 .757 .927 r
.23205 .45281 .23484 .4554 .23899 .454 .23619 .4514 Mtetra
.23619 .4514 .23899 .454 .24313 .45259 .24035 .44999 Mtetra
.24035 .44999 .24313 .45259 .24729 .45119 .24451 .44858 Mtetra
.24451 .44858 .24729 .45119 .25145 .44978 .24867 .44717 Mtetra
.951 .694 .513 r
.24867 .44717 .25145 .44978 .25562 .44837 .26595 .28825 Mtetra
.524 .3 .516 r
.26595 .28825 .25562 .44837 .2598 .44695 .26994 .28678 Mtetra
.26994 .28678 .2598 .44695 .27655 .28803 .27394 .28531 Mtetra
.663 .742 .908 r
.27394 .28531 .27655 .28803 .28055 .28656 .27794 .28384 Mtetra
.27794 .28384 .28055 .28656 .28455 .28509 .28194 .28237 Mtetra
.28194 .28237 .28455 .28509 .28856 .28361 .28596 .28089 Mtetra
.28596 .28089 .28856 .28361 .29258 .28214 .28997 .27941 Mtetra
.28997 .27941 .29258 .28214 .2966 .28066 .294 .27793 Mtetra
.294 .27793 .2966 .28066 .30063 .27918 .29803 .27644 Mtetra
.29803 .27644 .30063 .27918 .30466 .2777 .30207 .27496 Mtetra
.30207 .27496 .30466 .2777 .3087 .27622 .30611 .27347 Mtetra
.30611 .27347 .3087 .27622 .31274 .27473 .31016 .27198 Mtetra
.31016 .27198 .31274 .27473 .3168 .27324 .31422 .27049 Mtetra
.31422 .27049 .3168 .27324 .32085 .27175 .31828 .26899 Mtetra
.31828 .26899 .32085 .27175 .32492 .27026 .32235 .26749 Mtetra
.32235 .26749 .32492 .27026 .32899 .26876 .32642 .26599 Mtetra
.96 .677 .455 r
.32642 .26599 .32899 .26876 .32555 .38836 .32287 .38566 Mtetra
.654 .753 .922 r
.32287 .38566 .32555 .38836 .32979 .3869 .32711 .38419 Mtetra
.32711 .38419 .32979 .3869 .33403 .38544 .33136 .38273 Mtetra
.33136 .38273 .33403 .38544 .33828 .38397 .33562 .38125 Mtetra
.33562 .38125 .33828 .38397 .34254 .3825 .33988 .37978 Mtetra
.33988 .37978 .34254 .3825 .3468 .38103 .34415 .3783 Mtetra
.34415 .3783 .3468 .38103 .35107 .37955 .34842 .37683 Mtetra
.34842 .37683 .35107 .37955 .35535 .37808 .3527 .37534 Mtetra
.3527 .37534 .35535 .37808 .35964 .3766 .35699 .37386 Mtetra
.35699 .37386 .35964 .3766 .36393 .37512 .36129 .37238 Mtetra
.36129 .37238 .36393 .37512 .36823 .37363 .36559 .37089 Mtetra
.36559 .37089 .36823 .37363 .37253 .37215 .3699 .3694 Mtetra
.3699 .3694 .37253 .37215 .37685 .37066 .37422 .3679 Mtetra
.37422 .3679 .37685 .37066 .38117 .36917 .37854 .36641 Mtetra
.964 .668 .421 r
.37854 .36641 .38117 .36917 .38195 .44871 .37926 .446 Mtetra
.647 .761 .932 r
.37926 .446 .38195 .44871 .38639 .44725 .38371 .44453 Mtetra
.38371 .44453 .38639 .44725 .39084 .44578 .38816 .44306 Mtetra
.38816 .44306 .39084 .44578 .3953 .44431 .39262 .44158 Mtetra
.39262 .44158 .3953 .44431 .39976 .44283 .39709 .44011 Mtetra
.39709 .44011 .39976 .44283 .40423 .44136 .40156 .43862 Mtetra
.40156 .43862 .40423 .44136 .40871 .43988 .40605 .43714 Mtetra
.40605 .43714 .40871 .43988 .41319 .4384 .41054 .43566 Mtetra
.41054 .43566 .41319 .4384 .41769 .43691 .41503 .43417 Mtetra
.41503 .43417 .41769 .43691 .42219 .43543 .41954 .43268 Mtetra
.41954 .43268 .42219 .43543 .4267 .43394 .42405 .43118 Mtetra
.42405 .43118 .4267 .43394 .43121 .43245 .42857 .42969 Mtetra
.42857 .42969 .43121 .43245 .43573 .43095 .4331 .42819 Mtetra
.4331 .42819 .43573 .43095 .44027 .42946 .43764 .42669 Mtetra
.43764 .42669 .44027 .42946 .4448 .42796 .44218 .42518 Mtetra
.44218 .42518 .4448 .42796 .45012 .39337 .44673 .42368 Mtetra
0 0 .128 r
.44673 .42368 .45012 .39337 .45463 .39185 .45204 .38905 Mtetra
.65 .758 .928 r
.45204 .38905 .45463 .39185 .45914 .39033 .45656 .38753 Mtetra
.45656 .38753 .45914 .39033 .46366 .38881 .46109 .386 Mtetra
.46109 .386 .46366 .38881 .46819 .38729 .46562 .38447 Mtetra
.46562 .38447 .46819 .38729 .47273 .38576 .47016 .38294 Mtetra
.47016 .38294 .47273 .38576 .47728 .38424 .47471 .38141 Mtetra
.47471 .38141 .47728 .38424 .48183 .3827 .47927 .37987 Mtetra
.47927 .37987 .48183 .3827 .48639 .38117 .48384 .37833 Mtetra
.48384 .37833 .48639 .38117 .49096 .37964 .48841 .37679 Mtetra
.971 .711 .482 r
.48841 .37679 .49096 .37964 .49608 .31895 .49358 .31607 Mtetra
.655 .752 .921 r
.49358 .31607 .49608 .31895 .50058 .31739 .49809 .3145 Mtetra
.49809 .3145 .50058 .31739 .50508 .31583 .5026 .31293 Mtetra
.5026 .31293 .50508 .31583 .5096 .31426 .50712 .31136 Mtetra
.50712 .31136 .5096 .31426 .51412 .31269 .51164 .30979 Mtetra
.51164 .30979 .51412 .31269 .51865 .31112 .51618 .30821 Mtetra
.51618 .30821 .51865 .31112 .52318 .30954 .52072 .30663 Mtetra
.52072 .30663 .52318 .30954 .52773 .30797 .52527 .30505 Mtetra
.52527 .30505 .52773 .30797 .53228 .30639 .52982 .30346 Mtetra
.52982 .30346 .53228 .30639 .53684 .3048 .53439 .30188 Mtetra
.53439 .30188 .53684 .3048 .5414 .30322 .53896 .30029 Mtetra
.53896 .30029 .5414 .30322 .54598 .30163 .54354 .29869 Mtetra
.54354 .29869 .54598 .30163 .55056 .30004 .54812 .2971 Mtetra
.54812 .2971 .55056 .30004 .55515 .29845 .55272 .2955 Mtetra
.55272 .2955 .55515 .29845 .55975 .29685 .55732 .2939 Mtetra
.55732 .2939 .55975 .29685 .56435 .29526 .56193 .2923 Mtetra
.56193 .2923 .56435 .29526 .56896 .29366 .56655 .29069 Mtetra
.56655 .29069 .56896 .29366 .57358 .29205 .57117 .28909 Mtetra
.57117 .28909 .57358 .29205 .57821 .29045 .5758 .28747 Mtetra
.5758 .28747 .57821 .29045 .58285 .28884 .58044 .28586 Mtetra
.58044 .28586 .58285 .28884 .58749 .28723 .58509 .28424 Mtetra
.58509 .28424 .58749 .28723 .59214 .28561 .58975 .28262 Mtetra
.978 .696 .419 r
.58975 .28262 .59214 .28561 .59408 .16638 .59178 .16333 Mtetra
.664 .741 .908 r
.59178 .16333 .59408 .16638 .59856 .16473 .59627 .16167 Mtetra
.59627 .16167 .59856 .16473 .60306 .16307 .60077 .16001 Mtetra
.60077 .16001 .60306 .16307 .60756 .16142 .60528 .15835 Mtetra
.60528 .15835 .60756 .16142 .61207 .15975 .60979 .15668 Mtetra
.60979 .15668 .61207 .15975 .61659 .15809 .61431 .15501 Mtetra
.61431 .15501 .61659 .15809 .62111 .15642 .61884 .15334 Mtetra
.61884 .15334 .62111 .15642 .62564 .15476 .62338 .15167 Mtetra
.62338 .15167 .62564 .15476 .63018 .15308 .62792 .14999 Mtetra
.62792 .14999 .63018 .15308 .63472 .15141 .63247 .14831 Mtetra
.63247 .14831 .63472 .15141 .63928 .14973 .63703 .14663 Mtetra
.63703 .14663 .63928 .14973 .64384 .14805 .64159 .14494 Mtetra
.64159 .14494 .64384 .14805 .64841 .14637 .64617 .14326 Mtetra
.64617 .14326 .64841 .14637 .65298 .14468 .65075 .14157 Mtetra
.65075 .14157 .65298 .14468 .65757 .143 .65534 .13987 Mtetra
.65534 .13987 .65757 .143 .66216 .14131 .65993 .13818 Mtetra
.65993 .13818 .66216 .14131 .66675 .13961 .66453 .13648 Mtetra
.66453 .13648 .66675 .13961 .67136 .13792 .66914 .13478 Mtetra
.66914 .13478 .67136 .13792 .67597 .13622 .67376 .13307 Mtetra
.67376 .13307 .67597 .13622 .68059 .13451 .67839 .13136 Mtetra
.67839 .13136 .68059 .13451 .68522 .13281 .68302 .12965 Mtetra
.68302 .12965 .68522 .13281 .68986 .1311 .68766 .12794 Mtetra
.68766 .12794 .68986 .1311 .6945 .12939 .69231 .12623 Mtetra
.69231 .12623 .6945 .12939 .69915 .12768 .69697 .12451 Mtetra
.69697 .12451 .69915 .12768 .70381 .12596 .70163 .12279 Mtetra
.70163 .12279 .70381 .12596 .70847 .12424 .7063 .12106 Mtetra
.7063 .12106 .70847 .12424 .71315 .12252 .71098 .11934 Mtetra
.71098 .11934 .71315 .12252 .71783 .1208 .71567 .11761 Mtetra
.71567 .11761 .71783 .1208 .72252 .11907 .72036 .11587 Mtetra
.72036 .11587 .72252 .11907 .72722 .11734 .72506 .11414 Mtetra
.72506 .11414 .72722 .11734 .73192 .11561 .72977 .1124 Mtetra
.72977 .1124 .73192 .11561 .73663 .11387 .73449 .11066 Mtetra
.73449 .11066 .73663 .11387 .74135 .11213 .73922 .10892 Mtetra
.73922 .10892 .74135 .11213 .74608 .11039 .74395 .10717 Mtetra
.74395 .10717 .74608 .11039 .75082 .10865 .74869 .10542 Mtetra
.74869 .10542 .75082 .10865 .75556 .1069 .75344 .10367 Mtetra
.11663 .3351 .11939 .33766 .12315 .33627 .1204 .33371 Mtetra
.1204 .33371 .12315 .33627 .12692 .33488 .12417 .33231 Mtetra
.12417 .33231 .12692 .33488 .13069 .33349 .12795 .33092 Mtetra
.12795 .33092 .13069 .33349 .13447 .3321 .13173 .32952 Mtetra
.13173 .32952 .13447 .3321 .13825 .3307 .13551 .32812 Mtetra
.13551 .32812 .13825 .3307 .14204 .3293 .13931 .32671 Mtetra
.13931 .32671 .14204 .3293 .14584 .3279 .14311 .32531 Mtetra
.14311 .32531 .14584 .3279 .14964 .3265 .14691 .3239 Mtetra
.14691 .3239 .14964 .3265 .15345 .32509 .15072 .32249 Mtetra
.15072 .32249 .15345 .32509 .15726 .32369 .15454 .32108 Mtetra
.15454 .32108 .15726 .32369 .16108 .32228 .15836 .31967 Mtetra
.15836 .31967 .16108 .32228 .1649 .32087 .16218 .31826 Mtetra
.16218 .31826 .1649 .32087 .16873 .31945 .16602 .31684 Mtetra
.16602 .31684 .16873 .31945 .17257 .31804 .16986 .31542 Mtetra
.16986 .31542 .17257 .31804 .17641 .31662 .1737 .314 Mtetra
.1737 .314 .17641 .31662 .18025 .3152 .17755 .31257 Mtetra
.17755 .31257 .18025 .3152 .18411 .31378 .18141 .31115 Mtetra
.18141 .31115 .18411 .31378 .18796 .31236 .18527 .30972 Mtetra
.18527 .30972 .18796 .31236 .19183 .31093 .18913 .30829 Mtetra
.18913 .30829 .19183 .31093 .1957 .3095 .19301 .30686 Mtetra
.19301 .30686 .1957 .3095 .19957 .30807 .19689 .30543 Mtetra
.19689 .30543 .19957 .30807 .20345 .30664 .20077 .30399 Mtetra
.20077 .30399 .20345 .30664 .20734 .3052 .20466 .30255 Mtetra
.20466 .30255 .20734 .3052 .21123 .30377 .20856 .30111 Mtetra
.20856 .30111 .21123 .30377 .21513 .30233 .21246 .29967 Mtetra
.21246 .29967 .21513 .30233 .21904 .30089 .21637 .29822 Mtetra
.21637 .29822 .21904 .30089 .22295 .29944 .22028 .29677 Mtetra
.22028 .29677 .22295 .29944 .22686 .298 .2242 .29532 Mtetra
.2242 .29532 .22686 .298 .23079 .29655 .22813 .29387 Mtetra
.22813 .29387 .23079 .29655 .23472 .2951 .23206 .29242 Mtetra
.23206 .29242 .23472 .2951 .23865 .29365 .236 .29096 Mtetra
.236 .29096 .23865 .29365 .24259 .2922 .23994 .28951 Mtetra
.23994 .28951 .24259 .2922 .23205 .45281 .24389 .28804 Mtetra
0 0 .162 r
.24389 .28804 .23205 .45281 .23619 .4514 .23339 .4488 Mtetra
.949 .694 .516 r
.23339 .4488 .23619 .4514 .24035 .44999 .25138 .28994 Mtetra
.523 .299 .516 r
.25138 .28994 .24035 .44999 .24451 .44858 .25536 .28848 Mtetra
.25536 .28848 .24451 .44858 .24867 .44717 .25934 .28701 Mtetra
.25934 .28701 .24867 .44717 .26595 .28825 .26332 .28554 Mtetra
.663 .742 .908 r
.26332 .28554 .26595 .28825 .26994 .28678 .26731 .28407 Mtetra
.26731 .28407 .26994 .28678 .27394 .28531 .27131 .28259 Mtetra
.27131 .28259 .27394 .28531 .27794 .28384 .27532 .28112 Mtetra
.27532 .28112 .27794 .28384 .28194 .28237 .27933 .27964 Mtetra
.27933 .27964 .28194 .28237 .28596 .28089 .28334 .27816 Mtetra
.28334 .27816 .28596 .28089 .28997 .27941 .28736 .27667 Mtetra
.28736 .27667 .28997 .27941 .294 .27793 .29139 .27519 Mtetra
.29139 .27519 .294 .27793 .29803 .27644 .29543 .2737 Mtetra
.29543 .2737 .29803 .27644 .30207 .27496 .29947 .27221 Mtetra
.29947 .27221 .30207 .27496 .30611 .27347 .30351 .27072 Mtetra
.30351 .27072 .30611 .27347 .31016 .27198 .30757 .26922 Mtetra
.30757 .26922 .31016 .27198 .31422 .27049 .31163 .26772 Mtetra
.31163 .26772 .31422 .27049 .31828 .26899 .31569 .26622 Mtetra
.31569 .26622 .31828 .26899 .32235 .26749 .31977 .26472 Mtetra
.31977 .26472 .32235 .26749 .32642 .26599 .32384 .26322 Mtetra
.32384 .26322 .32642 .26599 .32287 .38566 .32793 .26171 Mtetra
0 0 .229 r
.32793 .26171 .32287 .38566 .32711 .38419 .32443 .38148 Mtetra
.654 .753 .922 r
.32443 .38148 .32711 .38419 .33136 .38273 .32868 .38001 Mtetra
.32868 .38001 .33136 .38273 .33562 .38125 .33294 .37853 Mtetra
.33294 .37853 .33562 .38125 .33988 .37978 .33721 .37705 Mtetra
.33721 .37705 .33988 .37978 .34415 .3783 .34148 .37557 Mtetra
.34148 .37557 .34415 .3783 .34842 .37683 .34576 .37409 Mtetra
.34576 .37409 .34842 .37683 .3527 .37534 .35005 .3726 Mtetra
.35005 .3726 .3527 .37534 .35699 .37386 .35434 .37112 Mtetra
.35434 .37112 .35699 .37386 .36129 .37238 .35864 .36963 Mtetra
.35864 .36963 .36129 .37238 .36559 .37089 .36295 .36813 Mtetra
.36295 .36813 .36559 .37089 .3699 .3694 .36726 .36664 Mtetra
.36726 .36664 .3699 .3694 .37422 .3679 .37159 .36514 Mtetra
.37159 .36514 .37422 .3679 .37854 .36641 .37591 .36364 Mtetra
.964 .668 .421 r
.37591 .36364 .37854 .36641 .37926 .446 .37656 .44329 Mtetra
.647 .761 .932 r
.37656 .44329 .37926 .446 .38371 .44453 .38101 .44181 Mtetra
.38101 .44181 .38371 .44453 .38816 .44306 .38547 .44033 Mtetra
.38547 .44033 .38816 .44306 .39262 .44158 .38994 .43885 Mtetra
.38994 .43885 .39262 .44158 .39709 .44011 .39441 .43737 Mtetra
.39441 .43737 .39709 .44011 .40156 .43862 .39889 .43588 Mtetra
.39889 .43588 .40156 .43862 .40605 .43714 .40338 .4344 Mtetra
.40338 .4344 .40605 .43714 .41054 .43566 .40787 .43291 Mtetra
.40787 .43291 .41054 .43566 .41503 .43417 .41237 .43141 Mtetra
.41237 .43141 .41503 .43417 .41954 .43268 .41688 .42992 Mtetra
.41688 .42992 .41954 .43268 .42405 .43118 .4214 .42842 Mtetra
.4214 .42842 .42405 .43118 .42857 .42969 .42593 .42692 Mtetra
.42593 .42692 .42857 .42969 .4331 .42819 .43046 .42542 Mtetra
.43046 .42542 .4331 .42819 .43764 .42669 .435 .42391 Mtetra
.435 .42391 .43764 .42669 .44218 .42518 .43955 .4224 Mtetra
.43955 .4224 .44218 .42518 .44673 .42368 .4441 .42089 Mtetra
.4441 .42089 .44673 .42368 .45204 .38905 .44866 .41938 Mtetra
0 0 .128 r
.44866 .41938 .45204 .38905 .45656 .38753 .45397 .38471 Mtetra
.65 .758 .928 r
.45397 .38471 .45656 .38753 .46109 .386 .4585 .38318 Mtetra
.4585 .38318 .46109 .386 .46562 .38447 .46304 .38164 Mtetra
.46304 .38164 .46562 .38447 .47016 .38294 .46759 .38011 Mtetra
.46759 .38011 .47016 .38294 .47471 .38141 .47214 .37857 Mtetra
.47214 .37857 .47471 .38141 .47927 .37987 .47671 .37703 Mtetra
.47671 .37703 .47927 .37987 .48384 .37833 .48128 .37549 Mtetra
.48128 .37549 .48384 .37833 .48841 .37679 .48585 .37394 Mtetra
.971 .711 .482 r
.48585 .37394 .48841 .37679 .49358 .31607 .49108 .31317 Mtetra
.655 .752 .921 r
.49108 .31317 .49358 .31607 .49809 .3145 .49559 .3116 Mtetra
.49559 .3116 .49809 .3145 .5026 .31293 .5001 .31003 Mtetra
.5001 .31003 .5026 .31293 .50712 .31136 .50463 .30845 Mtetra
.50463 .30845 .50712 .31136 .51164 .30979 .50916 .30687 Mtetra
.50916 .30687 .51164 .30979 .51618 .30821 .5137 .30529 Mtetra
.5137 .30529 .51618 .30821 .52072 .30663 .51824 .30371 Mtetra
.51824 .30371 .52072 .30663 .52527 .30505 .5228 .30212 Mtetra
.5228 .30212 .52527 .30505 .52982 .30346 .52736 .30053 Mtetra
.52736 .30053 .52982 .30346 .53439 .30188 .53193 .29894 Mtetra
.53193 .29894 .53439 .30188 .53896 .30029 .5365 .29735 Mtetra
.5365 .29735 .53896 .30029 .54354 .29869 .54109 .29575 Mtetra
.54109 .29575 .54354 .29869 .54812 .2971 .54568 .29415 Mtetra
.54568 .29415 .54812 .2971 .55272 .2955 .55028 .29255 Mtetra
.55028 .29255 .55272 .2955 .55732 .2939 .55489 .29094 Mtetra
.55489 .29094 .55732 .2939 .56193 .2923 .5595 .28933 Mtetra
.5595 .28933 .56193 .2923 .56655 .29069 .56412 .28772 Mtetra
.56412 .28772 .56655 .29069 .57117 .28909 .56875 .28611 Mtetra
.56875 .28611 .57117 .28909 .5758 .28747 .57339 .28449 Mtetra
.57339 .28449 .5758 .28747 .58044 .28586 .57804 .28287 Mtetra
.57804 .28287 .58044 .28586 .58509 .28424 .58269 .28125 Mtetra
.978 .696 .421 r
.58269 .28125 .58509 .28424 .58975 .28262 .58498 .16193 Mtetra
.525 .303 .52 r
.58498 .16193 .58975 .28262 .59178 .16333 .58947 .16027 Mtetra
.664 .741 .908 r
.58947 .16027 .59178 .16333 .59627 .16167 .59397 .1586 Mtetra
.59397 .1586 .59627 .16167 .60077 .16001 .59847 .15694 Mtetra
.59847 .15694 .60077 .16001 .60528 .15835 .60298 .15527 Mtetra
.60298 .15527 .60528 .15835 .60979 .15668 .6075 .1536 Mtetra
.6075 .1536 .60979 .15668 .61431 .15501 .61203 .15192 Mtetra
.61203 .15192 .61431 .15501 .61884 .15334 .61656 .15025 Mtetra
.61656 .15025 .61884 .15334 .62338 .15167 .6211 .14857 Mtetra
.6211 .14857 .62338 .15167 .62792 .14999 .62565 .14689 Mtetra
.62565 .14689 .62792 .14999 .63247 .14831 .63021 .1452 Mtetra
.63021 .1452 .63247 .14831 .63703 .14663 .63477 .14352 Mtetra
.63477 .14352 .63703 .14663 .64159 .14494 .63934 .14183 Mtetra
.63934 .14183 .64159 .14494 .64617 .14326 .64392 .14013 Mtetra
.64392 .14013 .64617 .14326 .65075 .14157 .64851 .13844 Mtetra
.64851 .13844 .65075 .14157 .65534 .13987 .6531 .13674 Mtetra
.6531 .13674 .65534 .13987 .65993 .13818 .6577 .13504 Mtetra
.6577 .13504 .65993 .13818 .66453 .13648 .66231 .13333 Mtetra
.66231 .13333 .66453 .13648 .66914 .13478 .66692 .13163 Mtetra
.66692 .13163 .66914 .13478 .67376 .13307 .67155 .12992 Mtetra
.67155 .12992 .67376 .13307 .67839 .13136 .67618 .12821 Mtetra
.67618 .12821 .67839 .13136 .68302 .12965 .68082 .12649 Mtetra
.68082 .12649 .68302 .12965 .68766 .12794 .68546 .12477 Mtetra
.68546 .12477 .68766 .12794 .69231 .12623 .69012 .12305 Mtetra
.69012 .12305 .69231 .12623 .69697 .12451 .69478 .12133 Mtetra
.69478 .12133 .69697 .12451 .70163 .12279 .69945 .1196 Mtetra
.69945 .1196 .70163 .12279 .7063 .12106 .70412 .11787 Mtetra
.70412 .11787 .7063 .12106 .71098 .11934 .70881 .11614 Mtetra
.70881 .11614 .71098 .11934 .71567 .11761 .7135 .11441 Mtetra
.7135 .11441 .71567 .11761 .72036 .11587 .7182 .11267 Mtetra
.7182 .11267 .72036 .11587 .72506 .11414 .72291 .11093 Mtetra
.72291 .11093 .72506 .11414 .72977 .1124 .72762 .10918 Mtetra
.72762 .10918 .72977 .1124 .73449 .11066 .73234 .10744 Mtetra
.73234 .10744 .73449 .11066 .73922 .10892 .73708 .10569 Mtetra
.73708 .10569 .73922 .10892 .74395 .10717 .74181 .10394 Mtetra
.74181 .10394 .74395 .10717 .74869 .10542 .74656 .10218 Mtetra
.74656 .10218 .74869 .10542 .75344 .10367 .75132 .10042 Mtetra
.11387 .33253 .11663 .3351 .1204 .33371 .11764 .33113 Mtetra
.11764 .33113 .1204 .33371 .12417 .33231 .12141 .32973 Mtetra
.12141 .32973 .12417 .33231 .12795 .33092 .12519 .32833 Mtetra
.12519 .32833 .12795 .33092 .13173 .32952 .12898 .32693 Mtetra
.12898 .32693 .13173 .32952 .13551 .32812 .13277 .32553 Mtetra
.13277 .32553 .13551 .32812 .13931 .32671 .13656 .32412 Mtetra
.13656 .32412 .13931 .32671 .14311 .32531 .14037 .32271 Mtetra
.14037 .32271 .14311 .32531 .14691 .3239 .14417 .3213 Mtetra
.14417 .3213 .14691 .3239 .15072 .32249 .14799 .31989 Mtetra
.14799 .31989 .15072 .32249 .15454 .32108 .15181 .31847 Mtetra
.15181 .31847 .15454 .32108 .15836 .31967 .15563 .31706 Mtetra
.15563 .31706 .15836 .31967 .16218 .31826 .15946 .31564 Mtetra
.15946 .31564 .16218 .31826 .16602 .31684 .1633 .31422 Mtetra
.1633 .31422 .16602 .31684 .16986 .31542 .16714 .31279 Mtetra
.16714 .31279 .16986 .31542 .1737 .314 .17099 .31137 Mtetra
.17099 .31137 .1737 .314 .17755 .31257 .17484 .30994 Mtetra
.17484 .30994 .17755 .31257 .18141 .31115 .1787 .30851 Mtetra
.1787 .30851 .18141 .31115 .18527 .30972 .18256 .30708 Mtetra
.18256 .30708 .18527 .30972 .18913 .30829 .18643 .30565 Mtetra
.18643 .30565 .18913 .30829 .19301 .30686 .19031 .30421 Mtetra
.19031 .30421 .19301 .30686 .19689 .30543 .19419 .30277 Mtetra
.19419 .30277 .19689 .30543 .20077 .30399 .19808 .30133 Mtetra
.19808 .30133 .20077 .30399 .20466 .30255 .20197 .29989 Mtetra
.20197 .29989 .20466 .30255 .20856 .30111 .20587 .29844 Mtetra
.20587 .29844 .20856 .30111 .21246 .29967 .20978 .297 Mtetra
.20978 .297 .21246 .29967 .21637 .29822 .21369 .29555 Mtetra
.21369 .29555 .21637 .29822 .22028 .29677 .21761 .2941 Mtetra
.21761 .2941 .22028 .29677 .2242 .29532 .22153 .29264 Mtetra
.22153 .29264 .2242 .29532 .22813 .29387 .22546 .29119 Mtetra
.22546 .29119 .22813 .29387 .23206 .29242 .2294 .28973 Mtetra
.2294 .28973 .23206 .29242 .236 .29096 .23334 .28827 Mtetra
.23334 .28827 .236 .29096 .23994 .28951 .23728 .28681 Mtetra
.23728 .28681 .23994 .28951 .24389 .28804 .24124 .28534 Mtetra
0 .036 .54 r
.24124 .28534 .24389 .28804 .23339 .4488 .24476 .2887 Mtetra
.523 .298 .515 r
.24476 .2887 .23339 .4488 .25138 .28994 .24873 .28724 Mtetra
.663 .742 .908 r
.24873 .28724 .25138 .28994 .25536 .28848 .25271 .28577 Mtetra
.25271 .28577 .25536 .28848 .25934 .28701 .25669 .28429 Mtetra
.25669 .28429 .25934 .28701 .26332 .28554 .26068 .28282 Mtetra
.26068 .28282 .26332 .28554 .26731 .28407 .26468 .28134 Mtetra
.26468 .28134 .26731 .28407 .27131 .28259 .26868 .27987 Mtetra
.26868 .27987 .27131 .28259 .27532 .28112 .27269 .27838 Mtetra
.27269 .27838 .27532 .28112 .27933 .27964 .2767 .2769 Mtetra
.2767 .2769 .27933 .27964 .28334 .27816 .28072 .27542 Mtetra
.28072 .27542 .28334 .27816 .28736 .27667 .28475 .27393 Mtetra
.28475 .27393 .28736 .27667 .29139 .27519 .28878 .27244 Mtetra
.28878 .27244 .29139 .27519 .29543 .2737 .29282 .27095 Mtetra
.29282 .27095 .29543 .2737 .29947 .27221 .29686 .26945 Mtetra
.29686 .26945 .29947 .27221 .30351 .27072 .30091 .26795 Mtetra
.30091 .26795 .30351 .27072 .30757 .26922 .30497 .26645 Mtetra
.30497 .26645 .30757 .26922 .31163 .26772 .30903 .26495 Mtetra
.30903 .26495 .31163 .26772 .31569 .26622 .3131 .26345 Mtetra
.3131 .26345 .31569 .26622 .31977 .26472 .31718 .26194 Mtetra
.31718 .26194 .31977 .26472 .32384 .26322 .32126 .26043 Mtetra
.32126 .26043 .32384 .26322 .32793 .26171 .32535 .25892 Mtetra
.32535 .25892 .32793 .26171 .32443 .38148 .32944 .25741 Mtetra
0 0 .229 r
.32944 .25741 .32443 .38148 .32868 .38001 .326 .37728 Mtetra
.654 .753 .922 r
.326 .37728 .32868 .38001 .33294 .37853 .33026 .3758 Mtetra
.33026 .3758 .33294 .37853 .33721 .37705 .33453 .37432 Mtetra
.33453 .37432 .33721 .37705 .34148 .37557 .33881 .37283 Mtetra
.33881 .37283 .34148 .37557 .34576 .37409 .34309 .37135 Mtetra
.34309 .37135 .34576 .37409 .35005 .3726 .34738 .36986 Mtetra
.34738 .36986 .35005 .3726 .35434 .37112 .35168 .36836 Mtetra
.35168 .36836 .35434 .37112 .35864 .36963 .35599 .36687 Mtetra
.35599 .36687 .35864 .36963 .36295 .36813 .3603 .36537 Mtetra
.3603 .36537 .36295 .36813 .36726 .36664 .36462 .36387 Mtetra
.36462 .36387 .36726 .36664 .37159 .36514 .36894 .36237 Mtetra
.36894 .36237 .37159 .36514 .37591 .36364 .37328 .36087 Mtetra
.964 .668 .421 r
.37328 .36087 .37591 .36364 .37656 .44329 .37386 .44056 Mtetra
.647 .761 .932 r
.37386 .44056 .37656 .44329 .38101 .44181 .37831 .43908 Mtetra
.37831 .43908 .38101 .44181 .38547 .44033 .38277 .4376 Mtetra
.38277 .4376 .38547 .44033 .38994 .43885 .38724 .43611 Mtetra
.38724 .43611 .38994 .43885 .39441 .43737 .39172 .43463 Mtetra
.39172 .43463 .39441 .43737 .39889 .43588 .3962 .43314 Mtetra
.3962 .43314 .39889 .43588 .40338 .4344 .4007 .43164 Mtetra
.4007 .43164 .40338 .4344 .40787 .43291 .4052 .43015 Mtetra
.4052 .43015 .40787 .43291 .41237 .43141 .4097 .42865 Mtetra
.4097 .42865 .41237 .43141 .41688 .42992 .41422 .42715 Mtetra
.41422 .42715 .41688 .42992 .4214 .42842 .41874 .42565 Mtetra
.41874 .42565 .4214 .42842 .42593 .42692 .42327 .42414 Mtetra
.42327 .42414 .42593 .42692 .43046 .42542 .42781 .42264 Mtetra
.42781 .42264 .43046 .42542 .435 .42391 .43235 .42112 Mtetra
.43235 .42112 .435 .42391 .43955 .4224 .43691 .41961 Mtetra
.43691 .41961 .43955 .4224 .4441 .42089 .44147 .4181 Mtetra
.44147 .4181 .4441 .42089 .44866 .41938 .44603 .41658 Mtetra
.44603 .41658 .44866 .41938 .45397 .38471 .45061 .41506 Mtetra
0 0 .128 r
.45061 .41506 .45397 .38471 .4585 .38318 .45591 .38034 Mtetra
.65 .758 .928 r
.45591 .38034 .4585 .38318 .46304 .38164 .46045 .37881 Mtetra
.46045 .37881 .46304 .38164 .46759 .38011 .465 .37727 Mtetra
.465 .37727 .46759 .38011 .47214 .37857 .46956 .37572 Mtetra
.46956 .37572 .47214 .37857 .47671 .37703 .47413 .37418 Mtetra
.47413 .37418 .47671 .37703 .48128 .37549 .47871 .37263 Mtetra
.47871 .37263 .48128 .37549 .48585 .37394 .48329 .37108 Mtetra
.971 .711 .482 r
.48329 .37108 .48585 .37394 .49108 .31317 .48857 .31027 Mtetra
.655 .752 .921 r
.48857 .31027 .49108 .31317 .49559 .3116 .49308 .30869 Mtetra
.49308 .30869 .49559 .3116 .5001 .31003 .4976 .30712 Mtetra
.4976 .30712 .5001 .31003 .50463 .30845 .50213 .30554 Mtetra
.50213 .30554 .50463 .30845 .50916 .30687 .50667 .30395 Mtetra
.50667 .30395 .50916 .30687 .5137 .30529 .51121 .30237 Mtetra
.51121 .30237 .5137 .30529 .51824 .30371 .51576 .30078 Mtetra
.51576 .30078 .51824 .30371 .5228 .30212 .52032 .29919 Mtetra
.52032 .29919 .5228 .30212 .52736 .30053 .52489 .29759 Mtetra
.52489 .29759 .52736 .30053 .53193 .29894 .52946 .29599 Mtetra
.52946 .29599 .53193 .29894 .5365 .29735 .53404 .29439 Mtetra
.53404 .29439 .5365 .29735 .54109 .29575 .53863 .29279 Mtetra
.53863 .29279 .54109 .29575 .54568 .29415 .54323 .29119 Mtetra
.54323 .29119 .54568 .29415 .55028 .29255 .54783 .28958 Mtetra
.54783 .28958 .55028 .29255 .55489 .29094 .55244 .28797 Mtetra
.55244 .28797 .55489 .29094 .5595 .28933 .55706 .28636 Mtetra
.55706 .28636 .5595 .28933 .56412 .28772 .56169 .28474 Mtetra
.56169 .28474 .56412 .28772 .56875 .28611 .56633 .28312 Mtetra
.56633 .28312 .56875 .28611 .57339 .28449 .57097 .2815 Mtetra
.57097 .2815 .57339 .28449 .57804 .28287 .57562 .27988 Mtetra
.977 .696 .422 r
.57562 .27988 .57804 .28287 .58269 .28125 .57818 .16052 Mtetra
.525 .302 .519 r
.57818 .16052 .58269 .28125 .58498 .16193 .58266 .15886 Mtetra
.664 .741 .908 r
.58266 .15886 .58498 .16193 .58947 .16027 .58716 .15719 Mtetra
.58716 .15719 .58947 .16027 .59397 .1586 .59166 .15553 Mtetra
.59166 .15553 .59397 .1586 .59847 .15694 .59617 .15386 Mtetra
.59617 .15386 .59847 .15694 .60298 .15527 .60069 .15218 Mtetra
.60069 .15218 .60298 .15527 .6075 .1536 .60521 .15051 Mtetra
.60521 .15051 .6075 .1536 .61203 .15192 .60974 .14883 Mtetra
.60974 .14883 .61203 .15192 .61656 .15025 .61428 .14715 Mtetra
.61428 .14715 .61656 .15025 .6211 .14857 .61883 .14546 Mtetra
.61883 .14546 .6211 .14857 .62565 .14689 .62338 .14378 Mtetra
.62338 .14378 .62565 .14689 .63021 .1452 .62794 .14209 Mtetra
.62794 .14209 .63021 .1452 .63477 .14352 .63251 .14039 Mtetra
.63251 .14039 .63477 .14352 .63934 .14183 .63708 .1387 Mtetra
.63708 .1387 .63934 .14183 .64392 .14013 .64167 .137 Mtetra
.64167 .137 .64392 .14013 .64851 .13844 .64626 .1353 Mtetra
.64626 .1353 .64851 .13844 .6531 .13674 .65086 .1336 Mtetra
.65086 .1336 .6531 .13674 .6577 .13504 .65546 .13189 Mtetra
.65546 .13189 .6577 .13504 .66231 .13333 .66007 .13018 Mtetra
.66007 .13018 .66231 .13333 .66692 .13163 .6647 .12847 Mtetra
.6647 .12847 .66692 .13163 .67155 .12992 .66932 .12675 Mtetra
.66932 .12675 .67155 .12992 .67618 .12821 .67396 .12504 Mtetra
.67396 .12504 .67618 .12821 .68082 .12649 .6786 .12332 Mtetra
.6786 .12332 .68082 .12649 .68546 .12477 .68325 .12159 Mtetra
.68325 .12159 .68546 .12477 .69012 .12305 .68791 .11987 Mtetra
.68791 .11987 .69012 .12305 .69478 .12133 .69258 .11814 Mtetra
.69258 .11814 .69478 .12133 .69945 .1196 .69725 .11641 Mtetra
.69725 .11641 .69945 .1196 .70412 .11787 .70194 .11467 Mtetra
.70194 .11467 .70412 .11787 .70881 .11614 .70663 .11294 Mtetra
.70663 .11294 .70881 .11614 .7135 .11441 .71132 .1112 Mtetra
.71132 .1112 .7135 .11441 .7182 .11267 .71603 .10945 Mtetra
.71603 .10945 .7182 .11267 .72291 .11093 .72074 .10771 Mtetra
.72074 .10771 .72291 .11093 .72762 .10918 .72546 .10596 Mtetra
.72546 .10596 .72762 .10918 .73234 .10744 .73019 .10421 Mtetra
.73019 .10421 .73234 .10744 .73708 .10569 .73493 .10245 Mtetra
.73493 .10245 .73708 .10569 .74181 .10394 .73967 .10069 Mtetra
.73967 .10069 .74181 .10394 .74656 .10218 .74442 .09893 Mtetra
.74442 .09893 .74656 .10218 .75132 .10042 .74918 .09717 Mtetra
.1111 .32995 .11387 .33253 .11764 .33113 .11487 .32855 Mtetra
.11487 .32855 .11764 .33113 .12141 .32973 .11865 .32715 Mtetra
.11865 .32715 .12141 .32973 .12519 .32833 .12243 .32574 Mtetra
.12243 .32574 .12519 .32833 .12898 .32693 .12622 .32434 Mtetra
.12622 .32434 .12898 .32693 .13277 .32553 .13001 .32293 Mtetra
.13001 .32293 .13277 .32553 .13656 .32412 .13381 .32152 Mtetra
.13381 .32152 .13656 .32412 .14037 .32271 .13762 .32011 Mtetra
.13762 .32011 .14037 .32271 .14417 .3213 .14143 .31869 Mtetra
.14143 .31869 .14417 .3213 .14799 .31989 .14525 .31728 Mtetra
.14525 .31728 .14799 .31989 .15181 .31847 .14907 .31586 Mtetra
.14907 .31586 .15181 .31847 .15563 .31706 .1529 .31444 Mtetra
.1529 .31444 .15563 .31706 .15946 .31564 .15673 .31301 Mtetra
.15673 .31301 .15946 .31564 .1633 .31422 .16057 .31159 Mtetra
.16057 .31159 .1633 .31422 .16714 .31279 .16441 .31016 Mtetra
.16441 .31016 .16714 .31279 .17099 .31137 .16826 .30873 Mtetra
.16826 .30873 .17099 .31137 .17484 .30994 .17212 .3073 Mtetra
.17212 .3073 .17484 .30994 .1787 .30851 .17598 .30587 Mtetra
.17598 .30587 .1787 .30851 .18256 .30708 .17985 .30443 Mtetra
.17985 .30443 .18256 .30708 .18643 .30565 .18372 .30299 Mtetra
.18372 .30299 .18643 .30565 .19031 .30421 .1876 .30155 Mtetra
.1876 .30155 .19031 .30421 .19419 .30277 .19149 .30011 Mtetra
.19149 .30011 .19419 .30277 .19808 .30133 .19538 .29867 Mtetra
.19538 .29867 .19808 .30133 .20197 .29989 .19928 .29722 Mtetra
.19928 .29722 .20197 .29989 .20587 .29844 .20318 .29577 Mtetra
.20318 .29577 .20587 .29844 .20978 .297 .20709 .29432 Mtetra
.20709 .29432 .20978 .297 .21369 .29555 .21101 .29287 Mtetra
.21101 .29287 .21369 .29555 .21761 .2941 .21493 .29141 Mtetra
.21493 .29141 .21761 .2941 .22153 .29264 .21885 .28995 Mtetra
.21885 .28995 .22153 .29264 .22546 .29119 .22279 .28849 Mtetra
.22279 .28849 .22546 .29119 .2294 .28973 .22673 .28703 Mtetra
.22673 .28703 .2294 .28973 .23334 .28827 .23067 .28557 Mtetra
.23067 .28557 .23334 .28827 .23728 .28681 .23462 .2841 Mtetra
.23462 .2841 .23728 .28681 .24124 .28534 .23858 .28263 Mtetra
0 .036 .54 r
.23858 .28263 .24124 .28534 .24476 .2887 .2421 .28599 Mtetra
.663 .742 .908 r
.2421 .28599 .24476 .2887 .24873 .28724 .24608 .28452 Mtetra
.24608 .28452 .24873 .28724 .25271 .28577 .25006 .28305 Mtetra
.25006 .28305 .25271 .28577 .25669 .28429 .25404 .28157 Mtetra
.25404 .28157 .25669 .28429 .26068 .28282 .25804 .28009 Mtetra
.25804 .28009 .26068 .28282 .26468 .28134 .26203 .27861 Mtetra
.26203 .27861 .26468 .28134 .26868 .27987 .26604 .27713 Mtetra
.26604 .27713 .26868 .27987 .27269 .27838 .27005 .27564 Mtetra
.27005 .27564 .27269 .27838 .2767 .2769 .27407 .27416 Mtetra
.27407 .27416 .2767 .2769 .28072 .27542 .27809 .27267 Mtetra
.27809 .27267 .28072 .27542 .28475 .27393 .28212 .27117 Mtetra
.28212 .27117 .28475 .27393 .28878 .27244 .28616 .26968 Mtetra
.28616 .26968 .28878 .27244 .29282 .27095 .2902 .26818 Mtetra
.2902 .26818 .29282 .27095 .29686 .26945 .29425 .26668 Mtetra
.29425 .26668 .29686 .26945 .30091 .26795 .2983 .26518 Mtetra
.2983 .26518 .30091 .26795 .30497 .26645 .30236 .26368 Mtetra
.30236 .26368 .30497 .26645 .30903 .26495 .30643 .26217 Mtetra
.30643 .26217 .30903 .26495 .3131 .26345 .3105 .26067 Mtetra
.3105 .26067 .3131 .26345 .31718 .26194 .31458 .25916 Mtetra
.31458 .25916 .31718 .26194 .32126 .26043 .31867 .25764 Mtetra
.31867 .25764 .32126 .26043 .32535 .25892 .32276 .25613 Mtetra
.32276 .25613 .32535 .25892 .32944 .25741 .32686 .25461 Mtetra
.96 .677 .453 r
.32686 .25461 .32944 .25741 .326 .37728 .32331 .37455 Mtetra
.654 .753 .922 r
.32331 .37455 .326 .37728 .33026 .3758 .32757 .37306 Mtetra
.32757 .37306 .33026 .3758 .33453 .37432 .33185 .37157 Mtetra
.33185 .37157 .33453 .37432 .33881 .37283 .33613 .37009 Mtetra
.33613 .37009 .33881 .37283 .34309 .37135 .34042 .36859 Mtetra
.34042 .36859 .34309 .37135 .34738 .36986 .34471 .3671 Mtetra
.34471 .3671 .34738 .36986 .35168 .36836 .34901 .3656 Mtetra
.34901 .3656 .35168 .36836 .35599 .36687 .35332 .3641 Mtetra
.35332 .3641 .35599 .36687 .3603 .36537 .35764 .3626 Mtetra
.35764 .3626 .3603 .36537 .36462 .36387 .36196 .3611 Mtetra
.36196 .3611 .36462 .36387 .36894 .36237 .36629 .35959 Mtetra
.36629 .35959 .36894 .36237 .37328 .36087 .37063 .35808 Mtetra
.964 .668 .421 r
.37063 .35808 .37328 .36087 .37386 .44056 .37114 .43783 Mtetra
.647 .761 .932 r
.37114 .43783 .37386 .44056 .37831 .43908 .3756 .43634 Mtetra
.3756 .43634 .37831 .43908 .38277 .4376 .38007 .43485 Mtetra
.38007 .43485 .38277 .4376 .38724 .43611 .38454 .43336 Mtetra
.38454 .43336 .38724 .43611 .39172 .43463 .38902 .43187 Mtetra
.38902 .43187 .39172 .43463 .3962 .43314 .39351 .43038 Mtetra
.39351 .43038 .3962 .43314 .4007 .43164 .39801 .42888 Mtetra
.39801 .42888 .4007 .43164 .4052 .43015 .40251 .42738 Mtetra
.40251 .42738 .4052 .43015 .4097 .42865 .40703 .42588 Mtetra
.40703 .42588 .4097 .42865 .41422 .42715 .41154 .42437 Mtetra
.41154 .42437 .41422 .42715 .41874 .42565 .41607 .42287 Mtetra
.41607 .42287 .41874 .42565 .42327 .42414 .42061 .42136 Mtetra
.42061 .42136 .42327 .42414 .42781 .42264 .42515 .41985 Mtetra
.42515 .41985 .42781 .42264 .43235 .42112 .4297 .41833 Mtetra
.4297 .41833 .43235 .42112 .43691 .41961 .43426 .41681 Mtetra
.43426 .41681 .43691 .41961 .44147 .4181 .43882 .41529 Mtetra
.43882 .41529 .44147 .4181 .44603 .41658 .44339 .41377 Mtetra
.44339 .41377 .44603 .41658 .45061 .41506 .44797 .41225 Mtetra
.965 .727 .529 r
.44797 .41225 .45061 .41506 .45591 .38034 .45331 .3775 Mtetra
.65 .758 .928 r
.45331 .3775 .45591 .38034 .46045 .37881 .45786 .37596 Mtetra
.45786 .37596 .46045 .37881 .465 .37727 .46241 .37442 Mtetra
.46241 .37442 .465 .37727 .46956 .37572 .46698 .37287 Mtetra
.46698 .37287 .46956 .37572 .47413 .37418 .47155 .37132 Mtetra
.971 .695 .448 r
.47155 .37132 .47413 .37418 .47871 .37263 .47875 .19837 Mtetra
.522 .296 .514 r
.47875 .19837 .47871 .37263 .48329 .37108 .48309 .19676 Mtetra
.48309 .19676 .48329 .37108 .48857 .31027 .48744 .19515 Mtetra
.524 .302 .519 r
.48744 .19515 .48857 .31027 .49308 .30869 .4918 .19354 Mtetra
0 0 .321 r
.4918 .19354 .49308 .30869 .4976 .30712 .49509 .3042 Mtetra
.655 .752 .921 r
.49509 .3042 .4976 .30712 .50213 .30554 .49963 .30261 Mtetra
.49963 .30261 .50213 .30554 .50667 .30395 .50417 .30102 Mtetra
.50417 .30102 .50667 .30395 .51121 .30237 .50872 .29943 Mtetra
.50872 .29943 .51121 .30237 .51576 .30078 .51327 .29784 Mtetra
.51327 .29784 .51576 .30078 .52032 .29919 .51784 .29624 Mtetra
.51784 .29624 .52032 .29919 .52489 .29759 .52241 .29464 Mtetra
.52241 .29464 .52489 .29759 .52946 .29599 .52699 .29304 Mtetra
.52699 .29304 .52946 .29599 .53404 .29439 .53157 .29143 Mtetra
.53157 .29143 .53404 .29439 .53863 .29279 .53617 .28983 Mtetra
.53617 .28983 .53863 .29279 .54323 .29119 .54077 .28822 Mtetra
.54077 .28822 .54323 .29119 .54783 .28958 .54538 .28661 Mtetra
.54538 .28661 .54783 .28958 .55244 .28797 .55 .28499 Mtetra
.55 .28499 .55244 .28797 .55706 .28636 .55462 .28337 Mtetra
.55462 .28337 .55706 .28636 .56169 .28474 .55925 .28175 Mtetra
.55925 .28175 .56169 .28474 .56633 .28312 .56389 .28013 Mtetra
.977 .696 .426 r
.56389 .28013 .56633 .28312 .57097 .2815 .56688 .16078 Mtetra
.524 .301 .519 r
.56688 .16078 .57097 .2815 .57562 .27988 .57136 .15911 Mtetra
.57136 .15911 .57562 .27988 .57818 .16052 .57585 .15745 Mtetra
.664 .741 .908 r
.57585 .15745 .57818 .16052 .58266 .15886 .58034 .15578 Mtetra
.58034 .15578 .58266 .15886 .58716 .15719 .58484 .15411 Mtetra
.58484 .15411 .58716 .15719 .59166 .15553 .58935 .15244 Mtetra
.58935 .15244 .59166 .15553 .59617 .15386 .59386 .15076 Mtetra
.59386 .15076 .59617 .15386 .60069 .15218 .59838 .14909 Mtetra
.59838 .14909 .60069 .15218 .60521 .15051 .60291 .14741 Mtetra
.60291 .14741 .60521 .15051 .60974 .14883 .60745 .14572 Mtetra
.60745 .14572 .60974 .14883 .61428 .14715 .61199 .14404 Mtetra
.61199 .14404 .61428 .14715 .61883 .14546 .61654 .14235 Mtetra
.61654 .14235 .61883 .14546 .62338 .14378 .6211 .14065 Mtetra
.6211 .14065 .62338 .14378 .62794 .14209 .62566 .13896 Mtetra
.62566 .13896 .62794 .14209 .63251 .14039 .63024 .13726 Mtetra
.63024 .13726 .63251 .14039 .63708 .1387 .63482 .13556 Mtetra
.63482 .13556 .63708 .1387 .64167 .137 .63941 .13386 Mtetra
.63941 .13386 .64167 .137 .64626 .1353 .644 .13215 Mtetra
.644 .13215 .64626 .1353 .65086 .1336 .64861 .13044 Mtetra
.64861 .13044 .65086 .1336 .65546 .13189 .65322 .12873 Mtetra
.65322 .12873 .65546 .13189 .66007 .13018 .65783 .12702 Mtetra
.65783 .12702 .66007 .13018 .6647 .12847 .66246 .1253 Mtetra
.66246 .1253 .6647 .12847 .66932 .12675 .66709 .12358 Mtetra
.66709 .12358 .66932 .12675 .67396 .12504 .67174 .12186 Mtetra
.67174 .12186 .67396 .12504 .6786 .12332 .67638 .12013 Mtetra
.67638 .12013 .6786 .12332 .68325 .12159 .68104 .11841 Mtetra
.68104 .11841 .68325 .12159 .68791 .11987 .6857 .11667 Mtetra
.6857 .11667 .68791 .11987 .69258 .11814 .69038 .11494 Mtetra
.69038 .11494 .69258 .11814 .69725 .11641 .69506 .1132 Mtetra
.69506 .1132 .69725 .11641 .70194 .11467 .69974 .11146 Mtetra
.69974 .11146 .70194 .11467 .70663 .11294 .70444 .10972 Mtetra
.70444 .10972 .70663 .11294 .71132 .1112 .70914 .10798 Mtetra
.70914 .10798 .71132 .1112 .71603 .10945 .71385 .10623 Mtetra
.71385 .10623 .71603 .10945 .72074 .10771 .71857 .10448 Mtetra
.71857 .10448 .72074 .10771 .72546 .10596 .7233 .10272 Mtetra
.7233 .10272 .72546 .10596 .73019 .10421 .72803 .10096 Mtetra
.72803 .10096 .73019 .10421 .73493 .10245 .73277 .0992 Mtetra
.73277 .0992 .73493 .10245 .73967 .10069 .73752 .09744 Mtetra
.73752 .09744 .73967 .10069 .74442 .09893 .74228 .09568 Mtetra
.74228 .09568 .74442 .09893 .74918 .09717 .74705 .09391 Mtetra
.10832 .32736 .1111 .32995 .11487 .32855 .1121 .32596 Mtetra
.1121 .32596 .11487 .32855 .11865 .32715 .11588 .32455 Mtetra
.11588 .32455 .11865 .32715 .12243 .32574 .11966 .32315 Mtetra
.11966 .32315 .12243 .32574 .12622 .32434 .12346 .32174 Mtetra
.12346 .32174 .12622 .32434 .13001 .32293 .12725 .32032 Mtetra
.12725 .32032 .13001 .32293 .13381 .32152 .13106 .31891 Mtetra
.13106 .31891 .13381 .32152 .13762 .32011 .13486 .31749 Mtetra
.13486 .31749 .13762 .32011 .14143 .31869 .13868 .31607 Mtetra
.13868 .31607 .14143 .31869 .14525 .31728 .1425 .31465 Mtetra
.1425 .31465 .14525 .31728 .14907 .31586 .14632 .31323 Mtetra
.14632 .31323 .14907 .31586 .1529 .31444 .15015 .31181 Mtetra
.15015 .31181 .1529 .31444 .15673 .31301 .15399 .31038 Mtetra
.15399 .31038 .15673 .31301 .16057 .31159 .15783 .30895 Mtetra
.15783 .30895 .16057 .31159 .16441 .31016 .16168 .30752 Mtetra
.16168 .30752 .16441 .31016 .16826 .30873 .16553 .30609 Mtetra
.16553 .30609 .16826 .30873 .17212 .3073 .16939 .30465 Mtetra
.16939 .30465 .17212 .3073 .17598 .30587 .17326 .30321 Mtetra
.17326 .30321 .17598 .30587 .17985 .30443 .17713 .30177 Mtetra
.17713 .30177 .17985 .30443 .18372 .30299 .18101 .30033 Mtetra
.18101 .30033 .18372 .30299 .1876 .30155 .18489 .29889 Mtetra
.18489 .29889 .1876 .30155 .19149 .30011 .18878 .29744 Mtetra
.18878 .29744 .19149 .30011 .19538 .29867 .19268 .29599 Mtetra
.19268 .29599 .19538 .29867 .19928 .29722 .19658 .29454 Mtetra
.19658 .29454 .19928 .29722 .20318 .29577 .20048 .29309 Mtetra
.20048 .29309 .20318 .29577 .20709 .29432 .2044 .29164 Mtetra
.2044 .29164 .20709 .29432 .21101 .29287 .20831 .29018 Mtetra
.20831 .29018 .21101 .29287 .21493 .29141 .21224 .28872 Mtetra
.21224 .28872 .21493 .29141 .21885 .28995 .21617 .28726 Mtetra
.21617 .28726 .21885 .28995 .22279 .28849 .2201 .28579 Mtetra
.2201 .28579 .22279 .28849 .22673 .28703 .22405 .28433 Mtetra
.22405 .28433 .22673 .28703 .23067 .28557 .22799 .28286 Mtetra
.22799 .28286 .23067 .28557 .23462 .2841 .23195 .28139 Mtetra
.23195 .28139 .23462 .2841 .23858 .28263 .23591 .27992 Mtetra
0 .036 .54 r
.23591 .27992 .23858 .28263 .2421 .28599 .23943 .28327 Mtetra
.663 .742 .908 r
.23943 .28327 .2421 .28599 .24608 .28452 .24341 .2818 Mtetra
.24341 .2818 .24608 .28452 .25006 .28305 .24739 .28032 Mtetra
.24739 .28032 .25006 .28305 .25404 .28157 .25138 .27884 Mtetra
.25138 .27884 .25404 .28157 .25804 .28009 .25538 .27736 Mtetra
.25538 .27736 .25804 .28009 .26203 .27861 .25938 .27587 Mtetra
.25938 .27587 .26203 .27861 .26604 .27713 .26339 .27439 Mtetra
.26339 .27439 .26604 .27713 .27005 .27564 .26741 .2729 Mtetra
.26741 .2729 .27005 .27564 .27407 .27416 .27143 .2714 Mtetra
.27143 .2714 .27407 .27416 .27809 .27267 .27545 .26991 Mtetra
.27545 .26991 .27809 .27267 .28212 .27117 .27949 .26841 Mtetra
.27949 .26841 .28212 .27117 .28616 .26968 .28353 .26692 Mtetra
.28353 .26692 .28616 .26968 .2902 .26818 .28757 .26541 Mtetra
.28757 .26541 .2902 .26818 .29425 .26668 .29163 .26391 Mtetra
.29163 .26391 .29425 .26668 .2983 .26518 .29568 .26241 Mtetra
.29568 .26241 .2983 .26518 .30236 .26368 .29975 .2609 Mtetra
.29975 .2609 .30236 .26368 .30643 .26217 .30382 .25939 Mtetra
.30382 .25939 .30643 .26217 .3105 .26067 .3079 .25788 Mtetra
.3079 .25788 .3105 .26067 .31458 .25916 .31198 .25636 Mtetra
.31198 .25636 .31458 .25916 .31867 .25764 .31607 .25484 Mtetra
.31607 .25484 .31867 .25764 .32276 .25613 .32016 .25332 Mtetra
.32016 .25332 .32276 .25613 .32686 .25461 .32427 .2518 Mtetra
.32427 .2518 .32686 .25461 .32331 .37455 .32838 .25028 Mtetra
0 0 .227 r
.32838 .25028 .32331 .37455 .32757 .37306 .32488 .37031 Mtetra
.654 .753 .922 r
.32488 .37031 .32757 .37306 .33185 .37157 .32915 .36882 Mtetra
.32915 .36882 .33185 .37157 .33613 .37009 .33344 .36733 Mtetra
.33344 .36733 .33613 .37009 .34042 .36859 .33773 .36583 Mtetra
.33773 .36583 .34042 .36859 .34471 .3671 .34203 .36433 Mtetra
.34203 .36433 .34471 .3671 .34901 .3656 .34634 .36283 Mtetra
.34634 .36283 .34901 .3656 .35332 .3641 .35065 .36133 Mtetra
.35065 .36133 .35332 .3641 .35764 .3626 .35497 .35982 Mtetra
.35497 .35982 .35764 .3626 .36196 .3611 .3593 .35832 Mtetra
.3593 .35832 .36196 .3611 .36629 .35959 .36363 .3568 Mtetra
.36363 .3568 .36629 .35959 .37063 .35808 .36797 .35529 Mtetra
.964 .668 .421 r
.36797 .35529 .37063 .35808 .37114 .43783 .36842 .43508 Mtetra
.647 .761 .932 r
.36842 .43508 .37114 .43783 .3756 .43634 .37288 .43359 Mtetra
.37288 .43359 .3756 .43634 .38007 .43485 .37735 .4321 Mtetra
.37735 .4321 .38007 .43485 .38454 .43336 .38183 .43061 Mtetra
.38183 .43061 .38454 .43336 .38902 .43187 .38632 .42911 Mtetra
.38632 .42911 .38902 .43187 .39351 .43038 .39081 .42761 Mtetra
.39081 .42761 .39351 .43038 .39801 .42888 .39531 .42611 Mtetra
.39531 .42611 .39801 .42888 .40251 .42738 .39982 .42461 Mtetra
.39982 .42461 .40251 .42738 .40703 .42588 .40434 .4231 Mtetra
.40434 .4231 .40703 .42588 .41154 .42437 .40886 .42159 Mtetra
.40886 .42159 .41154 .42437 .41607 .42287 .4134 .42008 Mtetra
.4134 .42008 .41607 .42287 .42061 .42136 .41793 .41856 Mtetra
.41793 .41856 .42061 .42136 .42515 .41985 .42248 .41705 Mtetra
.42248 .41705 .42515 .41985 .4297 .41833 .42704 .41553 Mtetra
.42704 .41553 .4297 .41833 .43426 .41681 .4316 .414 Mtetra
.4316 .414 .43426 .41681 .43882 .41529 .43617 .41248 Mtetra
.43617 .41248 .43882 .41529 .44339 .41377 .44075 .41095 Mtetra
.44075 .41095 .44339 .41377 .44797 .41225 .44533 .40942 Mtetra
.44533 .40942 .44797 .41225 .45331 .3775 .44993 .40789 Mtetra
0 0 .125 r
.44993 .40789 .45331 .3775 .45786 .37596 .45525 .37311 Mtetra
.97 .695 .453 r
.45525 .37311 .45786 .37596 .46241 .37442 .4633 .20022 Mtetra
.521 .295 .513 r
.4633 .20022 .46241 .37442 .46698 .37287 .46763 .19862 Mtetra
.46763 .19862 .46698 .37287 .47155 .37132 .47197 .19701 Mtetra
.47197 .19701 .47155 .37132 .47875 .19837 .47631 .1954 Mtetra
.663 .742 .908 r
.47631 .1954 .47875 .19837 .48309 .19676 .48065 .19378 Mtetra
.48065 .19378 .48309 .19676 .48744 .19515 .48501 .19217 Mtetra
.48501 .19217 .48744 .19515 .4918 .19354 .48937 .19055 Mtetra
.48937 .19055 .4918 .19354 .49509 .3042 .49374 .18893 Mtetra
.524 .301 .519 r
.49374 .18893 .49509 .3042 .49963 .30261 .49812 .18731 Mtetra
.49812 .18731 .49963 .30261 .50417 .30102 .5025 .18568 Mtetra
0 0 .325 r
.5025 .18568 .50417 .30102 .50872 .29943 .50622 .29649 Mtetra
.655 .752 .921 r
.50622 .29649 .50872 .29943 .51327 .29784 .51078 .29489 Mtetra
.51078 .29489 .51327 .29784 .51784 .29624 .51534 .29329 Mtetra
.51534 .29329 .51784 .29624 .52241 .29464 .51992 .29168 Mtetra
.51992 .29168 .52241 .29464 .52699 .29304 .5245 .29008 Mtetra
.5245 .29008 .52699 .29304 .53157 .29143 .5291 .28847 Mtetra
.5291 .28847 .53157 .29143 .53617 .28983 .5337 .28685 Mtetra
.5337 .28685 .53617 .28983 .54077 .28822 .5383 .28524 Mtetra
.5383 .28524 .54077 .28822 .54538 .28661 .54292 .28362 Mtetra
.54292 .28362 .54538 .28661 .55 .28499 .54754 .282 Mtetra
.54754 .282 .55 .28499 .55462 .28337 .55217 .28038 Mtetra
.55217 .28038 .55462 .28337 .55925 .28175 .55681 .27875 Mtetra
.977 .697 .428 r
.55681 .27875 .55925 .28175 .56389 .28013 .56006 .15937 Mtetra
.523 .3 .518 r
.56006 .15937 .56389 .28013 .56688 .16078 .56454 .15771 Mtetra
.664 .741 .908 r
.56454 .15771 .56688 .16078 .57136 .15911 .56902 .15604 Mtetra
.56902 .15604 .57136 .15911 .57585 .15745 .57351 .15437 Mtetra
.57351 .15437 .57585 .15745 .58034 .15578 .57801 .1527 Mtetra
.57801 .1527 .58034 .15578 .58484 .15411 .58251 .15102 Mtetra
.58251 .15102 .58484 .15411 .58935 .15244 .58702 .14934 Mtetra
.58702 .14934 .58935 .15244 .59386 .15076 .59154 .14766 Mtetra
.59154 .14766 .59386 .15076 .59838 .14909 .59607 .14598 Mtetra
.59607 .14598 .59838 .14909 .60291 .14741 .6006 .14429 Mtetra
.6006 .14429 .60291 .14741 .60745 .14572 .60514 .14261 Mtetra
.60514 .14261 .60745 .14572 .61199 .14404 .60969 .14091 Mtetra
.60969 .14091 .61199 .14404 .61654 .14235 .61425 .13922 Mtetra
.61425 .13922 .61654 .14235 .6211 .14065 .61881 .13752 Mtetra
.61881 .13752 .6211 .14065 .62566 .13896 .62338 .13582 Mtetra
.62338 .13582 .62566 .13896 .63024 .13726 .62796 .13412 Mtetra
.62796 .13412 .63024 .13726 .63482 .13556 .63255 .13242 Mtetra
.63255 .13242 .63482 .13556 .63941 .13386 .63714 .13071 Mtetra
.63714 .13071 .63941 .13386 .644 .13215 .64174 .129 Mtetra
.64174 .129 .644 .13215 .64861 .13044 .64635 .12728 Mtetra
.64635 .12728 .64861 .13044 .65322 .12873 .65096 .12557 Mtetra
.65096 .12557 .65322 .12873 .65783 .12702 .65559 .12385 Mtetra
.65559 .12385 .65783 .12702 .66246 .1253 .66022 .12212 Mtetra
.66022 .12212 .66246 .1253 .66709 .12358 .66486 .1204 Mtetra
.66486 .1204 .66709 .12358 .67174 .12186 .6695 .11867 Mtetra
.6695 .11867 .67174 .12186 .67638 .12013 .67416 .11694 Mtetra
.67416 .11694 .67638 .12013 .68104 .11841 .67882 .11521 Mtetra
.67882 .11521 .68104 .11841 .6857 .11667 .68349 .11347 Mtetra
.68349 .11347 .6857 .11667 .69038 .11494 .68817 .11173 Mtetra
.68817 .11173 .69038 .11494 .69506 .1132 .69285 .10999 Mtetra
.69285 .10999 .69506 .1132 .69974 .11146 .69754 .10824 Mtetra
.69754 .10824 .69974 .11146 .70444 .10972 .70224 .1065 Mtetra
.70224 .1065 .70444 .10972 .70914 .10798 .70695 .10475 Mtetra
.70695 .10475 .70914 .10798 .71385 .10623 .71167 .10299 Mtetra
.71167 .10299 .71385 .10623 .71857 .10448 .71639 .10123 Mtetra
.71639 .10123 .71857 .10448 .7233 .10272 .72112 .09948 Mtetra
.72112 .09948 .7233 .10272 .72803 .10096 .72586 .09771 Mtetra
.72586 .09771 .72803 .10096 .73277 .0992 .73061 .09595 Mtetra
.73061 .09595 .73277 .0992 .73752 .09744 .73537 .09418 Mtetra
.73537 .09418 .73752 .09744 .74228 .09568 .74013 .09241 Mtetra
.74013 .09241 .74228 .09568 .74705 .09391 .7449 .09063 Mtetra
.10554 .32477 .10832 .32736 .1121 .32596 .10932 .32336 Mtetra
.10932 .32336 .1121 .32596 .11588 .32455 .1131 .32195 Mtetra
.1131 .32195 .11588 .32455 .11966 .32315 .11689 .32054 Mtetra
.11689 .32054 .11966 .32315 .12346 .32174 .12068 .31913 Mtetra
.12068 .31913 .12346 .32174 .12725 .32032 .12448 .31771 Mtetra
.12448 .31771 .12725 .32032 .13106 .31891 .12829 .31629 Mtetra
.12829 .31629 .13106 .31891 .13486 .31749 .1321 .31487 Mtetra
.1321 .31487 .13486 .31749 .13868 .31607 .13592 .31345 Mtetra
.13592 .31345 .13868 .31607 .1425 .31465 .13974 .31203 Mtetra
.13974 .31203 .1425 .31465 .14632 .31323 .14357 .3106 Mtetra
.14357 .3106 .14632 .31323 .15015 .31181 .1474 .30917 Mtetra
.1474 .30917 .15015 .31181 .15399 .31038 .15124 .30774 Mtetra
.15124 .30774 .15399 .31038 .15783 .30895 .15509 .30631 Mtetra
.15509 .30631 .15783 .30895 .16168 .30752 .15894 .30487 Mtetra
.15894 .30487 .16168 .30752 .16553 .30609 .1628 .30344 Mtetra
.1628 .30344 .16553 .30609 .16939 .30465 .16666 .302 Mtetra
.16666 .302 .16939 .30465 .17326 .30321 .17053 .30055 Mtetra
.17053 .30055 .17326 .30321 .17713 .30177 .1744 .29911 Mtetra
.1744 .29911 .17713 .30177 .18101 .30033 .17829 .29767 Mtetra
.17829 .29767 .18101 .30033 .18489 .29889 .18217 .29622 Mtetra
.18217 .29622 .18489 .29889 .18878 .29744 .18606 .29477 Mtetra
.18606 .29477 .18878 .29744 .19268 .29599 .18996 .29331 Mtetra
.18996 .29331 .19268 .29599 .19658 .29454 .19387 .29186 Mtetra
.19387 .29186 .19658 .29454 .20048 .29309 .19778 .2904 Mtetra
.19778 .2904 .20048 .29309 .2044 .29164 .20169 .28894 Mtetra
.20169 .28894 .2044 .29164 .20831 .29018 .20561 .28748 Mtetra
.20561 .28748 .20831 .29018 .21224 .28872 .20954 .28602 Mtetra
.20954 .28602 .21224 .28872 .21617 .28726 .21348 .28455 Mtetra
.21348 .28455 .21617 .28726 .2201 .28579 .21742 .28309 Mtetra
.21742 .28309 .2201 .28579 .22405 .28433 .22136 .28162 Mtetra
.22136 .28162 .22405 .28433 .22799 .28286 .22531 .28014 Mtetra
.22531 .28014 .22799 .28286 .23195 .28139 .22927 .27867 Mtetra
.22927 .27867 .23195 .28139 .23591 .27992 .23323 .27719 Mtetra
0 .036 .54 r
.23323 .27719 .23591 .27992 .23943 .28327 .23675 .28055 Mtetra
.663 .742 .908 r
.23675 .28055 .23943 .28327 .24341 .2818 .24074 .27907 Mtetra
.24074 .27907 .24341 .2818 .24739 .28032 .24472 .27759 Mtetra
.24472 .27759 .24739 .28032 .25138 .27884 .24872 .2761 Mtetra
.24872 .2761 .25138 .27884 .25538 .27736 .25272 .27461 Mtetra
.25272 .27461 .25538 .27736 .25938 .27587 .25672 .27313 Mtetra
.25672 .27313 .25938 .27587 .26339 .27439 .26074 .27163 Mtetra
.26074 .27163 .26339 .27439 .26741 .2729 .26476 .27014 Mtetra
.26476 .27014 .26741 .2729 .27143 .2714 .26878 .26864 Mtetra
.26878 .26864 .27143 .2714 .27545 .26991 .27281 .26715 Mtetra
.27281 .26715 .27545 .26991 .27949 .26841 .27685 .26565 Mtetra
.27685 .26565 .27949 .26841 .28353 .26692 .28089 .26414 Mtetra
.28089 .26414 .28353 .26692 .28757 .26541 .28494 .26264 Mtetra
.28494 .26264 .28757 .26541 .29163 .26391 .289 .26113 Mtetra
.289 .26113 .29163 .26391 .29568 .26241 .29306 .25962 Mtetra
.29306 .25962 .29568 .26241 .29975 .2609 .29713 .25811 Mtetra
.29713 .25811 .29975 .2609 .30382 .25939 .3012 .25659 Mtetra
.3012 .25659 .30382 .25939 .3079 .25788 .30528 .25508 Mtetra
.30528 .25508 .3079 .25788 .31198 .25636 .30937 .25356 Mtetra
.30937 .25356 .31198 .25636 .31607 .25484 .31346 .25204 Mtetra
.31346 .25204 .31607 .25484 .32016 .25332 .31756 .25051 Mtetra
.31756 .25051 .32016 .25332 .32427 .2518 .32167 .24899 Mtetra
.32167 .24899 .32427 .2518 .32838 .25028 .32578 .24746 Mtetra
.32578 .24746 .32838 .25028 .32488 .37031 .3299 .24593 Mtetra
0 0 .227 r
.3299 .24593 .32488 .37031 .32915 .36882 .32645 .36606 Mtetra
.654 .753 .922 r
.32645 .36606 .32915 .36882 .33344 .36733 .33074 .36456 Mtetra
.33074 .36456 .33344 .36733 .33773 .36583 .33504 .36306 Mtetra
.33504 .36306 .33773 .36583 .34203 .36433 .33934 .36156 Mtetra
.33934 .36156 .34203 .36433 .34634 .36283 .34365 .36006 Mtetra
.34365 .36006 .34634 .36283 .35065 .36133 .34797 .35855 Mtetra
.34797 .35855 .35065 .36133 .35497 .35982 .3523 .35704 Mtetra
.3523 .35704 .35497 .35982 .3593 .35832 .35663 .35552 Mtetra
.35663 .35552 .3593 .35832 .36363 .3568 .36097 .35401 Mtetra
.36097 .35401 .36363 .3568 .36797 .35529 .36531 .35249 Mtetra
.964 .668 .421 r
.36531 .35249 .36797 .35529 .36842 .43508 .36569 .43233 Mtetra
.647 .761 .932 r
.36569 .43233 .36842 .43508 .37288 .43359 .37015 .43084 Mtetra
.37015 .43084 .37288 .43359 .37735 .4321 .37463 .42934 Mtetra
.37463 .42934 .37735 .4321 .38183 .43061 .37911 .42784 Mtetra
.37911 .42784 .38183 .43061 .38632 .42911 .38361 .42634 Mtetra
.38361 .42634 .38632 .42911 .39081 .42761 .3881 .42484 Mtetra
.3881 .42484 .39081 .42761 .39531 .42611 .39261 .42333 Mtetra
.39261 .42333 .39531 .42611 .39982 .42461 .39712 .42182 Mtetra
.39712 .42182 .39982 .42461 .40434 .4231 .40164 .42031 Mtetra
.40164 .42031 .40434 .4231 .40886 .42159 .40617 .4188 Mtetra
.40617 .4188 .40886 .42159 .4134 .42008 .41071 .41728 Mtetra
.41071 .41728 .4134 .42008 .41793 .41856 .41525 .41576 Mtetra
.41525 .41576 .41793 .41856 .42248 .41705 .41981 .41424 Mtetra
.41981 .41424 .42248 .41705 .42704 .41553 .42437 .41272 Mtetra
.42437 .41272 .42704 .41553 .4316 .414 .42893 .41119 Mtetra
.42893 .41119 .4316 .414 .43617 .41248 .43351 .40966 Mtetra
.43351 .40966 .43617 .41248 .44075 .41095 .43809 .40813 Mtetra
.43809 .40813 .44075 .41095 .44533 .40942 .44268 .40659 Mtetra
.44268 .40659 .44533 .40942 .44993 .40789 .44728 .40505 Mtetra
.97 .694 .451 r
.44728 .40505 .44993 .40789 .45525 .37311 .45652 .19886 Mtetra
.52 .294 .512 r
.45652 .19886 .45525 .37311 .4633 .20022 .46084 .19726 Mtetra
.663 .742 .908 r
.46084 .19726 .4633 .20022 .46763 .19862 .46517 .19565 Mtetra
.46517 .19565 .46763 .19862 .47197 .19701 .46951 .19403 Mtetra
.46951 .19403 .47197 .19701 .47631 .1954 .47386 .19242 Mtetra
.47386 .19242 .47631 .1954 .48065 .19378 .47821 .1908 Mtetra
.47821 .1908 .48065 .19378 .48501 .19217 .48257 .18918 Mtetra
.48257 .18918 .48501 .19217 .48937 .19055 .48694 .18756 Mtetra
.48694 .18756 .48937 .19055 .49374 .18893 .49131 .18593 Mtetra
.49131 .18593 .49374 .18893 .49812 .18731 .49569 .1843 Mtetra
.49569 .1843 .49812 .18731 .5025 .18568 .50008 .18267 Mtetra
.50008 .18267 .5025 .18568 .50622 .29649 .50447 .18104 Mtetra
.523 .3 .518 r
.50447 .18104 .50622 .29649 .51078 .29489 .50887 .1794 Mtetra
.50887 .1794 .51078 .29489 .51534 .29329 .51328 .17776 Mtetra
0 0 .329 r
.51328 .17776 .51534 .29329 .51992 .29168 .51743 .28871 Mtetra
.655 .752 .921 r
.51743 .28871 .51992 .29168 .5245 .29008 .52202 .2871 Mtetra
.52202 .2871 .5245 .29008 .5291 .28847 .52661 .28549 Mtetra
.52661 .28549 .5291 .28847 .5337 .28685 .53122 .28387 Mtetra
.53122 .28387 .5337 .28685 .5383 .28524 .53583 .28225 Mtetra
.53583 .28225 .5383 .28524 .54292 .28362 .54045 .28063 Mtetra
.54045 .28063 .54292 .28362 .54754 .282 .54507 .279 Mtetra
.976 .697 .431 r
.54507 .279 .54754 .282 .55217 .28038 .54877 .15963 Mtetra
.523 .3 .517 r
.54877 .15963 .55217 .28038 .55681 .27875 .55323 .15796 Mtetra
.55323 .15796 .55681 .27875 .56006 .15937 .5577 .1563 Mtetra
.664 .741 .908 r
.5577 .1563 .56006 .15937 .56454 .15771 .56218 .15463 Mtetra
.56218 .15463 .56454 .15771 .56902 .15604 .56667 .15295 Mtetra
.56667 .15295 .56902 .15604 .57351 .15437 .57117 .15128 Mtetra
.57117 .15128 .57351 .15437 .57801 .1527 .57567 .1496 Mtetra
.57567 .1496 .57801 .1527 .58251 .15102 .58018 .14792 Mtetra
.58018 .14792 .58251 .15102 .58702 .14934 .58469 .14624 Mtetra
.58469 .14624 .58702 .14934 .59154 .14766 .58922 .14455 Mtetra
.58922 .14455 .59154 .14766 .59607 .14598 .59375 .14287 Mtetra
.59375 .14287 .59607 .14598 .6006 .14429 .59829 .14118 Mtetra
.59829 .14118 .6006 .14429 .60514 .14261 .60283 .13948 Mtetra
.60283 .13948 .60514 .14261 .60969 .14091 .60739 .13778 Mtetra
.60739 .13778 .60969 .14091 .61425 .13922 .61195 .13609 Mtetra
.61195 .13609 .61425 .13922 .61881 .13752 .61652 .13438 Mtetra
.61652 .13438 .61881 .13752 .62338 .13582 .62109 .13268 Mtetra
.62109 .13268 .62338 .13582 .62796 .13412 .62568 .13097 Mtetra
.62568 .13097 .62796 .13412 .63255 .13242 .63027 .12926 Mtetra
.63027 .12926 .63255 .13242 .63714 .13071 .63487 .12755 Mtetra
.63487 .12755 .63714 .13071 .64174 .129 .63947 .12583 Mtetra
.63947 .12583 .64174 .129 .64635 .12728 .64408 .12411 Mtetra
.64408 .12411 .64635 .12728 .65096 .12557 .64871 .12239 Mtetra
.64871 .12239 .65096 .12557 .65559 .12385 .65333 .12067 Mtetra
.65333 .12067 .65559 .12385 .66022 .12212 .65797 .11894 Mtetra
.65797 .11894 .66022 .12212 .66486 .1204 .66261 .11721 Mtetra
.66261 .11721 .66486 .1204 .6695 .11867 .66727 .11547 Mtetra
.66727 .11547 .6695 .11867 .67416 .11694 .67193 .11374 Mtetra
.67193 .11374 .67416 .11694 .67882 .11521 .67659 .112 Mtetra
.67659 .112 .67882 .11521 .68349 .11347 .68127 .11026 Mtetra
.68127 .11026 .68349 .11347 .68817 .11173 .68595 .10851 Mtetra
.68595 .10851 .68817 .11173 .69285 .10999 .69064 .10677 Mtetra
.69064 .10677 .69285 .10999 .69754 .10824 .69534 .10501 Mtetra
.69534 .10501 .69754 .10824 .70224 .1065 .70004 .10326 Mtetra
.70004 .10326 .70224 .1065 .70695 .10475 .70476 .10151 Mtetra
.70476 .10151 .70695 .10475 .71167 .10299 .70948 .09975 Mtetra
.70948 .09975 .71167 .10299 .71639 .10123 .71421 .09798 Mtetra
.71421 .09798 .71639 .10123 .72112 .09948 .71895 .09622 Mtetra
.71895 .09622 .72112 .09948 .72586 .09771 .72369 .09445 Mtetra
.72369 .09445 .72586 .09771 .73061 .09595 .72844 .09268 Mtetra
.72844 .09268 .73061 .09595 .73537 .09418 .7332 .09091 Mtetra
.7332 .09091 .73537 .09418 .74013 .09241 .73797 .08913 Mtetra
.73797 .08913 .74013 .09241 .7449 .09063 .74275 .08735 Mtetra
.10275 .32217 .10554 .32477 .10932 .32336 .10653 .32076 Mtetra
.10653 .32076 .10932 .32336 .1131 .32195 .11031 .31934 Mtetra
.11031 .31934 .1131 .32195 .11689 .32054 .11411 .31793 Mtetra
.11411 .31793 .11689 .32054 .12068 .31913 .1179 .31651 Mtetra
.1179 .31651 .12068 .31913 .12448 .31771 .12171 .31509 Mtetra
.12171 .31509 .12448 .31771 .12829 .31629 .12552 .31367 Mtetra
.12552 .31367 .12829 .31629 .1321 .31487 .12933 .31225 Mtetra
.12933 .31225 .1321 .31487 .13592 .31345 .13315 .31082 Mtetra
.13315 .31082 .13592 .31345 .13974 .31203 .13698 .30939 Mtetra
.13698 .30939 .13974 .31203 .14357 .3106 .14081 .30796 Mtetra
.14081 .30796 .14357 .3106 .1474 .30917 .14465 .30653 Mtetra
.14465 .30653 .1474 .30917 .15124 .30774 .14849 .30509 Mtetra
.14849 .30509 .15124 .30774 .15509 .30631 .15234 .30366 Mtetra
.15234 .30366 .15509 .30631 .15894 .30487 .15619 .30222 Mtetra
.15619 .30222 .15894 .30487 .1628 .30344 .16005 .30078 Mtetra
.16005 .30078 .1628 .30344 .16666 .302 .16392 .29933 Mtetra
.16392 .29933 .16666 .302 .17053 .30055 .16779 .29789 Mtetra
.16779 .29789 .17053 .30055 .1744 .29911 .17167 .29644 Mtetra
.17167 .29644 .1744 .29911 .17829 .29767 .17555 .29499 Mtetra
.17555 .29499 .17829 .29767 .18217 .29622 .17944 .29354 Mtetra
.17944 .29354 .18217 .29622 .18606 .29477 .18334 .29208 Mtetra
.18334 .29208 .18606 .29477 .18996 .29331 .18724 .29063 Mtetra
.18724 .29063 .18996 .29331 .19387 .29186 .19115 .28917 Mtetra
.19115 .28917 .19387 .29186 .19778 .2904 .19506 .28771 Mtetra
.19506 .28771 .19778 .2904 .20169 .28894 .19898 .28624 Mtetra
.19898 .28624 .20169 .28894 .20561 .28748 .20291 .28478 Mtetra
.20291 .28478 .20561 .28748 .20954 .28602 .20684 .28331 Mtetra
.20684 .28331 .20954 .28602 .21348 .28455 .21078 .28184 Mtetra
.21078 .28184 .21348 .28455 .21742 .28309 .21472 .28037 Mtetra
.21472 .28037 .21742 .28309 .22136 .28162 .21867 .2789 Mtetra
.21867 .2789 .22136 .28162 .22531 .28014 .22262 .27742 Mtetra
.22262 .27742 .22531 .28014 .22927 .27867 .22658 .27594 Mtetra
.22658 .27594 .22927 .27867 .23323 .27719 .23055 .27446 Mtetra
.23055 .27446 .23323 .27719 .23675 .28055 .23452 .27298 Mtetra
.214 .258 .692 r
.23452 .27298 .23675 .28055 .24074 .27907 .23806 .27633 Mtetra
.663 .742 .908 r
.23806 .27633 .24074 .27907 .24472 .27759 .24205 .27484 Mtetra
.24205 .27484 .24472 .27759 .24872 .2761 .24604 .27335 Mtetra
.24604 .27335 .24872 .2761 .25272 .27461 .25005 .27186 Mtetra
.25005 .27186 .25272 .27461 .25672 .27313 .25406 .27037 Mtetra
.25406 .27037 .25672 .27313 .26074 .27163 .25807 .26887 Mtetra
.25807 .26887 .26074 .27163 .26476 .27014 .2621 .26738 Mtetra
.2621 .26738 .26476 .27014 .26878 .26864 .26612 .26588 Mtetra
.26612 .26588 .26878 .26864 .27281 .26715 .27016 .26437 Mtetra
.27016 .26437 .27281 .26715 .27685 .26565 .2742 .26287 Mtetra
.2742 .26287 .27685 .26565 .28089 .26414 .27825 .26136 Mtetra
.27825 .26136 .28089 .26414 .28494 .26264 .2823 .25985 Mtetra
.2823 .25985 .28494 .26264 .289 .26113 .28636 .25834 Mtetra
.28636 .25834 .289 .26113 .29306 .25962 .29043 .25683 Mtetra
.29043 .25683 .29306 .25962 .29713 .25811 .2945 .25531 Mtetra
.2945 .25531 .29713 .25811 .3012 .25659 .29858 .25379 Mtetra
.29858 .25379 .3012 .25659 .30528 .25508 .30266 .25227 Mtetra
.30266 .25227 .30528 .25508 .30937 .25356 .30675 .25075 Mtetra
.30675 .25075 .30937 .25356 .31346 .25204 .31085 .24922 Mtetra
.31085 .24922 .31346 .25204 .31756 .25051 .31495 .24769 Mtetra
.31495 .24769 .31756 .25051 .32167 .24899 .31906 .24616 Mtetra
.31906 .24616 .32167 .24899 .32578 .24746 .32318 .24463 Mtetra
.32318 .24463 .32578 .24746 .3299 .24593 .3273 .24309 Mtetra
.961 .677 .45 r
.3273 .24309 .3299 .24593 .32645 .36606 .32374 .3633 Mtetra
.654 .753 .922 r
.32374 .3633 .32645 .36606 .33074 .36456 .32804 .36179 Mtetra
.32804 .36179 .33074 .36456 .33504 .36306 .33234 .36029 Mtetra
.33234 .36029 .33504 .36306 .33934 .36156 .33665 .35878 Mtetra
.33665 .35878 .33934 .36156 .34365 .36006 .34096 .35727 Mtetra
.34096 .35727 .34365 .36006 .34797 .35855 .34528 .35576 Mtetra
.34528 .35576 .34797 .35855 .3523 .35704 .34961 .35424 Mtetra
.34961 .35424 .3523 .35704 .35663 .35552 .35395 .35272 Mtetra
.35395 .35272 .35663 .35552 .36097 .35401 .35829 .3512 Mtetra
.964 .668 .423 r
.35829 .3512 .36097 .35401 .36531 .35249 .35848 .43107 Mtetra
.501 .255 .473 r
.35848 .43107 .36531 .35249 .36569 .43233 .36295 .42957 Mtetra
.647 .761 .932 r
.36295 .42957 .36569 .43233 .37015 .43084 .36742 .42807 Mtetra
.36742 .42807 .37015 .43084 .37463 .42934 .3719 .42657 Mtetra
.3719 .42657 .37463 .42934 .37911 .42784 .37639 .42507 Mtetra
.37639 .42507 .37911 .42784 .38361 .42634 .38088 .42356 Mtetra
.38088 .42356 .38361 .42634 .3881 .42484 .38539 .42205 Mtetra
.38539 .42205 .3881 .42484 .39261 .42333 .3899 .42054 Mtetra
.3899 .42054 .39261 .42333 .39712 .42182 .39442 .41903 Mtetra
.39442 .41903 .39712 .42182 .40164 .42031 .39894 .41751 Mtetra
.39894 .41751 .40164 .42031 .40617 .4188 .40348 .41599 Mtetra
.40348 .41599 .40617 .4188 .41071 .41728 .40802 .41447 Mtetra
.40802 .41447 .41071 .41728 .41525 .41576 .41257 .41295 Mtetra
.41257 .41295 .41525 .41576 .41981 .41424 .41712 .41142 Mtetra
.41712 .41142 .41981 .41424 .42437 .41272 .42169 .40989 Mtetra
.42169 .40989 .42437 .41272 .42893 .41119 .42626 .40836 Mtetra
.42626 .40836 .42893 .41119 .43351 .40966 .43084 .40683 Mtetra
.43084 .40683 .43351 .40966 .43809 .40813 .43543 .40529 Mtetra
.43543 .40529 .43809 .40813 .44268 .40659 .44002 .40375 Mtetra
.97 .694 .453 r
.44002 .40375 .44268 .40659 .44728 .40505 .44972 .1975 Mtetra
.519 .292 .51 r
.44972 .1975 .44728 .40505 .45652 .19886 .45404 .19589 Mtetra
.663 .742 .908 r
.45404 .19589 .45652 .19886 .46084 .19726 .45837 .19428 Mtetra
.45837 .19428 .46084 .19726 .46517 .19565 .46271 .19267 Mtetra
.46271 .19267 .46517 .19565 .46951 .19403 .46705 .19105 Mtetra
.46705 .19105 .46951 .19403 .47386 .19242 .4714 .18943 Mtetra
.4714 .18943 .47386 .19242 .47821 .1908 .47576 .18781 Mtetra
.47576 .18781 .47821 .1908 .48257 .18918 .48012 .18618 Mtetra
.48012 .18618 .48257 .18918 .48694 .18756 .48449 .18455 Mtetra
.48449 .18455 .48694 .18756 .49131 .18593 .48887 .18292 Mtetra
.48887 .18292 .49131 .18593 .49569 .1843 .49325 .18129 Mtetra
.49325 .18129 .49569 .1843 .50008 .18267 .49765 .17965 Mtetra
.49765 .17965 .50008 .18267 .50447 .18104 .50205 .17802 Mtetra
.50205 .17802 .50447 .18104 .50887 .1794 .50645 .17638 Mtetra
.50645 .17638 .50887 .1794 .51328 .17776 .51086 .17473 Mtetra
.51086 .17473 .51328 .17776 .51743 .28871 .51529 .17309 Mtetra
.522 .299 .517 r
.51529 .17309 .51743 .28871 .52202 .2871 .51971 .17144 Mtetra
.51971 .17144 .52202 .2871 .52661 .28549 .52415 .16979 Mtetra
0 0 .333 r
.52415 .16979 .52661 .28549 .53122 .28387 .52873 .28088 Mtetra
.655 .752 .921 r
.52873 .28088 .53122 .28387 .53583 .28225 .53335 .27925 Mtetra
.53335 .27925 .53583 .28225 .54045 .28063 .53797 .27763 Mtetra
.976 .697 .433 r
.53797 .27763 .54045 .28063 .54507 .279 .54193 .15822 Mtetra
.522 .299 .517 r
.54193 .15822 .54507 .279 .54877 .15963 .54639 .15655 Mtetra
.664 .741 .908 r
.54639 .15655 .54877 .15963 .55323 .15796 .55086 .15488 Mtetra
.55086 .15488 .55323 .15796 .5577 .1563 .55534 .15321 Mtetra
.55534 .15321 .5577 .1563 .56218 .15463 .55982 .15154 Mtetra
.55982 .15154 .56218 .15463 .56667 .15295 .56432 .14986 Mtetra
.56432 .14986 .56667 .15295 .57117 .15128 .56882 .14818 Mtetra
.56882 .14818 .57117 .15128 .57567 .1496 .57332 .1465 Mtetra
.57332 .1465 .57567 .1496 .58018 .14792 .57784 .14481 Mtetra
.57784 .14481 .58018 .14792 .58469 .14624 .58236 .14313 Mtetra
.58236 .14313 .58469 .14624 .58922 .14455 .58689 .14144 Mtetra
.58689 .14144 .58922 .14455 .59375 .14287 .59142 .13974 Mtetra
.59142 .13974 .59375 .14287 .59829 .14118 .59597 .13805 Mtetra
.59597 .13805 .59829 .14118 .60283 .13948 .60052 .13635 Mtetra
.60052 .13635 .60283 .13948 .60739 .13778 .60508 .13465 Mtetra
.60508 .13465 .60739 .13778 .61195 .13609 .60964 .13294 Mtetra
.60964 .13294 .61195 .13609 .61652 .13438 .61422 .13123 Mtetra
.61422 .13123 .61652 .13438 .62109 .13268 .6188 .12952 Mtetra
.6188 .12952 .62109 .13268 .62568 .13097 .62339 .12781 Mtetra
.62339 .12781 .62568 .13097 .63027 .12926 .62798 .12609 Mtetra
.62798 .12609 .63027 .12926 .63487 .12755 .63258 .12438 Mtetra
.63258 .12438 .63487 .12755 .63947 .12583 .6372 .12265 Mtetra
.6372 .12265 .63947 .12583 .64408 .12411 .64181 .12093 Mtetra
.64181 .12093 .64408 .12411 .64871 .12239 .64644 .1192 Mtetra
.64644 .1192 .64871 .12239 .65333 .12067 .65107 .11747 Mtetra
.65107 .11747 .65333 .12067 .65797 .11894 .65572 .11574 Mtetra
.65572 .11574 .65797 .11894 .66261 .11721 .66037 .11401 Mtetra
.66037 .11401 .66261 .11721 .66727 .11547 .66502 .11227 Mtetra
.66502 .11227 .66727 .11547 .67193 .11374 .66969 .11053 Mtetra
.66969 .11053 .67193 .11374 .67659 .112 .67436 .10878 Mtetra
.67436 .10878 .67659 .112 .68127 .11026 .67904 .10703 Mtetra
.67904 .10703 .68127 .11026 .68595 .10851 .68373 .10528 Mtetra
.68373 .10528 .68595 .10851 .69064 .10677 .68842 .10353 Mtetra
.68842 .10353 .69064 .10677 .69534 .10501 .69313 .10178 Mtetra
.69313 .10178 .69534 .10501 .70004 .10326 .69784 .10002 Mtetra
.69784 .10002 .70004 .10326 .70476 .10151 .70256 .09826 Mtetra
.70256 .09826 .70476 .10151 .70948 .09975 .70728 .09649 Mtetra
.70728 .09649 .70948 .09975 .71421 .09798 .71202 .09472 Mtetra
.71202 .09472 .71421 .09798 .71895 .09622 .71676 .09295 Mtetra
.71676 .09295 .71895 .09622 .72369 .09445 .72151 .09118 Mtetra
.72151 .09118 .72369 .09445 .72844 .09268 .72627 .0894 Mtetra
.72627 .0894 .72844 .09268 .7332 .09091 .73104 .08762 Mtetra
.73104 .08762 .7332 .09091 .73797 .08913 .73581 .08584 Mtetra
.73581 .08584 .73797 .08913 .74275 .08735 .74059 .08406 Mtetra
.09995 .31956 .10275 .32217 .10653 .32076 .10373 .31815 Mtetra
.10373 .31815 .10653 .32076 .11031 .31934 .10752 .31673 Mtetra
.10752 .31673 .11031 .31934 .11411 .31793 .11132 .31531 Mtetra
.11132 .31531 .11411 .31793 .1179 .31651 .11512 .31389 Mtetra
.11512 .31389 .1179 .31651 .12171 .31509 .11892 .31247 Mtetra
.11892 .31247 .12171 .31509 .12552 .31367 .12273 .31104 Mtetra
.12273 .31104 .12552 .31367 .12933 .31225 .12655 .30961 Mtetra
.12655 .30961 .12933 .31225 .13315 .31082 .13038 .30818 Mtetra
.13038 .30818 .13315 .31082 .13698 .30939 .1342 .30675 Mtetra
.1342 .30675 .13698 .30939 .14081 .30796 .13804 .30531 Mtetra
.13804 .30531 .14081 .30796 .14465 .30653 .14188 .30388 Mtetra
.14188 .30388 .14465 .30653 .14849 .30509 .14573 .30244 Mtetra
.14573 .30244 .14849 .30509 .15234 .30366 .14958 .301 Mtetra
.14958 .301 .15234 .30366 .15619 .30222 .15344 .29956 Mtetra
.15344 .29956 .15619 .30222 .16005 .30078 .1573 .29811 Mtetra
.1573 .29811 .16005 .30078 .16392 .29933 .16117 .29666 Mtetra
.16117 .29666 .16392 .29933 .16779 .29789 .16505 .29521 Mtetra
.16505 .29521 .16779 .29789 .17167 .29644 .16893 .29376 Mtetra
.16893 .29376 .17167 .29644 .17555 .29499 .17282 .29231 Mtetra
.17282 .29231 .17555 .29499 .17944 .29354 .17671 .29085 Mtetra
.17671 .29085 .17944 .29354 .18334 .29208 .18061 .28939 Mtetra
.18061 .28939 .18334 .29208 .18724 .29063 .18451 .28793 Mtetra
.18451 .28793 .18724 .29063 .19115 .28917 .18842 .28647 Mtetra
.18842 .28647 .19115 .28917 .19506 .28771 .19234 .285 Mtetra
.19234 .285 .19506 .28771 .19898 .28624 .19626 .28354 Mtetra
.19626 .28354 .19898 .28624 .20291 .28478 .20019 .28207 Mtetra
.20019 .28207 .20291 .28478 .20684 .28331 .20413 .2806 Mtetra
.20413 .2806 .20684 .28331 .21078 .28184 .20807 .27912 Mtetra
.20807 .27912 .21078 .28184 .21472 .28037 .21201 .27765 Mtetra
.21201 .27765 .21472 .28037 .21867 .2789 .21597 .27617 Mtetra
.21597 .27617 .21867 .2789 .22262 .27742 .21993 .27469 Mtetra
.21993 .27469 .22262 .27742 .22658 .27594 .22389 .2732 Mtetra
.22389 .2732 .22658 .27594 .23055 .27446 .22786 .27172 Mtetra
.22786 .27172 .23055 .27446 .23452 .27298 .23184 .27023 Mtetra
.23184 .27023 .23452 .27298 .23806 .27633 .23582 .26874 Mtetra
.611 .512 .718 r
.23582 .26874 .23806 .27633 .24205 .27484 .23981 .26725 Mtetra
.216 .259 .693 r
.23981 .26725 .24205 .27484 .24604 .27335 .24336 .2706 Mtetra
.663 .742 .908 r
.24336 .2706 .24604 .27335 .25005 .27186 .24737 .26911 Mtetra
.24737 .26911 .25005 .27186 .25406 .27037 .25138 .26761 Mtetra
.25138 .26761 .25406 .27037 .25807 .26887 .2554 .26611 Mtetra
.2554 .26611 .25807 .26887 .2621 .26738 .25943 .26461 Mtetra
.25943 .26461 .2621 .26738 .26612 .26588 .26346 .2631 Mtetra
.26346 .2631 .26612 .26588 .27016 .26437 .2675 .26159 Mtetra
.2675 .26159 .27016 .26437 .2742 .26287 .27154 .26009 Mtetra
.27154 .26009 .2742 .26287 .27825 .26136 .2756 .25857 Mtetra
.2756 .25857 .27825 .26136 .2823 .25985 .27965 .25706 Mtetra
.27965 .25706 .2823 .25985 .28636 .25834 .28372 .25554 Mtetra
.28372 .25554 .28636 .25834 .29043 .25683 .28778 .25403 Mtetra
.28778 .25403 .29043 .25683 .2945 .25531 .29186 .2525 Mtetra
.29186 .2525 .2945 .25531 .29858 .25379 .29594 .25098 Mtetra
.29594 .25098 .29858 .25379 .30266 .25227 .30003 .24946 Mtetra
.30003 .24946 .30266 .25227 .30675 .25075 .30413 .24793 Mtetra
.30413 .24793 .30675 .25075 .31085 .24922 .30823 .2464 Mtetra
.30823 .2464 .31085 .24922 .31495 .24769 .31233 .24487 Mtetra
.31233 .24487 .31495 .24769 .31906 .24616 .31645 .24333 Mtetra
.31645 .24333 .31906 .24616 .32318 .24463 .32057 .24179 Mtetra
.32057 .24179 .32318 .24463 .3273 .24309 .3247 .24025 Mtetra
.3247 .24025 .3273 .24309 .32374 .3633 .32883 .23871 Mtetra
0 0 .224 r
.32883 .23871 .32374 .3633 .32804 .36179 .32533 .35901 Mtetra
.654 .753 .922 r
.32533 .35901 .32804 .36179 .33234 .36029 .32963 .3575 Mtetra
.32963 .3575 .33234 .36029 .33665 .35878 .33394 .35599 Mtetra
.33394 .35599 .33665 .35878 .34096 .35727 .33826 .35448 Mtetra
.33826 .35448 .34096 .35727 .34528 .35576 .34259 .35296 Mtetra
.34259 .35296 .34528 .35576 .34961 .35424 .34692 .35144 Mtetra
.34692 .35144 .34961 .35424 .35395 .35272 .35126 .34992 Mtetra
.35126 .34992 .35395 .35272 .35829 .3512 .35561 .34839 Mtetra
.964 .668 .423 r
.35561 .34839 .35829 .3512 .35848 .43107 .35573 .4283 Mtetra
.647 .761 .932 r
.35573 .4283 .35848 .43107 .36295 .42957 .3602 .4268 Mtetra
.3602 .4268 .36295 .42957 .36742 .42807 .36467 .4253 Mtetra
.36467 .4253 .36742 .42807 .3719 .42657 .36916 .42379 Mtetra
.36916 .42379 .3719 .42657 .37639 .42507 .37365 .42229 Mtetra
.37365 .42229 .37639 .42507 .38088 .42356 .37815 .42078 Mtetra
.37815 .42078 .38088 .42356 .38539 .42205 .38266 .41926 Mtetra
.38266 .41926 .38539 .42205 .3899 .42054 .38718 .41775 Mtetra
.38718 .41775 .3899 .42054 .39442 .41903 .3917 .41623 Mtetra
.3917 .41623 .39442 .41903 .39894 .41751 .39623 .41471 Mtetra
.39623 .41471 .39894 .41751 .40348 .41599 .40077 .41318 Mtetra
.40077 .41318 .40348 .41599 .40802 .41447 .40531 .41166 Mtetra
.40531 .41166 .40802 .41447 .41257 .41295 .40987 .41013 Mtetra
.40987 .41013 .41257 .41295 .41712 .41142 .41443 .4086 Mtetra
.41443 .4086 .41712 .41142 .42169 .40989 .419 .40706 Mtetra
.419 .40706 .42169 .40989 .42626 .40836 .42358 .40553 Mtetra
.42358 .40553 .42626 .40836 .43084 .40683 .42816 .40399 Mtetra
.42816 .40399 .43084 .40683 .43543 .40529 .43275 .40245 Mtetra
.969 .694 .454 r
.43275 .40245 .43543 .40529 .44002 .40375 .44291 .19614 Mtetra
.518 .291 .509 r
.44291 .19614 .44002 .40375 .44972 .1975 .44723 .19453 Mtetra
.663 .742 .908 r
.44723 .19453 .44972 .1975 .45404 .19589 .45156 .19292 Mtetra
.45156 .19292 .45404 .19589 .45837 .19428 .45589 .1913 Mtetra
.45589 .1913 .45837 .19428 .46271 .19267 .46023 .18968 Mtetra
.46023 .18968 .46271 .19267 .46705 .19105 .46458 .18806 Mtetra
.46458 .18806 .46705 .19105 .4714 .18943 .46894 .18643 Mtetra
.46894 .18643 .4714 .18943 .47576 .18781 .4733 .1848 Mtetra
.4733 .1848 .47576 .18781 .48012 .18618 .47767 .18317 Mtetra
.47767 .18317 .48012 .18618 .48449 .18455 .48204 .18154 Mtetra
.48204 .18154 .48449 .18455 .48887 .18292 .48642 .17991 Mtetra
.48642 .17991 .48887 .18292 .49325 .18129 .49081 .17827 Mtetra
.49081 .17827 .49325 .18129 .49765 .17965 .49521 .17663 Mtetra
.49521 .17663 .49765 .17965 .50205 .17802 .49961 .17499 Mtetra
.49961 .17499 .50205 .17802 .50645 .17638 .50402 .17334 Mtetra
.50402 .17334 .50645 .17638 .51086 .17473 .50844 .17169 Mtetra
.50844 .17169 .51086 .17473 .51529 .17309 .51287 .17004 Mtetra
.51287 .17004 .51529 .17309 .51971 .17144 .5173 .16839 Mtetra
.5173 .16839 .51971 .17144 .52415 .16979 .52174 .16673 Mtetra
.52174 .16673 .52415 .16979 .52873 .28088 .52618 .16507 Mtetra
.522 .299 .517 r
.52618 .16507 .52873 .28088 .53335 .27925 .53064 .16341 Mtetra
.54 .313 .519 r
.53064 .16341 .53335 .27925 .53797 .27763 .53508 .15681 Mtetra
.521 .298 .516 r
.53508 .15681 .53797 .27763 .54193 .15822 .53954 .15514 Mtetra
.664 .741 .908 r
.53954 .15514 .54193 .15822 .54639 .15655 .54401 .15347 Mtetra
.54401 .15347 .54639 .15655 .55086 .15488 .54849 .1518 Mtetra
.54849 .1518 .55086 .15488 .55534 .15321 .55297 .15012 Mtetra
.55297 .15012 .55534 .15321 .55982 .15154 .55746 .14844 Mtetra
.55746 .14844 .55982 .15154 .56432 .14986 .56195 .14676 Mtetra
.56195 .14676 .56432 .14986 .56882 .14818 .56646 .14507 Mtetra
.56646 .14507 .56882 .14818 .57332 .1465 .57097 .14339 Mtetra
.57097 .14339 .57332 .1465 .57784 .14481 .57549 .1417 Mtetra
.57549 .1417 .57784 .14481 .58236 .14313 .58002 .14 Mtetra
.58002 .14 .58236 .14313 .58689 .14144 .58455 .13831 Mtetra
.58455 .13831 .58689 .14144 .59142 .13974 .58909 .13661 Mtetra
.58909 .13661 .59142 .13974 .59597 .13805 .59364 .13491 Mtetra
.59364 .13491 .59597 .13805 .60052 .13635 .59819 .1332 Mtetra
.59819 .1332 .60052 .13635 .60508 .13465 .60276 .1315 Mtetra
.60276 .1315 .60508 .13465 .60964 .13294 .60733 .12979 Mtetra
.60733 .12979 .60964 .13294 .61422 .13123 .61191 .12807 Mtetra
.61191 .12807 .61422 .13123 .6188 .12952 .61649 .12636 Mtetra
.61649 .12636 .6188 .12952 .62339 .12781 .62109 .12464 Mtetra
.62109 .12464 .62339 .12781 .62798 .12609 .62569 .12292 Mtetra
.62569 .12292 .62798 .12609 .63258 .12438 .6303 .1212 Mtetra
.6303 .1212 .63258 .12438 .6372 .12265 .63491 .11947 Mtetra
.63491 .11947 .6372 .12265 .64181 .12093 .63954 .11774 Mtetra
.63954 .11774 .64181 .12093 .64644 .1192 .64417 .11601 Mtetra
.64417 .11601 .64644 .1192 .65107 .11747 .64881 .11427 Mtetra
.64881 .11427 .65107 .11747 .65572 .11574 .65345 .11253 Mtetra
.65345 .11253 .65572 .11574 .66037 .11401 .65811 .11079 Mtetra
.65811 .11079 .66037 .11401 .66502 .11227 .66277 .10905 Mtetra
.66277 .10905 .66502 .11227 .66969 .11053 .66744 .1073 Mtetra
.66744 .1073 .66969 .11053 .67436 .10878 .67212 .10555 Mtetra
.67212 .10555 .67436 .10878 .67904 .10703 .6768 .1038 Mtetra
.6768 .1038 .67904 .10703 .68373 .10528 .6815 .10205 Mtetra
.6815 .10205 .68373 .10528 .68842 .10353 .6862 .10029 Mtetra
.6862 .10029 .68842 .10353 .69313 .10178 .69091 .09853 Mtetra
.69091 .09853 .69313 .10178 .69784 .10002 .69562 .09676 Mtetra
.69562 .09676 .69784 .10002 .70256 .09826 .70035 .095 Mtetra
.70035 .095 .70256 .09826 .70728 .09649 .70508 .09323 Mtetra
.70508 .09323 .70728 .09649 .71202 .09472 .70982 .09145 Mtetra
.70982 .09145 .71202 .09472 .71676 .09295 .71457 .08968 Mtetra
.71457 .08968 .71676 .09295 .72151 .09118 .71932 .0879 Mtetra
.71932 .0879 .72151 .09118 .72627 .0894 .72409 .08612 Mtetra
.72409 .08612 .72627 .0894 .73104 .08762 .72886 .08433 Mtetra
.72886 .08433 .73104 .08762 .73581 .08584 .73364 .08254 Mtetra
.73364 .08254 .73581 .08584 .74059 .08406 .73843 .08075 Mtetra
.09714 .31695 .09995 .31956 .10373 .31815 .10093 .31553 Mtetra
.10093 .31553 .10373 .31815 .10752 .31673 .10472 .31411 Mtetra
.10472 .31411 .10752 .31673 .11132 .31531 .10852 .31268 Mtetra
.10852 .31268 .11132 .31531 .11512 .31389 .11232 .31126 Mtetra
.11232 .31126 .11512 .31389 .11892 .31247 .11613 .30983 Mtetra
.11613 .30983 .11892 .31247 .12273 .31104 .11995 .3084 Mtetra
.11995 .3084 .12273 .31104 .12655 .30961 .12377 .30697 Mtetra
.12377 .30697 .12655 .30961 .13038 .30818 .12759 .30554 Mtetra
.12759 .30554 .13038 .30818 .1342 .30675 .13143 .3041 Mtetra
.13143 .3041 .1342 .30675 .13804 .30531 .13526 .30266 Mtetra
.13526 .30266 .13804 .30531 .14188 .30388 .13911 .30122 Mtetra
.13911 .30122 .14188 .30388 .14573 .30244 .14296 .29978 Mtetra
.14296 .29978 .14573 .30244 .14958 .301 .14681 .29833 Mtetra
.14681 .29833 .14958 .301 .15344 .29956 .15067 .29689 Mtetra
.15067 .29689 .15344 .29956 .1573 .29811 .15454 .29544 Mtetra
.15454 .29544 .1573 .29811 .16117 .29666 .15841 .29399 Mtetra
.15841 .29399 .16117 .29666 .16505 .29521 .16229 .29253 Mtetra
.16229 .29253 .16505 .29521 .16893 .29376 .16618 .29108 Mtetra
.16618 .29108 .16893 .29376 .17282 .29231 .17007 .28962 Mtetra
.17007 .28962 .17282 .29231 .17671 .29085 .17397 .28816 Mtetra
.17397 .28816 .17671 .29085 .18061 .28939 .17787 .28669 Mtetra
.17787 .28669 .18061 .28939 .18451 .28793 .18178 .28523 Mtetra
.18178 .28523 .18451 .28793 .18842 .28647 .18569 .28376 Mtetra
.18569 .28376 .18842 .28647 .19234 .285 .18961 .28229 Mtetra
.18961 .28229 .19234 .285 .19626 .28354 .19354 .28082 Mtetra
.19354 .28082 .19626 .28354 .20019 .28207 .19747 .27935 Mtetra
.19747 .27935 .20019 .28207 .20413 .2806 .20141 .27787 Mtetra
.20141 .27787 .20413 .2806 .20807 .27912 .20535 .2764 Mtetra
.20535 .2764 .20807 .27912 .21201 .27765 .2093 .27492 Mtetra
.2093 .27492 .21201 .27765 .21597 .27617 .21326 .27343 Mtetra
.21326 .27343 .21597 .27617 .21993 .27469 .21722 .27195 Mtetra
.21722 .27195 .21993 .27469 .22389 .2732 .22119 .27046 Mtetra
.22119 .27046 .22389 .2732 .22786 .27172 .22516 .26897 Mtetra
.22516 .26897 .22786 .27172 .23184 .27023 .22914 .26748 Mtetra
.22914 .26748 .23184 .27023 .23582 .26874 .23313 .26599 Mtetra
.23313 .26599 .23582 .26874 .23981 .26725 .23712 .26449 Mtetra
.23712 .26449 .23981 .26725 .24336 .2706 .24112 .26299 Mtetra
.216 .259 .693 r
.24112 .26299 .24336 .2706 .24737 .26911 .24469 .26634 Mtetra
.663 .742 .908 r
.24469 .26634 .24737 .26911 .25138 .26761 .2487 .26484 Mtetra
.2487 .26484 .25138 .26761 .2554 .26611 .25273 .26333 Mtetra
.25273 .26333 .2554 .26611 .25943 .26461 .25676 .26183 Mtetra
.25676 .26183 .25943 .26461 .26346 .2631 .26079 .26032 Mtetra
.26079 .26032 .26346 .2631 .2675 .26159 .26483 .25881 Mtetra
.26483 .25881 .2675 .26159 .27154 .26009 .26888 .25729 Mtetra
.26888 .25729 .27154 .26009 .2756 .25857 .27294 .25578 Mtetra
.27294 .25578 .2756 .25857 .27965 .25706 .277 .25426 Mtetra
.277 .25426 .27965 .25706 .28372 .25554 .28106 .25274 Mtetra
.28106 .25274 .28372 .25554 .28778 .25403 .28514 .25122 Mtetra
.28514 .25122 .28778 .25403 .29186 .2525 .28922 .24969 Mtetra
.28922 .24969 .29186 .2525 .29594 .25098 .2933 .24816 Mtetra
.2933 .24816 .29594 .25098 .30003 .24946 .29739 .24663 Mtetra
.29739 .24663 .30003 .24946 .30413 .24793 .30149 .2451 Mtetra
.30149 .2451 .30413 .24793 .30823 .2464 .3056 .24357 Mtetra
.3056 .24357 .30823 .2464 .31233 .24487 .30971 .24203 Mtetra
.30971 .24203 .31233 .24487 .31645 .24333 .31383 .24049 Mtetra
.31383 .24049 .31645 .24333 .32057 .24179 .31795 .23895 Mtetra
.31795 .23895 .32057 .24179 .3247 .24025 .32208 .2374 Mtetra
.32208 .2374 .3247 .24025 .32883 .23871 .32622 .23586 Mtetra
.32622 .23586 .32883 .23871 .32533 .35901 .33036 .23431 Mtetra
0 0 .224 r
.33036 .23431 .32533 .35901 .32963 .3575 .32691 .35471 Mtetra
.654 .753 .922 r
.32691 .35471 .32963 .3575 .33394 .35599 .33123 .35319 Mtetra
.33123 .35319 .33394 .35599 .33826 .35448 .33555 .35167 Mtetra
.33555 .35167 .33826 .35448 .34259 .35296 .33988 .35015 Mtetra
.33988 .35015 .34259 .35296 .34692 .35144 .34422 .34863 Mtetra
.34422 .34863 .34692 .35144 .35126 .34992 .34857 .3471 Mtetra
.34857 .3471 .35126 .34992 .35561 .34839 .35292 .34557 Mtetra
.964 .668 .423 r
.35292 .34557 .35561 .34839 .35573 .4283 .35296 .42553 Mtetra
.647 .761 .932 r
.35296 .42553 .35573 .4283 .3602 .4268 .35744 .42403 Mtetra
.35744 .42403 .3602 .4268 .36467 .4253 .36192 .42252 Mtetra
.36192 .42252 .36467 .4253 .36916 .42379 .36641 .42101 Mtetra
.36641 .42101 .36916 .42379 .37365 .42229 .37091 .4195 Mtetra
.37091 .4195 .37365 .42229 .37815 .42078 .37541 .41798 Mtetra
.37541 .41798 .37815 .42078 .38266 .41926 .37993 .41646 Mtetra
.37993 .41646 .38266 .41926 .38718 .41775 .38445 .41494 Mtetra
.38445 .41494 .38718 .41775 .3917 .41623 .38897 .41342 Mtetra
.38897 .41342 .3917 .41623 .39623 .41471 .39351 .41189 Mtetra
.39351 .41189 .39623 .41471 .40077 .41318 .39805 .41036 Mtetra
.39805 .41036 .40077 .41318 .40531 .41166 .4026 .40883 Mtetra
.4026 .40883 .40531 .41166 .40987 .41013 .40716 .4073 Mtetra
.40716 .4073 .40987 .41013 .41443 .4086 .41173 .40576 Mtetra
.41173 .40576 .41443 .4086 .419 .40706 .4163 .40423 Mtetra
.4163 .40423 .419 .40706 .42358 .40553 .42089 .40268 Mtetra
.42089 .40268 .42358 .40553 .42816 .40399 .42548 .40114 Mtetra
.969 .694 .456 r
.42548 .40114 .42816 .40399 .43275 .40245 .4361 .19478 Mtetra
.517 .29 .508 r
.4361 .19478 .43275 .40245 .44291 .19614 .44042 .19316 Mtetra
.663 .742 .908 r
.44042 .19316 .44291 .19614 .44723 .19453 .44474 .19155 Mtetra
.44474 .19155 .44723 .19453 .45156 .19292 .44907 .18993 Mtetra
.44907 .18993 .45156 .19292 .45589 .1913 .45341 .18831 Mtetra
.45341 .18831 .45589 .1913 .46023 .18968 .45775 .18668 Mtetra
.45775 .18668 .46023 .18968 .46458 .18806 .46211 .18505 Mtetra
.46211 .18505 .46458 .18806 .46894 .18643 .46647 .18343 Mtetra
.46647 .18343 .46894 .18643 .4733 .1848 .47083 .18179 Mtetra
.47083 .18179 .4733 .1848 .47767 .18317 .4752 .18016 Mtetra
.4752 .18016 .47767 .18317 .48204 .18154 .47958 .17852 Mtetra
.47958 .17852 .48204 .18154 .48642 .17991 .48397 .17688 Mtetra
.48397 .17688 .48642 .17991 .49081 .17827 .48837 .17524 Mtetra
.48837 .17524 .49081 .17827 .49521 .17663 .49277 .17359 Mtetra
.49277 .17359 .49521 .17663 .49961 .17499 .49717 .17194 Mtetra
.49717 .17194 .49961 .17499 .50402 .17334 .50159 .17029 Mtetra
.50159 .17029 .50402 .17334 .50844 .17169 .50601 .16864 Mtetra
.50601 .16864 .50844 .17169 .51287 .17004 .51044 .16698 Mtetra
.51044 .16698 .51287 .17004 .5173 .16839 .51488 .16533 Mtetra
.51488 .16533 .5173 .16839 .52174 .16673 .51932 .16366 Mtetra
.51932 .16366 .52174 .16673 .52618 .16507 .52377 .162 Mtetra
.52377 .162 .52618 .16507 .53064 .16341 .52823 .16033 Mtetra
.884 .786 .748 r
.52823 .16033 .53064 .16341 .53508 .15681 .53268 .15373 Mtetra
.664 .741 .908 r
.53268 .15373 .53508 .15681 .53954 .15514 .53715 .15205 Mtetra
.53715 .15205 .53954 .15514 .54401 .15347 .54162 .15038 Mtetra
.54162 .15038 .54401 .15347 .54849 .1518 .5461 .1487 Mtetra
.5461 .1487 .54849 .1518 .55297 .15012 .55059 .14702 Mtetra
.55059 .14702 .55297 .15012 .55746 .14844 .55508 .14533 Mtetra
.55508 .14533 .55746 .14844 .56195 .14676 .55959 .14365 Mtetra
.55959 .14365 .56195 .14676 .56646 .14507 .56409 .14196 Mtetra
.56409 .14196 .56646 .14507 .57097 .14339 .56861 .14026 Mtetra
.56861 .14026 .57097 .14339 .57549 .1417 .57313 .13857 Mtetra
.57313 .13857 .57549 .1417 .58002 .14 .57767 .13687 Mtetra
.57767 .13687 .58002 .14 .58455 .13831 .5822 .13517 Mtetra
.5822 .13517 .58455 .13831 .58909 .13661 .58675 .13347 Mtetra
.58675 .13347 .58909 .13661 .59364 .13491 .5913 .13176 Mtetra
.5913 .13176 .59364 .13491 .59819 .1332 .59586 .13005 Mtetra
.59586 .13005 .59819 .1332 .60276 .1315 .60043 .12834 Mtetra
.60043 .12834 .60276 .1315 .60733 .12979 .60501 .12662 Mtetra
.60501 .12662 .60733 .12979 .61191 .12807 .60959 .12491 Mtetra
.60959 .12491 .61191 .12807 .61649 .12636 .61418 .12318 Mtetra
.61418 .12318 .61649 .12636 .62109 .12464 .61878 .12146 Mtetra
.61878 .12146 .62109 .12464 .62569 .12292 .62339 .11974 Mtetra
.62339 .11974 .62569 .12292 .6303 .1212 .628 .11801 Mtetra
.628 .11801 .6303 .1212 .63491 .11947 .63262 .11627 Mtetra
.63262 .11627 .63491 .11947 .63954 .11774 .63725 .11454 Mtetra
.63725 .11454 .63954 .11774 .64417 .11601 .64189 .1128 Mtetra
.64189 .1128 .64417 .11601 .64881 .11427 .64653 .11106 Mtetra
.64653 .11106 .64881 .11427 .65345 .11253 .65119 .10932 Mtetra
.65119 .10932 .65345 .11253 .65811 .11079 .65584 .10757 Mtetra
.65584 .10757 .65811 .11079 .66277 .10905 .66051 .10582 Mtetra
.66051 .10582 .66277 .10905 .66744 .1073 .66519 .10407 Mtetra
.66519 .10407 .66744 .1073 .67212 .10555 .66987 .10232 Mtetra
.66987 .10232 .67212 .10555 .6768 .1038 .67456 .10056 Mtetra
.67456 .10056 .6768 .1038 .6815 .10205 .67926 .0988 Mtetra
.67926 .0988 .6815 .10205 .6862 .10029 .68397 .09703 Mtetra
.68397 .09703 .6862 .10029 .69091 .09853 .68868 .09527 Mtetra
.68868 .09527 .69091 .09853 .69562 .09676 .6934 .0935 Mtetra
.6934 .0935 .69562 .09676 .70035 .095 .69813 .09173 Mtetra
.69813 .09173 .70035 .095 .70508 .09323 .70287 .08995 Mtetra
.70287 .08995 .70508 .09323 .70982 .09145 .70762 .08817 Mtetra
.70762 .08817 .70982 .09145 .71457 .08968 .71237 .08639 Mtetra
.71237 .08639 .71457 .08968 .71932 .0879 .71713 .08461 Mtetra
.71713 .08461 .71932 .0879 .72409 .08612 .7219 .08282 Mtetra
.7219 .08282 .72409 .08612 .72886 .08433 .72668 .08103 Mtetra
.72668 .08103 .72886 .08433 .73364 .08254 .73146 .07923 Mtetra
.73146 .07923 .73364 .08254 .73843 .08075 .73626 .07744 Mtetra
.09432 .31433 .09714 .31695 .10093 .31553 .09811 .3129 Mtetra
.09811 .3129 .10093 .31553 .10472 .31411 .10191 .31148 Mtetra
.10191 .31148 .10472 .31411 .10852 .31268 .10571 .31005 Mtetra
.10571 .31005 .10852 .31268 .11232 .31126 .10952 .30862 Mtetra
.10952 .30862 .11232 .31126 .11613 .30983 .11333 .30719 Mtetra
.11333 .30719 .11613 .30983 .11995 .3084 .11715 .30576 Mtetra
.11715 .30576 .11995 .3084 .12377 .30697 .12097 .30432 Mtetra
.12097 .30432 .12377 .30697 .12759 .30554 .1248 .30288 Mtetra
.1248 .30288 .12759 .30554 .13143 .3041 .12864 .30144 Mtetra
.12864 .30144 .13143 .3041 .13526 .30266 .13248 .3 Mtetra
.13248 .3 .13526 .30266 .13911 .30122 .13633 .29856 Mtetra
.13633 .29856 .13911 .30122 .14296 .29978 .14018 .29711 Mtetra
.14018 .29711 .14296 .29978 .14681 .29833 .14404 .29566 Mtetra
.14404 .29566 .14681 .29833 .15067 .29689 .1479 .29421 Mtetra
.1479 .29421 .15067 .29689 .15454 .29544 .15177 .29276 Mtetra
.15177 .29276 .15454 .29544 .15841 .29399 .15565 .2913 Mtetra
.15565 .2913 .15841 .29399 .16229 .29253 .15953 .28984 Mtetra
.15953 .28984 .16229 .29253 .16618 .29108 .16342 .28838 Mtetra
.16342 .28838 .16618 .29108 .17007 .28962 .16731 .28692 Mtetra
.16731 .28692 .17007 .28962 .17397 .28816 .17121 .28546 Mtetra
.17121 .28546 .17397 .28816 .17787 .28669 .17512 .28399 Mtetra
.17512 .28399 .17787 .28669 .18178 .28523 .17903 .28252 Mtetra
.17903 .28252 .18178 .28523 .18569 .28376 .18295 .28105 Mtetra
.18295 .28105 .18569 .28376 .18961 .28229 .18687 .27958 Mtetra
.18687 .27958 .18961 .28229 .19354 .28082 .1908 .2781 Mtetra
.1908 .2781 .19354 .28082 .19747 .27935 .19474 .27662 Mtetra
.19474 .27662 .19747 .27935 .20141 .27787 .19868 .27514 Mtetra
.19868 .27514 .20141 .27787 .20535 .2764 .20263 .27366 Mtetra
.20263 .27366 .20535 .2764 .2093 .27492 .20658 .27218 Mtetra
.20658 .27218 .2093 .27492 .21326 .27343 .21054 .27069 Mtetra
.21054 .27069 .21326 .27343 .21722 .27195 .21451 .2692 Mtetra
.21451 .2692 .21722 .27195 .22119 .27046 .21848 .26771 Mtetra
.21848 .26771 .22119 .27046 .22516 .26897 .22246 .26622 Mtetra
.22246 .26622 .22516 .26897 .22914 .26748 .22644 .26472 Mtetra
.22644 .26472 .22914 .26748 .23313 .26599 .23043 .26322 Mtetra
.23043 .26322 .23313 .26599 .23712 .26449 .23443 .26172 Mtetra
.23443 .26172 .23712 .26449 .24112 .26299 .23843 .26022 Mtetra
.23843 .26022 .24112 .26299 .24469 .26634 .24244 .25871 Mtetra
.216 .259 .693 r
.24244 .25871 .24469 .26634 .2487 .26484 .24601 .26206 Mtetra
.663 .742 .908 r
.24601 .26206 .2487 .26484 .25273 .26333 .25004 .26055 Mtetra
.25004 .26055 .25273 .26333 .25676 .26183 .25407 .25904 Mtetra
.25407 .25904 .25676 .26183 .26079 .26032 .25811 .25753 Mtetra
.25811 .25753 .26079 .26032 .26483 .25881 .26216 .25601 Mtetra
.26216 .25601 .26483 .25881 .26888 .25729 .26621 .25449 Mtetra
.26621 .25449 .26888 .25729 .27294 .25578 .27027 .25297 Mtetra
.27027 .25297 .27294 .25578 .277 .25426 .27433 .25145 Mtetra
.27433 .25145 .277 .25426 .28106 .25274 .2784 .24993 Mtetra
.2784 .24993 .28106 .25274 .28514 .25122 .28248 .2484 Mtetra
.28248 .2484 .28514 .25122 .28922 .24969 .28656 .24687 Mtetra
.28656 .24687 .28922 .24969 .2933 .24816 .29065 .24534 Mtetra
.29065 .24534 .2933 .24816 .29739 .24663 .29475 .2438 Mtetra
.29475 .2438 .29739 .24663 .30149 .2451 .29885 .24227 Mtetra
.29885 .24227 .30149 .2451 .3056 .24357 .30296 .24073 Mtetra
.30296 .24073 .3056 .24357 .30971 .24203 .30708 .23919 Mtetra
.30708 .23919 .30971 .24203 .31383 .24049 .3112 .23764 Mtetra
.3112 .23764 .31383 .24049 .31795 .23895 .31533 .2361 Mtetra
.31533 .2361 .31795 .23895 .32208 .2374 .31946 .23455 Mtetra
.31946 .23455 .32208 .2374 .32622 .23586 .3236 .233 Mtetra
.3236 .233 .32622 .23586 .33036 .23431 .32775 .23144 Mtetra
.962 .677 .447 r
.32775 .23144 .33036 .23431 .32691 .35471 .32419 .35191 Mtetra
.654 .753 .922 r
.32419 .35191 .32691 .35471 .33123 .35319 .32851 .35038 Mtetra
.32851 .35038 .33123 .35319 .33555 .35167 .33284 .34886 Mtetra
.33284 .34886 .33555 .35167 .33988 .35015 .33717 .34733 Mtetra
.33717 .34733 .33988 .35015 .34422 .34863 .34151 .34581 Mtetra
.961 .698 .489 r
.34151 .34581 .34422 .34863 .34857 .3471 .35305 .21718 Mtetra
.52 .295 .513 r
.35305 .21718 .34857 .3471 .35292 .34557 .35724 .21561 Mtetra
.35724 .21561 .35292 .34557 .35296 .42553 .36143 .21403 Mtetra
.517 .289 .508 r
.36143 .21403 .35296 .42553 .35744 .42403 .36563 .21246 Mtetra
.36563 .21246 .35744 .42403 .36192 .42252 .36984 .21088 Mtetra
.36984 .21088 .36192 .42252 .36641 .42101 .37405 .2093 Mtetra
.37405 .2093 .36641 .42101 .37091 .4195 .37827 .20771 Mtetra
.37827 .20771 .37091 .4195 .37541 .41798 .3825 .20612 Mtetra
0 0 .24 r
.3825 .20612 .37541 .41798 .37993 .41646 .37718 .41365 Mtetra
.647 .761 .932 r
.37718 .41365 .37993 .41646 .38445 .41494 .38171 .41213 Mtetra
.38171 .41213 .38445 .41494 .38897 .41342 .38624 .4106 Mtetra
.38624 .4106 .38897 .41342 .39351 .41189 .39078 .40907 Mtetra
.39078 .40907 .39351 .41189 .39805 .41036 .39533 .40754 Mtetra
.39533 .40754 .39805 .41036 .4026 .40883 .39989 .406 Mtetra
.39989 .406 .4026 .40883 .40716 .4073 .40445 .40446 Mtetra
.40445 .40446 .40716 .4073 .41173 .40576 .40902 .40292 Mtetra
.40902 .40292 .41173 .40576 .4163 .40423 .4136 .40138 Mtetra
.4136 .40138 .4163 .40423 .42089 .40268 .41819 .39983 Mtetra
.969 .694 .457 r
.41819 .39983 .42089 .40268 .42548 .40114 .42928 .19341 Mtetra
.517 .289 .508 r
.42928 .19341 .42548 .40114 .4361 .19478 .43359 .1918 Mtetra
.663 .742 .908 r
.43359 .1918 .4361 .19478 .44042 .19316 .43791 .19018 Mtetra
.43791 .19018 .44042 .19316 .44474 .19155 .44224 .18856 Mtetra
.44224 .18856 .44474 .19155 .44907 .18993 .44658 .18693 Mtetra
.44658 .18693 .44907 .18993 .45341 .18831 .45092 .18531 Mtetra
.45092 .18531 .45341 .18831 .45775 .18668 .45527 .18368 Mtetra
.45527 .18368 .45775 .18668 .46211 .18505 .45962 .18204 Mtetra
.45962 .18204 .46211 .18505 .46647 .18343 .46399 .18041 Mtetra
.46399 .18041 .46647 .18343 .47083 .18179 .46836 .17877 Mtetra
.46836 .17877 .47083 .18179 .4752 .18016 .47273 .17713 Mtetra
.47273 .17713 .4752 .18016 .47958 .17852 .47712 .17549 Mtetra
.47712 .17549 .47958 .17852 .48397 .17688 .48151 .17385 Mtetra
.48151 .17385 .48397 .17688 .48837 .17524 .48591 .1722 Mtetra
.48591 .1722 .48837 .17524 .49277 .17359 .49031 .17055 Mtetra
.49031 .17055 .49277 .17359 .49717 .17194 .49473 .1689 Mtetra
.49473 .1689 .49717 .17194 .50159 .17029 .49915 .16724 Mtetra
.49915 .16724 .50159 .17029 .50601 .16864 .50357 .16558 Mtetra
.50357 .16558 .50601 .16864 .51044 .16698 .50801 .16392 Mtetra
.50801 .16392 .51044 .16698 .51488 .16533 .51245 .16226 Mtetra
.51245 .16226 .51488 .16533 .51932 .16366 .5169 .16059 Mtetra
.5169 .16059 .51932 .16366 .52377 .162 .52135 .15892 Mtetra
.52135 .15892 .52377 .162 .52823 .16033 .52582 .15725 Mtetra
.884 .786 .748 r
.52582 .15725 .52823 .16033 .53268 .15373 .53028 .15064 Mtetra
.664 .741 .908 r
.53028 .15064 .53268 .15373 .53715 .15205 .53475 .14896 Mtetra
.53475 .14896 .53715 .15205 .54162 .15038 .53923 .14728 Mtetra
.53923 .14728 .54162 .15038 .5461 .1487 .54371 .14559 Mtetra
.54371 .14559 .5461 .1487 .55059 .14702 .5482 .14391 Mtetra
.5482 .14391 .55059 .14702 .55508 .14533 .5527 .14222 Mtetra
.5527 .14222 .55508 .14533 .55959 .14365 .55721 .14052 Mtetra
.55721 .14052 .55959 .14365 .56409 .14196 .56172 .13883 Mtetra
.56172 .13883 .56409 .14196 .56861 .14026 .56624 .13713 Mtetra
.56624 .13713 .56861 .14026 .57313 .13857 .57077 .13543 Mtetra
.57077 .13543 .57313 .13857 .57767 .13687 .57531 .13373 Mtetra
.57531 .13373 .57767 .13687 .5822 .13517 .57985 .13202 Mtetra
.57985 .13202 .5822 .13517 .58675 .13347 .5844 .13031 Mtetra
.5844 .13031 .58675 .13347 .5913 .13176 .58896 .1286 Mtetra
.58896 .1286 .5913 .13176 .59586 .13005 .59353 .12689 Mtetra
.59353 .12689 .59586 .13005 .60043 .12834 .5981 .12517 Mtetra
.5981 .12517 .60043 .12834 .60501 .12662 .60268 .12345 Mtetra
.60268 .12345 .60501 .12662 .60959 .12491 .60727 .12173 Mtetra
.60727 .12173 .60959 .12491 .61418 .12318 .61187 .12 Mtetra
.61187 .12 .61418 .12318 .61878 .12146 .61647 .11827 Mtetra
.61647 .11827 .61878 .12146 .62339 .11974 .62108 .11654 Mtetra
.62108 .11654 .62339 .11974 .628 .11801 .6257 .11481 Mtetra
.6257 .11481 .628 .11801 .63262 .11627 .63033 .11307 Mtetra
.63033 .11307 .63262 .11627 .63725 .11454 .63496 .11133 Mtetra
.63496 .11133 .63725 .11454 .64189 .1128 .6396 .10959 Mtetra
.6396 .10959 .64189 .1128 .64653 .11106 .64425 .10784 Mtetra
.64425 .10784 .64653 .11106 .65119 .10932 .64891 .10609 Mtetra
.64891 .10609 .65119 .10932 .65584 .10757 .65357 .10434 Mtetra
.65357 .10434 .65584 .10757 .66051 .10582 .65825 .10259 Mtetra
.65825 .10259 .66051 .10582 .66519 .10407 .66293 .10083 Mtetra
.66293 .10083 .66519 .10407 .66987 .10232 .66762 .09907 Mtetra
.66762 .09907 .66987 .10232 .67456 .10056 .67231 .09731 Mtetra
.67231 .09731 .67456 .10056 .67926 .0988 .67702 .09554 Mtetra
.67702 .09554 .67926 .0988 .68397 .09703 .68173 .09377 Mtetra
.68173 .09377 .68397 .09703 .68868 .09527 .68645 .092 Mtetra
.68645 .092 .68868 .09527 .6934 .0935 .69117 .09022 Mtetra
.69117 .09022 .6934 .0935 .69813 .09173 .69591 .08844 Mtetra
.69591 .08844 .69813 .09173 .70287 .08995 .70065 .08666 Mtetra
.70065 .08666 .70287 .08995 .70762 .08817 .7054 .08488 Mtetra
.7054 .08488 .70762 .08817 .71237 .08639 .71016 .08309 Mtetra
.71016 .08309 .71237 .08639 .71713 .08461 .71493 .0813 Mtetra
.71493 .0813 .71713 .08461 .7219 .08282 .7197 .07951 Mtetra
.7197 .07951 .7219 .08282 .72668 .08103 .72449 .07771 Mtetra
.72449 .07771 .72668 .08103 .73146 .07923 .72928 .07592 Mtetra
.72928 .07592 .73146 .07923 .73626 .07744 .73408 .07411 Mtetra
.0915 .3117 .09432 .31433 .09811 .3129 .09529 .31027 Mtetra
.09529 .31027 .09811 .3129 .10191 .31148 .09909 .30884 Mtetra
.09909 .30884 .10191 .31148 .10571 .31005 .1029 .30741 Mtetra
.1029 .30741 .10571 .31005 .10952 .30862 .10671 .30598 Mtetra
.10671 .30598 .10952 .30862 .11333 .30719 .11052 .30454 Mtetra
.11052 .30454 .11333 .30719 .11715 .30576 .11434 .3031 Mtetra
.11434 .3031 .11715 .30576 .12097 .30432 .11817 .30166 Mtetra
.11817 .30166 .12097 .30432 .1248 .30288 .12201 .30022 Mtetra
.12201 .30022 .1248 .30288 .12864 .30144 .12584 .29878 Mtetra
.12584 .29878 .12864 .30144 .13248 .3 .12969 .29733 Mtetra
.12969 .29733 .13248 .3 .13633 .29856 .13354 .29588 Mtetra
.13354 .29588 .13633 .29856 .14018 .29711 .1374 .29443 Mtetra
.1374 .29443 .14018 .29711 .14404 .29566 .14126 .29298 Mtetra
.14126 .29298 .14404 .29566 .1479 .29421 .14513 .29152 Mtetra
.14513 .29152 .1479 .29421 .15177 .29276 .149 .29007 Mtetra
.149 .29007 .15177 .29276 .15565 .2913 .15288 .28861 Mtetra
.15288 .28861 .15565 .2913 .15953 .28984 .15676 .28715 Mtetra
.15676 .28715 .15953 .28984 .16342 .28838 .16066 .28568 Mtetra
.16066 .28568 .16342 .28838 .16731 .28692 .16455 .28421 Mtetra
.16455 .28421 .16731 .28692 .17121 .28546 .16846 .28275 Mtetra
.16846 .28275 .17121 .28546 .17512 .28399 .17237 .28128 Mtetra
.17237 .28128 .17512 .28399 .17903 .28252 .17628 .2798 Mtetra
.17628 .2798 .17903 .28252 .18295 .28105 .1802 .27833 Mtetra
.1802 .27833 .18295 .28105 .18687 .27958 .18413 .27685 Mtetra
.18413 .27685 .18687 .27958 .1908 .2781 .18806 .27537 Mtetra
.18806 .27537 .1908 .2781 .19474 .27662 .192 .27389 Mtetra
.192 .27389 .19474 .27662 .19868 .27514 .19595 .2724 Mtetra
.19595 .2724 .19868 .27514 .20263 .27366 .1999 .27092 Mtetra
.1999 .27092 .20263 .27366 .20658 .27218 .20385 .26943 Mtetra
.20385 .26943 .20658 .27218 .21054 .27069 .20782 .26794 Mtetra
.20782 .26794 .21054 .27069 .21451 .2692 .21179 .26645 Mtetra
.21179 .26645 .21451 .2692 .21848 .26771 .21576 .26495 Mtetra
.21576 .26495 .21848 .26771 .22246 .26622 .21974 .26345 Mtetra
.21974 .26345 .22246 .26622 .22644 .26472 .22373 .26195 Mtetra
.22373 .26195 .22644 .26472 .23043 .26322 .22773 .26045 Mtetra
.22773 .26045 .23043 .26322 .23443 .26172 .23172 .25894 Mtetra
.23172 .25894 .23443 .26172 .23843 .26022 .23573 .25744 Mtetra
.23573 .25744 .23843 .26022 .24244 .25871 .23974 .25593 Mtetra
.23974 .25593 .24244 .25871 .24601 .26206 .24376 .25442 Mtetra
.216 .259 .693 r
.24376 .25442 .24601 .26206 .25004 .26055 .24735 .25776 Mtetra
.663 .742 .908 r
.24735 .25776 .25004 .26055 .25407 .25904 .25139 .25624 Mtetra
.25139 .25624 .25407 .25904 .25811 .25753 .25543 .25473 Mtetra
.25543 .25473 .25811 .25753 .26216 .25601 .25948 .25321 Mtetra
.25948 .25321 .26216 .25601 .26621 .25449 .26353 .25168 Mtetra
.26353 .25168 .26621 .25449 .27027 .25297 .26759 .25016 Mtetra
.26759 .25016 .27027 .25297 .27433 .25145 .27166 .24863 Mtetra
.27166 .24863 .27433 .25145 .2784 .24993 .27574 .2471 Mtetra
.27574 .2471 .2784 .24993 .28248 .2484 .27982 .24557 Mtetra
.27982 .24557 .28248 .2484 .28656 .24687 .28391 .24404 Mtetra
.28391 .24404 .28656 .24687 .29065 .24534 .288 .2425 Mtetra
.288 .2425 .29065 .24534 .29475 .2438 .2921 .24096 Mtetra
.2921 .24096 .29475 .2438 .29885 .24227 .29621 .23942 Mtetra
.29621 .23942 .29885 .24227 .30296 .24073 .30032 .23788 Mtetra
.30032 .23788 .30296 .24073 .30708 .23919 .30444 .23633 Mtetra
.30444 .23633 .30708 .23919 .3112 .23764 .30856 .23478 Mtetra
.30856 .23478 .3112 .23764 .31533 .2361 .31269 .23323 Mtetra
.31269 .23323 .31533 .2361 .31946 .23455 .31683 .23168 Mtetra
.31683 .23168 .31946 .23455 .3236 .233 .32098 .23013 Mtetra
.32098 .23013 .3236 .233 .32775 .23144 .32513 .22857 Mtetra
.32513 .22857 .32775 .23144 .32419 .35191 .32929 .22701 Mtetra
0 0 .222 r
.32929 .22701 .32419 .35191 .32851 .35038 .32578 .34757 Mtetra
.654 .753 .922 r
.32578 .34757 .32851 .35038 .33284 .34886 .33011 .34604 Mtetra
.961 .698 .491 r
.33011 .34604 .33284 .34886 .33717 .34733 .34209 .21742 Mtetra
.519 .294 .513 r
.34209 .21742 .33717 .34733 .34151 .34581 .34627 .21585 Mtetra
.34627 .21585 .34151 .34581 .35305 .21718 .35046 .21428 Mtetra
.664 .741 .908 r
.35046 .21428 .35305 .21718 .35724 .21561 .35465 .2127 Mtetra
.35465 .2127 .35724 .21561 .36143 .21403 .35884 .21112 Mtetra
.35884 .21112 .36143 .21403 .36563 .21246 .36305 .20954 Mtetra
.36305 .20954 .36563 .21246 .36984 .21088 .36726 .20796 Mtetra
.36726 .20796 .36984 .21088 .37405 .2093 .37148 .20637 Mtetra
.37148 .20637 .37405 .2093 .37827 .20771 .3757 .20478 Mtetra
.3757 .20478 .37827 .20771 .3825 .20612 .37993 .20319 Mtetra
.37993 .20319 .3825 .20612 .37718 .41365 .38417 .20159 Mtetra
.516 .288 .507 r
.38417 .20159 .37718 .41365 .38171 .41213 .38841 .2 Mtetra
.38841 .2 .38171 .41213 .38624 .4106 .39266 .1984 Mtetra
.39266 .1984 .38624 .4106 .39078 .40907 .39692 .1968 Mtetra
.39692 .1968 .39078 .40907 .39533 .40754 .40119 .19519 Mtetra
0 0 .25 r
.40119 .19519 .39533 .40754 .39989 .406 .39716 .40316 Mtetra
.647 .761 .932 r
.39716 .40316 .39989 .406 .40445 .40446 .40173 .40162 Mtetra
.40173 .40162 .40445 .40446 .40902 .40292 .4063 .40007 Mtetra
.4063 .40007 .40902 .40292 .4136 .40138 .41089 .39852 Mtetra
.968 .694 .458 r
.41089 .39852 .4136 .40138 .41819 .39983 .42244 .19204 Mtetra
.516 .288 .507 r
.42244 .19204 .41819 .39983 .42928 .19341 .42675 .19043 Mtetra
.663 .742 .908 r
.42675 .19043 .42928 .19341 .43359 .1918 .43107 .18881 Mtetra
.43107 .18881 .43359 .1918 .43791 .19018 .4354 .18718 Mtetra
.4354 .18718 .43791 .19018 .44224 .18856 .43973 .18556 Mtetra
.43973 .18556 .44224 .18856 .44658 .18693 .44407 .18393 Mtetra
.44407 .18393 .44658 .18693 .45092 .18531 .44842 .1823 Mtetra
.44842 .1823 .45092 .18531 .45527 .18368 .45277 .18066 Mtetra
.45277 .18066 .45527 .18368 .45962 .18204 .45713 .17903 Mtetra
.45713 .17903 .45962 .18204 .46399 .18041 .4615 .17739 Mtetra
.4615 .17739 .46399 .18041 .46836 .17877 .46588 .17574 Mtetra
.46588 .17574 .46836 .17877 .47273 .17713 .47026 .1741 Mtetra
.47026 .1741 .47273 .17713 .47712 .17549 .47465 .17245 Mtetra
.47465 .17245 .47712 .17549 .48151 .17385 .47904 .1708 Mtetra
.47904 .1708 .48151 .17385 .48591 .1722 .48345 .16915 Mtetra
.48345 .16915 .48591 .1722 .49031 .17055 .48786 .16749 Mtetra
.48786 .16749 .49031 .17055 .49473 .1689 .49227 .16584 Mtetra
.49227 .16584 .49473 .1689 .49915 .16724 .4967 .16418 Mtetra
.4967 .16418 .49915 .16724 .50357 .16558 .50113 .16251 Mtetra
.50113 .16251 .50357 .16558 .50801 .16392 .50557 .16085 Mtetra
.50557 .16085 .50801 .16392 .51245 .16226 .51001 .15918 Mtetra
.51001 .15918 .51245 .16226 .5169 .16059 .51447 .15751 Mtetra
.51447 .15751 .5169 .16059 .52135 .15892 .51893 .15583 Mtetra
.51893 .15583 .52135 .15892 .52582 .15725 .5234 .15416 Mtetra
.884 .786 .748 r
.5234 .15416 .52582 .15725 .53028 .15064 .52787 .14753 Mtetra
.664 .741 .908 r
.52787 .14753 .53028 .15064 .53475 .14896 .53234 .14585 Mtetra
.53234 .14585 .53475 .14896 .53923 .14728 .53682 .14417 Mtetra
.53682 .14417 .53923 .14728 .54371 .14559 .54131 .14248 Mtetra
.54131 .14248 .54371 .14559 .5482 .14391 .54581 .14078 Mtetra
.54581 .14078 .5482 .14391 .5527 .14222 .55031 .13909 Mtetra
.55031 .13909 .5527 .14222 .55721 .14052 .55482 .13739 Mtetra
.55482 .13739 .55721 .14052 .56172 .13883 .55934 .13569 Mtetra
.55934 .13569 .56172 .13883 .56624 .13713 .56387 .13399 Mtetra
.56387 .13399 .56624 .13713 .57077 .13543 .5684 .13228 Mtetra
.5684 .13228 .57077 .13543 .57531 .13373 .57294 .13058 Mtetra
.57294 .13058 .57531 .13373 .57985 .13202 .57749 .12886 Mtetra
.57749 .12886 .57985 .13202 .5844 .13031 .58205 .12715 Mtetra
.58205 .12715 .5844 .13031 .58896 .1286 .58661 .12543 Mtetra
.58661 .12543 .58896 .1286 .59353 .12689 .59118 .12371 Mtetra
.59118 .12371 .59353 .12689 .5981 .12517 .59576 .12199 Mtetra
.59576 .12199 .5981 .12517 .60268 .12345 .60035 .12027 Mtetra
.60035 .12027 .60268 .12345 .60727 .12173 .60494 .11854 Mtetra
.60494 .11854 .60727 .12173 .61187 .12 .60954 .11681 Mtetra
.60954 .11681 .61187 .12 .61647 .11827 .61415 .11507 Mtetra
.61415 .11507 .61647 .11827 .62108 .11654 .61877 .11334 Mtetra
.61877 .11334 .62108 .11654 .6257 .11481 .62339 .1116 Mtetra
.62339 .1116 .6257 .11481 .63033 .11307 .62802 .10986 Mtetra
.62802 .10986 .63033 .11307 .63496 .11133 .63266 .10811 Mtetra
.63266 .10811 .63496 .11133 .6396 .10959 .63731 .10636 Mtetra
.63731 .10636 .6396 .10959 .64425 .10784 .64196 .10461 Mtetra
.64196 .10461 .64425 .10784 .64891 .10609 .64663 .10286 Mtetra
.64663 .10286 .64891 .10609 .65357 .10434 .6513 .1011 Mtetra
.6513 .1011 .65357 .10434 .65825 .10259 .65597 .09934 Mtetra
.65597 .09934 .65825 .10259 .66293 .10083 .66066 .09758 Mtetra
.66066 .09758 .66293 .10083 .66762 .09907 .66535 .09581 Mtetra
.66535 .09581 .66762 .09907 .67231 .09731 .67006 .09404 Mtetra
.67006 .09404 .67231 .09731 .67702 .09554 .67476 .09227 Mtetra
.67476 .09227 .67702 .09554 .68173 .09377 .67948 .0905 Mtetra
.67948 .0905 .68173 .09377 .68645 .092 .68421 .08872 Mtetra
.68421 .08872 .68645 .092 .69117 .09022 .68894 .08694 Mtetra
.68894 .08694 .69117 .09022 .69591 .08844 .69368 .08515 Mtetra
.69368 .08515 .69591 .08844 .70065 .08666 .69843 .08337 Mtetra
.69843 .08337 .70065 .08666 .7054 .08488 .70319 .08158 Mtetra
.70319 .08158 .7054 .08488 .71016 .08309 .70795 .07979 Mtetra
.70795 .07979 .71016 .08309 .71493 .0813 .71272 .07799 Mtetra
.71272 .07799 .71493 .0813 .7197 .07951 .7175 .07619 Mtetra
.7175 .07619 .7197 .07951 .72449 .07771 .72229 .07439 Mtetra
.72229 .07439 .72449 .07771 .72928 .07592 .72709 .07259 Mtetra
.72709 .07259 .72928 .07592 .73408 .07411 .73189 .07078 Mtetra
.08867 .30906 .0915 .3117 .09529 .31027 .09247 .30763 Mtetra
.09247 .30763 .09529 .31027 .09909 .30884 .09627 .3062 Mtetra
.09627 .3062 .09909 .30884 .1029 .30741 .10008 .30476 Mtetra
.10008 .30476 .1029 .30741 .10671 .30598 .10389 .30333 Mtetra
.10389 .30333 .10671 .30598 .11052 .30454 .10771 .30189 Mtetra
.10771 .30189 .11052 .30454 .11434 .3031 .11153 .30044 Mtetra
.11153 .30044 .11434 .3031 .11817 .30166 .11536 .299 Mtetra
.11536 .299 .11817 .30166 .12201 .30022 .1192 .29755 Mtetra
.1192 .29755 .12201 .30022 .12584 .29878 .12304 .29611 Mtetra
.12304 .29611 .12584 .29878 .12969 .29733 .12689 .29466 Mtetra
.12689 .29466 .12969 .29733 .13354 .29588 .13074 .2932 Mtetra
.13074 .2932 .13354 .29588 .1374 .29443 .1346 .29175 Mtetra
.1346 .29175 .1374 .29443 .14126 .29298 .13847 .29029 Mtetra
.13847 .29029 .14126 .29298 .14513 .29152 .14234 .28883 Mtetra
.14234 .28883 .14513 .29152 .149 .29007 .14622 .28737 Mtetra
.14622 .28737 .149 .29007 .15288 .28861 .1501 .28591 Mtetra
.1501 .28591 .15288 .28861 .15676 .28715 .15399 .28444 Mtetra
.15399 .28444 .15676 .28715 .16066 .28568 .15788 .28297 Mtetra
.15788 .28297 .16066 .28568 .16455 .28421 .16178 .2815 Mtetra
.16178 .2815 .16455 .28421 .16846 .28275 .16569 .28003 Mtetra
.16569 .28003 .16846 .28275 .17237 .28128 .1696 .27855 Mtetra
.1696 .27855 .17237 .28128 .17628 .2798 .17352 .27708 Mtetra
.17352 .27708 .17628 .2798 .1802 .27833 .17745 .2756 Mtetra
.17745 .2756 .1802 .27833 .18413 .27685 .18138 .27412 Mtetra
.18138 .27412 .18413 .27685 .18806 .27537 .18531 .27263 Mtetra
.18531 .27263 .18806 .27537 .192 .27389 .18926 .27115 Mtetra
.18926 .27115 .192 .27389 .19595 .2724 .1932 .26966 Mtetra
.1932 .26966 .19595 .2724 .1999 .27092 .19716 .26817 Mtetra
.19716 .26817 .1999 .27092 .20385 .26943 .20112 .26668 Mtetra
.20112 .26668 .20385 .26943 .20782 .26794 .20509 .26518 Mtetra
.20509 .26518 .20782 .26794 .21179 .26645 .20906 .26368 Mtetra
.20906 .26368 .21179 .26645 .21576 .26495 .21304 .26218 Mtetra
.21304 .26218 .21576 .26495 .21974 .26345 .21702 .26068 Mtetra
.21702 .26068 .21974 .26345 .22373 .26195 .22101 .25918 Mtetra
.22101 .25918 .22373 .26195 .22773 .26045 .22501 .25767 Mtetra
.22501 .25767 .22773 .26045 .23172 .25894 .22901 .25616 Mtetra
.22901 .25616 .23172 .25894 .23573 .25744 .23302 .25465 Mtetra
.23302 .25465 .23573 .25744 .23974 .25593 .23704 .25314 Mtetra
.23704 .25314 .23974 .25593 .24376 .25442 .24106 .25162 Mtetra
.24106 .25162 .24376 .25442 .24735 .25776 .24509 .2501 Mtetra
.216 .259 .693 r
.24509 .2501 .24735 .25776 .25139 .25624 .24869 .25344 Mtetra
.663 .742 .908 r
.24869 .25344 .25139 .25624 .25543 .25473 .25273 .25192 Mtetra
.25273 .25192 .25543 .25473 .25948 .25321 .25679 .25039 Mtetra
.25679 .25039 .25948 .25321 .26353 .25168 .26085 .24887 Mtetra
.26085 .24887 .26353 .25168 .26759 .25016 .26491 .24734 Mtetra
.26491 .24734 .26759 .25016 .27166 .24863 .26898 .24581 Mtetra
.26898 .24581 .27166 .24863 .27574 .2471 .27306 .24427 Mtetra
.27306 .24427 .27574 .2471 .27982 .24557 .27715 .24274 Mtetra
.27715 .24274 .27982 .24557 .28391 .24404 .28124 .2412 Mtetra
.28124 .2412 .28391 .24404 .288 .2425 .28534 .23966 Mtetra
.28534 .23966 .288 .2425 .2921 .24096 .28944 .23812 Mtetra
.28944 .23812 .2921 .24096 .29621 .23942 .29355 .23657 Mtetra
.29355 .23657 .29621 .23942 .30032 .23788 .29767 .23502 Mtetra
.29767 .23502 .30032 .23788 .30444 .23633 .30179 .23347 Mtetra
.30179 .23347 .30444 .23633 .30856 .23478 .30592 .23192 Mtetra
.30592 .23192 .30856 .23478 .31269 .23323 .31005 .23036 Mtetra
.31005 .23036 .31269 .23323 .31683 .23168 .3142 .22881 Mtetra
.3142 .22881 .31683 .23168 .32098 .23013 .31835 .22725 Mtetra
.31835 .22725 .32098 .23013 .32513 .22857 .3225 .22568 Mtetra
.3225 .22568 .32513 .22857 .32929 .22701 .32666 .22412 Mtetra
.871 .77 .748 r
.32666 .22412 .32929 .22701 .32578 .34757 .33114 .21766 Mtetra
.518 .293 .512 r
.33114 .21766 .32578 .34757 .33011 .34604 .33531 .21609 Mtetra
.33531 .21609 .33011 .34604 .34209 .21742 .33949 .21452 Mtetra
.664 .741 .908 r
.33949 .21452 .34209 .21742 .34627 .21585 .34367 .21294 Mtetra
.34367 .21294 .34627 .21585 .35046 .21428 .34786 .21136 Mtetra
.34786 .21136 .35046 .21428 .35465 .2127 .35205 .20978 Mtetra
.35205 .20978 .35465 .2127 .35884 .21112 .35625 .2082 Mtetra
.35625 .2082 .35884 .21112 .36305 .20954 .36046 .20661 Mtetra
.36046 .20661 .36305 .20954 .36726 .20796 .36468 .20502 Mtetra
.36468 .20502 .36726 .20796 .37148 .20637 .3689 .20343 Mtetra
.3689 .20343 .37148 .20637 .3757 .20478 .37313 .20184 Mtetra
.37313 .20184 .3757 .20478 .37993 .20319 .37736 .20024 Mtetra
.37736 .20024 .37993 .20319 .38417 .20159 .3816 .19864 Mtetra
.3816 .19864 .38417 .20159 .38841 .2 .38585 .19704 Mtetra
.38585 .19704 .38841 .2 .39266 .1984 .39011 .19544 Mtetra
.39011 .19544 .39266 .1984 .39692 .1968 .39437 .19383 Mtetra
.39437 .19383 .39692 .1968 .40119 .19519 .39864 .19222 Mtetra
.39864 .19222 .40119 .19519 .39716 .40316 .40291 .19061 Mtetra
.515 .287 .506 r
.40291 .19061 .39716 .40316 .40173 .40162 .40719 .189 Mtetra
.40719 .189 .40173 .40162 .4063 .40007 .41148 .18738 Mtetra
.41148 .18738 .4063 .40007 .41089 .39852 .41578 .18576 Mtetra
.504 .278 .504 r
.41578 .18576 .41089 .39852 .42244 .19204 .41991 .18906 Mtetra
.663 .742 .908 r
.41991 .18906 .42244 .19204 .42675 .19043 .42423 .18743 Mtetra
.42423 .18743 .42675 .19043 .43107 .18881 .42855 .18581 Mtetra
.42855 .18581 .43107 .18881 .4354 .18718 .43288 .18418 Mtetra
.43288 .18418 .4354 .18718 .43973 .18556 .43722 .18255 Mtetra
.43722 .18255 .43973 .18556 .44407 .18393 .44156 .18091 Mtetra
.44156 .18091 .44407 .18393 .44842 .1823 .44591 .17928 Mtetra
.44591 .17928 .44842 .1823 .45277 .18066 .45027 .17764 Mtetra
.45027 .17764 .45277 .18066 .45713 .17903 .45464 .176 Mtetra
.45464 .176 .45713 .17903 .4615 .17739 .45901 .17435 Mtetra
.45901 .17435 .4615 .17739 .46588 .17574 .46339 .17271 Mtetra
.46339 .17271 .46588 .17574 .47026 .1741 .46777 .17106 Mtetra
.46777 .17106 .47026 .1741 .47465 .17245 .47217 .1694 Mtetra
.47217 .1694 .47465 .17245 .47904 .1708 .47657 .16775 Mtetra
.47657 .16775 .47904 .1708 .48345 .16915 .48098 .16609 Mtetra
.48098 .16609 .48345 .16915 .48786 .16749 .48539 .16443 Mtetra
.48539 .16443 .48786 .16749 .49227 .16584 .48981 .16277 Mtetra
.48981 .16277 .49227 .16584 .4967 .16418 .49424 .1611 Mtetra
.49424 .1611 .4967 .16418 .50113 .16251 .49868 .15944 Mtetra
.49868 .15944 .50113 .16251 .50557 .16085 .50312 .15776 Mtetra
.50312 .15776 .50557 .16085 .51001 .15918 .50757 .15609 Mtetra
.50757 .15609 .51001 .15918 .51447 .15751 .51203 .15441 Mtetra
.51203 .15441 .51447 .15751 .51893 .15583 .5165 .15274 Mtetra
.5165 .15274 .51893 .15583 .5234 .15416 .52097 .15105 Mtetra
.884 .786 .748 r
.52097 .15105 .5234 .15416 .52787 .14753 .52545 .14442 Mtetra
.664 .741 .908 r
.52545 .14442 .52787 .14753 .53234 .14585 .52993 .14274 Mtetra
.52993 .14274 .53234 .14585 .53682 .14417 .53441 .14104 Mtetra
.53441 .14104 .53682 .14417 .54131 .14248 .53891 .13935 Mtetra
.53891 .13935 .54131 .14248 .54581 .14078 .54341 .13765 Mtetra
.54341 .13765 .54581 .14078 .55031 .13909 .54792 .13595 Mtetra
.54792 .13595 .55031 .13909 .55482 .13739 .55243 .13425 Mtetra
.55243 .13425 .55482 .13739 .55934 .13569 .55696 .13255 Mtetra
.55696 .13255 .55934 .13569 .56387 .13399 .56149 .13084 Mtetra
.56149 .13084 .56387 .13399 .5684 .13228 .56603 .12913 Mtetra
.56603 .12913 .5684 .13228 .57294 .13058 .57057 .12741 Mtetra
.57057 .12741 .57294 .13058 .57749 .12886 .57513 .1257 Mtetra
.57513 .1257 .57749 .12886 .58205 .12715 .57969 .12398 Mtetra
.57969 .12398 .58205 .12715 .58661 .12543 .58426 .12226 Mtetra
.58426 .12226 .58661 .12543 .59118 .12371 .58883 .12053 Mtetra
.58883 .12053 .59118 .12371 .59576 .12199 .59342 .1188 Mtetra
.59342 .1188 .59576 .12199 .60035 .12027 .59801 .11707 Mtetra
.59801 .11707 .60035 .12027 .60494 .11854 .60261 .11534 Mtetra
.60261 .11534 .60494 .11854 .60954 .11681 .60721 .1136 Mtetra
.60721 .1136 .60954 .11681 .61415 .11507 .61183 .11187 Mtetra
.61183 .11187 .61415 .11507 .61877 .11334 .61645 .11012 Mtetra
.61645 .11012 .61877 .11334 .62339 .1116 .62108 .10838 Mtetra
.62108 .10838 .62339 .1116 .62802 .10986 .62571 .10663 Mtetra
.62571 .10663 .62802 .10986 .63266 .10811 .63036 .10488 Mtetra
.63036 .10488 .63266 .10811 .63731 .10636 .63501 .10313 Mtetra
.63501 .10313 .63731 .10636 .64196 .10461 .63967 .10137 Mtetra
.63967 .10137 .64196 .10461 .64663 .10286 .64434 .09961 Mtetra
.64434 .09961 .64663 .10286 .6513 .1011 .64901 .09785 Mtetra
.64901 .09785 .6513 .1011 .65597 .09934 .6537 .09608 Mtetra
.6537 .09608 .65597 .09934 .66066 .09758 .65839 .09431 Mtetra
.65839 .09431 .66066 .09758 .66535 .09581 .66309 .09254 Mtetra
.66309 .09254 .66535 .09581 .67006 .09404 .66779 .09077 Mtetra
.66779 .09077 .67006 .09404 .67476 .09227 .67251 .08899 Mtetra
.67251 .08899 .67476 .09227 .67948 .0905 .67723 .08721 Mtetra
.67723 .08721 .67948 .0905 .68421 .08872 .68196 .08543 Mtetra
.68196 .08543 .68421 .08872 .68894 .08694 .6867 .08364 Mtetra
.6867 .08364 .68894 .08694 .69368 .08515 .69144 .08185 Mtetra
.69144 .08185 .69368 .08515 .69843 .08337 .6962 .08006 Mtetra
.6962 .08006 .69843 .08337 .70319 .08158 .70096 .07827 Mtetra
.70096 .07827 .70319 .08158 .70795 .07979 .70573 .07647 Mtetra
.70573 .07647 .70795 .07979 .71272 .07799 .71051 .07467 Mtetra
.71051 .07467 .71272 .07799 .7175 .07619 .71529 .07286 Mtetra
.71529 .07286 .7175 .07619 .72229 .07439 .72009 .07106 Mtetra
.72009 .07106 .72229 .07439 .72709 .07259 .72489 .06925 Mtetra
.72489 .06925 .72709 .07259 .73189 .07078 .7297 .06743 Mtetra
.08583 .30642 .08867 .30906 .09247 .30763 .08963 .30498 Mtetra
.08963 .30498 .09247 .30763 .09627 .3062 .09344 .30355 Mtetra
.09344 .30355 .09627 .3062 .10008 .30476 .09725 .30211 Mtetra
.09725 .30211 .10008 .30476 .10389 .30333 .10106 .30067 Mtetra
.10106 .30067 .10389 .30333 .10771 .30189 .10488 .29922 Mtetra
.10488 .29922 .10771 .30189 .11153 .30044 .10871 .29778 Mtetra
.10871 .29778 .11153 .30044 .11536 .299 .11255 .29633 Mtetra
.11255 .29633 .11536 .299 .1192 .29755 .11639 .29488 Mtetra
.11639 .29488 .1192 .29755 .12304 .29611 .12023 .29343 Mtetra
.12023 .29343 .12304 .29611 .12689 .29466 .12408 .29197 Mtetra
.12408 .29197 .12689 .29466 .13074 .2932 .12794 .29052 Mtetra
.12794 .29052 .13074 .2932 .1346 .29175 .1318 .28906 Mtetra
.1318 .28906 .1346 .29175 .13847 .29029 .13567 .2876 Mtetra
.13567 .2876 .13847 .29029 .14234 .28883 .13955 .28613 Mtetra
.13955 .28613 .14234 .28883 .14622 .28737 .14343 .28467 Mtetra
.14343 .28467 .14622 .28737 .1501 .28591 .14731 .2832 Mtetra
.14731 .2832 .1501 .28591 .15399 .28444 .1512 .28173 Mtetra
.1512 .28173 .15399 .28444 .15788 .28297 .1551 .28026 Mtetra
.1551 .28026 .15788 .28297 .16178 .2815 .15901 .27878 Mtetra
.15901 .27878 .16178 .2815 .16569 .28003 .16292 .27731 Mtetra
.16292 .27731 .16569 .28003 .1696 .27855 .16683 .27583 Mtetra
.16683 .27583 .1696 .27855 .17352 .27708 .17075 .27435 Mtetra
.17075 .27435 .17352 .27708 .17745 .2756 .17468 .27286 Mtetra
.17468 .27286 .17745 .2756 .18138 .27412 .17862 .27138 Mtetra
.17862 .27138 .18138 .27412 .18531 .27263 .18256 .26989 Mtetra
.18256 .26989 .18531 .27263 .18926 .27115 .1865 .2684 Mtetra
.1865 .2684 .18926 .27115 .1932 .26966 .19045 .26691 Mtetra
.19045 .26691 .1932 .26966 .19716 .26817 .19441 .26541 Mtetra
.19441 .26541 .19716 .26817 .20112 .26668 .19838 .26391 Mtetra
.19838 .26391 .20112 .26668 .20509 .26518 .20235 .26241 Mtetra
.20235 .26241 .20509 .26518 .20906 .26368 .20632 .26091 Mtetra
.20632 .26091 .20906 .26368 .21304 .26218 .21031 .25941 Mtetra
.21031 .25941 .21304 .26218 .21702 .26068 .21429 .2579 Mtetra
.21429 .2579 .21702 .26068 .22101 .25918 .21829 .25639 Mtetra
.21829 .25639 .22101 .25918 .22501 .25767 .22229 .25488 Mtetra
.22229 .25488 .22501 .25767 .22901 .25616 .2263 .25337 Mtetra
.2263 .25337 .22901 .25616 .23302 .25465 .23031 .25185 Mtetra
.23031 .25185 .23302 .25465 .23704 .25314 .23433 .25033 Mtetra
.23433 .25033 .23704 .25314 .24106 .25162 .23835 .24881 Mtetra
.23835 .24881 .24106 .25162 .24509 .2501 .24239 .24729 Mtetra
.24239 .24729 .24509 .2501 .24869 .25344 .24642 .24577 Mtetra
.216 .259 .693 r
.24642 .24577 .24869 .25344 .25273 .25192 .25003 .2491 Mtetra
.663 .742 .908 r
.25003 .2491 .25273 .25192 .25679 .25039 .25409 .24758 Mtetra
.25409 .24758 .25679 .25039 .26085 .24887 .25815 .24604 Mtetra
.25815 .24604 .26085 .24887 .26491 .24734 .26222 .24451 Mtetra
.26222 .24451 .26491 .24734 .26898 .24581 .2663 .24298 Mtetra
.2663 .24298 .26898 .24581 .27306 .24427 .27038 .24144 Mtetra
.27038 .24144 .27306 .24427 .27715 .24274 .27447 .2399 Mtetra
.27447 .2399 .27715 .24274 .28124 .2412 .27856 .23835 Mtetra
.27856 .23835 .28124 .2412 .28534 .23966 .28266 .23681 Mtetra
.28266 .23681 .28534 .23966 .28944 .23812 .28677 .23526 Mtetra
.28677 .23526 .28944 .23812 .29355 .23657 .29089 .23371 Mtetra
.29089 .23371 .29355 .23657 .29767 .23502 .29501 .23216 Mtetra
.29501 .23216 .29767 .23502 .30179 .23347 .29913 .2306 Mtetra
.29913 .2306 .30179 .23347 .30592 .23192 .30327 .22905 Mtetra
.30327 .22905 .30592 .23192 .31005 .23036 .30741 .22749 Mtetra
.30741 .22749 .31005 .23036 .3142 .22881 .31155 .22592 Mtetra
.31155 .22592 .3142 .22881 .31835 .22725 .31571 .22436 Mtetra
.31571 .22436 .31835 .22725 .3225 .22568 .31987 .22279 Mtetra
.31987 .22279 .3225 .22568 .32666 .22412 .32403 .22122 Mtetra
.871 .77 .748 r
.32403 .22122 .32666 .22412 .33114 .21766 .32852 .21476 Mtetra
.664 .741 .908 r
.32852 .21476 .33114 .21766 .33531 .21609 .33269 .21319 Mtetra
.33269 .21319 .33531 .21609 .33949 .21452 .33687 .21161 Mtetra
.33687 .21161 .33949 .21452 .34367 .21294 .34106 .21003 Mtetra
.34106 .21003 .34367 .21294 .34786 .21136 .34525 .20844 Mtetra
.34525 .20844 .34786 .21136 .35205 .20978 .34945 .20686 Mtetra
.34945 .20686 .35205 .20978 .35625 .2082 .35365 .20527 Mtetra
.35365 .20527 .35625 .2082 .36046 .20661 .35787 .20368 Mtetra
.35787 .20368 .36046 .20661 .36468 .20502 .36209 .20209 Mtetra
.36209 .20209 .36468 .20502 .3689 .20343 .36631 .20049 Mtetra
.36631 .20049 .3689 .20343 .37313 .20184 .37054 .19889 Mtetra
.37054 .19889 .37313 .20184 .37736 .20024 .37478 .19729 Mtetra
.37478 .19729 .37736 .20024 .3816 .19864 .37903 .19569 Mtetra
.37903 .19569 .3816 .19864 .38585 .19704 .38328 .19408 Mtetra
.38328 .19408 .38585 .19704 .39011 .19544 .38754 .19247 Mtetra
.38754 .19247 .39011 .19544 .39437 .19383 .39181 .19086 Mtetra
.39181 .19086 .39437 .19383 .39864 .19222 .39608 .18925 Mtetra
.39608 .18925 .39864 .19222 .40291 .19061 .40036 .18763 Mtetra
.40036 .18763 .40291 .19061 .40719 .189 .40464 .18601 Mtetra
.40464 .18601 .40719 .189 .41148 .18738 .40894 .18439 Mtetra
.40894 .18439 .41148 .18738 .41578 .18576 .41324 .18277 Mtetra
0 .175 .69 r
.41324 .18277 .41578 .18576 .41991 .18906 .41737 .18606 Mtetra
.663 .742 .908 r
.41737 .18606 .41991 .18906 .42423 .18743 .42169 .18443 Mtetra
.42169 .18443 .42423 .18743 .42855 .18581 .42602 .1828 Mtetra
.42602 .1828 .42855 .18581 .43288 .18418 .43035 .18116 Mtetra
.43035 .18116 .43288 .18418 .43722 .18255 .43469 .17953 Mtetra
.43469 .17953 .43722 .18255 .44156 .18091 .43904 .17789 Mtetra
.43904 .17789 .44156 .18091 .44591 .17928 .4434 .17625 Mtetra
.4434 .17625 .44591 .17928 .45027 .17764 .44776 .17461 Mtetra
.44776 .17461 .45027 .17764 .45464 .176 .45213 .17296 Mtetra
.45213 .17296 .45464 .176 .45901 .17435 .45651 .17131 Mtetra
.45651 .17131 .45901 .17435 .46339 .17271 .46089 .16966 Mtetra
.46089 .16966 .46339 .17271 .46777 .17106 .46528 .168 Mtetra
.46528 .168 .46777 .17106 .47217 .1694 .46968 .16635 Mtetra
.46968 .16635 .47217 .1694 .47657 .16775 .47409 .16469 Mtetra
.47409 .16469 .47657 .16775 .48098 .16609 .4785 .16303 Mtetra
.4785 .16303 .48098 .16609 .48539 .16443 .48292 .16136 Mtetra
.48292 .16136 .48539 .16443 .48981 .16277 .48734 .15969 Mtetra
.48734 .15969 .48981 .16277 .49424 .1611 .49178 .15802 Mtetra
.49178 .15802 .49424 .1611 .49868 .15944 .49622 .15635 Mtetra
.49622 .15635 .49868 .15944 .50312 .15776 .50067 .15467 Mtetra
.50067 .15467 .50312 .15776 .50757 .15609 .50512 .15299 Mtetra
.50512 .15299 .50757 .15609 .51203 .15441 .50958 .15131 Mtetra
.50958 .15131 .51203 .15441 .5165 .15274 .51405 .14963 Mtetra
.51405 .14963 .5165 .15274 .52097 .15105 .51853 .14794 Mtetra
.884 .786 .748 r
.51853 .14794 .52097 .15105 .52545 .14442 .52302 .14131 Mtetra
.664 .741 .908 r
.52302 .14131 .52545 .14442 .52993 .14274 .5275 .13961 Mtetra
.5275 .13961 .52993 .14274 .53441 .14104 .532 .13792 Mtetra
.532 .13792 .53441 .14104 .53891 .13935 .53649 .13622 Mtetra
.53649 .13622 .53891 .13935 .54341 .13765 .541 .13451 Mtetra
.541 .13451 .54341 .13765 .54792 .13595 .54551 .13281 Mtetra
.54551 .13281 .54792 .13595 .55243 .13425 .55004 .1311 Mtetra
.55004 .1311 .55243 .13425 .55696 .13255 .55456 .12939 Mtetra
.55456 .12939 .55696 .13255 .56149 .13084 .5591 .12768 Mtetra
.5591 .12768 .56149 .13084 .56603 .12913 .56364 .12596 Mtetra
.56364 .12596 .56603 .12913 .57057 .12741 .56819 .12424 Mtetra
.56819 .12424 .57057 .12741 .57513 .1257 .57275 .12252 Mtetra
.57275 .12252 .57513 .1257 .57969 .12398 .57732 .1208 Mtetra
.57732 .1208 .57969 .12398 .58426 .12226 .58189 .11907 Mtetra
.58189 .11907 .58426 .12226 .58883 .12053 .58647 .11734 Mtetra
.58647 .11734 .58883 .12053 .59342 .1188 .59106 .11561 Mtetra
.59106 .11561 .59342 .1188 .59801 .11707 .59566 .11387 Mtetra
.59566 .11387 .59801 .11707 .60261 .11534 .60026 .11213 Mtetra
.60026 .11213 .60261 .11534 .60721 .1136 .60487 .11039 Mtetra
.60487 .11039 .60721 .1136 .61183 .11187 .60949 .10865 Mtetra
.60949 .10865 .61183 .11187 .61645 .11012 .61412 .1069 Mtetra
.61412 .1069 .61645 .11012 .62108 .10838 .61875 .10515 Mtetra
.61875 .10515 .62108 .10838 .62571 .10663 .62339 .1034 Mtetra
.62339 .1034 .62571 .10663 .63036 .10488 .62804 .10164 Mtetra
.62804 .10164 .63036 .10488 .63501 .10313 .6327 .09988 Mtetra
.6327 .09988 .63501 .10313 .63967 .10137 .63737 .09812 Mtetra
.63737 .09812 .63967 .10137 .64434 .09961 .64204 .09635 Mtetra
.64204 .09635 .64434 .09961 .64901 .09785 .64672 .09459 Mtetra
.64672 .09459 .64901 .09785 .6537 .09608 .65141 .09282 Mtetra
.65141 .09282 .6537 .09608 .65839 .09431 .65611 .09104 Mtetra
.65611 .09104 .65839 .09431 .66309 .09254 .66081 .08927 Mtetra
.66081 .08927 .66309 .09254 .66779 .09077 .66552 .08749 Mtetra
.66552 .08749 .66779 .09077 .67251 .08899 .67024 .0857 Mtetra
.67024 .0857 .67251 .08899 .67723 .08721 .67497 .08392 Mtetra
.67497 .08392 .67723 .08721 .68196 .08543 .67971 .08213 Mtetra
.67971 .08213 .68196 .08543 .6867 .08364 .68445 .08034 Mtetra
.68445 .08034 .6867 .08364 .69144 .08185 .6892 .07854 Mtetra
.6892 .07854 .69144 .08185 .6962 .08006 .69396 .07675 Mtetra
.69396 .07675 .6962 .08006 .70096 .07827 .69873 .07495 Mtetra
.69873 .07495 .70096 .07827 .70573 .07647 .7035 .07314 Mtetra
.7035 .07314 .70573 .07647 .71051 .07467 .70829 .07133 Mtetra
.70829 .07133 .71051 .07467 .71529 .07286 .71308 .06953 Mtetra
.71308 .06953 .71529 .07286 .72009 .07106 .71788 .06771 Mtetra
.71788 .06771 .72009 .07106 .72489 .06925 .72269 .0659 Mtetra
.72269 .0659 .72489 .06925 .7297 .06743 .7275 .06408 Mtetra
.08298 .30377 .08583 .30642 .08963 .30498 .08679 .30233 Mtetra
.08679 .30233 .08963 .30498 .09344 .30355 .09059 .30089 Mtetra
.09059 .30089 .09344 .30355 .09725 .30211 .09441 .29944 Mtetra
.09441 .29944 .09725 .30211 .10106 .30067 .09823 .298 Mtetra
.09823 .298 .10106 .30067 .10488 .29922 .10205 .29655 Mtetra
.10205 .29655 .10488 .29922 .10871 .29778 .10588 .2951 Mtetra
.10588 .2951 .10871 .29778 .11255 .29633 .10972 .29365 Mtetra
.10972 .29365 .11255 .29633 .11639 .29488 .11356 .2922 Mtetra
.11356 .2922 .11639 .29488 .12023 .29343 .11741 .29074 Mtetra
.11741 .29074 .12023 .29343 .12408 .29197 .12127 .28928 Mtetra
.12127 .28928 .12408 .29197 .12794 .29052 .12513 .28782 Mtetra
.12513 .28782 .12794 .29052 .1318 .28906 .12899 .28636 Mtetra
.12899 .28636 .1318 .28906 .13567 .2876 .13287 .28489 Mtetra
.13287 .28489 .13567 .2876 .13955 .28613 .13674 .28342 Mtetra
.13674 .28342 .13955 .28613 .14343 .28467 .14063 .28195 Mtetra
.14063 .28195 .14343 .28467 .14731 .2832 .14452 .28048 Mtetra
.14452 .28048 .14731 .2832 .1512 .28173 .14841 .27901 Mtetra
.14841 .27901 .1512 .28173 .1551 .28026 .15231 .27753 Mtetra
.15231 .27753 .1551 .28026 .15901 .27878 .15622 .27605 Mtetra
.15622 .27605 .15901 .27878 .16292 .27731 .16013 .27457 Mtetra
.16013 .27457 .16292 .27731 .16683 .27583 .16405 .27309 Mtetra
.16405 .27309 .16683 .27583 .17075 .27435 .16798 .2716 Mtetra
.16798 .2716 .17075 .27435 .17468 .27286 .17191 .27012 Mtetra
.17191 .27012 .17468 .27286 .17862 .27138 .17585 .26863 Mtetra
.17585 .26863 .17862 .27138 .18256 .26989 .17979 .26713 Mtetra
.17979 .26713 .18256 .26989 .1865 .2684 .18374 .26564 Mtetra
.18374 .26564 .1865 .2684 .19045 .26691 .1877 .26414 Mtetra
.1877 .26414 .19045 .26691 .19441 .26541 .19166 .26264 Mtetra
.19166 .26264 .19441 .26541 .19838 .26391 .19563 .26114 Mtetra
.19563 .26114 .19838 .26391 .20235 .26241 .1996 .25964 Mtetra
.1996 .25964 .20235 .26241 .20632 .26091 .20358 .25813 Mtetra
.20358 .25813 .20632 .26091 .21031 .25941 .20757 .25663 Mtetra
.20757 .25663 .21031 .25941 .21429 .2579 .21156 .25511 Mtetra
.21156 .25511 .21429 .2579 .21829 .25639 .21556 .2536 Mtetra
.21556 .2536 .21829 .25639 .22229 .25488 .21956 .25209 Mtetra
.21956 .25209 .22229 .25488 .2263 .25337 .22357 .25057 Mtetra
.22357 .25057 .2263 .25337 .23031 .25185 .22759 .24905 Mtetra
.22759 .24905 .23031 .25185 .23433 .25033 .23161 .24753 Mtetra
.23161 .24753 .23433 .25033 .23835 .24881 .23564 .246 Mtetra
.23564 .246 .23835 .24881 .24239 .24729 .23968 .24447 Mtetra
.23968 .24447 .24239 .24729 .24642 .24577 .24372 .24294 Mtetra
.24372 .24294 .24642 .24577 .25003 .2491 .24777 .24141 Mtetra
.216 .259 .693 r
.24777 .24141 .25003 .2491 .25409 .24758 .25139 .24475 Mtetra
.663 .742 .908 r
.25139 .24475 .25409 .24758 .25815 .24604 .25545 .24321 Mtetra
.25545 .24321 .25815 .24604 .26222 .24451 .25953 .24167 Mtetra
.25953 .24167 .26222 .24451 .2663 .24298 .2636 .24013 Mtetra
.2636 .24013 .2663 .24298 .27038 .24144 .26769 .23859 Mtetra
.26769 .23859 .27038 .24144 .27447 .2399 .27178 .23705 Mtetra
.27178 .23705 .27447 .2399 .27856 .23835 .27588 .2355 Mtetra
.27588 .2355 .27856 .23835 .28266 .23681 .27999 .23395 Mtetra
.27999 .23395 .28266 .23681 .28677 .23526 .2841 .2324 Mtetra
.2841 .2324 .28677 .23526 .29089 .23371 .28822 .23084 Mtetra
.28822 .23084 .29089 .23371 .29501 .23216 .29234 .22929 Mtetra
.29234 .22929 .29501 .23216 .29913 .2306 .29647 .22773 Mtetra
.29647 .22773 .29913 .2306 .30327 .22905 .30061 .22617 Mtetra
.30061 .22617 .30327 .22905 .30741 .22749 .30475 .2246 Mtetra
.30475 .2246 .30741 .22749 .31155 .22592 .3089 .22303 Mtetra
.3089 .22303 .31155 .22592 .31571 .22436 .31306 .22147 Mtetra
.31306 .22147 .31571 .22436 .31987 .22279 .31722 .21989 Mtetra
.871 .77 .748 r
.31722 .21989 .31987 .22279 .32403 .22122 .32172 .21343 Mtetra
.61 .511 .718 r
.32172 .21343 .32403 .22122 .32852 .21476 .32589 .21185 Mtetra
.664 .741 .908 r
.32589 .21185 .32852 .21476 .33269 .21319 .33007 .21027 Mtetra
.33007 .21027 .33269 .21319 .33687 .21161 .33425 .20869 Mtetra
.33425 .20869 .33687 .21161 .34106 .21003 .33844 .2071 Mtetra
.33844 .2071 .34106 .21003 .34525 .20844 .34264 .20551 Mtetra
.34264 .20551 .34525 .20844 .34945 .20686 .34684 .20392 Mtetra
.34684 .20392 .34945 .20686 .35365 .20527 .35105 .20233 Mtetra
.35105 .20233 .35365 .20527 .35787 .20368 .35526 .20073 Mtetra
.35526 .20073 .35787 .20368 .36209 .20209 .35949 .19914 Mtetra
.35949 .19914 .36209 .20209 .36631 .20049 .36372 .19754 Mtetra
.36372 .19754 .36631 .20049 .37054 .19889 .36795 .19593 Mtetra
.36795 .19593 .37054 .19889 .37478 .19729 .3722 .19433 Mtetra
.3722 .19433 .37478 .19729 .37903 .19569 .37645 .19272 Mtetra
.37645 .19272 .37903 .19569 .38328 .19408 .3807 .19111 Mtetra
.3807 .19111 .38328 .19408 .38754 .19247 .38497 .1895 Mtetra
.38497 .1895 .38754 .19247 .39181 .19086 .38924 .18788 Mtetra
.38924 .18788 .39181 .19086 .39608 .18925 .39351 .18626 Mtetra
.39351 .18626 .39608 .18925 .40036 .18763 .3978 .18464 Mtetra
.3978 .18464 .40036 .18763 .40464 .18601 .40209 .18302 Mtetra
.40209 .18302 .40464 .18601 .40894 .18439 .40639 .18139 Mtetra
.40639 .18139 .40894 .18439 .41324 .18277 .41069 .17976 Mtetra
0 .175 .69 r
.41069 .17976 .41324 .18277 .41737 .18606 .41482 .18305 Mtetra
.663 .742 .908 r
.41482 .18305 .41737 .18606 .42169 .18443 .41915 .18142 Mtetra
.41915 .18142 .42169 .18443 .42602 .1828 .42348 .17978 Mtetra
.42348 .17978 .42602 .1828 .43035 .18116 .42782 .17814 Mtetra
.42782 .17814 .43035 .18116 .43469 .17953 .43216 .1765 Mtetra
.43216 .1765 .43469 .17953 .43904 .17789 .43652 .17486 Mtetra
.43652 .17486 .43904 .17789 .4434 .17625 .44088 .17321 Mtetra
.44088 .17321 .4434 .17625 .44776 .17461 .44524 .17156 Mtetra
.44524 .17156 .44776 .17461 .45213 .17296 .44962 .16991 Mtetra
.44962 .16991 .45213 .17296 .45651 .17131 .454 .16826 Mtetra
.454 .16826 .45651 .17131 .46089 .16966 .45839 .1666 Mtetra
.45839 .1666 .46089 .16966 .46528 .168 .46278 .16494 Mtetra
.46278 .16494 .46528 .168 .46968 .16635 .46719 .16328 Mtetra
.46719 .16328 .46968 .16635 .47409 .16469 .4716 .16162 Mtetra
.4716 .16162 .47409 .16469 .4785 .16303 .47601 .15995 Mtetra
.47601 .15995 .4785 .16303 .48292 .16136 .48044 .15828 Mtetra
.48044 .15828 .48292 .16136 .48734 .15969 .48487 .15661 Mtetra
.48487 .15661 .48734 .15969 .49178 .15802 .48931 .15493 Mtetra
.48931 .15493 .49178 .15802 .49622 .15635 .49375 .15325 Mtetra
.49375 .15325 .49622 .15635 .50067 .15467 .4982 .15157 Mtetra
.4982 .15157 .50067 .15467 .50512 .15299 .50266 .14989 Mtetra
.50266 .14989 .50512 .15299 .50958 .15131 .50713 .1482 Mtetra
.50713 .1482 .50958 .15131 .51405 .14963 .51161 .14651 Mtetra
.51161 .14651 .51405 .14963 .51853 .14794 .51609 .14482 Mtetra
.884 .786 .748 r
.51609 .14482 .51853 .14794 .52302 .14131 .52058 .13818 Mtetra
.664 .741 .908 r
.52058 .13818 .52302 .14131 .5275 .13961 .52507 .13648 Mtetra
.52507 .13648 .5275 .13961 .532 .13792 .52957 .13478 Mtetra
.52957 .13478 .532 .13792 .53649 .13622 .53407 .13307 Mtetra
.53407 .13307 .53649 .13622 .541 .13451 .53859 .13136 Mtetra
.53859 .13136 .541 .13451 .54551 .13281 .5431 .12965 Mtetra
.5431 .12965 .54551 .13281 .55004 .1311 .54763 .12794 Mtetra
.54763 .12794 .55004 .1311 .55456 .12939 .55216 .12623 Mtetra
.55216 .12623 .55456 .12939 .5591 .12768 .5567 .12451 Mtetra
.5567 .12451 .5591 .12768 .56364 .12596 .56125 .12279 Mtetra
.56125 .12279 .56364 .12596 .56819 .12424 .56581 .12106 Mtetra
.56581 .12106 .56819 .12424 .57275 .12252 .57037 .11934 Mtetra
.57037 .11934 .57275 .12252 .57732 .1208 .57494 .11761 Mtetra
.57494 .11761 .57732 .1208 .58189 .11907 .57952 .11587 Mtetra
.57952 .11587 .58189 .11907 .58647 .11734 .58411 .11414 Mtetra
.58411 .11414 .58647 .11734 .59106 .11561 .5887 .1124 Mtetra
.5887 .1124 .59106 .11561 .59566 .11387 .5933 .11066 Mtetra
.5933 .11066 .59566 .11387 .60026 .11213 .59791 .10892 Mtetra
.59791 .10892 .60026 .11213 .60487 .11039 .60253 .10717 Mtetra
.60253 .10717 .60487 .11039 .60949 .10865 .60715 .10542 Mtetra
.60715 .10542 .60949 .10865 .61412 .1069 .61178 .10367 Mtetra
.61178 .10367 .61412 .1069 .61875 .10515 .61642 .10191 Mtetra
.61642 .10191 .61875 .10515 .62339 .1034 .62107 .10015 Mtetra
.62107 .10015 .62339 .1034 .62804 .10164 .62572 .09839 Mtetra
.62572 .09839 .62804 .10164 .6327 .09988 .63039 .09663 Mtetra
.63039 .09663 .6327 .09988 .63737 .09812 .63506 .09486 Mtetra
.63506 .09486 .63737 .09812 .64204 .09635 .63974 .09309 Mtetra
.63974 .09309 .64204 .09635 .64672 .09459 .64442 .09132 Mtetra
.64442 .09132 .64672 .09459 .65141 .09282 .64912 .08954 Mtetra
.64912 .08954 .65141 .09282 .65611 .09104 .65382 .08776 Mtetra
.65382 .08776 .65611 .09104 .66081 .08927 .65853 .08598 Mtetra
.65853 .08598 .66081 .08927 .66552 .08749 .66324 .08419 Mtetra
.66324 .08419 .66552 .08749 .67024 .0857 .66797 .0824 Mtetra
.66797 .0824 .67024 .0857 .67497 .08392 .6727 .08061 Mtetra
.6727 .08061 .67497 .08392 .67971 .08213 .67744 .07882 Mtetra
.67744 .07882 .67971 .08213 .68445 .08034 .68219 .07702 Mtetra
.68219 .07702 .68445 .08034 .6892 .07854 .68695 .07522 Mtetra
.68695 .07522 .6892 .07854 .69396 .07675 .69172 .07342 Mtetra
.69172 .07342 .69396 .07675 .69873 .07495 .69649 .07161 Mtetra
.69649 .07161 .69873 .07495 .7035 .07314 .70127 .0698 Mtetra
.70127 .0698 .7035 .07314 .70829 .07133 .70606 .06799 Mtetra
.70606 .06799 .70829 .07133 .71308 .06953 .71086 .06618 Mtetra
.71086 .06618 .71308 .06953 .71788 .06771 .71566 .06436 Mtetra
.71566 .06436 .71788 .06771 .72269 .0659 .72048 .06254 Mtetra
.72048 .06254 .72269 .0659 .7275 .06408 .7253 .06071 Mtetra
.08013 .30111 .08298 .30377 .08679 .30233 .08393 .29967 Mtetra
.08393 .29967 .08679 .30233 .09059 .30089 .08775 .29822 Mtetra
.08775 .29822 .09059 .30089 .09441 .29944 .09156 .29677 Mtetra
.09156 .29677 .09441 .29944 .09823 .298 .09539 .29532 Mtetra
.09539 .29532 .09823 .298 .10205 .29655 .09921 .29387 Mtetra
.09921 .29387 .10205 .29655 .10588 .2951 .10305 .29242 Mtetra
.10305 .29242 .10588 .2951 .10972 .29365 .10689 .29096 Mtetra
.10689 .29096 .10972 .29365 .11356 .2922 .11074 .28951 Mtetra
.11074 .28951 .11356 .2922 .11741 .29074 .11459 .28804 Mtetra
.11459 .28804 .11741 .29074 .12127 .28928 .11844 .28658 Mtetra
.11844 .28658 .12127 .28928 .12513 .28782 .12231 .28512 Mtetra
.12231 .28512 .12513 .28782 .12899 .28636 .12618 .28365 Mtetra
.12618 .28365 .12899 .28636 .13287 .28489 .13005 .28218 Mtetra
.13005 .28218 .13287 .28489 .13674 .28342 .13393 .28071 Mtetra
.13393 .28071 .13674 .28342 .14063 .28195 .13782 .27924 Mtetra
.13782 .27924 .14063 .28195 .14452 .28048 .14171 .27776 Mtetra
.14171 .27776 .14452 .28048 .14841 .27901 .14561 .27628 Mtetra
.14561 .27628 .14841 .27901 .15231 .27753 .14952 .2748 Mtetra
.14952 .2748 .15231 .27753 .15622 .27605 .15343 .27332 Mtetra
.15343 .27332 .15622 .27605 .16013 .27457 .15735 .27183 Mtetra
.15735 .27183 .16013 .27457 .16405 .27309 .16127 .27035 Mtetra
.16127 .27035 .16405 .27309 .16798 .2716 .1652 .26886 Mtetra
.1652 .26886 .16798 .2716 .17191 .27012 .16913 .26736 Mtetra
.16913 .26736 .17191 .27012 .17585 .26863 .17307 .26587 Mtetra
.17307 .26587 .17585 .26863 .17979 .26713 .17702 .26437 Mtetra
.17702 .26437 .17979 .26713 .18374 .26564 .18097 .26288 Mtetra
.18097 .26288 .18374 .26564 .1877 .26414 .18493 .26137 Mtetra
.18493 .26137 .1877 .26414 .19166 .26264 .1889 .25987 Mtetra
.1889 .25987 .19166 .26264 .19563 .26114 .19287 .25837 Mtetra
.19287 .25837 .19563 .26114 .1996 .25964 .19684 .25686 Mtetra
.19684 .25686 .1996 .25964 .20358 .25813 .20083 .25535 Mtetra
.20083 .25535 .20358 .25813 .20757 .25663 .20482 .25383 Mtetra
.20482 .25383 .20757 .25663 .21156 .25511 .20881 .25232 Mtetra
.20881 .25232 .21156 .25511 .21556 .2536 .21282 .2508 Mtetra
.21282 .2508 .21556 .2536 .21956 .25209 .21682 .24928 Mtetra
.21682 .24928 .21956 .25209 .22357 .25057 .22084 .24776 Mtetra
.22084 .24776 .22357 .25057 .22759 .24905 .22486 .24624 Mtetra
.22486 .24624 .22759 .24905 .23161 .24753 .22888 .24471 Mtetra
.22888 .24471 .23161 .24753 .23564 .246 .23292 .24318 Mtetra
.23292 .24318 .23564 .246 .23968 .24447 .23696 .24165 Mtetra
.23696 .24165 .23968 .24447 .24372 .24294 .241 .24012 Mtetra
.241 .24012 .24372 .24294 .24777 .24141 .24505 .23858 Mtetra
.24505 .23858 .24777 .24141 .25139 .24475 .24911 .23704 Mtetra
.216 .259 .693 r
.24911 .23704 .25139 .24475 .25545 .24321 .25274 .24037 Mtetra
.663 .742 .908 r
.25274 .24037 .25545 .24321 .25953 .24167 .25682 .23883 Mtetra
.25682 .23883 .25953 .24167 .2636 .24013 .2609 .23728 Mtetra
.2609 .23728 .2636 .24013 .26769 .23859 .26499 .23574 Mtetra
.26499 .23574 .26769 .23859 .27178 .23705 .26909 .23419 Mtetra
.26909 .23419 .27178 .23705 .27588 .2355 .27319 .23264 Mtetra
.27319 .23264 .27588 .2355 .27999 .23395 .2773 .23108 Mtetra
.2773 .23108 .27999 .23395 .2841 .2324 .28142 .22953 Mtetra
.28142 .22953 .2841 .2324 .28822 .23084 .28554 .22797 Mtetra
.28554 .22797 .28822 .23084 .29234 .22929 .28967 .22641 Mtetra
.28967 .22641 .29234 .22929 .29647 .22773 .2938 .22484 Mtetra
.2938 .22484 .29647 .22773 .30061 .22617 .29794 .22328 Mtetra
.29794 .22328 .30061 .22617 .30475 .2246 .30209 .22171 Mtetra
.30209 .22171 .30475 .2246 .3089 .22303 .30624 .22014 Mtetra
.30624 .22014 .3089 .22303 .31306 .22147 .3104 .21856 Mtetra
.871 .77 .748 r
.3104 .21856 .31306 .22147 .31722 .21989 .31491 .21209 Mtetra
.609 .511 .718 r
.31491 .21209 .31722 .21989 .32172 .21343 .31908 .21051 Mtetra
.664 .741 .908 r
.31908 .21051 .32172 .21343 .32589 .21185 .32325 .20893 Mtetra
.32325 .20893 .32589 .21185 .33007 .21027 .32743 .20735 Mtetra
.32743 .20735 .33007 .21027 .33425 .20869 .33162 .20576 Mtetra
.33162 .20576 .33425 .20869 .33844 .2071 .33581 .20417 Mtetra
.33581 .20417 .33844 .2071 .34264 .20551 .34001 .20258 Mtetra
.34001 .20258 .34264 .20551 .34684 .20392 .34422 .20098 Mtetra
.34422 .20098 .34684 .20392 .35105 .20233 .34843 .19938 Mtetra
.34843 .19938 .35105 .20233 .35526 .20073 .35265 .19778 Mtetra
.35265 .19778 .35526 .20073 .35949 .19914 .35688 .19618 Mtetra
.35688 .19618 .35949 .19914 .36372 .19754 .36112 .19457 Mtetra
.36112 .19457 .36372 .19754 .36795 .19593 .36536 .19297 Mtetra
.36536 .19297 .36795 .19593 .3722 .19433 .3696 .19136 Mtetra
.3696 .19136 .3722 .19433 .37645 .19272 .37386 .18974 Mtetra
.37386 .18974 .37645 .19272 .3807 .19111 .37812 .18813 Mtetra
.37812 .18813 .3807 .19111 .38497 .1895 .38239 .18651 Mtetra
.38239 .18651 .38497 .1895 .38924 .18788 .38666 .18489 Mtetra
.38666 .18489 .38924 .18788 .39351 .18626 .39094 .18327 Mtetra
.39094 .18327 .39351 .18626 .3978 .18464 .39523 .18164 Mtetra
.39523 .18164 .3978 .18464 .40209 .18302 .39952 .18001 Mtetra
.39952 .18001 .40209 .18302 .40639 .18139 .40383 .17838 Mtetra
.40383 .17838 .40639 .18139 .41069 .17976 .40813 .17675 Mtetra
0 .175 .69 r
.40813 .17675 .41069 .17976 .41482 .18305 .41227 .18003 Mtetra
.663 .742 .908 r
.41227 .18003 .41482 .18305 .41915 .18142 .4166 .17839 Mtetra
.4166 .17839 .41915 .18142 .42348 .17978 .42093 .17675 Mtetra
.42093 .17675 .42348 .17978 .42782 .17814 .42528 .17511 Mtetra
.42528 .17511 .42782 .17814 .43216 .1765 .42963 .17347 Mtetra
.42963 .17347 .43216 .1765 .43652 .17486 .43398 .17182 Mtetra
.43398 .17182 .43652 .17486 .44088 .17321 .43835 .17017 Mtetra
.43835 .17017 .44088 .17321 .44524 .17156 .44272 .16851 Mtetra
.44272 .16851 .44524 .17156 .44962 .16991 .4471 .16686 Mtetra
.4471 .16686 .44962 .16991 .454 .16826 .45148 .1652 Mtetra
.45148 .1652 .454 .16826 .45839 .1666 .45588 .16354 Mtetra
.45588 .16354 .45839 .1666 .46278 .16494 .46028 .16187 Mtetra
.46028 .16187 .46278 .16494 .46719 .16328 .46468 .16021 Mtetra
.46468 .16021 .46719 .16328 .4716 .16162 .4691 .15854 Mtetra
.4691 .15854 .4716 .16162 .47601 .15995 .47352 .15686 Mtetra
.47352 .15686 .47601 .15995 .48044 .15828 .47795 .15519 Mtetra
.47795 .15519 .48044 .15828 .48487 .15661 .48238 .15351 Mtetra
.48238 .15351 .48487 .15661 .48931 .15493 .48683 .15183 Mtetra
.48683 .15183 .48931 .15493 .49375 .15325 .49128 .15015 Mtetra
.49128 .15015 .49375 .15325 .4982 .15157 .49573 .14846 Mtetra
.49573 .14846 .4982 .15157 .50266 .14989 .5002 .14677 Mtetra
.5002 .14677 .50266 .14989 .50713 .1482 .50467 .14508 Mtetra
.50467 .14508 .50713 .1482 .51161 .14651 .50915 .14339 Mtetra
.50915 .14339 .51161 .14651 .51609 .14482 .51364 .14169 Mtetra
.884 .786 .748 r
.51364 .14169 .51609 .14482 .52058 .13818 .51814 .13504 Mtetra
.664 .741 .908 r
.51814 .13504 .52058 .13818 .52507 .13648 .52264 .13333 Mtetra
.52264 .13333 .52507 .13648 .52957 .13478 .52714 .13163 Mtetra
.52714 .13163 .52957 .13478 .53407 .13307 .53165 .12992 Mtetra
.53165 .12992 .53407 .13307 .53859 .13136 .53616 .12821 Mtetra
.53616 .12821 .53859 .13136 .5431 .12965 .54069 .12649 Mtetra
.54069 .12649 .5431 .12965 .54763 .12794 .54522 .12477 Mtetra
.54522 .12477 .54763 .12794 .55216 .12623 .54976 .12305 Mtetra
.54976 .12305 .55216 .12623 .5567 .12451 .5543 .12133 Mtetra
.5543 .12133 .5567 .12451 .56125 .12279 .55886 .1196 Mtetra
.55886 .1196 .56125 .12279 .56581 .12106 .56342 .11787 Mtetra
.56342 .11787 .56581 .12106 .57037 .11934 .56798 .11614 Mtetra
.56798 .11614 .57037 .11934 .57494 .11761 .57256 .11441 Mtetra
.57256 .11441 .57494 .11761 .57952 .11587 .57714 .11267 Mtetra
.57714 .11267 .57952 .11587 .58411 .11414 .58173 .11093 Mtetra
.58173 .11093 .58411 .11414 .5887 .1124 .58633 .10918 Mtetra
.58633 .10918 .5887 .1124 .5933 .11066 .59094 .10744 Mtetra
.59094 .10744 .5933 .11066 .59791 .10892 .59555 .10569 Mtetra
.59555 .10569 .59791 .10892 .60253 .10717 .60017 .10394 Mtetra
.60017 .10394 .60253 .10717 .60715 .10542 .6048 .10218 Mtetra
.6048 .10218 .60715 .10542 .61178 .10367 .60944 .10042 Mtetra
.60944 .10042 .61178 .10367 .61642 .10191 .61409 .09866 Mtetra
.61409 .09866 .61642 .10191 .62107 .10015 .61874 .0969 Mtetra
.61874 .0969 .62107 .10015 .62572 .09839 .6234 .09513 Mtetra
.6234 .09513 .62572 .09839 .63039 .09663 .62807 .09336 Mtetra
.62807 .09336 .63039 .09663 .63506 .09486 .63274 .09159 Mtetra
.63274 .09159 .63506 .09486 .63974 .09309 .63742 .08981 Mtetra
.63742 .08981 .63974 .09309 .64442 .09132 .64212 .08803 Mtetra
.64212 .08803 .64442 .09132 .64912 .08954 .64682 .08625 Mtetra
.64682 .08625 .64912 .08954 .65382 .08776 .65152 .08447 Mtetra
.65152 .08447 .65382 .08776 .65853 .08598 .65624 .08268 Mtetra
.65624 .08268 .65853 .08598 .66324 .08419 .66096 .08089 Mtetra
.66096 .08089 .66324 .08419 .66797 .0824 .66569 .0791 Mtetra
.66569 .0791 .66797 .0824 .6727 .08061 .67043 .0773 Mtetra
.67043 .0773 .6727 .08061 .67744 .07882 .67518 .0755 Mtetra
.67518 .0755 .67744 .07882 .68219 .07702 .67993 .0737 Mtetra
.67993 .0737 .68219 .07702 .68695 .07522 .68469 .07189 Mtetra
.68469 .07189 .68695 .07522 .69172 .07342 .68946 .07008 Mtetra
.68946 .07008 .69172 .07342 .69649 .07161 .69424 .06827 Mtetra
.69424 .06827 .69649 .07161 .70127 .0698 .69903 .06646 Mtetra
.69903 .06646 .70127 .0698 .70606 .06799 .70382 .06464 Mtetra
.70382 .06464 .70606 .06799 .71086 .06618 .70863 .06282 Mtetra
.70863 .06282 .71086 .06618 .71566 .06436 .71344 .06099 Mtetra
.71344 .06099 .71566 .06436 .72048 .06254 .71826 .05917 Mtetra
.71826 .05917 .72048 .06254 .7253 .06071 .72309 .05734 Mtetra
.07727 .29844 .08013 .30111 .08393 .29967 .08108 .297 Mtetra
.08108 .297 .08393 .29967 .08775 .29822 .08489 .29555 Mtetra
.08489 .29555 .08775 .29822 .09156 .29677 .08871 .2941 Mtetra
.08871 .2941 .09156 .29677 .09539 .29532 .09254 .29264 Mtetra
.09254 .29264 .09539 .29532 .09921 .29387 .09637 .29119 Mtetra
.09637 .29119 .09921 .29387 .10305 .29242 .10021 .28973 Mtetra
.10021 .28973 .10305 .29242 .10689 .29096 .10405 .28827 Mtetra
.10405 .28827 .10689 .29096 .11074 .28951 .1079 .28681 Mtetra
.1079 .28681 .11074 .28951 .11459 .28804 .11175 .28534 Mtetra
.11175 .28534 .11459 .28804 .11844 .28658 .11561 .28388 Mtetra
.11561 .28388 .11844 .28658 .12231 .28512 .11948 .28241 Mtetra
.11948 .28241 .12231 .28512 .12618 .28365 .12335 .28094 Mtetra
.12335 .28094 .12618 .28365 .13005 .28218 .12723 .27946 Mtetra
.12723 .27946 .13005 .28218 .13393 .28071 .13112 .27799 Mtetra
.13112 .27799 .13393 .28071 .13782 .27924 .13501 .27651 Mtetra
.13501 .27651 .13782 .27924 .14171 .27776 .1389 .27503 Mtetra
.1389 .27503 .14171 .27776 .14561 .27628 .14281 .27355 Mtetra
.14281 .27355 .14561 .27628 .14952 .2748 .14671 .27206 Mtetra
.14671 .27206 .14952 .2748 .15343 .27332 .15063 .27057 Mtetra
.15063 .27057 .15343 .27332 .15735 .27183 .15455 .26909 Mtetra
.15455 .26909 .15735 .27183 .16127 .27035 .15847 .26759 Mtetra
.15847 .26759 .16127 .27035 .1652 .26886 .16241 .2661 Mtetra
.16241 .2661 .1652 .26886 .16913 .26736 .16634 .2646 Mtetra
.16634 .2646 .16913 .26736 .17307 .26587 .17029 .26311 Mtetra
.17029 .26311 .17307 .26587 .17702 .26437 .17424 .26161 Mtetra
.17424 .26161 .17702 .26437 .18097 .26288 .1782 .2601 Mtetra
.1782 .2601 .18097 .26288 .18493 .26137 .18216 .2586 Mtetra
.18216 .2586 .18493 .26137 .1889 .25987 .18613 .25709 Mtetra
.18613 .25709 .1889 .25987 .19287 .25837 .1901 .25558 Mtetra
.1901 .25558 .19287 .25837 .19684 .25686 .19408 .25407 Mtetra
.19408 .25407 .19684 .25686 .20083 .25535 .19807 .25255 Mtetra
.19807 .25255 .20083 .25535 .20482 .25383 .20206 .25104 Mtetra
.20206 .25104 .20482 .25383 .20881 .25232 .20606 .24952 Mtetra
.20606 .24952 .20881 .25232 .21282 .2508 .21007 .24799 Mtetra
.21007 .24799 .21282 .2508 .21682 .24928 .21408 .24647 Mtetra
.21408 .24647 .21682 .24928 .22084 .24776 .2181 .24494 Mtetra
.2181 .24494 .22084 .24776 .22486 .24624 .22212 .24342 Mtetra
.22212 .24342 .22486 .24624 .22888 .24471 .22615 .24188 Mtetra
.22615 .24188 .22888 .24471 .23292 .24318 .23019 .24035 Mtetra
.23019 .24035 .23292 .24318 .23696 .24165 .23423 .23882 Mtetra
.23423 .23882 .23696 .24165 .241 .24012 .23828 .23728 Mtetra
.23828 .23728 .241 .24012 .24505 .23858 .24233 .23574 Mtetra
.24233 .23574 .24505 .23858 .24911 .23704 .2464 .23419 Mtetra
.2464 .23419 .24911 .23704 .25274 .24037 .25046 .23265 Mtetra
.216 .259 .693 r
.25046 .23265 .25274 .24037 .25682 .23883 .25411 .23598 Mtetra
.663 .742 .908 r
.25411 .23598 .25682 .23883 .2609 .23728 .25819 .23443 Mtetra
.25819 .23443 .2609 .23728 .26499 .23574 .26229 .23288 Mtetra
.26229 .23288 .26499 .23574 .26909 .23419 .26639 .23132 Mtetra
.26639 .23132 .26909 .23419 .27319 .23264 .27049 .22977 Mtetra
.27049 .22977 .27319 .23264 .2773 .23108 .27461 .22821 Mtetra
.27461 .22821 .2773 .23108 .28142 .22953 .27873 .22665 Mtetra
.27873 .22665 .28142 .22953 .28554 .22797 .28285 .22508 Mtetra
.28285 .22508 .28554 .22797 .28967 .22641 .28698 .22352 Mtetra
.28698 .22352 .28967 .22641 .2938 .22484 .29112 .22195 Mtetra
.29112 .22195 .2938 .22484 .29794 .22328 .29527 .22038 Mtetra
.29527 .22038 .29794 .22328 .30209 .22171 .29942 .2188 Mtetra
.29942 .2188 .30209 .22171 .30624 .22014 .30358 .21723 Mtetra
.30358 .21723 .30624 .22014 .3104 .21856 .30774 .21565 Mtetra
.871 .77 .748 r
.30774 .21565 .3104 .21856 .31491 .21209 .31226 .20917 Mtetra
.664 .741 .908 r
.31226 .20917 .31491 .21209 .31908 .21051 .31643 .20759 Mtetra
.31643 .20759 .31908 .21051 .32325 .20893 .3206 .206 Mtetra
.3206 .206 .32325 .20893 .32743 .20735 .32479 .20441 Mtetra
.32479 .20441 .32743 .20735 .33162 .20576 .32898 .20282 Mtetra
.32898 .20282 .33162 .20576 .33581 .20417 .33318 .20123 Mtetra
.33318 .20123 .33581 .20417 .34001 .20258 .33738 .19963 Mtetra
.33738 .19963 .34001 .20258 .34422 .20098 .34159 .19803 Mtetra
.34159 .19803 .34422 .20098 .34843 .19938 .34581 .19643 Mtetra
.34581 .19643 .34843 .19938 .35265 .19778 .35004 .19482 Mtetra
.35004 .19482 .35265 .19778 .35688 .19618 .35427 .19321 Mtetra
.35427 .19321 .35688 .19618 .36112 .19457 .35851 .1916 Mtetra
.35851 .1916 .36112 .19457 .36536 .19297 .36275 .18999 Mtetra
.36275 .18999 .36536 .19297 .3696 .19136 .367 .18838 Mtetra
.367 .18838 .3696 .19136 .37386 .18974 .37126 .18676 Mtetra
.37126 .18676 .37386 .18974 .37812 .18813 .37553 .18514 Mtetra
.37553 .18514 .37812 .18813 .38239 .18651 .3798 .18352 Mtetra
.3798 .18352 .38239 .18651 .38666 .18489 .38408 .18189 Mtetra
.38408 .18189 .38666 .18489 .39094 .18327 .38836 .18026 Mtetra
.38836 .18026 .39094 .18327 .39523 .18164 .39265 .17863 Mtetra
.39265 .17863 .39523 .18164 .39952 .18001 .39695 .177 Mtetra
.39695 .177 .39952 .18001 .40383 .17838 .40126 .17536 Mtetra
.40126 .17536 .40383 .17838 .40813 .17675 .40557 .17372 Mtetra
0 .175 .69 r
.40557 .17372 .40813 .17675 .41227 .18003 .4097 .17701 Mtetra
.663 .742 .908 r
.4097 .17701 .41227 .18003 .4166 .17839 .41404 .17536 Mtetra
.41404 .17536 .4166 .17839 .42093 .17675 .41838 .17372 Mtetra
.41838 .17372 .42093 .17675 .42528 .17511 .42273 .17207 Mtetra
.42273 .17207 .42528 .17511 .42963 .17347 .42708 .17042 Mtetra
.42708 .17042 .42963 .17347 .43398 .17182 .43144 .16877 Mtetra
.43144 .16877 .43398 .17182 .43835 .17017 .43581 .16711 Mtetra
.43581 .16711 .43835 .17017 .44272 .16851 .44019 .16545 Mtetra
.44019 .16545 .44272 .16851 .4471 .16686 .44457 .16379 Mtetra
.44457 .16379 .4471 .16686 .45148 .1652 .44896 .16213 Mtetra
.44896 .16213 .45148 .1652 .45588 .16354 .45336 .16046 Mtetra
.45336 .16046 .45588 .16354 .46028 .16187 .45776 .15879 Mtetra
.45776 .15879 .46028 .16187 .46468 .16021 .46217 .15712 Mtetra
.46217 .15712 .46468 .16021 .4691 .15854 .46659 .15545 Mtetra
.46659 .15545 .4691 .15854 .47352 .15686 .47102 .15377 Mtetra
.47102 .15377 .47352 .15686 .47795 .15519 .47545 .15209 Mtetra
.47545 .15209 .47795 .15519 .48238 .15351 .47989 .15041 Mtetra
.47989 .15041 .48238 .15351 .48683 .15183 .48434 .14872 Mtetra
.48434 .14872 .48683 .15183 .49128 .15015 .4888 .14703 Mtetra
.4888 .14703 .49128 .15015 .49573 .14846 .49326 .14534 Mtetra
.49326 .14534 .49573 .14846 .5002 .14677 .49773 .14365 Mtetra
.49773 .14365 .5002 .14677 .50467 .14508 .5022 .14195 Mtetra
.5022 .14195 .50467 .14508 .50915 .14339 .50669 .14025 Mtetra
.50669 .14025 .50915 .14339 .51364 .14169 .51118 .13855 Mtetra
.884 .786 .748 r
.51118 .13855 .51364 .14169 .51814 .13504 .51569 .13189 Mtetra
.664 .741 .908 r
.51569 .13189 .51814 .13504 .52264 .13333 .52019 .13018 Mtetra
.52019 .13018 .52264 .13333 .52714 .13163 .5247 .12847 Mtetra
.5247 .12847 .52714 .13163 .53165 .12992 .52921 .12675 Mtetra
.52921 .12675 .53165 .12992 .53616 .12821 .53373 .12504 Mtetra
.53373 .12504 .53616 .12821 .54069 .12649 .53826 .12332 Mtetra
.53826 .12332 .54069 .12649 .54522 .12477 .5428 .12159 Mtetra
.5428 .12159 .54522 .12477 .54976 .12305 .54734 .11987 Mtetra
.54734 .11987 .54976 .12305 .5543 .12133 .55189 .11814 Mtetra
.55189 .11814 .5543 .12133 .55886 .1196 .55645 .11641 Mtetra
.55645 .11641 .55886 .1196 .56342 .11787 .56102 .11467 Mtetra
.56102 .11467 .56342 .11787 .56798 .11614 .56559 .11294 Mtetra
.56559 .11294 .56798 .11614 .57256 .11441 .57017 .1112 Mtetra
.57017 .1112 .57256 .11441 .57714 .11267 .57476 .10945 Mtetra
.57476 .10945 .57714 .11267 .58173 .11093 .57935 .10771 Mtetra
.57935 .10771 .58173 .11093 .58633 .10918 .58396 .10596 Mtetra
.58396 .10596 .58633 .10918 .59094 .10744 .58857 .10421 Mtetra
.58857 .10421 .59094 .10744 .59555 .10569 .59319 .10245 Mtetra
.59319 .10245 .59555 .10569 .60017 .10394 .59781 .10069 Mtetra
.59781 .10069 .60017 .10394 .6048 .10218 .60245 .09893 Mtetra
.60245 .09893 .6048 .10218 .60944 .10042 .60709 .09717 Mtetra
.60709 .09717 .60944 .10042 .61409 .09866 .61174 .0954 Mtetra
.61174 .0954 .61409 .09866 .61874 .0969 .6164 .09363 Mtetra
.6164 .09363 .61874 .0969 .6234 .09513 .62106 .09186 Mtetra
.62106 .09186 .6234 .09513 .62807 .09336 .62574 .09009 Mtetra
.62574 .09009 .62807 .09336 .63274 .09159 .63042 .08831 Mtetra
.63042 .08831 .63274 .09159 .63742 .08981 .63511 .08653 Mtetra
.63511 .08653 .63742 .08981 .64212 .08803 .6398 .08474 Mtetra
.6398 .08474 .64212 .08803 .64682 .08625 .64451 .08296 Mtetra
.64451 .08296 .64682 .08625 .65152 .08447 .64922 .08117 Mtetra
.64922 .08117 .65152 .08447 .65624 .08268 .65394 .07937 Mtetra
.65394 .07937 .65624 .08268 .66096 .08089 .65867 .07758 Mtetra
.65867 .07758 .66096 .08089 .66569 .0791 .6634 .07578 Mtetra
.6634 .07578 .66569 .0791 .67043 .0773 .66815 .07397 Mtetra
.66815 .07397 .67043 .0773 .67518 .0755 .6729 .07217 Mtetra
.6729 .07217 .67518 .0755 .67993 .0737 .67766 .07036 Mtetra
.67766 .07036 .67993 .0737 .68469 .07189 .68243 .06855 Mtetra
.68243 .06855 .68469 .07189 .68946 .07008 .68721 .06674 Mtetra
.68721 .06674 .68946 .07008 .69424 .06827 .69199 .06492 Mtetra
.69199 .06492 .69424 .06827 .69903 .06646 .69678 .0631 Mtetra
.69678 .0631 .69903 .06646 .70382 .06464 .70158 .06127 Mtetra
.70158 .06127 .70382 .06464 .70863 .06282 .70639 .05945 Mtetra
.70639 .05945 .70863 .06282 .71344 .06099 .71121 .05762 Mtetra
.71121 .05762 .71344 .06099 .71826 .05917 .71603 .05578 Mtetra
.71603 .05578 .71826 .05917 .72309 .05734 .72087 .05395 Mtetra
.0744 .29577 .07727 .29844 .08108 .297 .07821 .29432 Mtetra
.07821 .29432 .08108 .297 .08489 .29555 .08203 .29287 Mtetra
.08203 .29287 .08489 .29555 .08871 .2941 .08585 .29141 Mtetra
.08585 .29141 .08871 .2941 .09254 .29264 .08968 .28995 Mtetra
.08968 .28995 .09254 .29264 .09637 .29119 .09351 .28849 Mtetra
.09351 .28849 .09637 .29119 .10021 .28973 .09735 .28703 Mtetra
.09735 .28703 .10021 .28973 .10405 .28827 .1012 .28557 Mtetra
.1012 .28557 .10405 .28827 .1079 .28681 .10505 .2841 Mtetra
.10505 .2841 .1079 .28681 .11175 .28534 .10891 .28263 Mtetra
.10891 .28263 .11175 .28534 .11561 .28388 .11278 .28116 Mtetra
.11278 .28116 .11561 .28388 .11948 .28241 .11665 .27969 Mtetra
.11665 .27969 .11948 .28241 .12335 .28094 .12052 .27821 Mtetra
.12052 .27821 .12335 .28094 .12723 .27946 .1244 .27674 Mtetra
.1244 .27674 .12723 .27946 .13112 .27799 .12829 .27526 Mtetra
.12829 .27526 .13112 .27799 .13501 .27651 .13218 .27377 Mtetra
.13218 .27377 .13501 .27651 .1389 .27503 .13608 .27229 Mtetra
.13608 .27229 .1389 .27503 .14281 .27355 .13999 .2708 Mtetra
.13999 .2708 .14281 .27355 .14671 .27206 .1439 .26932 Mtetra
.1439 .26932 .14671 .27206 .15063 .27057 .14782 .26782 Mtetra
.14782 .26782 .15063 .27057 .15455 .26909 .15174 .26633 Mtetra
.15174 .26633 .15455 .26909 .15847 .26759 .15567 .26483 Mtetra
.15567 .26483 .15847 .26759 .16241 .2661 .15961 .26334 Mtetra
.15961 .26334 .16241 .2661 .16634 .2646 .16355 .26184 Mtetra
.16355 .26184 .16634 .2646 .17029 .26311 .1675 .26033 Mtetra
.1675 .26033 .17029 .26311 .17424 .26161 .17145 .25883 Mtetra
.17145 .25883 .17424 .26161 .1782 .2601 .17541 .25732 Mtetra
.17541 .25732 .1782 .2601 .18216 .2586 .17938 .25581 Mtetra
.17938 .25581 .18216 .2586 .18613 .25709 .18335 .2543 Mtetra
.18335 .2543 .18613 .25709 .1901 .25558 .18733 .25279 Mtetra
.18733 .25279 .1901 .25558 .19408 .25407 .19131 .25127 Mtetra
.19131 .25127 .19408 .25407 .19807 .25255 .1953 .24975 Mtetra
.1953 .24975 .19807 .25255 .20206 .25104 .1993 .24823 Mtetra
.1993 .24823 .20206 .25104 .20606 .24952 .2033 .24671 Mtetra
.2033 .24671 .20606 .24952 .21007 .24799 .20731 .24518 Mtetra
.20731 .24518 .21007 .24799 .21408 .24647 .21133 .24365 Mtetra
.21133 .24365 .21408 .24647 .2181 .24494 .21535 .24212 Mtetra
.21535 .24212 .2181 .24494 .22212 .24342 .21937 .24059 Mtetra
.21937 .24059 .22212 .24342 .22615 .24188 .22341 .23905 Mtetra
.22341 .23905 .22615 .24188 .23019 .24035 .22745 .23751 Mtetra
.22745 .23751 .23019 .24035 .23423 .23882 .2315 .23597 Mtetra
.2315 .23597 .23423 .23882 .23828 .23728 .23555 .23443 Mtetra
.23555 .23443 .23828 .23728 .24233 .23574 .23961 .23289 Mtetra
.23961 .23289 .24233 .23574 .2464 .23419 .24367 .23134 Mtetra
.24367 .23134 .2464 .23419 .25046 .23265 .24774 .22979 Mtetra
.24774 .22979 .25046 .23265 .25411 .23598 .25182 .22824 Mtetra
.216 .259 .693 r
.25182 .22824 .25411 .23598 .25819 .23443 .25548 .23156 Mtetra
.663 .742 .908 r
.25548 .23156 .25819 .23443 .26229 .23288 .25957 .23001 Mtetra
.25957 .23001 .26229 .23288 .26639 .23132 .26368 .22845 Mtetra
.26368 .22845 .26639 .23132 .27049 .22977 .26779 .22689 Mtetra
.26779 .22689 .27049 .22977 .27461 .22821 .2719 .22532 Mtetra
.2719 .22532 .27461 .22821 .27873 .22665 .27603 .22376 Mtetra
.27603 .22376 .27873 .22665 .28285 .22508 .28016 .22219 Mtetra
.28016 .22219 .28285 .22508 .28698 .22352 .28429 .22062 Mtetra
.28429 .22062 .28698 .22352 .29112 .22195 .28843 .21905 Mtetra
.28843 .21905 .29112 .22195 .29527 .22038 .29258 .21747 Mtetra
.29258 .21747 .29527 .22038 .29942 .2188 .29674 .21589 Mtetra
.29674 .21589 .29942 .2188 .30358 .21723 .3009 .21431 Mtetra
.87 .769 .748 r
.3009 .21431 .30358 .21723 .30774 .21565 .30542 .20783 Mtetra
.609 .511 .718 r
.30542 .20783 .30774 .21565 .31226 .20917 .30959 .20625 Mtetra
.664 .741 .908 r
.30959 .20625 .31226 .20917 .31643 .20759 .31377 .20466 Mtetra
.31377 .20466 .31643 .20759 .3206 .206 .31795 .20307 Mtetra
.31795 .20307 .3206 .206 .32479 .20441 .32214 .20147 Mtetra
.32214 .20147 .32479 .20441 .32898 .20282 .32633 .19987 Mtetra
.32633 .19987 .32898 .20282 .33318 .20123 .33054 .19828 Mtetra
.33054 .19828 .33318 .20123 .33738 .19963 .33475 .19667 Mtetra
.33475 .19667 .33738 .19963 .34159 .19803 .33896 .19507 Mtetra
.33896 .19507 .34159 .19803 .34581 .19643 .34318 .19346 Mtetra
.34318 .19346 .34581 .19643 .35004 .19482 .34741 .19185 Mtetra
.34741 .19185 .35004 .19482 .35427 .19321 .35165 .19024 Mtetra
.35165 .19024 .35427 .19321 .35851 .1916 .35589 .18863 Mtetra
.35589 .18863 .35851 .1916 .36275 .18999 .36014 .18701 Mtetra
.36014 .18701 .36275 .18999 .367 .18838 .36439 .18539 Mtetra
.36439 .18539 .367 .18838 .37126 .18676 .36866 .18377 Mtetra
.36866 .18377 .37126 .18676 .37553 .18514 .37292 .18214 Mtetra
.37292 .18214 .37553 .18514 .3798 .18352 .3772 .18051 Mtetra
.3772 .18051 .3798 .18352 .38408 .18189 .38148 .17888 Mtetra
.38148 .17888 .38408 .18189 .38836 .18026 .38577 .17725 Mtetra
.38577 .17725 .38836 .18026 .39265 .17863 .39007 .17561 Mtetra
.39007 .17561 .39265 .17863 .39695 .177 .39437 .17398 Mtetra
.39437 .17398 .39695 .177 .40126 .17536 .39868 .17234 Mtetra
.39868 .17234 .40126 .17536 .40557 .17372 .403 .17069 Mtetra
.403 .17069 .40557 .17372 .4097 .17701 .40733 .16905 Mtetra
.262 .291 .703 r
.40733 .16905 .4097 .17701 .41404 .17536 .41147 .17233 Mtetra
.663 .742 .908 r
.41147 .17233 .41404 .17536 .41838 .17372 .41582 .17068 Mtetra
.41582 .17068 .41838 .17372 .42273 .17207 .42017 .16902 Mtetra
.42017 .16902 .42273 .17207 .42708 .17042 .42453 .16737 Mtetra
.42453 .16737 .42708 .17042 .43144 .16877 .42889 .16571 Mtetra
.42889 .16571 .43144 .16877 .43581 .16711 .43327 .16405 Mtetra
.43327 .16405 .43581 .16711 .44019 .16545 .43765 .16238 Mtetra
.43765 .16238 .44019 .16545 .44457 .16379 .44204 .16072 Mtetra
.44204 .16072 .44457 .16379 .44896 .16213 .44643 .15905 Mtetra
.44643 .15905 .44896 .16213 .45336 .16046 .45083 .15738 Mtetra
.45083 .15738 .45336 .16046 .45776 .15879 .45524 .1557 Mtetra
.45524 .1557 .45776 .15879 .46217 .15712 .45966 .15403 Mtetra
.45966 .15403 .46217 .15712 .46659 .15545 .46408 .15235 Mtetra
.46408 .15235 .46659 .15545 .47102 .15377 .46851 .15067 Mtetra
.46851 .15067 .47102 .15377 .47545 .15209 .47295 .14898 Mtetra
.47295 .14898 .47545 .15209 .47989 .15041 .47739 .14729 Mtetra
.47739 .14729 .47989 .15041 .48434 .14872 .48185 .1456 Mtetra
.48185 .1456 .48434 .14872 .4888 .14703 .48631 .14391 Mtetra
.48631 .14391 .4888 .14703 .49326 .14534 .49077 .14221 Mtetra
.49077 .14221 .49326 .14534 .49773 .14365 .49525 .14051 Mtetra
.49525 .14051 .49773 .14365 .5022 .14195 .49973 .13881 Mtetra
.49973 .13881 .5022 .14195 .50669 .14025 .50422 .13711 Mtetra
.50422 .13711 .50669 .14025 .51118 .13855 .50871 .1354 Mtetra
.884 .786 .748 r
.50871 .1354 .51118 .13855 .51569 .13189 .51324 .12873 Mtetra
.664 .741 .908 r
.51324 .12873 .51569 .13189 .52019 .13018 .51774 .12702 Mtetra
.51774 .12702 .52019 .13018 .5247 .12847 .52225 .1253 Mtetra
.52225 .1253 .5247 .12847 .52921 .12675 .52677 .12358 Mtetra
.52677 .12358 .52921 .12675 .53373 .12504 .5313 .12186 Mtetra
.5313 .12186 .53373 .12504 .53826 .12332 .53583 .12013 Mtetra
.53583 .12013 .53826 .12332 .5428 .12159 .54037 .11841 Mtetra
.54037 .11841 .5428 .12159 .54734 .11987 .54492 .11667 Mtetra
.54492 .11667 .54734 .11987 .55189 .11814 .54947 .11494 Mtetra
.54947 .11494 .55189 .11814 .55645 .11641 .55404 .1132 Mtetra
.55404 .1132 .55645 .11641 .56102 .11467 .55861 .11146 Mtetra
.55861 .11146 .56102 .11467 .56559 .11294 .56319 .10972 Mtetra
.56319 .10972 .56559 .11294 .57017 .1112 .56777 .10798 Mtetra
.56777 .10798 .57017 .1112 .57476 .10945 .57237 .10623 Mtetra
.57237 .10623 .57476 .10945 .57935 .10771 .57697 .10448 Mtetra
.57697 .10448 .57935 .10771 .58396 .10596 .58158 .10272 Mtetra
.58158 .10272 .58396 .10596 .58857 .10421 .58619 .10096 Mtetra
.58619 .10096 .58857 .10421 .59319 .10245 .59082 .0992 Mtetra
.59082 .0992 .59319 .10245 .59781 .10069 .59545 .09744 Mtetra
.59545 .09744 .59781 .10069 .60245 .09893 .60009 .09568 Mtetra
.60009 .09568 .60245 .09893 .60709 .09717 .60473 .09391 Mtetra
.60473 .09391 .60709 .09717 .61174 .0954 .60939 .09213 Mtetra
.60939 .09213 .61174 .0954 .6164 .09363 .61405 .09036 Mtetra
.61405 .09036 .6164 .09363 .62106 .09186 .61872 .08858 Mtetra
.61872 .08858 .62106 .09186 .62574 .09009 .6234 .0868 Mtetra
.6234 .0868 .62574 .09009 .63042 .08831 .62809 .08502 Mtetra
.62809 .08502 .63042 .08831 .63511 .08653 .63278 .08323 Mtetra
.63278 .08323 .63511 .08653 .6398 .08474 .63748 .08144 Mtetra
.63748 .08144 .6398 .08474 .64451 .08296 .64219 .07965 Mtetra
.64219 .07965 .64451 .08296 .64922 .08117 .64691 .07785 Mtetra
.64691 .07785 .64922 .08117 .65394 .07937 .65164 .07605 Mtetra
.65164 .07605 .65394 .07937 .65867 .07758 .65637 .07425 Mtetra
.65637 .07425 .65867 .07758 .6634 .07578 .66111 .07245 Mtetra
.66111 .07245 .6634 .07578 .66815 .07397 .66586 .07064 Mtetra
.66586 .07064 .66815 .07397 .6729 .07217 .67062 .06883 Mtetra
.67062 .06883 .6729 .07217 .67766 .07036 .67538 .06701 Mtetra
.67538 .06701 .67766 .07036 .68243 .06855 .68016 .0652 Mtetra
.68016 .0652 .68243 .06855 .68721 .06674 .68494 .06338 Mtetra
.68494 .06338 .68721 .06674 .69199 .06492 .68973 .06155 Mtetra
.68973 .06155 .69199 .06492 .69678 .0631 .69453 .05973 Mtetra
.69453 .05973 .69678 .0631 .70158 .06127 .69933 .0579 Mtetra
.69933 .0579 .70158 .06127 .70639 .05945 .70415 .05607 Mtetra
.70415 .05607 .70639 .05945 .71121 .05762 .70897 .05423 Mtetra
.70897 .05423 .71121 .05762 .71603 .05578 .7138 .05239 Mtetra
.7138 .05239 .71603 .05578 .72087 .05395 .71864 .05055 Mtetra
.07152 .29309 .0744 .29577 .07821 .29432 .07533 .29164 Mtetra
.07533 .29164 .07821 .29432 .08203 .29287 .07915 .29018 Mtetra
.07915 .29018 .08203 .29287 .08585 .29141 .08298 .28872 Mtetra
.08298 .28872 .08585 .29141 .08968 .28995 .08681 .28726 Mtetra
.08681 .28726 .08968 .28995 .09351 .28849 .09065 .28579 Mtetra
.09065 .28579 .09351 .28849 .09735 .28703 .09449 .28433 Mtetra
.09449 .28433 .09735 .28703 .1012 .28557 .09834 .28286 Mtetra
.09834 .28286 .1012 .28557 .10505 .2841 .1022 .28139 Mtetra
.1022 .28139 .10505 .2841 .10891 .28263 .10606 .27992 Mtetra
.10606 .27992 .10891 .28263 .11278 .28116 .10993 .27844 Mtetra
.10993 .27844 .11278 .28116 .11665 .27969 .1138 .27696 Mtetra
.1138 .27696 .11665 .27969 .12052 .27821 .11768 .27548 Mtetra
.11768 .27548 .12052 .27821 .1244 .27674 .12157 .274 Mtetra
.12157 .274 .1244 .27674 .12829 .27526 .12546 .27252 Mtetra
.12546 .27252 .12829 .27526 .13218 .27377 .12935 .27103 Mtetra
.12935 .27103 .13218 .27377 .13608 .27229 .13326 .26954 Mtetra
.13326 .26954 .13608 .27229 .13999 .2708 .13717 .26805 Mtetra
.13717 .26805 .13999 .2708 .1439 .26932 .14108 .26656 Mtetra
.14108 .26656 .1439 .26932 .14782 .26782 .145 .26506 Mtetra
.145 .26506 .14782 .26782 .15174 .26633 .14893 .26357 Mtetra
.14893 .26357 .15174 .26633 .15567 .26483 .15286 .26207 Mtetra
.15286 .26207 .15567 .26483 .15961 .26334 .1568 .26057 Mtetra
.1568 .26057 .15961 .26334 .16355 .26184 .16075 .25906 Mtetra
.16075 .25906 .16355 .26184 .1675 .26033 .1647 .25755 Mtetra
.1647 .25755 .1675 .26033 .17145 .25883 .16865 .25604 Mtetra
.16865 .25604 .17145 .25883 .17541 .25732 .17262 .25453 Mtetra
.17262 .25453 .17541 .25732 .17938 .25581 .17659 .25302 Mtetra
.17659 .25302 .17938 .25581 .18335 .2543 .18056 .2515 Mtetra
.18056 .2515 .18335 .2543 .18733 .25279 .18454 .24998 Mtetra
.18454 .24998 .18733 .25279 .19131 .25127 .18853 .24846 Mtetra
.18853 .24846 .19131 .25127 .1953 .24975 .19253 .24694 Mtetra
.19253 .24694 .1953 .24975 .1993 .24823 .19653 .24541 Mtetra
.19653 .24541 .1993 .24823 .2033 .24671 .20053 .24389 Mtetra
.20053 .24389 .2033 .24671 .20731 .24518 .20455 .24236 Mtetra
.20455 .24236 .20731 .24518 .21133 .24365 .20856 .24082 Mtetra
.20856 .24082 .21133 .24365 .21535 .24212 .21259 .23929 Mtetra
.21259 .23929 .21535 .24212 .21937 .24059 .21662 .23775 Mtetra
.21662 .23775 .21937 .24059 .22341 .23905 .22066 .23621 Mtetra
.22066 .23621 .22341 .23905 .22745 .23751 .2247 .23467 Mtetra
.2247 .23467 .22745 .23751 .2315 .23597 .22875 .23312 Mtetra
.22875 .23312 .2315 .23597 .23555 .23443 .23281 .23158 Mtetra
.23281 .23158 .23555 .23443 .23961 .23289 .23687 .23003 Mtetra
.23687 .23003 .23961 .23289 .24367 .23134 .24094 .22848 Mtetra
.24094 .22848 .24367 .23134 .24774 .22979 .24502 .22692 Mtetra
.24502 .22692 .24774 .22979 .25182 .22824 .2491 .22536 Mtetra
.2491 .22536 .25182 .22824 .25548 .23156 .25319 .22381 Mtetra
.216 .259 .693 r
.25319 .22381 .25548 .23156 .25957 .23001 .25685 .22713 Mtetra
.663 .742 .908 r
.25685 .22713 .25957 .23001 .26368 .22845 .26096 .22556 Mtetra
.26096 .22556 .26368 .22845 .26779 .22689 .26507 .224 Mtetra
.26507 .224 .26779 .22689 .2719 .22532 .26919 .22243 Mtetra
.26919 .22243 .2719 .22532 .27603 .22376 .27332 .22086 Mtetra
.27332 .22086 .27603 .22376 .28016 .22219 .27745 .21929 Mtetra
.27745 .21929 .28016 .22219 .28429 .22062 .28159 .21771 Mtetra
.28159 .21771 .28429 .22062 .28843 .21905 .28574 .21614 Mtetra
.28574 .21614 .28843 .21905 .29258 .21747 .28989 .21456 Mtetra
.28989 .21456 .29258 .21747 .29674 .21589 .29405 .21297 Mtetra
.29405 .21297 .29674 .21589 .3009 .21431 .29822 .21139 Mtetra
.87 .769 .748 r
.29822 .21139 .3009 .21431 .30542 .20783 .30275 .2049 Mtetra
.664 .741 .908 r
.30275 .2049 .30542 .20783 .30959 .20625 .30692 .20331 Mtetra
.30692 .20331 .30959 .20625 .31377 .20466 .3111 .20172 Mtetra
.3111 .20172 .31377 .20466 .31795 .20307 .31529 .20012 Mtetra
.31529 .20012 .31795 .20307 .32214 .20147 .31948 .19852 Mtetra
.31948 .19852 .32214 .20147 .32633 .19987 .32368 .19692 Mtetra
.32368 .19692 .32633 .19987 .33054 .19828 .32789 .19532 Mtetra
.32789 .19532 .33054 .19828 .33475 .19667 .3321 .19371 Mtetra
.3321 .19371 .33475 .19667 .33896 .19507 .33632 .1921 Mtetra
.33632 .1921 .33896 .19507 .34318 .19346 .34054 .19049 Mtetra
.34054 .19049 .34318 .19346 .34741 .19185 .34478 .18887 Mtetra
.34478 .18887 .34741 .19185 .35165 .19024 .34902 .18726 Mtetra
.34902 .18726 .35165 .19024 .35589 .18863 .35326 .18564 Mtetra
.35326 .18564 .35589 .18863 .36014 .18701 .35752 .18402 Mtetra
.35752 .18402 .36014 .18701 .36439 .18539 .36178 .18239 Mtetra
.36178 .18239 .36439 .18539 .36866 .18377 .36604 .18076 Mtetra
.36604 .18076 .36866 .18377 .37292 .18214 .37032 .17913 Mtetra
.37032 .17913 .37292 .18214 .3772 .18051 .3746 .1775 Mtetra
.3746 .1775 .3772 .18051 .38148 .17888 .37888 .17587 Mtetra
.37888 .17587 .38148 .17888 .38577 .17725 .38318 .17423 Mtetra
.38318 .17423 .38577 .17725 .39007 .17561 .38748 .17259 Mtetra
.38748 .17259 .39007 .17561 .39437 .17398 .39179 .17095 Mtetra
.39179 .17095 .39437 .17398 .39868 .17234 .3961 .1693 Mtetra
.3961 .1693 .39868 .17234 .403 .17069 .40042 .16765 Mtetra
.40042 .16765 .403 .17069 .40733 .16905 .40475 .166 Mtetra
0 .178 .692 r
.40475 .166 .40733 .16905 .41147 .17233 .4089 .16928 Mtetra
.663 .742 .908 r
.4089 .16928 .41147 .17233 .41582 .17068 .41325 .16762 Mtetra
.41325 .16762 .41582 .17068 .42017 .16902 .4176 .16596 Mtetra
.4176 .16596 .42017 .16902 .42453 .16737 .42197 .1643 Mtetra
.42197 .1643 .42453 .16737 .42889 .16571 .42634 .16264 Mtetra
.42634 .16264 .42889 .16571 .43327 .16405 .43072 .16098 Mtetra
.43072 .16098 .43327 .16405 .43765 .16238 .4351 .15931 Mtetra
.4351 .15931 .43765 .16238 .44204 .16072 .43949 .15764 Mtetra
.43949 .15764 .44204 .16072 .44643 .15905 .44389 .15596 Mtetra
.44389 .15596 .44643 .15905 .45083 .15738 .4483 .15429 Mtetra
.4483 .15429 .45083 .15738 .45524 .1557 .45271 .15261 Mtetra
.45271 .15261 .45524 .1557 .45966 .15403 .45713 .15092 Mtetra
.45713 .15092 .45966 .15403 .46408 .15235 .46156 .14924 Mtetra
.46156 .14924 .46408 .15235 .46851 .15067 .466 .14755 Mtetra
.466 .14755 .46851 .15067 .47295 .14898 .47044 .14586 Mtetra
.47044 .14586 .47295 .14898 .47739 .14729 .47489 .14417 Mtetra
.47489 .14417 .47739 .14729 .48185 .1456 .47935 .14247 Mtetra
.47935 .14247 .48185 .1456 .48631 .14391 .48381 .14077 Mtetra
.48381 .14077 .48631 .14391 .49077 .14221 .48828 .13907 Mtetra
.48828 .13907 .49077 .14221 .49525 .14051 .49276 .13737 Mtetra
.49276 .13737 .49525 .14051 .49973 .13881 .49725 .13566 Mtetra
.49725 .13566 .49973 .13881 .50422 .13711 .50174 .13395 Mtetra
.50174 .13395 .50422 .13711 .50871 .1354 .50624 .13224 Mtetra
.884 .786 .748 r
.50624 .13224 .50871 .1354 .51324 .12873 .51077 .12557 Mtetra
.664 .741 .908 r
.51077 .12557 .51324 .12873 .51774 .12702 .51528 .12385 Mtetra
.51528 .12385 .51774 .12702 .52225 .1253 .5198 .12212 Mtetra
.5198 .12212 .52225 .1253 .52677 .12358 .52432 .1204 Mtetra
.52432 .1204 .52677 .12358 .5313 .12186 .52885 .11867 Mtetra
.52885 .11867 .5313 .12186 .53583 .12013 .53339 .11694 Mtetra
.53339 .11694 .53583 .12013 .54037 .11841 .53794 .11521 Mtetra
.53794 .11521 .54037 .11841 .54492 .11667 .54249 .11347 Mtetra
.54249 .11347 .54492 .11667 .54947 .11494 .54705 .11173 Mtetra
.54705 .11173 .54947 .11494 .55404 .1132 .55162 .10999 Mtetra
.55162 .10999 .55404 .1132 .55861 .11146 .55619 .10824 Mtetra
.55619 .10824 .55861 .11146 .56319 .10972 .56078 .1065 Mtetra
.56078 .1065 .56319 .10972 .56777 .10798 .56537 .10475 Mtetra
.56537 .10475 .56777 .10798 .57237 .10623 .56997 .10299 Mtetra
.56997 .10299 .57237 .10623 .57697 .10448 .57457 .10123 Mtetra
.57457 .10123 .57697 .10448 .58158 .10272 .57919 .09948 Mtetra
.57919 .09948 .58158 .10272 .58619 .10096 .58381 .09771 Mtetra
.58381 .09771 .58619 .10096 .59082 .0992 .58844 .09595 Mtetra
.58844 .09595 .59082 .0992 .59545 .09744 .59307 .09418 Mtetra
.59307 .09418 .59545 .09744 .60009 .09568 .59772 .09241 Mtetra
.59772 .09241 .60009 .09568 .60473 .09391 .60237 .09063 Mtetra
.60237 .09063 .60473 .09391 .60939 .09213 .60703 .08886 Mtetra
.60703 .08886 .60939 .09213 .61405 .09036 .6117 .08708 Mtetra
.6117 .08708 .61405 .09036 .61872 .08858 .61637 .08529 Mtetra
.61637 .08529 .61872 .08858 .6234 .0868 .62106 .08351 Mtetra
.62106 .08351 .6234 .0868 .62809 .08502 .62575 .08172 Mtetra
.62575 .08172 .62809 .08502 .63278 .08323 .63045 .07992 Mtetra
.63045 .07992 .63278 .08323 .63748 .08144 .63516 .07813 Mtetra
.63516 .07813 .63748 .08144 .64219 .07965 .63987 .07633 Mtetra
.63987 .07633 .64219 .07965 .64691 .07785 .64459 .07453 Mtetra
.64459 .07453 .64691 .07785 .65164 .07605 .64933 .07273 Mtetra
.64933 .07273 .65164 .07605 .65637 .07425 .65406 .07092 Mtetra
.65406 .07092 .65637 .07425 .66111 .07245 .65881 .06911 Mtetra
.65881 .06911 .66111 .07245 .66586 .07064 .66357 .06729 Mtetra
.66357 .06729 .66586 .07064 .67062 .06883 .66833 .06548 Mtetra
.66833 .06548 .67062 .06883 .67538 .06701 .6731 .06366 Mtetra
.6731 .06366 .67538 .06701 .68016 .0652 .67788 .06183 Mtetra
.67788 .06183 .68016 .0652 .68494 .06338 .68267 .06001 Mtetra
.68267 .06001 .68494 .06338 .68973 .06155 .68746 .05818 Mtetra
.68746 .05818 .68973 .06155 .69453 .05973 .69227 .05635 Mtetra
.69227 .05635 .69453 .05973 .69933 .0579 .69708 .05451 Mtetra
.69708 .05451 .69933 .0579 .70415 .05607 .7019 .05267 Mtetra
.7019 .05267 .70415 .05607 .70897 .05423 .70673 .05083 Mtetra
.70673 .05083 .70897 .05423 .7138 .05239 .71156 .04899 Mtetra
.71156 .04899 .7138 .05239 .71864 .05055 .71641 .04714 Mtetra
.06863 .2904 .07152 .29309 .07533 .29164 .07245 .28894 Mtetra
.07245 .28894 .07533 .29164 .07915 .29018 .07627 .28748 Mtetra
.07627 .28748 .07915 .29018 .08298 .28872 .0801 .28602 Mtetra
.0801 .28602 .08298 .28872 .08681 .28726 .08394 .28455 Mtetra
.08394 .28455 .08681 .28726 .09065 .28579 .08778 .28309 Mtetra
.08778 .28309 .09065 .28579 .09449 .28433 .09163 .28162 Mtetra
.09163 .28162 .09449 .28433 .09834 .28286 .09548 .28014 Mtetra
.09548 .28014 .09834 .28286 .1022 .28139 .09934 .27867 Mtetra
.09934 .27867 .1022 .28139 .10606 .27992 .1032 .27719 Mtetra
.1032 .27719 .10606 .27992 .10993 .27844 .10707 .27571 Mtetra
.10707 .27571 .10993 .27844 .1138 .27696 .11095 .27423 Mtetra
.11095 .27423 .1138 .27696 .11768 .27548 .11483 .27275 Mtetra
.11483 .27275 .11768 .27548 .12157 .274 .11872 .27126 Mtetra
.11872 .27126 .12157 .274 .12546 .27252 .12262 .26977 Mtetra
.12262 .26977 .12546 .27252 .12935 .27103 .12652 .26828 Mtetra
.12652 .26828 .12935 .27103 .13326 .26954 .13042 .26679 Mtetra
.13042 .26679 .13326 .26954 .13717 .26805 .13433 .2653 Mtetra
.13433 .2653 .13717 .26805 .14108 .26656 .13825 .2638 Mtetra
.13825 .2638 .14108 .26656 .145 .26506 .14218 .2623 Mtetra
.14218 .2623 .145 .26506 .14893 .26357 .14611 .2608 Mtetra
.14611 .2608 .14893 .26357 .15286 .26207 .15004 .25929 Mtetra
.15004 .25929 .15286 .26207 .1568 .26057 .15399 .25779 Mtetra
.15399 .25779 .1568 .26057 .16075 .25906 .15794 .25628 Mtetra
.15794 .25628 .16075 .25906 .1647 .25755 .16189 .25477 Mtetra
.16189 .25477 .1647 .25755 .16865 .25604 .16585 .25325 Mtetra
.16585 .25325 .16865 .25604 .17262 .25453 .16982 .25174 Mtetra
.16982 .25174 .17262 .25453 .17659 .25302 .17379 .25022 Mtetra
.17379 .25022 .17659 .25302 .18056 .2515 .17777 .2487 Mtetra
.17777 .2487 .18056 .2515 .18454 .24998 .18175 .24717 Mtetra
.18175 .24717 .18454 .24998 .18853 .24846 .18575 .24565 Mtetra
.18575 .24565 .18853 .24846 .19253 .24694 .18974 .24412 Mtetra
.18974 .24412 .19253 .24694 .19653 .24541 .19375 .24259 Mtetra
.19375 .24259 .19653 .24541 .20053 .24389 .19776 .24106 Mtetra
.19776 .24106 .20053 .24389 .20455 .24236 .20177 .23952 Mtetra
.20177 .23952 .20455 .24236 .20856 .24082 .2058 .23799 Mtetra
.2058 .23799 .20856 .24082 .21259 .23929 .20982 .23645 Mtetra
.20982 .23645 .21259 .23929 .21662 .23775 .21386 .23491 Mtetra
.21386 .23491 .21662 .23775 .22066 .23621 .2179 .23336 Mtetra
.2179 .23336 .22066 .23621 .2247 .23467 .22195 .23182 Mtetra
.22195 .23182 .2247 .23467 .22875 .23312 .226 .23027 Mtetra
.226 .23027 .22875 .23312 .23281 .23158 .23006 .22871 Mtetra
.23006 .22871 .23281 .23158 .23687 .23003 .23413 .22716 Mtetra
.23413 .22716 .23687 .23003 .24094 .22848 .2382 .2256 Mtetra
.2382 .2256 .24094 .22848 .24502 .22692 .24228 .22405 Mtetra
.24228 .22405 .24502 .22692 .2491 .22536 .24637 .22248 Mtetra
.24637 .22248 .2491 .22536 .25319 .22381 .25046 .22092 Mtetra
.25046 .22092 .25319 .22381 .25685 .22713 .25456 .21935 Mtetra
.609 .511 .718 r
.25456 .21935 .25685 .22713 .26096 .22556 .25866 .21779 Mtetra
.217 .26 .693 r
.25866 .21779 .26096 .22556 .26507 .224 .26235 .2211 Mtetra
.663 .742 .908 r
.26235 .2211 .26507 .224 .26919 .22243 .26648 .21953 Mtetra
.26648 .21953 .26919 .22243 .27332 .22086 .27061 .21796 Mtetra
.27061 .21796 .27332 .22086 .27745 .21929 .27474 .21638 Mtetra
.27474 .21638 .27745 .21929 .28159 .21771 .27889 .2148 Mtetra
.27889 .2148 .28159 .21771 .28574 .21614 .28304 .21322 Mtetra
.28304 .21322 .28574 .21614 .28989 .21456 .2872 .21163 Mtetra
.2872 .21163 .28989 .21456 .29405 .21297 .29136 .21004 Mtetra
.87 .769 .748 r
.29136 .21004 .29405 .21297 .29822 .21139 .2959 .20356 Mtetra
.609 .511 .718 r
.2959 .20356 .29822 .21139 .30275 .2049 .30007 .20196 Mtetra
.664 .741 .908 r
.30007 .20196 .30275 .2049 .30692 .20331 .30425 .20037 Mtetra
.30425 .20037 .30692 .20331 .3111 .20172 .30843 .19877 Mtetra
.30843 .19877 .3111 .20172 .31529 .20012 .31262 .19717 Mtetra
.31262 .19717 .31529 .20012 .31948 .19852 .31682 .19556 Mtetra
.31682 .19556 .31948 .19852 .32368 .19692 .32102 .19396 Mtetra
.32102 .19396 .32368 .19692 .32789 .19532 .32523 .19235 Mtetra
.32523 .19235 .32789 .19532 .3321 .19371 .32945 .19074 Mtetra
.32945 .19074 .3321 .19371 .33632 .1921 .33367 .18912 Mtetra
.33367 .18912 .33632 .1921 .34054 .19049 .3379 .18751 Mtetra
.3379 .18751 .34054 .19049 .34478 .18887 .34214 .18589 Mtetra
.34214 .18589 .34478 .18887 .34902 .18726 .34638 .18427 Mtetra
.34638 .18427 .34902 .18726 .35326 .18564 .35063 .18264 Mtetra
.35063 .18264 .35326 .18564 .35752 .18402 .35489 .18101 Mtetra
.35489 .18101 .35752 .18402 .36178 .18239 .35915 .17939 Mtetra
.35915 .17939 .36178 .18239 .36604 .18076 .36342 .17775 Mtetra
.36342 .17775 .36604 .18076 .37032 .17913 .3677 .17612 Mtetra
.3677 .17612 .37032 .17913 .3746 .1775 .37199 .17448 Mtetra
.37199 .17448 .3746 .1775 .37888 .17587 .37628 .17284 Mtetra
.37628 .17284 .37888 .17587 .38318 .17423 .38058 .1712 Mtetra
.38058 .1712 .38318 .17423 .38748 .17259 .38488 .16955 Mtetra
.38488 .16955 .38748 .17259 .39179 .17095 .38919 .16791 Mtetra
.38919 .16791 .39179 .17095 .3961 .1693 .39351 .16626 Mtetra
.39351 .16626 .3961 .1693 .40042 .16765 .39784 .1646 Mtetra
.39784 .1646 .40042 .16765 .40475 .166 .40217 .16295 Mtetra
0 .178 .692 r
.40217 .16295 .40475 .166 .4089 .16928 .40632 .16622 Mtetra
.663 .742 .908 r
.40632 .16622 .4089 .16928 .41325 .16762 .41067 .16456 Mtetra
.41067 .16456 .41325 .16762 .4176 .16596 .41503 .1629 Mtetra
.41503 .1629 .4176 .16596 .42197 .1643 .4194 .16123 Mtetra
.4194 .16123 .42197 .1643 .42634 .16264 .42377 .15956 Mtetra
.42377 .15956 .42634 .16264 .43072 .16098 .42816 .15789 Mtetra
.42816 .15789 .43072 .16098 .4351 .15931 .43255 .15622 Mtetra
.43255 .15622 .4351 .15931 .43949 .15764 .43694 .15454 Mtetra
.43694 .15454 .43949 .15764 .44389 .15596 .44135 .15286 Mtetra
.44135 .15286 .44389 .15596 .4483 .15429 .44576 .15118 Mtetra
.44576 .15118 .4483 .15429 .45271 .15261 .45018 .1495 Mtetra
.45018 .1495 .45271 .15261 .45713 .15092 .4546 .14781 Mtetra
.4546 .14781 .45713 .15092 .46156 .14924 .45903 .14612 Mtetra
.45903 .14612 .46156 .14924 .466 .14755 .46347 .14443 Mtetra
.46347 .14443 .466 .14755 .47044 .14586 .46792 .14273 Mtetra
.46792 .14273 .47044 .14586 .47489 .14417 .47237 .14104 Mtetra
.47237 .14104 .47489 .14417 .47935 .14247 .47684 .13933 Mtetra
.47684 .13933 .47935 .14247 .48381 .14077 .48131 .13763 Mtetra
.48131 .13763 .48381 .14077 .48828 .13907 .48578 .13592 Mtetra
.48578 .13592 .48828 .13907 .49276 .13737 .49027 .13422 Mtetra
.49027 .13422 .49276 .13737 .49725 .13566 .49476 .1325 Mtetra
.49476 .1325 .49725 .13566 .50174 .13395 .49926 .13079 Mtetra
.49926 .13079 .50174 .13395 .50624 .13224 .50376 .12907 Mtetra
.884 .786 .748 r
.50376 .12907 .50624 .13224 .51077 .12557 .5083 .12239 Mtetra
.664 .741 .908 r
.5083 .12239 .51077 .12557 .51528 .12385 .51282 .12067 Mtetra
.51282 .12067 .51528 .12385 .5198 .12212 .51734 .11894 Mtetra
.51734 .11894 .5198 .12212 .52432 .1204 .52186 .11721 Mtetra
.52186 .11721 .52432 .1204 .52885 .11867 .5264 .11547 Mtetra
.5264 .11547 .52885 .11867 .53339 .11694 .53094 .11374 Mtetra
.53094 .11374 .53339 .11694 .53794 .11521 .53549 .112 Mtetra
.53549 .112 .53794 .11521 .54249 .11347 .54005 .11026 Mtetra
.54005 .11026 .54249 .11347 .54705 .11173 .54462 .10851 Mtetra
.54462 .10851 .54705 .11173 .55162 .10999 .54919 .10677 Mtetra
.54919 .10677 .55162 .10999 .55619 .10824 .55377 .10501 Mtetra
.55377 .10501 .55619 .10824 .56078 .1065 .55836 .10326 Mtetra
.55836 .10326 .56078 .1065 .56537 .10475 .56295 .10151 Mtetra
.56295 .10151 .56537 .10475 .56997 .10299 .56756 .09975 Mtetra
.56756 .09975 .56997 .10299 .57457 .10123 .57217 .09798 Mtetra
.57217 .09798 .57457 .10123 .57919 .09948 .57679 .09622 Mtetra
.57679 .09622 .57919 .09948 .58381 .09771 .58142 .09445 Mtetra
.58142 .09445 .58381 .09771 .58844 .09595 .58605 .09268 Mtetra
.58605 .09268 .58844 .09595 .59307 .09418 .59069 .09091 Mtetra
.59069 .09091 .59307 .09418 .59772 .09241 .59534 .08913 Mtetra
.59534 .08913 .59772 .09241 .60237 .09063 .6 .08735 Mtetra
.6 .08735 .60237 .09063 .60703 .08886 .60466 .08557 Mtetra
.60466 .08557 .60703 .08886 .6117 .08708 .60934 .08378 Mtetra
.60934 .08378 .6117 .08708 .61637 .08529 .61402 .08199 Mtetra
.61402 .08199 .61637 .08529 .62106 .08351 .61871 .0802 Mtetra
.61871 .0802 .62106 .08351 .62575 .08172 .6234 .07841 Mtetra
.6234 .07841 .62575 .08172 .63045 .07992 .62811 .07661 Mtetra
.62811 .07661 .63045 .07992 .63516 .07813 .63282 .07481 Mtetra
.63282 .07481 .63516 .07813 .63987 .07633 .63754 .073 Mtetra
.63754 .073 .63987 .07633 .64459 .07453 .64227 .0712 Mtetra
.64227 .0712 .64459 .07453 .64933 .07273 .64701 .06939 Mtetra
.64701 .06939 .64933 .07273 .65406 .07092 .65175 .06757 Mtetra
.65175 .06757 .65406 .07092 .65881 .06911 .6565 .06576 Mtetra
.6565 .06576 .65881 .06911 .66357 .06729 .66126 .06394 Mtetra
.66126 .06394 .66357 .06729 .66833 .06548 .66603 .06212 Mtetra
.66603 .06212 .66833 .06548 .6731 .06366 .67081 .06029 Mtetra
.67081 .06029 .6731 .06366 .67788 .06183 .67559 .05846 Mtetra
.67559 .05846 .67788 .06183 .68267 .06001 .68039 .05663 Mtetra
.68039 .05663 .68267 .06001 .68746 .05818 .68519 .0548 Mtetra
.68519 .0548 .68746 .05818 .69227 .05635 .69 .05296 Mtetra
.69 .05296 .69227 .05635 .69708 .05451 .69482 .05112 Mtetra
.69482 .05112 .69708 .05451 .7019 .05267 .69964 .04927 Mtetra
.69964 .04927 .7019 .05267 .70673 .05083 .70447 .04743 Mtetra
.70447 .04743 .70673 .05083 .71156 .04899 .70932 .04558 Mtetra
.70932 .04558 .71156 .04899 .71641 .04714 .71417 .04372 Mtetra
.06574 .28771 .06863 .2904 .07245 .28894 .06956 .28624 Mtetra
.06956 .28624 .07245 .28894 .07627 .28748 .07338 .28478 Mtetra
.07338 .28478 .07627 .28748 .0801 .28602 .07722 .28331 Mtetra
.07722 .28331 .0801 .28602 .08394 .28455 .08106 .28184 Mtetra
.08106 .28184 .08394 .28455 .08778 .28309 .0849 .28037 Mtetra
.0849 .28037 .08778 .28309 .09163 .28162 .08875 .2789 Mtetra
.08875 .2789 .09163 .28162 .09548 .28014 .09261 .27742 Mtetra
.09261 .27742 .09548 .28014 .09934 .27867 .09647 .27594 Mtetra
.09647 .27594 .09934 .27867 .1032 .27719 .10034 .27446 Mtetra
.10034 .27446 .1032 .27719 .10707 .27571 .10421 .27298 Mtetra
.10421 .27298 .10707 .27571 .11095 .27423 .10809 .27149 Mtetra
.10809 .27149 .11095 .27423 .11483 .27275 .11198 .27 Mtetra
.11198 .27 .11483 .27275 .11872 .27126 .11587 .26851 Mtetra
.11587 .26851 .11872 .27126 .12262 .26977 .11977 .26702 Mtetra
.11977 .26702 .12262 .26977 .12652 .26828 .12367 .26553 Mtetra
.12367 .26553 .12652 .26828 .13042 .26679 .12758 .26403 Mtetra
.12758 .26403 .13042 .26679 .13433 .2653 .1315 .26253 Mtetra
.1315 .26253 .13433 .2653 .13825 .2638 .13542 .26103 Mtetra
.13542 .26103 .13825 .2638 .14218 .2623 .13934 .25952 Mtetra
.13934 .25952 .14218 .2623 .14611 .2608 .14328 .25802 Mtetra
.14328 .25802 .14611 .2608 .15004 .25929 .14722 .25651 Mtetra
.14722 .25651 .15004 .25929 .15399 .25779 .15116 .255 Mtetra
.15116 .255 .15399 .25779 .15794 .25628 .15512 .25348 Mtetra
.15512 .25348 .15794 .25628 .16189 .25477 .15907 .25197 Mtetra
.15907 .25197 .16189 .25477 .16585 .25325 .16304 .25045 Mtetra
.16304 .25045 .16585 .25325 .16982 .25174 .16701 .24893 Mtetra
.16701 .24893 .16982 .25174 .17379 .25022 .17099 .24741 Mtetra
.17099 .24741 .17379 .25022 .17777 .2487 .17497 .24588 Mtetra
.17497 .24588 .17777 .2487 .18175 .24717 .17896 .24436 Mtetra
.17896 .24436 .18175 .24717 .18575 .24565 .18295 .24283 Mtetra
.18295 .24283 .18575 .24565 .18974 .24412 .18695 .2413 Mtetra
.18695 .2413 .18974 .24412 .19375 .24259 .19096 .23976 Mtetra
.19096 .23976 .19375 .24259 .19776 .24106 .19497 .23822 Mtetra
.19497 .23822 .19776 .24106 .20177 .23952 .19899 .23668 Mtetra
.19899 .23668 .20177 .23952 .2058 .23799 .20302 .23514 Mtetra
.20302 .23514 .2058 .23799 .20982 .23645 .20705 .2336 Mtetra
.20705 .2336 .20982 .23645 .21386 .23491 .21109 .23205 Mtetra
.21109 .23205 .21386 .23491 .2179 .23336 .21514 .2305 Mtetra
.21514 .2305 .2179 .23336 .22195 .23182 .21919 .22895 Mtetra
.21919 .22895 .22195 .23182 .226 .23027 .22324 .2274 Mtetra
.22324 .2274 .226 .23027 .23006 .22871 .22731 .22584 Mtetra
.22731 .22584 .23006 .22871 .23413 .22716 .23138 .22429 Mtetra
.23138 .22429 .23413 .22716 .2382 .2256 .23546 .22272 Mtetra
.23546 .22272 .2382 .2256 .24228 .22405 .23954 .22116 Mtetra
.23954 .22116 .24228 .22405 .24637 .22248 .24363 .2196 Mtetra
.24363 .2196 .24637 .22248 .25046 .22092 .24772 .21803 Mtetra
.24772 .21803 .25046 .22092 .25456 .21935 .25183 .21646 Mtetra
.25183 .21646 .25456 .21935 .25866 .21779 .25593 .21488 Mtetra
.25593 .21488 .25866 .21779 .26235 .2211 .26005 .21331 Mtetra
.217 .26 .693 r
.26005 .21331 .26235 .2211 .26648 .21953 .26375 .21662 Mtetra
.663 .742 .908 r
.26375 .21662 .26648 .21953 .27061 .21796 .26789 .21504 Mtetra
.26789 .21504 .27061 .21796 .27474 .21638 .27203 .21346 Mtetra
.27203 .21346 .27474 .21638 .27889 .2148 .27617 .21188 Mtetra
.27617 .21188 .27889 .2148 .28304 .21322 .28033 .21029 Mtetra
.28033 .21029 .28304 .21322 .2872 .21163 .28449 .2087 Mtetra
.87 .769 .748 r
.28449 .2087 .2872 .21163 .29136 .21004 .28904 .20221 Mtetra
.609 .511 .718 r
.28904 .20221 .29136 .21004 .2959 .20356 .29321 .20061 Mtetra
.664 .741 .908 r
.29321 .20061 .2959 .20356 .30007 .20196 .29738 .19901 Mtetra
.29738 .19901 .30007 .20196 .30425 .20037 .30156 .19741 Mtetra
.30156 .19741 .30425 .20037 .30843 .19877 .30575 .19581 Mtetra
.30575 .19581 .30843 .19877 .31262 .19717 .30994 .1942 Mtetra
.30994 .1942 .31262 .19717 .31682 .19556 .31414 .1926 Mtetra
.31414 .1926 .31682 .19556 .32102 .19396 .31835 .19098 Mtetra
.31835 .19098 .32102 .19396 .32523 .19235 .32256 .18937 Mtetra
.32256 .18937 .32523 .19235 .32945 .19074 .32679 .18776 Mtetra
.32679 .18776 .32945 .19074 .33367 .18912 .33101 .18614 Mtetra
.33101 .18614 .33367 .18912 .3379 .18751 .33525 .18452 Mtetra
.33525 .18452 .3379 .18751 .34214 .18589 .33949 .18289 Mtetra
.33949 .18289 .34214 .18589 .34638 .18427 .34374 .18126 Mtetra
.34374 .18126 .34638 .18427 .35063 .18264 .34799 .17964 Mtetra
.34799 .17964 .35063 .18264 .35489 .18101 .35225 .178 Mtetra
.35225 .178 .35489 .18101 .35915 .17939 .35652 .17637 Mtetra
.35652 .17637 .35915 .17939 .36342 .17775 .3608 .17473 Mtetra
.3608 .17473 .36342 .17775 .3677 .17612 .36508 .17309 Mtetra
.36508 .17309 .3677 .17612 .37199 .17448 .36937 .17145 Mtetra
.36937 .17145 .37199 .17448 .37628 .17284 .37366 .16981 Mtetra
.37366 .16981 .37628 .17284 .38058 .1712 .37796 .16816 Mtetra
.37796 .16816 .38058 .1712 .38488 .16955 .38227 .16651 Mtetra
.38227 .16651 .38488 .16955 .38919 .16791 .38659 .16486 Mtetra
.38659 .16486 .38919 .16791 .39351 .16626 .39091 .1632 Mtetra
.39091 .1632 .39351 .16626 .39784 .1646 .39524 .16154 Mtetra
.39524 .16154 .39784 .1646 .40217 .16295 .39958 .15988 Mtetra
0 .178 .692 r
.39958 .15988 .40217 .16295 .40632 .16622 .40373 .16315 Mtetra
.663 .742 .908 r
.40373 .16315 .40632 .16622 .41067 .16456 .40808 .16149 Mtetra
.40808 .16149 .41067 .16456 .41503 .1629 .41245 .15982 Mtetra
.41245 .15982 .41503 .1629 .4194 .16123 .41682 .15815 Mtetra
.41682 .15815 .4194 .16123 .42377 .15956 .4212 .15648 Mtetra
.4212 .15648 .42377 .15956 .42816 .15789 .42559 .1548 Mtetra
.42559 .1548 .42816 .15789 .43255 .15622 .42998 .15312 Mtetra
.42998 .15312 .43255 .15622 .43694 .15454 .43438 .15144 Mtetra
.43438 .15144 .43694 .15454 .44135 .15286 .43879 .14976 Mtetra
.43879 .14976 .44135 .15286 .44576 .15118 .44321 .14807 Mtetra
.44321 .14807 .44576 .15118 .45018 .1495 .44763 .14638 Mtetra
.44763 .14638 .45018 .1495 .4546 .14781 .45206 .14469 Mtetra
.45206 .14469 .4546 .14781 .45903 .14612 .4565 .14299 Mtetra
.4565 .14299 .45903 .14612 .46347 .14443 .46094 .1413 Mtetra
.46094 .1413 .46347 .14443 .46792 .14273 .46539 .1396 Mtetra
.46539 .1396 .46792 .14273 .47237 .14104 .46985 .13789 Mtetra
.46985 .13789 .47237 .14104 .47684 .13933 .47432 .13619 Mtetra
.47432 .13619 .47684 .13933 .48131 .13763 .47879 .13448 Mtetra
.47879 .13448 .48131 .13763 .48578 .13592 .48327 .13277 Mtetra
.48327 .13277 .48578 .13592 .49027 .13422 .48776 .13105 Mtetra
.48776 .13105 .49027 .13422 .49476 .1325 .49226 .12933 Mtetra
.49226 .12933 .49476 .1325 .49926 .13079 .49676 .12761 Mtetra
.49676 .12761 .49926 .13079 .50376 .12907 .50127 .12589 Mtetra
.884 .786 .748 r
.50127 .12589 .50376 .12907 .5083 .12239 .50582 .1192 Mtetra
.664 .741 .908 r
.50582 .1192 .5083 .12239 .51282 .12067 .51034 .11747 Mtetra
.51034 .11747 .51282 .12067 .51734 .11894 .51487 .11574 Mtetra
.51487 .11574 .51734 .11894 .52186 .11721 .5194 .11401 Mtetra
.5194 .11401 .52186 .11721 .5264 .11547 .52394 .11227 Mtetra
.52394 .11227 .5264 .11547 .53094 .11374 .52849 .11053 Mtetra
.52849 .11053 .53094 .11374 .53549 .112 .53304 .10878 Mtetra
.53304 .10878 .53549 .112 .54005 .11026 .53761 .10703 Mtetra
.53761 .10703 .54005 .11026 .54462 .10851 .54218 .10528 Mtetra
.54218 .10528 .54462 .10851 .54919 .10677 .54675 .10353 Mtetra
.54675 .10353 .54919 .10677 .55377 .10501 .55134 .10178 Mtetra
.55134 .10178 .55377 .10501 .55836 .10326 .55593 .10002 Mtetra
.55593 .10002 .55836 .10326 .56295 .10151 .56054 .09826 Mtetra
.56054 .09826 .56295 .10151 .56756 .09975 .56514 .09649 Mtetra
.56514 .09649 .56756 .09975 .57217 .09798 .56976 .09472 Mtetra
.56976 .09472 .57217 .09798 .57679 .09622 .57438 .09295 Mtetra
.57438 .09295 .57679 .09622 .58142 .09445 .57902 .09118 Mtetra
.57902 .09118 .58142 .09445 .58605 .09268 .58366 .0894 Mtetra
.58366 .0894 .58605 .09268 .59069 .09091 .5883 .08762 Mtetra
.5883 .08762 .59069 .09091 .59534 .08913 .59296 .08584 Mtetra
.59296 .08584 .59534 .08913 .6 .08735 .59762 .08406 Mtetra
.59762 .08406 .6 .08735 .60466 .08557 .60229 .08227 Mtetra
.60229 .08227 .60466 .08557 .60934 .08378 .60697 .08048 Mtetra
.60697 .08048 .60934 .08378 .61402 .08199 .61166 .07868 Mtetra
.61166 .07868 .61402 .08199 .61871 .0802 .61635 .07688 Mtetra
.61635 .07688 .61871 .0802 .6234 .07841 .62105 .07508 Mtetra
.62105 .07508 .6234 .07841 .62811 .07661 .62576 .07328 Mtetra
.62576 .07328 .62811 .07661 .63282 .07481 .63048 .07147 Mtetra
.63048 .07147 .63282 .07481 .63754 .073 .63521 .06966 Mtetra
.63521 .06966 .63754 .073 .64227 .0712 .63994 .06785 Mtetra
.63994 .06785 .64227 .0712 .64701 .06939 .64468 .06604 Mtetra
.64468 .06604 .64701 .06939 .65175 .06757 .64943 .06422 Mtetra
.64943 .06422 .65175 .06757 .6565 .06576 .65419 .0624 Mtetra
.65419 .0624 .6565 .06576 .66126 .06394 .65896 .06057 Mtetra
.65896 .06057 .66126 .06394 .66603 .06212 .66373 .05874 Mtetra
.66373 .05874 .66603 .06212 .67081 .06029 .66851 .05691 Mtetra
.66851 .05691 .67081 .06029 .67559 .05846 .6733 .05508 Mtetra
.6733 .05508 .67559 .05846 .68039 .05663 .6781 .05324 Mtetra
.6781 .05324 .68039 .05663 .68519 .0548 .68291 .0514 Mtetra
.68291 .0514 .68519 .0548 .69 .05296 .68772 .04956 Mtetra
.68772 .04956 .69 .05296 .69482 .05112 .69254 .04771 Mtetra
.69254 .04771 .69482 .05112 .69964 .04927 .69738 .04586 Mtetra
.69738 .04586 .69964 .04927 .70447 .04743 .70222 .04401 Mtetra
.70222 .04401 .70447 .04743 .70932 .04558 .70706 .04215 Mtetra
.70706 .04215 .70932 .04558 .71417 .04372 .71192 .04029 Mtetra
.06283 .285 .06574 .28771 .06956 .28624 .06666 .28354 Mtetra
.06666 .28354 .06956 .28624 .07338 .28478 .07049 .28207 Mtetra
.07049 .28207 .07338 .28478 .07722 .28331 .07432 .2806 Mtetra
.07432 .2806 .07722 .28331 .08106 .28184 .07817 .27912 Mtetra
.07817 .27912 .08106 .28184 .0849 .28037 .08201 .27765 Mtetra
.08201 .27765 .0849 .28037 .08875 .2789 .08587 .27617 Mtetra
.08587 .27617 .08875 .2789 .09261 .27742 .08973 .27469 Mtetra
.08973 .27469 .09261 .27742 .09647 .27594 .09359 .2732 Mtetra
.09359 .2732 .09647 .27594 .10034 .27446 .09746 .27172 Mtetra
.09746 .27172 .10034 .27446 .10421 .27298 .10134 .27023 Mtetra
.10134 .27023 .10421 .27298 .10809 .27149 .10522 .26874 Mtetra
.10522 .26874 .10809 .27149 .11198 .27 .10911 .26725 Mtetra
.10911 .26725 .11198 .27 .11587 .26851 .11301 .26576 Mtetra
.11301 .26576 .11587 .26851 .11977 .26702 .11691 .26426 Mtetra
.11691 .26426 .11977 .26702 .12367 .26553 .12082 .26276 Mtetra
.12082 .26276 .12367 .26553 .12758 .26403 .12473 .26126 Mtetra
.12473 .26126 .12758 .26403 .1315 .26253 .12865 .25976 Mtetra
.12865 .25976 .1315 .26253 .13542 .26103 .13257 .25825 Mtetra
.13257 .25825 .13542 .26103 .13934 .25952 .1365 .25674 Mtetra
.1365 .25674 .13934 .25952 .14328 .25802 .14044 .25523 Mtetra
.14044 .25523 .14328 .25802 .14722 .25651 .14438 .25372 Mtetra
.14438 .25372 .14722 .25651 .15116 .255 .14833 .2522 Mtetra
.14833 .2522 .15116 .255 .15512 .25348 .15229 .25069 Mtetra
.15229 .25069 .15512 .25348 .15907 .25197 .15625 .24917 Mtetra
.15625 .24917 .15907 .25197 .16304 .25045 .16022 .24764 Mtetra
.16022 .24764 .16304 .25045 .16701 .24893 .16419 .24612 Mtetra
.16419 .24612 .16701 .24893 .17099 .24741 .16817 .24459 Mtetra
.16817 .24459 .17099 .24741 .17497 .24588 .17216 .24306 Mtetra
.17216 .24306 .17497 .24588 .17896 .24436 .17615 .24153 Mtetra
.17615 .24153 .17896 .24436 .18295 .24283 .18015 .24 Mtetra
.18015 .24 .18295 .24283 .18695 .2413 .18415 .23846 Mtetra
.18415 .23846 .18695 .2413 .19096 .23976 .18816 .23692 Mtetra
.18816 .23692 .19096 .23976 .19497 .23822 .19218 .23538 Mtetra
.19218 .23538 .19497 .23822 .19899 .23668 .19621 .23384 Mtetra
.19621 .23384 .19899 .23668 .20302 .23514 .20024 .23229 Mtetra
.20024 .23229 .20302 .23514 .20705 .2336 .20427 .23074 Mtetra
.20427 .23074 .20705 .2336 .21109 .23205 .20831 .22919 Mtetra
.20831 .22919 .21109 .23205 .21514 .2305 .21236 .22764 Mtetra
.21236 .22764 .21514 .2305 .21919 .22895 .21642 .22608 Mtetra
.21642 .22608 .21919 .22895 .22324 .2274 .22048 .22453 Mtetra
.22048 .22453 .22324 .2274 .22731 .22584 .22455 .22296 Mtetra
.22455 .22296 .22731 .22584 .23138 .22429 .22862 .2214 Mtetra
.22862 .2214 .23138 .22429 .23546 .22272 .2327 .21984 Mtetra
.2327 .21984 .23546 .22272 .23954 .22116 .23679 .21827 Mtetra
.23679 .21827 .23954 .22116 .24363 .2196 .24088 .2167 Mtetra
.24088 .2167 .24363 .2196 .24772 .21803 .24498 .21513 Mtetra
.24498 .21513 .24772 .21803 .25183 .21646 .24909 .21355 Mtetra
.24909 .21355 .25183 .21646 .25593 .21488 .2532 .21197 Mtetra
.2532 .21197 .25593 .21488 .26005 .21331 .25732 .21039 Mtetra
.25732 .21039 .26005 .21331 .26375 .21662 .26144 .20881 Mtetra
.217 .26 .693 r
.26144 .20881 .26375 .21662 .26789 .21504 .26516 .21212 Mtetra
.663 .742 .908 r
.26516 .21212 .26789 .21504 .27203 .21346 .2693 .21053 Mtetra
.2693 .21053 .27203 .21346 .27617 .21188 .27345 .20894 Mtetra
.27345 .20894 .27617 .21188 .28033 .21029 .27761 .20735 Mtetra
.27761 .20735 .28033 .21029 .28449 .2087 .28178 .20576 Mtetra
.87 .769 .748 r
.28178 .20576 .28449 .2087 .28904 .20221 .28633 .19926 Mtetra
.664 .741 .908 r
.28633 .19926 .28904 .20221 .29321 .20061 .29051 .19766 Mtetra
.29051 .19766 .29321 .20061 .29738 .19901 .29468 .19606 Mtetra
.29468 .19606 .29738 .19901 .30156 .19741 .29887 .19445 Mtetra
.29887 .19445 .30156 .19741 .30575 .19581 .30306 .19284 Mtetra
.30306 .19284 .30575 .19581 .30994 .1942 .30726 .19123 Mtetra
.30726 .19123 .30994 .1942 .31414 .1926 .31146 .18962 Mtetra
.31146 .18962 .31414 .1926 .31835 .19098 .31567 .188 Mtetra
.31567 .188 .31835 .19098 .32256 .18937 .31989 .18639 Mtetra
.31989 .18639 .32256 .18937 .32679 .18776 .32412 .18476 Mtetra
.32412 .18476 .32679 .18776 .33101 .18614 .32835 .18314 Mtetra
.32835 .18314 .33101 .18614 .33525 .18452 .33259 .18152 Mtetra
.33259 .18152 .33525 .18452 .33949 .18289 .33683 .17989 Mtetra
.33683 .17989 .33949 .18289 .34374 .18126 .34108 .17826 Mtetra
.34108 .17826 .34374 .18126 .34799 .17964 .34534 .17662 Mtetra
.34534 .17662 .34799 .17964 .35225 .178 .34961 .17499 Mtetra
.34961 .17499 .35225 .178 .35652 .17637 .35388 .17335 Mtetra
.35388 .17335 .35652 .17637 .3608 .17473 .35816 .1717 Mtetra
.35816 .1717 .3608 .17473 .36508 .17309 .36245 .17006 Mtetra
.36245 .17006 .36508 .17309 .36937 .17145 .36674 .16841 Mtetra
.36674 .16841 .36937 .17145 .37366 .16981 .37104 .16676 Mtetra
.37104 .16676 .37366 .16981 .37796 .16816 .37535 .16511 Mtetra
.37535 .16511 .37796 .16816 .38227 .16651 .37966 .16346 Mtetra
.37966 .16346 .38227 .16651 .38659 .16486 .38398 .1618 Mtetra
.38398 .1618 .38659 .16486 .39091 .1632 .38831 .16014 Mtetra
.38831 .16014 .39091 .1632 .39524 .16154 .39264 .15847 Mtetra
.39264 .15847 .39524 .16154 .39958 .15988 .39698 .15681 Mtetra
0 .178 .692 r
.39698 .15681 .39958 .15988 .40373 .16315 .40113 .16008 Mtetra
.663 .742 .908 r
.40113 .16008 .40373 .16315 .40808 .16149 .40549 .15841 Mtetra
.40549 .15841 .40808 .16149 .41245 .15982 .40986 .15673 Mtetra
.40986 .15673 .41245 .15982 .41682 .15815 .41424 .15506 Mtetra
.41424 .15506 .41682 .15815 .4212 .15648 .41862 .15338 Mtetra
.41862 .15338 .4212 .15648 .42559 .1548 .42301 .1517 Mtetra
.42301 .1517 .42559 .1548 .42998 .15312 .42741 .15002 Mtetra
.42741 .15002 .42998 .15312 .43438 .15144 .43182 .14833 Mtetra
.43182 .14833 .43438 .15144 .43879 .14976 .43623 .14664 Mtetra
.43623 .14664 .43879 .14976 .44321 .14807 .44065 .14495 Mtetra
.44065 .14495 .44321 .14807 .44763 .14638 .44508 .14326 Mtetra
.44508 .14326 .44763 .14638 .45206 .14469 .44951 .14156 Mtetra
.44951 .14156 .45206 .14469 .4565 .14299 .45396 .13986 Mtetra
.45396 .13986 .4565 .14299 .46094 .1413 .4584 .13816 Mtetra
.4584 .13816 .46094 .1413 .46539 .1396 .46286 .13645 Mtetra
.46286 .13645 .46539 .1396 .46985 .13789 .46732 .13474 Mtetra
.46732 .13474 .46985 .13789 .47432 .13619 .4718 .13303 Mtetra
.4718 .13303 .47432 .13619 .47879 .13448 .47627 .13132 Mtetra
.47627 .13132 .47879 .13448 .48327 .13277 .48076 .1296 Mtetra
.48076 .1296 .48327 .13277 .48776 .13105 .48525 .12788 Mtetra
.48525 .12788 .48776 .13105 .49226 .12933 .48975 .12616 Mtetra
.48975 .12616 .49226 .12933 .49676 .12761 .49426 .12443 Mtetra
.49426 .12443 .49676 .12761 .50127 .12589 .49878 .1227 Mtetra
.884 .786 .748 r
.49878 .1227 .50127 .12589 .50582 .1192 .50334 .11601 Mtetra
.664 .741 .908 r
.50334 .11601 .50582 .1192 .51034 .11747 .50786 .11427 Mtetra
.50786 .11427 .51034 .11747 .51487 .11574 .51239 .11253 Mtetra
.51239 .11253 .51487 .11574 .5194 .11401 .51693 .11079 Mtetra
.51693 .11079 .5194 .11401 .52394 .11227 .52147 .10905 Mtetra
.52147 .10905 .52394 .11227 .52849 .11053 .52603 .1073 Mtetra
.52603 .1073 .52849 .11053 .53304 .10878 .53059 .10555 Mtetra
.53059 .10555 .53304 .10878 .53761 .10703 .53515 .1038 Mtetra
.53515 .1038 .53761 .10703 .54218 .10528 .53973 .10205 Mtetra
.53973 .10205 .54218 .10528 .54675 .10353 .54431 .10029 Mtetra
.54431 .10029 .54675 .10353 .55134 .10178 .5489 .09853 Mtetra
.5489 .09853 .55134 .10178 .55593 .10002 .5535 .09676 Mtetra
.5535 .09676 .55593 .10002 .56054 .09826 .55811 .095 Mtetra
.55811 .095 .56054 .09826 .56514 .09649 .56272 .09323 Mtetra
.56272 .09323 .56514 .09649 .56976 .09472 .56734 .09145 Mtetra
.56734 .09145 .56976 .09472 .57438 .09295 .57197 .08968 Mtetra
.57197 .08968 .57438 .09295 .57902 .09118 .57661 .0879 Mtetra
.57661 .0879 .57902 .09118 .58366 .0894 .58125 .08612 Mtetra
.58125 .08612 .58366 .0894 .5883 .08762 .58591 .08433 Mtetra
.58591 .08433 .5883 .08762 .59296 .08584 .59057 .08254 Mtetra
.59057 .08254 .59296 .08584 .59762 .08406 .59523 .08075 Mtetra
.59523 .08075 .59762 .08406 .60229 .08227 .59991 .07896 Mtetra
.59991 .07896 .60229 .08227 .60697 .08048 .60459 .07716 Mtetra
.60459 .07716 .60697 .08048 .61166 .07868 .60929 .07536 Mtetra
.60929 .07536 .61166 .07868 .61635 .07688 .61399 .07356 Mtetra
.61399 .07356 .61635 .07688 .62105 .07508 .61869 .07175 Mtetra
.61869 .07175 .62105 .07508 .62576 .07328 .62341 .06994 Mtetra
.62341 .06994 .62576 .07328 .63048 .07147 .62813 .06813 Mtetra
.62813 .06813 .63048 .07147 .63521 .06966 .63286 .06632 Mtetra
.63286 .06632 .63521 .06966 .63994 .06785 .6376 .0645 Mtetra
.6376 .0645 .63994 .06785 .64468 .06604 .64235 .06268 Mtetra
.64235 .06268 .64468 .06604 .64943 .06422 .6471 .06085 Mtetra
.6471 .06085 .64943 .06422 .65419 .0624 .65187 .05902 Mtetra
.65187 .05902 .65419 .0624 .65896 .06057 .65664 .05719 Mtetra
.65664 .05719 .65896 .06057 .66373 .05874 .66142 .05536 Mtetra
.66142 .05536 .66373 .05874 .66851 .05691 .66621 .05352 Mtetra
.66621 .05352 .66851 .05691 .6733 .05508 .671 .05168 Mtetra
.671 .05168 .6733 .05508 .6781 .05324 .67581 .04984 Mtetra
.67581 .04984 .6781 .05324 .68291 .0514 .68062 .04799 Mtetra
.68062 .04799 .68291 .0514 .68772 .04956 .68544 .04615 Mtetra
.68544 .04615 .68772 .04956 .69254 .04771 .69027 .04429 Mtetra
.69027 .04429 .69254 .04771 .69738 .04586 .6951 .04244 Mtetra
.6951 .04244 .69738 .04586 .70222 .04401 .69995 .04058 Mtetra
.69995 .04058 .70222 .04401 .70706 .04215 .7048 .03872 Mtetra
.7048 .03872 .70706 .04215 .71192 .04029 .70966 .03685 Mtetra
.05992 .28229 .06283 .285 .06666 .28354 .06375 .28082 Mtetra
.06375 .28082 .06666 .28354 .07049 .28207 .06758 .27935 Mtetra
.06758 .27935 .07049 .28207 .07432 .2806 .07142 .27787 Mtetra
.07142 .27787 .07432 .2806 .07817 .27912 .07527 .2764 Mtetra
.07527 .2764 .07817 .27912 .08201 .27765 .07912 .27492 Mtetra
.07912 .27492 .08201 .27765 .08587 .27617 .08298 .27343 Mtetra
.08298 .27343 .08587 .27617 .08973 .27469 .08684 .27195 Mtetra
.08684 .27195 .08973 .27469 .09359 .2732 .09071 .27046 Mtetra
.09071 .27046 .09359 .2732 .09746 .27172 .09458 .26897 Mtetra
.09458 .26897 .09746 .27172 .10134 .27023 .09846 .26748 Mtetra
.09846 .26748 .10134 .27023 .10522 .26874 .10235 .26599 Mtetra
.10235 .26599 .10522 .26874 .10911 .26725 .10624 .26449 Mtetra
.10624 .26449 .10911 .26725 .11301 .26576 .11014 .26299 Mtetra
.11014 .26299 .11301 .26576 .11691 .26426 .11404 .26149 Mtetra
.11404 .26149 .11691 .26426 .12082 .26276 .11795 .25999 Mtetra
.11795 .25999 .12082 .26276 .12473 .26126 .12187 .25848 Mtetra
.12187 .25848 .12473 .26126 .12865 .25976 .12579 .25697 Mtetra
.12579 .25697 .12865 .25976 .13257 .25825 .12972 .25546 Mtetra
.12972 .25546 .13257 .25825 .1365 .25674 .13366 .25395 Mtetra
.13366 .25395 .1365 .25674 .14044 .25523 .1376 .25244 Mtetra
.1376 .25244 .14044 .25523 .14438 .25372 .14154 .25092 Mtetra
.14154 .25092 .14438 .25372 .14833 .2522 .1455 .2494 Mtetra
.1455 .2494 .14833 .2522 .15229 .25069 .14945 .24788 Mtetra
.14945 .24788 .15229 .25069 .15625 .24917 .15342 .24635 Mtetra
.15342 .24635 .15625 .24917 .16022 .24764 .15739 .24483 Mtetra
.15739 .24483 .16022 .24764 .16419 .24612 .16137 .2433 Mtetra
.16137 .2433 .16419 .24612 .16817 .24459 .16535 .24177 Mtetra
.16535 .24177 .16817 .24459 .17216 .24306 .16934 .24023 Mtetra
.16934 .24023 .17216 .24306 .17615 .24153 .17334 .2387 Mtetra
.17334 .2387 .17615 .24153 .18015 .24 .17734 .23716 Mtetra
.17734 .23716 .18015 .24 .18415 .23846 .18135 .23562 Mtetra
.18135 .23562 .18415 .23846 .18816 .23692 .18536 .23407 Mtetra
.18536 .23407 .18816 .23692 .19218 .23538 .18938 .23253 Mtetra
.18938 .23253 .19218 .23538 .19621 .23384 .19341 .23098 Mtetra
.19341 .23098 .19621 .23384 .20024 .23229 .19744 .22943 Mtetra
.19744 .22943 .20024 .23229 .20427 .23074 .20148 .22788 Mtetra
.20148 .22788 .20427 .23074 .20831 .22919 .20553 .22632 Mtetra
.20553 .22632 .20831 .22919 .21236 .22764 .20958 .22476 Mtetra
.20958 .22476 .21236 .22764 .21642 .22608 .21364 .2232 Mtetra
.21364 .2232 .21642 .22608 .22048 .22453 .2177 .22164 Mtetra
.2177 .22164 .22048 .22453 .22455 .22296 .22178 .22008 Mtetra
.22178 .22008 .22455 .22296 .22862 .2214 .22585 .21851 Mtetra
.22585 .21851 .22862 .2214 .2327 .21984 .22994 .21694 Mtetra
.22994 .21694 .2327 .21984 .23679 .21827 .23403 .21537 Mtetra
.23403 .21537 .23679 .21827 .24088 .2167 .23812 .21379 Mtetra
.23812 .21379 .24088 .2167 .24498 .21513 .24223 .21221 Mtetra
.24223 .21221 .24498 .21513 .24909 .21355 .24634 .21064 Mtetra
.24634 .21064 .24909 .21355 .2532 .21197 .25045 .20905 Mtetra
.25045 .20905 .2532 .21197 .25732 .21039 .25458 .20747 Mtetra
.25458 .20747 .25732 .21039 .26144 .20881 .25871 .20588 Mtetra
.25871 .20588 .26144 .20881 .26516 .21212 .26284 .20429 Mtetra
.217 .26 .693 r
.26284 .20429 .26516 .21212 .2693 .21053 .26657 .2076 Mtetra
.663 .742 .908 r
.26657 .2076 .2693 .21053 .27345 .20894 .27072 .206 Mtetra
.27072 .206 .27345 .20894 .27761 .20735 .27488 .20441 Mtetra
.87 .768 .748 r
.27488 .20441 .27761 .20735 .28178 .20576 .27945 .19791 Mtetra
.608 .51 .718 r
.27945 .19791 .28178 .20576 .28633 .19926 .28362 .1963 Mtetra
.664 .741 .908 r
.28362 .1963 .28633 .19926 .29051 .19766 .2878 .1947 Mtetra
.2878 .1947 .29051 .19766 .29468 .19606 .29198 .19309 Mtetra
.29198 .19309 .29468 .19606 .29887 .19445 .29617 .19148 Mtetra
.29617 .19148 .29887 .19445 .30306 .19284 .30036 .18987 Mtetra
.30036 .18987 .30306 .19284 .30726 .19123 .30456 .18825 Mtetra
.30456 .18825 .30726 .19123 .31146 .18962 .30877 .18663 Mtetra
.30877 .18663 .31146 .18962 .31567 .188 .31299 .18501 Mtetra
.31299 .18501 .31567 .188 .31989 .18639 .31721 .18339 Mtetra
.31721 .18339 .31989 .18639 .32412 .18476 .32144 .18177 Mtetra
.32144 .18177 .32412 .18476 .32835 .18314 .32568 .18014 Mtetra
.32568 .18014 .32835 .18314 .33259 .18152 .32992 .17851 Mtetra
.32992 .17851 .33259 .18152 .33683 .17989 .33417 .17687 Mtetra
.33417 .17687 .33683 .17989 .34108 .17826 .33842 .17524 Mtetra
.33842 .17524 .34108 .17826 .34534 .17662 .34269 .1736 Mtetra
.34269 .1736 .34534 .17662 .34961 .17499 .34696 .17196 Mtetra
.34696 .17196 .34961 .17499 .35388 .17335 .35123 .17031 Mtetra
.35123 .17031 .35388 .17335 .35816 .1717 .35552 .16867 Mtetra
.35552 .16867 .35816 .1717 .36245 .17006 .35981 .16702 Mtetra
.35981 .16702 .36245 .17006 .36674 .16841 .3641 .16537 Mtetra
.3641 .16537 .36674 .16841 .37104 .16676 .36841 .16371 Mtetra
.36841 .16371 .37104 .16676 .37535 .16511 .37272 .16205 Mtetra
.37272 .16205 .37535 .16511 .37966 .16346 .37704 .16039 Mtetra
.37704 .16039 .37966 .16346 .38398 .1618 .38136 .15873 Mtetra
.38136 .15873 .38398 .1618 .38831 .16014 .38569 .15707 Mtetra
.38569 .15707 .38831 .16014 .39264 .15847 .39003 .1554 Mtetra
.39003 .1554 .39264 .15847 .39698 .15681 .39438 .15373 Mtetra
0 .178 .692 r
.39438 .15373 .39698 .15681 .40113 .16008 .39852 .15699 Mtetra
.663 .742 .908 r
.39852 .15699 .40113 .16008 .40549 .15841 .40289 .15532 Mtetra
.40289 .15532 .40549 .15841 .40986 .15673 .40727 .15364 Mtetra
.40727 .15364 .40986 .15673 .41424 .15506 .41165 .15196 Mtetra
.41165 .15196 .41424 .15506 .41862 .15338 .41604 .15028 Mtetra
.41604 .15028 .41862 .15338 .42301 .1517 .42043 .14859 Mtetra
.42043 .14859 .42301 .1517 .42741 .15002 .42483 .1469 Mtetra
.42483 .1469 .42741 .15002 .43182 .14833 .42925 .14521 Mtetra
.42925 .14521 .43182 .14833 .43623 .14664 .43366 .14352 Mtetra
.43366 .14352 .43623 .14664 .44065 .14495 .43809 .14182 Mtetra
.43809 .14182 .44065 .14495 .44508 .14326 .44252 .14012 Mtetra
.44252 .14012 .44508 .14326 .44951 .14156 .44696 .13842 Mtetra
.44696 .13842 .44951 .14156 .45396 .13986 .45141 .13671 Mtetra
.45141 .13671 .45396 .13986 .4584 .13816 .45586 .135 Mtetra
.45586 .135 .4584 .13816 .46286 .13645 .46032 .13329 Mtetra
.46032 .13329 .46286 .13645 .46732 .13474 .46479 .13158 Mtetra
.46479 .13158 .46732 .13474 .4718 .13303 .46926 .12986 Mtetra
.46926 .12986 .4718 .13303 .47627 .13132 .47375 .12814 Mtetra
.47375 .12814 .47627 .13132 .48076 .1296 .47824 .12642 Mtetra
.47824 .12642 .48076 .1296 .48525 .12788 .48274 .1247 Mtetra
.48274 .1247 .48525 .12788 .48975 .12616 .48724 .12297 Mtetra
.48724 .12297 .48975 .12616 .49426 .12443 .49175 .12124 Mtetra
.49175 .12124 .49426 .12443 .49878 .1227 .49627 .1195 Mtetra
.884 .786 .748 r
.49627 .1195 .49878 .1227 .50334 .11601 .50084 .1128 Mtetra
.664 .741 .908 r
.50084 .1128 .50334 .11601 .50786 .11427 .50537 .11106 Mtetra
.50537 .11106 .50786 .11427 .51239 .11253 .50991 .10932 Mtetra
.50991 .10932 .51239 .11253 .51693 .11079 .51445 .10757 Mtetra
.51445 .10757 .51693 .11079 .52147 .10905 .519 .10582 Mtetra
.519 .10582 .52147 .10905 .52603 .1073 .52356 .10407 Mtetra
.52356 .10407 .52603 .1073 .53059 .10555 .52812 .10232 Mtetra
.52812 .10232 .53059 .10555 .53515 .1038 .53269 .10056 Mtetra
.53269 .10056 .53515 .1038 .53973 .10205 .53727 .0988 Mtetra
.53727 .0988 .53973 .10205 .54431 .10029 .54186 .09703 Mtetra
.54186 .09703 .54431 .10029 .5489 .09853 .54646 .09527 Mtetra
.54646 .09527 .5489 .09853 .5535 .09676 .55106 .0935 Mtetra
.55106 .0935 .5535 .09676 .55811 .095 .55567 .09173 Mtetra
.55567 .09173 .55811 .095 .56272 .09323 .56029 .08995 Mtetra
.56029 .08995 .56272 .09323 .56734 .09145 .56492 .08817 Mtetra
.56492 .08817 .56734 .09145 .57197 .08968 .56955 .08639 Mtetra
.56955 .08639 .57197 .08968 .57661 .0879 .57419 .08461 Mtetra
.57419 .08461 .57661 .0879 .58125 .08612 .57884 .08282 Mtetra
.57884 .08282 .58125 .08612 .58591 .08433 .5835 .08103 Mtetra
.5835 .08103 .58591 .08433 .59057 .08254 .58817 .07923 Mtetra
.58817 .07923 .59057 .08254 .59523 .08075 .59284 .07744 Mtetra
.59284 .07744 .59523 .08075 .59991 .07896 .59752 .07564 Mtetra
.59752 .07564 .59991 .07896 .60459 .07716 .60221 .07384 Mtetra
.60221 .07384 .60459 .07716 .60929 .07536 .60691 .07203 Mtetra
.60691 .07203 .60929 .07536 .61399 .07356 .61161 .07022 Mtetra
.61161 .07022 .61399 .07356 .61869 .07175 .61633 .06841 Mtetra
.61633 .06841 .61869 .07175 .62341 .06994 .62105 .0666 Mtetra
.62105 .0666 .62341 .06994 .62813 .06813 .62577 .06478 Mtetra
.62577 .06478 .62813 .06813 .63286 .06632 .63051 .06296 Mtetra
.63051 .06296 .63286 .06632 .6376 .0645 .63526 .06113 Mtetra
.63526 .06113 .6376 .0645 .64235 .06268 .64001 .05931 Mtetra
.64001 .05931 .64235 .06268 .6471 .06085 .64477 .05748 Mtetra
.64477 .05748 .6471 .06085 .65187 .05902 .64954 .05564 Mtetra
.64954 .05564 .65187 .05902 .65664 .05719 .65432 .05381 Mtetra
.65432 .05381 .65664 .05719 .66142 .05536 .6591 .05197 Mtetra
.6591 .05197 .66142 .05536 .66621 .05352 .66389 .05012 Mtetra
.66389 .05012 .66621 .05352 .671 .05168 .6687 .04828 Mtetra
.6687 .04828 .671 .05168 .67581 .04984 .67351 .04643 Mtetra
.67351 .04643 .67581 .04984 .68062 .04799 .67832 .04458 Mtetra
.67832 .04458 .68062 .04799 .68544 .04615 .68315 .04272 Mtetra
.68315 .04272 .68544 .04615 .69027 .04429 .68798 .04086 Mtetra
.68798 .04086 .69027 .04429 .6951 .04244 .69283 .039 Mtetra
.69283 .039 .6951 .04244 .69995 .04058 .69768 .03714 Mtetra
.69768 .03714 .69995 .04058 .7048 .03872 .70254 .03527 Mtetra
.70254 .03527 .7048 .03872 .70966 .03685 .7074 .0334 Mtetra
.057 .27958 .05992 .28229 .06375 .28082 .06083 .2781 Mtetra
.06083 .2781 .06375 .28082 .06758 .27935 .06467 .27662 Mtetra
.06467 .27662 .06758 .27935 .07142 .27787 .06851 .27514 Mtetra
.06851 .27514 .07142 .27787 .07527 .2764 .07236 .27366 Mtetra
.07236 .27366 .07527 .2764 .07912 .27492 .07622 .27218 Mtetra
.07622 .27218 .07912 .27492 .08298 .27343 .08008 .27069 Mtetra
.08008 .27069 .08298 .27343 .08684 .27195 .08394 .2692 Mtetra
.08394 .2692 .08684 .27195 .09071 .27046 .08781 .26771 Mtetra
.08781 .26771 .09071 .27046 .09458 .26897 .09169 .26622 Mtetra
.09169 .26622 .09458 .26897 .09846 .26748 .09557 .26472 Mtetra
.09557 .26472 .09846 .26748 .10235 .26599 .09946 .26322 Mtetra
.09946 .26322 .10235 .26599 .10624 .26449 .10336 .26172 Mtetra
.10336 .26172 .10624 .26449 .11014 .26299 .10726 .26022 Mtetra
.10726 .26022 .11014 .26299 .11404 .26149 .11117 .25871 Mtetra
.11117 .25871 .11404 .26149 .11795 .25999 .11508 .25721 Mtetra
.11508 .25721 .11795 .25999 .12187 .25848 .119 .2557 Mtetra
.119 .2557 .12187 .25848 .12579 .25697 .12293 .25418 Mtetra
.12293 .25418 .12579 .25697 .12972 .25546 .12686 .25267 Mtetra
.12686 .25267 .12972 .25546 .13366 .25395 .1308 .25115 Mtetra
.1308 .25115 .13366 .25395 .1376 .25244 .13474 .24963 Mtetra
.13474 .24963 .1376 .25244 .14154 .25092 .13869 .24811 Mtetra
.13869 .24811 .14154 .25092 .1455 .2494 .14265 .24659 Mtetra
.14265 .24659 .1455 .2494 .14945 .24788 .14661 .24506 Mtetra
.14661 .24506 .14945 .24788 .15342 .24635 .15058 .24353 Mtetra
.15058 .24353 .15342 .24635 .15739 .24483 .15455 .242 Mtetra
.15455 .242 .15739 .24483 .16137 .2433 .15853 .24047 Mtetra
.15853 .24047 .16137 .2433 .16535 .24177 .16252 .23893 Mtetra
.16252 .23893 .16535 .24177 .16934 .24023 .16651 .2374 Mtetra
.16651 .2374 .16934 .24023 .17334 .2387 .17051 .23586 Mtetra
.17051 .23586 .17334 .2387 .17734 .23716 .17452 .23431 Mtetra
.17452 .23431 .17734 .23716 .18135 .23562 .17853 .23277 Mtetra
.17853 .23277 .18135 .23562 .18536 .23407 .18255 .23122 Mtetra
.18255 .23122 .18536 .23407 .18938 .23253 .18657 .22967 Mtetra
.18657 .22967 .18938 .23253 .19341 .23098 .1906 .22812 Mtetra
.1906 .22812 .19341 .23098 .19744 .22943 .19464 .22656 Mtetra
.19464 .22656 .19744 .22943 .20148 .22788 .19869 .225 Mtetra
.19869 .225 .20148 .22788 .20553 .22632 .20273 .22344 Mtetra
.20273 .22344 .20553 .22632 .20958 .22476 .20679 .22188 Mtetra
.20679 .22188 .20958 .22476 .21364 .2232 .21085 .22032 Mtetra
.21085 .22032 .21364 .2232 .2177 .22164 .21492 .21875 Mtetra
.21492 .21875 .2177 .22164 .22178 .22008 .219 .21718 Mtetra
.219 .21718 .22178 .22008 .22585 .21851 .22308 .21561 Mtetra
.22308 .21561 .22585 .21851 .22994 .21694 .22717 .21403 Mtetra
.22717 .21403 .22994 .21694 .23403 .21537 .23126 .21246 Mtetra
.23126 .21246 .23403 .21537 .23812 .21379 .23536 .21088 Mtetra
.23536 .21088 .23812 .21379 .24223 .21221 .23947 .2093 Mtetra
.23947 .2093 .24223 .21221 .24634 .21064 .24358 .20771 Mtetra
.24358 .20771 .24634 .21064 .25045 .20905 .2477 .20612 Mtetra
.2477 .20612 .25045 .20905 .25458 .20747 .25183 .20454 Mtetra
.25183 .20454 .25458 .20747 .25871 .20588 .25596 .20294 Mtetra
.25596 .20294 .25871 .20588 .26284 .20429 .2601 .20135 Mtetra
.2601 .20135 .26284 .20429 .26657 .2076 .26425 .19975 Mtetra
.217 .26 .693 r
.26425 .19975 .26657 .2076 .27072 .206 .26799 .20306 Mtetra
.869 .768 .748 r
.26799 .20306 .27072 .206 .27488 .20441 .27256 .19655 Mtetra
.608 .51 .718 r
.27256 .19655 .27488 .20441 .27945 .19791 .27673 .19495 Mtetra
.664 .741 .908 r
.27673 .19495 .27945 .19791 .28362 .1963 .2809 .19334 Mtetra
.2809 .19334 .28362 .1963 .2878 .1947 .28508 .19173 Mtetra
.28508 .19173 .2878 .1947 .29198 .19309 .28927 .19012 Mtetra
.28927 .19012 .29198 .19309 .29617 .19148 .29346 .1885 Mtetra
.29346 .1885 .29617 .19148 .30036 .18987 .29766 .18688 Mtetra
.29766 .18688 .30036 .18987 .30456 .18825 .30186 .18526 Mtetra
.30186 .18526 .30456 .18825 .30877 .18663 .30608 .18364 Mtetra
.30608 .18364 .30877 .18663 .31299 .18501 .3103 .18202 Mtetra
.3103 .18202 .31299 .18501 .31721 .18339 .31452 .18039 Mtetra
.31452 .18039 .31721 .18339 .32144 .18177 .31876 .17876 Mtetra
.31876 .17876 .32144 .18177 .32568 .18014 .32299 .17712 Mtetra
.32299 .17712 .32568 .18014 .32992 .17851 .32724 .17549 Mtetra
.32724 .17549 .32992 .17851 .33417 .17687 .33149 .17385 Mtetra
.33149 .17385 .33417 .17687 .33842 .17524 .33576 .17221 Mtetra
.33576 .17221 .33842 .17524 .34269 .1736 .34002 .17057 Mtetra
.34002 .17057 .34269 .1736 .34696 .17196 .3443 .16892 Mtetra
.3443 .16892 .34696 .17196 .35123 .17031 .34858 .16727 Mtetra
.34858 .16727 .35123 .17031 .35552 .16867 .35286 .16562 Mtetra
.35286 .16562 .35552 .16867 .35981 .16702 .35716 .16397 Mtetra
.35716 .16397 .35981 .16702 .3641 .16537 .36146 .16231 Mtetra
.36146 .16231 .3641 .16537 .36841 .16371 .36577 .16065 Mtetra
.36577 .16065 .36841 .16371 .37272 .16205 .37009 .15899 Mtetra
.37009 .15899 .37272 .16205 .37704 .16039 .37441 .15732 Mtetra
.37441 .15732 .37704 .16039 .38136 .15873 .37874 .15565 Mtetra
.37874 .15565 .38136 .15873 .38569 .15707 .38307 .15398 Mtetra
.38307 .15398 .38569 .15707 .39003 .1554 .38742 .15231 Mtetra
.38742 .15231 .39003 .1554 .39438 .15373 .39177 .15064 Mtetra
0 .178 .692 r
.39177 .15064 .39438 .15373 .39852 .15699 .39591 .1539 Mtetra
.663 .742 .908 r
.39591 .1539 .39852 .15699 .40289 .15532 .40028 .15222 Mtetra
.40028 .15222 .40289 .15532 .40727 .15364 .40466 .15054 Mtetra
.40466 .15054 .40727 .15364 .41165 .15196 .40905 .14885 Mtetra
.40905 .14885 .41165 .15196 .41604 .15028 .41344 .14716 Mtetra
.41344 .14716 .41604 .15028 .42043 .14859 .41784 .14547 Mtetra
.41784 .14547 .42043 .14859 .42483 .1469 .42225 .14378 Mtetra
.42225 .14378 .42483 .1469 .42925 .14521 .42666 .14208 Mtetra
.42666 .14208 .42925 .14521 .43366 .14352 .43109 .14038 Mtetra
.43109 .14038 .43366 .14352 .43809 .14182 .43552 .13868 Mtetra
.43552 .13868 .43809 .14182 .44252 .14012 .43995 .13697 Mtetra
.43995 .13697 .44252 .14012 .44696 .13842 .4444 .13527 Mtetra
.4444 .13527 .44696 .13842 .45141 .13671 .44885 .13356 Mtetra
.44885 .13356 .45141 .13671 .45586 .135 .45331 .13184 Mtetra
.45331 .13184 .45586 .135 .46032 .13329 .45777 .13013 Mtetra
.45777 .13013 .46032 .13329 .46479 .13158 .46224 .12841 Mtetra
.46224 .12841 .46479 .13158 .46926 .12986 .46672 .12669 Mtetra
.46672 .12669 .46926 .12986 .47375 .12814 .47121 .12496 Mtetra
.47121 .12496 .47375 .12814 .47824 .12642 .47571 .12324 Mtetra
.47571 .12324 .47824 .12642 .48274 .1247 .48021 .1215 Mtetra
.48021 .1215 .48274 .1247 .48724 .12297 .48472 .11977 Mtetra
.48472 .11977 .48724 .12297 .49175 .12124 .48924 .11804 Mtetra
.48924 .11804 .49175 .12124 .49627 .1195 .49376 .1163 Mtetra
.884 .786 .748 r
.49376 .1163 .49627 .1195 .50084 .1128 .49834 .10959 Mtetra
.664 .741 .908 r
.49834 .10959 .50084 .1128 .50537 .11106 .50287 .10784 Mtetra
.50287 .10784 .50537 .11106 .50991 .10932 .50741 .10609 Mtetra
.50741 .10609 .50991 .10932 .51445 .10757 .51196 .10434 Mtetra
.51196 .10434 .51445 .10757 .519 .10582 .51652 .10259 Mtetra
.51652 .10259 .519 .10582 .52356 .10407 .52108 .10083 Mtetra
.52108 .10083 .52356 .10407 .52812 .10232 .52565 .09907 Mtetra
.52565 .09907 .52812 .10232 .53269 .10056 .53023 .09731 Mtetra
.53023 .09731 .53269 .10056 .53727 .0988 .53481 .09554 Mtetra
.53481 .09554 .53727 .0988 .54186 .09703 .53941 .09377 Mtetra
.53941 .09377 .54186 .09703 .54646 .09527 .54401 .092 Mtetra
.54401 .092 .54646 .09527 .55106 .0935 .54861 .09022 Mtetra
.54861 .09022 .55106 .0935 .55567 .09173 .55323 .08844 Mtetra
.55323 .08844 .55567 .09173 .56029 .08995 .55785 .08666 Mtetra
.55785 .08666 .56029 .08995 .56492 .08817 .56249 .08488 Mtetra
.56249 .08488 .56492 .08817 .56955 .08639 .56713 .08309 Mtetra
.56713 .08309 .56955 .08639 .57419 .08461 .57177 .0813 Mtetra
.57177 .0813 .57419 .08461 .57884 .08282 .57643 .07951 Mtetra
.57643 .07951 .57884 .08282 .5835 .08103 .58109 .07771 Mtetra
.58109 .07771 .5835 .08103 .58817 .07923 .58576 .07592 Mtetra
.58576 .07592 .58817 .07923 .59284 .07744 .59044 .07411 Mtetra
.59044 .07411 .59284 .07744 .59752 .07564 .59513 .07231 Mtetra
.59513 .07231 .59752 .07564 .60221 .07384 .59982 .0705 Mtetra
.59982 .0705 .60221 .07384 .60691 .07203 .60452 .06869 Mtetra
.60452 .06869 .60691 .07203 .61161 .07022 .60923 .06687 Mtetra
.60923 .06687 .61161 .07022 .61633 .06841 .61395 .06506 Mtetra
.61395 .06506 .61633 .06841 .62105 .0666 .61868 .06324 Mtetra
.61868 .06324 .62105 .0666 .62577 .06478 .62341 .06141 Mtetra
.62341 .06141 .62577 .06478 .63051 .06296 .62815 .05959 Mtetra
.62815 .05959 .63051 .06296 .63526 .06113 .6329 .05776 Mtetra
.6329 .05776 .63526 .06113 .64001 .05931 .63766 .05592 Mtetra
.63766 .05592 .64001 .05931 .64477 .05748 .64243 .05409 Mtetra
.64243 .05409 .64477 .05748 .64954 .05564 .6472 .05225 Mtetra
.6472 .05225 .64954 .05564 .65432 .05381 .65198 .05041 Mtetra
.65198 .05041 .65432 .05381 .6591 .05197 .65678 .04856 Mtetra
.65678 .04856 .6591 .05197 .66389 .05012 .66157 .04671 Mtetra
.66157 .04671 .66389 .05012 .6687 .04828 .66638 .04486 Mtetra
.66638 .04486 .6687 .04828 .67351 .04643 .6712 .04301 Mtetra
.6712 .04301 .67351 .04643 .67832 .04458 .67602 .04115 Mtetra
.67602 .04115 .67832 .04458 .68315 .04272 .68085 .03929 Mtetra
.68085 .03929 .68315 .04272 .68798 .04086 .68569 .03743 Mtetra
.68569 .03743 .68798 .04086 .69283 .039 .69054 .03556 Mtetra
.69054 .03556 .69283 .039 .69768 .03714 .6954 .03369 Mtetra
.6954 .03369 .69768 .03714 .70254 .03527 .70026 .03181 Mtetra
.70026 .03181 .70254 .03527 .7074 .0334 .70513 .02994 Mtetra
.05408 .27685 .057 .27958 .06083 .2781 .05791 .27537 Mtetra
.05791 .27537 .06083 .2781 .06467 .27662 .06175 .27389 Mtetra
.06175 .27389 .06467 .27662 .06851 .27514 .06559 .2724 Mtetra
.06559 .2724 .06851 .27514 .07236 .27366 .06945 .27092 Mtetra
.06945 .27092 .07236 .27366 .07622 .27218 .0733 .26943 Mtetra
.0733 .26943 .07622 .27218 .08008 .27069 .07717 .26794 Mtetra
.07717 .26794 .08008 .27069 .08394 .2692 .08104 .26645 Mtetra
.08104 .26645 .08394 .2692 .08781 .26771 .08491 .26495 Mtetra
.08491 .26495 .08781 .26771 .09169 .26622 .08879 .26345 Mtetra
.08879 .26345 .09169 .26622 .09557 .26472 .09268 .26195 Mtetra
.09268 .26195 .09557 .26472 .09946 .26322 .09657 .26045 Mtetra
.09657 .26045 .09946 .26322 .10336 .26172 .10047 .25894 Mtetra
.10047 .25894 .10336 .26172 .10726 .26022 .10438 .25744 Mtetra
.10438 .25744 .10726 .26022 .11117 .25871 .10829 .25593 Mtetra
.10829 .25593 .11117 .25871 .11508 .25721 .1122 .25442 Mtetra
.1122 .25442 .11508 .25721 .119 .2557 .11613 .2529 Mtetra
.11613 .2529 .119 .2557 .12293 .25418 .12006 .25139 Mtetra
.12006 .25139 .12293 .25418 .12686 .25267 .12399 .24987 Mtetra
.12399 .24987 .12686 .25267 .1308 .25115 .12793 .24835 Mtetra
.12793 .24835 .1308 .25115 .13474 .24963 .13188 .24682 Mtetra
.13188 .24682 .13474 .24963 .13869 .24811 .13583 .2453 Mtetra
.13583 .2453 .13869 .24811 .14265 .24659 .13979 .24377 Mtetra
.13979 .24377 .14265 .24659 .14661 .24506 .14376 .24224 Mtetra
.14376 .24224 .14661 .24506 .15058 .24353 .14773 .24071 Mtetra
.14773 .24071 .15058 .24353 .15455 .242 .15171 .23917 Mtetra
.15171 .23917 .15455 .242 .15853 .24047 .15569 .23763 Mtetra
.15569 .23763 .15853 .24047 .16252 .23893 .15968 .23609 Mtetra
.15968 .23609 .16252 .23893 .16651 .2374 .16368 .23455 Mtetra
.16368 .23455 .16651 .2374 .17051 .23586 .16768 .23301 Mtetra
.16768 .23301 .17051 .23586 .17452 .23431 .17169 .23146 Mtetra
.17169 .23146 .17452 .23431 .17853 .23277 .17571 .22991 Mtetra
.17571 .22991 .17853 .23277 .18255 .23122 .17973 .22836 Mtetra
.17973 .22836 .18255 .23122 .18657 .22967 .18376 .2268 Mtetra
.18376 .2268 .18657 .22967 .1906 .22812 .18779 .22524 Mtetra
.18779 .22524 .1906 .22812 .19464 .22656 .19183 .22369 Mtetra
.19183 .22369 .19464 .22656 .19869 .225 .19588 .22212 Mtetra
.19588 .22212 .19869 .225 .20273 .22344 .19993 .22056 Mtetra
.19993 .22056 .20273 .22344 .20679 .22188 .20399 .21899 Mtetra
.20399 .21899 .20679 .22188 .21085 .22032 .20806 .21742 Mtetra
.20806 .21742 .21085 .22032 .21492 .21875 .21213 .21585 Mtetra
.21213 .21585 .21492 .21875 .219 .21718 .21621 .21428 Mtetra
.21621 .21428 .219 .21718 .22308 .21561 .2203 .2127 Mtetra
.2203 .2127 .22308 .21561 .22717 .21403 .22439 .21112 Mtetra
.22439 .21112 .22717 .21403 .23126 .21246 .22849 .20954 Mtetra
.22849 .20954 .23126 .21246 .23536 .21088 .23259 .20796 Mtetra
.23259 .20796 .23536 .21088 .23947 .2093 .2367 .20637 Mtetra
.2367 .20637 .23947 .2093 .24358 .20771 .24082 .20478 Mtetra
.24082 .20478 .24358 .20771 .2477 .20612 .24494 .20319 Mtetra
.24494 .20319 .2477 .20612 .25183 .20454 .24907 .20159 Mtetra
.24907 .20159 .25183 .20454 .25596 .20294 .25321 .2 Mtetra
.25321 .2 .25596 .20294 .2601 .20135 .25735 .1984 Mtetra
.25735 .1984 .2601 .20135 .26425 .19975 .2615 .1968 Mtetra
.2615 .1968 .26425 .19975 .26799 .20306 .26566 .19519 Mtetra
.608 .51 .718 r
.26566 .19519 .26799 .20306 .27256 .19655 .26982 .19359 Mtetra
.664 .741 .908 r
.26982 .19359 .27256 .19655 .27673 .19495 .27399 .19198 Mtetra
.27399 .19198 .27673 .19495 .2809 .19334 .27817 .19036 Mtetra
.27817 .19036 .2809 .19334 .28508 .19173 .28235 .18875 Mtetra
.28235 .18875 .28508 .19173 .28927 .19012 .28654 .18713 Mtetra
.28654 .18713 .28927 .19012 .29346 .1885 .29074 .18551 Mtetra
.29074 .18551 .29346 .1885 .29766 .18688 .29494 .18389 Mtetra
.29494 .18389 .29766 .18688 .30186 .18526 .29915 .18227 Mtetra
.29915 .18227 .30186 .18526 .30608 .18364 .30337 .18064 Mtetra
.30337 .18064 .30608 .18364 .3103 .18202 .30759 .17901 Mtetra
.30759 .17901 .3103 .18202 .31452 .18039 .31183 .17738 Mtetra
.31183 .17738 .31452 .18039 .31876 .17876 .31606 .17574 Mtetra
.31606 .17574 .31876 .17876 .32299 .17712 .32031 .1741 Mtetra
.32031 .1741 .32299 .17712 .32724 .17549 .32456 .17246 Mtetra
.32456 .17246 .32724 .17549 .33149 .17385 .32881 .17082 Mtetra
.32881 .17082 .33149 .17385 .33576 .17221 .33308 .16917 Mtetra
.33308 .16917 .33576 .17221 .34002 .17057 .33735 .16752 Mtetra
.33735 .16752 .34002 .17057 .3443 .16892 .34163 .16587 Mtetra
.34163 .16587 .3443 .16892 .34858 .16727 .34591 .16422 Mtetra
.34591 .16422 .34858 .16727 .35286 .16562 .35021 .16256 Mtetra
.35021 .16256 .35286 .16562 .35716 .16397 .3545 .1609 Mtetra
.3545 .1609 .35716 .16397 .36146 .16231 .35881 .15924 Mtetra
.35881 .15924 .36146 .16231 .36577 .16065 .36312 .15758 Mtetra
.36312 .15758 .36577 .16065 .37009 .15899 .36744 .15591 Mtetra
.36744 .15591 .37009 .15899 .37441 .15732 .37177 .15424 Mtetra
.37177 .15424 .37441 .15732 .37874 .15565 .3761 .15257 Mtetra
.3761 .15257 .37874 .15565 .38307 .15398 .38044 .15089 Mtetra
.38044 .15089 .38307 .15398 .38742 .15231 .38479 .14922 Mtetra
.38479 .14922 .38742 .15231 .39177 .15064 .38915 .14753 Mtetra
0 .178 .692 r
.38915 .14753 .39177 .15064 .39591 .1539 .39329 .15079 Mtetra
.663 .742 .908 r
.39329 .15079 .39591 .1539 .40028 .15222 .39767 .14911 Mtetra
.39767 .14911 .40028 .15222 .40466 .15054 .40205 .14742 Mtetra
.40205 .14742 .40466 .15054 .40905 .14885 .40644 .14573 Mtetra
.40644 .14573 .40905 .14885 .41344 .14716 .41084 .14404 Mtetra
.41084 .14404 .41344 .14716 .41784 .14547 .41524 .14234 Mtetra
.41524 .14234 .41784 .14547 .42225 .14378 .41966 .14064 Mtetra
.41966 .14064 .42225 .14378 .42666 .14208 .42407 .13894 Mtetra
.42407 .13894 .42666 .14208 .43109 .14038 .4285 .13724 Mtetra
.4285 .13724 .43109 .14038 .43552 .13868 .43294 .13553 Mtetra
.43294 .13553 .43552 .13868 .43995 .13697 .43738 .13382 Mtetra
.43738 .13382 .43995 .13697 .4444 .13527 .44182 .13211 Mtetra
.44182 .13211 .4444 .13527 .44885 .13356 .44628 .13039 Mtetra
.44628 .13039 .44885 .13356 .45331 .13184 .45074 .12867 Mtetra
.45074 .12867 .45331 .13184 .45777 .13013 .45521 .12695 Mtetra
.45521 .12695 .45777 .13013 .46224 .12841 .45969 .12523 Mtetra
.45969 .12523 .46224 .12841 .46672 .12669 .46418 .1235 Mtetra
.46418 .1235 .46672 .12669 .47121 .12496 .46867 .12177 Mtetra
.46867 .12177 .47121 .12496 .47571 .12324 .47317 .12004 Mtetra
.47317 .12004 .47571 .12324 .48021 .1215 .47768 .1183 Mtetra
.47768 .1183 .48021 .1215 .48472 .11977 .48219 .11656 Mtetra
.48219 .11656 .48472 .11977 .48924 .11804 .48671 .11482 Mtetra
.48671 .11482 .48924 .11804 .49376 .1163 .49124 .11308 Mtetra
.884 .786 .748 r
.49124 .11308 .49376 .1163 .49834 .10959 .49583 .10636 Mtetra
.664 .741 .908 r
.49583 .10636 .49834 .10959 .50287 .10784 .50037 .10461 Mtetra
.50037 .10461 .50287 .10784 .50741 .10609 .50491 .10286 Mtetra
.50491 .10286 .50741 .10609 .51196 .10434 .50947 .1011 Mtetra
.50947 .1011 .51196 .10434 .51652 .10259 .51403 .09934 Mtetra
.51403 .09934 .51652 .10259 .52108 .10083 .51859 .09758 Mtetra
.51859 .09758 .52108 .10083 .52565 .09907 .52317 .09581 Mtetra
.52317 .09581 .52565 .09907 .53023 .09731 .52775 .09404 Mtetra
.52775 .09404 .53023 .09731 .53481 .09554 .53234 .09227 Mtetra
.53234 .09227 .53481 .09554 .53941 .09377 .53694 .0905 Mtetra
.53694 .0905 .53941 .09377 .54401 .092 .54155 .08872 Mtetra
.54155 .08872 .54401 .092 .54861 .09022 .54616 .08694 Mtetra
.54616 .08694 .54861 .09022 .55323 .08844 .55078 .08515 Mtetra
.55078 .08515 .55323 .08844 .55785 .08666 .55541 .08337 Mtetra
.55541 .08337 .55785 .08666 .56249 .08488 .56005 .08158 Mtetra
.56005 .08158 .56249 .08488 .56713 .08309 .56469 .07979 Mtetra
.56469 .07979 .56713 .08309 .57177 .0813 .56934 .07799 Mtetra
.56934 .07799 .57177 .0813 .57643 .07951 .574 .07619 Mtetra
.574 .07619 .57643 .07951 .58109 .07771 .57867 .07439 Mtetra
.57867 .07439 .58109 .07771 .58576 .07592 .58335 .07259 Mtetra
.58335 .07259 .58576 .07592 .59044 .07411 .58803 .07078 Mtetra
.58803 .07078 .59044 .07411 .59513 .07231 .59272 .06897 Mtetra
.59272 .06897 .59513 .07231 .59982 .0705 .59742 .06715 Mtetra
.59742 .06715 .59982 .0705 .60452 .06869 .60213 .06534 Mtetra
.60213 .06534 .60452 .06869 .60923 .06687 .60685 .06352 Mtetra
.60685 .06352 .60923 .06687 .61395 .06506 .61157 .06169 Mtetra
.61157 .06169 .61395 .06506 .61868 .06324 .6163 .05987 Mtetra
.6163 .05987 .61868 .06324 .62341 .06141 .62104 .05804 Mtetra
.62104 .05804 .62341 .06141 .62815 .05959 .62579 .05621 Mtetra
.62579 .05621 .62815 .05959 .6329 .05776 .63054 .05437 Mtetra
.63054 .05437 .6329 .05776 .63766 .05592 .63531 .05253 Mtetra
.63531 .05253 .63766 .05592 .64243 .05409 .64008 .05069 Mtetra
.64008 .05069 .64243 .05409 .6472 .05225 .64486 .04885 Mtetra
.64486 .04885 .6472 .05225 .65198 .05041 .64965 .047 Mtetra
.64965 .047 .65198 .05041 .65678 .04856 .65444 .04515 Mtetra
.65444 .04515 .65678 .04856 .66157 .04671 .65925 .04329 Mtetra
.65925 .04329 .66157 .04671 .66638 .04486 .66406 .04144 Mtetra
.66406 .04144 .66638 .04486 .6712 .04301 .66888 .03958 Mtetra
.66888 .03958 .6712 .04301 .67602 .04115 .67371 .03771 Mtetra
.67371 .03771 .67602 .04115 .68085 .03929 .67855 .03585 Mtetra
.67855 .03585 .68085 .03929 .68569 .03743 .68339 .03398 Mtetra
.68339 .03398 .68569 .03743 .69054 .03556 .68825 .0321 Mtetra
.68825 .0321 .69054 .03556 .6954 .03369 .69311 .03023 Mtetra
.69311 .03023 .6954 .03369 .70026 .03181 .69798 .02835 Mtetra
.69798 .02835 .70026 .03181 .70513 .02994 .70286 .02646 Mtetra
.05114 .27412 .05408 .27685 .05791 .27537 .05498 .27263 Mtetra
.05498 .27263 .05791 .27537 .06175 .27389 .05882 .27115 Mtetra
.05882 .27115 .06175 .27389 .06559 .2724 .06267 .26966 Mtetra
.06267 .26966 .06559 .2724 .06945 .27092 .06652 .26817 Mtetra
.06652 .26817 .06945 .27092 .0733 .26943 .07038 .26668 Mtetra
.07038 .26668 .0733 .26943 .07717 .26794 .07425 .26518 Mtetra
.07425 .26518 .07717 .26794 .08104 .26645 .07812 .26368 Mtetra
.07812 .26368 .08104 .26645 .08491 .26495 .082 .26218 Mtetra
.082 .26218 .08491 .26495 .08879 .26345 .08589 .26068 Mtetra
.08589 .26068 .08879 .26345 .09268 .26195 .08978 .25918 Mtetra
.08978 .25918 .09268 .26195 .09657 .26045 .09367 .25767 Mtetra
.09367 .25767 .09657 .26045 .10047 .25894 .09757 .25616 Mtetra
.09757 .25616 .10047 .25894 .10438 .25744 .10148 .25465 Mtetra
.10148 .25465 .10438 .25744 .10829 .25593 .1054 .25314 Mtetra
.1054 .25314 .10829 .25593 .1122 .25442 .10932 .25162 Mtetra
.10932 .25162 .1122 .25442 .11613 .2529 .11324 .2501 Mtetra
.11324 .2501 .11613 .2529 .12006 .25139 .11718 .24858 Mtetra
.11718 .24858 .12006 .25139 .12399 .24987 .12112 .24706 Mtetra
.12112 .24706 .12399 .24987 .12793 .24835 .12506 .24553 Mtetra
.12506 .24553 .12793 .24835 .13188 .24682 .12901 .244 Mtetra
.12901 .244 .13188 .24682 .13583 .2453 .13297 .24247 Mtetra
.13297 .24247 .13583 .2453 .13979 .24377 .13693 .24094 Mtetra
.13693 .24094 .13979 .24377 .14376 .24224 .1409 .23941 Mtetra
.1409 .23941 .14376 .24224 .14773 .24071 .14488 .23787 Mtetra
.14488 .23787 .14773 .24071 .15171 .23917 .14886 .23633 Mtetra
.14886 .23633 .15171 .23917 .15569 .23763 .15284 .23479 Mtetra
.15284 .23479 .15569 .23763 .15968 .23609 .15684 .23324 Mtetra
.15684 .23324 .15968 .23609 .16368 .23455 .16084 .2317 Mtetra
.16084 .2317 .16368 .23455 .16768 .23301 .16485 .23015 Mtetra
.16485 .23015 .16768 .23301 .17169 .23146 .16886 .22859 Mtetra
.16886 .22859 .17169 .23146 .17571 .22991 .17288 .22704 Mtetra
.17288 .22704 .17571 .22991 .17973 .22836 .1769 .22548 Mtetra
.1769 .22548 .17973 .22836 .18376 .2268 .18093 .22393 Mtetra
.18093 .22393 .18376 .2268 .18779 .22524 .18497 .22236 Mtetra
.18497 .22236 .18779 .22524 .19183 .22369 .18902 .2208 Mtetra
.18902 .2208 .19183 .22369 .19588 .22212 .19307 .21923 Mtetra
.19307 .21923 .19588 .22212 .19993 .22056 .19712 .21766 Mtetra
.19712 .21766 .19993 .22056 .20399 .21899 .20119 .21609 Mtetra
.20119 .21609 .20399 .21899 .20806 .21742 .20526 .21452 Mtetra
.20526 .21452 .20806 .21742 .21213 .21585 .20933 .21294 Mtetra
.20933 .21294 .21213 .21585 .21621 .21428 .21342 .21136 Mtetra
.21342 .21136 .21621 .21428 .2203 .2127 .2175 .20978 Mtetra
.2175 .20978 .2203 .2127 .22439 .21112 .2216 .2082 Mtetra
.2216 .2082 .22439 .21112 .22849 .20954 .2257 .20661 Mtetra
.2257 .20661 .22849 .20954 .23259 .20796 .22981 .20502 Mtetra
.22981 .20502 .23259 .20796 .2367 .20637 .23392 .20343 Mtetra
.23392 .20343 .2367 .20637 .24082 .20478 .23805 .20184 Mtetra
.23805 .20184 .24082 .20478 .24494 .20319 .24217 .20024 Mtetra
.24217 .20024 .24494 .20319 .24907 .20159 .24631 .19864 Mtetra
.24631 .19864 .24907 .20159 .25321 .2 .25045 .19704 Mtetra
.25045 .19704 .25321 .2 .25735 .1984 .2546 .19544 Mtetra
.2546 .19544 .25735 .1984 .2615 .1968 .25875 .19383 Mtetra
.25875 .19383 .2615 .1968 .26566 .19519 .26291 .19222 Mtetra
.26291 .19222 .26566 .19519 .26982 .19359 .26708 .19061 Mtetra
.26708 .19061 .26982 .19359 .27399 .19198 .27125 .189 Mtetra
.27125 .189 .27399 .19198 .27817 .19036 .27543 .18738 Mtetra
.27543 .18738 .27817 .19036 .28235 .18875 .27962 .18576 Mtetra
.27962 .18576 .28235 .18875 .28654 .18713 .28382 .18414 Mtetra
.28382 .18414 .28654 .18713 .29074 .18551 .28802 .18252 Mtetra
.28802 .18252 .29074 .18551 .29494 .18389 .29222 .18089 Mtetra
.29222 .18089 .29494 .18389 .29915 .18227 .29644 .17926 Mtetra
.29644 .17926 .29915 .18227 .30337 .18064 .30066 .17763 Mtetra
.30066 .17763 .30337 .18064 .30759 .17901 .30489 .17599 Mtetra
.30489 .17599 .30759 .17901 .31183 .17738 .30912 .17435 Mtetra
.30912 .17435 .31183 .17738 .31606 .17574 .31336 .17271 Mtetra
.31336 .17271 .31606 .17574 .32031 .1741 .31761 .17107 Mtetra
.31761 .17107 .32031 .1741 .32456 .17246 .32186 .16943 Mtetra
.32186 .16943 .32456 .17246 .32881 .17082 .32613 .16778 Mtetra
.32613 .16778 .32881 .17082 .33308 .16917 .3304 .16613 Mtetra
.3304 .16613 .33308 .16917 .33735 .16752 .33467 .16447 Mtetra
.33467 .16447 .33735 .16752 .34163 .16587 .33895 .16282 Mtetra
.33895 .16282 .34163 .16587 .34591 .16422 .34324 .16116 Mtetra
.34324 .16116 .34591 .16422 .35021 .16256 .34754 .1595 Mtetra
.34754 .1595 .35021 .16256 .3545 .1609 .35184 .15783 Mtetra
.35184 .15783 .3545 .1609 .35881 .15924 .35615 .15617 Mtetra
.35615 .15617 .35881 .15924 .36312 .15758 .36047 .1545 Mtetra
.36047 .1545 .36312 .15758 .36744 .15591 .36479 .15283 Mtetra
.36479 .15283 .36744 .15591 .37177 .15424 .36912 .15115 Mtetra
.36912 .15115 .37177 .15424 .3761 .15257 .37346 .14947 Mtetra
.37346 .14947 .3761 .15257 .38044 .15089 .37781 .14779 Mtetra
.37781 .14779 .38044 .15089 .38479 .14922 .38216 .14611 Mtetra
.38216 .14611 .38479 .14922 .38915 .14753 .38652 .14442 Mtetra
.38652 .14442 .38915 .14753 .39329 .15079 .39089 .14274 Mtetra
.254 .286 .702 r
.39089 .14274 .39329 .15079 .39767 .14911 .39504 .14599 Mtetra
.663 .742 .908 r
.39504 .14599 .39767 .14911 .40205 .14742 .39943 .1443 Mtetra
.39943 .1443 .40205 .14742 .40644 .14573 .40383 .1426 Mtetra
.40383 .1426 .40644 .14573 .41084 .14404 .40823 .1409 Mtetra
.40823 .1409 .41084 .14404 .41524 .14234 .41264 .1392 Mtetra
.41264 .1392 .41524 .14234 .41966 .14064 .41705 .1375 Mtetra
.41705 .1375 .41966 .14064 .42407 .13894 .42148 .13579 Mtetra
.42148 .13579 .42407 .13894 .4285 .13724 .42591 .13408 Mtetra
.42591 .13408 .4285 .13724 .43294 .13553 .43035 .13237 Mtetra
.43035 .13237 .43294 .13553 .43738 .13382 .43479 .13066 Mtetra
.43479 .13066 .43738 .13382 .44182 .13211 .43925 .12894 Mtetra
.43925 .12894 .44182 .13211 .44628 .13039 .44371 .12722 Mtetra
.44371 .12722 .44628 .13039 .45074 .12867 .44817 .12549 Mtetra
.44817 .12549 .45074 .12867 .45521 .12695 .45265 .12377 Mtetra
.45265 .12377 .45521 .12695 .45969 .12523 .45713 .12204 Mtetra
.45713 .12204 .45969 .12523 .46418 .1235 .46162 .12031 Mtetra
.46162 .12031 .46418 .1235 .46867 .12177 .46612 .11857 Mtetra
.46612 .11857 .46867 .12177 .47317 .12004 .47062 .11683 Mtetra
.47062 .11683 .47317 .12004 .47768 .1183 .47514 .11509 Mtetra
.47514 .11509 .47768 .1183 .48219 .11656 .47966 .11335 Mtetra
.47966 .11335 .48219 .11656 .48671 .11482 .48418 .1116 Mtetra
.48418 .1116 .48671 .11482 .49124 .11308 .48872 .10985 Mtetra
.884 .786 .748 r
.48872 .10985 .49124 .11308 .49583 .10636 .49331 .10313 Mtetra
.664 .741 .908 r
.49331 .10313 .49583 .10636 .50037 .10461 .49786 .10137 Mtetra
.49786 .10137 .50037 .10461 .50491 .10286 .50241 .09961 Mtetra
.50241 .09961 .50491 .10286 .50947 .1011 .50696 .09785 Mtetra
.50696 .09785 .50947 .1011 .51403 .09934 .51153 .09608 Mtetra
.51153 .09608 .51403 .09934 .51859 .09758 .5161 .09431 Mtetra
.5161 .09431 .51859 .09758 .52317 .09581 .52068 .09254 Mtetra
.52068 .09254 .52317 .09581 .52775 .09404 .52527 .09077 Mtetra
.52527 .09077 .52775 .09404 .53234 .09227 .52986 .08899 Mtetra
.52986 .08899 .53234 .09227 .53694 .0905 .53447 .08721 Mtetra
.53447 .08721 .53694 .0905 .54155 .08872 .53908 .08543 Mtetra
.53908 .08543 .54155 .08872 .54616 .08694 .5437 .08364 Mtetra
.5437 .08364 .54616 .08694 .55078 .08515 .54832 .08185 Mtetra
.54832 .08185 .55078 .08515 .55541 .08337 .55296 .08006 Mtetra
.55296 .08006 .55541 .08337 .56005 .08158 .5576 .07827 Mtetra
.5576 .07827 .56005 .08158 .56469 .07979 .56225 .07647 Mtetra
.56225 .07647 .56469 .07979 .56934 .07799 .56691 .07467 Mtetra
.56691 .07467 .56934 .07799 .574 .07619 .57157 .07286 Mtetra
.57157 .07286 .574 .07619 .57867 .07439 .57625 .07106 Mtetra
.57625 .07106 .57867 .07439 .58335 .07259 .58093 .06925 Mtetra
.58093 .06925 .58335 .07259 .58803 .07078 .58562 .06743 Mtetra
.58562 .06743 .58803 .07078 .59272 .06897 .59031 .06562 Mtetra
.59031 .06562 .59272 .06897 .59742 .06715 .59502 .0638 Mtetra
.59502 .0638 .59742 .06715 .60213 .06534 .59973 .06198 Mtetra
.59973 .06198 .60213 .06534 .60685 .06352 .60445 .06015 Mtetra
.60445 .06015 .60685 .06352 .61157 .06169 .60918 .05832 Mtetra
.60918 .05832 .61157 .06169 .6163 .05987 .61392 .05649 Mtetra
.61392 .05649 .6163 .05987 .62104 .05804 .61866 .05465 Mtetra
.61866 .05465 .62104 .05804 .62579 .05621 .62341 .05282 Mtetra
.62341 .05282 .62579 .05621 .63054 .05437 .62818 .05098 Mtetra
.62818 .05098 .63054 .05437 .63531 .05253 .63294 .04913 Mtetra
.63294 .04913 .63531 .05253 .64008 .05069 .63772 .04728 Mtetra
.63772 .04728 .64008 .05069 .64486 .04885 .64251 .04543 Mtetra
.64251 .04543 .64486 .04885 .64965 .047 .6473 .04358 Mtetra
.6473 .04358 .64965 .047 .65444 .04515 .6521 .04172 Mtetra
.6521 .04172 .65444 .04515 .65925 .04329 .65691 .03986 Mtetra
.65691 .03986 .65925 .04329 .66406 .04144 .66173 .038 Mtetra
.66173 .038 .66406 .04144 .66888 .03958 .66656 .03613 Mtetra
.66656 .03613 .66888 .03958 .67371 .03771 .67139 .03426 Mtetra
.67139 .03426 .67371 .03771 .67855 .03585 .67624 .03239 Mtetra
.67624 .03239 .67855 .03585 .68339 .03398 .68109 .03051 Mtetra
.68109 .03051 .68339 .03398 .68825 .0321 .68595 .02864 Mtetra
.68595 .02864 .68825 .0321 .69311 .03023 .69081 .02675 Mtetra
.69081 .02675 .69311 .03023 .69798 .02835 .69569 .02487 Mtetra
.69569 .02487 .69798 .02835 .70286 .02646 .70058 .02298 Mtetra
.0482 .27138 .05114 .27412 .05498 .27263 .05204 .26989 Mtetra
.05204 .26989 .05498 .27263 .05882 .27115 .05588 .2684 Mtetra
.05588 .2684 .05882 .27115 .06267 .26966 .05973 .26691 Mtetra
.05973 .26691 .06267 .26966 .06652 .26817 .06359 .26541 Mtetra
.06359 .26541 .06652 .26817 .07038 .26668 .06746 .26391 Mtetra
.06746 .26391 .07038 .26668 .07425 .26518 .07133 .26241 Mtetra
.07133 .26241 .07425 .26518 .07812 .26368 .0752 .26091 Mtetra
.0752 .26091 .07812 .26368 .082 .26218 .07908 .25941 Mtetra
.07908 .25941 .082 .26218 .08589 .26068 .08297 .2579 Mtetra
.08297 .2579 .08589 .26068 .08978 .25918 .08686 .25639 Mtetra
.08686 .25639 .08978 .25918 .09367 .25767 .09076 .25488 Mtetra
.09076 .25488 .09367 .25767 .09757 .25616 .09467 .25337 Mtetra
.09467 .25337 .09757 .25616 .10148 .25465 .09858 .25185 Mtetra
.09858 .25185 .10148 .25465 .1054 .25314 .1025 .25033 Mtetra
.1025 .25033 .1054 .25314 .10932 .25162 .10642 .24881 Mtetra
.10642 .24881 .10932 .25162 .11324 .2501 .11035 .24729 Mtetra
.11035 .24729 .11324 .2501 .11718 .24858 .11429 .24577 Mtetra
.11429 .24577 .11718 .24858 .12112 .24706 .11823 .24424 Mtetra
.11823 .24424 .12112 .24706 .12506 .24553 .12218 .24271 Mtetra
.12218 .24271 .12506 .24553 .12901 .244 .12613 .24118 Mtetra
.12613 .24118 .12901 .244 .13297 .24247 .13009 .23964 Mtetra
.13009 .23964 .13297 .24247 .13693 .24094 .13406 .23811 Mtetra
.13406 .23811 .13693 .24094 .1409 .23941 .13803 .23657 Mtetra
.13803 .23657 .1409 .23941 .14488 .23787 .14201 .23502 Mtetra
.14201 .23502 .14488 .23787 .14886 .23633 .146 .23348 Mtetra
.146 .23348 .14886 .23633 .15284 .23479 .14999 .23193 Mtetra
.14999 .23193 .15284 .23479 .15684 .23324 .15399 .23039 Mtetra
.15399 .23039 .15684 .23324 .16084 .2317 .15799 .22883 Mtetra
.15799 .22883 .16084 .2317 .16485 .23015 .162 .22728 Mtetra
.162 .22728 .16485 .23015 .16886 .22859 .16602 .22572 Mtetra
.16602 .22572 .16886 .22859 .17288 .22704 .17004 .22417 Mtetra
.17004 .22417 .17288 .22704 .1769 .22548 .17407 .2226 Mtetra
.17407 .2226 .1769 .22548 .18093 .22393 .1781 .22104 Mtetra
.1781 .22104 .18093 .22393 .18497 .22236 .18214 .21947 Mtetra
.18214 .21947 .18497 .22236 .18902 .2208 .18619 .21791 Mtetra
.18619 .21791 .18902 .2208 .19307 .21923 .19025 .21634 Mtetra
.19025 .21634 .19307 .21923 .19712 .21766 .19431 .21476 Mtetra
.19431 .21476 .19712 .21766 .20119 .21609 .19837 .21319 Mtetra
.19837 .21319 .20119 .21609 .20526 .21452 .20245 .21161 Mtetra
.20245 .21161 .20526 .21452 .20933 .21294 .20653 .21003 Mtetra
.20653 .21003 .20933 .21294 .21342 .21136 .21061 .20844 Mtetra
.21061 .20844 .21342 .21136 .2175 .20978 .21471 .20686 Mtetra
.21471 .20686 .2175 .20978 .2216 .2082 .2188 .20527 Mtetra
.2188 .20527 .2216 .2082 .2257 .20661 .22291 .20368 Mtetra
.22291 .20368 .2257 .20661 .22981 .20502 .22702 .20209 Mtetra
.22702 .20209 .22981 .20502 .23392 .20343 .23114 .20049 Mtetra
.23114 .20049 .23392 .20343 .23805 .20184 .23527 .19889 Mtetra
.23527 .19889 .23805 .20184 .24217 .20024 .2394 .19729 Mtetra
.2394 .19729 .24217 .20024 .24631 .19864 .24354 .19569 Mtetra
.24354 .19569 .24631 .19864 .25045 .19704 .24768 .19408 Mtetra
.24768 .19408 .25045 .19704 .2546 .19544 .25183 .19247 Mtetra
.25183 .19247 .2546 .19544 .25875 .19383 .25599 .19086 Mtetra
.25599 .19086 .25875 .19383 .26291 .19222 .26015 .18925 Mtetra
.26015 .18925 .26291 .19222 .26708 .19061 .26433 .18763 Mtetra
.26433 .18763 .26708 .19061 .27125 .189 .2685 .18601 Mtetra
.2685 .18601 .27125 .189 .27543 .18738 .27269 .18439 Mtetra
.27269 .18439 .27543 .18738 .27962 .18576 .27688 .18277 Mtetra
.27688 .18277 .27962 .18576 .28382 .18414 .28108 .18114 Mtetra
.28108 .18114 .28382 .18414 .28802 .18252 .28528 .17951 Mtetra
.28528 .17951 .28802 .18252 .29222 .18089 .28949 .17788 Mtetra
.28949 .17788 .29222 .18089 .29644 .17926 .29371 .17624 Mtetra
.29371 .17624 .29644 .17926 .30066 .17763 .29794 .17461 Mtetra
.29794 .17461 .30066 .17763 .30489 .17599 .30217 .17297 Mtetra
.30217 .17297 .30489 .17599 .30912 .17435 .30641 .17133 Mtetra
.30641 .17133 .30912 .17435 .31336 .17271 .31065 .16968 Mtetra
.31065 .16968 .31336 .17271 .31761 .17107 .31491 .16803 Mtetra
.31491 .16803 .31761 .17107 .32186 .16943 .31916 .16638 Mtetra
.31916 .16638 .32186 .16943 .32613 .16778 .32343 .16473 Mtetra
.32343 .16473 .32613 .16778 .3304 .16613 .3277 .16307 Mtetra
.3277 .16307 .3304 .16613 .33467 .16447 .33198 .16142 Mtetra
.33198 .16142 .33467 .16447 .33895 .16282 .33627 .15975 Mtetra
.33627 .15975 .33895 .16282 .34324 .16116 .34056 .15809 Mtetra
.34056 .15809 .34324 .16116 .34754 .1595 .34486 .15642 Mtetra
.34486 .15642 .34754 .1595 .35184 .15783 .34917 .15476 Mtetra
.34917 .15476 .35184 .15783 .35615 .15617 .35349 .15308 Mtetra
.35349 .15308 .35615 .15617 .36047 .1545 .35781 .15141 Mtetra
.35781 .15141 .36047 .1545 .36479 .15283 .36214 .14973 Mtetra
.36214 .14973 .36479 .15283 .36912 .15115 .36647 .14805 Mtetra
.36647 .14805 .36912 .15115 .37346 .14947 .37081 .14637 Mtetra
.37081 .14637 .37346 .14947 .37781 .14779 .37516 .14468 Mtetra
.37516 .14468 .37781 .14779 .38216 .14611 .37952 .143 Mtetra
.37952 .143 .38216 .14611 .38652 .14442 .38388 .14131 Mtetra
.38388 .14131 .38652 .14442 .39089 .14274 .38825 .13961 Mtetra
0 .181 .695 r
.38825 .13961 .39089 .14274 .39504 .14599 .39241 .14286 Mtetra
.663 .742 .908 r
.39241 .14286 .39504 .14599 .39943 .1443 .3968 .14117 Mtetra
.3968 .14117 .39943 .1443 .40383 .1426 .4012 .13947 Mtetra
.4012 .13947 .40383 .1426 .40823 .1409 .40561 .13776 Mtetra
.40561 .13776 .40823 .1409 .41264 .1392 .41002 .13606 Mtetra
.41002 .13606 .41264 .1392 .41705 .1375 .41444 .13435 Mtetra
.41444 .13435 .41705 .1375 .42148 .13579 .41887 .13263 Mtetra
.41887 .13263 .42148 .13579 .42591 .13408 .42331 .13092 Mtetra
.42331 .13092 .42591 .13408 .43035 .13237 .42775 .1292 Mtetra
.42775 .1292 .43035 .13237 .43479 .13066 .4322 .12748 Mtetra
.4322 .12748 .43479 .13066 .43925 .12894 .43666 .12576 Mtetra
.43666 .12576 .43925 .12894 .44371 .12722 .44113 .12403 Mtetra
.44113 .12403 .44371 .12722 .44817 .12549 .4456 .1223 Mtetra
.4456 .1223 .44817 .12549 .45265 .12377 .45008 .12057 Mtetra
.45008 .12057 .45265 .12377 .45713 .12204 .45456 .11884 Mtetra
.45456 .11884 .45713 .12204 .46162 .12031 .45906 .1171 Mtetra
.45906 .1171 .46162 .12031 .46612 .11857 .46356 .11536 Mtetra
.46356 .11536 .46612 .11857 .47062 .11683 .46807 .11362 Mtetra
.46807 .11362 .47062 .11683 .47514 .11509 .47259 .11187 Mtetra
.47259 .11187 .47514 .11509 .47966 .11335 .47711 .11012 Mtetra
.47711 .11012 .47966 .11335 .48418 .1116 .48165 .10837 Mtetra
.48165 .10837 .48418 .1116 .48872 .10985 .48618 .10661 Mtetra
.884 .786 .748 r
.48618 .10661 .48872 .10985 .49331 .10313 .49079 .09988 Mtetra
.664 .741 .908 r
.49079 .09988 .49331 .10313 .49786 .10137 .49534 .09812 Mtetra
.49534 .09812 .49786 .10137 .50241 .09961 .49989 .09635 Mtetra
.49989 .09635 .50241 .09961 .50696 .09785 .50445 .09459 Mtetra
.50445 .09459 .50696 .09785 .51153 .09608 .50902 .09282 Mtetra
.50902 .09282 .51153 .09608 .5161 .09431 .5136 .09104 Mtetra
.5136 .09104 .5161 .09431 .52068 .09254 .51819 .08927 Mtetra
.51819 .08927 .52068 .09254 .52527 .09077 .52278 .08749 Mtetra
.52278 .08749 .52527 .09077 .52986 .08899 .52738 .0857 Mtetra
.52738 .0857 .52986 .08899 .53447 .08721 .53199 .08392 Mtetra
.53199 .08392 .53447 .08721 .53908 .08543 .5366 .08213 Mtetra
.5366 .08213 .53908 .08543 .5437 .08364 .54123 .08034 Mtetra
.54123 .08034 .5437 .08364 .54832 .08185 .54586 .07854 Mtetra
.54586 .07854 .54832 .08185 .55296 .08006 .5505 .07675 Mtetra
.5505 .07675 .55296 .08006 .5576 .07827 .55515 .07495 Mtetra
.55515 .07495 .5576 .07827 .56225 .07647 .5598 .07314 Mtetra
.5598 .07314 .56225 .07647 .56691 .07467 .56446 .07133 Mtetra
.56446 .07133 .56691 .07467 .57157 .07286 .56913 .06953 Mtetra
.56913 .06953 .57157 .07286 .57625 .07106 .57381 .06771 Mtetra
.57381 .06771 .57625 .07106 .58093 .06925 .5785 .0659 Mtetra
.5785 .0659 .58093 .06925 .58562 .06743 .58319 .06408 Mtetra
.58319 .06408 .58562 .06743 .59031 .06562 .58789 .06226 Mtetra
.58789 .06226 .59031 .06562 .59502 .0638 .5926 .06043 Mtetra
.5926 .06043 .59502 .0638 .59973 .06198 .59732 .0586 Mtetra
.59732 .0586 .59973 .06198 .60445 .06015 .60205 .05677 Mtetra
.60205 .05677 .60445 .06015 .60918 .05832 .60678 .05494 Mtetra
.60678 .05494 .60918 .05832 .61392 .05649 .61153 .0531 Mtetra
.61153 .0531 .61392 .05649 .61866 .05465 .61628 .05126 Mtetra
.61628 .05126 .61866 .05465 .62341 .05282 .62103 .04941 Mtetra
.62103 .04941 .62341 .05282 .62818 .05098 .6258 .04757 Mtetra
.6258 .04757 .62818 .05098 .63294 .04913 .63058 .04572 Mtetra
.63058 .04572 .63294 .04913 .63772 .04728 .63536 .04386 Mtetra
.63536 .04386 .63772 .04728 .64251 .04543 .64015 .04201 Mtetra
.64015 .04201 .64251 .04543 .6473 .04358 .64495 .04015 Mtetra
.64495 .04015 .6473 .04358 .6521 .04172 .64976 .03829 Mtetra
.64976 .03829 .6521 .04172 .65691 .03986 .65457 .03642 Mtetra
.65457 .03642 .65691 .03986 .66173 .038 .65939 .03455 Mtetra
.65939 .03455 .66173 .038 .66656 .03613 .66423 .03268 Mtetra
.66423 .03268 .66656 .03613 .67139 .03426 .66907 .0308 Mtetra
.66907 .0308 .67139 .03426 .67624 .03239 .67392 .02892 Mtetra
.67392 .02892 .67624 .03239 .68109 .03051 .67877 .02704 Mtetra
.67877 .02704 .68109 .03051 .68595 .02864 .68364 .02516 Mtetra
.68364 .02516 .68595 .02864 .69081 .02675 .68851 .02327 Mtetra
.68851 .02327 .69081 .02675 .69569 .02487 .69339 .02138 Mtetra
.69339 .02138 .69569 .02487 .70058 .02298 .69828 .01948 Mtetra
.04524 .26863 .0482 .27138 .05204 .26989 .04909 .26713 Mtetra
.04909 .26713 .05204 .26989 .05588 .2684 .05294 .26564 Mtetra
.05294 .26564 .05588 .2684 .05973 .26691 .05679 .26414 Mtetra
.05679 .26414 .05973 .26691 .06359 .26541 .06065 .26264 Mtetra
.06065 .26264 .06359 .26541 .06746 .26391 .06452 .26114 Mtetra
.06452 .26114 .06746 .26391 .07133 .26241 .06839 .25964 Mtetra
.06839 .25964 .07133 .26241 .0752 .26091 .07227 .25813 Mtetra
.07227 .25813 .0752 .26091 .07908 .25941 .07616 .25663 Mtetra
.07616 .25663 .07908 .25941 .08297 .2579 .08005 .25511 Mtetra
.08005 .25511 .08297 .2579 .08686 .25639 .08394 .2536 Mtetra
.08394 .2536 .08686 .25639 .09076 .25488 .08785 .25209 Mtetra
.08785 .25209 .09076 .25488 .09467 .25337 .09176 .25057 Mtetra
.09176 .25057 .09467 .25337 .09858 .25185 .09567 .24905 Mtetra
.09567 .24905 .09858 .25185 .1025 .25033 .09959 .24753 Mtetra
.09959 .24753 .1025 .25033 .10642 .24881 .10352 .246 Mtetra
.10352 .246 .10642 .24881 .11035 .24729 .10745 .24447 Mtetra
.10745 .24447 .11035 .24729 .11429 .24577 .11139 .24294 Mtetra
.11139 .24294 .11429 .24577 .11823 .24424 .11534 .24141 Mtetra
.11534 .24141 .11823 .24424 .12218 .24271 .11929 .23988 Mtetra
.11929 .23988 .12218 .24271 .12613 .24118 .12325 .23834 Mtetra
.12325 .23834 .12613 .24118 .13009 .23964 .12721 .2368 Mtetra
.12721 .2368 .13009 .23964 .13406 .23811 .13118 .23526 Mtetra
.13118 .23526 .13406 .23811 .13803 .23657 .13516 .23372 Mtetra
.13516 .23372 .13803 .23657 .14201 .23502 .13914 .23217 Mtetra
.13914 .23217 .14201 .23502 .146 .23348 .14313 .23062 Mtetra
.14313 .23062 .146 .23348 .14999 .23193 .14712 .22907 Mtetra
.14712 .22907 .14999 .23193 .15399 .23039 .15112 .22752 Mtetra
.15112 .22752 .15399 .23039 .15799 .22883 .15513 .22596 Mtetra
.15513 .22596 .15799 .22883 .162 .22728 .15914 .22441 Mtetra
.15914 .22441 .162 .22728 .16602 .22572 .16316 .22284 Mtetra
.16316 .22284 .16602 .22572 .17004 .22417 .16719 .22128 Mtetra
.16719 .22128 .17004 .22417 .17407 .2226 .17122 .21972 Mtetra
.17122 .21972 .17407 .2226 .1781 .22104 .17526 .21815 Mtetra
.17526 .21815 .1781 .22104 .18214 .21947 .17931 .21658 Mtetra
.17931 .21658 .18214 .21947 .18619 .21791 .18336 .215 Mtetra
.18336 .215 .18619 .21791 .19025 .21634 .18742 .21343 Mtetra
.18742 .21343 .19025 .21634 .19431 .21476 .19148 .21185 Mtetra
.19148 .21185 .19431 .21476 .19837 .21319 .19555 .21027 Mtetra
.19555 .21027 .19837 .21319 .20245 .21161 .19963 .20869 Mtetra
.19963 .20869 .20245 .21161 .20653 .21003 .20371 .2071 Mtetra
.20371 .2071 .20653 .21003 .21061 .20844 .2078 .20551 Mtetra
.2078 .20551 .21061 .20844 .21471 .20686 .2119 .20392 Mtetra
.2119 .20392 .21471 .20686 .2188 .20527 .216 .20233 Mtetra
.216 .20233 .2188 .20527 .22291 .20368 .22011 .20073 Mtetra
.22011 .20073 .22291 .20368 .22702 .20209 .22423 .19914 Mtetra
.22423 .19914 .22702 .20209 .23114 .20049 .22835 .19754 Mtetra
.22835 .19754 .23114 .20049 .23527 .19889 .23248 .19593 Mtetra
.23248 .19593 .23527 .19889 .2394 .19729 .23661 .19433 Mtetra
.23661 .19433 .2394 .19729 .24354 .19569 .24076 .19272 Mtetra
.24076 .19272 .24354 .19569 .24768 .19408 .2449 .19111 Mtetra
.2449 .19111 .24768 .19408 .25183 .19247 .24906 .1895 Mtetra
.24906 .1895 .25183 .19247 .25599 .19086 .25322 .18788 Mtetra
.25322 .18788 .25599 .19086 .26015 .18925 .25739 .18626 Mtetra
.25739 .18626 .26015 .18925 .26433 .18763 .26157 .18464 Mtetra
.26157 .18464 .26433 .18763 .2685 .18601 .26575 .18302 Mtetra
.26575 .18302 .2685 .18601 .27269 .18439 .26994 .18139 Mtetra
.26994 .18139 .27269 .18439 .27688 .18277 .27413 .17976 Mtetra
.27413 .17976 .27688 .18277 .28108 .18114 .27833 .17813 Mtetra
.27833 .17813 .28108 .18114 .28528 .17951 .28254 .1765 Mtetra
.28254 .1765 .28528 .17951 .28949 .17788 .28676 .17486 Mtetra
.28676 .17486 .28949 .17788 .29371 .17624 .29098 .17322 Mtetra
.29098 .17322 .29371 .17624 .29794 .17461 .29521 .17158 Mtetra
.29521 .17158 .29794 .17461 .30217 .17297 .29944 .16993 Mtetra
.29944 .16993 .30217 .17297 .30641 .17133 .30369 .16829 Mtetra
.30369 .16829 .30641 .17133 .31065 .16968 .30794 .16664 Mtetra
.30794 .16664 .31065 .16968 .31491 .16803 .31219 .16498 Mtetra
.31219 .16498 .31491 .16803 .31916 .16638 .31646 .16333 Mtetra
.31646 .16333 .31916 .16638 .32343 .16473 .32073 .16167 Mtetra
.32073 .16167 .32343 .16473 .3277 .16307 .325 .16001 Mtetra
.325 .16001 .3277 .16307 .33198 .16142 .32929 .15835 Mtetra
.32929 .15835 .33198 .16142 .33627 .15975 .33358 .15668 Mtetra
.33358 .15668 .33627 .15975 .34056 .15809 .33788 .15501 Mtetra
.33788 .15501 .34056 .15809 .34486 .15642 .34218 .15334 Mtetra
.34218 .15334 .34486 .15642 .34917 .15476 .34649 .15167 Mtetra
.34649 .15167 .34917 .15476 .35349 .15308 .35081 .14999 Mtetra
.35081 .14999 .35349 .15308 .35781 .15141 .35514 .14831 Mtetra
.35514 .14831 .35781 .15141 .36214 .14973 .35947 .14663 Mtetra
.35947 .14663 .36214 .14973 .36647 .14805 .36381 .14494 Mtetra
.36381 .14494 .36647 .14805 .37081 .14637 .36816 .14326 Mtetra
.36816 .14326 .37081 .14637 .37516 .14468 .37251 .14157 Mtetra
.37251 .14157 .37516 .14468 .37952 .143 .37687 .13987 Mtetra
.37687 .13987 .37952 .143 .38388 .14131 .38124 .13818 Mtetra
.38124 .13818 .38388 .14131 .38825 .13961 .38561 .13648 Mtetra
0 .181 .695 r
.38561 .13648 .38825 .13961 .39241 .14286 .38977 .13973 Mtetra
.663 .742 .908 r
.38977 .13973 .39241 .14286 .3968 .14117 .39417 .13802 Mtetra
.39417 .13802 .3968 .14117 .4012 .13947 .39857 .13632 Mtetra
.39857 .13632 .4012 .13947 .40561 .13776 .40298 .13461 Mtetra
.40298 .13461 .40561 .13776 .41002 .13606 .4074 .1329 Mtetra
.4074 .1329 .41002 .13606 .41444 .13435 .41183 .13118 Mtetra
.41183 .13118 .41444 .13435 .41887 .13263 .41626 .12947 Mtetra
.41626 .12947 .41887 .13263 .42331 .13092 .4207 .12775 Mtetra
.4207 .12775 .42331 .13092 .42775 .1292 .42515 .12602 Mtetra
.42515 .12602 .42775 .1292 .4322 .12748 .4296 .1243 Mtetra
.4296 .1243 .4322 .12748 .43666 .12576 .43407 .12257 Mtetra
.43407 .12257 .43666 .12576 .44113 .12403 .43854 .12084 Mtetra
.43854 .12084 .44113 .12403 .4456 .1223 .44301 .1191 Mtetra
.44301 .1191 .4456 .1223 .45008 .12057 .4475 .11737 Mtetra
.4475 .11737 .45008 .12057 .45456 .11884 .45199 .11563 Mtetra
.45199 .11563 .45456 .11884 .45906 .1171 .45649 .11388 Mtetra
.45649 .11388 .45906 .1171 .46356 .11536 .461 .11214 Mtetra
.461 .11214 .46356 .11536 .46807 .11362 .46551 .11039 Mtetra
.46551 .11039 .46807 .11362 .47259 .11187 .47003 .10864 Mtetra
.47003 .10864 .47259 .11187 .47711 .11012 .47456 .10688 Mtetra
.47456 .10688 .47711 .11012 .48165 .10837 .4791 .10513 Mtetra
.4791 .10513 .48165 .10837 .48618 .10661 .48364 .10337 Mtetra
.884 .786 .748 r
.48364 .10337 .48618 .10661 .49079 .09988 .48826 .09663 Mtetra
.664 .741 .908 r
.48826 .09663 .49079 .09988 .49534 .09812 .49281 .09486 Mtetra
.49281 .09486 .49534 .09812 .49989 .09635 .49737 .09309 Mtetra
.49737 .09309 .49989 .09635 .50445 .09459 .50194 .09132 Mtetra
.50194 .09132 .50445 .09459 .50902 .09282 .50651 .08954 Mtetra
.50651 .08954 .50902 .09282 .5136 .09104 .51109 .08776 Mtetra
.51109 .08776 .5136 .09104 .51819 .08927 .51568 .08598 Mtetra
.51568 .08598 .51819 .08927 .52278 .08749 .52028 .08419 Mtetra
.52028 .08419 .52278 .08749 .52738 .0857 .52489 .0824 Mtetra
.52489 .0824 .52738 .0857 .53199 .08392 .5295 .08061 Mtetra
.5295 .08061 .53199 .08392 .5366 .08213 .53412 .07882 Mtetra
.53412 .07882 .5366 .08213 .54123 .08034 .53875 .07702 Mtetra
.53875 .07702 .54123 .08034 .54586 .07854 .54339 .07522 Mtetra
.54339 .07522 .54586 .07854 .5505 .07675 .54803 .07342 Mtetra
.54803 .07342 .5505 .07675 .55515 .07495 .55268 .07161 Mtetra
.55268 .07161 .55515 .07495 .5598 .07314 .55734 .0698 Mtetra
.55734 .0698 .5598 .07314 .56446 .07133 .56201 .06799 Mtetra
.56201 .06799 .56446 .07133 .56913 .06953 .56669 .06618 Mtetra
.56669 .06618 .56913 .06953 .57381 .06771 .57137 .06436 Mtetra
.57137 .06436 .57381 .06771 .5785 .0659 .57606 .06254 Mtetra
.57606 .06254 .5785 .0659 .58319 .06408 .58076 .06071 Mtetra
.58076 .06071 .58319 .06408 .58789 .06226 .58547 .05888 Mtetra
.58547 .05888 .58789 .06226 .5926 .06043 .59018 .05705 Mtetra
.59018 .05705 .5926 .06043 .59732 .0586 .59491 .05522 Mtetra
.59491 .05522 .59732 .0586 .60205 .05677 .59964 .05338 Mtetra
.59964 .05338 .60205 .05677 .60678 .05494 .60438 .05154 Mtetra
.60438 .05154 .60678 .05494 .61153 .0531 .60913 .0497 Mtetra
.60913 .0497 .61153 .0531 .61628 .05126 .61388 .04785 Mtetra
.61388 .04785 .61628 .05126 .62103 .04941 .61865 .046 Mtetra
.61865 .046 .62103 .04941 .6258 .04757 .62342 .04415 Mtetra
.62342 .04415 .6258 .04757 .63058 .04572 .6282 .04229 Mtetra
.6282 .04229 .63058 .04572 .63536 .04386 .63299 .04044 Mtetra
.63299 .04044 .63536 .04386 .64015 .04201 .63778 .03857 Mtetra
.63778 .03857 .64015 .04201 .64495 .04015 .64259 .03671 Mtetra
.64259 .03671 .64495 .04015 .64976 .03829 .6474 .03484 Mtetra
.6474 .03484 .64976 .03829 .65457 .03642 .65222 .03297 Mtetra
.65222 .03297 .65457 .03642 .65939 .03455 .65705 .03109 Mtetra
.65705 .03109 .65939 .03455 .66423 .03268 .66189 .02921 Mtetra
.66189 .02921 .66423 .03268 .66907 .0308 .66673 .02733 Mtetra
.66673 .02733 .66907 .0308 .67392 .02892 .67159 .02545 Mtetra
.67159 .02545 .67392 .02892 .67877 .02704 .67645 .02356 Mtetra
.67645 .02356 .67877 .02704 .68364 .02516 .68132 .02167 Mtetra
.68132 .02167 .68364 .02516 .68851 .02327 .6862 .01977 Mtetra
.6862 .01977 .68851 .02327 .69339 .02138 .69109 .01788 Mtetra
.69109 .01788 .69339 .02138 .69828 .01948 .69599 .01598 Mtetra
.04228 .26587 .04524 .26863 .04909 .26713 .04613 .26437 Mtetra
.04613 .26437 .04909 .26713 .05294 .26564 .04998 .26288 Mtetra
.04998 .26288 .05294 .26564 .05679 .26414 .05384 .26137 Mtetra
.05384 .26137 .05679 .26414 .06065 .26264 .0577 .25987 Mtetra
.0577 .25987 .06065 .26264 .06452 .26114 .06158 .25837 Mtetra
.06158 .25837 .06452 .26114 .06839 .25964 .06545 .25686 Mtetra
.06545 .25686 .06839 .25964 .07227 .25813 .06933 .25535 Mtetra
.06933 .25535 .07227 .25813 .07616 .25663 .07322 .25383 Mtetra
.07322 .25383 .07616 .25663 .08005 .25511 .07712 .25232 Mtetra
.07712 .25232 .08005 .25511 .08394 .2536 .08102 .2508 Mtetra
.08102 .2508 .08394 .2536 .08785 .25209 .08492 .24928 Mtetra
.08492 .24928 .08785 .25209 .09176 .25057 .08883 .24776 Mtetra
.08883 .24776 .09176 .25057 .09567 .24905 .09275 .24624 Mtetra
.09275 .24624 .09567 .24905 .09959 .24753 .09668 .24471 Mtetra
.09668 .24471 .09959 .24753 .10352 .246 .10061 .24318 Mtetra
.10061 .24318 .10352 .246 .10745 .24447 .10454 .24165 Mtetra
.10454 .24165 .10745 .24447 .11139 .24294 .10849 .24012 Mtetra
.10849 .24012 .11139 .24294 .11534 .24141 .11244 .23858 Mtetra
.11244 .23858 .11534 .24141 .11929 .23988 .11639 .23704 Mtetra
.11639 .23704 .11929 .23988 .12325 .23834 .12035 .2355 Mtetra
.12035 .2355 .12325 .23834 .12721 .2368 .12432 .23396 Mtetra
.12432 .23396 .12721 .2368 .13118 .23526 .12829 .23241 Mtetra
.12829 .23241 .13118 .23526 .13516 .23372 .13227 .23086 Mtetra
.13227 .23086 .13516 .23372 .13914 .23217 .13626 .22931 Mtetra
.13626 .22931 .13914 .23217 .14313 .23062 .14025 .22776 Mtetra
.14025 .22776 .14313 .23062 .14712 .22907 .14425 .2262 Mtetra
.14425 .2262 .14712 .22907 .15112 .22752 .14825 .22464 Mtetra
.14825 .22464 .15112 .22752 .15513 .22596 .15226 .22308 Mtetra
.15226 .22308 .15513 .22596 .15914 .22441 .15628 .22152 Mtetra
.15628 .22152 .15914 .22441 .16316 .22284 .1603 .21996 Mtetra
.1603 .21996 .16316 .22284 .16719 .22128 .16433 .21839 Mtetra
.16433 .21839 .16719 .22128 .17122 .21972 .16837 .21682 Mtetra
.16837 .21682 .17122 .21972 .17526 .21815 .17241 .21525 Mtetra
.17241 .21525 .17526 .21815 .17931 .21658 .17646 .21367 Mtetra
.17646 .21367 .17931 .21658 .18336 .215 .18052 .21209 Mtetra
.18052 .21209 .18336 .215 .18742 .21343 .18458 .21051 Mtetra
.18458 .21051 .18742 .21343 .19148 .21185 .18865 .20893 Mtetra
.18865 .20893 .19148 .21185 .19555 .21027 .19272 .20735 Mtetra
.19272 .20735 .19555 .21027 .19963 .20869 .1968 .20576 Mtetra
.1968 .20576 .19963 .20869 .20371 .2071 .20089 .20417 Mtetra
.20089 .20417 .20371 .2071 .2078 .20551 .20498 .20258 Mtetra
.20498 .20258 .2078 .20551 .2119 .20392 .20908 .20098 Mtetra
.20908 .20098 .2119 .20392 .216 .20233 .21319 .19938 Mtetra
.21319 .19938 .216 .20233 .22011 .20073 .2173 .19778 Mtetra
.2173 .19778 .22011 .20073 .22423 .19914 .22142 .19618 Mtetra
.22142 .19618 .22423 .19914 .22835 .19754 .22555 .19457 Mtetra
.22555 .19457 .22835 .19754 .23248 .19593 .22968 .19297 Mtetra
.22968 .19297 .23248 .19593 .23661 .19433 .23382 .19136 Mtetra
.23382 .19136 .23661 .19433 .24076 .19272 .23797 .18974 Mtetra
.23797 .18974 .24076 .19272 .2449 .19111 .24212 .18813 Mtetra
.24212 .18813 .2449 .19111 .24906 .1895 .24628 .18651 Mtetra
.24628 .18651 .24906 .1895 .25322 .18788 .25044 .18489 Mtetra
.25044 .18489 .25322 .18788 .25739 .18626 .25462 .18327 Mtetra
.25462 .18327 .25739 .18626 .26157 .18464 .2588 .18164 Mtetra
.2588 .18164 .26157 .18464 .26575 .18302 .26298 .18001 Mtetra
.26298 .18001 .26575 .18302 .26994 .18139 .26717 .17838 Mtetra
.26717 .17838 .26994 .18139 .27413 .17976 .27137 .17675 Mtetra
.27137 .17675 .27413 .17976 .27833 .17813 .27558 .17511 Mtetra
.27558 .17511 .27833 .17813 .28254 .1765 .27979 .17347 Mtetra
.27979 .17347 .28254 .1765 .28676 .17486 .28401 .17183 Mtetra
.28401 .17183 .28676 .17486 .29098 .17322 .28824 .17019 Mtetra
.28824 .17019 .29098 .17322 .29521 .17158 .29247 .16854 Mtetra
.29247 .16854 .29521 .17158 .29944 .16993 .29671 .16689 Mtetra
.29671 .16689 .29944 .16993 .30369 .16829 .30096 .16524 Mtetra
.30096 .16524 .30369 .16829 .30794 .16664 .30521 .16358 Mtetra
.30521 .16358 .30794 .16664 .31219 .16498 .30947 .16193 Mtetra
.30947 .16193 .31219 .16498 .31646 .16333 .31374 .16027 Mtetra
.31374 .16027 .31646 .16333 .32073 .16167 .31801 .1586 Mtetra
.31801 .1586 .32073 .16167 .325 .16001 .3223 .15694 Mtetra
.3223 .15694 .325 .16001 .32929 .15835 .32658 .15527 Mtetra
.32658 .15527 .32929 .15835 .33358 .15668 .33088 .1536 Mtetra
.33088 .1536 .33358 .15668 .33788 .15501 .33518 .15192 Mtetra
.33518 .15192 .33788 .15501 .34218 .15334 .33949 .15025 Mtetra
.33949 .15025 .34218 .15334 .34649 .15167 .34381 .14857 Mtetra
.34381 .14857 .34649 .15167 .35081 .14999 .34813 .14689 Mtetra
.34813 .14689 .35081 .14999 .35514 .14831 .35246 .1452 Mtetra
.35246 .1452 .35514 .14831 .35947 .14663 .3568 .14352 Mtetra
.3568 .14352 .35947 .14663 .36381 .14494 .36114 .14183 Mtetra
.36114 .14183 .36381 .14494 .36816 .14326 .36549 .14013 Mtetra
.36549 .14013 .36816 .14326 .37251 .14157 .36985 .13844 Mtetra
.36985 .13844 .37251 .14157 .37687 .13987 .37421 .13674 Mtetra
.37421 .13674 .37687 .13987 .38124 .13818 .37859 .13504 Mtetra
.37859 .13504 .38124 .13818 .38561 .13648 .38297 .13333 Mtetra
0 .181 .695 r
.38297 .13333 .38561 .13648 .38977 .13973 .38712 .13658 Mtetra
.663 .742 .908 r
.38712 .13658 .38977 .13973 .39417 .13802 .39152 .13487 Mtetra
.39152 .13487 .39417 .13802 .39857 .13632 .39593 .13316 Mtetra
.39593 .13316 .39857 .13632 .40298 .13461 .40035 .13145 Mtetra
.40035 .13145 .40298 .13461 .4074 .1329 .40477 .12973 Mtetra
.40477 .12973 .4074 .1329 .41183 .13118 .4092 .12801 Mtetra
.4092 .12801 .41183 .13118 .41626 .12947 .41364 .12629 Mtetra
.41364 .12629 .41626 .12947 .4207 .12775 .41808 .12456 Mtetra
.41808 .12456 .4207 .12775 .42515 .12602 .42254 .12284 Mtetra
.42254 .12284 .42515 .12602 .4296 .1243 .427 .12111 Mtetra
.427 .12111 .4296 .1243 .43407 .12257 .43146 .11937 Mtetra
.43146 .11937 .43407 .12257 .43854 .12084 .43594 .11763 Mtetra
.43594 .11763 .43854 .12084 .44301 .1191 .44042 .1159 Mtetra
.44042 .1159 .44301 .1191 .4475 .11737 .44491 .11415 Mtetra
.44491 .11415 .4475 .11737 .45199 .11563 .44941 .11241 Mtetra
.44941 .11241 .45199 .11563 .45649 .11388 .45391 .11066 Mtetra
.45391 .11066 .45649 .11388 .461 .11214 .45842 .10891 Mtetra
.45842 .10891 .461 .11214 .46551 .11039 .46294 .10715 Mtetra
.46294 .10715 .46551 .11039 .47003 .10864 .46747 .1054 Mtetra
.46747 .1054 .47003 .10864 .47456 .10688 .472 .10364 Mtetra
.472 .10364 .47456 .10688 .4791 .10513 .47654 .10187 Mtetra
.47654 .10187 .4791 .10513 .48364 .10337 .48109 .10011 Mtetra
.48109 .10011 .48364 .10337 .48826 .09663 .48565 .09834 Mtetra
.857 .971 .656 r
.48565 .09834 .48826 .09663 .49281 .09486 .49027 .09159 Mtetra
.664 .741 .908 r
.49027 .09159 .49281 .09486 .49737 .09309 .49484 .08981 Mtetra
.49484 .08981 .49737 .09309 .50194 .09132 .49941 .08803 Mtetra
.49941 .08803 .50194 .09132 .50651 .08954 .50399 .08625 Mtetra
.50399 .08625 .50651 .08954 .51109 .08776 .50858 .08447 Mtetra
.50858 .08447 .51109 .08776 .51568 .08598 .51317 .08268 Mtetra
.51317 .08268 .51568 .08598 .52028 .08419 .51778 .08089 Mtetra
.51778 .08089 .52028 .08419 .52489 .0824 .52239 .0791 Mtetra
.52239 .0791 .52489 .0824 .5295 .08061 .527 .0773 Mtetra
.527 .0773 .5295 .08061 .53412 .07882 .53163 .0755 Mtetra
.53163 .0755 .53412 .07882 .53875 .07702 .53626 .0737 Mtetra
.53626 .0737 .53875 .07702 .54339 .07522 .54091 .07189 Mtetra
.54091 .07189 .54339 .07522 .54803 .07342 .54556 .07008 Mtetra
.54556 .07008 .54803 .07342 .55268 .07161 .55021 .06827 Mtetra
.55021 .06827 .55268 .07161 .55734 .0698 .55488 .06646 Mtetra
.55488 .06646 .55734 .0698 .56201 .06799 .55955 .06464 Mtetra
.55955 .06464 .56201 .06799 .56669 .06618 .56423 .06282 Mtetra
.56423 .06282 .56669 .06618 .57137 .06436 .56892 .06099 Mtetra
.56892 .06099 .57137 .06436 .57606 .06254 .57362 .05917 Mtetra
.57362 .05917 .57606 .06254 .58076 .06071 .57832 .05734 Mtetra
.57832 .05734 .58076 .06071 .58547 .05888 .58304 .0555 Mtetra
.58304 .0555 .58547 .05888 .59018 .05705 .58776 .05367 Mtetra
.58776 .05367 .59018 .05705 .59491 .05522 .59249 .05183 Mtetra
.59249 .05183 .59491 .05522 .59964 .05338 .59722 .04998 Mtetra
.59722 .04998 .59964 .05338 .60438 .05154 .60197 .04814 Mtetra
.60197 .04814 .60438 .05154 .60913 .0497 .60672 .04629 Mtetra
.60672 .04629 .60913 .0497 .61388 .04785 .61148 .04444 Mtetra
.61148 .04444 .61388 .04785 .61865 .046 .61625 .04258 Mtetra
.61625 .04258 .61865 .046 .62342 .04415 .62103 .04072 Mtetra
.62103 .04072 .62342 .04415 .6282 .04229 .62581 .03886 Mtetra
.62581 .03886 .6282 .04229 .63299 .04044 .63061 .03699 Mtetra
.63061 .03699 .63299 .04044 .63778 .03857 .63541 .03513 Mtetra
.63541 .03513 .63778 .03857 .64259 .03671 .64022 .03326 Mtetra
.64022 .03326 .64259 .03671 .6474 .03484 .64504 .03138 Mtetra
.64504 .03138 .6474 .03484 .65222 .03297 .64986 .0295 Mtetra
.64986 .0295 .65222 .03297 .65705 .03109 .6547 .02762 Mtetra
.6547 .02762 .65705 .03109 .66189 .02921 .65954 .02574 Mtetra
.65954 .02574 .66189 .02921 .66673 .02733 .6644 .02385 Mtetra
.6644 .02385 .66673 .02733 .67159 .02545 .66926 .02196 Mtetra
.66926 .02196 .67159 .02545 .67645 .02356 .67412 .02007 Mtetra
.67412 .02007 .67645 .02356 .68132 .02167 .679 .01817 Mtetra
.679 .01817 .68132 .02167 .6862 .01977 .68389 .01627 Mtetra
.68389 .01627 .6862 .01977 .69109 .01788 .68878 .01436 Mtetra
.68878 .01436 .69109 .01788 .69599 .01598 .69368 .01246 Mtetra
.03931 .26311 .04228 .26587 .04613 .26437 .04316 .26161 Mtetra
.04316 .26161 .04613 .26437 .04998 .26288 .04702 .2601 Mtetra
.04702 .2601 .04998 .26288 .05384 .26137 .05088 .2586 Mtetra
.05088 .2586 .05384 .26137 .0577 .25987 .05475 .25709 Mtetra
.05475 .25709 .0577 .25987 .06158 .25837 .05862 .25558 Mtetra
.05862 .25558 .06158 .25837 .06545 .25686 .0625 .25407 Mtetra
.0625 .25407 .06545 .25686 .06933 .25535 .06639 .25255 Mtetra
.06639 .25255 .06933 .25535 .07322 .25383 .07028 .25104 Mtetra
.07028 .25104 .07322 .25383 .07712 .25232 .07418 .24952 Mtetra
.07418 .24952 .07712 .25232 .08102 .2508 .07808 .24799 Mtetra
.07808 .24799 .08102 .2508 .08492 .24928 .08199 .24647 Mtetra
.08199 .24647 .08492 .24928 .08883 .24776 .0859 .24494 Mtetra
.0859 .24494 .08883 .24776 .09275 .24624 .08983 .24342 Mtetra
.08983 .24342 .09275 .24624 .09668 .24471 .09375 .24188 Mtetra
.09375 .24188 .09668 .24471 .10061 .24318 .09769 .24035 Mtetra
.09769 .24035 .10061 .24318 .10454 .24165 .10163 .23882 Mtetra
.10163 .23882 .10454 .24165 .10849 .24012 .10557 .23728 Mtetra
.10557 .23728 .10849 .24012 .11244 .23858 .10953 .23574 Mtetra
.10953 .23574 .11244 .23858 .11639 .23704 .11348 .23419 Mtetra
.11348 .23419 .11639 .23704 .12035 .2355 .11745 .23265 Mtetra
.11745 .23265 .12035 .2355 .12432 .23396 .12142 .2311 Mtetra
.12142 .2311 .12432 .23396 .12829 .23241 .1254 .22955 Mtetra
.1254 .22955 .12829 .23241 .13227 .23086 .12938 .228 Mtetra
.12938 .228 .13227 .23086 .13626 .22931 .13337 .22644 Mtetra
.13337 .22644 .13626 .22931 .14025 .22776 .13736 .22488 Mtetra
.13736 .22488 .14025 .22776 .14425 .2262 .14137 .22332 Mtetra
.14137 .22332 .14425 .2262 .14825 .22464 .14537 .22176 Mtetra
.14537 .22176 .14825 .22464 .15226 .22308 .14939 .2202 Mtetra
.14939 .2202 .15226 .22308 .15628 .22152 .15341 .21863 Mtetra
.15341 .21863 .15628 .22152 .1603 .21996 .15744 .21706 Mtetra
.15744 .21706 .1603 .21996 .16433 .21839 .16147 .21549 Mtetra
.16147 .21549 .16433 .21839 .16837 .21682 .16551 .21391 Mtetra
.16551 .21391 .16837 .21682 .17241 .21525 .16956 .21234 Mtetra
.16956 .21234 .17241 .21525 .17646 .21367 .17361 .21076 Mtetra
.17361 .21076 .17646 .21367 .18052 .21209 .17767 .20917 Mtetra
.17767 .20917 .18052 .21209 .18458 .21051 .18173 .20759 Mtetra
.18173 .20759 .18458 .21051 .18865 .20893 .1858 .206 Mtetra
.1858 .206 .18865 .20893 .19272 .20735 .18988 .20441 Mtetra
.18988 .20441 .19272 .20735 .1968 .20576 .19397 .20282 Mtetra
.19397 .20282 .1968 .20576 .20089 .20417 .19806 .20123 Mtetra
.19806 .20123 .20089 .20417 .20498 .20258 .20215 .19963 Mtetra
.20215 .19963 .20498 .20258 .20908 .20098 .20626 .19803 Mtetra
.20626 .19803 .20908 .20098 .21319 .19938 .21037 .19643 Mtetra
.21037 .19643 .21319 .19938 .2173 .19778 .21449 .19482 Mtetra
.21449 .19482 .2173 .19778 .22142 .19618 .21861 .19321 Mtetra
.21861 .19321 .22142 .19618 .22555 .19457 .22274 .1916 Mtetra
.22274 .1916 .22555 .19457 .22968 .19297 .22688 .18999 Mtetra
.22688 .18999 .22968 .19297 .23382 .19136 .23102 .18838 Mtetra
.23102 .18838 .23382 .19136 .23797 .18974 .23517 .18676 Mtetra
.23517 .18676 .23797 .18974 .24212 .18813 .23933 .18514 Mtetra
.23933 .18514 .24212 .18813 .24628 .18651 .24349 .18352 Mtetra
.24349 .18352 .24628 .18651 .25044 .18489 .24766 .18189 Mtetra
.24766 .18189 .25044 .18489 .25462 .18327 .25184 .18026 Mtetra
.25184 .18026 .25462 .18327 .2588 .18164 .25602 .17863 Mtetra
.25602 .17863 .2588 .18164 .26298 .18001 .26021 .177 Mtetra
.26021 .177 .26298 .18001 .26717 .17838 .2644 .17536 Mtetra
.2644 .17536 .26717 .17838 .27137 .17675 .26861 .17372 Mtetra
.26861 .17372 .27137 .17675 .27558 .17511 .27282 .17208 Mtetra
.27282 .17208 .27558 .17511 .27979 .17347 .27704 .17044 Mtetra
.27704 .17044 .27979 .17347 .28401 .17183 .28126 .16879 Mtetra
.28126 .16879 .28401 .17183 .28824 .17019 .28549 .16714 Mtetra
.28549 .16714 .28824 .17019 .29247 .16854 .28973 .16549 Mtetra
.28973 .16549 .29247 .16854 .29671 .16689 .29397 .16384 Mtetra
.29397 .16384 .29671 .16689 .30096 .16524 .29822 .16218 Mtetra
.29822 .16218 .30096 .16524 .30521 .16358 .30248 .16052 Mtetra
.30248 .16052 .30521 .16358 .30947 .16193 .30674 .15886 Mtetra
.30674 .15886 .30947 .16193 .31374 .16027 .31102 .15719 Mtetra
.31102 .15719 .31374 .16027 .31801 .1586 .31529 .15553 Mtetra
.31529 .15553 .31801 .1586 .3223 .15694 .31958 .15386 Mtetra
.31958 .15386 .3223 .15694 .32658 .15527 .32387 .15218 Mtetra
.32387 .15218 .32658 .15527 .33088 .1536 .32817 .15051 Mtetra
.32817 .15051 .33088 .1536 .33518 .15192 .33248 .14883 Mtetra
.33248 .14883 .33518 .15192 .33949 .15025 .33679 .14715 Mtetra
.33679 .14715 .33949 .15025 .34381 .14857 .34111 .14546 Mtetra
.34111 .14546 .34381 .14857 .34813 .14689 .34544 .14378 Mtetra
.34544 .14378 .34813 .14689 .35246 .1452 .34977 .14209 Mtetra
.34977 .14209 .35246 .1452 .3568 .14352 .35411 .14039 Mtetra
.35411 .14039 .3568 .14352 .36114 .14183 .35846 .1387 Mtetra
.35846 .1387 .36114 .14183 .36549 .14013 .36282 .137 Mtetra
.36282 .137 .36549 .14013 .36985 .13844 .36718 .1353 Mtetra
.36718 .1353 .36985 .13844 .37421 .13674 .37155 .1336 Mtetra
.37155 .1336 .37421 .13674 .37859 .13504 .37593 .13189 Mtetra
.37593 .13189 .37859 .13504 .38297 .13333 .38031 .13018 Mtetra
0 .181 .695 r
.38031 .13018 .38297 .13333 .38712 .13658 .38447 .13343 Mtetra
.663 .742 .908 r
.38447 .13343 .38712 .13658 .39152 .13487 .38887 .13171 Mtetra
.38887 .13171 .39152 .13487 .39593 .13316 .39329 .13 Mtetra
.39329 .13 .39593 .13316 .40035 .13145 .39771 .12828 Mtetra
.39771 .12828 .40035 .13145 .40477 .12973 .40213 .12655 Mtetra
.40213 .12655 .40477 .12973 .4092 .12801 .40657 .12483 Mtetra
.40657 .12483 .4092 .12801 .41364 .12629 .41101 .1231 Mtetra
.41101 .1231 .41364 .12629 .41808 .12456 .41546 .12137 Mtetra
.41546 .12137 .41808 .12456 .42254 .12284 .41992 .11964 Mtetra
.41992 .11964 .42254 .12284 .427 .12111 .42438 .1179 Mtetra
.42438 .1179 .427 .12111 .43146 .11937 .42885 .11616 Mtetra
.42885 .11616 .43146 .11937 .43594 .11763 .43333 .11442 Mtetra
.43333 .11442 .43594 .11763 .44042 .1159 .43782 .11268 Mtetra
.43782 .11268 .44042 .1159 .44491 .11415 .44231 .11093 Mtetra
.44231 .11093 .44491 .11415 .44941 .11241 .44681 .10918 Mtetra
.44681 .10918 .44941 .11241 .45391 .11066 .45132 .10742 Mtetra
.45132 .10742 .45391 .11066 .45842 .10891 .45584 .10567 Mtetra
.45584 .10567 .45842 .10891 .46294 .10715 .46036 .10391 Mtetra
.46036 .10391 .46294 .10715 .46747 .1054 .4649 .10215 Mtetra
.4649 .10215 .46747 .1054 .472 .10364 .46943 .10038 Mtetra
.46943 .10038 .472 .10364 .47654 .10187 .47398 .09861 Mtetra
.47398 .09861 .47654 .10187 .48109 .10011 .47854 .09684 Mtetra
.47854 .09684 .48109 .10011 .48565 .09834 .4831 .09507 Mtetra
.884 .787 .748 r
.4831 .09507 .48565 .09834 .49027 .09159 .48773 .08831 Mtetra
.664 .741 .908 r
.48773 .08831 .49027 .09159 .49484 .08981 .4923 .08653 Mtetra
.4923 .08653 .49484 .08981 .49941 .08803 .49688 .08474 Mtetra
.49688 .08474 .49941 .08803 .50399 .08625 .50146 .08296 Mtetra
.50146 .08296 .50399 .08625 .50858 .08447 .50605 .08117 Mtetra
.50605 .08117 .50858 .08447 .51317 .08268 .51065 .07937 Mtetra
.51065 .07937 .51317 .08268 .51778 .08089 .51526 .07758 Mtetra
.51526 .07758 .51778 .08089 .52239 .0791 .51988 .07578 Mtetra
.51988 .07578 .52239 .0791 .527 .0773 .5245 .07397 Mtetra
.5245 .07397 .527 .0773 .53163 .0755 .52913 .07217 Mtetra
.52913 .07217 .53163 .0755 .53626 .0737 .53377 .07036 Mtetra
.53377 .07036 .53626 .0737 .54091 .07189 .53842 .06855 Mtetra
.53842 .06855 .54091 .07189 .54556 .07008 .54307 .06674 Mtetra
.54307 .06674 .54556 .07008 .55021 .06827 .54774 .06492 Mtetra
.54774 .06492 .55021 .06827 .55488 .06646 .55241 .0631 Mtetra
.55241 .0631 .55488 .06646 .55955 .06464 .55708 .06127 Mtetra
.55708 .06127 .55955 .06464 .56423 .06282 .56177 .05945 Mtetra
.56177 .05945 .56423 .06282 .56892 .06099 .56646 .05762 Mtetra
.56646 .05762 .56892 .06099 .57362 .05917 .57117 .05578 Mtetra
.57117 .05578 .57362 .05917 .57832 .05734 .57588 .05395 Mtetra
.57588 .05395 .57832 .05734 .58304 .0555 .58059 .05211 Mtetra
.58059 .05211 .58304 .0555 .58776 .05367 .58532 .05027 Mtetra
.58532 .05027 .58776 .05367 .59249 .05183 .59006 .04842 Mtetra
.59006 .04842 .59249 .05183 .59722 .04998 .5948 .04657 Mtetra
.5948 .04657 .59722 .04998 .60197 .04814 .59955 .04472 Mtetra
.59955 .04472 .60197 .04814 .60672 .04629 .60431 .04287 Mtetra
.60431 .04287 .60672 .04629 .61148 .04444 .60907 .04101 Mtetra
.60907 .04101 .61148 .04444 .61625 .04258 .61385 .03915 Mtetra
.61385 .03915 .61625 .04258 .62103 .04072 .61863 .03728 Mtetra
.61863 .03728 .62103 .04072 .62581 .03886 .62342 .03541 Mtetra
.62342 .03541 .62581 .03886 .63061 .03699 .62822 .03354 Mtetra
.62822 .03354 .63061 .03699 .63541 .03513 .63303 .03167 Mtetra
.63303 .03167 .63541 .03513 .64022 .03326 .63784 .02979 Mtetra
.63784 .02979 .64022 .03326 .64504 .03138 .64267 .02791 Mtetra
.64267 .02791 .64504 .03138 .64986 .0295 .6475 .02603 Mtetra
.6475 .02603 .64986 .0295 .6547 .02762 .65234 .02414 Mtetra
.65234 .02414 .6547 .02762 .65954 .02574 .65719 .02225 Mtetra
.65719 .02225 .65954 .02574 .6644 .02385 .66205 .02036 Mtetra
.66205 .02036 .6644 .02385 .66926 .02196 .66691 .01846 Mtetra
.66691 .01846 .66926 .02196 .67412 .02007 .67179 .01656 Mtetra
.67179 .01656 .67412 .02007 .679 .01817 .67667 .01466 Mtetra
.67667 .01466 .679 .01817 .68389 .01627 .68156 .01275 Mtetra
.68156 .01275 .68389 .01627 .68878 .01436 .68646 .01084 Mtetra
.68646 .01084 .68878 .01436 .69368 .01246 .69137 .00893 Mtetra
.03634 .26033 .03931 .26311 .04316 .26161 .04019 .25883 Mtetra
.04019 .25883 .04316 .26161 .04702 .2601 .04405 .25732 Mtetra
.04405 .25732 .04702 .2601 .05088 .2586 .04791 .25581 Mtetra
.04791 .25581 .05088 .2586 .05475 .25709 .05178 .2543 Mtetra
.05178 .2543 .05475 .25709 .05862 .25558 .05566 .25279 Mtetra
.05566 .25279 .05862 .25558 .0625 .25407 .05954 .25127 Mtetra
.05954 .25127 .0625 .25407 .06639 .25255 .06343 .24975 Mtetra
.06343 .24975 .06639 .25255 .07028 .25104 .06733 .24823 Mtetra
.06733 .24823 .07028 .25104 .07418 .24952 .07123 .24671 Mtetra
.07123 .24671 .07418 .24952 .07808 .24799 .07513 .24518 Mtetra
.07513 .24518 .07808 .24799 .08199 .24647 .07905 .24365 Mtetra
.07905 .24365 .08199 .24647 .0859 .24494 .08297 .24212 Mtetra
.08297 .24212 .0859 .24494 .08983 .24342 .08689 .24059 Mtetra
.08689 .24059 .08983 .24342 .09375 .24188 .09082 .23905 Mtetra
.09082 .23905 .09375 .24188 .09769 .24035 .09476 .23751 Mtetra
.09476 .23751 .09769 .24035 .10163 .23882 .0987 .23597 Mtetra
.0987 .23597 .10163 .23882 .10557 .23728 .10265 .23443 Mtetra
.10265 .23443 .10557 .23728 .10953 .23574 .10661 .23289 Mtetra
.10661 .23289 .10953 .23574 .11348 .23419 .11057 .23134 Mtetra
.11057 .23134 .11348 .23419 .11745 .23265 .11454 .22979 Mtetra
.11454 .22979 .11745 .23265 .12142 .2311 .11851 .22824 Mtetra
.11851 .22824 .12142 .2311 .1254 .22955 .12249 .22668 Mtetra
.12249 .22668 .1254 .22955 .12938 .228 .12648 .22512 Mtetra
.12648 .22512 .12938 .228 .13337 .22644 .13047 .22356 Mtetra
.13047 .22356 .13337 .22644 .13736 .22488 .13447 .222 Mtetra
.13447 .222 .13736 .22488 .14137 .22332 .13848 .22044 Mtetra
.13848 .22044 .14137 .22332 .14537 .22176 .14249 .21887 Mtetra
.14249 .21887 .14537 .22176 .14939 .2202 .14651 .2173 Mtetra
.14651 .2173 .14939 .2202 .15341 .21863 .15053 .21573 Mtetra
.15053 .21573 .15341 .21863 .15744 .21706 .15456 .21416 Mtetra
.15456 .21416 .15744 .21706 .16147 .21549 .1586 .21258 Mtetra
.1586 .21258 .16147 .21549 .16551 .21391 .16264 .211 Mtetra
.16264 .211 .16551 .21391 .16956 .21234 .16669 .20942 Mtetra
.16669 .20942 .16956 .21234 .17361 .21076 .17075 .20783 Mtetra
.17075 .20783 .17361 .21076 .17767 .20917 .17481 .20625 Mtetra
.17481 .20625 .17767 .20917 .18173 .20759 .17888 .20466 Mtetra
.17888 .20466 .18173 .20759 .1858 .206 .18295 .20307 Mtetra
.18295 .20307 .1858 .206 .18988 .20441 .18703 .20147 Mtetra
.18703 .20147 .18988 .20441 .19397 .20282 .19112 .19987 Mtetra
.19112 .19987 .19397 .20282 .19806 .20123 .19522 .19828 Mtetra
.19522 .19828 .19806 .20123 .20215 .19963 .19932 .19667 Mtetra
.19932 .19667 .20215 .19963 .20626 .19803 .20343 .19507 Mtetra
.20343 .19507 .20626 .19803 .21037 .19643 .20754 .19346 Mtetra
.20754 .19346 .21037 .19643 .21449 .19482 .21166 .19185 Mtetra
.21166 .19185 .21449 .19482 .21861 .19321 .21579 .19024 Mtetra
.21579 .19024 .21861 .19321 .22274 .1916 .21992 .18863 Mtetra
.21992 .18863 .22274 .1916 .22688 .18999 .22406 .18701 Mtetra
.22406 .18701 .22688 .18999 .23102 .18838 .22821 .18539 Mtetra
.22821 .18539 .23102 .18838 .23517 .18676 .23236 .18377 Mtetra
.23236 .18377 .23517 .18676 .23933 .18514 .23652 .18214 Mtetra
.23652 .18214 .23933 .18514 .24349 .18352 .24069 .18051 Mtetra
.24069 .18051 .24349 .18352 .24766 .18189 .24487 .17888 Mtetra
.24487 .17888 .24766 .18189 .25184 .18026 .24905 .17725 Mtetra
.24905 .17725 .25184 .18026 .25602 .17863 .25323 .17561 Mtetra
.25323 .17561 .25602 .17863 .26021 .177 .25743 .17398 Mtetra
.25743 .17398 .26021 .177 .2644 .17536 .26163 .17234 Mtetra
.26163 .17234 .2644 .17536 .26861 .17372 .26583 .17069 Mtetra
.26583 .17069 .26861 .17372 .27282 .17208 .27005 .16905 Mtetra
.27005 .16905 .27282 .17208 .27704 .17044 .27427 .1674 Mtetra
.27427 .1674 .27704 .17044 .28126 .16879 .2785 .16575 Mtetra
.2785 .16575 .28126 .16879 .28549 .16714 .28273 .16409 Mtetra
.28273 .16409 .28549 .16714 .28973 .16549 .28697 .16244 Mtetra
.28697 .16244 .28973 .16549 .29397 .16384 .29122 .16078 Mtetra
.29122 .16078 .29397 .16384 .29822 .16218 .29548 .15911 Mtetra
.29548 .15911 .29822 .16218 .30248 .16052 .29974 .15745 Mtetra
.29974 .15745 .30248 .16052 .30674 .15886 .30401 .15578 Mtetra
.30401 .15578 .30674 .15886 .31102 .15719 .30828 .15411 Mtetra
.30828 .15411 .31102 .15719 .31529 .15553 .31256 .15244 Mtetra
.31256 .15244 .31529 .15553 .31958 .15386 .31685 .15076 Mtetra
.31685 .15076 .31958 .15386 .32387 .15218 .32115 .14909 Mtetra
.32115 .14909 .32387 .15218 .32817 .15051 .32545 .14741 Mtetra
.32545 .14741 .32817 .15051 .33248 .14883 .32977 .14572 Mtetra
.32977 .14572 .33248 .14883 .33679 .14715 .33408 .14404 Mtetra
.33408 .14404 .33679 .14715 .34111 .14546 .33841 .14235 Mtetra
.33841 .14235 .34111 .14546 .34544 .14378 .34274 .14065 Mtetra
.34274 .14065 .34544 .14378 .34977 .14209 .34708 .13896 Mtetra
.34708 .13896 .34977 .14209 .35411 .14039 .35142 .13726 Mtetra
.35142 .13726 .35411 .14039 .35846 .1387 .35578 .13556 Mtetra
.35578 .13556 .35846 .1387 .36282 .137 .36014 .13386 Mtetra
.36014 .13386 .36282 .137 .36718 .1353 .3645 .13215 Mtetra
.3645 .13215 .36718 .1353 .37155 .1336 .36888 .13044 Mtetra
.36888 .13044 .37155 .1336 .37593 .13189 .37326 .12873 Mtetra
.37326 .12873 .37593 .13189 .38031 .13018 .37765 .12702 Mtetra
0 .181 .695 r
.37765 .12702 .38031 .13018 .38447 .13343 .3818 .13026 Mtetra
.663 .742 .908 r
.3818 .13026 .38447 .13343 .38887 .13171 .38621 .12854 Mtetra
.38621 .12854 .38887 .13171 .39329 .13 .39063 .12682 Mtetra
.39063 .12682 .39329 .13 .39771 .12828 .39506 .1251 Mtetra
.39506 .1251 .39771 .12828 .40213 .12655 .39949 .12337 Mtetra
.39949 .12337 .40213 .12655 .40657 .12483 .40393 .12164 Mtetra
.40393 .12164 .40657 .12483 .41101 .1231 .40837 .11991 Mtetra
.40837 .11991 .41101 .1231 .41546 .12137 .41283 .11817 Mtetra
.41283 .11817 .41546 .12137 .41992 .11964 .41729 .11643 Mtetra
.41729 .11643 .41992 .11964 .42438 .1179 .42176 .11469 Mtetra
.42176 .11469 .42438 .1179 .42885 .11616 .42624 .11295 Mtetra
.42624 .11295 .42885 .11616 .43333 .11442 .43072 .1112 Mtetra
.43072 .1112 .43333 .11442 .43782 .11268 .43521 .10945 Mtetra
.43521 .10945 .43782 .11268 .44231 .11093 .43971 .10769 Mtetra
.43971 .10769 .44231 .11093 .44681 .10918 .44422 .10594 Mtetra
.44422 .10594 .44681 .10918 .45132 .10742 .44873 .10418 Mtetra
.44873 .10418 .45132 .10742 .45584 .10567 .45325 .10242 Mtetra
.45325 .10242 .45584 .10567 .46036 .10391 .45778 .10065 Mtetra
.45778 .10065 .46036 .10391 .4649 .10215 .46232 .09889 Mtetra
.46232 .09889 .4649 .10215 .46943 .10038 .46686 .09711 Mtetra
.46686 .09711 .46943 .10038 .47398 .09861 .47141 .09534 Mtetra
.47141 .09534 .47398 .09861 .47854 .09684 .47597 .09356 Mtetra
.47597 .09356 .47854 .09684 .4831 .09507 .48054 .09178 Mtetra
.884 .787 .748 r
.48054 .09178 .4831 .09507 .48773 .08831 .48518 .08502 Mtetra
.664 .741 .908 r
.48518 .08502 .48773 .08831 .4923 .08653 .48975 .08323 Mtetra
.48975 .08323 .4923 .08653 .49688 .08474 .49434 .08144 Mtetra
.49434 .08144 .49688 .08474 .50146 .08296 .49893 .07965 Mtetra
.49893 .07965 .50146 .08296 .50605 .08117 .50352 .07785 Mtetra
.50352 .07785 .50605 .08117 .51065 .07937 .50813 .07605 Mtetra
.50813 .07605 .51065 .07937 .51526 .07758 .51274 .07425 Mtetra
.51274 .07425 .51526 .07758 .51988 .07578 .51736 .07245 Mtetra
.51736 .07245 .51988 .07578 .5245 .07397 .52199 .07064 Mtetra
.52199 .07064 .5245 .07397 .52913 .07217 .52663 .06883 Mtetra
.52663 .06883 .52913 .07217 .53377 .07036 .53127 .06701 Mtetra
.53127 .06701 .53377 .07036 .53842 .06855 .53592 .0652 Mtetra
.53592 .0652 .53842 .06855 .54307 .06674 .54058 .06338 Mtetra
.54058 .06338 .54307 .06674 .54774 .06492 .54525 .06155 Mtetra
.54525 .06155 .54774 .06492 .55241 .0631 .54993 .05973 Mtetra
.54993 .05973 .55241 .0631 .55708 .06127 .55461 .0579 Mtetra
.55461 .0579 .55708 .06127 .56177 .05945 .5593 .05607 Mtetra
.5593 .05607 .56177 .05945 .56646 .05762 .564 .05423 Mtetra
.564 .05423 .56646 .05762 .57117 .05578 .56871 .05239 Mtetra
.56871 .05239 .57117 .05578 .57588 .05395 .57342 .05055 Mtetra
.57342 .05055 .57588 .05395 .58059 .05211 .57815 .0487 Mtetra
.57815 .0487 .58059 .05211 .58532 .05027 .58288 .04686 Mtetra
.58288 .04686 .58532 .05027 .59006 .04842 .58762 .04501 Mtetra
.58762 .04501 .59006 .04842 .5948 .04657 .59236 .04315 Mtetra
.59236 .04315 .5948 .04657 .59955 .04472 .59712 .04129 Mtetra
.59712 .04129 .59955 .04472 .60431 .04287 .60188 .03943 Mtetra
.60188 .03943 .60431 .04287 .60907 .04101 .60666 .03757 Mtetra
.60666 .03757 .60907 .04101 .61385 .03915 .61144 .0357 Mtetra
.61144 .0357 .61385 .03915 .61863 .03728 .61623 .03383 Mtetra
.61623 .03383 .61863 .03728 .62342 .03541 .62102 .03196 Mtetra
.62102 .03196 .62342 .03541 .62822 .03354 .62583 .03008 Mtetra
.62583 .03008 .62822 .03354 .63303 .03167 .63064 .0282 Mtetra
.63064 .0282 .63303 .03167 .63784 .02979 .63546 .02632 Mtetra
.63546 .02632 .63784 .02979 .64267 .02791 .64029 .02443 Mtetra
.64029 .02443 .64267 .02791 .6475 .02603 .64513 .02254 Mtetra
.64513 .02254 .6475 .02603 .65234 .02414 .64998 .02065 Mtetra
.64998 .02065 .65234 .02414 .65719 .02225 .65483 .01875 Mtetra
.65483 .01875 .65719 .02225 .66205 .02036 .65969 .01685 Mtetra
.65969 .01685 .66205 .02036 .66691 .01846 .66456 .01495 Mtetra
.66456 .01495 .66691 .01846 .67179 .01656 .66944 .01304 Mtetra
.66944 .01304 .67179 .01656 .67667 .01466 .67433 .01113 Mtetra
.67433 .01113 .67667 .01466 .68156 .01275 .67923 .00922 Mtetra
.67923 .00922 .68156 .01275 .68646 .01084 .68414 .00731 Mtetra
.68414 .00731 .68646 .01084 .69137 .00893 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37803e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.646 .762 .934 r
.3959 .80403 .39806 .80578 .40167 .80483 .39951 .80308 Mtetra
.39951 .80308 .40167 .80483 .40528 .80388 .40313 .80213 Mtetra
.40313 .80213 .40528 .80388 .40889 .80293 .40674 .80117 Mtetra
.40674 .80117 .40889 .80293 .41252 .80198 .41037 .80022 Mtetra
.41037 .80022 .41252 .80198 .41614 .80103 .414 .79926 Mtetra
.414 .79926 .41614 .80103 .41977 .80007 .41763 .79831 Mtetra
.41763 .79831 .41977 .80007 .42341 .79912 .42127 .79735 Mtetra
.42127 .79735 .42341 .79912 .42705 .79816 .42492 .79639 Mtetra
.42492 .79639 .42705 .79816 .4307 .7972 .42857 .79543 Mtetra
.42857 .79543 .4307 .7972 .43435 .79624 .43222 .79447 Mtetra
.43222 .79447 .43435 .79624 .438 .79528 .43588 .7935 Mtetra
.43588 .7935 .438 .79528 .44166 .79432 .43954 .79254 Mtetra
.43954 .79254 .44166 .79432 .44533 .79336 .44321 .79157 Mtetra
.44321 .79157 .44533 .79336 .449 .79239 .44688 .79061 Mtetra
.44688 .79061 .449 .79239 .45268 .79143 .45056 .78964 Mtetra
.45056 .78964 .45268 .79143 .45636 .79046 .45425 .78867 Mtetra
.45425 .78867 .45636 .79046 .46004 .78949 .45794 .7877 Mtetra
.45794 .7877 .46004 .78949 .46373 .78852 .46163 .78673 Mtetra
.46163 .78673 .46373 .78852 .46743 .78755 .46533 .78575 Mtetra
.46533 .78575 .46743 .78755 .47113 .78658 .46903 .78478 Mtetra
.46903 .78478 .47113 .78658 .47483 .7856 .47274 .7838 Mtetra
.943 .696 .534 r
.47274 .7838 .47483 .7856 .47983 .68466 .4778 .68278 Mtetra
.655 .752 .921 r
.4778 .68278 .47983 .68466 .48344 .68364 .48142 .68176 Mtetra
.48142 .68176 .48344 .68364 .48706 .68262 .48504 .68074 Mtetra
.48504 .68074 .48706 .68262 .49068 .68161 .48866 .67972 Mtetra
.48866 .67972 .49068 .68161 .49431 .68059 .49229 .6787 Mtetra
.49229 .6787 .49431 .68059 .49795 .67957 .49593 .67768 Mtetra
.49593 .67768 .49795 .67957 .50158 .67854 .49957 .67665 Mtetra
.49957 .67665 .50158 .67854 .50523 .67752 .50322 .67563 Mtetra
.50322 .67563 .50523 .67752 .50887 .67649 .50687 .6746 Mtetra
.50687 .6746 .50887 .67649 .51252 .67547 .51052 .67357 Mtetra
.51052 .67357 .51252 .67547 .51618 .67444 .51418 .67254 Mtetra
.51418 .67254 .51618 .67444 .51984 .67341 .51785 .67151 Mtetra
.51785 .67151 .51984 .67341 .52351 .67238 .52152 .67047 Mtetra
.52152 .67047 .52351 .67238 .52718 .67135 .52519 .66944 Mtetra
.52519 .66944 .52718 .67135 .53086 .67032 .52887 .6684 Mtetra
.52887 .6684 .53086 .67032 .53454 .66928 .53256 .66737 Mtetra
.53256 .66737 .53454 .66928 .53823 .66824 .53625 .66633 Mtetra
.53625 .66633 .53823 .66824 .54192 .66721 .53994 .66529 Mtetra
.53994 .66529 .54192 .66721 .54561 .66617 .54364 .66425 Mtetra
.54364 .66425 .54561 .66617 .54932 .66513 .54735 .6632 Mtetra
.54735 .6632 .54932 .66513 .55302 .66409 .55106 .66216 Mtetra
.55106 .66216 .55302 .66409 .55673 .66304 .55477 .66111 Mtetra
.55477 .66111 .55673 .66304 .56045 .662 .55849 .66007 Mtetra
.55849 .66007 .56045 .662 .56417 .66095 .56221 .65902 Mtetra
.56221 .65902 .56417 .66095 .5679 .65991 .56594 .65797 Mtetra
.56594 .65797 .5679 .65991 .57163 .65886 .56968 .65692 Mtetra
.56968 .65692 .57163 .65886 .57536 .65781 .57342 .65586 Mtetra
.57342 .65586 .57536 .65781 .57911 .65676 .57716 .65481 Mtetra
.957 .64 .385 r
.57716 .65481 .57911 .65676 .58285 .6557 .58139 .68349 Mtetra
.557 .326 .52 r
.58139 .68349 .58285 .6557 .58713 .68438 .58518 .68245 Mtetra
.653 .755 .925 r
.58518 .68245 .58713 .68438 .59092 .68333 .58897 .6814 Mtetra
.58897 .6814 .59092 .68333 .59471 .68229 .59277 .68035 Mtetra
.59277 .68035 .59471 .68229 .59851 .68124 .59657 .6793 Mtetra
.59657 .6793 .59851 .68124 .60232 .68019 .60038 .67825 Mtetra
.60038 .67825 .60232 .68019 .60613 .67914 .60419 .6772 Mtetra
.60419 .6772 .60613 .67914 .60994 .67809 .60801 .67614 Mtetra
.958 .638 .373 r
.60801 .67614 .60994 .67809 .61453 .70736 .61259 .70543 Mtetra
.65 .758 .928 r
.61259 .70543 .61453 .70736 .61839 .70632 .61645 .70439 Mtetra
.61645 .70439 .61839 .70632 .62226 .70527 .62032 .70334 Mtetra
.62032 .70334 .62226 .70527 .62613 .70423 .62419 .70229 Mtetra
.62419 .70229 .62613 .70423 .63 .70318 .62807 .70124 Mtetra
.62807 .70124 .63 .70318 .63388 .70213 .63196 .70019 Mtetra
.63196 .70019 .63388 .70213 .63777 .70108 .63585 .69914 Mtetra
.63585 .69914 .63777 .70108 .64166 .70003 .63974 .69808 Mtetra
.63974 .69808 .64166 .70003 .64556 .69898 .64364 .69703 Mtetra
.64364 .69703 .64556 .69898 .64946 .69792 .64755 .69597 Mtetra
.64755 .69597 .64946 .69792 .65337 .69687 .65146 .69491 Mtetra
.65146 .69491 .65337 .69687 .65728 .69581 .65537 .69385 Mtetra
.65537 .69385 .65728 .69581 .6612 .69475 .6593 .69279 Mtetra
.6593 .69279 .6612 .69475 .66512 .69369 .66322 .69173 Mtetra
.66322 .69173 .66512 .69369 .66905 .69263 .66716 .69066 Mtetra
.66716 .69066 .66905 .69263 .67298 .69156 .6711 .6896 Mtetra
.6711 .6896 .67298 .69156 .67692 .6905 .67504 .68853 Mtetra
.67504 .68853 .67692 .6905 .68087 .68943 .67899 .68746 Mtetra
.67899 .68746 .68087 .68943 .68482 .68837 .68294 .68639 Mtetra
.68294 .68639 .68482 .68837 .68878 .6873 .6869 .68532 Mtetra
.6869 .68532 .68878 .6873 .69274 .68623 .69087 .68425 Mtetra
.69087 .68425 .69274 .68623 .69671 .68515 .69484 .68317 Mtetra
.69484 .68317 .69671 .68515 .70068 .68408 .69882 .68209 Mtetra
.69882 .68209 .70068 .68408 .70466 .683 .7028 .68102 Mtetra
.7028 .68102 .70466 .683 .70865 .68193 .70679 .67994 Mtetra
.70679 .67994 .70865 .68193 .71264 .68085 .71079 .67886 Mtetra
.71079 .67886 .71264 .68085 .71663 .67977 .71478 .67777 Mtetra
.71478 .67777 .71663 .67977 .72063 .67869 .71879 .67669 Mtetra
.71879 .67669 .72063 .67869 .72464 .67761 .7228 .6756 Mtetra
.969 .707 .481 r
.7228 .6756 .72464 .67761 .72482 .61075 .72302 .6087 Mtetra
.656 .751 .92 r
.72302 .6087 .72482 .61075 .72876 .60964 .72696 .60758 Mtetra
.72696 .60758 .72876 .60964 .73271 .60853 .73091 .60647 Mtetra
.73091 .60647 .73271 .60853 .73666 .60741 .73487 .60535 Mtetra
.73487 .60535 .73666 .60741 .74062 .6063 .73883 .60423 Mtetra
.73883 .60423 .74062 .6063 .74458 .60518 .74279 .60311 Mtetra
.74279 .60311 .74458 .60518 .75018 .62912 .74676 .60199 Mtetra
.19 .127 .55 r
.74676 .60199 .75018 .62912 .75418 .62801 .75239 .62595 Mtetra
.654 .754 .923 r
.75239 .62595 .75418 .62801 .75819 .6269 .75641 .62484 Mtetra
.75641 .62484 .75819 .6269 .76221 .62578 .76043 .62372 Mtetra
.76043 .62372 .76221 .62578 .76623 .62467 .76445 .6226 Mtetra
.76445 .6226 .76623 .62467 .77025 .62355 .76848 .62148 Mtetra
.76848 .62148 .77025 .62355 .77428 .62243 .77251 .62036 Mtetra
.77251 .62036 .77428 .62243 .77832 .62131 .77656 .61924 Mtetra
.77656 .61924 .77832 .62131 .78236 .62019 .7806 .61811 Mtetra
.7806 .61811 .78236 .62019 .78641 .61907 .78465 .61699 Mtetra
.78465 .61699 .78641 .61907 .79047 .61794 .78871 .61586 Mtetra
.78871 .61586 .79047 .61794 .79453 .61681 .79278 .61473 Mtetra
.79278 .61473 .79453 .61681 .79859 .61569 .79685 .6136 Mtetra
.79685 .6136 .79859 .61569 .80266 .61456 .80092 .61247 Mtetra
.80092 .61247 .80266 .61456 .80674 .61343 .805 .61133 Mtetra
.805 .61133 .80674 .61343 .81082 .61229 .80909 .6102 Mtetra
.80909 .6102 .81082 .61229 .81491 .61116 .81318 .60906 Mtetra
.81318 .60906 .81491 .61116 .819 .61002 .81728 .60792 Mtetra
.81728 .60792 .819 .61002 .8231 .60888 .82138 .60678 Mtetra
.82138 .60678 .8231 .60888 .82721 .60774 .82549 .60564 Mtetra
.82549 .60564 .82721 .60774 .83132 .6066 .82961 .60449 Mtetra
.82961 .60449 .83132 .6066 .83544 .60546 .83373 .60335 Mtetra
.83373 .60335 .83544 .60546 .83956 .60432 .83786 .6022 Mtetra
.83786 .6022 .83956 .60432 .84369 .60317 .84199 .60105 Mtetra
.84199 .60105 .84369 .60317 .84783 .60202 .84613 .5999 Mtetra
.84613 .5999 .84783 .60202 .85197 .60088 .85028 .59875 Mtetra
.921 .541 .135 r
.85028 .59875 .85197 .60088 .8581 .62024 .85641 .61812 Mtetra
.652 .756 .926 r
.85641 .61812 .8581 .62024 .86228 .61909 .86059 .61698 Mtetra
.86059 .61698 .86228 .61909 .86646 .61795 .86478 .61583 Mtetra
.86478 .61583 .86646 .61795 .87066 .6168 .86897 .61468 Mtetra
.86897 .61468 .87066 .6168 .87485 .61565 .87318 .61352 Mtetra
.87318 .61352 .87485 .61565 .87906 .6145 .87738 .61237 Mtetra
.87738 .61237 .87906 .6145 .88327 .61335 .8816 .61121 Mtetra
.8816 .61121 .88327 .61335 .88748 .61219 .88582 .61006 Mtetra
.88582 .61006 .88748 .61219 .8917 .61104 .89004 .6089 Mtetra
.89004 .6089 .8917 .61104 .89593 .60988 .89427 .60774 Mtetra
.89427 .60774 .89593 .60988 .90016 .60872 .89851 .60657 Mtetra
.89851 .60657 .90016 .60872 .9044 .60756 .90276 .60541 Mtetra
.90276 .60541 .9044 .60756 .90865 .6064 .90701 .60424 Mtetra
.90701 .60424 .90865 .6064 .9129 .60523 .91126 .60308 Mtetra
.91126 .60308 .9129 .60523 .91716 .60406 .91552 .60191 Mtetra
.91552 .60191 .91716 .60406 .92142 .6029 .91979 .60074 Mtetra
.91979 .60074 .92142 .6029 .92569 .60173 .92407 .59956 Mtetra
.92407 .59956 .92569 .60173 .92997 .60056 .92835 .59839 Mtetra
.92835 .59839 .92997 .60056 .93425 .59938 .93264 .59721 Mtetra
.93264 .59721 .93425 .59938 .93854 .59821 .93693 .59604 Mtetra
.93693 .59604 .93854 .59821 .94284 .59703 .94123 .59486 Mtetra
.94123 .59486 .94284 .59703 .94714 .59585 .94554 .59367 Mtetra
.94554 .59367 .94714 .59585 .95144 .59467 .94985 .59249 Mtetra
.94985 .59249 .95144 .59467 .95576 .59349 .95417 .59131 Mtetra
.95417 .59131 .95576 .59349 .96008 .59231 .95849 .59012 Mtetra
.95849 .59012 .96008 .59231 .96441 .59112 .96282 .58893 Mtetra
.96282 .58893 .96441 .59112 .96874 .58994 .96716 .58774 Mtetra
.96716 .58774 .96874 .58994 .97308 .58875 .9715 .58655 Mtetra
.9715 .58655 .97308 .58875 .97742 .58756 .97585 .58536 Mtetra
.97585 .58536 .97742 .58756 .98177 .58637 .98021 .58416 Mtetra
.98021 .58416 .98177 .58637 .98613 .58517 .98457 .58297 Mtetra
.98457 .58297 .98613 .58517 .9905 .58398 .98894 .58177 Mtetra
.646 .762 .934 r
.39374 .80227 .3959 .80403 .39951 .80308 .39735 .80132 Mtetra
.39735 .80132 .39951 .80308 .40313 .80213 .40097 .80037 Mtetra
.40097 .80037 .40313 .80213 .40674 .80117 .40459 .79941 Mtetra
.40459 .79941 .40674 .80117 .41037 .80022 .40822 .79845 Mtetra
.40822 .79845 .41037 .80022 .414 .79926 .41185 .7975 Mtetra
.41185 .7975 .414 .79926 .41763 .79831 .41549 .79654 Mtetra
.41549 .79654 .41763 .79831 .42127 .79735 .41913 .79558 Mtetra
.41913 .79558 .42127 .79735 .42492 .79639 .42278 .79462 Mtetra
.42278 .79462 .42492 .79639 .42857 .79543 .42643 .79365 Mtetra
.42643 .79365 .42857 .79543 .43222 .79447 .43009 .79269 Mtetra
.43009 .79269 .43222 .79447 .43588 .7935 .43375 .79172 Mtetra
.43375 .79172 .43588 .7935 .43954 .79254 .43742 .79076 Mtetra
.43742 .79076 .43954 .79254 .44321 .79157 .44109 .78979 Mtetra
.44109 .78979 .44321 .79157 .44688 .79061 .44476 .78882 Mtetra
.44476 .78882 .44688 .79061 .45056 .78964 .44845 .78785 Mtetra
.44845 .78785 .45056 .78964 .45425 .78867 .45213 .78688 Mtetra
.45213 .78688 .45425 .78867 .45794 .7877 .45583 .7859 Mtetra
.45583 .7859 .45794 .7877 .46163 .78673 .45952 .78493 Mtetra
.45952 .78493 .46163 .78673 .46533 .78575 .46322 .78395 Mtetra
.46322 .78395 .46533 .78575 .46903 .78478 .46693 .78297 Mtetra
.46693 .78297 .46903 .78478 .47274 .7838 .47064 .782 Mtetra
.943 .696 .534 r
.47064 .782 .47274 .7838 .4778 .68278 .47576 .6809 Mtetra
.655 .752 .921 r
.47576 .6809 .4778 .68278 .48142 .68176 .47938 .67988 Mtetra
.47938 .67988 .48142 .68176 .48504 .68074 .48301 .67886 Mtetra
.48301 .67886 .48504 .68074 .48866 .67972 .48664 .67784 Mtetra
.48664 .67784 .48866 .67972 .49229 .6787 .49027 .67681 Mtetra
.49027 .67681 .49229 .6787 .49593 .67768 .49391 .67578 Mtetra
.49391 .67578 .49593 .67768 .49957 .67665 .49756 .67476 Mtetra
.49756 .67476 .49957 .67665 .50322 .67563 .5012 .67373 Mtetra
.5012 .67373 .50322 .67563 .50687 .6746 .50486 .6727 Mtetra
.50486 .6727 .50687 .6746 .51052 .67357 .50852 .67167 Mtetra
.50852 .67167 .51052 .67357 .51418 .67254 .51218 .67063 Mtetra
.51218 .67063 .51418 .67254 .51785 .67151 .51585 .6696 Mtetra
.51585 .6696 .51785 .67151 .52152 .67047 .51952 .66856 Mtetra
.51952 .66856 .52152 .67047 .52519 .66944 .5232 .66753 Mtetra
.5232 .66753 .52519 .66944 .52887 .6684 .52688 .66649 Mtetra
.52688 .66649 .52887 .6684 .53256 .66737 .53057 .66545 Mtetra
.53057 .66545 .53256 .66737 .53625 .66633 .53426 .66441 Mtetra
.53426 .66441 .53625 .66633 .53994 .66529 .53796 .66336 Mtetra
.53796 .66336 .53994 .66529 .54364 .66425 .54166 .66232 Mtetra
.54166 .66232 .54364 .66425 .54735 .6632 .54537 .66128 Mtetra
.54537 .66128 .54735 .6632 .55106 .66216 .54908 .66023 Mtetra
.54908 .66023 .55106 .66216 .55477 .66111 .5528 .65918 Mtetra
.5528 .65918 .55477 .66111 .55849 .66007 .55653 .65813 Mtetra
.55653 .65813 .55849 .66007 .56221 .65902 .56025 .65708 Mtetra
.56025 .65708 .56221 .65902 .56594 .65797 .56399 .65603 Mtetra
.56399 .65603 .56594 .65797 .56968 .65692 .56772 .65497 Mtetra
.56772 .65497 .56968 .65692 .57342 .65586 .57147 .65392 Mtetra
.57147 .65392 .57342 .65586 .57716 .65481 .57522 .65286 Mtetra
.957 .64 .385 r
.57522 .65286 .57716 .65481 .58139 .68349 .57943 .68156 Mtetra
.653 .755 .925 r
.57943 .68156 .58139 .68349 .58518 .68245 .58322 .68051 Mtetra
.58322 .68051 .58518 .68245 .58897 .6814 .58702 .67946 Mtetra
.58702 .67946 .58897 .6814 .59277 .68035 .59082 .67841 Mtetra
.59082 .67841 .59277 .68035 .59657 .6793 .59463 .67736 Mtetra
.59463 .67736 .59657 .6793 .60038 .67825 .59844 .67631 Mtetra
.59844 .67631 .60038 .67825 .60419 .6772 .60225 .67525 Mtetra
.60225 .67525 .60419 .6772 .60801 .67614 .60608 .67419 Mtetra
.60608 .67419 .60801 .67614 .61259 .70543 .6099 .67313 Mtetra
.115 .057 .508 r
.6099 .67313 .61259 .70543 .61645 .70439 .61451 .70245 Mtetra
.65 .758 .928 r
.61451 .70245 .61645 .70439 .62032 .70334 .61838 .7014 Mtetra
.61838 .7014 .62032 .70334 .62419 .70229 .62226 .70035 Mtetra
.62226 .70035 .62419 .70229 .62807 .70124 .62614 .6993 Mtetra
.62614 .6993 .62807 .70124 .63196 .70019 .63003 .69825 Mtetra
.63003 .69825 .63196 .70019 .63585 .69914 .63392 .69719 Mtetra
.63392 .69719 .63585 .69914 .63974 .69808 .63782 .69613 Mtetra
.63782 .69613 .63974 .69808 .64364 .69703 .64172 .69508 Mtetra
.64172 .69508 .64364 .69703 .64755 .69597 .64563 .69402 Mtetra
.64563 .69402 .64755 .69597 .65146 .69491 .64955 .69295 Mtetra
.64955 .69295 .65146 .69491 .65537 .69385 .65347 .69189 Mtetra
.65347 .69189 .65537 .69385 .6593 .69279 .65739 .69083 Mtetra
.65739 .69083 .6593 .69279 .66322 .69173 .66132 .68976 Mtetra
.66132 .68976 .66322 .69173 .66716 .69066 .66526 .68869 Mtetra
.66526 .68869 .66716 .69066 .6711 .6896 .6692 .68763 Mtetra
.6692 .68763 .6711 .6896 .67504 .68853 .67315 .68656 Mtetra
.67315 .68656 .67504 .68853 .67899 .68746 .6771 .68548 Mtetra
.6771 .68548 .67899 .68746 .68294 .68639 .68106 .68441 Mtetra
.68106 .68441 .68294 .68639 .6869 .68532 .68503 .68334 Mtetra
.68503 .68334 .6869 .68532 .69087 .68425 .689 .68226 Mtetra
.689 .68226 .69087 .68425 .69484 .68317 .69297 .68118 Mtetra
.69297 .68118 .69484 .68317 .69882 .68209 .69695 .6801 Mtetra
.69695 .6801 .69882 .68209 .7028 .68102 .70094 .67902 Mtetra
.70094 .67902 .7028 .68102 .70679 .67994 .70493 .67794 Mtetra
.70493 .67794 .70679 .67994 .71079 .67886 .70893 .67686 Mtetra
.70893 .67686 .71079 .67886 .71478 .67777 .71293 .67577 Mtetra
.71293 .67577 .71478 .67777 .71879 .67669 .71694 .67468 Mtetra
.969 .707 .482 r
.71694 .67468 .71879 .67669 .7228 .6756 .71727 .60775 Mtetra
.58 .385 .581 r
.71727 .60775 .7228 .6756 .72302 .6087 .72121 .60664 Mtetra
.656 .751 .92 r
.72121 .60664 .72302 .6087 .72696 .60758 .72516 .60552 Mtetra
.72516 .60552 .72696 .60758 .73091 .60647 .72911 .60441 Mtetra
.72911 .60441 .73091 .60647 .73487 .60535 .73307 .60329 Mtetra
.73307 .60329 .73487 .60535 .73883 .60423 .73703 .60216 Mtetra
.73703 .60216 .73883 .60423 .74279 .60311 .741 .60104 Mtetra
.741 .60104 .74279 .60311 .74676 .60199 .74498 .59992 Mtetra
.952 .601 .262 r
.74498 .59992 .74676 .60199 .75239 .62595 .7506 .62389 Mtetra
.654 .754 .923 r
.7506 .62389 .75239 .62595 .75641 .62484 .75462 .62278 Mtetra
.75462 .62278 .75641 .62484 .76043 .62372 .75864 .62166 Mtetra
.75864 .62166 .76043 .62372 .76445 .6226 .76267 .62053 Mtetra
.76267 .62053 .76445 .6226 .76848 .62148 .7667 .61941 Mtetra
.7667 .61941 .76848 .62148 .77251 .62036 .77074 .61829 Mtetra
.77074 .61829 .77251 .62036 .77656 .61924 .77479 .61716 Mtetra
.77479 .61716 .77656 .61924 .7806 .61811 .77884 .61603 Mtetra
.77884 .61603 .7806 .61811 .78465 .61699 .78289 .6149 Mtetra
.78289 .6149 .78465 .61699 .78871 .61586 .78695 .61377 Mtetra
.78695 .61377 .78871 .61586 .79278 .61473 .79102 .61264 Mtetra
.79102 .61264 .79278 .61473 .79685 .6136 .7951 .61151 Mtetra
.7951 .61151 .79685 .6136 .80092 .61247 .79918 .61037 Mtetra
.79918 .61037 .80092 .61247 .805 .61133 .80326 .60923 Mtetra
.80326 .60923 .805 .61133 .80909 .6102 .80735 .6081 Mtetra
.80735 .6081 .80909 .6102 .81318 .60906 .81145 .60696 Mtetra
.81145 .60696 .81318 .60906 .81728 .60792 .81555 .60581 Mtetra
.81555 .60581 .81728 .60792 .82138 .60678 .81966 .60467 Mtetra
.81966 .60467 .82138 .60678 .82549 .60564 .82377 .60352 Mtetra
.82377 .60352 .82549 .60564 .82961 .60449 .82789 .60238 Mtetra
.82789 .60238 .82961 .60449 .83373 .60335 .83202 .60123 Mtetra
.83202 .60123 .83373 .60335 .83786 .6022 .83615 .60008 Mtetra
.83615 .60008 .83786 .6022 .84199 .60105 .84029 .59893 Mtetra
.84029 .59893 .84199 .60105 .84613 .5999 .84443 .59777 Mtetra
.922 .543 .138 r
.84443 .59777 .84613 .5999 .85028 .59875 .85052 .61715 Mtetra
.546 .301 .495 r
.85052 .61715 .85028 .59875 .85641 .61812 .85471 .616 Mtetra
.652 .756 .926 r
.85471 .616 .85641 .61812 .86059 .61698 .85889 .61485 Mtetra
.85889 .61485 .86059 .61698 .86478 .61583 .86309 .6137 Mtetra
.86309 .6137 .86478 .61583 .86897 .61468 .86729 .61255 Mtetra
.86729 .61255 .86897 .61468 .87318 .61352 .87149 .61139 Mtetra
.87149 .61139 .87318 .61352 .87738 .61237 .87571 .61023 Mtetra
.87571 .61023 .87738 .61237 .8816 .61121 .87992 .60908 Mtetra
.87992 .60908 .8816 .61121 .88582 .61006 .88415 .60792 Mtetra
.88415 .60792 .88582 .61006 .89004 .6089 .88838 .60675 Mtetra
.88838 .60675 .89004 .6089 .89427 .60774 .89261 .60559 Mtetra
.89261 .60559 .89427 .60774 .89851 .60657 .89686 .60442 Mtetra
.89686 .60442 .89851 .60657 .90276 .60541 .90111 .60326 Mtetra
.90111 .60326 .90276 .60541 .90701 .60424 .90536 .60209 Mtetra
.90536 .60209 .90701 .60424 .91126 .60308 .90962 .60092 Mtetra
.90962 .60092 .91126 .60308 .91552 .60191 .91389 .59974 Mtetra
.91389 .59974 .91552 .60191 .91979 .60074 .91816 .59857 Mtetra
.91816 .59857 .91979 .60074 .92407 .59956 .92244 .59739 Mtetra
.92244 .59739 .92407 .59956 .92835 .59839 .92673 .59622 Mtetra
.92673 .59622 .92835 .59839 .93264 .59721 .93102 .59504 Mtetra
.93102 .59504 .93264 .59721 .93693 .59604 .93532 .59386 Mtetra
.93532 .59386 .93693 .59604 .94123 .59486 .93962 .59267 Mtetra
.93962 .59267 .94123 .59486 .94554 .59367 .94393 .59149 Mtetra
.94393 .59149 .94554 .59367 .94985 .59249 .94825 .5903 Mtetra
.94825 .5903 .94985 .59249 .95417 .59131 .95257 .58912 Mtetra
.95257 .58912 .95417 .59131 .95849 .59012 .9569 .58793 Mtetra
.9569 .58793 .95849 .59012 .96282 .58893 .96124 .58673 Mtetra
.96124 .58673 .96282 .58893 .96716 .58774 .96558 .58554 Mtetra
.96558 .58554 .96716 .58774 .9715 .58655 .96993 .58435 Mtetra
.96993 .58435 .9715 .58655 .97585 .58536 .97428 .58315 Mtetra
.97428 .58315 .97585 .58536 .98021 .58416 .97864 .58195 Mtetra
.97864 .58195 .98021 .58416 .98457 .58297 .98301 .58075 Mtetra
.98301 .58075 .98457 .58297 .98894 .58177 .98739 .57955 Mtetra
.646 .762 .934 r
.39157 .80051 .39374 .80227 .39735 .80132 .39518 .79956 Mtetra
.39518 .79956 .39735 .80132 .40097 .80037 .3988 .7986 Mtetra
.3988 .7986 .40097 .80037 .40459 .79941 .40243 .79764 Mtetra
.40243 .79764 .40459 .79941 .40822 .79845 .40606 .79669 Mtetra
.40606 .79669 .40822 .79845 .41185 .7975 .4097 .79573 Mtetra
.4097 .79573 .41185 .7975 .41549 .79654 .41334 .79476 Mtetra
.41334 .79476 .41549 .79654 .41913 .79558 .41698 .7938 Mtetra
.41698 .7938 .41913 .79558 .42278 .79462 .42063 .79284 Mtetra
.42063 .79284 .42278 .79462 .42643 .79365 .42429 .79187 Mtetra
.42429 .79187 .42643 .79365 .43009 .79269 .42795 .79091 Mtetra
.42795 .79091 .43009 .79269 .43375 .79172 .43161 .78994 Mtetra
.43161 .78994 .43375 .79172 .43742 .79076 .43528 .78897 Mtetra
.43528 .78897 .43742 .79076 .44109 .78979 .43896 .788 Mtetra
.43896 .788 .44109 .78979 .44476 .78882 .44264 .78703 Mtetra
.44264 .78703 .44476 .78882 .44845 .78785 .44632 .78605 Mtetra
.44632 .78605 .44845 .78785 .45213 .78688 .45001 .78508 Mtetra
.45001 .78508 .45213 .78688 .45583 .7859 .45371 .7841 Mtetra
.45371 .7841 .45583 .7859 .45952 .78493 .45741 .78313 Mtetra
.45741 .78313 .45952 .78493 .46322 .78395 .46111 .78215 Mtetra
.46111 .78215 .46322 .78395 .46693 .78297 .46483 .78117 Mtetra
.46483 .78117 .46693 .78297 .47064 .782 .46854 .78019 Mtetra
.943 .696 .534 r
.46854 .78019 .47064 .782 .47576 .6809 .47372 .67902 Mtetra
.655 .752 .921 r
.47372 .67902 .47576 .6809 .47938 .67988 .47735 .67799 Mtetra
.47735 .67799 .47938 .67988 .48301 .67886 .48098 .67697 Mtetra
.48098 .67697 .48301 .67886 .48664 .67784 .48461 .67594 Mtetra
.48461 .67594 .48664 .67784 .49027 .67681 .48825 .67492 Mtetra
.48825 .67492 .49027 .67681 .49391 .67578 .49189 .67389 Mtetra
.49189 .67389 .49391 .67578 .49756 .67476 .49553 .67286 Mtetra
.49553 .67286 .49756 .67476 .5012 .67373 .49919 .67183 Mtetra
.49919 .67183 .5012 .67373 .50486 .6727 .50284 .67079 Mtetra
.50284 .67079 .50486 .6727 .50852 .67167 .5065 .66976 Mtetra
.5065 .66976 .50852 .67167 .51218 .67063 .51017 .66872 Mtetra
.51017 .66872 .51218 .67063 .51585 .6696 .51384 .66769 Mtetra
.51384 .66769 .51585 .6696 .51952 .66856 .51752 .66665 Mtetra
.51752 .66665 .51952 .66856 .5232 .66753 .5212 .66561 Mtetra
.5212 .66561 .5232 .66753 .52688 .66649 .52489 .66457 Mtetra
.52489 .66457 .52688 .66649 .53057 .66545 .52858 .66353 Mtetra
.52858 .66353 .53057 .66545 .53426 .66441 .53227 .66248 Mtetra
.53227 .66248 .53426 .66441 .53796 .66336 .53598 .66144 Mtetra
.53598 .66144 .53796 .66336 .54166 .66232 .53968 .66039 Mtetra
.53968 .66039 .54166 .66232 .54537 .66128 .54339 .65934 Mtetra
.54339 .65934 .54537 .66128 .54908 .66023 .54711 .65829 Mtetra
.54711 .65829 .54908 .66023 .5528 .65918 .55083 .65724 Mtetra
.55083 .65724 .5528 .65918 .55653 .65813 .55456 .65619 Mtetra
.55456 .65619 .55653 .65813 .56025 .65708 .55829 .65514 Mtetra
.55829 .65514 .56025 .65708 .56399 .65603 .56202 .65408 Mtetra
.56202 .65408 .56399 .65603 .56772 .65497 .56576 .65302 Mtetra
.56576 .65302 .56772 .65497 .57147 .65392 .56951 .65197 Mtetra
.56951 .65197 .57147 .65392 .57522 .65286 .57326 .65091 Mtetra
.957 .64 .385 r
.57326 .65091 .57522 .65286 .57943 .68156 .57747 .67962 Mtetra
.653 .755 .925 r
.57747 .67962 .57943 .68156 .58322 .68051 .58126 .67857 Mtetra
.58126 .67857 .58322 .68051 .58702 .67946 .58506 .67752 Mtetra
.58506 .67752 .58702 .67946 .59082 .67841 .58886 .67647 Mtetra
.58886 .67647 .59082 .67841 .59463 .67736 .59267 .67541 Mtetra
.59267 .67541 .59463 .67736 .59844 .67631 .59649 .67436 Mtetra
.59649 .67436 .59844 .67631 .60225 .67525 .60031 .6733 Mtetra
.60031 .6733 .60225 .67525 .60608 .67419 .60413 .67224 Mtetra
.60413 .67224 .60608 .67419 .6099 .67313 .60796 .67118 Mtetra
.958 .638 .371 r
.60796 .67118 .6099 .67313 .61451 .70245 .61256 .70051 Mtetra
.65 .758 .928 r
.61256 .70051 .61451 .70245 .61838 .7014 .61643 .69946 Mtetra
.61643 .69946 .61838 .7014 .62226 .70035 .62031 .69841 Mtetra
.62031 .69841 .62226 .70035 .62614 .6993 .6242 .69735 Mtetra
.6242 .69735 .62614 .6993 .63003 .69825 .62809 .6963 Mtetra
.62809 .6963 .63003 .69825 .63392 .69719 .63199 .69524 Mtetra
.63199 .69524 .63392 .69719 .63782 .69613 .63589 .69418 Mtetra
.63589 .69418 .63782 .69613 .64172 .69508 .6398 .69312 Mtetra
.6398 .69312 .64172 .69508 .64563 .69402 .64371 .69206 Mtetra
.64371 .69206 .64563 .69402 .64955 .69295 .64763 .69099 Mtetra
.64763 .69099 .64955 .69295 .65347 .69189 .65155 .68993 Mtetra
.65155 .68993 .65347 .69189 .65739 .69083 .65548 .68886 Mtetra
.65548 .68886 .65739 .69083 .66132 .68976 .65942 .68779 Mtetra
.65942 .68779 .66132 .68976 .66526 .68869 .66336 .68672 Mtetra
.66336 .68672 .66526 .68869 .6692 .68763 .6673 .68565 Mtetra
.6673 .68565 .6692 .68763 .67315 .68656 .67126 .68458 Mtetra
.67126 .68458 .67315 .68656 .6771 .68548 .67521 .6835 Mtetra
.67521 .6835 .6771 .68548 .68106 .68441 .67917 .68243 Mtetra
.67917 .68243 .68106 .68441 .68503 .68334 .68314 .68135 Mtetra
.68314 .68135 .68503 .68334 .689 .68226 .68712 .68027 Mtetra
.68712 .68027 .689 .68226 .69297 .68118 .6911 .67919 Mtetra
.6911 .67919 .69297 .68118 .69695 .6801 .69508 .67811 Mtetra
.69508 .67811 .69695 .6801 .70094 .67902 .69907 .67702 Mtetra
.69907 .67702 .70094 .67902 .70493 .67794 .70307 .67594 Mtetra
.70307 .67594 .70493 .67794 .70893 .67686 .70707 .67485 Mtetra
.70707 .67485 .70893 .67686 .71293 .67577 .71108 .67376 Mtetra
.71108 .67376 .71293 .67577 .71694 .67468 .71509 .67267 Mtetra
.969 .707 .482 r
.71509 .67267 .71694 .67468 .71727 .60775 .71545 .6057 Mtetra
.656 .751 .92 r
.71545 .6057 .71727 .60775 .72121 .60664 .71939 .60458 Mtetra
.71939 .60458 .72121 .60664 .72516 .60552 .72334 .60346 Mtetra
.72334 .60346 .72516 .60552 .72911 .60441 .7273 .60234 Mtetra
.7273 .60234 .72911 .60441 .73307 .60329 .73126 .60121 Mtetra
.73126 .60121 .73307 .60329 .73703 .60216 .73523 .60009 Mtetra
.73523 .60009 .73703 .60216 .741 .60104 .73921 .59896 Mtetra
.73921 .59896 .741 .60104 .74498 .59992 .74318 .59784 Mtetra
.952 .601 .262 r
.74318 .59784 .74498 .59992 .7506 .62389 .7488 .62183 Mtetra
.654 .754 .923 r
.7488 .62183 .7506 .62389 .75462 .62278 .75282 .62071 Mtetra
.75282 .62071 .75462 .62278 .75864 .62166 .75685 .61958 Mtetra
.75685 .61958 .75864 .62166 .76267 .62053 .76088 .61846 Mtetra
.76088 .61846 .76267 .62053 .7667 .61941 .76492 .61733 Mtetra
.76492 .61733 .7667 .61941 .77074 .61829 .76896 .61621 Mtetra
.76896 .61621 .77074 .61829 .77479 .61716 .77301 .61508 Mtetra
.77301 .61508 .77479 .61716 .77884 .61603 .77706 .61395 Mtetra
.77706 .61395 .77884 .61603 .78289 .6149 .78113 .61282 Mtetra
.78113 .61282 .78289 .6149 .78695 .61377 .78519 .61168 Mtetra
.78519 .61168 .78695 .61377 .79102 .61264 .78926 .61055 Mtetra
.78926 .61055 .79102 .61264 .7951 .61151 .79334 .60941 Mtetra
.79334 .60941 .7951 .61151 .79918 .61037 .79742 .60827 Mtetra
.79742 .60827 .79918 .61037 .80326 .60923 .80151 .60713 Mtetra
.80151 .60713 .80326 .60923 .80735 .6081 .80561 .60599 Mtetra
.80561 .60599 .80735 .6081 .81145 .60696 .80971 .60485 Mtetra
.80971 .60485 .81145 .60696 .81555 .60581 .81382 .6037 Mtetra
.81382 .6037 .81555 .60581 .81966 .60467 .81793 .60255 Mtetra
.81793 .60255 .81966 .60467 .82377 .60352 .82205 .60141 Mtetra
.82205 .60141 .82377 .60352 .82789 .60238 .82617 .60026 Mtetra
.82617 .60026 .82789 .60238 .83202 .60123 .8303 .5991 Mtetra
.8303 .5991 .83202 .60123 .83615 .60008 .83444 .59795 Mtetra
.83444 .59795 .83615 .60008 .84029 .59893 .83858 .5968 Mtetra
.83858 .5968 .84029 .59893 .84443 .59777 .84273 .59564 Mtetra
.922 .543 .138 r
.84273 .59564 .84443 .59777 .85052 .61715 .84882 .61503 Mtetra
.652 .756 .926 r
.84882 .61503 .85052 .61715 .85471 .616 .853 .61388 Mtetra
.853 .61388 .85471 .616 .85889 .61485 .8572 .61273 Mtetra
.8572 .61273 .85889 .61485 .86309 .6137 .86139 .61157 Mtetra
.86139 .61157 .86309 .6137 .86729 .61255 .8656 .61041 Mtetra
.8656 .61041 .86729 .61255 .87149 .61139 .86981 .60925 Mtetra
.86981 .60925 .87149 .61139 .87571 .61023 .87402 .60809 Mtetra
.87402 .60809 .87571 .61023 .87992 .60908 .87825 .60693 Mtetra
.87825 .60693 .87992 .60908 .88415 .60792 .88247 .60577 Mtetra
.88247 .60577 .88415 .60792 .88838 .60675 .88671 .6046 Mtetra
.88671 .6046 .88838 .60675 .89261 .60559 .89095 .60344 Mtetra
.89095 .60344 .89261 .60559 .89686 .60442 .8952 .60227 Mtetra
.8952 .60227 .89686 .60442 .90111 .60326 .89945 .6011 Mtetra
.89945 .6011 .90111 .60326 .90536 .60209 .90371 .59992 Mtetra
.90371 .59992 .90536 .60209 .90962 .60092 .90797 .59875 Mtetra
.90797 .59875 .90962 .60092 .91389 .59974 .91225 .59758 Mtetra
.91225 .59758 .91389 .59974 .91816 .59857 .91652 .5964 Mtetra
.91652 .5964 .91816 .59857 .92244 .59739 .92081 .59522 Mtetra
.92081 .59522 .92244 .59739 .92673 .59622 .9251 .59404 Mtetra
.9251 .59404 .92673 .59622 .93102 .59504 .92939 .59286 Mtetra
.92939 .59286 .93102 .59504 .93532 .59386 .9337 .59167 Mtetra
.9337 .59167 .93532 .59386 .93962 .59267 .93801 .59049 Mtetra
.93801 .59049 .93962 .59267 .94393 .59149 .94232 .5893 Mtetra
.94232 .5893 .94393 .59149 .94825 .5903 .94664 .58811 Mtetra
.94664 .58811 .94825 .5903 .95257 .58912 .95097 .58692 Mtetra
.95097 .58692 .95257 .58912 .9569 .58793 .95531 .58573 Mtetra
.95531 .58573 .9569 .58793 .96124 .58673 .95965 .58453 Mtetra
.95965 .58453 .96124 .58673 .96558 .58554 .96399 .58333 Mtetra
.96399 .58333 .96558 .58554 .96993 .58435 .96835 .58214 Mtetra
.96835 .58214 .96993 .58435 .97428 .58315 .97271 .58094 Mtetra
.97271 .58094 .97428 .58315 .97864 .58195 .97707 .57974 Mtetra
.97707 .57974 .97864 .58195 .98301 .58075 .98144 .57853 Mtetra
.98144 .57853 .98301 .58075 .98739 .57955 .98582 .57733 Mtetra
.646 .762 .934 r
.38939 .79875 .39157 .80051 .39518 .79956 .39301 .79779 Mtetra
.39301 .79779 .39518 .79956 .3988 .7986 .39664 .79683 Mtetra
.39664 .79683 .3988 .7986 .40243 .79764 .40027 .79587 Mtetra
.40027 .79587 .40243 .79764 .40606 .79669 .4039 .79491 Mtetra
.4039 .79491 .40606 .79669 .4097 .79573 .40754 .79395 Mtetra
.40754 .79395 .4097 .79573 .41334 .79476 .41118 .79299 Mtetra
.41118 .79299 .41334 .79476 .41698 .7938 .41483 .79202 Mtetra
.41483 .79202 .41698 .7938 .42063 .79284 .41848 .79105 Mtetra
.41848 .79105 .42063 .79284 .42429 .79187 .42214 .79009 Mtetra
.42214 .79009 .42429 .79187 .42795 .79091 .4258 .78912 Mtetra
.4258 .78912 .42795 .79091 .43161 .78994 .42947 .78815 Mtetra
.42947 .78815 .43161 .78994 .43528 .78897 .43315 .78718 Mtetra
.43315 .78718 .43528 .78897 .43896 .788 .43682 .7862 Mtetra
.43682 .7862 .43896 .788 .44264 .78703 .44051 .78523 Mtetra
.44051 .78523 .44264 .78703 .44632 .78605 .4442 .78425 Mtetra
.4442 .78425 .44632 .78605 .45001 .78508 .44789 .78328 Mtetra
.44789 .78328 .45001 .78508 .45371 .7841 .45159 .7823 Mtetra
.45159 .7823 .45371 .7841 .45741 .78313 .45529 .78132 Mtetra
.45529 .78132 .45741 .78313 .46111 .78215 .459 .78034 Mtetra
.459 .78034 .46111 .78215 .46483 .78117 .46271 .77935 Mtetra
.46271 .77935 .46483 .78117 .46854 .78019 .46643 .77837 Mtetra
.943 .696 .534 r
.46643 .77837 .46854 .78019 .47372 .67902 .47168 .67713 Mtetra
.655 .752 .921 r
.47168 .67713 .47372 .67902 .47735 .67799 .47531 .6761 Mtetra
.47531 .6761 .47735 .67799 .48098 .67697 .47894 .67507 Mtetra
.47894 .67507 .48098 .67697 .48461 .67594 .48257 .67404 Mtetra
.48257 .67404 .48461 .67594 .48825 .67492 .48621 .67302 Mtetra
.48621 .67302 .48825 .67492 .49189 .67389 .48986 .67198 Mtetra
.48986 .67198 .49189 .67389 .49553 .67286 .49351 .67095 Mtetra
.49351 .67095 .49553 .67286 .49919 .67183 .49716 .66992 Mtetra
.49716 .66992 .49919 .67183 .50284 .67079 .50082 .66888 Mtetra
.50082 .66888 .50284 .67079 .5065 .66976 .50449 .66785 Mtetra
.50449 .66785 .5065 .66976 .51017 .66872 .50816 .66681 Mtetra
.50816 .66681 .51017 .66872 .51384 .66769 .51183 .66577 Mtetra
.51183 .66577 .51384 .66769 .51752 .66665 .51551 .66473 Mtetra
.51551 .66473 .51752 .66665 .5212 .66561 .5192 .66369 Mtetra
.5192 .66369 .5212 .66561 .52489 .66457 .52289 .66264 Mtetra
.52289 .66264 .52489 .66457 .52858 .66353 .52658 .6616 Mtetra
.52658 .6616 .52858 .66353 .53227 .66248 .53028 .66055 Mtetra
.53028 .66055 .53227 .66248 .53598 .66144 .53398 .6595 Mtetra
.53398 .6595 .53598 .66144 .53968 .66039 .53769 .65845 Mtetra
.53769 .65845 .53968 .66039 .54339 .65934 .54141 .6574 Mtetra
.54141 .6574 .54339 .65934 .54711 .65829 .54513 .65635 Mtetra
.54513 .65635 .54711 .65829 .55083 .65724 .54885 .6553 Mtetra
.54885 .6553 .55083 .65724 .55456 .65619 .55258 .65424 Mtetra
.55258 .65424 .55456 .65619 .55829 .65514 .55632 .65319 Mtetra
.55632 .65319 .55829 .65514 .56202 .65408 .56006 .65213 Mtetra
.56006 .65213 .56202 .65408 .56576 .65302 .5638 .65107 Mtetra
.5638 .65107 .56576 .65302 .56951 .65197 .56755 .65001 Mtetra
.956 .641 .387 r
.56755 .65001 .56951 .65197 .57326 .65091 .5717 .67874 Mtetra
.556 .324 .519 r
.5717 .67874 .57326 .65091 .57747 .67962 .5755 .67768 Mtetra
.653 .755 .925 r
.5755 .67768 .57747 .67962 .58126 .67857 .57929 .67663 Mtetra
.57929 .67663 .58126 .67857 .58506 .67752 .5831 .67557 Mtetra
.5831 .67557 .58506 .67752 .58886 .67647 .5869 .67452 Mtetra
.5869 .67452 .58886 .67647 .59267 .67541 .59072 .67346 Mtetra
.59072 .67346 .59267 .67541 .59649 .67436 .59454 .6724 Mtetra
.59454 .6724 .59649 .67436 .60031 .6733 .59836 .67134 Mtetra
.59836 .67134 .60031 .6733 .60413 .67224 .60219 .67028 Mtetra
.60219 .67028 .60413 .67224 .60796 .67118 .60602 .66921 Mtetra
.60602 .66921 .60796 .67118 .61256 .70051 .60986 .66815 Mtetra
.113 .055 .507 r
.60986 .66815 .61256 .70051 .61643 .69946 .61448 .69752 Mtetra
.65 .758 .928 r
.61448 .69752 .61643 .69946 .62031 .69841 .61837 .69646 Mtetra
.61837 .69646 .62031 .69841 .6242 .69735 .62225 .6954 Mtetra
.62225 .6954 .6242 .69735 .62809 .6963 .62615 .69434 Mtetra
.62615 .69434 .62809 .6963 .63199 .69524 .63005 .69328 Mtetra
.63005 .69328 .63199 .69524 .63589 .69418 .63396 .69222 Mtetra
.63396 .69222 .63589 .69418 .6398 .69312 .63787 .69115 Mtetra
.63787 .69115 .6398 .69312 .64371 .69206 .64178 .69009 Mtetra
.64178 .69009 .64371 .69206 .64763 .69099 .64571 .68902 Mtetra
.64571 .68902 .64763 .69099 .65155 .68993 .64963 .68795 Mtetra
.64963 .68795 .65155 .68993 .65548 .68886 .65357 .68688 Mtetra
.65357 .68688 .65548 .68886 .65942 .68779 .65751 .68581 Mtetra
.65751 .68581 .65942 .68779 .66336 .68672 .66145 .68474 Mtetra
.66145 .68474 .66336 .68672 .6673 .68565 .6654 .68367 Mtetra
.6654 .68367 .6673 .68565 .67126 .68458 .66936 .68259 Mtetra
.66936 .68259 .67126 .68458 .67521 .6835 .67332 .68151 Mtetra
.67332 .68151 .67521 .6835 .67917 .68243 .67728 .68043 Mtetra
.67728 .68043 .67917 .68243 .68314 .68135 .68125 .67935 Mtetra
.68125 .67935 .68314 .68135 .68712 .68027 .68523 .67827 Mtetra
.68523 .67827 .68712 .68027 .6911 .67919 .68922 .67719 Mtetra
.68922 .67719 .6911 .67919 .69508 .67811 .6932 .6761 Mtetra
.6932 .6761 .69508 .67811 .69907 .67702 .6972 .67502 Mtetra
.6972 .67502 .69907 .67702 .70307 .67594 .7012 .67393 Mtetra
.7012 .67393 .70307 .67594 .70707 .67485 .7052 .67284 Mtetra
.7052 .67284 .70707 .67485 .71108 .67376 .70922 .67175 Mtetra
.968 .707 .483 r
.70922 .67175 .71108 .67376 .71509 .67267 .70968 .60475 Mtetra
.58 .384 .58 r
.70968 .60475 .71509 .67267 .71545 .6057 .71362 .60363 Mtetra
.656 .751 .92 r
.71362 .60363 .71545 .6057 .71939 .60458 .71757 .60251 Mtetra
.71757 .60251 .71939 .60458 .72334 .60346 .72153 .60139 Mtetra
.72153 .60139 .72334 .60346 .7273 .60234 .72549 .60026 Mtetra
.72549 .60026 .7273 .60234 .73126 .60121 .72946 .59914 Mtetra
.72946 .59914 .73126 .60121 .73523 .60009 .73343 .59801 Mtetra
.73343 .59801 .73523 .60009 .73921 .59896 .73741 .59688 Mtetra
.73741 .59688 .73921 .59896 .74318 .59784 .74139 .59575 Mtetra
.74139 .59575 .74318 .59784 .7488 .62183 .74538 .59462 Mtetra
.187 .124 .549 r
.74538 .59462 .7488 .62183 .75282 .62071 .75102 .61863 Mtetra
.654 .754 .923 r
.75102 .61863 .75282 .62071 .75685 .61958 .75505 .61751 Mtetra
.75505 .61751 .75685 .61958 .76088 .61846 .75909 .61638 Mtetra
.75909 .61638 .76088 .61846 .76492 .61733 .76313 .61525 Mtetra
.76313 .61525 .76492 .61733 .76896 .61621 .76718 .61412 Mtetra
.76718 .61412 .76896 .61621 .77301 .61508 .77123 .61299 Mtetra
.77123 .61299 .77301 .61508 .77706 .61395 .77529 .61186 Mtetra
.77529 .61186 .77706 .61395 .78113 .61282 .77935 .61072 Mtetra
.77935 .61072 .78113 .61282 .78519 .61168 .78342 .60958 Mtetra
.78342 .60958 .78519 .61168 .78926 .61055 .7875 .60845 Mtetra
.7875 .60845 .78926 .61055 .79334 .60941 .79158 .60731 Mtetra
.79158 .60731 .79334 .60941 .79742 .60827 .79567 .60616 Mtetra
.79567 .60616 .79742 .60827 .80151 .60713 .79976 .60502 Mtetra
.79976 .60502 .80151 .60713 .80561 .60599 .80386 .60388 Mtetra
.80386 .60388 .80561 .60599 .80971 .60485 .80797 .60273 Mtetra
.80797 .60273 .80971 .60485 .81382 .6037 .81208 .60158 Mtetra
.81208 .60158 .81382 .6037 .81793 .60255 .81619 .60043 Mtetra
.81619 .60043 .81793 .60255 .82205 .60141 .82032 .59928 Mtetra
.82032 .59928 .82205 .60141 .82617 .60026 .82445 .59813 Mtetra
.82445 .59813 .82617 .60026 .8303 .5991 .82858 .59697 Mtetra
.82858 .59697 .8303 .5991 .83444 .59795 .83272 .59582 Mtetra
.83272 .59582 .83444 .59795 .83858 .5968 .83687 .59466 Mtetra
.923 .544 .142 r
.83687 .59466 .83858 .5968 .84273 .59564 .84292 .61406 Mtetra
.545 .3 .494 r
.84292 .61406 .84273 .59564 .84882 .61503 .8471 .6129 Mtetra
.652 .756 .926 r
.8471 .6129 .84882 .61503 .853 .61388 .85129 .61175 Mtetra
.85129 .61175 .853 .61388 .8572 .61273 .85549 .61059 Mtetra
.85549 .61059 .8572 .61273 .86139 .61157 .85969 .60943 Mtetra
.85969 .60943 .86139 .61157 .8656 .61041 .8639 .60827 Mtetra
.8639 .60827 .8656 .61041 .86981 .60925 .86812 .60711 Mtetra
.86812 .60711 .86981 .60925 .87402 .60809 .87234 .60595 Mtetra
.87234 .60595 .87402 .60809 .87825 .60693 .87656 .60478 Mtetra
.87656 .60478 .87825 .60693 .88247 .60577 .8808 .60362 Mtetra
.8808 .60362 .88247 .60577 .88671 .6046 .88504 .60245 Mtetra
.88504 .60245 .88671 .6046 .89095 .60344 .88928 .60128 Mtetra
.88928 .60128 .89095 .60344 .8952 .60227 .89353 .60011 Mtetra
.89353 .60011 .8952 .60227 .89945 .6011 .89779 .59893 Mtetra
.89779 .59893 .89945 .6011 .90371 .59992 .90205 .59776 Mtetra
.90205 .59776 .90371 .59992 .90797 .59875 .90632 .59658 Mtetra
.90632 .59658 .90797 .59875 .91225 .59758 .9106 .5954 Mtetra
.9106 .5954 .91225 .59758 .91652 .5964 .91488 .59422 Mtetra
.91488 .59422 .91652 .5964 .92081 .59522 .91917 .59304 Mtetra
.91917 .59304 .92081 .59522 .9251 .59404 .92347 .59185 Mtetra
.92347 .59185 .9251 .59404 .92939 .59286 .92777 .59067 Mtetra
.92777 .59067 .92939 .59286 .9337 .59167 .93207 .58948 Mtetra
.93207 .58948 .9337 .59167 .93801 .59049 .93639 .58829 Mtetra
.93639 .58829 .93801 .59049 .94232 .5893 .94071 .5871 Mtetra
.94071 .5871 .94232 .5893 .94664 .58811 .94503 .58591 Mtetra
.94503 .58591 .94664 .58811 .95097 .58692 .94937 .58471 Mtetra
.94937 .58471 .95097 .58692 .95531 .58573 .95371 .58352 Mtetra
.95371 .58352 .95531 .58573 .95965 .58453 .95805 .58232 Mtetra
.95805 .58232 .95965 .58453 .96399 .58333 .9624 .58112 Mtetra
.9624 .58112 .96399 .58333 .96835 .58214 .96676 .57992 Mtetra
.96676 .57992 .96835 .58214 .97271 .58094 .97112 .57872 Mtetra
.97112 .57872 .97271 .58094 .97707 .57974 .9755 .57751 Mtetra
.9755 .57751 .97707 .57974 .98144 .57853 .97987 .57631 Mtetra
.97987 .57631 .98144 .57853 .98582 .57733 .98426 .5751 Mtetra
.646 .762 .934 r
.38721 .79698 .38939 .79875 .39301 .79779 .39084 .79602 Mtetra
.39084 .79602 .39301 .79779 .39664 .79683 .39446 .79506 Mtetra
.39446 .79506 .39664 .79683 .40027 .79587 .39809 .7941 Mtetra
.39809 .7941 .40027 .79587 .4039 .79491 .40173 .79313 Mtetra
.40173 .79313 .4039 .79491 .40754 .79395 .40537 .79217 Mtetra
.40537 .79217 .40754 .79395 .41118 .79299 .40902 .7912 Mtetra
.40902 .7912 .41118 .79299 .41483 .79202 .41267 .79024 Mtetra
.41267 .79024 .41483 .79202 .41848 .79105 .41633 .78927 Mtetra
.41633 .78927 .41848 .79105 .42214 .79009 .41999 .7883 Mtetra
.41999 .7883 .42214 .79009 .4258 .78912 .42366 .78733 Mtetra
.42366 .78733 .4258 .78912 .42947 .78815 .42733 .78635 Mtetra
.42733 .78635 .42947 .78815 .43315 .78718 .431 .78538 Mtetra
.431 .78538 .43315 .78718 .43682 .7862 .43469 .7844 Mtetra
.43469 .7844 .43682 .7862 .44051 .78523 .43837 .78343 Mtetra
.43837 .78343 .44051 .78523 .4442 .78425 .44206 .78245 Mtetra
.44206 .78245 .4442 .78425 .44789 .78328 .44576 .78147 Mtetra
.44576 .78147 .44789 .78328 .45159 .7823 .44946 .78049 Mtetra
.44946 .78049 .45159 .7823 .45529 .78132 .45317 .77951 Mtetra
.45317 .77951 .45529 .78132 .459 .78034 .45688 .77852 Mtetra
.45688 .77852 .459 .78034 .46271 .77935 .4606 .77754 Mtetra
.4606 .77754 .46271 .77935 .46643 .77837 .46432 .77655 Mtetra
.943 .696 .534 r
.46432 .77655 .46643 .77837 .47168 .67713 .46963 .67523 Mtetra
.655 .752 .921 r
.46963 .67523 .47168 .67713 .47531 .6761 .47326 .6742 Mtetra
.47326 .6742 .47531 .6761 .47894 .67507 .47689 .67317 Mtetra
.47689 .67317 .47894 .67507 .48257 .67404 .48053 .67214 Mtetra
.48053 .67214 .48257 .67404 .48621 .67302 .48418 .67111 Mtetra
.48418 .67111 .48621 .67302 .48986 .67198 .48782 .67008 Mtetra
.48782 .67008 .48986 .67198 .49351 .67095 .49148 .66904 Mtetra
.49148 .66904 .49351 .67095 .49716 .66992 .49514 .66801 Mtetra
.49514 .66801 .49716 .66992 .50082 .66888 .4988 .66697 Mtetra
.4988 .66697 .50082 .66888 .50449 .66785 .50247 .66593 Mtetra
.50247 .66593 .50449 .66785 .50816 .66681 .50614 .66489 Mtetra
.50614 .66489 .50816 .66681 .51183 .66577 .50982 .66385 Mtetra
.50982 .66385 .51183 .66577 .51551 .66473 .5135 .6628 Mtetra
.5135 .6628 .51551 .66473 .5192 .66369 .51719 .66176 Mtetra
.51719 .66176 .5192 .66369 .52289 .66264 .52088 .66071 Mtetra
.52088 .66071 .52289 .66264 .52658 .6616 .52458 .65966 Mtetra
.52458 .65966 .52658 .6616 .53028 .66055 .52828 .65862 Mtetra
.52828 .65862 .53028 .66055 .53398 .6595 .53199 .65756 Mtetra
.53199 .65756 .53398 .6595 .53769 .65845 .5357 .65651 Mtetra
.5357 .65651 .53769 .65845 .54141 .6574 .53942 .65546 Mtetra
.53942 .65546 .54141 .6574 .54513 .65635 .54314 .6544 Mtetra
.54314 .6544 .54513 .65635 .54885 .6553 .54687 .65335 Mtetra
.54687 .65335 .54885 .6553 .55258 .65424 .5506 .65229 Mtetra
.5506 .65229 .55258 .65424 .55632 .65319 .55434 .65123 Mtetra
.55434 .65123 .55632 .65319 .56006 .65213 .55808 .65017 Mtetra
.55808 .65017 .56006 .65213 .5638 .65107 .56183 .64911 Mtetra
.56183 .64911 .5638 .65107 .56755 .65001 .56558 .64805 Mtetra
.956 .641 .387 r
.56558 .64805 .56755 .65001 .5717 .67874 .56972 .67679 Mtetra
.653 .755 .925 r
.56972 .67679 .5717 .67874 .5755 .67768 .57352 .67574 Mtetra
.57352 .67574 .5755 .67768 .57929 .67663 .57732 .67468 Mtetra
.57732 .67468 .57929 .67663 .5831 .67557 .58113 .67362 Mtetra
.58113 .67362 .5831 .67557 .5869 .67452 .58494 .67256 Mtetra
.58494 .67256 .5869 .67452 .59072 .67346 .58876 .6715 Mtetra
.58876 .6715 .59072 .67346 .59454 .6724 .59258 .67044 Mtetra
.59258 .67044 .59454 .6724 .59836 .67134 .5964 .66938 Mtetra
.5964 .66938 .59836 .67134 .60219 .67028 .60024 .66831 Mtetra
.60024 .66831 .60219 .67028 .60602 .66921 .60407 .66725 Mtetra
.60407 .66725 .60602 .66921 .60986 .66815 .60792 .66618 Mtetra
.60792 .66618 .60986 .66815 .61448 .69752 .61177 .66511 Mtetra
.113 .055 .507 r
.61177 .66511 .61448 .69752 .61837 .69646 .61641 .6945 Mtetra
.65 .758 .928 r
.61641 .6945 .61837 .69646 .62225 .6954 .62031 .69344 Mtetra
.62031 .69344 .62225 .6954 .62615 .69434 .6242 .69238 Mtetra
.6242 .69238 .62615 .69434 .63005 .69328 .62811 .69132 Mtetra
.62811 .69132 .63005 .69328 .63396 .69222 .63202 .69025 Mtetra
.63202 .69025 .63396 .69222 .63787 .69115 .63593 .68919 Mtetra
.63593 .68919 .63787 .69115 .64178 .69009 .63985 .68812 Mtetra
.63985 .68812 .64178 .69009 .64571 .68902 .64378 .68705 Mtetra
.64378 .68705 .64571 .68902 .64963 .68795 .64771 .68598 Mtetra
.64771 .68598 .64963 .68795 .65357 .68688 .65165 .68491 Mtetra
.65165 .68491 .65357 .68688 .65751 .68581 .65559 .68383 Mtetra
.65559 .68383 .65751 .68581 .66145 .68474 .65954 .68276 Mtetra
.65954 .68276 .66145 .68474 .6654 .68367 .66349 .68168 Mtetra
.66349 .68168 .6654 .68367 .66936 .68259 .66745 .6806 Mtetra
.66745 .6806 .66936 .68259 .67332 .68151 .67142 .67952 Mtetra
.67142 .67952 .67332 .68151 .67728 .68043 .67539 .67844 Mtetra
.67539 .67844 .67728 .68043 .68125 .67935 .67936 .67736 Mtetra
.67936 .67736 .68125 .67935 .68523 .67827 .68334 .67627 Mtetra
.68334 .67627 .68523 .67827 .68922 .67719 .68733 .67519 Mtetra
.68733 .67519 .68922 .67719 .6932 .6761 .69132 .6741 Mtetra
.69132 .6741 .6932 .6761 .6972 .67502 .69532 .67301 Mtetra
.69532 .67301 .6972 .67502 .7012 .67393 .69933 .67192 Mtetra
.69933 .67192 .7012 .67393 .7052 .67284 .70333 .67083 Mtetra
.70333 .67083 .7052 .67284 .70922 .67175 .70735 .66973 Mtetra
.968 .707 .483 r
.70735 .66973 .70922 .67175 .70968 .60475 .70785 .60268 Mtetra
.656 .751 .92 r
.70785 .60268 .70968 .60475 .71362 .60363 .7118 .60156 Mtetra
.7118 .60156 .71362 .60363 .71757 .60251 .71575 .60044 Mtetra
.71575 .60044 .71757 .60251 .72153 .60139 .71971 .59931 Mtetra
.71971 .59931 .72153 .60139 .72549 .60026 .72367 .59818 Mtetra
.72367 .59818 .72549 .60026 .72946 .59914 .72764 .59706 Mtetra
.72764 .59706 .72946 .59914 .73343 .59801 .73162 .59593 Mtetra
.73162 .59593 .73343 .59801 .73741 .59688 .7356 .59479 Mtetra
.7356 .59479 .73741 .59688 .74139 .59575 .73959 .59366 Mtetra
.73959 .59366 .74139 .59575 .74538 .59462 .74358 .59253 Mtetra
.952 .6 .259 r
.74358 .59253 .74538 .59462 .75102 .61863 .74922 .61655 Mtetra
.654 .754 .923 r
.74922 .61655 .75102 .61863 .75505 .61751 .75325 .61543 Mtetra
.75325 .61543 .75505 .61751 .75909 .61638 .75729 .6143 Mtetra
.75729 .6143 .75909 .61638 .76313 .61525 .76134 .61316 Mtetra
.76134 .61316 .76313 .61525 .76718 .61412 .76539 .61203 Mtetra
.76539 .61203 .76718 .61412 .77123 .61299 .76945 .6109 Mtetra
.76945 .6109 .77123 .61299 .77529 .61186 .77351 .60976 Mtetra
.77351 .60976 .77529 .61186 .77935 .61072 .77758 .60862 Mtetra
.77758 .60862 .77935 .61072 .78342 .60958 .78165 .60748 Mtetra
.78165 .60748 .78342 .60958 .7875 .60845 .78573 .60634 Mtetra
.78573 .60634 .7875 .60845 .79158 .60731 .78982 .6052 Mtetra
.78982 .6052 .79158 .60731 .79567 .60616 .79391 .60405 Mtetra
.79391 .60405 .79567 .60616 .79976 .60502 .79801 .60291 Mtetra
.79801 .60291 .79976 .60502 .80386 .60388 .80211 .60176 Mtetra
.80211 .60176 .80386 .60388 .80797 .60273 .80622 .60061 Mtetra
.80622 .60061 .80797 .60273 .81208 .60158 .81033 .59946 Mtetra
.81033 .59946 .81208 .60158 .81619 .60043 .81446 .59831 Mtetra
.81446 .59831 .81619 .60043 .82032 .59928 .81858 .59715 Mtetra
.81858 .59715 .82032 .59928 .82445 .59813 .82271 .596 Mtetra
.82271 .596 .82445 .59813 .82858 .59697 .82685 .59484 Mtetra
.82685 .59484 .82858 .59697 .83272 .59582 .831 .59368 Mtetra
.831 .59368 .83272 .59582 .83687 .59466 .83515 .59252 Mtetra
.923 .544 .142 r
.83515 .59252 .83687 .59466 .84292 .61406 .8412 .61193 Mtetra
.652 .756 .926 r
.8412 .61193 .84292 .61406 .8471 .6129 .84539 .61077 Mtetra
.84539 .61077 .8471 .6129 .85129 .61175 .84958 .60961 Mtetra
.84958 .60961 .85129 .61175 .85549 .61059 .85378 .60845 Mtetra
.85378 .60845 .85549 .61059 .85969 .60943 .85799 .60729 Mtetra
.85799 .60729 .85969 .60943 .8639 .60827 .8622 .60613 Mtetra
.8622 .60613 .8639 .60827 .86812 .60711 .86642 .60496 Mtetra
.86642 .60496 .86812 .60711 .87234 .60595 .87065 .6038 Mtetra
.87065 .6038 .87234 .60595 .87656 .60478 .87488 .60263 Mtetra
.87488 .60263 .87656 .60478 .8808 .60362 .87912 .60146 Mtetra
.87912 .60146 .8808 .60362 .88504 .60245 .88336 .60029 Mtetra
.88336 .60029 .88504 .60245 .88928 .60128 .88761 .59911 Mtetra
.88761 .59911 .88928 .60128 .89353 .60011 .89186 .59794 Mtetra
.89186 .59794 .89353 .60011 .89779 .59893 .89613 .59676 Mtetra
.89613 .59676 .89779 .59893 .90205 .59776 .90039 .59558 Mtetra
.90039 .59558 .90205 .59776 .90632 .59658 .90467 .5944 Mtetra
.90467 .5944 .90632 .59658 .9106 .5954 .90895 .59322 Mtetra
.90895 .59322 .9106 .5954 .91488 .59422 .91324 .59204 Mtetra
.91324 .59204 .91488 .59422 .91917 .59304 .91753 .59085 Mtetra
.91753 .59085 .91917 .59304 .92347 .59185 .92183 .58966 Mtetra
.92183 .58966 .92347 .59185 .92777 .59067 .92613 .58848 Mtetra
.92613 .58848 .92777 .59067 .93207 .58948 .93045 .58728 Mtetra
.93045 .58728 .93207 .58948 .93639 .58829 .93476 .58609 Mtetra
.93476 .58609 .93639 .58829 .94071 .5871 .93909 .5849 Mtetra
.93909 .5849 .94071 .5871 .94503 .58591 .94342 .5837 Mtetra
.94342 .5837 .94503 .58591 .94937 .58471 .94776 .58251 Mtetra
.94776 .58251 .94937 .58471 .95371 .58352 .9521 .58131 Mtetra
.9521 .58131 .95371 .58352 .95805 .58232 .95645 .58011 Mtetra
.95645 .58011 .95805 .58232 .9624 .58112 .96081 .5789 Mtetra
.96081 .5789 .9624 .58112 .96676 .57992 .96517 .5777 Mtetra
.96517 .5777 .96676 .57992 .97112 .57872 .96954 .57649 Mtetra
.96954 .57649 .97112 .57872 .9755 .57751 .97391 .57528 Mtetra
.97391 .57528 .9755 .57751 .97987 .57631 .9783 .57407 Mtetra
.9783 .57407 .97987 .57631 .98426 .5751 .98269 .57286 Mtetra
.646 .762 .934 r
.38503 .79521 .38721 .79698 .39084 .79602 .38865 .79425 Mtetra
.38865 .79425 .39084 .79602 .39446 .79506 .39228 .79328 Mtetra
.39228 .79328 .39446 .79506 .39809 .7941 .39592 .79232 Mtetra
.39592 .79232 .39809 .7941 .40173 .79313 .39956 .79135 Mtetra
.39956 .79135 .40173 .79313 .40537 .79217 .4032 .79038 Mtetra
.4032 .79038 .40537 .79217 .40902 .7912 .40685 .78942 Mtetra
.40685 .78942 .40902 .7912 .41267 .79024 .41051 .78845 Mtetra
.41051 .78845 .41267 .79024 .41633 .78927 .41417 .78747 Mtetra
.41417 .78747 .41633 .78927 .41999 .7883 .41783 .7865 Mtetra
.41783 .7865 .41999 .7883 .42366 .78733 .4215 .78553 Mtetra
.4215 .78553 .42366 .78733 .42733 .78635 .42518 .78455 Mtetra
.42518 .78455 .42733 .78635 .431 .78538 .42886 .78358 Mtetra
.42886 .78358 .431 .78538 .43469 .7844 .43254 .7826 Mtetra
.43254 .7826 .43469 .7844 .43837 .78343 .43623 .78162 Mtetra
.43623 .78162 .43837 .78343 .44206 .78245 .43992 .78064 Mtetra
.43992 .78064 .44206 .78245 .44576 .78147 .44362 .77966 Mtetra
.44362 .77966 .44576 .78147 .44946 .78049 .44733 .77867 Mtetra
.44733 .77867 .44946 .78049 .45317 .77951 .45104 .77769 Mtetra
.45104 .77769 .45317 .77951 .45688 .77852 .45475 .7767 Mtetra
.45475 .7767 .45688 .77852 .4606 .77754 .45847 .77572 Mtetra
.45847 .77572 .4606 .77754 .46432 .77655 .4622 .77473 Mtetra
.943 .696 .534 r
.4622 .77473 .46432 .77655 .46963 .67523 .46758 .67333 Mtetra
.655 .752 .921 r
.46758 .67333 .46963 .67523 .47326 .6742 .47121 .6723 Mtetra
.47121 .6723 .47326 .6742 .47689 .67317 .47484 .67127 Mtetra
.47484 .67127 .47689 .67317 .48053 .67214 .47849 .67024 Mtetra
.47849 .67024 .48053 .67214 .48418 .67111 .48213 .6692 Mtetra
.48213 .6692 .48418 .67111 .48782 .67008 .48578 .66817 Mtetra
.48578 .66817 .48782 .67008 .49148 .66904 .48944 .66713 Mtetra
.48944 .66713 .49148 .66904 .49514 .66801 .4931 .66609 Mtetra
.4931 .66609 .49514 .66801 .4988 .66697 .49677 .66505 Mtetra
.49677 .66505 .4988 .66697 .50247 .66593 .50044 .66401 Mtetra
.50044 .66401 .50247 .66593 .50614 .66489 .50412 .66296 Mtetra
.50412 .66296 .50614 .66489 .50982 .66385 .5078 .66192 Mtetra
.5078 .66192 .50982 .66385 .5135 .6628 .51148 .66087 Mtetra
.51148 .66087 .5135 .6628 .51719 .66176 .51517 .65983 Mtetra
.51517 .65983 .51719 .66176 .52088 .66071 .51887 .65878 Mtetra
.51887 .65878 .52088 .66071 .52458 .65966 .52257 .65773 Mtetra
.52257 .65773 .52458 .65966 .52828 .65862 .52628 .65667 Mtetra
.52628 .65667 .52828 .65862 .53199 .65756 .52999 .65562 Mtetra
.52999 .65562 .53199 .65756 .5357 .65651 .5337 .65457 Mtetra
.5337 .65457 .5357 .65651 .53942 .65546 .53743 .65351 Mtetra
.53743 .65351 .53942 .65546 .54314 .6544 .54115 .65245 Mtetra
.54115 .65245 .54314 .6544 .54687 .65335 .54488 .6514 Mtetra
.54488 .6514 .54687 .65335 .5506 .65229 .54862 .65034 Mtetra
.54862 .65034 .5506 .65229 .55434 .65123 .55236 .64927 Mtetra
.55236 .64927 .55434 .65123 .55808 .65017 .55611 .64821 Mtetra
.55611 .64821 .55808 .65017 .56183 .64911 .55986 .64715 Mtetra
.55986 .64715 .56183 .64911 .56558 .64805 .56361 .64608 Mtetra
.956 .641 .387 r
.56361 .64608 .56558 .64805 .56972 .67679 .56774 .67484 Mtetra
.653 .755 .925 r
.56774 .67484 .56972 .67679 .57352 .67574 .57154 .67379 Mtetra
.57154 .67379 .57352 .67574 .57732 .67468 .57534 .67273 Mtetra
.57534 .67273 .57732 .67468 .58113 .67362 .57915 .67167 Mtetra
.57915 .67167 .58113 .67362 .58494 .67256 .58297 .6706 Mtetra
.58297 .6706 .58494 .67256 .58876 .6715 .58679 .66954 Mtetra
.58679 .66954 .58876 .6715 .59258 .67044 .59061 .66848 Mtetra
.59061 .66848 .59258 .67044 .5964 .66938 .59444 .66741 Mtetra
.59444 .66741 .5964 .66938 .60024 .66831 .59828 .66634 Mtetra
.59828 .66634 .60024 .66831 .60407 .66725 .60212 .66527 Mtetra
.60212 .66527 .60407 .66725 .60792 .66618 .60597 .6642 Mtetra
.60597 .6642 .60792 .66618 .61177 .66511 .60982 .66313 Mtetra
.958 .637 .367 r
.60982 .66313 .61177 .66511 .61641 .6945 .61445 .69255 Mtetra
.65 .758 .928 r
.61445 .69255 .61641 .6945 .62031 .69344 .61835 .69148 Mtetra
.61835 .69148 .62031 .69344 .6242 .69238 .62225 .69042 Mtetra
.62225 .69042 .6242 .69238 .62811 .69132 .62616 .68935 Mtetra
.62616 .68935 .62811 .69132 .63202 .69025 .63007 .68828 Mtetra
.63007 .68828 .63202 .69025 .63593 .68919 .63399 .68721 Mtetra
.63399 .68721 .63593 .68919 .63985 .68812 .63792 .68614 Mtetra
.63792 .68614 .63985 .68812 .64378 .68705 .64185 .68507 Mtetra
.64185 .68507 .64378 .68705 .64771 .68598 .64578 .684 Mtetra
.64578 .684 .64771 .68598 .65165 .68491 .64972 .68292 Mtetra
.64972 .68292 .65165 .68491 .65559 .68383 .65367 .68185 Mtetra
.65367 .68185 .65559 .68383 .65954 .68276 .65762 .68077 Mtetra
.65762 .68077 .65954 .68276 .66349 .68168 .66158 .67969 Mtetra
.66158 .67969 .66349 .68168 .66745 .6806 .66554 .67861 Mtetra
.66554 .67861 .66745 .6806 .67142 .67952 .66951 .67752 Mtetra
.66951 .67752 .67142 .67952 .67539 .67844 .67348 .67644 Mtetra
.67348 .67644 .67539 .67844 .67936 .67736 .67746 .67535 Mtetra
.67746 .67535 .67936 .67736 .68334 .67627 .68145 .67426 Mtetra
.68145 .67426 .68334 .67627 .68733 .67519 .68544 .67318 Mtetra
.68544 .67318 .68733 .67519 .69132 .6741 .68944 .67209 Mtetra
.68944 .67209 .69132 .6741 .69532 .67301 .69344 .67099 Mtetra
.69344 .67099 .69532 .67301 .69933 .67192 .69745 .6699 Mtetra
.69745 .6699 .69933 .67192 .70333 .67083 .70146 .6688 Mtetra
.968 .707 .484 r
.70146 .6688 .70333 .67083 .70735 .66973 .70207 .60173 Mtetra
.579 .383 .58 r
.70207 .60173 .70735 .66973 .70785 .60268 .70601 .60061 Mtetra
.656 .751 .92 r
.70601 .60061 .70785 .60268 .7118 .60156 .70996 .59948 Mtetra
.70996 .59948 .7118 .60156 .71575 .60044 .71392 .59836 Mtetra
.71392 .59836 .71575 .60044 .71971 .59931 .71788 .59723 Mtetra
.71788 .59723 .71971 .59931 .72367 .59818 .72185 .5961 Mtetra
.72185 .5961 .72367 .59818 .72764 .59706 .72583 .59497 Mtetra
.72583 .59497 .72764 .59706 .73162 .59593 .72981 .59384 Mtetra
.72981 .59384 .73162 .59593 .7356 .59479 .73379 .5927 Mtetra
.73379 .5927 .7356 .59479 .73959 .59366 .73778 .59157 Mtetra
.73778 .59157 .73959 .59366 .74358 .59253 .74178 .59043 Mtetra
.952 .6 .259 r
.74178 .59043 .74358 .59253 .74922 .61655 .74741 .61447 Mtetra
.654 .754 .923 r
.74741 .61447 .74922 .61655 .75325 .61543 .75145 .61334 Mtetra
.75145 .61334 .75325 .61543 .75729 .6143 .75549 .61221 Mtetra
.75549 .61221 .75729 .6143 .76134 .61316 .75954 .61107 Mtetra
.75954 .61107 .76134 .61316 .76539 .61203 .7636 .60993 Mtetra
.7636 .60993 .76539 .61203 .76945 .6109 .76766 .6088 Mtetra
.76766 .6088 .76945 .6109 .77351 .60976 .77172 .60766 Mtetra
.77172 .60766 .77351 .60976 .77758 .60862 .7758 .60652 Mtetra
.7758 .60652 .77758 .60862 .78165 .60748 .77988 .60537 Mtetra
.77988 .60537 .78165 .60748 .78573 .60634 .78396 .60423 Mtetra
.78396 .60423 .78573 .60634 .78982 .6052 .78805 .60308 Mtetra
.78805 .60308 .78982 .6052 .79391 .60405 .79215 .60194 Mtetra
.79215 .60194 .79391 .60405 .79801 .60291 .79625 .60079 Mtetra
.79625 .60079 .79801 .60291 .80211 .60176 .80035 .59964 Mtetra
.80035 .59964 .80211 .60176 .80622 .60061 .80447 .59848 Mtetra
.80447 .59848 .80622 .60061 .81033 .59946 .80859 .59733 Mtetra
.80859 .59733 .81033 .59946 .81446 .59831 .81271 .59617 Mtetra
.81271 .59617 .81446 .59831 .81858 .59715 .81684 .59502 Mtetra
.81684 .59502 .81858 .59715 .82271 .596 .82098 .59386 Mtetra
.82098 .59386 .82271 .596 .82685 .59484 .82512 .5927 Mtetra
.82512 .5927 .82685 .59484 .831 .59368 .82927 .59153 Mtetra
.82927 .59153 .831 .59368 .83515 .59252 .83343 .59037 Mtetra
.923 .544 .142 r
.83343 .59037 .83515 .59252 .8412 .61193 .83947 .60979 Mtetra
.652 .756 .926 r
.83947 .60979 .8412 .61193 .84539 .61077 .84367 .60863 Mtetra
.84367 .60863 .84539 .61077 .84958 .60961 .84786 .60747 Mtetra
.84786 .60747 .84958 .60961 .85378 .60845 .85207 .60631 Mtetra
.85207 .60631 .85378 .60845 .85799 .60729 .85628 .60514 Mtetra
.85628 .60514 .85799 .60729 .8622 .60613 .8605 .60397 Mtetra
.8605 .60397 .8622 .60613 .86642 .60496 .86472 .60281 Mtetra
.86472 .60281 .86642 .60496 .87065 .6038 .86895 .60164 Mtetra
.86895 .60164 .87065 .6038 .87488 .60263 .87319 .60047 Mtetra
.87319 .60047 .87488 .60263 .87912 .60146 .87743 .59929 Mtetra
.87743 .59929 .87912 .60146 .88336 .60029 .88168 .59812 Mtetra
.88168 .59812 .88336 .60029 .88761 .59911 .88593 .59694 Mtetra
.88593 .59694 .88761 .59911 .89186 .59794 .89019 .59576 Mtetra
.89019 .59576 .89186 .59794 .89613 .59676 .89446 .59458 Mtetra
.89446 .59458 .89613 .59676 .90039 .59558 .89873 .5934 Mtetra
.89873 .5934 .90039 .59558 .90467 .5944 .90301 .59222 Mtetra
.90301 .59222 .90467 .5944 .90895 .59322 .90729 .59103 Mtetra
.90729 .59103 .90895 .59322 .91324 .59204 .91159 .58985 Mtetra
.91159 .58985 .91324 .59204 .91753 .59085 .91588 .58866 Mtetra
.91588 .58866 .91753 .59085 .92183 .58966 .92019 .58747 Mtetra
.92019 .58747 .92183 .58966 .92613 .58848 .9245 .58628 Mtetra
.9245 .58628 .92613 .58848 .93045 .58728 .92881 .58508 Mtetra
.92881 .58508 .93045 .58728 .93476 .58609 .93314 .58389 Mtetra
.93314 .58389 .93476 .58609 .93909 .5849 .93747 .58269 Mtetra
.93747 .58269 .93909 .5849 .94342 .5837 .9418 .58149 Mtetra
.9418 .58149 .94342 .5837 .94776 .58251 .94614 .58029 Mtetra
.94614 .58029 .94776 .58251 .9521 .58131 .95049 .57909 Mtetra
.95049 .57909 .9521 .58131 .95645 .58011 .95485 .57788 Mtetra
.95485 .57788 .95645 .58011 .96081 .5789 .95921 .57668 Mtetra
.95921 .57668 .96081 .5789 .96517 .5777 .96358 .57547 Mtetra
.96358 .57547 .96517 .5777 .96954 .57649 .96795 .57426 Mtetra
.96795 .57426 .96954 .57649 .97391 .57528 .97233 .57305 Mtetra
.97233 .57305 .97391 .57528 .9783 .57407 .97672 .57184 Mtetra
.97672 .57184 .9783 .57407 .98269 .57286 .98111 .57062 Mtetra
.646 .762 .934 r
.38284 .79343 .38503 .79521 .38865 .79425 .38647 .79247 Mtetra
.38647 .79247 .38865 .79425 .39228 .79328 .3901 .7915 Mtetra
.3901 .7915 .39228 .79328 .39592 .79232 .39374 .79053 Mtetra
.39374 .79053 .39592 .79232 .39956 .79135 .39738 .78956 Mtetra
.39738 .78956 .39956 .79135 .4032 .79038 .40103 .7886 Mtetra
.40103 .7886 .4032 .79038 .40685 .78942 .40468 .78762 Mtetra
.40468 .78762 .40685 .78942 .41051 .78845 .40834 .78665 Mtetra
.40834 .78665 .41051 .78845 .41417 .78747 .412 .78568 Mtetra
.412 .78568 .41417 .78747 .41783 .7865 .41567 .7847 Mtetra
.41567 .7847 .41783 .7865 .4215 .78553 .41934 .78373 Mtetra
.41934 .78373 .4215 .78553 .42518 .78455 .42302 .78275 Mtetra
.42302 .78275 .42518 .78455 .42886 .78358 .4267 .78177 Mtetra
.4267 .78177 .42886 .78358 .43254 .7826 .43039 .78079 Mtetra
.43039 .78079 .43254 .7826 .43623 .78162 .43408 .77981 Mtetra
.43408 .77981 .43623 .78162 .43992 .78064 .43778 .77882 Mtetra
.43778 .77882 .43992 .78064 .44362 .77966 .44148 .77784 Mtetra
.44148 .77784 .44362 .77966 .44733 .77867 .44519 .77685 Mtetra
.44519 .77685 .44733 .77867 .45104 .77769 .4489 .77587 Mtetra
.4489 .77587 .45104 .77769 .45475 .7767 .45262 .77488 Mtetra
.45262 .77488 .45475 .7767 .45847 .77572 .45635 .77389 Mtetra
.45635 .77389 .45847 .77572 .4622 .77473 .46007 .7729 Mtetra
.943 .696 .534 r
.46007 .7729 .4622 .77473 .46758 .67333 .46552 .67143 Mtetra
.655 .752 .921 r
.46552 .67143 .46758 .67333 .47121 .6723 .46915 .6704 Mtetra
.46915 .6704 .47121 .6723 .47484 .67127 .47279 .66936 Mtetra
.47279 .66936 .47484 .67127 .47849 .67024 .47644 .66832 Mtetra
.47644 .66832 .47849 .67024 .48213 .6692 .48009 .66729 Mtetra
.48009 .66729 .48213 .6692 .48578 .66817 .48374 .66625 Mtetra
.48374 .66625 .48578 .66817 .48944 .66713 .4874 .66521 Mtetra
.4874 .66521 .48944 .66713 .4931 .66609 .49106 .66417 Mtetra
.49106 .66417 .4931 .66609 .49677 .66505 .49473 .66312 Mtetra
.49473 .66312 .49677 .66505 .50044 .66401 .49841 .66208 Mtetra
.49841 .66208 .50044 .66401 .50412 .66296 .50209 .66103 Mtetra
.50209 .66103 .50412 .66296 .5078 .66192 .50577 .65999 Mtetra
.50577 .65999 .5078 .66192 .51148 .66087 .50946 .65894 Mtetra
.50946 .65894 .51148 .66087 .51517 .65983 .51316 .65789 Mtetra
.51316 .65789 .51517 .65983 .51887 .65878 .51685 .65684 Mtetra
.51685 .65684 .51887 .65878 .52257 .65773 .52056 .65578 Mtetra
.52056 .65578 .52257 .65773 .52628 .65667 .52427 .65473 Mtetra
.52427 .65473 .52628 .65667 .52999 .65562 .52798 .65367 Mtetra
.52798 .65367 .52999 .65562 .5337 .65457 .5317 .65262 Mtetra
.5317 .65262 .5337 .65457 .53743 .65351 .53543 .65156 Mtetra
.53543 .65156 .53743 .65351 .54115 .65245 .53916 .6505 Mtetra
.53916 .6505 .54115 .65245 .54488 .6514 .54289 .64944 Mtetra
.54289 .64944 .54488 .6514 .54862 .65034 .54663 .64837 Mtetra
.54663 .64837 .54862 .65034 .55236 .64927 .55037 .64731 Mtetra
.55037 .64731 .55236 .64927 .55611 .64821 .55412 .64624 Mtetra
.55412 .64624 .55611 .64821 .55986 .64715 .55788 .64518 Mtetra
.956 .641 .389 r
.55788 .64518 .55986 .64715 .56361 .64608 .56195 .67395 Mtetra
.554 .322 .517 r
.56195 .67395 .56361 .64608 .56774 .67484 .56575 .67289 Mtetra
.653 .755 .925 r
.56575 .67289 .56774 .67484 .57154 .67379 .56955 .67183 Mtetra
.56955 .67183 .57154 .67379 .57534 .67273 .57336 .67077 Mtetra
.57336 .67077 .57534 .67273 .57915 .67167 .57717 .6697 Mtetra
.57717 .6697 .57915 .67167 .58297 .6706 .58099 .66864 Mtetra
.58099 .66864 .58297 .6706 .58679 .66954 .58482 .66757 Mtetra
.58482 .66757 .58679 .66954 .59061 .66848 .58865 .66651 Mtetra
.58865 .66651 .59061 .66848 .59444 .66741 .59248 .66544 Mtetra
.59248 .66544 .59444 .66741 .59828 .66634 .59632 .66437 Mtetra
.59632 .66437 .59828 .66634 .60212 .66527 .60016 .66329 Mtetra
.60016 .66329 .60212 .66527 .60597 .6642 .60401 .66222 Mtetra
.60401 .66222 .60597 .6642 .60982 .66313 .60787 .66115 Mtetra
.60787 .66115 .60982 .66313 .61445 .69255 .61173 .66007 Mtetra
.111 .054 .506 r
.61173 .66007 .61445 .69255 .61835 .69148 .61639 .68952 Mtetra
.65 .758 .928 r
.61639 .68952 .61835 .69148 .62225 .69042 .6203 .68845 Mtetra
.6203 .68845 .62225 .69042 .62616 .68935 .62421 .68738 Mtetra
.62421 .68738 .62616 .68935 .63007 .68828 .62813 .68631 Mtetra
.62813 .68631 .63007 .68828 .63399 .68721 .63205 .68524 Mtetra
.63205 .68524 .63399 .68721 .63792 .68614 .63598 .68416 Mtetra
.63598 .68416 .63792 .68614 .64185 .68507 .63991 .68309 Mtetra
.63991 .68309 .64185 .68507 .64578 .684 .64385 .68201 Mtetra
.64385 .68201 .64578 .684 .64972 .68292 .64779 .68093 Mtetra
.64779 .68093 .64972 .68292 .65367 .68185 .65174 .67985 Mtetra
.65174 .67985 .65367 .68185 .65762 .68077 .6557 .67877 Mtetra
.6557 .67877 .65762 .68077 .66158 .67969 .65966 .67769 Mtetra
.65966 .67769 .66158 .67969 .66554 .67861 .66363 .67661 Mtetra
.66363 .67661 .66554 .67861 .66951 .67752 .6676 .67552 Mtetra
.6676 .67552 .66951 .67752 .67348 .67644 .67158 .67443 Mtetra
.67158 .67443 .67348 .67644 .67746 .67535 .67556 .67334 Mtetra
.67556 .67334 .67746 .67535 .68145 .67426 .67955 .67225 Mtetra
.67955 .67225 .68145 .67426 .68544 .67318 .68354 .67116 Mtetra
.68354 .67116 .68544 .67318 .68944 .67209 .68755 .67007 Mtetra
.68755 .67007 .68944 .67209 .69344 .67099 .69155 .66897 Mtetra
.69155 .66897 .69344 .67099 .69745 .6699 .69556 .66788 Mtetra
.69556 .66788 .69745 .6699 .70146 .6688 .69958 .66678 Mtetra
.968 .707 .484 r
.69958 .66678 .70146 .6688 .70207 .60173 .70022 .59966 Mtetra
.656 .751 .92 r
.70022 .59966 .70207 .60173 .70601 .60061 .70417 .59853 Mtetra
.70417 .59853 .70601 .60061 .70996 .59948 .70813 .5974 Mtetra
.70813 .5974 .70996 .59948 .71392 .59836 .71209 .59627 Mtetra
.71209 .59627 .71392 .59836 .71788 .59723 .71605 .59514 Mtetra
.71605 .59514 .71788 .59723 .72185 .5961 .72003 .59401 Mtetra
.72003 .59401 .72185 .5961 .72583 .59497 .724 .59288 Mtetra
.724 .59288 .72583 .59497 .72981 .59384 .72799 .59174 Mtetra
.72799 .59174 .72981 .59384 .73379 .5927 .73198 .5906 Mtetra
.73198 .5906 .73379 .5927 .73778 .59157 .73597 .58946 Mtetra
.73597 .58946 .73778 .59157 .74178 .59043 .73997 .58832 Mtetra
.73997 .58832 .74178 .59043 .74741 .61447 .74398 .58718 Mtetra
.184 .121 .548 r
.74398 .58718 .74741 .61447 .75145 .61334 .74964 .61125 Mtetra
.654 .754 .923 r
.74964 .61125 .75145 .61334 .75549 .61221 .75369 .61011 Mtetra
.75369 .61011 .75549 .61221 .75954 .61107 .75774 .60897 Mtetra
.75774 .60897 .75954 .61107 .7636 .60993 .7618 .60783 Mtetra
.7618 .60783 .7636 .60993 .76766 .6088 .76586 .60669 Mtetra
.76586 .60669 .76766 .6088 .77172 .60766 .76994 .60555 Mtetra
.76994 .60555 .77172 .60766 .7758 .60652 .77401 .60441 Mtetra
.77401 .60441 .7758 .60652 .77988 .60537 .77809 .60326 Mtetra
.77809 .60326 .77988 .60537 .78396 .60423 .78218 .60211 Mtetra
.78218 .60211 .78396 .60423 .78805 .60308 .78628 .60096 Mtetra
.78628 .60096 .78805 .60308 .79215 .60194 .79038 .59981 Mtetra
.79038 .59981 .79215 .60194 .79625 .60079 .79448 .59866 Mtetra
.79448 .59866 .79625 .60079 .80035 .59964 .79859 .59751 Mtetra
.79859 .59751 .80035 .59964 .80447 .59848 .80271 .59635 Mtetra
.80271 .59635 .80447 .59848 .80859 .59733 .80683 .59519 Mtetra
.80683 .59519 .80859 .59733 .81271 .59617 .81096 .59404 Mtetra
.81096 .59404 .81271 .59617 .81684 .59502 .8151 .59288 Mtetra
.8151 .59288 .81684 .59502 .82098 .59386 .81924 .59171 Mtetra
.81924 .59171 .82098 .59386 .82512 .5927 .82339 .59055 Mtetra
.82339 .59055 .82512 .5927 .82927 .59153 .82754 .58938 Mtetra
.924 .546 .145 r
.82754 .58938 .82927 .59153 .83343 .59037 .83355 .60881 Mtetra
.544 .298 .492 r
.83355 .60881 .83343 .59037 .83947 .60979 .83774 .60765 Mtetra
.652 .756 .926 r
.83774 .60765 .83947 .60979 .84367 .60863 .84194 .60648 Mtetra
.84194 .60648 .84367 .60863 .84786 .60747 .84614 .60532 Mtetra
.84614 .60532 .84786 .60747 .85207 .60631 .85035 .60415 Mtetra
.85035 .60415 .85207 .60631 .85628 .60514 .85457 .60299 Mtetra
.85457 .60299 .85628 .60514 .8605 .60397 .85879 .60182 Mtetra
.85879 .60182 .8605 .60397 .86472 .60281 .86302 .60065 Mtetra
.86302 .60065 .86472 .60281 .86895 .60164 .86725 .59947 Mtetra
.86725 .59947 .86895 .60164 .87319 .60047 .87149 .5983 Mtetra
.87149 .5983 .87319 .60047 .87743 .59929 .87574 .59712 Mtetra
.87574 .59712 .87743 .59929 .88168 .59812 .87999 .59594 Mtetra
.87999 .59594 .88168 .59812 .88593 .59694 .88425 .59477 Mtetra
.88425 .59477 .88593 .59694 .89019 .59576 .88851 .59358 Mtetra
.88851 .59358 .89019 .59576 .89446 .59458 .89278 .5924 Mtetra
.89278 .5924 .89446 .59458 .89873 .5934 .89706 .59122 Mtetra
.89706 .59122 .89873 .5934 .90301 .59222 .90135 .59003 Mtetra
.90135 .59003 .90301 .59222 .90729 .59103 .90564 .58884 Mtetra
.90564 .58884 .90729 .59103 .91159 .58985 .90993 .58765 Mtetra
.90993 .58765 .91159 .58985 .91588 .58866 .91423 .58646 Mtetra
.91423 .58646 .91588 .58866 .92019 .58747 .91854 .58527 Mtetra
.91854 .58527 .92019 .58747 .9245 .58628 .92286 .58407 Mtetra
.92286 .58407 .9245 .58628 .92881 .58508 .92718 .58287 Mtetra
.92718 .58287 .92881 .58508 .93314 .58389 .93151 .58168 Mtetra
.93151 .58168 .93314 .58389 .93747 .58269 .93584 .58048 Mtetra
.93584 .58048 .93747 .58269 .9418 .58149 .94018 .57927 Mtetra
.94018 .57927 .9418 .58149 .94614 .58029 .94453 .57807 Mtetra
.94453 .57807 .94614 .58029 .95049 .57909 .94888 .57686 Mtetra
.94888 .57686 .95049 .57909 .95485 .57788 .95324 .57566 Mtetra
.95324 .57566 .95485 .57788 .95921 .57668 .9576 .57445 Mtetra
.9576 .57445 .95921 .57668 .96358 .57547 .96198 .57324 Mtetra
.96198 .57324 .96358 .57547 .96795 .57426 .96636 .57202 Mtetra
.96636 .57202 .96795 .57426 .97233 .57305 .97074 .57081 Mtetra
.97074 .57081 .97233 .57305 .97672 .57184 .97513 .56959 Mtetra
.97513 .56959 .97672 .57184 .98111 .57062 .97953 .56837 Mtetra
.646 .762 .934 r
.38064 .79165 .38284 .79343 .38647 .79247 .38427 .79068 Mtetra
.38427 .79068 .38647 .79247 .3901 .7915 .38791 .78971 Mtetra
.38791 .78971 .3901 .7915 .39374 .79053 .39155 .78874 Mtetra
.39155 .78874 .39374 .79053 .39738 .78956 .3952 .78777 Mtetra
.3952 .78777 .39738 .78956 .40103 .7886 .39885 .7868 Mtetra
.39885 .7868 .40103 .7886 .40468 .78762 .4025 .78583 Mtetra
.4025 .78583 .40468 .78762 .40834 .78665 .40616 .78485 Mtetra
.40616 .78485 .40834 .78665 .412 .78568 .40983 .78388 Mtetra
.40983 .78388 .412 .78568 .41567 .7847 .4135 .7829 Mtetra
.4135 .7829 .41567 .7847 .41934 .78373 .41718 .78192 Mtetra
.41718 .78192 .41934 .78373 .42302 .78275 .42086 .78094 Mtetra
.42086 .78094 .42302 .78275 .4267 .78177 .42454 .77996 Mtetra
.42454 .77996 .4267 .78177 .43039 .78079 .42823 .77898 Mtetra
.42823 .77898 .43039 .78079 .43408 .77981 .43193 .77799 Mtetra
.43193 .77799 .43408 .77981 .43778 .77882 .43563 .77701 Mtetra
.43563 .77701 .43778 .77882 .44148 .77784 .43934 .77602 Mtetra
.43934 .77602 .44148 .77784 .44519 .77685 .44305 .77503 Mtetra
.44305 .77503 .44519 .77685 .4489 .77587 .44677 .77404 Mtetra
.44677 .77404 .4489 .77587 .45262 .77488 .45049 .77305 Mtetra
.45049 .77305 .45262 .77488 .45635 .77389 .45421 .77206 Mtetra
.45421 .77206 .45635 .77389 .46007 .7729 .45794 .77106 Mtetra
.45794 .77106 .46007 .7729 .46552 .67143 .46168 .77007 Mtetra
0 0 .341 r
.46168 .77007 .46552 .67143 .46915 .6704 .46709 .66848 Mtetra
.655 .752 .921 r
.46709 .66848 .46915 .6704 .47279 .66936 .47073 .66745 Mtetra
.47073 .66745 .47279 .66936 .47644 .66832 .47438 .66641 Mtetra
.47438 .66641 .47644 .66832 .48009 .66729 .47803 .66537 Mtetra
.47803 .66537 .48009 .66729 .48374 .66625 .48169 .66433 Mtetra
.48169 .66433 .48374 .66625 .4874 .66521 .48535 .66328 Mtetra
.48535 .66328 .4874 .66521 .49106 .66417 .48902 .66224 Mtetra
.48902 .66224 .49106 .66417 .49473 .66312 .49269 .66119 Mtetra
.49269 .66119 .49473 .66312 .49841 .66208 .49637 .66015 Mtetra
.49637 .66015 .49841 .66208 .50209 .66103 .50005 .6591 Mtetra
.50005 .6591 .50209 .66103 .50577 .65999 .50374 .65805 Mtetra
.50374 .65805 .50577 .65999 .50946 .65894 .50743 .657 Mtetra
.50743 .657 .50946 .65894 .51316 .65789 .51113 .65595 Mtetra
.51113 .65595 .51316 .65789 .51685 .65684 .51483 .65489 Mtetra
.51483 .65489 .51685 .65684 .52056 .65578 .51854 .65384 Mtetra
.51854 .65384 .52056 .65578 .52427 .65473 .52225 .65278 Mtetra
.52225 .65278 .52427 .65473 .52798 .65367 .52597 .65172 Mtetra
.52597 .65172 .52798 .65367 .5317 .65262 .52969 .65066 Mtetra
.52969 .65066 .5317 .65262 .53543 .65156 .53342 .6496 Mtetra
.53342 .6496 .53543 .65156 .53916 .6505 .53715 .64854 Mtetra
.53715 .64854 .53916 .6505 .54289 .64944 .54089 .64747 Mtetra
.54089 .64747 .54289 .64944 .54663 .64837 .54463 .64641 Mtetra
.54463 .64641 .54663 .64837 .55037 .64731 .54838 .64534 Mtetra
.54838 .64534 .55037 .64731 .55412 .64624 .55214 .64427 Mtetra
.55214 .64427 .55412 .64624 .55788 .64518 .55589 .6432 Mtetra
.956 .641 .389 r
.55589 .6432 .55788 .64518 .56195 .67395 .55996 .67199 Mtetra
.653 .755 .925 r
.55996 .67199 .56195 .67395 .56575 .67289 .56376 .67093 Mtetra
.56376 .67093 .56575 .67289 .56955 .67183 .56756 .66987 Mtetra
.56756 .66987 .56955 .67183 .57336 .67077 .57137 .6688 Mtetra
.57137 .6688 .57336 .67077 .57717 .6697 .57519 .66774 Mtetra
.57519 .66774 .57717 .6697 .58099 .66864 .57901 .66667 Mtetra
.57901 .66667 .58099 .66864 .58482 .66757 .58284 .6656 Mtetra
.58284 .6656 .58482 .66757 .58865 .66651 .58667 .66453 Mtetra
.58667 .66453 .58865 .66651 .59248 .66544 .59051 .66346 Mtetra
.59051 .66346 .59248 .66544 .59632 .66437 .59435 .66239 Mtetra
.59435 .66239 .59632 .66437 .60016 .66329 .5982 .66131 Mtetra
.5982 .66131 .60016 .66329 .60401 .66222 .60206 .66024 Mtetra
.60206 .66024 .60401 .66222 .60787 .66115 .60591 .65916 Mtetra
.60591 .65916 .60787 .66115 .61173 .66007 .60978 .65808 Mtetra
.959 .636 .365 r
.60978 .65808 .61173 .66007 .61639 .68952 .61443 .68754 Mtetra
.65 .758 .928 r
.61443 .68754 .61639 .68952 .6203 .68845 .61834 .68647 Mtetra
.61834 .68647 .6203 .68845 .62421 .68738 .62225 .6854 Mtetra
.62225 .6854 .62421 .68738 .62813 .68631 .62617 .68433 Mtetra
.62617 .68433 .62813 .68631 .63205 .68524 .6301 .68325 Mtetra
.6301 .68325 .63205 .68524 .63598 .68416 .63403 .68218 Mtetra
.63403 .68218 .63598 .68416 .63991 .68309 .63797 .6811 Mtetra
.63797 .6811 .63991 .68309 .64385 .68201 .64191 .68002 Mtetra
.64191 .68002 .64385 .68201 .64779 .68093 .64586 .67894 Mtetra
.64586 .67894 .64779 .68093 .65174 .67985 .64981 .67786 Mtetra
.64981 .67786 .65174 .67985 .6557 .67877 .65377 .67677 Mtetra
.65377 .67677 .6557 .67877 .65966 .67769 .65774 .67569 Mtetra
.65774 .67569 .65966 .67769 .66363 .67661 .66171 .6746 Mtetra
.66171 .6746 .66363 .67661 .6676 .67552 .66568 .67351 Mtetra
.66568 .67351 .6676 .67552 .67158 .67443 .66967 .67242 Mtetra
.66967 .67242 .67158 .67443 .67556 .67334 .67365 .67133 Mtetra
.67365 .67133 .67556 .67334 .67955 .67225 .67765 .67024 Mtetra
.67765 .67024 .67955 .67225 .68354 .67116 .68164 .66914 Mtetra
.68164 .66914 .68354 .67116 .68755 .67007 .68565 .66805 Mtetra
.68565 .66805 .68755 .67007 .69155 .66897 .68966 .66695 Mtetra
.68966 .66695 .69155 .66897 .69556 .66788 .69367 .66585 Mtetra
.968 .707 .486 r
.69367 .66585 .69556 .66788 .69958 .66678 .69442 .5987 Mtetra
.579 .382 .579 r
.69442 .5987 .69958 .66678 .70022 .59966 .69837 .59758 Mtetra
.656 .751 .92 r
.69837 .59758 .70022 .59966 .70417 .59853 .70233 .59645 Mtetra
.70233 .59645 .70417 .59853 .70813 .5974 .70629 .59532 Mtetra
.70629 .59532 .70813 .5974 .71209 .59627 .71025 .59419 Mtetra
.71025 .59419 .71209 .59627 .71605 .59514 .71422 .59305 Mtetra
.71422 .59305 .71605 .59514 .72003 .59401 .7182 .59192 Mtetra
.7182 .59192 .72003 .59401 .724 .59288 .72218 .59078 Mtetra
.72218 .59078 .724 .59288 .72799 .59174 .72617 .58964 Mtetra
.72617 .58964 .72799 .59174 .73198 .5906 .73016 .5885 Mtetra
.73016 .5885 .73198 .5906 .73597 .58946 .73416 .58736 Mtetra
.73416 .58736 .73597 .58946 .73997 .58832 .73816 .58621 Mtetra
.73816 .58621 .73997 .58832 .74398 .58718 .74217 .58507 Mtetra
.952 .6 .257 r
.74217 .58507 .74398 .58718 .74964 .61125 .74782 .60915 Mtetra
.654 .754 .923 r
.74782 .60915 .74964 .61125 .75369 .61011 .75188 .60801 Mtetra
.75188 .60801 .75369 .61011 .75774 .60897 .75593 .60687 Mtetra
.75593 .60687 .75774 .60897 .7618 .60783 .76 .60573 Mtetra
.76 .60573 .7618 .60783 .76586 .60669 .76407 .60458 Mtetra
.76407 .60458 .76586 .60669 .76994 .60555 .76814 .60344 Mtetra
.76814 .60344 .76994 .60555 .77401 .60441 .77222 .60229 Mtetra
.77222 .60229 .77401 .60441 .77809 .60326 .77631 .60114 Mtetra
.77631 .60114 .77809 .60326 .78218 .60211 .7804 .59999 Mtetra
.7804 .59999 .78218 .60211 .78628 .60096 .7845 .59884 Mtetra
.7845 .59884 .78628 .60096 .79038 .59981 .7886 .59768 Mtetra
.7886 .59768 .79038 .59981 .79448 .59866 .79271 .59653 Mtetra
.79271 .59653 .79448 .59866 .79859 .59751 .79683 .59537 Mtetra
.79683 .59537 .79859 .59751 .80271 .59635 .80095 .59421 Mtetra
.80095 .59421 .80271 .59635 .80683 .59519 .80508 .59305 Mtetra
.80508 .59305 .80683 .59519 .81096 .59404 .80921 .59189 Mtetra
.80921 .59189 .81096 .59404 .8151 .59288 .81335 .59073 Mtetra
.81335 .59073 .8151 .59288 .81924 .59171 .8175 .58956 Mtetra
.8175 .58956 .81924 .59171 .82339 .59055 .82165 .5884 Mtetra
.82165 .5884 .82339 .59055 .82754 .58938 .8258 .58723 Mtetra
.924 .546 .145 r
.8258 .58723 .82754 .58938 .83355 .60881 .83181 .60666 Mtetra
.652 .756 .926 r
.83181 .60666 .83355 .60881 .83774 .60765 .83601 .6055 Mtetra
.83601 .6055 .83774 .60765 .84194 .60648 .84021 .60433 Mtetra
.84021 .60433 .84194 .60648 .84614 .60532 .84442 .60317 Mtetra
.84442 .60317 .84614 .60532 .85035 .60415 .84863 .602 Mtetra
.84863 .602 .85035 .60415 .85457 .60299 .85285 .60083 Mtetra
.85285 .60083 .85457 .60299 .85879 .60182 .85708 .59965 Mtetra
.85708 .59965 .85879 .60182 .86302 .60065 .86131 .59848 Mtetra
.86131 .59848 .86302 .60065 .86725 .59947 .86555 .5973 Mtetra
.86555 .5973 .86725 .59947 .87149 .5983 .86979 .59613 Mtetra
.86979 .59613 .87149 .5983 .87574 .59712 .87404 .59495 Mtetra
.87404 .59495 .87574 .59712 .87999 .59594 .8783 .59377 Mtetra
.8783 .59377 .87999 .59594 .88425 .59477 .88256 .59258 Mtetra
.88256 .59258 .88425 .59477 .88851 .59358 .88683 .5914 Mtetra
.88683 .5914 .88851 .59358 .89278 .5924 .89111 .59021 Mtetra
.89111 .59021 .89278 .5924 .89706 .59122 .89539 .58902 Mtetra
.89539 .58902 .89706 .59122 .90135 .59003 .89968 .58783 Mtetra
.89968 .58783 .90135 .59003 .90564 .58884 .90397 .58664 Mtetra
.90397 .58664 .90564 .58884 .90993 .58765 .90827 .58545 Mtetra
.90827 .58545 .90993 .58765 .91423 .58646 .91258 .58426 Mtetra
.91258 .58426 .91423 .58646 .91854 .58527 .91689 .58306 Mtetra
.91689 .58306 .91854 .58527 .92286 .58407 .92121 .58186 Mtetra
.92121 .58186 .92286 .58407 .92718 .58287 .92554 .58066 Mtetra
.92554 .58066 .92718 .58287 .93151 .58168 .92987 .57946 Mtetra
.92987 .57946 .93151 .58168 .93584 .58048 .93421 .57825 Mtetra
.93421 .57825 .93584 .58048 .94018 .57927 .93855 .57705 Mtetra
.93855 .57705 .94018 .57927 .94453 .57807 .9429 .57584 Mtetra
.9429 .57584 .94453 .57807 .94888 .57686 .94726 .57463 Mtetra
.94726 .57463 .94888 .57686 .95324 .57566 .95163 .57342 Mtetra
.95163 .57342 .95324 .57566 .9576 .57445 .956 .57221 Mtetra
.956 .57221 .9576 .57445 .96198 .57324 .96037 .57099 Mtetra
.96037 .57099 .96198 .57324 .96636 .57202 .96476 .56978 Mtetra
.96476 .56978 .96636 .57202 .97074 .57081 .96915 .56856 Mtetra
.96915 .56856 .97074 .57081 .97513 .56959 .97354 .56734 Mtetra
.97354 .56734 .97513 .56959 .97953 .56837 .97795 .56612 Mtetra
.646 .762 .934 r
.37844 .78986 .38064 .79165 .38427 .79068 .38207 .78889 Mtetra
.38207 .78889 .38427 .79068 .38791 .78971 .38571 .78792 Mtetra
.38571 .78792 .38791 .78971 .39155 .78874 .38936 .78695 Mtetra
.38936 .78695 .39155 .78874 .3952 .78777 .39301 .78598 Mtetra
.39301 .78598 .3952 .78777 .39885 .7868 .39666 .785 Mtetra
.39666 .785 .39885 .7868 .4025 .78583 .40032 .78403 Mtetra
.40032 .78403 .4025 .78583 .40616 .78485 .40398 .78305 Mtetra
.40398 .78305 .40616 .78485 .40983 .78388 .40765 .78207 Mtetra
.40765 .78207 .40983 .78388 .4135 .7829 .41133 .78109 Mtetra
.41133 .78109 .4135 .7829 .41718 .78192 .41501 .78011 Mtetra
.41501 .78011 .41718 .78192 .42086 .78094 .41869 .77913 Mtetra
.41869 .77913 .42086 .78094 .42454 .77996 .42238 .77814 Mtetra
.42238 .77814 .42454 .77996 .42823 .77898 .42607 .77716 Mtetra
.42607 .77716 .42823 .77898 .43193 .77799 .42977 .77617 Mtetra
.42977 .77617 .43193 .77799 .43563 .77701 .43348 .77518 Mtetra
.43348 .77518 .43563 .77701 .43934 .77602 .43719 .77419 Mtetra
.43719 .77419 .43934 .77602 .44305 .77503 .4409 .7732 Mtetra
.4409 .7732 .44305 .77503 .44677 .77404 .44462 .77221 Mtetra
.44462 .77221 .44677 .77404 .45049 .77305 .44834 .77122 Mtetra
.44834 .77122 .45049 .77305 .45421 .77206 .45207 .77022 Mtetra
.45207 .77022 .45421 .77206 .45794 .77106 .45581 .76923 Mtetra
.45581 .76923 .45794 .77106 .46168 .77007 .45955 .76823 Mtetra
.943 .696 .533 r
.45955 .76823 .46168 .77007 .46709 .66848 .46502 .66657 Mtetra
.655 .752 .921 r
.46502 .66657 .46709 .66848 .47073 .66745 .46867 .66553 Mtetra
.46867 .66553 .47073 .66745 .47438 .66641 .47232 .66449 Mtetra
.47232 .66449 .47438 .66641 .47803 .66537 .47598 .66344 Mtetra
.47598 .66344 .47803 .66537 .48169 .66433 .47964 .6624 Mtetra
.47964 .6624 .48169 .66433 .48535 .66328 .4833 .66136 Mtetra
.4833 .66136 .48535 .66328 .48902 .66224 .48697 .66031 Mtetra
.48697 .66031 .48902 .66224 .49269 .66119 .49065 .65926 Mtetra
.49065 .65926 .49269 .66119 .49637 .66015 .49433 .65821 Mtetra
.49433 .65821 .49637 .66015 .50005 .6591 .49802 .65716 Mtetra
.49802 .65716 .50005 .6591 .50374 .65805 .50171 .65611 Mtetra
.50171 .65611 .50374 .65805 .50743 .657 .5054 .65505 Mtetra
.5054 .65505 .50743 .657 .51113 .65595 .5091 .654 Mtetra
.5091 .654 .51113 .65595 .51483 .65489 .51281 .65294 Mtetra
.51281 .65294 .51483 .65489 .51854 .65384 .51652 .65188 Mtetra
.51652 .65188 .51854 .65384 .52225 .65278 .52024 .65082 Mtetra
.52024 .65082 .52225 .65278 .52597 .65172 .52396 .64976 Mtetra
.52396 .64976 .52597 .65172 .52969 .65066 .52768 .6487 Mtetra
.52768 .6487 .52969 .65066 .53342 .6496 .53141 .64764 Mtetra
.53141 .64764 .53342 .6496 .53715 .64854 .53515 .64657 Mtetra
.53515 .64657 .53715 .64854 .54089 .64747 .53889 .64551 Mtetra
.53889 .64551 .54089 .64747 .54463 .64641 .54264 .64444 Mtetra
.54264 .64444 .54463 .64641 .54838 .64534 .54639 .64337 Mtetra
.54639 .64337 .54838 .64534 .55214 .64427 .55014 .6423 Mtetra
.956 .641 .39 r
.55014 .6423 .55214 .64427 .55589 .6432 .55415 .67109 Mtetra
.553 .32 .516 r
.55415 .67109 .55589 .6432 .55996 .67199 .55795 .67003 Mtetra
.653 .755 .925 r
.55795 .67003 .55996 .67199 .56376 .67093 .56176 .66897 Mtetra
.56176 .66897 .56376 .67093 .56756 .66987 .56557 .6679 Mtetra
.56557 .6679 .56756 .66987 .57137 .6688 .56938 .66683 Mtetra
.56938 .66683 .57137 .6688 .57519 .66774 .5732 .66577 Mtetra
.5732 .66577 .57519 .66774 .57901 .66667 .57703 .6647 Mtetra
.57703 .6647 .57901 .66667 .58284 .6656 .58086 .66362 Mtetra
.58086 .66362 .58284 .6656 .58667 .66453 .58469 .66255 Mtetra
.58469 .66255 .58667 .66453 .59051 .66346 .58854 .66148 Mtetra
.58854 .66148 .59051 .66346 .59435 .66239 .59238 .6604 Mtetra
.59238 .6604 .59435 .66239 .5982 .66131 .59623 .65932 Mtetra
.59623 .65932 .5982 .66131 .60206 .66024 .60009 .65824 Mtetra
.60009 .65824 .60206 .66024 .60591 .65916 .60395 .65716 Mtetra
.60395 .65716 .60591 .65916 .60978 .65808 .60782 .65608 Mtetra
.60782 .65608 .60978 .65808 .61443 .68754 .6117 .655 Mtetra
.109 .052 .505 r
.6117 .655 .61443 .68754 .61834 .68647 .61637 .68449 Mtetra
.65 .758 .928 r
.61637 .68449 .61834 .68647 .62225 .6854 .62029 .68342 Mtetra
.62029 .68342 .62225 .6854 .62617 .68433 .62422 .68234 Mtetra
.62422 .68234 .62617 .68433 .6301 .68325 .62815 .68126 Mtetra
.62815 .68126 .6301 .68325 .63403 .68218 .63208 .68019 Mtetra
.63208 .68019 .63403 .68218 .63797 .6811 .63602 .6791 Mtetra
.63602 .6791 .63797 .6811 .64191 .68002 .63997 .67802 Mtetra
.63997 .67802 .64191 .68002 .64586 .67894 .64392 .67694 Mtetra
.64392 .67694 .64586 .67894 .64981 .67786 .64788 .67585 Mtetra
.64788 .67585 .64981 .67786 .65377 .67677 .65184 .67477 Mtetra
.65184 .67477 .65377 .67677 .65774 .67569 .65581 .67368 Mtetra
.65581 .67368 .65774 .67569 .66171 .6746 .65978 .67259 Mtetra
.65978 .67259 .66171 .6746 .66568 .67351 .66376 .6715 Mtetra
.66376 .6715 .66568 .67351 .66967 .67242 .66775 .6704 Mtetra
.66775 .6704 .66967 .67242 .67365 .67133 .67174 .66931 Mtetra
.67174 .66931 .67365 .67133 .67765 .67024 .67574 .66821 Mtetra
.67574 .66821 .67765 .67024 .68164 .66914 .67974 .66712 Mtetra
.67974 .66712 .68164 .66914 .68565 .66805 .68375 .66602 Mtetra
.68375 .66602 .68565 .66805 .68966 .66695 .68776 .66492 Mtetra
.68776 .66492 .68966 .66695 .69367 .66585 .69178 .66381 Mtetra
.968 .707 .486 r
.69178 .66381 .69367 .66585 .69442 .5987 .69257 .59662 Mtetra
.656 .751 .92 r
.69257 .59662 .69442 .5987 .69837 .59758 .69652 .59549 Mtetra
.69652 .59549 .69837 .59758 .70233 .59645 .70048 .59436 Mtetra
.70048 .59436 .70233 .59645 .70629 .59532 .70444 .59323 Mtetra
.70444 .59323 .70629 .59532 .71025 .59419 .70841 .59209 Mtetra
.70841 .59209 .71025 .59419 .71422 .59305 .71238 .59095 Mtetra
.71238 .59095 .71422 .59305 .7182 .59192 .71636 .58982 Mtetra
.71636 .58982 .7182 .59192 .72218 .59078 .72035 .58868 Mtetra
.72035 .58868 .72218 .59078 .72617 .58964 .72434 .58753 Mtetra
.72434 .58753 .72617 .58964 .73016 .5885 .72834 .58639 Mtetra
.72834 .58639 .73016 .5885 .73416 .58736 .73234 .58525 Mtetra
.73234 .58525 .73416 .58736 .73816 .58621 .73635 .5841 Mtetra
.73635 .5841 .73816 .58621 .74217 .58507 .74036 .58295 Mtetra
.74036 .58295 .74217 .58507 .74782 .60915 .74438 .5818 Mtetra
.182 .12 .547 r
.74438 .5818 .74782 .60915 .75188 .60801 .75006 .6059 Mtetra
.654 .754 .923 r
.75006 .6059 .75188 .60801 .75593 .60687 .75412 .60476 Mtetra
.75412 .60476 .75593 .60687 .76 .60573 .75819 .60361 Mtetra
.75819 .60361 .76 .60573 .76407 .60458 .76226 .60247 Mtetra
.76226 .60247 .76407 .60458 .76814 .60344 .76634 .60132 Mtetra
.76634 .60132 .76814 .60344 .77222 .60229 .77043 .60017 Mtetra
.77043 .60017 .77222 .60229 .77631 .60114 .77452 .59902 Mtetra
.77452 .59902 .77631 .60114 .7804 .59999 .77861 .59786 Mtetra
.77861 .59786 .7804 .59999 .7845 .59884 .78272 .59671 Mtetra
.78272 .59671 .7845 .59884 .7886 .59768 .78683 .59555 Mtetra
.78683 .59555 .7886 .59768 .79271 .59653 .79094 .59439 Mtetra
.79094 .59439 .79271 .59653 .79683 .59537 .79506 .59323 Mtetra
.79506 .59323 .79683 .59537 .80095 .59421 .79918 .59207 Mtetra
.79918 .59207 .80095 .59421 .80508 .59305 .80332 .59091 Mtetra
.80332 .59091 .80508 .59305 .80921 .59189 .80745 .58974 Mtetra
.80745 .58974 .80921 .59189 .81335 .59073 .8116 .58858 Mtetra
.8116 .58858 .81335 .59073 .8175 .58956 .81575 .58741 Mtetra
.81575 .58741 .8175 .58956 .82165 .5884 .8199 .58624 Mtetra
.8199 .58624 .82165 .5884 .8258 .58723 .82406 .58507 Mtetra
.924 .546 .145 r
.82406 .58507 .8258 .58723 .83181 .60666 .83007 .60451 Mtetra
.652 .756 .926 r
.83007 .60451 .83181 .60666 .83601 .6055 .83427 .60335 Mtetra
.83427 .60335 .83601 .6055 .84021 .60433 .83847 .60218 Mtetra
.83847 .60218 .84021 .60433 .84442 .60317 .84269 .60101 Mtetra
.84269 .60101 .84442 .60317 .84863 .602 .8469 .59983 Mtetra
.8469 .59983 .84863 .602 .85285 .60083 .85113 .59866 Mtetra
.85113 .59866 .85285 .60083 .85708 .59965 .85536 .59748 Mtetra
.85536 .59748 .85708 .59965 .86131 .59848 .8596 .59631 Mtetra
.8596 .59631 .86131 .59848 .86555 .5973 .86384 .59513 Mtetra
.86384 .59513 .86555 .5973 .86979 .59613 .86809 .59395 Mtetra
.86809 .59395 .86979 .59613 .87404 .59495 .87234 .59277 Mtetra
.87234 .59277 .87404 .59495 .8783 .59377 .8766 .59158 Mtetra
.8766 .59158 .8783 .59377 .88256 .59258 .88087 .59039 Mtetra
.88087 .59039 .88256 .59258 .88683 .5914 .88515 .58921 Mtetra
.88515 .58921 .88683 .5914 .89111 .59021 .88943 .58802 Mtetra
.88943 .58802 .89111 .59021 .89539 .58902 .89371 .58683 Mtetra
.89371 .58683 .89539 .58902 .89968 .58783 .898 .58563 Mtetra
.898 .58563 .89968 .58783 .90397 .58664 .9023 .58444 Mtetra
.9023 .58444 .90397 .58664 .90827 .58545 .90661 .58324 Mtetra
.90661 .58324 .90827 .58545 .91258 .58426 .91092 .58204 Mtetra
.91092 .58204 .91258 .58426 .91689 .58306 .91524 .58084 Mtetra
.91524 .58084 .91689 .58306 .92121 .58186 .91956 .57964 Mtetra
.91956 .57964 .92121 .58186 .92554 .58066 .92389 .57844 Mtetra
.92389 .57844 .92554 .58066 .92987 .57946 .92823 .57723 Mtetra
.92823 .57723 .92987 .57946 .93421 .57825 .93257 .57603 Mtetra
.93257 .57603 .93421 .57825 .93855 .57705 .93692 .57482 Mtetra
.93692 .57482 .93855 .57705 .9429 .57584 .94128 .57361 Mtetra
.94128 .57361 .9429 .57584 .94726 .57463 .94564 .5724 Mtetra
.94564 .5724 .94726 .57463 .95163 .57342 .95001 .57118 Mtetra
.95001 .57118 .95163 .57342 .956 .57221 .95438 .56997 Mtetra
.95438 .56997 .956 .57221 .96037 .57099 .95877 .56875 Mtetra
.95877 .56875 .96037 .57099 .96476 .56978 .96315 .56753 Mtetra
.96315 .56753 .96476 .56978 .96915 .56856 .96755 .56631 Mtetra
.96755 .56631 .96915 .56856 .97354 .56734 .97195 .56508 Mtetra
.97195 .56508 .97354 .56734 .97795 .56612 .97636 .56386 Mtetra
.646 .762 .934 r
.37623 .78807 .37844 .78986 .38207 .78889 .37987 .7871 Mtetra
.37987 .7871 .38207 .78889 .38571 .78792 .38351 .78613 Mtetra
.38351 .78613 .38571 .78792 .38936 .78695 .38716 .78515 Mtetra
.38716 .78515 .38936 .78695 .39301 .78598 .39081 .78418 Mtetra
.39081 .78418 .39301 .78598 .39666 .785 .39447 .7832 Mtetra
.39447 .7832 .39666 .785 .40032 .78403 .39813 .78222 Mtetra
.39813 .78222 .40032 .78403 .40398 .78305 .4018 .78124 Mtetra
.4018 .78124 .40398 .78305 .40765 .78207 .40547 .78026 Mtetra
.40547 .78026 .40765 .78207 .41133 .78109 .40915 .77928 Mtetra
.40915 .77928 .41133 .78109 .41501 .78011 .41283 .7783 Mtetra
.41283 .7783 .41501 .78011 .41869 .77913 .41652 .77731 Mtetra
.41652 .77731 .41869 .77913 .42238 .77814 .42021 .77632 Mtetra
.42021 .77632 .42238 .77814 .42607 .77716 .42391 .77534 Mtetra
.42391 .77534 .42607 .77716 .42977 .77617 .42761 .77435 Mtetra
.42761 .77435 .42977 .77617 .43348 .77518 .43132 .77336 Mtetra
.43132 .77336 .43348 .77518 .43719 .77419 .43503 .77236 Mtetra
.43503 .77236 .43719 .77419 .4409 .7732 .43875 .77137 Mtetra
.43875 .77137 .4409 .7732 .44462 .77221 .44247 .77038 Mtetra
.44247 .77038 .44462 .77221 .44834 .77122 .4462 .76938 Mtetra
.4462 .76938 .44834 .77122 .45207 .77022 .44993 .76838 Mtetra
.44993 .76838 .45207 .77022 .45581 .76923 .45367 .76738 Mtetra
.45367 .76738 .45581 .76923 .45955 .76823 .45741 .76638 Mtetra
.943 .696 .533 r
.45741 .76638 .45955 .76823 .46502 .66657 .46295 .66465 Mtetra
.655 .752 .921 r
.46295 .66465 .46502 .66657 .46867 .66553 .4666 .66361 Mtetra
.4666 .66361 .46867 .66553 .47232 .66449 .47025 .66256 Mtetra
.47025 .66256 .47232 .66449 .47598 .66344 .47391 .66152 Mtetra
.47391 .66152 .47598 .66344 .47964 .6624 .47758 .66047 Mtetra
.47758 .66047 .47964 .6624 .4833 .66136 .48125 .65942 Mtetra
.48125 .65942 .4833 .66136 .48697 .66031 .48492 .65837 Mtetra
.48492 .65837 .48697 .66031 .49065 .65926 .4886 .65732 Mtetra
.4886 .65732 .49065 .65926 .49433 .65821 .49228 .65627 Mtetra
.49228 .65627 .49433 .65821 .49802 .65716 .49597 .65522 Mtetra
.49597 .65522 .49802 .65716 .50171 .65611 .49967 .65416 Mtetra
.49967 .65416 .50171 .65611 .5054 .65505 .50337 .6531 Mtetra
.50337 .6531 .5054 .65505 .5091 .654 .50707 .65205 Mtetra
.50707 .65205 .5091 .654 .51281 .65294 .51078 .65099 Mtetra
.51078 .65099 .51281 .65294 .51652 .65188 .51449 .64993 Mtetra
.51449 .64993 .51652 .65188 .52024 .65082 .51821 .64886 Mtetra
.51821 .64886 .52024 .65082 .52396 .64976 .52194 .6478 Mtetra
.52194 .6478 .52396 .64976 .52768 .6487 .52566 .64674 Mtetra
.52566 .64674 .52768 .6487 .53141 .64764 .5294 .64567 Mtetra
.5294 .64567 .53141 .64764 .53515 .64657 .53314 .6446 Mtetra
.53314 .6446 .53515 .64657 .53889 .64551 .53688 .64353 Mtetra
.53688 .64353 .53889 .64551 .54264 .64444 .54063 .64246 Mtetra
.54063 .64246 .54264 .64444 .54639 .64337 .54439 .64139 Mtetra
.54439 .64139 .54639 .64337 .55014 .6423 .54815 .64032 Mtetra
.956 .641 .39 r
.54815 .64032 .55014 .6423 .55415 .67109 .55214 .66913 Mtetra
.653 .755 .925 r
.55214 .66913 .55415 .67109 .55795 .67003 .55595 .66807 Mtetra
.55595 .66807 .55795 .67003 .56176 .66897 .55975 .667 Mtetra
.55975 .667 .56176 .66897 .56557 .6679 .56357 .66593 Mtetra
.56357 .66593 .56557 .6679 .56938 .66683 .56739 .66486 Mtetra
.56739 .66486 .56938 .66683 .5732 .66577 .57121 .66379 Mtetra
.57121 .66379 .5732 .66577 .57703 .6647 .57504 .66272 Mtetra
.57504 .66272 .57703 .6647 .58086 .66362 .57887 .66164 Mtetra
.57887 .66164 .58086 .66362 .58469 .66255 .58271 .66057 Mtetra
.58271 .66057 .58469 .66255 .58854 .66148 .58656 .65949 Mtetra
.58656 .65949 .58854 .66148 .59238 .6604 .59041 .65841 Mtetra
.59041 .65841 .59238 .6604 .59623 .65932 .59426 .65733 Mtetra
.59426 .65733 .59623 .65932 .60009 .65824 .59812 .65625 Mtetra
.59812 .65625 .60009 .65824 .60395 .65716 .60199 .65517 Mtetra
.60199 .65517 .60395 .65716 .60782 .65608 .60586 .65408 Mtetra
.60586 .65408 .60782 .65608 .6117 .655 .60974 .65299 Mtetra
.60974 .65299 .6117 .655 .61637 .68449 .61362 .65191 Mtetra
.109 .052 .505 r
.61362 .65191 .61637 .68449 .62029 .68342 .61832 .68143 Mtetra
.65 .758 .928 r
.61832 .68143 .62029 .68342 .62422 .68234 .62225 .68035 Mtetra
.62225 .68035 .62422 .68234 .62815 .68126 .62619 .67927 Mtetra
.62619 .67927 .62815 .68126 .63208 .68019 .63012 .67819 Mtetra
.63012 .67819 .63208 .68019 .63602 .6791 .63407 .67711 Mtetra
.63407 .67711 .63602 .6791 .63997 .67802 .63802 .67602 Mtetra
.63802 .67602 .63997 .67802 .64392 .67694 .64198 .67493 Mtetra
.64198 .67493 .64392 .67694 .64788 .67585 .64594 .67385 Mtetra
.64594 .67385 .64788 .67585 .65184 .67477 .6499 .67276 Mtetra
.6499 .67276 .65184 .67477 .65581 .67368 .65388 .67167 Mtetra
.65388 .67167 .65581 .67368 .65978 .67259 .65785 .67057 Mtetra
.65785 .67057 .65978 .67259 .66376 .6715 .66184 .66948 Mtetra
.66184 .66948 .66376 .6715 .66775 .6704 .66583 .66838 Mtetra
.66583 .66838 .66775 .6704 .67174 .66931 .66982 .66729 Mtetra
.66982 .66729 .67174 .66931 .67574 .66821 .67382 .66619 Mtetra
.67382 .66619 .67574 .66821 .67974 .66712 .67783 .66509 Mtetra
.67783 .66509 .67974 .66712 .68375 .66602 .68184 .66398 Mtetra
.68184 .66398 .68375 .66602 .68776 .66492 .68586 .66288 Mtetra
.967 .707 .487 r
.68586 .66288 .68776 .66492 .69178 .66381 .68675 .59567 Mtetra
.578 .381 .578 r
.68675 .59567 .69178 .66381 .69257 .59662 .6907 .59453 Mtetra
.656 .751 .92 r
.6907 .59453 .69257 .59662 .69652 .59549 .69466 .5934 Mtetra
.69466 .5934 .69652 .59549 .70048 .59436 .69862 .59227 Mtetra
.69862 .59227 .70048 .59436 .70444 .59323 .70259 .59113 Mtetra
.70259 .59113 .70444 .59323 .70841 .59209 .70656 .58999 Mtetra
.70656 .58999 .70841 .59209 .71238 .59095 .71054 .58885 Mtetra
.71054 .58885 .71238 .59095 .71636 .58982 .71452 .58771 Mtetra
.71452 .58771 .71636 .58982 .72035 .58868 .71851 .58657 Mtetra
.71851 .58657 .72035 .58868 .72434 .58753 .72251 .58542 Mtetra
.72251 .58542 .72434 .58753 .72834 .58639 .72651 .58428 Mtetra
.72651 .58428 .72834 .58639 .73234 .58525 .73051 .58313 Mtetra
.73051 .58313 .73234 .58525 .73635 .5841 .73453 .58198 Mtetra
.73453 .58198 .73635 .5841 .74036 .58295 .73854 .58083 Mtetra
.73854 .58083 .74036 .58295 .74438 .5818 .74257 .57967 Mtetra
.951 .599 .254 r
.74257 .57967 .74438 .5818 .75006 .6059 .74824 .60379 Mtetra
.654 .754 .923 r
.74824 .60379 .75006 .6059 .75412 .60476 .75231 .60264 Mtetra
.75231 .60264 .75412 .60476 .75819 .60361 .75638 .60149 Mtetra
.75638 .60149 .75819 .60361 .76226 .60247 .76046 .60034 Mtetra
.76046 .60034 .76226 .60247 .76634 .60132 .76454 .59919 Mtetra
.76454 .59919 .76634 .60132 .77043 .60017 .76863 .59804 Mtetra
.76863 .59804 .77043 .60017 .77452 .59902 .77272 .59689 Mtetra
.77272 .59689 .77452 .59902 .77861 .59786 .77682 .59573 Mtetra
.77682 .59573 .77861 .59786 .78272 .59671 .78093 .59457 Mtetra
.78093 .59457 .78272 .59671 .78683 .59555 .78504 .59341 Mtetra
.78504 .59341 .78683 .59555 .79094 .59439 .78916 .59225 Mtetra
.78916 .59225 .79094 .59439 .79506 .59323 .79328 .59109 Mtetra
.79328 .59109 .79506 .59323 .79918 .59207 .79741 .58992 Mtetra
.79741 .58992 .79918 .59207 .80332 .59091 .80155 .58876 Mtetra
.80155 .58876 .80332 .59091 .80745 .58974 .80569 .58759 Mtetra
.80569 .58759 .80745 .58974 .8116 .58858 .80984 .58642 Mtetra
.80984 .58642 .8116 .58858 .81575 .58741 .81399 .58525 Mtetra
.81399 .58525 .81575 .58741 .8199 .58624 .81815 .58407 Mtetra
.925 .547 .149 r
.81815 .58407 .8199 .58624 .82406 .58507 .82412 .60353 Mtetra
.542 .295 .491 r
.82412 .60353 .82406 .58507 .83007 .60451 .82832 .60236 Mtetra
.652 .756 .926 r
.82832 .60236 .83007 .60451 .83427 .60335 .83252 .60119 Mtetra
.83252 .60119 .83427 .60335 .83847 .60218 .83673 .60001 Mtetra
.83673 .60001 .83847 .60218 .84269 .60101 .84095 .59884 Mtetra
.84095 .59884 .84269 .60101 .8469 .59983 .84517 .59767 Mtetra
.84517 .59767 .8469 .59983 .85113 .59866 .8494 .59649 Mtetra
.8494 .59649 .85113 .59866 .85536 .59748 .85364 .59531 Mtetra
.85364 .59531 .85536 .59748 .8596 .59631 .85788 .59413 Mtetra
.85788 .59413 .8596 .59631 .86384 .59513 .86212 .59295 Mtetra
.86212 .59295 .86384 .59513 .86809 .59395 .86638 .59176 Mtetra
.86638 .59176 .86809 .59395 .87234 .59277 .87064 .59058 Mtetra
.87064 .59058 .87234 .59277 .8766 .59158 .8749 .58939 Mtetra
.8749 .58939 .8766 .59158 .88087 .59039 .87918 .5882 Mtetra
.87918 .5882 .88087 .59039 .88515 .58921 .88345 .58701 Mtetra
.88345 .58701 .88515 .58921 .88943 .58802 .88774 .58582 Mtetra
.88774 .58582 .88943 .58802 .89371 .58683 .89203 .58462 Mtetra
.89203 .58462 .89371 .58683 .898 .58563 .89633 .58343 Mtetra
.89633 .58343 .898 .58563 .9023 .58444 .90063 .58223 Mtetra
.90063 .58223 .9023 .58444 .90661 .58324 .90494 .58103 Mtetra
.90494 .58103 .90661 .58324 .91092 .58204 .90926 .57983 Mtetra
.90926 .57983 .91092 .58204 .91524 .58084 .91358 .57862 Mtetra
.91358 .57862 .91524 .58084 .91956 .57964 .91791 .57742 Mtetra
.91791 .57742 .91956 .57964 .92389 .57844 .92224 .57621 Mtetra
.92224 .57621 .92389 .57844 .92823 .57723 .92658 .575 Mtetra
.92658 .575 .92823 .57723 .93257 .57603 .93093 .57379 Mtetra
.93093 .57379 .93257 .57603 .93692 .57482 .93529 .57258 Mtetra
.93529 .57258 .93692 .57482 .94128 .57361 .93965 .57137 Mtetra
.93965 .57137 .94128 .57361 .94564 .5724 .94401 .57015 Mtetra
.94401 .57015 .94564 .5724 .95001 .57118 .94839 .56894 Mtetra
.94839 .56894 .95001 .57118 .95438 .56997 .95277 .56772 Mtetra
.95277 .56772 .95438 .56997 .95877 .56875 .95715 .56649 Mtetra
.95715 .56649 .95877 .56875 .96315 .56753 .96155 .56527 Mtetra
.96155 .56527 .96315 .56753 .96755 .56631 .96595 .56405 Mtetra
.96595 .56405 .96755 .56631 .97195 .56508 .97035 .56282 Mtetra
.97035 .56282 .97195 .56508 .97636 .56386 .97477 .56159 Mtetra
.646 .762 .934 r
.37402 .78628 .37623 .78807 .37987 .7871 .37766 .7853 Mtetra
.37766 .7853 .37987 .7871 .38351 .78613 .38131 .78433 Mtetra
.38131 .78433 .38351 .78613 .38716 .78515 .38496 .78335 Mtetra
.38496 .78335 .38716 .78515 .39081 .78418 .38861 .78237 Mtetra
.38861 .78237 .39081 .78418 .39447 .7832 .39227 .78139 Mtetra
.39227 .78139 .39447 .7832 .39813 .78222 .39594 .78041 Mtetra
.39594 .78041 .39813 .78222 .4018 .78124 .39961 .77943 Mtetra
.39961 .77943 .4018 .78124 .40547 .78026 .40328 .77845 Mtetra
.40328 .77845 .40547 .78026 .40915 .77928 .40696 .77746 Mtetra
.40696 .77746 .40915 .77928 .41283 .7783 .41065 .77648 Mtetra
.41065 .77648 .41283 .7783 .41652 .77731 .41434 .77549 Mtetra
.41434 .77549 .41652 .77731 .42021 .77632 .41803 .7745 Mtetra
.41803 .7745 .42021 .77632 .42391 .77534 .42173 .77351 Mtetra
.42173 .77351 .42391 .77534 .42761 .77435 .42544 .77252 Mtetra
.42544 .77252 .42761 .77435 .43132 .77336 .42915 .77152 Mtetra
.42915 .77152 .43132 .77336 .43503 .77236 .43287 .77053 Mtetra
.43287 .77053 .43503 .77236 .43875 .77137 .43659 .76953 Mtetra
.43659 .76953 .43875 .77137 .44247 .77038 .44031 .76854 Mtetra
.44031 .76854 .44247 .77038 .4462 .76938 .44404 .76754 Mtetra
.44404 .76754 .4462 .76938 .44993 .76838 .44778 .76654 Mtetra
.44778 .76654 .44993 .76838 .45367 .76738 .45152 .76554 Mtetra
.45152 .76554 .45367 .76738 .45741 .76638 .45527 .76453 Mtetra
.943 .696 .533 r
.45527 .76453 .45741 .76638 .46295 .66465 .46087 .66272 Mtetra
.655 .752 .921 r
.46087 .66272 .46295 .66465 .4666 .66361 .46453 .66168 Mtetra
.46453 .66168 .4666 .66361 .47025 .66256 .46818 .66063 Mtetra
.46818 .66063 .47025 .66256 .47391 .66152 .47185 .65958 Mtetra
.47185 .65958 .47391 .66152 .47758 .66047 .47551 .65853 Mtetra
.47551 .65853 .47758 .66047 .48125 .65942 .47918 .65748 Mtetra
.47918 .65748 .48125 .65942 .48492 .65837 .48286 .65643 Mtetra
.48286 .65643 .48492 .65837 .4886 .65732 .48654 .65538 Mtetra
.48654 .65538 .4886 .65732 .49228 .65627 .49023 .65432 Mtetra
.49023 .65432 .49228 .65627 .49597 .65522 .49392 .65327 Mtetra
.49392 .65327 .49597 .65522 .49967 .65416 .49762 .65221 Mtetra
.49762 .65221 .49967 .65416 .50337 .6531 .50132 .65115 Mtetra
.50132 .65115 .50337 .6531 .50707 .65205 .50503 .65009 Mtetra
.50503 .65009 .50707 .65205 .51078 .65099 .50874 .64903 Mtetra
.50874 .64903 .51078 .65099 .51449 .64993 .51246 .64797 Mtetra
.51246 .64797 .51449 .64993 .51821 .64886 .51618 .6469 Mtetra
.51618 .6469 .51821 .64886 .52194 .6478 .51991 .64583 Mtetra
.51991 .64583 .52194 .6478 .52566 .64674 .52364 .64477 Mtetra
.52364 .64477 .52566 .64674 .5294 .64567 .52738 .6437 Mtetra
.52738 .6437 .5294 .64567 .53314 .6446 .53112 .64263 Mtetra
.53112 .64263 .53314 .6446 .53688 .64353 .53487 .64155 Mtetra
.53487 .64155 .53688 .64353 .54063 .64246 .53862 .64048 Mtetra
.53862 .64048 .54063 .64246 .54439 .64139 .54238 .63941 Mtetra
.54238 .63941 .54439 .64139 .54815 .64032 .54614 .63833 Mtetra
.956 .641 .39 r
.54614 .63833 .54815 .64032 .55214 .66913 .55013 .66716 Mtetra
.653 .755 .925 r
.55013 .66716 .55214 .66913 .55595 .66807 .55393 .6661 Mtetra
.55393 .6661 .55595 .66807 .55975 .667 .55774 .66503 Mtetra
.55774 .66503 .55975 .667 .56357 .66593 .56156 .66395 Mtetra
.56156 .66395 .56357 .66593 .56739 .66486 .56538 .66288 Mtetra
.56538 .66288 .56739 .66486 .57121 .66379 .56921 .66181 Mtetra
.56921 .66181 .57121 .66379 .57504 .66272 .57304 .66073 Mtetra
.57304 .66073 .57504 .66272 .57887 .66164 .57688 .65966 Mtetra
.57688 .65966 .57887 .66164 .58271 .66057 .58072 .65858 Mtetra
.58072 .65858 .58271 .66057 .58656 .65949 .58457 .6575 Mtetra
.58457 .6575 .58656 .65949 .59041 .65841 .58843 .65642 Mtetra
.58843 .65642 .59041 .65841 .59426 .65733 .59228 .65533 Mtetra
.59228 .65533 .59426 .65733 .59812 .65625 .59615 .65425 Mtetra
.59615 .65425 .59812 .65625 .60199 .65517 .60002 .65316 Mtetra
.60002 .65316 .60199 .65517 .60586 .65408 .60389 .65207 Mtetra
.60389 .65207 .60586 .65408 .60974 .65299 .60777 .65099 Mtetra
.60777 .65099 .60974 .65299 .61362 .65191 .61166 .64989 Mtetra
.959 .636 .362 r
.61166 .64989 .61362 .65191 .61832 .68143 .61635 .67944 Mtetra
.65 .758 .928 r
.61635 .67944 .61832 .68143 .62225 .68035 .62028 .67836 Mtetra
.62028 .67836 .62225 .68035 .62619 .67927 .62422 .67727 Mtetra
.62422 .67727 .62619 .67927 .63012 .67819 .62816 .67619 Mtetra
.62816 .67619 .63012 .67819 .63407 .67711 .63211 .6751 Mtetra
.63211 .6751 .63407 .67711 .63802 .67602 .63607 .67401 Mtetra
.63607 .67401 .63802 .67602 .64198 .67493 .64003 .67292 Mtetra
.64003 .67292 .64198 .67493 .64594 .67385 .64399 .67183 Mtetra
.64399 .67183 .64594 .67385 .6499 .67276 .64796 .67074 Mtetra
.64796 .67074 .6499 .67276 .65388 .67167 .65194 .66965 Mtetra
.65194 .66965 .65388 .67167 .65785 .67057 .65592 .66855 Mtetra
.65592 .66855 .65785 .67057 .66184 .66948 .65991 .66745 Mtetra
.65991 .66745 .66184 .66948 .66583 .66838 .6639 .66636 Mtetra
.6639 .66636 .66583 .66838 .66982 .66729 .6679 .66526 Mtetra
.6679 .66526 .66982 .66729 .67382 .66619 .6719 .66415 Mtetra
.6719 .66415 .67382 .66619 .67783 .66509 .67591 .66305 Mtetra
.67591 .66305 .67783 .66509 .68184 .66398 .67993 .66195 Mtetra
.67993 .66195 .68184 .66398 .68586 .66288 .68395 .66084 Mtetra
.967 .707 .487 r
.68395 .66084 .68586 .66288 .68675 .59567 .68488 .59357 Mtetra
.656 .751 .92 r
.68488 .59357 .68675 .59567 .6907 .59453 .68884 .59244 Mtetra
.68884 .59244 .6907 .59453 .69466 .5934 .6928 .5913 Mtetra
.6928 .5913 .69466 .5934 .69862 .59227 .69676 .59017 Mtetra
.69676 .59017 .69862 .59227 .70259 .59113 .70073 .58903 Mtetra
.70073 .58903 .70259 .59113 .70656 .58999 .70471 .58789 Mtetra
.70471 .58789 .70656 .58999 .71054 .58885 .70869 .58674 Mtetra
.70869 .58674 .71054 .58885 .71452 .58771 .71268 .5856 Mtetra
.71268 .5856 .71452 .58771 .71851 .58657 .71667 .58445 Mtetra
.71667 .58445 .71851 .58657 .72251 .58542 .72067 .5833 Mtetra
.72067 .5833 .72251 .58542 .72651 .58428 .72467 .58216 Mtetra
.72467 .58216 .72651 .58428 .73051 .58313 .72868 .581 Mtetra
.72868 .581 .73051 .58313 .73453 .58198 .7327 .57985 Mtetra
.7327 .57985 .73453 .58198 .73854 .58083 .73672 .5787 Mtetra
.73672 .5787 .73854 .58083 .74257 .57967 .74075 .57754 Mtetra
.951 .599 .254 r
.74075 .57754 .74257 .57967 .74824 .60379 .74642 .60167 Mtetra
.654 .754 .923 r
.74642 .60167 .74824 .60379 .75231 .60264 .75049 .60052 Mtetra
.75049 .60052 .75231 .60264 .75638 .60149 .75456 .59937 Mtetra
.75456 .59937 .75638 .60149 .76046 .60034 .75864 .59822 Mtetra
.75864 .59822 .76046 .60034 .76454 .59919 .76273 .59706 Mtetra
.76273 .59706 .76454 .59919 .76863 .59804 .76682 .59591 Mtetra
.76682 .59591 .76863 .59804 .77272 .59689 .77092 .59475 Mtetra
.77092 .59475 .77272 .59689 .77682 .59573 .77503 .59359 Mtetra
.77503 .59359 .77682 .59573 .78093 .59457 .77914 .59243 Mtetra
.77914 .59243 .78093 .59457 .78504 .59341 .78325 .59127 Mtetra
.78325 .59127 .78504 .59341 .78916 .59225 .78738 .5901 Mtetra
.78738 .5901 .78916 .59225 .79328 .59109 .79151 .58894 Mtetra
.79151 .58894 .79328 .59109 .79741 .58992 .79564 .58777 Mtetra
.79564 .58777 .79741 .58992 .80155 .58876 .79978 .5866 Mtetra
.79978 .5866 .80155 .58876 .80569 .58759 .80393 .58543 Mtetra
.80393 .58543 .80569 .58759 .80984 .58642 .80808 .58425 Mtetra
.80808 .58425 .80984 .58642 .81399 .58525 .81224 .58308 Mtetra
.81224 .58308 .81399 .58525 .81815 .58407 .8164 .5819 Mtetra
.925 .547 .149 r
.8164 .5819 .81815 .58407 .82412 .60353 .82236 .60137 Mtetra
.652 .756 .926 r
.82236 .60137 .82412 .60353 .82832 .60236 .82656 .6002 Mtetra
.82656 .6002 .82832 .60236 .83252 .60119 .83077 .59902 Mtetra
.83077 .59902 .83252 .60119 .83673 .60001 .83499 .59785 Mtetra
.83499 .59785 .83673 .60001 .84095 .59884 .83921 .59667 Mtetra
.83921 .59667 .84095 .59884 .84517 .59767 .84344 .59549 Mtetra
.84344 .59549 .84517 .59767 .8494 .59649 .84767 .59431 Mtetra
.84767 .59431 .8494 .59649 .85364 .59531 .85191 .59313 Mtetra
.85191 .59313 .85364 .59531 .85788 .59413 .85615 .59195 Mtetra
.85615 .59195 .85788 .59413 .86212 .59295 .86041 .59076 Mtetra
.86041 .59076 .86212 .59295 .86638 .59176 .86466 .58957 Mtetra
.86466 .58957 .86638 .59176 .87064 .59058 .86893 .58838 Mtetra
.86893 .58838 .87064 .59058 .8749 .58939 .8732 .58719 Mtetra
.8732 .58719 .8749 .58939 .87918 .5882 .87748 .586 Mtetra
.87748 .586 .87918 .5882 .88345 .58701 .88176 .58481 Mtetra
.88176 .58481 .88345 .58701 .88774 .58582 .88605 .58361 Mtetra
.88605 .58361 .88774 .58582 .89203 .58462 .89034 .58241 Mtetra
.89034 .58241 .89203 .58462 .89633 .58343 .89464 .58121 Mtetra
.89464 .58121 .89633 .58343 .90063 .58223 .89895 .58001 Mtetra
.89895 .58001 .90063 .58223 .90494 .58103 .90327 .57881 Mtetra
.90327 .57881 .90494 .58103 .90926 .57983 .90759 .57761 Mtetra
.90759 .57761 .90926 .57983 .91358 .57862 .91191 .5764 Mtetra
.91191 .5764 .91358 .57862 .91791 .57742 .91625 .57519 Mtetra
.91625 .57519 .91791 .57742 .92224 .57621 .92059 .57398 Mtetra
.92059 .57398 .92224 .57621 .92658 .575 .92493 .57277 Mtetra
.92493 .57277 .92658 .575 .93093 .57379 .92929 .57156 Mtetra
.92929 .57156 .93093 .57379 .93529 .57258 .93365 .57034 Mtetra
.93365 .57034 .93529 .57258 .93965 .57137 .93801 .56912 Mtetra
.93801 .56912 .93965 .57137 .94401 .57015 .94238 .5679 Mtetra
.94238 .5679 .94401 .57015 .94839 .56894 .94676 .56668 Mtetra
.94676 .56668 .94839 .56894 .95277 .56772 .95115 .56546 Mtetra
.95115 .56546 .95277 .56772 .95715 .56649 .95554 .56424 Mtetra
.95554 .56424 .95715 .56649 .96155 .56527 .95994 .56301 Mtetra
.95994 .56301 .96155 .56527 .96595 .56405 .96434 .56178 Mtetra
.96434 .56178 .96595 .56405 .97035 .56282 .96875 .56055 Mtetra
.96875 .56055 .97035 .56282 .97477 .56159 .97317 .55932 Mtetra
.646 .762 .934 r
.3718 .78448 .37402 .78628 .37766 .7853 .37545 .7835 Mtetra
.37545 .7835 .37766 .7853 .38131 .78433 .37909 .78252 Mtetra
.37909 .78252 .38131 .78433 .38496 .78335 .38275 .78154 Mtetra
.38275 .78154 .38496 .78335 .38861 .78237 .38641 .78056 Mtetra
.38641 .78056 .38861 .78237 .39227 .78139 .39007 .77958 Mtetra
.39007 .77958 .39227 .78139 .39594 .78041 .39374 .7786 Mtetra
.39374 .7786 .39594 .78041 .39961 .77943 .39741 .77761 Mtetra
.39741 .77761 .39961 .77943 .40328 .77845 .40109 .77663 Mtetra
.40109 .77663 .40328 .77845 .40696 .77746 .40477 .77564 Mtetra
.40477 .77564 .40696 .77746 .41065 .77648 .40846 .77465 Mtetra
.40846 .77465 .41065 .77648 .41434 .77549 .41215 .77366 Mtetra
.41215 .77366 .41434 .77549 .41803 .7745 .41585 .77267 Mtetra
.41585 .77267 .41803 .7745 .42173 .77351 .41956 .77168 Mtetra
.41956 .77168 .42173 .77351 .42544 .77252 .42327 .77068 Mtetra
.42327 .77068 .42544 .77252 .42915 .77152 .42698 .76969 Mtetra
.42698 .76969 .42915 .77152 .43287 .77053 .4307 .76869 Mtetra
.4307 .76869 .43287 .77053 .43659 .76953 .43442 .76769 Mtetra
.43442 .76769 .43659 .76953 .44031 .76854 .43815 .76669 Mtetra
.43815 .76669 .44031 .76854 .44404 .76754 .44189 .76569 Mtetra
.44189 .76569 .44404 .76754 .44778 .76654 .44563 .76469 Mtetra
.44563 .76469 .44778 .76654 .45152 .76554 .44937 .76368 Mtetra
.44937 .76368 .45152 .76554 .45527 .76453 .45312 .76268 Mtetra
.943 .696 .533 r
.45312 .76268 .45527 .76453 .46087 .66272 .45879 .66079 Mtetra
.655 .752 .921 r
.45879 .66079 .46087 .66272 .46453 .66168 .46245 .65974 Mtetra
.46245 .65974 .46453 .66168 .46818 .66063 .46611 .6587 Mtetra
.46611 .6587 .46818 .66063 .47185 .65958 .46977 .65765 Mtetra
.46977 .65765 .47185 .65958 .47551 .65853 .47344 .65659 Mtetra
.47344 .65659 .47551 .65853 .47918 .65748 .47712 .65554 Mtetra
.47712 .65554 .47918 .65748 .48286 .65643 .4808 .65449 Mtetra
.4808 .65449 .48286 .65643 .48654 .65538 .48448 .65343 Mtetra
.48448 .65343 .48654 .65538 .49023 .65432 .48817 .65237 Mtetra
.48817 .65237 .49023 .65432 .49392 .65327 .49187 .65131 Mtetra
.49187 .65131 .49392 .65327 .49762 .65221 .49557 .65025 Mtetra
.49557 .65025 .49762 .65221 .50132 .65115 .49928 .64919 Mtetra
.49928 .64919 .50132 .65115 .50503 .65009 .50299 .64813 Mtetra
.50299 .64813 .50503 .65009 .50874 .64903 .5067 .64706 Mtetra
.5067 .64706 .50874 .64903 .51246 .64797 .51042 .646 Mtetra
.51042 .646 .51246 .64797 .51618 .6469 .51415 .64493 Mtetra
.51415 .64493 .51618 .6469 .51991 .64583 .51788 .64386 Mtetra
.51788 .64386 .51991 .64583 .52364 .64477 .52161 .64279 Mtetra
.52161 .64279 .52364 .64477 .52738 .6437 .52535 .64172 Mtetra
.52535 .64172 .52738 .6437 .53112 .64263 .5291 .64065 Mtetra
.5291 .64065 .53112 .64263 .53487 .64155 .53285 .63957 Mtetra
.53285 .63957 .53487 .64155 .53862 .64048 .53661 .6385 Mtetra
.53661 .6385 .53862 .64048 .54238 .63941 .54037 .63742 Mtetra
.956 .641 .392 r
.54037 .63742 .54238 .63941 .54614 .63833 .5443 .66626 Mtetra
.552 .318 .515 r
.5443 .66626 .54614 .63833 .55013 .66716 .54811 .66519 Mtetra
.653 .755 .925 r
.54811 .66519 .55013 .66716 .55393 .6661 .55192 .66412 Mtetra
.55192 .66412 .55393 .6661 .55774 .66503 .55573 .66305 Mtetra
.55573 .66305 .55774 .66503 .56156 .66395 .55955 .66197 Mtetra
.55955 .66197 .56156 .66395 .56538 .66288 .56338 .6609 Mtetra
.56338 .6609 .56538 .66288 .56921 .66181 .56721 .65982 Mtetra
.56721 .65982 .56921 .66181 .57304 .66073 .57104 .65874 Mtetra
.57104 .65874 .57304 .66073 .57688 .65966 .57488 .65766 Mtetra
.57488 .65766 .57688 .65966 .58072 .65858 .57873 .65658 Mtetra
.57873 .65658 .58072 .65858 .58457 .6575 .58258 .6555 Mtetra
.58258 .6555 .58457 .6575 .58843 .65642 .58644 .65441 Mtetra
.58644 .65441 .58843 .65642 .59228 .65533 .5903 .65333 Mtetra
.5903 .65333 .59228 .65533 .59615 .65425 .59417 .65224 Mtetra
.59417 .65224 .59615 .65425 .60002 .65316 .59804 .65115 Mtetra
.59804 .65115 .60002 .65316 .60389 .65207 .60192 .65006 Mtetra
.60192 .65006 .60389 .65207 .60777 .65099 .60581 .64897 Mtetra
.60581 .64897 .60777 .65099 .61166 .64989 .6097 .64788 Mtetra
.6097 .64788 .61166 .64989 .61635 .67944 .61359 .64678 Mtetra
.107 .05 .504 r
.61359 .64678 .61635 .67944 .62028 .67836 .61831 .67635 Mtetra
.65 .758 .928 r
.61831 .67635 .62028 .67836 .62422 .67727 .62225 .67527 Mtetra
.62225 .67527 .62422 .67727 .62816 .67619 .6262 .67418 Mtetra
.6262 .67418 .62816 .67619 .63211 .6751 .63015 .67309 Mtetra
.63015 .67309 .63211 .6751 .63607 .67401 .63411 .672 Mtetra
.63411 .672 .63607 .67401 .64003 .67292 .63807 .67091 Mtetra
.63807 .67091 .64003 .67292 .64399 .67183 .64204 .66982 Mtetra
.64204 .66982 .64399 .67183 .64796 .67074 .64601 .66872 Mtetra
.64601 .66872 .64796 .67074 .65194 .66965 .64999 .66762 Mtetra
.64999 .66762 .65194 .66965 .65592 .66855 .65398 .66652 Mtetra
.65398 .66652 .65592 .66855 .65991 .66745 .65797 .66542 Mtetra
.65797 .66542 .65991 .66745 .6639 .66636 .66197 .66432 Mtetra
.66197 .66432 .6639 .66636 .6679 .66526 .66597 .66322 Mtetra
.66597 .66322 .6679 .66526 .6719 .66415 .66998 .66212 Mtetra
.66998 .66212 .6719 .66415 .67591 .66305 .67399 .66101 Mtetra
.67399 .66101 .67591 .66305 .67993 .66195 .67801 .6599 Mtetra
.967 .707 .488 r
.67801 .6599 .67993 .66195 .68395 .66084 .67905 .59261 Mtetra
.577 .38 .578 r
.67905 .59261 .68395 .66084 .68488 .59357 .683 .59148 Mtetra
.656 .751 .92 r
.683 .59148 .68488 .59357 .68884 .59244 .68696 .59034 Mtetra
.68696 .59034 .68884 .59244 .6928 .5913 .69093 .5892 Mtetra
.69093 .5892 .6928 .5913 .69676 .59017 .6949 .58806 Mtetra
.6949 .58806 .69676 .59017 .70073 .58903 .69887 .58692 Mtetra
.69887 .58692 .70073 .58903 .70471 .58789 .70285 .58577 Mtetra
.70285 .58577 .70471 .58789 .70869 .58674 .70684 .58463 Mtetra
.70684 .58463 .70869 .58674 .71268 .5856 .71083 .58348 Mtetra
.71083 .58348 .71268 .5856 .71667 .58445 .71483 .58233 Mtetra
.71483 .58233 .71667 .58445 .72067 .5833 .71883 .58118 Mtetra
.71883 .58118 .72067 .5833 .72467 .58216 .72284 .58003 Mtetra
.72284 .58003 .72467 .58216 .72868 .581 .72685 .57888 Mtetra
.72685 .57888 .72868 .581 .7327 .57985 .73087 .57772 Mtetra
.73087 .57772 .7327 .57985 .73672 .5787 .7349 .57656 Mtetra
.7349 .57656 .73672 .5787 .74075 .57754 .73893 .57541 Mtetra
.73893 .57541 .74075 .57754 .74642 .60167 .74296 .57424 Mtetra
.179 .117 .545 r
.74296 .57424 .74642 .60167 .75049 .60052 .74866 .59839 Mtetra
.654 .754 .923 r
.74866 .59839 .75049 .60052 .75456 .59937 .75274 .59724 Mtetra
.75274 .59724 .75456 .59937 .75864 .59822 .75683 .59608 Mtetra
.75683 .59608 .75864 .59822 .76273 .59706 .76092 .59493 Mtetra
.76092 .59493 .76273 .59706 .76682 .59591 .76502 .59377 Mtetra
.76502 .59377 .76682 .59591 .77092 .59475 .76912 .59261 Mtetra
.76912 .59261 .77092 .59475 .77503 .59359 .77323 .59144 Mtetra
.77323 .59144 .77503 .59359 .77914 .59243 .77734 .59028 Mtetra
.77734 .59028 .77914 .59243 .78325 .59127 .78146 .58911 Mtetra
.78146 .58911 .78325 .59127 .78738 .5901 .78559 .58795 Mtetra
.78559 .58795 .78738 .5901 .79151 .58894 .78972 .58678 Mtetra
.78972 .58678 .79151 .58894 .79564 .58777 .79386 .58561 Mtetra
.79386 .58561 .79564 .58777 .79978 .5866 .798 .58444 Mtetra
.798 .58444 .79978 .5866 .80393 .58543 .80215 .58326 Mtetra
.80215 .58326 .80393 .58543 .80808 .58425 .80631 .58208 Mtetra
.80631 .58208 .80808 .58425 .81224 .58308 .81047 .58091 Mtetra
.926 .549 .152 r
.81047 .58091 .81224 .58308 .8164 .5819 .8164 .60038 Mtetra
.541 .294 .489 r
.8164 .60038 .8164 .5819 .82236 .60137 .8206 .5992 Mtetra
.652 .756 .926 r
.8206 .5992 .82236 .60137 .82656 .6002 .82481 .59803 Mtetra
.82481 .59803 .82656 .6002 .83077 .59902 .82902 .59685 Mtetra
.82902 .59685 .83077 .59902 .83499 .59785 .83324 .59567 Mtetra
.83324 .59567 .83499 .59785 .83921 .59667 .83746 .59449 Mtetra
.83746 .59449 .83921 .59667 .84344 .59549 .8417 .59331 Mtetra
.8417 .59331 .84344 .59549 .84767 .59431 .84593 .59213 Mtetra
.84593 .59213 .84767 .59431 .85191 .59313 .85018 .59094 Mtetra
.85018 .59094 .85191 .59313 .85615 .59195 .85443 .58976 Mtetra
.85443 .58976 .85615 .59195 .86041 .59076 .85868 .58857 Mtetra
.85868 .58857 .86041 .59076 .86466 .58957 .86295 .58738 Mtetra
.86295 .58738 .86466 .58957 .86893 .58838 .86721 .58618 Mtetra
.86721 .58618 .86893 .58838 .8732 .58719 .87149 .58499 Mtetra
.87149 .58499 .8732 .58719 .87748 .586 .87577 .5838 Mtetra
.87577 .5838 .87748 .586 .88176 .58481 .88006 .5826 Mtetra
.88006 .5826 .88176 .58481 .88605 .58361 .88435 .5814 Mtetra
.88435 .5814 .88605 .58361 .89034 .58241 .88865 .5802 Mtetra
.88865 .5802 .89034 .58241 .89464 .58121 .89296 .579 Mtetra
.89296 .579 .89464 .58121 .89895 .58001 .89727 .57779 Mtetra
.89727 .57779 .89895 .58001 .90327 .57881 .90159 .57658 Mtetra
.90159 .57658 .90327 .57881 .90759 .57761 .90592 .57538 Mtetra
.90592 .57538 .90759 .57761 .91191 .5764 .91025 .57417 Mtetra
.91025 .57417 .91191 .5764 .91625 .57519 .91458 .57296 Mtetra
.91458 .57296 .91625 .57519 .92059 .57398 .91893 .57174 Mtetra
.91893 .57174 .92059 .57398 .92493 .57277 .92328 .57053 Mtetra
.92328 .57053 .92493 .57277 .92929 .57156 .92764 .56931 Mtetra
.92764 .56931 .92929 .57156 .93365 .57034 .932 .56809 Mtetra
.932 .56809 .93365 .57034 .93801 .56912 .93637 .56687 Mtetra
.93637 .56687 .93801 .56912 .94238 .5679 .94075 .56565 Mtetra
.94075 .56565 .94238 .5679 .94676 .56668 .94513 .56442 Mtetra
.94513 .56442 .94676 .56668 .95115 .56546 .94952 .5632 Mtetra
.94952 .5632 .95115 .56546 .95554 .56424 .95392 .56197 Mtetra
.95392 .56197 .95554 .56424 .95994 .56301 .95832 .56074 Mtetra
.95832 .56074 .95994 .56301 .96434 .56178 .96273 .55951 Mtetra
.96273 .55951 .96434 .56178 .96875 .56055 .96715 .55828 Mtetra
.96715 .55828 .96875 .56055 .97317 .55932 .97157 .55704 Mtetra
.646 .762 .934 r
.36958 .78267 .3718 .78448 .37545 .7835 .37322 .78169 Mtetra
.37322 .78169 .37545 .7835 .37909 .78252 .37688 .78071 Mtetra
.37688 .78071 .37909 .78252 .38275 .78154 .38053 .77973 Mtetra
.38053 .77973 .38275 .78154 .38641 .78056 .38419 .77875 Mtetra
.38419 .77875 .38641 .78056 .39007 .77958 .38786 .77776 Mtetra
.38786 .77776 .39007 .77958 .39374 .7786 .39153 .77678 Mtetra
.39153 .77678 .39374 .7786 .39741 .77761 .39521 .77579 Mtetra
.39521 .77579 .39741 .77761 .40109 .77663 .39889 .7748 Mtetra
.39889 .7748 .40109 .77663 .40477 .77564 .40258 .77381 Mtetra
.40258 .77381 .40477 .77564 .40846 .77465 .40627 .77282 Mtetra
.40627 .77282 .40846 .77465 .41215 .77366 .40996 .77183 Mtetra
.40996 .77183 .41215 .77366 .41585 .77267 .41367 .77084 Mtetra
.41367 .77084 .41585 .77267 .41956 .77168 .41737 .76984 Mtetra
.41737 .76984 .41956 .77168 .42327 .77068 .42109 .76884 Mtetra
.42109 .76884 .42327 .77068 .42698 .76969 .4248 .76785 Mtetra
.4248 .76785 .42698 .76969 .4307 .76869 .42853 .76685 Mtetra
.42853 .76685 .4307 .76869 .43442 .76769 .43225 .76584 Mtetra
.43225 .76584 .43442 .76769 .43815 .76669 .43599 .76484 Mtetra
.43599 .76484 .43815 .76669 .44189 .76569 .43972 .76384 Mtetra
.43972 .76384 .44189 .76569 .44563 .76469 .44347 .76283 Mtetra
.44347 .76283 .44563 .76469 .44937 .76368 .44721 .76183 Mtetra
.44721 .76183 .44937 .76368 .45312 .76268 .45097 .76082 Mtetra
.943 .696 .533 r
.45097 .76082 .45312 .76268 .45879 .66079 .4567 .65886 Mtetra
.655 .752 .921 r
.4567 .65886 .45879 .66079 .46245 .65974 .46036 .65781 Mtetra
.46036 .65781 .46245 .65974 .46611 .6587 .46403 .65676 Mtetra
.46403 .65676 .46611 .6587 .46977 .65765 .46769 .6557 Mtetra
.46769 .6557 .46977 .65765 .47344 .65659 .47137 .65465 Mtetra
.47137 .65465 .47344 .65659 .47712 .65554 .47505 .65359 Mtetra
.47505 .65359 .47712 .65554 .4808 .65449 .47873 .65254 Mtetra
.47873 .65254 .4808 .65449 .48448 .65343 .48242 .65148 Mtetra
.48242 .65148 .48448 .65343 .48817 .65237 .48611 .65042 Mtetra
.48611 .65042 .48817 .65237 .49187 .65131 .48981 .64936 Mtetra
.48981 .64936 .49187 .65131 .49557 .65025 .49351 .64829 Mtetra
.49351 .64829 .49557 .65025 .49928 .64919 .49722 .64723 Mtetra
.49722 .64723 .49928 .64919 .50299 .64813 .50094 .64616 Mtetra
.50094 .64616 .50299 .64813 .5067 .64706 .50466 .64509 Mtetra
.50466 .64509 .5067 .64706 .51042 .646 .50838 .64403 Mtetra
.50838 .64403 .51042 .646 .51415 .64493 .51211 .64296 Mtetra
.51211 .64296 .51415 .64493 .51788 .64386 .51584 .64188 Mtetra
.51584 .64188 .51788 .64386 .52161 .64279 .51958 .64081 Mtetra
.51958 .64081 .52161 .64279 .52535 .64172 .52333 .63974 Mtetra
.52333 .63974 .52535 .64172 .5291 .64065 .52707 .63866 Mtetra
.52707 .63866 .5291 .64065 .53285 .63957 .53083 .63758 Mtetra
.53083 .63758 .53285 .63957 .53661 .6385 .53459 .6365 Mtetra
.53459 .6365 .53661 .6385 .54037 .63742 .53835 .63542 Mtetra
.956 .641 .392 r
.53835 .63542 .54037 .63742 .5443 .66626 .54227 .66428 Mtetra
.653 .755 .925 r
.54227 .66428 .5443 .66626 .54811 .66519 .54608 .66321 Mtetra
.54608 .66321 .54811 .66519 .55192 .66412 .54989 .66214 Mtetra
.54989 .66214 .55192 .66412 .55573 .66305 .55371 .66106 Mtetra
.55371 .66106 .55573 .66305 .55955 .66197 .55753 .65999 Mtetra
.55753 .65999 .55955 .66197 .56338 .6609 .56136 .65891 Mtetra
.56136 .65891 .56338 .6609 .56721 .65982 .5652 .65783 Mtetra
.5652 .65783 .56721 .65982 .57104 .65874 .56904 .65675 Mtetra
.56904 .65675 .57104 .65874 .57488 .65766 .57288 .65567 Mtetra
.57288 .65567 .57488 .65766 .57873 .65658 .57673 .65458 Mtetra
.57673 .65458 .57873 .65658 .58258 .6555 .58059 .6535 Mtetra
.58059 .6535 .58258 .6555 .58644 .65441 .58445 .65241 Mtetra
.58445 .65241 .58644 .65441 .5903 .65333 .58831 .65132 Mtetra
.58831 .65132 .5903 .65333 .59417 .65224 .59219 .65023 Mtetra
.59219 .65023 .59417 .65224 .59804 .65115 .59606 .64914 Mtetra
.59606 .64914 .59804 .65115 .60192 .65006 .59994 .64805 Mtetra
.59994 .64805 .60192 .65006 .60581 .64897 .60383 .64695 Mtetra
.60383 .64695 .60581 .64897 .6097 .64788 .60773 .64585 Mtetra
.60773 .64585 .6097 .64788 .61359 .64678 .61162 .64476 Mtetra
.959 .635 .36 r
.61162 .64476 .61359 .64678 .61831 .67635 .61633 .67435 Mtetra
.65 .758 .928 r
.61633 .67435 .61831 .67635 .62225 .67527 .62028 .67326 Mtetra
.62028 .67326 .62225 .67527 .6262 .67418 .62423 .67217 Mtetra
.62423 .67217 .6262 .67418 .63015 .67309 .62818 .67108 Mtetra
.62818 .67108 .63015 .67309 .63411 .672 .63214 .66998 Mtetra
.63214 .66998 .63411 .672 .63807 .67091 .63611 .66889 Mtetra
.63611 .66889 .63807 .67091 .64204 .66982 .64008 .66779 Mtetra
.64008 .66779 .64204 .66982 .64601 .66872 .64406 .66669 Mtetra
.64406 .66669 .64601 .66872 .64999 .66762 .64805 .66559 Mtetra
.64805 .66559 .64999 .66762 .65398 .66652 .65204 .66449 Mtetra
.65204 .66449 .65398 .66652 .65797 .66542 .65603 .66339 Mtetra
.65603 .66339 .65797 .66542 .66197 .66432 .66003 .66229 Mtetra
.66003 .66229 .66197 .66432 .66597 .66322 .66404 .66118 Mtetra
.66404 .66118 .66597 .66322 .66998 .66212 .66805 .66007 Mtetra
.66805 .66007 .66998 .66212 .67399 .66101 .67207 .65896 Mtetra
.67207 .65896 .67399 .66101 .67801 .6599 .67609 .65785 Mtetra
.967 .707 .488 r
.67609 .65785 .67801 .6599 .67905 .59261 .67717 .59052 Mtetra
.656 .751 .92 r
.67717 .59052 .67905 .59261 .683 .59148 .68112 .58938 Mtetra
.68112 .58938 .683 .59148 .68696 .59034 .68509 .58824 Mtetra
.68509 .58824 .68696 .59034 .69093 .5892 .68905 .58709 Mtetra
.68905 .58709 .69093 .5892 .6949 .58806 .69303 .58595 Mtetra
.69303 .58595 .6949 .58806 .69887 .58692 .697 .5848 Mtetra
.697 .5848 .69887 .58692 .70285 .58577 .70099 .58366 Mtetra
.70099 .58366 .70285 .58577 .70684 .58463 .70498 .58251 Mtetra
.70498 .58251 .70684 .58463 .71083 .58348 .70897 .58136 Mtetra
.70897 .58136 .71083 .58348 .71483 .58233 .71298 .58021 Mtetra
.71298 .58021 .71483 .58233 .71883 .58118 .71698 .57905 Mtetra
.71698 .57905 .71883 .58118 .72284 .58003 .72099 .5779 Mtetra
.72099 .5779 .72284 .58003 .72685 .57888 .72501 .57674 Mtetra
.72501 .57674 .72685 .57888 .73087 .57772 .72904 .57558 Mtetra
.72904 .57558 .73087 .57772 .7349 .57656 .73307 .57442 Mtetra
.73307 .57442 .7349 .57656 .73893 .57541 .7371 .57326 Mtetra
.7371 .57326 .73893 .57541 .74296 .57424 .74114 .5721 Mtetra
.951 .598 .251 r
.74114 .5721 .74296 .57424 .74866 .59839 .74683 .59626 Mtetra
.654 .754 .923 r
.74683 .59626 .74866 .59839 .75274 .59724 .75092 .59511 Mtetra
.75092 .59511 .75274 .59724 .75683 .59608 .755 .59395 Mtetra
.755 .59395 .75683 .59608 .76092 .59493 .7591 .59279 Mtetra
.7591 .59279 .76092 .59493 .76502 .59377 .7632 .59162 Mtetra
.7632 .59162 .76502 .59377 .76912 .59261 .76731 .59046 Mtetra
.76731 .59046 .76912 .59261 .77323 .59144 .77142 .58929 Mtetra
.77142 .58929 .77323 .59144 .77734 .59028 .77554 .58813 Mtetra
.77554 .58813 .77734 .59028 .78146 .58911 .77967 .58696 Mtetra
.77967 .58696 .78146 .58911 .78559 .58795 .7838 .58579 Mtetra
.7838 .58579 .78559 .58795 .78972 .58678 .78793 .58462 Mtetra
.78793 .58462 .78972 .58678 .79386 .58561 .79207 .58344 Mtetra
.79207 .58344 .79386 .58561 .798 .58444 .79622 .58227 Mtetra
.79622 .58227 .798 .58444 .80215 .58326 .80038 .58109 Mtetra
.80038 .58109 .80215 .58326 .80631 .58208 .80454 .57991 Mtetra
.80454 .57991 .80631 .58208 .81047 .58091 .8087 .57873 Mtetra
.926 .549 .152 r
.8087 .57873 .81047 .58091 .8164 .60038 .81463 .59821 Mtetra
.652 .756 .926 r
.81463 .59821 .8164 .60038 .8206 .5992 .81883 .59703 Mtetra
.81883 .59703 .8206 .5992 .82481 .59803 .82304 .59585 Mtetra
.82304 .59585 .82481 .59803 .82902 .59685 .82726 .59467 Mtetra
.82726 .59467 .82902 .59685 .83324 .59567 .83148 .59349 Mtetra
.83148 .59349 .83324 .59567 .83746 .59449 .83571 .59231 Mtetra
.83571 .59231 .83746 .59449 .8417 .59331 .83995 .59112 Mtetra
.83995 .59112 .8417 .59331 .84593 .59213 .84419 .58994 Mtetra
.84419 .58994 .84593 .59213 .85018 .59094 .84844 .58875 Mtetra
.84844 .58875 .85018 .59094 .85443 .58976 .8527 .58756 Mtetra
.8527 .58756 .85443 .58976 .85868 .58857 .85696 .58637 Mtetra
.85696 .58637 .85868 .58857 .86295 .58738 .86122 .58517 Mtetra
.86122 .58517 .86295 .58738 .86721 .58618 .8655 .58398 Mtetra
.8655 .58398 .86721 .58618 .87149 .58499 .86978 .58278 Mtetra
.86978 .58278 .87149 .58499 .87577 .5838 .87406 .58158 Mtetra
.87406 .58158 .87577 .5838 .88006 .5826 .87835 .58038 Mtetra
.87835 .58038 .88006 .5826 .88435 .5814 .88265 .57918 Mtetra
.88265 .57918 .88435 .5814 .88865 .5802 .88696 .57798 Mtetra
.88696 .57798 .88865 .5802 .89296 .579 .89127 .57677 Mtetra
.89127 .57677 .89296 .579 .89727 .57779 .89558 .57556 Mtetra
.89558 .57556 .89727 .57779 .90159 .57658 .89991 .57435 Mtetra
.89991 .57435 .90159 .57658 .90592 .57538 .90424 .57314 Mtetra
.90424 .57314 .90592 .57538 .91025 .57417 .90857 .57193 Mtetra
.90857 .57193 .91025 .57417 .91458 .57296 .91292 .57071 Mtetra
.91292 .57071 .91458 .57296 .91893 .57174 .91727 .5695 Mtetra
.91727 .5695 .91893 .57174 .92328 .57053 .92162 .56828 Mtetra
.92162 .56828 .92328 .57053 .92764 .56931 .92598 .56706 Mtetra
.92598 .56706 .92764 .56931 .932 .56809 .93035 .56584 Mtetra
.93035 .56584 .932 .56809 .93637 .56687 .93473 .56461 Mtetra
.93473 .56461 .93637 .56687 .94075 .56565 .93911 .56339 Mtetra
.93911 .56339 .94075 .56565 .94513 .56442 .9435 .56216 Mtetra
.9435 .56216 .94513 .56442 .94952 .5632 .94789 .56093 Mtetra
.94789 .56093 .94952 .5632 .95392 .56197 .95229 .5597 Mtetra
.95229 .5597 .95392 .56197 .95832 .56074 .9567 .55847 Mtetra
.9567 .55847 .95832 .56074 .96273 .55951 .96111 .55723 Mtetra
.96111 .55723 .96273 .55951 .96715 .55828 .96554 .556 Mtetra
.96554 .556 .96715 .55828 .97157 .55704 .96996 .55476 Mtetra
.646 .762 .934 r
.36735 .78087 .36958 .78267 .37322 .78169 .371 .77988 Mtetra
.371 .77988 .37322 .78169 .37688 .78071 .37465 .7789 Mtetra
.37465 .7789 .37688 .78071 .38053 .77973 .37831 .77792 Mtetra
.37831 .77792 .38053 .77973 .38419 .77875 .38198 .77693 Mtetra
.38198 .77693 .38419 .77875 .38786 .77776 .38565 .77594 Mtetra
.38565 .77594 .38786 .77776 .39153 .77678 .38932 .77496 Mtetra
.38932 .77496 .39153 .77678 .39521 .77579 .393 .77397 Mtetra
.393 .77397 .39521 .77579 .39889 .7748 .39669 .77297 Mtetra
.39669 .77297 .39889 .7748 .40258 .77381 .40038 .77198 Mtetra
.40038 .77198 .40258 .77381 .40627 .77282 .40407 .77099 Mtetra
.40407 .77099 .40627 .77282 .40996 .77183 .40777 .76999 Mtetra
.40777 .76999 .40996 .77183 .41367 .77084 .41147 .769 Mtetra
.41147 .769 .41367 .77084 .41737 .76984 .41519 .768 Mtetra
.41519 .768 .41737 .76984 .42109 .76884 .4189 .767 Mtetra
.4189 .767 .42109 .76884 .4248 .76785 .42262 .766 Mtetra
.42262 .766 .4248 .76785 .42853 .76685 .42635 .765 Mtetra
.42635 .765 .42853 .76685 .43225 .76584 .43008 .76399 Mtetra
.43008 .76399 .43225 .76584 .43599 .76484 .43381 .76299 Mtetra
.43381 .76299 .43599 .76484 .43972 .76384 .43755 .76198 Mtetra
.43755 .76198 .43972 .76384 .44347 .76283 .4413 .76098 Mtetra
.4413 .76098 .44347 .76283 .44721 .76183 .44505 .75997 Mtetra
.44505 .75997 .44721 .76183 .45097 .76082 .44881 .75896 Mtetra
.943 .696 .533 r
.44881 .75896 .45097 .76082 .4567 .65886 .45461 .65692 Mtetra
.655 .752 .921 r
.45461 .65692 .4567 .65886 .46036 .65781 .45827 .65586 Mtetra
.45827 .65586 .46036 .65781 .46403 .65676 .46194 .65481 Mtetra
.46194 .65481 .46403 .65676 .46769 .6557 .46561 .65376 Mtetra
.46561 .65376 .46769 .6557 .47137 .65465 .46929 .6527 Mtetra
.46929 .6527 .47137 .65465 .47505 .65359 .47297 .65164 Mtetra
.47297 .65164 .47505 .65359 .47873 .65254 .47666 .65058 Mtetra
.47666 .65058 .47873 .65254 .48242 .65148 .48035 .64952 Mtetra
.48035 .64952 .48242 .65148 .48611 .65042 .48405 .64846 Mtetra
.48405 .64846 .48611 .65042 .48981 .64936 .48775 .64739 Mtetra
.48775 .64739 .48981 .64936 .49351 .64829 .49145 .64633 Mtetra
.49145 .64633 .49351 .64829 .49722 .64723 .49517 .64526 Mtetra
.49517 .64526 .49722 .64723 .50094 .64616 .49888 .64419 Mtetra
.49888 .64419 .50094 .64616 .50466 .64509 .5026 .64312 Mtetra
.5026 .64312 .50466 .64509 .50838 .64403 .50633 .64205 Mtetra
.50633 .64205 .50838 .64403 .51211 .64296 .51006 .64098 Mtetra
.51006 .64098 .51211 .64296 .51584 .64188 .5138 .6399 Mtetra
.5138 .6399 .51584 .64188 .51958 .64081 .51754 .63883 Mtetra
.51754 .63883 .51958 .64081 .52333 .63974 .52129 .63775 Mtetra
.52129 .63775 .52333 .63974 .52707 .63866 .52504 .63667 Mtetra
.52504 .63667 .52707 .63866 .53083 .63758 .5288 .63559 Mtetra
.5288 .63559 .53083 .63758 .53459 .6365 .53256 .63451 Mtetra
.53256 .63451 .53459 .6365 .53835 .63542 .53633 .63343 Mtetra
.956 .641 .392 r
.53633 .63343 .53835 .63542 .54227 .66428 .54024 .6623 Mtetra
.653 .755 .925 r
.54024 .6623 .54227 .66428 .54608 .66321 .54405 .66123 Mtetra
.54405 .66123 .54608 .66321 .54989 .66214 .54786 .66015 Mtetra
.54786 .66015 .54989 .66214 .55371 .66106 .55169 .65907 Mtetra
.55169 .65907 .55371 .66106 .55753 .65999 .55551 .658 Mtetra
.55551 .658 .55753 .65999 .56136 .65891 .55935 .65691 Mtetra
.55935 .65691 .56136 .65891 .5652 .65783 .56318 .65583 Mtetra
.56318 .65583 .5652 .65783 .56904 .65675 .56703 .65475 Mtetra
.56703 .65475 .56904 .65675 .57288 .65567 .57087 .65366 Mtetra
.57087 .65366 .57288 .65567 .57673 .65458 .57473 .65258 Mtetra
.57473 .65258 .57673 .65458 .58059 .6535 .57859 .65149 Mtetra
.57859 .65149 .58059 .6535 .58445 .65241 .58245 .6504 Mtetra
.58245 .6504 .58445 .65241 .58831 .65132 .58632 .64931 Mtetra
.58632 .64931 .58831 .65132 .59219 .65023 .5902 .64821 Mtetra
.5902 .64821 .59219 .65023 .59606 .64914 .59408 .64712 Mtetra
.59408 .64712 .59606 .64914 .59994 .64805 .59796 .64602 Mtetra
.59796 .64602 .59994 .64805 .60383 .64695 .60185 .64493 Mtetra
.60185 .64493 .60383 .64695 .60773 .64585 .60575 .64383 Mtetra
.60575 .64383 .60773 .64585 .61162 .64476 .60965 .64273 Mtetra
.60965 .64273 .61162 .64476 .61633 .67435 .61356 .64162 Mtetra
.105 .049 .503 r
.61356 .64162 .61633 .67435 .62028 .67326 .6183 .67125 Mtetra
.65 .758 .928 r
.6183 .67125 .62028 .67326 .62423 .67217 .62225 .67015 Mtetra
.62225 .67015 .62423 .67217 .62818 .67108 .62621 .66906 Mtetra
.62621 .66906 .62818 .67108 .63214 .66998 .63017 .66796 Mtetra
.63017 .66796 .63214 .66998 .63611 .66889 .63415 .66686 Mtetra
.63415 .66686 .63611 .66889 .64008 .66779 .63812 .66576 Mtetra
.63812 .66576 .64008 .66779 .64406 .66669 .6421 .66466 Mtetra
.6421 .66466 .64406 .66669 .64805 .66559 .64609 .66356 Mtetra
.64609 .66356 .64805 .66559 .65204 .66449 .65009 .66246 Mtetra
.65009 .66246 .65204 .66449 .65603 .66339 .65408 .66135 Mtetra
.65408 .66135 .65603 .66339 .66003 .66229 .65809 .66024 Mtetra
.65809 .66024 .66003 .66229 .66404 .66118 .6621 .65913 Mtetra
.6621 .65913 .66404 .66118 .66805 .66007 .66612 .65802 Mtetra
.66612 .65802 .66805 .66007 .67207 .65896 .67014 .65691 Mtetra
.966 .707 .489 r
.67014 .65691 .67207 .65896 .67609 .65785 .67132 .58955 Mtetra
.577 .379 .577 r
.67132 .58955 .67609 .65785 .67717 .59052 .67528 .58841 Mtetra
.656 .751 .92 r
.67528 .58841 .67717 .59052 .68112 .58938 .67924 .58727 Mtetra
.67924 .58727 .68112 .58938 .68509 .58824 .6832 .58613 Mtetra
.6832 .58613 .68509 .58824 .68905 .58709 .68717 .58498 Mtetra
.68717 .58498 .68905 .58709 .69303 .58595 .69115 .58383 Mtetra
.69115 .58383 .69303 .58595 .697 .5848 .69513 .58269 Mtetra
.69513 .58269 .697 .5848 .70099 .58366 .69912 .58154 Mtetra
.69912 .58154 .70099 .58366 .70498 .58251 .70312 .58038 Mtetra
.70312 .58038 .70498 .58251 .70897 .58136 .70712 .57923 Mtetra
.70712 .57923 .70897 .58136 .71298 .58021 .71112 .57808 Mtetra
.71112 .57808 .71298 .58021 .71698 .57905 .71513 .57692 Mtetra
.71513 .57692 .71698 .57905 .72099 .5779 .71915 .57576 Mtetra
.71915 .57576 .72099 .5779 .72501 .57674 .72317 .5746 Mtetra
.72317 .5746 .72501 .57674 .72904 .57558 .7272 .57344 Mtetra
.7272 .57344 .72904 .57558 .73307 .57442 .73123 .57228 Mtetra
.73123 .57228 .73307 .57442 .7371 .57326 .73527 .57111 Mtetra
.73527 .57111 .7371 .57326 .74114 .5721 .73931 .56995 Mtetra
.951 .598 .251 r
.73931 .56995 .74114 .5721 .74683 .59626 .745 .59412 Mtetra
.654 .754 .923 r
.745 .59412 .74683 .59626 .75092 .59511 .74908 .59296 Mtetra
.74908 .59296 .75092 .59511 .755 .59395 .75318 .5918 Mtetra
.75318 .5918 .755 .59395 .7591 .59279 .75728 .59064 Mtetra
.75728 .59064 .7591 .59279 .7632 .59162 .76138 .58947 Mtetra
.76138 .58947 .7632 .59162 .76731 .59046 .76549 .58831 Mtetra
.76549 .58831 .76731 .59046 .77142 .58929 .76961 .58714 Mtetra
.76961 .58714 .77142 .58929 .77554 .58813 .77373 .58597 Mtetra
.77373 .58597 .77554 .58813 .77967 .58696 .77786 .5848 Mtetra
.77786 .5848 .77967 .58696 .7838 .58579 .782 .58362 Mtetra
.782 .58362 .7838 .58579 .78793 .58462 .78614 .58245 Mtetra
.78614 .58245 .78793 .58462 .79207 .58344 .79029 .58127 Mtetra
.79029 .58127 .79207 .58344 .79622 .58227 .79444 .58009 Mtetra
.79444 .58009 .79622 .58227 .80038 .58109 .7986 .57891 Mtetra
.7986 .57891 .80038 .58109 .80454 .57991 .80276 .57773 Mtetra
.80276 .57773 .80454 .57991 .8087 .57873 .80693 .57654 Mtetra
.926 .549 .152 r
.80693 .57654 .8087 .57873 .81463 .59821 .81285 .59604 Mtetra
.652 .756 .926 r
.81285 .59604 .81463 .59821 .81883 .59703 .81706 .59486 Mtetra
.81706 .59486 .81883 .59703 .82304 .59585 .82128 .59367 Mtetra
.82128 .59367 .82304 .59585 .82726 .59467 .8255 .59249 Mtetra
.8255 .59249 .82726 .59467 .83148 .59349 .82973 .59131 Mtetra
.82973 .59131 .83148 .59349 .83571 .59231 .83396 .59012 Mtetra
.83396 .59012 .83571 .59231 .83995 .59112 .8382 .58893 Mtetra
.8382 .58893 .83995 .59112 .84419 .58994 .84245 .58774 Mtetra
.84245 .58774 .84419 .58994 .84844 .58875 .8467 .58655 Mtetra
.8467 .58655 .84844 .58875 .8527 .58756 .85096 .58536 Mtetra
.85096 .58536 .8527 .58756 .85696 .58637 .85522 .58416 Mtetra
.85522 .58416 .85696 .58637 .86122 .58517 .8595 .58297 Mtetra
.8595 .58297 .86122 .58517 .8655 .58398 .86377 .58177 Mtetra
.86377 .58177 .8655 .58398 .86978 .58278 .86806 .58057 Mtetra
.86806 .58057 .86978 .58278 .87406 .58158 .87235 .57937 Mtetra
.87235 .57937 .87406 .58158 .87835 .58038 .87664 .57816 Mtetra
.87664 .57816 .87835 .58038 .88265 .57918 .88095 .57696 Mtetra
.88095 .57696 .88265 .57918 .88696 .57798 .88526 .57575 Mtetra
.88526 .57575 .88696 .57798 .89127 .57677 .88957 .57454 Mtetra
.88957 .57454 .89127 .57677 .89558 .57556 .89389 .57333 Mtetra
.89389 .57333 .89558 .57556 .89991 .57435 .89822 .57212 Mtetra
.89822 .57212 .89991 .57435 .90424 .57314 .90256 .5709 Mtetra
.90256 .5709 .90424 .57314 .90857 .57193 .9069 .56968 Mtetra
.9069 .56968 .90857 .57193 .91292 .57071 .91124 .56847 Mtetra
.91124 .56847 .91292 .57071 .91727 .5695 .9156 .56725 Mtetra
.9156 .56725 .91727 .5695 .92162 .56828 .91996 .56602 Mtetra
.91996 .56602 .92162 .56828 .92598 .56706 .92433 .5648 Mtetra
.92433 .5648 .92598 .56706 .93035 .56584 .9287 .56358 Mtetra
.9287 .56358 .93035 .56584 .93473 .56461 .93308 .56235 Mtetra
.93308 .56235 .93473 .56461 .93911 .56339 .93747 .56112 Mtetra
.93747 .56112 .93911 .56339 .9435 .56216 .94186 .55989 Mtetra
.94186 .55989 .9435 .56216 .94789 .56093 .94626 .55866 Mtetra
.94626 .55866 .94789 .56093 .95229 .5597 .95066 .55742 Mtetra
.95066 .55742 .95229 .5597 .9567 .55847 .95508 .55619 Mtetra
.95508 .55619 .9567 .55847 .96111 .55723 .95949 .55495 Mtetra
.95949 .55495 .96111 .55723 .96554 .556 .96392 .55371 Mtetra
.96392 .55371 .96554 .556 .96996 .55476 .96835 .55247 Mtetra
.646 .762 .934 r
.36511 .77905 .36735 .78087 .371 .77988 .36877 .77807 Mtetra
.36877 .77807 .371 .77988 .37465 .7789 .37242 .77708 Mtetra
.37242 .77708 .37465 .7789 .37831 .77792 .37609 .7761 Mtetra
.37609 .7761 .37831 .77792 .38198 .77693 .37975 .77511 Mtetra
.37975 .77511 .38198 .77693 .38565 .77594 .38343 .77412 Mtetra
.38343 .77412 .38565 .77594 .38932 .77496 .3871 .77313 Mtetra
.3871 .77313 .38932 .77496 .393 .77397 .39079 .77214 Mtetra
.39079 .77214 .393 .77397 .39669 .77297 .39448 .77114 Mtetra
.39448 .77114 .39669 .77297 .40038 .77198 .39817 .77015 Mtetra
.39817 .77015 .40038 .77198 .40407 .77099 .40187 .76915 Mtetra
.40187 .76915 .40407 .77099 .40777 .76999 .40557 .76815 Mtetra
.40557 .76815 .40777 .76999 .41147 .769 .40928 .76715 Mtetra
.40928 .76715 .41147 .769 .41519 .768 .41299 .76615 Mtetra
.41299 .76615 .41519 .768 .4189 .767 .41671 .76515 Mtetra
.41671 .76515 .4189 .767 .42262 .766 .42043 .76415 Mtetra
.42043 .76415 .42262 .766 .42635 .765 .42416 .76314 Mtetra
.42416 .76314 .42635 .765 .43008 .76399 .4279 .76214 Mtetra
.4279 .76214 .43008 .76399 .43381 .76299 .43163 .76113 Mtetra
.43163 .76113 .43381 .76299 .43755 .76198 .43538 .76012 Mtetra
.43538 .76012 .43755 .76198 .4413 .76098 .43913 .75911 Mtetra
.43913 .75911 .4413 .76098 .44505 .75997 .44288 .7581 Mtetra
.44288 .7581 .44505 .75997 .44881 .75896 .44664 .75709 Mtetra
.943 .696 .533 r
.44664 .75709 .44881 .75896 .45461 .65692 .45251 .65497 Mtetra
.655 .752 .921 r
.45251 .65497 .45461 .65692 .45827 .65586 .45618 .65392 Mtetra
.45618 .65392 .45827 .65586 .46194 .65481 .45985 .65286 Mtetra
.45985 .65286 .46194 .65481 .46561 .65376 .46352 .6518 Mtetra
.46352 .6518 .46561 .65376 .46929 .6527 .4672 .65074 Mtetra
.4672 .65074 .46929 .6527 .47297 .65164 .47089 .64968 Mtetra
.47089 .64968 .47297 .65164 .47666 .65058 .47458 .64862 Mtetra
.47458 .64862 .47666 .65058 .48035 .64952 .47827 .64756 Mtetra
.47827 .64756 .48035 .64952 .48405 .64846 .48197 .64649 Mtetra
.48197 .64649 .48405 .64846 .48775 .64739 .48568 .64542 Mtetra
.48568 .64542 .48775 .64739 .49145 .64633 .48939 .64436 Mtetra
.48939 .64436 .49145 .64633 .49517 .64526 .4931 .64329 Mtetra
.4931 .64329 .49517 .64526 .49888 .64419 .49682 .64221 Mtetra
.49682 .64221 .49888 .64419 .5026 .64312 .50055 .64114 Mtetra
.50055 .64114 .5026 .64312 .50633 .64205 .50428 .64007 Mtetra
.50428 .64007 .50633 .64205 .51006 .64098 .50801 .63899 Mtetra
.50801 .63899 .51006 .64098 .5138 .6399 .51175 .63792 Mtetra
.51175 .63792 .5138 .6399 .51754 .63883 .5155 .63684 Mtetra
.5155 .63684 .51754 .63883 .52129 .63775 .51925 .63576 Mtetra
.51925 .63576 .52129 .63775 .52504 .63667 .52301 .63468 Mtetra
.52301 .63468 .52504 .63667 .5288 .63559 .52677 .63359 Mtetra
.52677 .63359 .5288 .63559 .53256 .63451 .53053 .63251 Mtetra
.956 .642 .394 r
.53053 .63251 .53256 .63451 .53633 .63343 .53439 .66139 Mtetra
.551 .316 .513 r
.53439 .66139 .53633 .63343 .54024 .6623 .5382 .66032 Mtetra
.653 .755 .925 r
.5382 .66032 .54024 .6623 .54405 .66123 .54201 .65924 Mtetra
.54201 .65924 .54405 .66123 .54786 .66015 .54583 .65816 Mtetra
.54583 .65816 .54786 .66015 .55169 .65907 .54966 .65708 Mtetra
.54966 .65708 .55169 .65907 .55551 .658 .55349 .656 Mtetra
.55349 .656 .55551 .658 .55935 .65691 .55732 .65492 Mtetra
.55732 .65492 .55935 .65691 .56318 .65583 .56116 .65383 Mtetra
.56116 .65383 .56318 .65583 .56703 .65475 .56501 .65274 Mtetra
.56501 .65274 .56703 .65475 .57087 .65366 .56886 .65166 Mtetra
.56886 .65166 .57087 .65366 .57473 .65258 .57272 .65057 Mtetra
.57272 .65057 .57473 .65258 .57859 .65149 .57658 .64947 Mtetra
.57658 .64947 .57859 .65149 .58245 .6504 .58045 .64838 Mtetra
.58045 .64838 .58245 .6504 .58632 .64931 .58432 .64729 Mtetra
.58432 .64729 .58632 .64931 .5902 .64821 .5882 .64619 Mtetra
.5882 .64619 .5902 .64821 .59408 .64712 .59209 .64509 Mtetra
.59209 .64509 .59408 .64712 .59796 .64602 .59598 .644 Mtetra
.59598 .644 .59796 .64602 .60185 .64493 .59987 .6429 Mtetra
.59987 .6429 .60185 .64493 .60575 .64383 .60377 .64179 Mtetra
.60377 .64179 .60575 .64383 .60965 .64273 .60768 .64069 Mtetra
.60768 .64069 .60965 .64273 .61356 .64162 .61159 .63959 Mtetra
.61159 .63959 .61356 .64162 .6183 .67125 .61551 .63848 Mtetra
.105 .049 .503 r
.61551 .63848 .6183 .67125 .62225 .67015 .62027 .66813 Mtetra
.65 .758 .928 r
.62027 .66813 .62225 .67015 .62621 .66906 .62423 .66703 Mtetra
.62423 .66703 .62621 .66906 .63017 .66796 .6282 .66593 Mtetra
.6282 .66593 .63017 .66796 .63415 .66686 .63218 .66483 Mtetra
.63218 .66483 .63415 .66686 .63812 .66576 .63616 .66373 Mtetra
.63616 .66373 .63812 .66576 .6421 .66466 .64014 .66263 Mtetra
.64014 .66263 .6421 .66466 .64609 .66356 .64413 .66152 Mtetra
.64413 .66152 .64609 .66356 .65009 .66246 .64813 .66041 Mtetra
.64813 .66041 .65009 .66246 .65408 .66135 .65213 .6593 Mtetra
.65213 .6593 .65408 .66135 .65809 .66024 .65614 .65819 Mtetra
.65614 .65819 .65809 .66024 .6621 .65913 .66016 .65708 Mtetra
.66016 .65708 .6621 .65913 .66612 .65802 .66418 .65597 Mtetra
.66418 .65597 .66612 .65802 .67014 .65691 .6682 .65485 Mtetra
.966 .707 .489 r
.6682 .65485 .67014 .65691 .67132 .58955 .66942 .58745 Mtetra
.656 .751 .92 r
.66942 .58745 .67132 .58955 .67528 .58841 .67338 .5863 Mtetra
.67338 .5863 .67528 .58841 .67924 .58727 .67735 .58516 Mtetra
.67735 .58516 .67924 .58727 .6832 .58613 .68132 .58401 Mtetra
.68132 .58401 .6832 .58613 .68717 .58498 .68529 .58286 Mtetra
.68529 .58286 .68717 .58498 .69115 .58383 .68927 .58171 Mtetra
.68927 .58171 .69115 .58383 .69513 .58269 .69326 .58056 Mtetra
.69326 .58056 .69513 .58269 .69912 .58154 .69725 .57941 Mtetra
.69725 .57941 .69912 .58154 .70312 .58038 .70125 .57825 Mtetra
.70125 .57825 .70312 .58038 .70712 .57923 .70525 .5771 Mtetra
.70525 .5771 .70712 .57923 .71112 .57808 .70926 .57594 Mtetra
.70926 .57594 .71112 .57808 .71513 .57692 .71327 .57478 Mtetra
.71327 .57478 .71513 .57692 .71915 .57576 .7173 .57362 Mtetra
.7173 .57362 .71915 .57576 .72317 .5746 .72132 .57246 Mtetra
.72132 .57246 .72317 .5746 .7272 .57344 .72535 .57129 Mtetra
.72535 .57129 .7272 .57344 .73123 .57228 .72939 .57013 Mtetra
.72939 .57013 .73123 .57228 .73527 .57111 .73343 .56896 Mtetra
.73343 .56896 .73527 .57111 .73931 .56995 .73748 .56779 Mtetra
.73748 .56779 .73931 .56995 .745 .59412 .74154 .56662 Mtetra
.176 .115 .544 r
.74154 .56662 .745 .59412 .74908 .59296 .74725 .59082 Mtetra
.654 .754 .923 r
.74725 .59082 .74908 .59296 .75318 .5918 .75135 .58965 Mtetra
.75135 .58965 .75318 .5918 .75728 .59064 .75545 .58849 Mtetra
.75545 .58849 .75728 .59064 .76138 .58947 .75956 .58732 Mtetra
.75956 .58732 .76138 .58947 .76549 .58831 .76368 .58615 Mtetra
.76368 .58615 .76549 .58831 .76961 .58714 .7678 .58498 Mtetra
.7678 .58498 .76961 .58714 .77373 .58597 .77192 .5838 Mtetra
.77192 .5838 .77373 .58597 .77786 .5848 .77606 .58263 Mtetra
.77606 .58263 .77786 .5848 .782 .58362 .7802 .58145 Mtetra
.7802 .58145 .782 .58362 .78614 .58245 .78434 .58027 Mtetra
.78434 .58027 .78614 .58245 .79029 .58127 .78849 .57909 Mtetra
.78849 .57909 .79029 .58127 .79444 .58009 .79265 .57791 Mtetra
.79265 .57791 .79444 .58009 .7986 .57891 .79681 .57673 Mtetra
.79681 .57673 .7986 .57891 .80276 .57773 .80098 .57554 Mtetra
.927 .55 .156 r
.80098 .57554 .80276 .57773 .80693 .57654 .80686 .59504 Mtetra
.54 .291 .487 r
.80686 .59504 .80693 .57654 .81285 .59604 .81107 .59386 Mtetra
.652 .756 .926 r
.81107 .59386 .81285 .59604 .81706 .59486 .81528 .59267 Mtetra
.81528 .59267 .81706 .59486 .82128 .59367 .8195 .59149 Mtetra
.8195 .59149 .82128 .59367 .8255 .59249 .82373 .5903 Mtetra
.82373 .5903 .8255 .59249 .82973 .59131 .82796 .58912 Mtetra
.82796 .58912 .82973 .59131 .83396 .59012 .8322 .58793 Mtetra
.8322 .58793 .83396 .59012 .8382 .58893 .83645 .58673 Mtetra
.83645 .58673 .8382 .58893 .84245 .58774 .8407 .58554 Mtetra
.8407 .58554 .84245 .58774 .8467 .58655 .84495 .58435 Mtetra
.84495 .58435 .8467 .58655 .85096 .58536 .84922 .58315 Mtetra
.84922 .58315 .85096 .58536 .85522 .58416 .85349 .58195 Mtetra
.85349 .58195 .85522 .58416 .8595 .58297 .85776 .58075 Mtetra
.85776 .58075 .8595 .58297 .86377 .58177 .86204 .57955 Mtetra
.86204 .57955 .86377 .58177 .86806 .58057 .86633 .57835 Mtetra
.86633 .57835 .86806 .58057 .87235 .57937 .87063 .57714 Mtetra
.87063 .57714 .87235 .57937 .87664 .57816 .87493 .57593 Mtetra
.87493 .57593 .87664 .57816 .88095 .57696 .87924 .57473 Mtetra
.87924 .57473 .88095 .57696 .88526 .57575 .88355 .57351 Mtetra
.88355 .57351 .88526 .57575 .88957 .57454 .88787 .5723 Mtetra
.88787 .5723 .88957 .57454 .89389 .57333 .8922 .57109 Mtetra
.8922 .57109 .89389 .57333 .89822 .57212 .89653 .56987 Mtetra
.89653 .56987 .89822 .57212 .90256 .5709 .90087 .56865 Mtetra
.90087 .56865 .90256 .5709 .9069 .56968 .90522 .56743 Mtetra
.90522 .56743 .9069 .56968 .91124 .56847 .90957 .56621 Mtetra
.90957 .56621 .91124 .56847 .9156 .56725 .91393 .56499 Mtetra
.91393 .56499 .9156 .56725 .91996 .56602 .91829 .56376 Mtetra
.91829 .56376 .91996 .56602 .92433 .5648 .92266 .56254 Mtetra
.92266 .56254 .92433 .5648 .9287 .56358 .92704 .56131 Mtetra
.92704 .56131 .9287 .56358 .93308 .56235 .93143 .56008 Mtetra
.93143 .56008 .93308 .56235 .93747 .56112 .93582 .55885 Mtetra
.93582 .55885 .93747 .56112 .94186 .55989 .94021 .55761 Mtetra
.94021 .55761 .94186 .55989 .94626 .55866 .94462 .55638 Mtetra
.94462 .55638 .94626 .55866 .95066 .55742 .94903 .55514 Mtetra
.94903 .55514 .95066 .55742 .95508 .55619 .95345 .5539 Mtetra
.95345 .5539 .95508 .55619 .95949 .55495 .95787 .55266 Mtetra
.95787 .55266 .95949 .55495 .96392 .55371 .9623 .55141 Mtetra
.9623 .55141 .96392 .55371 .96835 .55247 .96674 .55017 Mtetra
.646 .762 .934 r
.36287 .77723 .36511 .77905 .36877 .77807 .36653 .77625 Mtetra
.36653 .77625 .36877 .77807 .37242 .77708 .37019 .77526 Mtetra
.37019 .77526 .37242 .77708 .37609 .7761 .37385 .77427 Mtetra
.37385 .77427 .37609 .7761 .37975 .77511 .37753 .77328 Mtetra
.37753 .77328 .37975 .77511 .38343 .77412 .3812 .77229 Mtetra
.3812 .77229 .38343 .77412 .3871 .77313 .38488 .77129 Mtetra
.38488 .77129 .3871 .77313 .39079 .77214 .38857 .7703 Mtetra
.38857 .7703 .39079 .77214 .39448 .77114 .39226 .7693 Mtetra
.39226 .7693 .39448 .77114 .39817 .77015 .39596 .76831 Mtetra
.39596 .76831 .39817 .77015 .40187 .76915 .39966 .76731 Mtetra
.39966 .76731 .40187 .76915 .40557 .76815 .40336 .76631 Mtetra
.40336 .76631 .40557 .76815 .40928 .76715 .40707 .76531 Mtetra
.40707 .76531 .40928 .76715 .41299 .76615 .41079 .7643 Mtetra
.41079 .7643 .41299 .76615 .41671 .76515 .41451 .7633 Mtetra
.41451 .7633 .41671 .76515 .42043 .76415 .41824 .76229 Mtetra
.41824 .76229 .42043 .76415 .42416 .76314 .42197 .76129 Mtetra
.42197 .76129 .42416 .76314 .4279 .76214 .42571 .76028 Mtetra
.42571 .76028 .4279 .76214 .43163 .76113 .42945 .75927 Mtetra
.42945 .75927 .43163 .76113 .43538 .76012 .4332 .75826 Mtetra
.4332 .75826 .43538 .76012 .43913 .75911 .43695 .75724 Mtetra
.43695 .75724 .43913 .75911 .44288 .7581 .44071 .75623 Mtetra
.44071 .75623 .44288 .7581 .44664 .75709 .44447 .75521 Mtetra
.943 .696 .533 r
.44447 .75521 .44664 .75709 .45251 .65497 .45041 .65302 Mtetra
.655 .752 .921 r
.45041 .65302 .45251 .65497 .45618 .65392 .45408 .65197 Mtetra
.45408 .65197 .45618 .65392 .45985 .65286 .45775 .65091 Mtetra
.45775 .65091 .45985 .65286 .46352 .6518 .46143 .64985 Mtetra
.46143 .64985 .46352 .6518 .4672 .65074 .46511 .64878 Mtetra
.46511 .64878 .4672 .65074 .47089 .64968 .4688 .64772 Mtetra
.4688 .64772 .47089 .64968 .47458 .64862 .47249 .64665 Mtetra
.47249 .64665 .47458 .64862 .47827 .64756 .47619 .64559 Mtetra
.47619 .64559 .47827 .64756 .48197 .64649 .47989 .64452 Mtetra
.47989 .64452 .48197 .64649 .48568 .64542 .4836 .64345 Mtetra
.4836 .64345 .48568 .64542 .48939 .64436 .48732 .64238 Mtetra
.48732 .64238 .48939 .64436 .4931 .64329 .49104 .64131 Mtetra
.49104 .64131 .4931 .64329 .49682 .64221 .49476 .64023 Mtetra
.49476 .64023 .49682 .64221 .50055 .64114 .49849 .63916 Mtetra
.49849 .63916 .50055 .64114 .50428 .64007 .50222 .63808 Mtetra
.50222 .63808 .50428 .64007 .50801 .63899 .50596 .637 Mtetra
.50596 .637 .50801 .63899 .51175 .63792 .5097 .63592 Mtetra
.5097 .63592 .51175 .63792 .5155 .63684 .51345 .63484 Mtetra
.51345 .63484 .5155 .63684 .51925 .63576 .51721 .63376 Mtetra
.51721 .63376 .51925 .63576 .52301 .63468 .52097 .63267 Mtetra
.52097 .63267 .52301 .63468 .52677 .63359 .52473 .63159 Mtetra
.52473 .63159 .52677 .63359 .53053 .63251 .5285 .6305 Mtetra
.956 .642 .394 r
.5285 .6305 .53053 .63251 .53439 .66139 .53234 .65941 Mtetra
.653 .755 .925 r
.53234 .65941 .53439 .66139 .5382 .66032 .53615 .65833 Mtetra
.53615 .65833 .5382 .66032 .54201 .65924 .53997 .65725 Mtetra
.53997 .65725 .54201 .65924 .54583 .65816 .54379 .65617 Mtetra
.54379 .65617 .54583 .65816 .54966 .65708 .54762 .65508 Mtetra
.54762 .65508 .54966 .65708 .55349 .656 .55146 .654 Mtetra
.55146 .654 .55349 .656 .55732 .65492 .55529 .65291 Mtetra
.55529 .65291 .55732 .65492 .56116 .65383 .55914 .65182 Mtetra
.55914 .65182 .56116 .65383 .56501 .65274 .56299 .65073 Mtetra
.56299 .65073 .56501 .65274 .56886 .65166 .56684 .64964 Mtetra
.56684 .64964 .56886 .65166 .57272 .65057 .57071 .64855 Mtetra
.57071 .64855 .57272 .65057 .57658 .64947 .57457 .64746 Mtetra
.57457 .64746 .57658 .64947 .58045 .64838 .57844 .64636 Mtetra
.57844 .64636 .58045 .64838 .58432 .64729 .58232 .64526 Mtetra
.58232 .64526 .58432 .64729 .5882 .64619 .5862 .64417 Mtetra
.5862 .64417 .5882 .64619 .59209 .64509 .59009 .64307 Mtetra
.59009 .64307 .59209 .64509 .59598 .644 .59398 .64196 Mtetra
.59398 .64196 .59598 .644 .59987 .6429 .59788 .64086 Mtetra
.59788 .64086 .59987 .6429 .60377 .64179 .60179 .63976 Mtetra
.60179 .63976 .60377 .64179 .60768 .64069 .6057 .63865 Mtetra
.6057 .63865 .60768 .64069 .61159 .63959 .60961 .63754 Mtetra
.60961 .63754 .61159 .63959 .61551 .63848 .61353 .63643 Mtetra
.959 .634 .356 r
.61353 .63643 .61551 .63848 .62027 .66813 .61828 .6661 Mtetra
.65 .758 .928 r
.61828 .6661 .62027 .66813 .62423 .66703 .62225 .665 Mtetra
.62225 .665 .62423 .66703 .6282 .66593 .62622 .6639 Mtetra
.62622 .6639 .6282 .66593 .63218 .66483 .6302 .6628 Mtetra
.6302 .6628 .63218 .66483 .63616 .66373 .63418 .66169 Mtetra
.63418 .66169 .63616 .66373 .64014 .66263 .63817 .66058 Mtetra
.63817 .66058 .64014 .66263 .64413 .66152 .64217 .65948 Mtetra
.64217 .65948 .64413 .66152 .64813 .66041 .64617 .65837 Mtetra
.64617 .65837 .64813 .66041 .65213 .6593 .65018 .65725 Mtetra
.65018 .65725 .65213 .6593 .65614 .65819 .65419 .65614 Mtetra
.65419 .65614 .65614 .65819 .66016 .65708 .65821 .65503 Mtetra
.65821 .65503 .66016 .65708 .66418 .65597 .66223 .65391 Mtetra
.66223 .65391 .66418 .65597 .6682 .65485 .66626 .65279 Mtetra
.966 .707 .489 r
.66626 .65279 .6682 .65485 .66942 .58745 .66752 .58533 Mtetra
.656 .751 .92 r
.66752 .58533 .66942 .58745 .67338 .5863 .67148 .58419 Mtetra
.67148 .58419 .67338 .5863 .67735 .58516 .67545 .58304 Mtetra
.67545 .58304 .67735 .58516 .68132 .58401 .67942 .58189 Mtetra
.67942 .58189 .68132 .58401 .68529 .58286 .6834 .58074 Mtetra
.6834 .58074 .68529 .58286 .68927 .58171 .68739 .57959 Mtetra
.68739 .57959 .68927 .58171 .69326 .58056 .69138 .57843 Mtetra
.69138 .57843 .69326 .58056 .69725 .57941 .69537 .57728 Mtetra
.69537 .57728 .69725 .57941 .70125 .57825 .69938 .57612 Mtetra
.69938 .57612 .70125 .57825 .70525 .5771 .70338 .57496 Mtetra
.70338 .57496 .70525 .5771 .70926 .57594 .7074 .5738 Mtetra
.7074 .5738 .70926 .57594 .71327 .57478 .71141 .57264 Mtetra
.71141 .57264 .71327 .57478 .7173 .57362 .71544 .57147 Mtetra
.71544 .57147 .7173 .57362 .72132 .57246 .71947 .57031 Mtetra
.71947 .57031 .72132 .57246 .72535 .57129 .7235 .56914 Mtetra
.7235 .56914 .72535 .57129 .72939 .57013 .72754 .56797 Mtetra
.72754 .56797 .72939 .57013 .73343 .56896 .73159 .5668 Mtetra
.73159 .5668 .73343 .56896 .73748 .56779 .73564 .56563 Mtetra
.73564 .56563 .73748 .56779 .74154 .56662 .7397 .56445 Mtetra
.95 .597 .248 r
.7397 .56445 .74154 .56662 .74725 .59082 .74541 .58867 Mtetra
.654 .754 .923 r
.74541 .58867 .74725 .59082 .75135 .58965 .74951 .5875 Mtetra
.74951 .5875 .75135 .58965 .75545 .58849 .75362 .58633 Mtetra
.75362 .58633 .75545 .58849 .75956 .58732 .75773 .58516 Mtetra
.75773 .58516 .75956 .58732 .76368 .58615 .76185 .58398 Mtetra
.76185 .58398 .76368 .58615 .7678 .58498 .76598 .58281 Mtetra
.76598 .58281 .7678 .58498 .77192 .5838 .77011 .58163 Mtetra
.77011 .58163 .77192 .5838 .77606 .58263 .77425 .58045 Mtetra
.77425 .58045 .77606 .58263 .7802 .58145 .77839 .57927 Mtetra
.77839 .57927 .7802 .58145 .78434 .58027 .78254 .57809 Mtetra
.78254 .57809 .78434 .58027 .78849 .57909 .78669 .57691 Mtetra
.78669 .57691 .78849 .57909 .79265 .57791 .79085 .57572 Mtetra
.79085 .57572 .79265 .57791 .79681 .57673 .79502 .57454 Mtetra
.79502 .57454 .79681 .57673 .80098 .57554 .79919 .57335 Mtetra
.927 .55 .156 r
.79919 .57335 .80098 .57554 .80686 .59504 .80507 .59286 Mtetra
.652 .756 .926 r
.80507 .59286 .80686 .59504 .81107 .59386 .80928 .59167 Mtetra
.80928 .59167 .81107 .59386 .81528 .59267 .8135 .59049 Mtetra
.8135 .59049 .81528 .59267 .8195 .59149 .81773 .5893 Mtetra
.81773 .5893 .8195 .59149 .82373 .5903 .82196 .58811 Mtetra
.82196 .58811 .82373 .5903 .82796 .58912 .82619 .58692 Mtetra
.82619 .58692 .82796 .58912 .8322 .58793 .83044 .58573 Mtetra
.83044 .58573 .8322 .58793 .83645 .58673 .83469 .58453 Mtetra
.83469 .58453 .83645 .58673 .8407 .58554 .83894 .58333 Mtetra
.83894 .58333 .8407 .58554 .84495 .58435 .8432 .58214 Mtetra
.8432 .58214 .84495 .58435 .84922 .58315 .84747 .58094 Mtetra
.84747 .58094 .84922 .58315 .85349 .58195 .85175 .57974 Mtetra
.85175 .57974 .85349 .58195 .85776 .58075 .85603 .57853 Mtetra
.85603 .57853 .85776 .58075 .86204 .57955 .86031 .57733 Mtetra
.86031 .57733 .86204 .57955 .86633 .57835 .86461 .57612 Mtetra
.86461 .57612 .86633 .57835 .87063 .57714 .8689 .57491 Mtetra
.8689 .57491 .87063 .57714 .87493 .57593 .87321 .5737 Mtetra
.87321 .5737 .87493 .57593 .87924 .57473 .87752 .57249 Mtetra
.87752 .57249 .87924 .57473 .88355 .57351 .88184 .57127 Mtetra
.88184 .57127 .88355 .57351 .88787 .5723 .88617 .57006 Mtetra
.88617 .57006 .88787 .5723 .8922 .57109 .8905 .56884 Mtetra
.8905 .56884 .8922 .57109 .89653 .56987 .89483 .56762 Mtetra
.89483 .56762 .89653 .56987 .90087 .56865 .89918 .5664 Mtetra
.89918 .5664 .90087 .56865 .90522 .56743 .90353 .56518 Mtetra
.90353 .56518 .90522 .56743 .90957 .56621 .90789 .56395 Mtetra
.90789 .56395 .90957 .56621 .91393 .56499 .91225 .56273 Mtetra
.91225 .56273 .91393 .56499 .91829 .56376 .91662 .5615 Mtetra
.91662 .5615 .91829 .56376 .92266 .56254 .921 .56027 Mtetra
.921 .56027 .92266 .56254 .92704 .56131 .92538 .55904 Mtetra
.92538 .55904 .92704 .56131 .93143 .56008 .92977 .5578 Mtetra
.92977 .5578 .93143 .56008 .93582 .55885 .93416 .55657 Mtetra
.93416 .55657 .93582 .55885 .94021 .55761 .93857 .55533 Mtetra
.93857 .55533 .94021 .55761 .94462 .55638 .94298 .55409 Mtetra
.94298 .55409 .94462 .55638 .94903 .55514 .94739 .55285 Mtetra
.94739 .55285 .94903 .55514 .95345 .5539 .95181 .5516 Mtetra
.95181 .5516 .95345 .5539 .95787 .55266 .95624 .55036 Mtetra
.95624 .55036 .95787 .55266 .9623 .55141 .96068 .54911 Mtetra
.96068 .54911 .9623 .55141 .96674 .55017 .96512 .54786 Mtetra
.646 .762 .934 r
.36063 .77541 .36287 .77723 .36653 .77625 .36428 .77442 Mtetra
.36428 .77442 .36653 .77625 .37019 .77526 .36795 .77343 Mtetra
.36795 .77343 .37019 .77526 .37385 .77427 .37162 .77244 Mtetra
.37162 .77244 .37385 .77427 .37753 .77328 .37529 .77145 Mtetra
.37529 .77145 .37753 .77328 .3812 .77229 .37897 .77045 Mtetra
.37897 .77045 .3812 .77229 .38488 .77129 .38265 .76946 Mtetra
.38265 .76946 .38488 .77129 .38857 .7703 .38634 .76846 Mtetra
.38634 .76846 .38857 .7703 .39226 .7693 .39004 .76746 Mtetra
.39004 .76746 .39226 .7693 .39596 .76831 .39374 .76646 Mtetra
.39374 .76646 .39596 .76831 .39966 .76731 .39744 .76546 Mtetra
.39744 .76546 .39966 .76731 .40336 .76631 .40115 .76446 Mtetra
.40115 .76446 .40336 .76631 .40707 .76531 .40487 .76345 Mtetra
.40487 .76345 .40707 .76531 .41079 .7643 .40859 .76245 Mtetra
.40859 .76245 .41079 .7643 .41451 .7633 .41231 .76144 Mtetra
.41231 .76144 .41451 .7633 .41824 .76229 .41604 .76043 Mtetra
.41604 .76043 .41824 .76229 .42197 .76129 .41978 .75942 Mtetra
.41978 .75942 .42197 .76129 .42571 .76028 .42352 .75841 Mtetra
.42352 .75841 .42571 .76028 .42945 .75927 .42726 .7574 Mtetra
.42726 .7574 .42945 .75927 .4332 .75826 .43101 .75638 Mtetra
.43101 .75638 .4332 .75826 .43695 .75724 .43477 .75537 Mtetra
.43477 .75537 .43695 .75724 .44071 .75623 .43853 .75435 Mtetra
.43853 .75435 .44071 .75623 .44447 .75521 .4423 .75333 Mtetra
.943 .696 .533 r
.4423 .75333 .44447 .75521 .45041 .65302 .4483 .65107 Mtetra
.655 .752 .921 r
.4483 .65107 .45041 .65302 .45408 .65197 .45197 .65001 Mtetra
.45197 .65001 .45408 .65197 .45775 .65091 .45565 .64895 Mtetra
.45565 .64895 .45775 .65091 .46143 .64985 .45933 .64788 Mtetra
.45933 .64788 .46143 .64985 .46511 .64878 .46302 .64682 Mtetra
.46302 .64682 .46511 .64878 .4688 .64772 .46671 .64575 Mtetra
.46671 .64575 .4688 .64772 .47249 .64665 .4704 .64468 Mtetra
.4704 .64468 .47249 .64665 .47619 .64559 .47411 .64361 Mtetra
.47411 .64361 .47619 .64559 .47989 .64452 .47781 .64254 Mtetra
.47781 .64254 .47989 .64452 .4836 .64345 .48152 .64147 Mtetra
.48152 .64147 .4836 .64345 .48732 .64238 .48524 .6404 Mtetra
.48524 .6404 .48732 .64238 .49104 .64131 .48896 .63932 Mtetra
.48896 .63932 .49104 .64131 .49476 .64023 .49269 .63825 Mtetra
.49269 .63825 .49476 .64023 .49849 .63916 .49642 .63717 Mtetra
.49642 .63717 .49849 .63916 .50222 .63808 .50016 .63609 Mtetra
.50016 .63609 .50222 .63808 .50596 .637 .5039 .63501 Mtetra
.5039 .63501 .50596 .637 .5097 .63592 .50765 .63393 Mtetra
.50765 .63393 .5097 .63592 .51345 .63484 .5114 .63284 Mtetra
.5114 .63284 .51345 .63484 .51721 .63376 .51516 .63176 Mtetra
.51516 .63176 .51721 .63376 .52097 .63267 .51892 .63067 Mtetra
.51892 .63067 .52097 .63267 .52473 .63159 .52269 .62958 Mtetra
.955 .642 .395 r
.52269 .62958 .52473 .63159 .5285 .6305 .52647 .65849 Mtetra
.55 .315 .512 r
.52647 .65849 .5285 .6305 .53234 .65941 .53028 .65741 Mtetra
.653 .755 .925 r
.53028 .65741 .53234 .65941 .53615 .65833 .5341 .65633 Mtetra
.5341 .65633 .53615 .65833 .53997 .65725 .53792 .65525 Mtetra
.53792 .65525 .53997 .65725 .54379 .65617 .54175 .65416 Mtetra
.54175 .65416 .54379 .65617 .54762 .65508 .54558 .65308 Mtetra
.54558 .65308 .54762 .65508 .55146 .654 .54942 .65199 Mtetra
.54942 .65199 .55146 .654 .55529 .65291 .55326 .6509 Mtetra
.55326 .6509 .55529 .65291 .55914 .65182 .55711 .64981 Mtetra
.55711 .64981 .55914 .65182 .56299 .65073 .56096 .64872 Mtetra
.56096 .64872 .56299 .65073 .56684 .64964 .56482 .64762 Mtetra
.56482 .64762 .56684 .64964 .57071 .64855 .56869 .64653 Mtetra
.56869 .64653 .57071 .64855 .57457 .64746 .57256 .64543 Mtetra
.57256 .64543 .57457 .64746 .57844 .64636 .57643 .64433 Mtetra
.57643 .64433 .57844 .64636 .58232 .64526 .58031 .64323 Mtetra
.58031 .64323 .58232 .64526 .5862 .64417 .5842 .64213 Mtetra
.5842 .64213 .5862 .64417 .59009 .64307 .58809 .64103 Mtetra
.58809 .64103 .59009 .64307 .59398 .64196 .59199 .63993 Mtetra
.59199 .63993 .59398 .64196 .59788 .64086 .59589 .63882 Mtetra
.59589 .63882 .59788 .64086 .60179 .63976 .5998 .63771 Mtetra
.5998 .63771 .60179 .63976 .6057 .63865 .60371 .6366 Mtetra
.60371 .6366 .6057 .63865 .60961 .63754 .60763 .63549 Mtetra
.60763 .63549 .60961 .63754 .61353 .63643 .61155 .63438 Mtetra
.61155 .63438 .61353 .63643 .61828 .6661 .61548 .63327 Mtetra
.103 .047 .502 r
.61548 .63327 .61828 .6661 .62225 .665 .62026 .66297 Mtetra
.65 .758 .928 r
.62026 .66297 .62225 .665 .62622 .6639 .62424 .66186 Mtetra
.62424 .66186 .62622 .6639 .6302 .6628 .62822 .66075 Mtetra
.62822 .66075 .6302 .6628 .63418 .66169 .63221 .65965 Mtetra
.63221 .65965 .63418 .66169 .63817 .66058 .6362 .65854 Mtetra
.6362 .65854 .63817 .66058 .64217 .65948 .6402 .65742 Mtetra
.6402 .65742 .64217 .65948 .64617 .65837 .64421 .65631 Mtetra
.64421 .65631 .64617 .65837 .65018 .65725 .64822 .6552 Mtetra
.64822 .6552 .65018 .65725 .65419 .65614 .65223 .65408 Mtetra
.65223 .65408 .65419 .65614 .65821 .65503 .65626 .65296 Mtetra
.65626 .65296 .65821 .65503 .66223 .65391 .66028 .65184 Mtetra
.966 .707 .49 r
.66028 .65184 .66223 .65391 .66626 .65279 .66165 .58436 Mtetra
.576 .378 .576 r
.66165 .58436 .66626 .65279 .66752 .58533 .66561 .58322 Mtetra
.656 .751 .92 r
.66561 .58322 .66752 .58533 .67148 .58419 .66958 .58207 Mtetra
.66958 .58207 .67148 .58419 .67545 .58304 .67355 .58092 Mtetra
.67355 .58092 .67545 .58304 .67942 .58189 .67753 .57976 Mtetra
.67753 .57976 .67942 .58189 .6834 .58074 .68151 .57861 Mtetra
.68151 .57861 .6834 .58074 .68739 .57959 .6855 .57745 Mtetra
.6855 .57745 .68739 .57959 .69138 .57843 .68949 .5763 Mtetra
.68949 .5763 .69138 .57843 .69537 .57728 .69349 .57514 Mtetra
.69349 .57514 .69537 .57728 .69938 .57612 .6975 .57398 Mtetra
.6975 .57398 .69938 .57612 .70338 .57496 .70151 .57281 Mtetra
.70151 .57281 .70338 .57496 .7074 .5738 .70553 .57165 Mtetra
.70553 .57165 .7074 .5738 .71141 .57264 .70955 .57048 Mtetra
.70955 .57048 .71141 .57264 .71544 .57147 .71358 .56932 Mtetra
.71358 .56932 .71544 .57147 .71947 .57031 .71761 .56815 Mtetra
.71761 .56815 .71947 .57031 .7235 .56914 .72165 .56698 Mtetra
.72165 .56698 .7235 .56914 .72754 .56797 .72569 .56581 Mtetra
.72569 .56581 .72754 .56797 .73159 .5668 .72975 .56463 Mtetra
.72975 .56463 .73159 .5668 .73564 .56563 .7338 .56346 Mtetra
.7338 .56346 .73564 .56563 .7397 .56445 .73787 .56228 Mtetra
.95 .597 .248 r
.73787 .56228 .7397 .56445 .74541 .58867 .74356 .58651 Mtetra
.654 .754 .923 r
.74356 .58651 .74541 .58867 .74951 .5875 .74767 .58534 Mtetra
.74767 .58534 .74951 .5875 .75362 .58633 .75178 .58416 Mtetra
.75178 .58416 .75362 .58633 .75773 .58516 .7559 .58299 Mtetra
.7559 .58299 .75773 .58516 .76185 .58398 .76002 .58181 Mtetra
.76002 .58181 .76185 .58398 .76598 .58281 .76415 .58064 Mtetra
.76415 .58064 .76598 .58281 .77011 .58163 .76829 .57946 Mtetra
.76829 .57946 .77011 .58163 .77425 .58045 .77243 .57827 Mtetra
.77243 .57827 .77425 .58045 .77839 .57927 .77658 .57709 Mtetra
.77658 .57709 .77839 .57927 .78254 .57809 .78073 .57591 Mtetra
.78073 .57591 .78254 .57809 .78669 .57691 .78489 .57472 Mtetra
.78489 .57472 .78669 .57691 .79085 .57572 .78905 .57353 Mtetra
.78905 .57353 .79085 .57572 .79502 .57454 .79323 .57234 Mtetra
.928 .552 .159 r
.79323 .57234 .79502 .57454 .79919 .57335 .79907 .59185 Mtetra
.539 .29 .486 r
.79907 .59185 .79919 .57335 .80507 .59286 .80328 .59067 Mtetra
.652 .756 .926 r
.80328 .59067 .80507 .59286 .80928 .59167 .80749 .58948 Mtetra
.80749 .58948 .80928 .59167 .8135 .59049 .81172 .58829 Mtetra
.81172 .58829 .8135 .59049 .81773 .5893 .81594 .5871 Mtetra
.81594 .5871 .81773 .5893 .82196 .58811 .82018 .58591 Mtetra
.82018 .58591 .82196 .58811 .82619 .58692 .82442 .58471 Mtetra
.82442 .58471 .82619 .58692 .83044 .58573 .82867 .58352 Mtetra
.82867 .58352 .83044 .58573 .83469 .58453 .83292 .58232 Mtetra
.83292 .58232 .83469 .58453 .83894 .58333 .83718 .58112 Mtetra
.83718 .58112 .83894 .58333 .8432 .58214 .84145 .57992 Mtetra
.84145 .57992 .8432 .58214 .84747 .58094 .84572 .57872 Mtetra
.84572 .57872 .84747 .58094 .85175 .57974 .85 .57751 Mtetra
.85 .57751 .85175 .57974 .85603 .57853 .85428 .57631 Mtetra
.85428 .57631 .85603 .57853 .86031 .57733 .85858 .5751 Mtetra
.85858 .5751 .86031 .57733 .86461 .57612 .86287 .57389 Mtetra
.86287 .57389 .86461 .57612 .8689 .57491 .86718 .57268 Mtetra
.86718 .57268 .8689 .57491 .87321 .5737 .87149 .57146 Mtetra
.87149 .57146 .87321 .5737 .87752 .57249 .8758 .57025 Mtetra
.8758 .57025 .87752 .57249 .88184 .57127 .88013 .56903 Mtetra
.88013 .56903 .88184 .57127 .88617 .57006 .88446 .56781 Mtetra
.88446 .56781 .88617 .57006 .8905 .56884 .88879 .56659 Mtetra
.88879 .56659 .8905 .56884 .89483 .56762 .89313 .56537 Mtetra
.89313 .56537 .89483 .56762 .89918 .5664 .89748 .56414 Mtetra
.89748 .56414 .89918 .5664 .90353 .56518 .90184 .56292 Mtetra
.90184 .56292 .90353 .56518 .90789 .56395 .9062 .56169 Mtetra
.9062 .56169 .90789 .56395 .91225 .56273 .91057 .56046 Mtetra
.91057 .56046 .91225 .56273 .91662 .5615 .91494 .55923 Mtetra
.91494 .55923 .91662 .5615 .921 .56027 .91932 .55799 Mtetra
.91932 .55799 .921 .56027 .92538 .55904 .92371 .55676 Mtetra
.92371 .55676 .92538 .55904 .92977 .5578 .92811 .55552 Mtetra
.92811 .55552 .92977 .5578 .93416 .55657 .93251 .55428 Mtetra
.93251 .55428 .93416 .55657 .93857 .55533 .93691 .55304 Mtetra
.93691 .55304 .93857 .55533 .94298 .55409 .94133 .5518 Mtetra
.94133 .5518 .94298 .55409 .94739 .55285 .94575 .55055 Mtetra
.94575 .55055 .94739 .55285 .95181 .5516 .95017 .5493 Mtetra
.95017 .5493 .95181 .5516 .95624 .55036 .95461 .54806 Mtetra
.95461 .54806 .95624 .55036 .96068 .54911 .95905 .54681 Mtetra
.95905 .54681 .96068 .54911 .96512 .54786 .9635 .54555 Mtetra
.646 .762 .934 r
.35837 .77358 .36063 .77541 .36428 .77442 .36204 .77259 Mtetra
.36204 .77259 .36428 .77442 .36795 .77343 .3657 .7716 Mtetra
.3657 .7716 .36795 .77343 .37162 .77244 .36937 .77061 Mtetra
.36937 .77061 .37162 .77244 .37529 .77145 .37305 .76961 Mtetra
.37305 .76961 .37529 .77145 .37897 .77045 .37673 .76861 Mtetra
.37673 .76861 .37897 .77045 .38265 .76946 .38042 .76761 Mtetra
.38042 .76761 .38265 .76946 .38634 .76846 .38411 .76661 Mtetra
.38411 .76661 .38634 .76846 .39004 .76746 .38781 .76561 Mtetra
.38781 .76561 .39004 .76746 .39374 .76646 .39151 .76461 Mtetra
.39151 .76461 .39374 .76646 .39744 .76546 .39522 .76361 Mtetra
.39522 .76361 .39744 .76546 .40115 .76446 .39893 .7626 Mtetra
.39893 .7626 .40115 .76446 .40487 .76345 .40265 .7616 Mtetra
.40265 .7616 .40487 .76345 .40859 .76245 .40637 .76059 Mtetra
.40637 .76059 .40859 .76245 .41231 .76144 .4101 .75958 Mtetra
.4101 .75958 .41231 .76144 .41604 .76043 .41384 .75857 Mtetra
.41384 .75857 .41604 .76043 .41978 .75942 .41757 .75755 Mtetra
.41757 .75755 .41978 .75942 .42352 .75841 .42132 .75654 Mtetra
.42132 .75654 .42352 .75841 .42726 .7574 .42507 .75553 Mtetra
.42507 .75553 .42726 .7574 .43101 .75638 .42882 .75451 Mtetra
.42882 .75451 .43101 .75638 .43477 .75537 .43258 .75349 Mtetra
.43258 .75349 .43477 .75537 .43853 .75435 .43634 .75247 Mtetra
.43634 .75247 .43853 .75435 .4423 .75333 .44011 .75145 Mtetra
.943 .697 .535 r
.44011 .75145 .4423 .75333 .4483 .65107 .44596 .65898 Mtetra
.494 .195 .387 r
.44596 .65898 .4483 .65107 .45197 .65001 .44965 .65792 Mtetra
.44965 .65792 .45197 .65001 .45565 .64895 .45334 .65686 Mtetra
.45334 .65686 .45565 .64895 .45933 .64788 .45703 .6558 Mtetra
.45703 .6558 .45933 .64788 .46302 .64682 .46073 .65474 Mtetra
.46073 .65474 .46302 .64682 .46671 .64575 .46444 .65367 Mtetra
.46444 .65367 .46671 .64575 .4704 .64468 .46815 .6526 Mtetra
.46815 .6526 .4704 .64468 .47411 .64361 .47186 .65154 Mtetra
.47186 .65154 .47411 .64361 .47781 .64254 .47558 .65047 Mtetra
0 0 0 r
.47558 .65047 .47781 .64254 .48152 .64147 .47944 .63949 Mtetra
.655 .752 .921 r
.47944 .63949 .48152 .64147 .48524 .6404 .48316 .63841 Mtetra
.48316 .63841 .48524 .6404 .48896 .63932 .48688 .63733 Mtetra
.48688 .63733 .48896 .63932 .49269 .63825 .49061 .63626 Mtetra
.49061 .63626 .49269 .63825 .49642 .63717 .49435 .63517 Mtetra
.49435 .63517 .49642 .63717 .50016 .63609 .49809 .63409 Mtetra
.49809 .63409 .50016 .63609 .5039 .63501 .50183 .63301 Mtetra
.50183 .63301 .5039 .63501 .50765 .63393 .50558 .63192 Mtetra
.50558 .63192 .50765 .63393 .5114 .63284 .50934 .63084 Mtetra
.50934 .63084 .5114 .63284 .51516 .63176 .5131 .62975 Mtetra
.5131 .62975 .51516 .63176 .51892 .63067 .51687 .62866 Mtetra
.51687 .62866 .51892 .63067 .52269 .62958 .52064 .62757 Mtetra
.955 .642 .395 r
.52064 .62757 .52269 .62958 .52647 .65849 .52441 .6565 Mtetra
.653 .755 .925 r
.52441 .6565 .52647 .65849 .53028 .65741 .52822 .65542 Mtetra
.52822 .65542 .53028 .65741 .5341 .65633 .53204 .65433 Mtetra
.53204 .65433 .5341 .65633 .53792 .65525 .53587 .65325 Mtetra
.53587 .65325 .53792 .65525 .54175 .65416 .5397 .65216 Mtetra
.5397 .65216 .54175 .65416 .54558 .65308 .54354 .65107 Mtetra
.54354 .65107 .54558 .65308 .54942 .65199 .54738 .64998 Mtetra
.54738 .64998 .54942 .65199 .55326 .6509 .55122 .64889 Mtetra
.55122 .64889 .55326 .6509 .55711 .64981 .55507 .64779 Mtetra
.55507 .64779 .55711 .64981 .56096 .64872 .55893 .6467 Mtetra
.55893 .6467 .56096 .64872 .56482 .64762 .56279 .6456 Mtetra
.56279 .6456 .56482 .64762 .56869 .64653 .56666 .6445 Mtetra
.56666 .6445 .56869 .64653 .57256 .64543 .57054 .6434 Mtetra
.57054 .6434 .57256 .64543 .57643 .64433 .57441 .6423 Mtetra
.57441 .6423 .57643 .64433 .58031 .64323 .5783 .6412 Mtetra
.5783 .6412 .58031 .64323 .5842 .64213 .58219 .6401 Mtetra
.58219 .6401 .5842 .64213 .58809 .64103 .58608 .63899 Mtetra
.58608 .63899 .58809 .64103 .59199 .63993 .58998 .63788 Mtetra
.58998 .63788 .59199 .63993 .59589 .63882 .59389 .63677 Mtetra
.59389 .63677 .59589 .63882 .5998 .63771 .5978 .63566 Mtetra
.5978 .63566 .5998 .63771 .60371 .6366 .60172 .63455 Mtetra
.60172 .63455 .60371 .6366 .60763 .63549 .60564 .63344 Mtetra
.60564 .63344 .60763 .63549 .61155 .63438 .60957 .63232 Mtetra
.60957 .63232 .61155 .63438 .61548 .63327 .6135 .63121 Mtetra
.962 .7 .49 r
.6135 .63121 .61548 .63327 .62026 .66297 .61479 .53113 Mtetra
.572 .369 .567 r
.61479 .53113 .62026 .66297 .62424 .66186 .61862 .52997 Mtetra
.05 0 .447 r
.61862 .52997 .62424 .66186 .62822 .66075 .62623 .65871 Mtetra
.65 .758 .928 r
.62623 .65871 .62822 .66075 .63221 .65965 .63023 .6576 Mtetra
.63023 .6576 .63221 .65965 .6362 .65854 .63422 .65648 Mtetra
.63422 .65648 .6362 .65854 .6402 .65742 .63823 .65537 Mtetra
.63823 .65537 .6402 .65742 .64421 .65631 .64224 .65425 Mtetra
.64224 .65425 .64421 .65631 .64822 .6552 .64625 .65314 Mtetra
.64625 .65314 .64822 .6552 .65223 .65408 .65027 .65202 Mtetra
.65027 .65202 .65223 .65408 .65626 .65296 .6543 .6509 Mtetra
.6543 .6509 .65626 .65296 .66028 .65184 .65833 .64977 Mtetra
.966 .707 .49 r
.65833 .64977 .66028 .65184 .66165 .58436 .65974 .58224 Mtetra
.656 .751 .92 r
.65974 .58224 .66165 .58436 .66561 .58322 .6637 .58109 Mtetra
.6637 .58109 .66561 .58322 .66958 .58207 .66767 .57994 Mtetra
.66767 .57994 .66958 .58207 .67355 .58092 .67165 .57879 Mtetra
.67165 .57879 .67355 .58092 .67753 .57976 .67563 .57763 Mtetra
.67563 .57763 .67753 .57976 .68151 .57861 .67961 .57647 Mtetra
.67961 .57647 .68151 .57861 .6855 .57745 .68361 .57532 Mtetra
.68361 .57532 .6855 .57745 .68949 .5763 .6876 .57416 Mtetra
.6876 .57416 .68949 .5763 .69349 .57514 .69161 .57299 Mtetra
.69161 .57299 .69349 .57514 .6975 .57398 .69562 .57183 Mtetra
.69562 .57183 .6975 .57398 .70151 .57281 .69963 .57066 Mtetra
.69963 .57066 .70151 .57281 .70553 .57165 .70365 .5695 Mtetra
.70365 .5695 .70553 .57165 .70955 .57048 .70768 .56833 Mtetra
.70768 .56833 .70955 .57048 .71358 .56932 .71171 .56716 Mtetra
.71171 .56716 .71358 .56932 .71761 .56815 .71575 .56599 Mtetra
.71575 .56599 .71761 .56815 .72165 .56698 .71979 .56481 Mtetra
.71979 .56481 .72165 .56698 .72569 .56581 .72384 .56364 Mtetra
.72384 .56364 .72569 .56581 .72975 .56463 .7279 .56246 Mtetra
.7279 .56246 .72975 .56463 .7338 .56346 .73196 .56128 Mtetra
.73196 .56128 .7338 .56346 .73787 .56228 .73602 .5601 Mtetra
.73602 .5601 .73787 .56228 .74356 .58651 .74009 .55892 Mtetra
.173 .112 .543 r
.74009 .55892 .74356 .58651 .74767 .58534 .74582 .58317 Mtetra
.654 .754 .923 r
.74582 .58317 .74767 .58534 .75178 .58416 .74994 .58199 Mtetra
.74994 .58199 .75178 .58416 .7559 .58299 .75406 .58082 Mtetra
.75406 .58082 .7559 .58299 .76002 .58181 .75819 .57964 Mtetra
.75819 .57964 .76002 .58181 .76415 .58064 .76232 .57846 Mtetra
.76232 .57846 .76415 .58064 .76829 .57946 .76646 .57727 Mtetra
.76646 .57727 .76829 .57946 .77243 .57827 .77061 .57609 Mtetra
.77061 .57609 .77243 .57827 .77658 .57709 .77476 .5749 Mtetra
.77476 .5749 .77658 .57709 .78073 .57591 .77892 .57371 Mtetra
.77892 .57371 .78073 .57591 .78489 .57472 .78308 .57253 Mtetra
.78308 .57253 .78489 .57472 .78905 .57353 .78725 .57133 Mtetra
.78725 .57133 .78905 .57353 .79323 .57234 .79143 .57014 Mtetra
.928 .552 .159 r
.79143 .57014 .79323 .57234 .79907 .59185 .79726 .58966 Mtetra
.652 .756 .926 r
.79726 .58966 .79907 .59185 .80328 .59067 .80148 .58848 Mtetra
.80148 .58848 .80328 .59067 .80749 .58948 .8057 .58728 Mtetra
.8057 .58728 .80749 .58948 .81172 .58829 .80992 .58609 Mtetra
.80992 .58609 .81172 .58829 .81594 .5871 .81416 .5849 Mtetra
.81416 .5849 .81594 .5871 .82018 .58591 .8184 .5837 Mtetra
.8184 .5837 .82018 .58591 .82442 .58471 .82264 .58251 Mtetra
.82264 .58251 .82442 .58471 .82867 .58352 .82689 .58131 Mtetra
.82689 .58131 .82867 .58352 .83292 .58232 .83115 .58011 Mtetra
.83115 .58011 .83292 .58232 .83718 .58112 .83542 .5789 Mtetra
.83542 .5789 .83718 .58112 .84145 .57992 .83969 .5777 Mtetra
.83969 .5777 .84145 .57992 .84572 .57872 .84396 .57649 Mtetra
.84396 .57649 .84572 .57872 .85 .57751 .84825 .57528 Mtetra
.84825 .57528 .85 .57751 .85428 .57631 .85254 .57407 Mtetra
.85254 .57407 .85428 .57631 .85858 .5751 .85683 .57286 Mtetra
.85683 .57286 .85858 .5751 .86287 .57389 .86114 .57165 Mtetra
.86114 .57165 .86287 .57389 .86718 .57268 .86544 .57043 Mtetra
.86544 .57043 .86718 .57268 .87149 .57146 .86976 .56922 Mtetra
.86976 .56922 .87149 .57146 .8758 .57025 .87408 .568 Mtetra
.87408 .568 .8758 .57025 .88013 .56903 .87841 .56678 Mtetra
.87841 .56678 .88013 .56903 .88446 .56781 .88274 .56555 Mtetra
.88274 .56555 .88446 .56781 .88879 .56659 .88708 .56433 Mtetra
.88708 .56433 .88879 .56659 .89313 .56537 .89143 .5631 Mtetra
.89143 .5631 .89313 .56537 .89748 .56414 .89578 .56188 Mtetra
.89578 .56188 .89748 .56414 .90184 .56292 .90014 .56065 Mtetra
.90014 .56065 .90184 .56292 .9062 .56169 .90451 .55942 Mtetra
.90451 .55942 .9062 .56169 .91057 .56046 .90888 .55818 Mtetra
.90888 .55818 .91057 .56046 .91494 .55923 .91326 .55695 Mtetra
.91326 .55695 .91494 .55923 .91932 .55799 .91765 .55571 Mtetra
.91765 .55571 .91932 .55799 .92371 .55676 .92204 .55447 Mtetra
.92204 .55447 .92371 .55676 .92811 .55552 .92644 .55323 Mtetra
.92644 .55323 .92811 .55552 .93251 .55428 .93084 .55199 Mtetra
.93084 .55199 .93251 .55428 .93691 .55304 .93526 .55074 Mtetra
.93526 .55074 .93691 .55304 .94133 .5518 .93967 .5495 Mtetra
.93967 .5495 .94133 .5518 .94575 .55055 .9441 .54825 Mtetra
.9441 .54825 .94575 .55055 .95017 .5493 .94853 .547 Mtetra
.94853 .547 .95017 .5493 .95461 .54806 .95297 .54575 Mtetra
.95297 .54575 .95461 .54806 .95905 .54681 .95742 .54449 Mtetra
.95742 .54449 .95905 .54681 .9635 .54555 .96187 .54324 Mtetra
.646 .762 .934 r
.35612 .77175 .35837 .77358 .36204 .77259 .35978 .77076 Mtetra
.35978 .77076 .36204 .77259 .3657 .7716 .36345 .76976 Mtetra
.36345 .76976 .3657 .7716 .36937 .77061 .36713 .76877 Mtetra
.36713 .76877 .36937 .77061 .37305 .76961 .37081 .76777 Mtetra
.37081 .76777 .37305 .76961 .37673 .76861 .37449 .76677 Mtetra
.37449 .76677 .37673 .76861 .38042 .76761 .37818 .76577 Mtetra
.37818 .76577 .38042 .76761 .38411 .76661 .38188 .76477 Mtetra
.38188 .76477 .38411 .76661 .38781 .76561 .38558 .76376 Mtetra
.38558 .76376 .38781 .76561 .39151 .76461 .38928 .76276 Mtetra
.38928 .76276 .39151 .76461 .39522 .76361 .39299 .76175 Mtetra
.39299 .76175 .39522 .76361 .39893 .7626 .39671 .76074 Mtetra
.39671 .76074 .39893 .7626 .40265 .7616 .40043 .75973 Mtetra
.40043 .75973 .40265 .7616 .40637 .76059 .40416 .75872 Mtetra
.40416 .75872 .40637 .76059 .4101 .75958 .40789 .75771 Mtetra
.40789 .75771 .4101 .75958 .41384 .75857 .41163 .7567 Mtetra
.41163 .7567 .41384 .75857 .41757 .75755 .41537 .75568 Mtetra
.41537 .75568 .41757 .75755 .42132 .75654 .41911 .75467 Mtetra
.41911 .75467 .42132 .75654 .42507 .75553 .42287 .75365 Mtetra
.42287 .75365 .42507 .75553 .42882 .75451 .42662 .75263 Mtetra
.42662 .75263 .42882 .75451 .43258 .75349 .43039 .75161 Mtetra
.43039 .75161 .43258 .75349 .43634 .75247 .43415 .75059 Mtetra
.943 .697 .536 r
.43415 .75059 .43634 .75247 .44011 .75145 .44015 .65809 Mtetra
.573 .372 .57 r
.44015 .65809 .44011 .75145 .44596 .65898 .44384 .65703 Mtetra
.655 .753 .922 r
.44384 .65703 .44596 .65898 .44965 .65792 .44753 .65596 Mtetra
.44753 .65596 .44965 .65792 .45334 .65686 .45122 .6549 Mtetra
.45122 .6549 .45334 .65686 .45703 .6558 .45492 .65383 Mtetra
.45492 .65383 .45703 .6558 .46073 .65474 .45862 .65277 Mtetra
.45862 .65277 .46073 .65474 .46444 .65367 .46233 .6517 Mtetra
.46233 .6517 .46444 .65367 .46815 .6526 .46604 .65063 Mtetra
.46604 .65063 .46815 .6526 .47186 .65154 .46976 .64956 Mtetra
.46976 .64956 .47186 .65154 .47558 .65047 .47348 .64849 Mtetra
.47348 .64849 .47558 .65047 .47944 .63949 .47721 .64741 Mtetra
.493 .193 .386 r
.47721 .64741 .47944 .63949 .48316 .63841 .48095 .64634 Mtetra
.48095 .64634 .48316 .63841 .48688 .63733 .48468 .64526 Mtetra
.48468 .64526 .48688 .63733 .49061 .63626 .48843 .64418 Mtetra
.48843 .64418 .49061 .63626 .49435 .63517 .49218 .6431 Mtetra
.49218 .6431 .49435 .63517 .49809 .63409 .49593 .64202 Mtetra
.49593 .64202 .49809 .63409 .50183 .63301 .49969 .64094 Mtetra
.49969 .64094 .50183 .63301 .50558 .63192 .50346 .63985 Mtetra
.50346 .63985 .50558 .63192 .50934 .63084 .50723 .63877 Mtetra
.50723 .63877 .50934 .63084 .5131 .62975 .511 .63768 Mtetra
.511 .63768 .5131 .62975 .51687 .62866 .51478 .63659 Mtetra
.51478 .63659 .51687 .62866 .52064 .62757 .51857 .6355 Mtetra
.83 .531 .483 r
.51857 .6355 .52064 .62757 .52441 .6565 .52234 .6545 Mtetra
.653 .755 .925 r
.52234 .6545 .52441 .6565 .52822 .65542 .52616 .65341 Mtetra
.52616 .65341 .52822 .65542 .53204 .65433 .52998 .65233 Mtetra
.52998 .65233 .53204 .65433 .53587 .65325 .53381 .65124 Mtetra
.53381 .65124 .53587 .65325 .5397 .65216 .53765 .65015 Mtetra
.53765 .65015 .5397 .65216 .54354 .65107 .54148 .64905 Mtetra
.54148 .64905 .54354 .65107 .54738 .64998 .54533 .64796 Mtetra
.54533 .64796 .54738 .64998 .55122 .64889 .54918 .64687 Mtetra
.54918 .64687 .55122 .64889 .55507 .64779 .55303 .64577 Mtetra
.55303 .64577 .55507 .64779 .55893 .6467 .5569 .64467 Mtetra
.5569 .64467 .55893 .6467 .56279 .6456 .56076 .64357 Mtetra
.56076 .64357 .56279 .6456 .56666 .6445 .56463 .64247 Mtetra
.56463 .64247 .56666 .6445 .57054 .6434 .56851 .64137 Mtetra
.56851 .64137 .57054 .6434 .57441 .6423 .57239 .64027 Mtetra
.57239 .64027 .57441 .6423 .5783 .6412 .57628 .63916 Mtetra
.57628 .63916 .5783 .6412 .58219 .6401 .58017 .63805 Mtetra
.58017 .63805 .58219 .6401 .58608 .63899 .58407 .63694 Mtetra
.58407 .63694 .58608 .63899 .58998 .63788 .58798 .63583 Mtetra
.58798 .63583 .58998 .63788 .59389 .63677 .59189 .63472 Mtetra
.59189 .63472 .59389 .63677 .5978 .63566 .5958 .63361 Mtetra
.5958 .63361 .5978 .63566 .60172 .63455 .59972 .63249 Mtetra
.59972 .63249 .60172 .63455 .60564 .63344 .60365 .63138 Mtetra
.60365 .63138 .60564 .63344 .60957 .63232 .60758 .63026 Mtetra
.962 .7 .491 r
.60758 .63026 .60957 .63232 .6135 .63121 .60903 .53015 Mtetra
.573 .371 .569 r
.60903 .53015 .6135 .63121 .61479 .53113 .61286 .529 Mtetra
.661 .745 .912 r
.61286 .529 .61479 .53113 .61862 .52997 .61669 .52784 Mtetra
.61669 .52784 .61862 .52997 .62623 .65871 .62053 .52668 Mtetra
.572 .368 .567 r
.62053 .52668 .62623 .65871 .63023 .6576 .62437 .52551 Mtetra
.62437 .52551 .63023 .6576 .63422 .65648 .62822 .52435 Mtetra
.62822 .52435 .63422 .65648 .63823 .65537 .63208 .52319 Mtetra
.63208 .52319 .63823 .65537 .64224 .65425 .63594 .52202 Mtetra
.63594 .52202 .64224 .65425 .64625 .65314 .6398 .52085 Mtetra
.061 0 .453 r
.6398 .52085 .64625 .65314 .65027 .65202 .6483 .64995 Mtetra
.65 .758 .928 r
.6483 .64995 .65027 .65202 .6543 .6509 .65233 .64882 Mtetra
.966 .707 .492 r
.65233 .64882 .6543 .6509 .65833 .64977 .65385 .58127 Mtetra
.575 .377 .576 r
.65385 .58127 .65833 .64977 .65974 .58224 .65781 .58012 Mtetra
.656 .751 .92 r
.65781 .58012 .65974 .58224 .6637 .58109 .66178 .57896 Mtetra
.66178 .57896 .6637 .58109 .66767 .57994 .66576 .57781 Mtetra
.66576 .57781 .66767 .57994 .67165 .57879 .66974 .57665 Mtetra
.66974 .57665 .67165 .57879 .67563 .57763 .67372 .57549 Mtetra
.67372 .57549 .67563 .57763 .67961 .57647 .67771 .57433 Mtetra
.67771 .57433 .67961 .57647 .68361 .57532 .68171 .57317 Mtetra
.68171 .57317 .68361 .57532 .6876 .57416 .68571 .57201 Mtetra
.68571 .57201 .6876 .57416 .69161 .57299 .68972 .57084 Mtetra
.68972 .57084 .69161 .57299 .69562 .57183 .69373 .56968 Mtetra
.69373 .56968 .69562 .57183 .69963 .57066 .69775 .56851 Mtetra
.69775 .56851 .69963 .57066 .70365 .5695 .70177 .56734 Mtetra
.70177 .56734 .70365 .5695 .70768 .56833 .7058 .56617 Mtetra
.7058 .56617 .70768 .56833 .71171 .56716 .70984 .56499 Mtetra
.70984 .56499 .71171 .56716 .71575 .56599 .71388 .56382 Mtetra
.71388 .56382 .71575 .56599 .71979 .56481 .71793 .56264 Mtetra
.71793 .56264 .71979 .56481 .72384 .56364 .72198 .56146 Mtetra
.72198 .56146 .72384 .56364 .7279 .56246 .72604 .56028 Mtetra
.72604 .56028 .7279 .56246 .73196 .56128 .7301 .5591 Mtetra
.7301 .5591 .73196 .56128 .73602 .5601 .73418 .55792 Mtetra
.73418 .55792 .73602 .5601 .74009 .55892 .73825 .55673 Mtetra
.95 .596 .246 r
.73825 .55673 .74009 .55892 .74582 .58317 .74397 .581 Mtetra
.654 .754 .923 r
.74397 .581 .74582 .58317 .74994 .58199 .74809 .57982 Mtetra
.74809 .57982 .74994 .58199 .75406 .58082 .75222 .57864 Mtetra
.75222 .57864 .75406 .58082 .75819 .57964 .75635 .57746 Mtetra
.75635 .57746 .75819 .57964 .76232 .57846 .76049 .57627 Mtetra
.76049 .57627 .76232 .57846 .76646 .57727 .76463 .57509 Mtetra
.76463 .57509 .76646 .57727 .77061 .57609 .76878 .5739 Mtetra
.76878 .5739 .77061 .57609 .77476 .5749 .77294 .57271 Mtetra
.77294 .57271 .77476 .5749 .77892 .57371 .7771 .57152 Mtetra
.7771 .57152 .77892 .57371 .78308 .57253 .78127 .57032 Mtetra
.78127 .57032 .78308 .57253 .78725 .57133 .78544 .56913 Mtetra
.78544 .56913 .78725 .57133 .79143 .57014 .78962 .56793 Mtetra
.928 .552 .159 r
.78962 .56793 .79143 .57014 .79726 .58966 .79545 .58747 Mtetra
.652 .756 .926 r
.79545 .58747 .79726 .58966 .80148 .58848 .79967 .58628 Mtetra
.79967 .58628 .80148 .58848 .8057 .58728 .8039 .58508 Mtetra
.8039 .58508 .8057 .58728 .80992 .58609 .80813 .58389 Mtetra
.80813 .58389 .80992 .58609 .81416 .5849 .81237 .58269 Mtetra
.81237 .58269 .81416 .5849 .8184 .5837 .81661 .58149 Mtetra
.81661 .58149 .8184 .5837 .82264 .58251 .82086 .58029 Mtetra
.82086 .58029 .82264 .58251 .82689 .58131 .82512 .57909 Mtetra
.82512 .57909 .82689 .58131 .83115 .58011 .82938 .57788 Mtetra
.82938 .57788 .83115 .58011 .83542 .5789 .83365 .57668 Mtetra
.83365 .57668 .83542 .5789 .83969 .5777 .83792 .57547 Mtetra
.83792 .57547 .83969 .5777 .84396 .57649 .8422 .57426 Mtetra
.8422 .57426 .84396 .57649 .84825 .57528 .84649 .57305 Mtetra
.84649 .57305 .84825 .57528 .85254 .57407 .85079 .57184 Mtetra
.85079 .57184 .85254 .57407 .85683 .57286 .85509 .57062 Mtetra
.85509 .57062 .85683 .57286 .86114 .57165 .85939 .5694 Mtetra
.85939 .5694 .86114 .57165 .86544 .57043 .86371 .56819 Mtetra
.86371 .56819 .86544 .57043 .86976 .56922 .86803 .56696 Mtetra
.86803 .56696 .86976 .56922 .87408 .568 .87235 .56574 Mtetra
.87235 .56574 .87408 .568 .87841 .56678 .87668 .56452 Mtetra
.87668 .56452 .87841 .56678 .88274 .56555 .88102 .56329 Mtetra
.88102 .56329 .88274 .56555 .88708 .56433 .88537 .56207 Mtetra
.88537 .56207 .88708 .56433 .89143 .5631 .88972 .56084 Mtetra
.88972 .56084 .89143 .5631 .89578 .56188 .89408 .5596 Mtetra
.89408 .5596 .89578 .56188 .90014 .56065 .89844 .55837 Mtetra
.89844 .55837 .90014 .56065 .90451 .55942 .90281 .55714 Mtetra
.90281 .55714 .90451 .55942 .90888 .55818 .90719 .5559 Mtetra
.90719 .5559 .90888 .55818 .91326 .55695 .91158 .55466 Mtetra
.91158 .55466 .91326 .55695 .91765 .55571 .91597 .55342 Mtetra
.91597 .55342 .91765 .55571 .92204 .55447 .92036 .55218 Mtetra
.92036 .55218 .92204 .55447 .92644 .55323 .92477 .55093 Mtetra
.92477 .55093 .92644 .55323 .93084 .55199 .92918 .54969 Mtetra
.92918 .54969 .93084 .55199 .93526 .55074 .93359 .54844 Mtetra
.93359 .54844 .93526 .55074 .93967 .5495 .93802 .54719 Mtetra
.93802 .54719 .93967 .5495 .9441 .54825 .94245 .54594 Mtetra
.94245 .54594 .9441 .54825 .94853 .547 .94688 .54469 Mtetra
.94688 .54469 .94853 .547 .95297 .54575 .95133 .54343 Mtetra
.95133 .54343 .95297 .54575 .95742 .54449 .95578 .54217 Mtetra
.95578 .54217 .95742 .54449 .96187 .54324 .96024 .54091 Mtetra
.575 .376 .575 r
.35699 .70391 .35612 .77175 .35978 .77076 .3606 .70289 Mtetra
0 0 .36 r
.3606 .70289 .35978 .77076 .36345 .76976 .36119 .76792 Mtetra
.646 .762 .934 r
.36119 .76792 .36345 .76976 .36713 .76877 .36487 .76692 Mtetra
.36487 .76692 .36713 .76877 .37081 .76777 .36856 .76592 Mtetra
.36856 .76592 .37081 .76777 .37449 .76677 .37224 .76492 Mtetra
.37224 .76492 .37449 .76677 .37818 .76577 .37594 .76392 Mtetra
.37594 .76392 .37818 .76577 .38188 .76477 .37964 .76291 Mtetra
.37964 .76291 .38188 .76477 .38558 .76376 .38334 .76191 Mtetra
.38334 .76191 .38558 .76376 .38928 .76276 .38705 .7609 Mtetra
.38705 .7609 .38928 .76276 .39299 .76175 .39076 .75989 Mtetra
.39076 .75989 .39299 .76175 .39671 .76074 .39448 .75888 Mtetra
.39448 .75888 .39671 .76074 .40043 .75973 .39821 .75787 Mtetra
.39821 .75787 .40043 .75973 .40416 .75872 .40194 .75685 Mtetra
.40194 .75685 .40416 .75872 .40789 .75771 .40567 .75584 Mtetra
.40567 .75584 .40789 .75771 .41163 .7567 .40941 .75482 Mtetra
.40941 .75482 .41163 .7567 .41537 .75568 .41315 .7538 Mtetra
.41315 .7538 .41537 .75568 .41911 .75467 .4169 .75279 Mtetra
.4169 .75279 .41911 .75467 .42287 .75365 .42066 .75177 Mtetra
.42066 .75177 .42287 .75365 .42662 .75263 .42442 .75074 Mtetra
.42442 .75074 .42662 .75263 .43039 .75161 .42819 .74972 Mtetra
.942 .696 .537 r
.42819 .74972 .43039 .75161 .43415 .75059 .43434 .65719 Mtetra
.573 .372 .57 r
.43434 .65719 .43415 .75059 .44015 .65809 .43802 .65613 Mtetra
.655 .753 .922 r
.43802 .65613 .44015 .65809 .44384 .65703 .44171 .65506 Mtetra
.44171 .65506 .44384 .65703 .44753 .65596 .4454 .654 Mtetra
.4454 .654 .44753 .65596 .45122 .6549 .44909 .65293 Mtetra
.44909 .65293 .45122 .6549 .45492 .65383 .4528 .65186 Mtetra
.4528 .65186 .45492 .65383 .45862 .65277 .4565 .65079 Mtetra
.4565 .65079 .45862 .65277 .46233 .6517 .46021 .64972 Mtetra
.46021 .64972 .46233 .6517 .46604 .65063 .46393 .64865 Mtetra
.46393 .64865 .46604 .65063 .46976 .64956 .46765 .64758 Mtetra
.46765 .64758 .46976 .64956 .47348 .64849 .47138 .6465 Mtetra
.47138 .6465 .47348 .64849 .47721 .64741 .47511 .64543 Mtetra
.47511 .64543 .47721 .64741 .48095 .64634 .47885 .64435 Mtetra
.47885 .64435 .48095 .64634 .48468 .64526 .48259 .64327 Mtetra
.48259 .64327 .48468 .64526 .48843 .64418 .48634 .64219 Mtetra
.48634 .64219 .48843 .64418 .49218 .6431 .49009 .64111 Mtetra
.49009 .64111 .49218 .6431 .49593 .64202 .49385 .64002 Mtetra
.49385 .64002 .49593 .64202 .49969 .64094 .49761 .63894 Mtetra
.49761 .63894 .49969 .64094 .50346 .63985 .50138 .63785 Mtetra
.50138 .63785 .50346 .63985 .50723 .63877 .50515 .63676 Mtetra
.50515 .63676 .50723 .63877 .511 .63768 .50893 .63567 Mtetra
.50893 .63567 .511 .63768 .51478 .63659 .51271 .63458 Mtetra
.51271 .63458 .51478 .63659 .51857 .6355 .5165 .63349 Mtetra
.95 .612 .338 r
.5165 .63349 .51857 .6355 .52234 .6545 .52027 .65249 Mtetra
.653 .755 .925 r
.52027 .65249 .52234 .6545 .52616 .65341 .52409 .6514 Mtetra
.52409 .6514 .52616 .65341 .52998 .65233 .52792 .65031 Mtetra
.52792 .65031 .52998 .65233 .53381 .65124 .53175 .64922 Mtetra
.53175 .64922 .53381 .65124 .53765 .65015 .53559 .64813 Mtetra
.53559 .64813 .53765 .65015 .54148 .64905 .53943 .64704 Mtetra
.53943 .64704 .54148 .64905 .54533 .64796 .54328 .64594 Mtetra
.54328 .64594 .54533 .64796 .54918 .64687 .54713 .64484 Mtetra
.54713 .64484 .54918 .64687 .55303 .64577 .55099 .64374 Mtetra
.55099 .64374 .55303 .64577 .5569 .64467 .55485 .64264 Mtetra
.55485 .64264 .5569 .64467 .56076 .64357 .55872 .64154 Mtetra
.55872 .64154 .56076 .64357 .56463 .64247 .5626 .64044 Mtetra
.5626 .64044 .56463 .64247 .56851 .64137 .56648 .63933 Mtetra
.56648 .63933 .56851 .64137 .57239 .64027 .57036 .63822 Mtetra
.57036 .63822 .57239 .64027 .57628 .63916 .57426 .63712 Mtetra
.57426 .63712 .57628 .63916 .58017 .63805 .57815 .63601 Mtetra
.57815 .63601 .58017 .63805 .58407 .63694 .58205 .63489 Mtetra
.58205 .63489 .58407 .63694 .58798 .63583 .58596 .63378 Mtetra
.58596 .63378 .58798 .63583 .59189 .63472 .58988 .63267 Mtetra
.58988 .63267 .59189 .63472 .5958 .63361 .59379 .63155 Mtetra
.59379 .63155 .5958 .63361 .59972 .63249 .59772 .63043 Mtetra
.59772 .63043 .59972 .63249 .60365 .63138 .60165 .62931 Mtetra
.961 .7 .492 r
.60165 .62931 .60365 .63138 .60758 .63026 .60327 .52917 Mtetra
.572 .371 .569 r
.60327 .52917 .60758 .63026 .60903 .53015 .60709 .52801 Mtetra
.661 .745 .912 r
.60709 .52801 .60903 .53015 .61286 .529 .61093 .52686 Mtetra
.61093 .52686 .61286 .529 .61669 .52784 .61476 .52569 Mtetra
.61476 .52569 .61669 .52784 .62053 .52668 .6186 .52453 Mtetra
.6186 .52453 .62053 .52668 .62437 .52551 .62245 .52337 Mtetra
.62245 .52337 .62437 .52551 .62822 .52435 .6263 .5222 Mtetra
.6263 .5222 .62822 .52435 .63208 .52319 .63016 .52103 Mtetra
.63016 .52103 .63208 .52319 .63594 .52202 .63403 .51986 Mtetra
.63403 .51986 .63594 .52202 .6398 .52085 .63789 .51869 Mtetra
.63789 .51869 .6398 .52085 .6483 .64995 .64177 .51752 Mtetra
.571 .368 .566 r
.64177 .51752 .6483 .64995 .65233 .64882 .64565 .51634 Mtetra
.374 .22 .54 r
.64565 .51634 .65233 .64882 .65385 .58127 .65192 .57914 Mtetra
.656 .751 .92 r
.65192 .57914 .65385 .58127 .65781 .58012 .65589 .57799 Mtetra
.65589 .57799 .65781 .58012 .66178 .57896 .65986 .57683 Mtetra
.65986 .57683 .66178 .57896 .66576 .57781 .66384 .57567 Mtetra
.66384 .57567 .66576 .57781 .66974 .57665 .66782 .57451 Mtetra
.66782 .57451 .66974 .57665 .67372 .57549 .67181 .57335 Mtetra
.67181 .57335 .67372 .57549 .67771 .57433 .6758 .57219 Mtetra
.6758 .57219 .67771 .57433 .68171 .57317 .6798 .57102 Mtetra
.6798 .57102 .68171 .57317 .68571 .57201 .68381 .56986 Mtetra
.68381 .56986 .68571 .57201 .68972 .57084 .68782 .56869 Mtetra
.68782 .56869 .68972 .57084 .69373 .56968 .69184 .56752 Mtetra
.69184 .56752 .69373 .56968 .69775 .56851 .69586 .56635 Mtetra
.69586 .56635 .69775 .56851 .70177 .56734 .69989 .56517 Mtetra
.69989 .56517 .70177 .56734 .7058 .56617 .70392 .564 Mtetra
.70392 .564 .7058 .56617 .70984 .56499 .70796 .56282 Mtetra
.70796 .56282 .70984 .56499 .71388 .56382 .71201 .56164 Mtetra
.71201 .56164 .71388 .56382 .71793 .56264 .71606 .56046 Mtetra
.71606 .56046 .71793 .56264 .72198 .56146 .72012 .55928 Mtetra
.72012 .55928 .72198 .56146 .72604 .56028 .72418 .5581 Mtetra
.72418 .5581 .72604 .56028 .7301 .5591 .72825 .55692 Mtetra
.72825 .55692 .7301 .5591 .73418 .55792 .73232 .55573 Mtetra
.73232 .55573 .73418 .55792 .73825 .55673 .7364 .55454 Mtetra
.95 .596 .246 r
.7364 .55454 .73825 .55673 .74397 .581 .74212 .57882 Mtetra
.654 .754 .923 r
.74212 .57882 .74397 .581 .74809 .57982 .74624 .57764 Mtetra
.74624 .57764 .74809 .57982 .75222 .57864 .75037 .57645 Mtetra
.75037 .57645 .75222 .57864 .75635 .57746 .75451 .57527 Mtetra
.75451 .57527 .75635 .57746 .76049 .57627 .75865 .57408 Mtetra
.75865 .57408 .76049 .57627 .76463 .57509 .7628 .57289 Mtetra
.7628 .57289 .76463 .57509 .76878 .5739 .76695 .5717 Mtetra
.76695 .5717 .76878 .5739 .77294 .57271 .77111 .57051 Mtetra
.77111 .57051 .77294 .57271 .7771 .57152 .77528 .56931 Mtetra
.77528 .56931 .7771 .57152 .78127 .57032 .77945 .56812 Mtetra
.77945 .56812 .78127 .57032 .78544 .56913 .78363 .56692 Mtetra
.929 .553 .163 r
.78363 .56692 .78544 .56913 .78962 .56793 .78942 .58646 Mtetra
.537 .288 .484 r
.78942 .58646 .78962 .56793 .79545 .58747 .79364 .58527 Mtetra
.652 .756 .926 r
.79364 .58527 .79545 .58747 .79967 .58628 .79786 .58407 Mtetra
.79786 .58407 .79967 .58628 .8039 .58508 .80209 .58287 Mtetra
.80209 .58287 .8039 .58508 .80813 .58389 .80633 .58168 Mtetra
.80633 .58168 .80813 .58389 .81237 .58269 .81057 .58048 Mtetra
.81057 .58048 .81237 .58269 .81661 .58149 .81482 .57927 Mtetra
.81482 .57927 .81661 .58149 .82086 .58029 .81907 .57807 Mtetra
.81907 .57807 .82086 .58029 .82512 .57909 .82333 .57686 Mtetra
.82333 .57686 .82512 .57909 .82938 .57788 .8276 .57566 Mtetra
.8276 .57566 .82938 .57788 .83365 .57668 .83187 .57445 Mtetra
.83187 .57445 .83365 .57668 .83792 .57547 .83615 .57324 Mtetra
.83615 .57324 .83792 .57547 .8422 .57426 .84044 .57202 Mtetra
.84044 .57202 .8422 .57426 .84649 .57305 .84473 .57081 Mtetra
.84473 .57081 .84649 .57305 .85079 .57184 .84903 .56959 Mtetra
.84903 .56959 .85079 .57184 .85509 .57062 .85334 .56837 Mtetra
.85334 .56837 .85509 .57062 .85939 .5694 .85765 .56715 Mtetra
.85765 .56715 .85939 .5694 .86371 .56819 .86196 .56593 Mtetra
.86196 .56593 .86371 .56819 .86803 .56696 .86629 .56471 Mtetra
.86629 .56471 .86803 .56696 .87235 .56574 .87062 .56348 Mtetra
.87062 .56348 .87235 .56574 .87668 .56452 .87496 .56225 Mtetra
.87496 .56225 .87668 .56452 .88102 .56329 .8793 .56103 Mtetra
.8793 .56103 .88102 .56329 .88537 .56207 .88365 .55979 Mtetra
.88365 .55979 .88537 .56207 .88972 .56084 .88801 .55856 Mtetra
.88801 .55856 .88972 .56084 .89408 .5596 .89237 .55733 Mtetra
.89237 .55733 .89408 .5596 .89844 .55837 .89674 .55609 Mtetra
.89674 .55609 .89844 .55837 .90281 .55714 .90111 .55485 Mtetra
.90111 .55485 .90281 .55714 .90719 .5559 .9055 .55361 Mtetra
.9055 .55361 .90719 .5559 .91158 .55466 .90988 .55237 Mtetra
.90988 .55237 .91158 .55466 .91597 .55342 .91428 .55113 Mtetra
.91428 .55113 .91597 .55342 .92036 .55218 .91868 .54988 Mtetra
.91868 .54988 .92036 .55218 .92477 .55093 .92309 .54863 Mtetra
.92309 .54863 .92477 .55093 .92918 .54969 .92751 .54738 Mtetra
.92751 .54738 .92918 .54969 .93359 .54844 .93193 .54613 Mtetra
.93193 .54613 .93359 .54844 .93802 .54719 .93636 .54488 Mtetra
.93636 .54488 .93802 .54719 .94245 .54594 .94079 .54362 Mtetra
.94079 .54362 .94245 .54594 .94688 .54469 .94523 .54237 Mtetra
.94523 .54237 .94688 .54469 .95133 .54343 .94968 .54111 Mtetra
.94968 .54111 .95133 .54343 .95578 .54217 .95414 .53985 Mtetra
.95414 .53985 .95578 .54217 .96024 .54091 .9586 .53858 Mtetra
.652 .755 .925 r
.35477 .70202 .35699 .70391 .3606 .70289 .35838 .70099 Mtetra
.35838 .70099 .3606 .70289 .36119 .76792 .36199 .69997 Mtetra
.574 .376 .575 r
.36199 .69997 .36119 .76792 .36487 .76692 .3656 .69894 Mtetra
.3656 .69894 .36487 .76692 .36856 .76592 .36922 .69791 Mtetra
.36922 .69791 .36856 .76592 .37224 .76492 .37285 .69688 Mtetra
.37285 .69688 .37224 .76492 .37594 .76392 .37648 .69585 Mtetra
.37648 .69585 .37594 .76392 .37964 .76291 .38011 .69481 Mtetra
.38011 .69481 .37964 .76291 .38334 .76191 .38375 .69378 Mtetra
0 0 .371 r
.38375 .69378 .38334 .76191 .38705 .7609 .38481 .75903 Mtetra
.646 .762 .934 r
.38481 .75903 .38705 .7609 .39076 .75989 .38852 .75802 Mtetra
.38852 .75802 .39076 .75989 .39448 .75888 .39225 .75701 Mtetra
.39225 .75701 .39448 .75888 .39821 .75787 .39597 .75599 Mtetra
.39597 .75599 .39821 .75787 .40194 .75685 .39971 .75498 Mtetra
.39971 .75498 .40194 .75685 .40567 .75584 .40344 .75396 Mtetra
.40344 .75396 .40567 .75584 .40941 .75482 .40719 .75294 Mtetra
.40719 .75294 .40941 .75482 .41315 .7538 .41094 .75192 Mtetra
.41094 .75192 .41315 .7538 .4169 .75279 .41469 .7509 Mtetra
.41469 .7509 .4169 .75279 .42066 .75177 .41845 .74988 Mtetra
.41845 .74988 .42066 .75177 .42442 .75074 .42221 .74885 Mtetra
.42221 .74885 .42442 .75074 .42819 .74972 .42598 .74783 Mtetra
.942 .696 .537 r
.42598 .74783 .42819 .74972 .43434 .65719 .4322 .65523 Mtetra
.655 .753 .922 r
.4322 .65523 .43434 .65719 .43802 .65613 .43588 .65416 Mtetra
.43588 .65416 .43802 .65613 .44171 .65506 .43957 .6531 Mtetra
.43957 .6531 .44171 .65506 .4454 .654 .44327 .65203 Mtetra
.44327 .65203 .4454 .654 .44909 .65293 .44696 .65096 Mtetra
.44696 .65096 .44909 .65293 .4528 .65186 .45067 .64989 Mtetra
.45067 .64989 .4528 .65186 .4565 .65079 .45438 .64882 Mtetra
.45438 .64882 .4565 .65079 .46021 .64972 .45809 .64774 Mtetra
.45809 .64774 .46021 .64972 .46393 .64865 .46181 .64667 Mtetra
.46181 .64667 .46393 .64865 .46765 .64758 .46554 .64559 Mtetra
.46554 .64559 .46765 .64758 .47138 .6465 .46927 .64451 Mtetra
.46927 .64451 .47138 .6465 .47511 .64543 .473 .64344 Mtetra
.473 .64344 .47511 .64543 .47885 .64435 .47674 .64235 Mtetra
.47674 .64235 .47885 .64435 .48259 .64327 .48049 .64127 Mtetra
.48049 .64127 .48259 .64327 .48634 .64219 .48424 .64019 Mtetra
.48424 .64019 .48634 .64219 .49009 .64111 .488 .6391 Mtetra
.488 .6391 .49009 .64111 .49385 .64002 .49176 .63802 Mtetra
.49176 .63802 .49385 .64002 .49761 .63894 .49552 .63693 Mtetra
.49552 .63693 .49761 .63894 .50138 .63785 .49929 .63584 Mtetra
.49929 .63584 .50138 .63785 .50515 .63676 .50307 .63475 Mtetra
.50307 .63475 .50515 .63676 .50893 .63567 .50685 .63365 Mtetra
.50685 .63365 .50893 .63567 .51271 .63458 .51064 .63256 Mtetra
.51064 .63256 .51271 .63458 .5165 .63349 .51443 .63146 Mtetra
.51443 .63146 .5165 .63349 .52027 .65249 .51823 .63037 Mtetra
.087 .047 .511 r
.51823 .63037 .52027 .65249 .52409 .6514 .52201 .64939 Mtetra
.653 .755 .925 r
.52201 .64939 .52409 .6514 .52792 .65031 .52584 .6483 Mtetra
.52584 .6483 .52792 .65031 .53175 .64922 .52968 .6472 Mtetra
.52968 .6472 .53175 .64922 .53559 .64813 .53352 .64611 Mtetra
.53352 .64611 .53559 .64813 .53943 .64704 .53737 .64501 Mtetra
.53737 .64501 .53943 .64704 .54328 .64594 .54122 .64391 Mtetra
.54122 .64391 .54328 .64594 .54713 .64484 .54508 .64281 Mtetra
.54508 .64281 .54713 .64484 .55099 .64374 .54894 .64171 Mtetra
.54894 .64171 .55099 .64374 .55485 .64264 .55281 .64061 Mtetra
.55281 .64061 .55485 .64264 .55872 .64154 .55668 .6395 Mtetra
.55668 .6395 .55872 .64154 .5626 .64044 .56056 .63839 Mtetra
.56056 .63839 .5626 .64044 .56648 .63933 .56444 .63729 Mtetra
.56444 .63729 .56648 .63933 .57036 .63822 .56833 .63618 Mtetra
.56833 .63618 .57036 .63822 .57426 .63712 .57223 .63506 Mtetra
.57223 .63506 .57426 .63712 .57815 .63601 .57613 .63395 Mtetra
.57613 .63395 .57815 .63601 .58205 .63489 .58003 .63284 Mtetra
.58003 .63284 .58205 .63489 .58596 .63378 .58394 .63172 Mtetra
.58394 .63172 .58596 .63378 .58988 .63267 .58786 .6306 Mtetra
.58786 .6306 .58988 .63267 .59379 .63155 .59178 .62949 Mtetra
.59178 .62949 .59379 .63155 .59772 .63043 .59571 .62836 Mtetra
.961 .7 .493 r
.59571 .62836 .59772 .63043 .60165 .62931 .5975 .52819 Mtetra
.572 .37 .569 r
.5975 .52819 .60165 .62931 .60327 .52917 .60132 .52703 Mtetra
.661 .745 .912 r
.60132 .52703 .60327 .52917 .60709 .52801 .60515 .52587 Mtetra
.60515 .52587 .60709 .52801 .61093 .52686 .60899 .52471 Mtetra
.60899 .52471 .61093 .52686 .61476 .52569 .61283 .52355 Mtetra
.61283 .52355 .61476 .52569 .6186 .52453 .61667 .52238 Mtetra
.61667 .52238 .6186 .52453 .62245 .52337 .62052 .52121 Mtetra
.62052 .52121 .62245 .52337 .6263 .5222 .62438 .52004 Mtetra
.62438 .52004 .6263 .5222 .63016 .52103 .62824 .51887 Mtetra
.62824 .51887 .63016 .52103 .63403 .51986 .63211 .5177 Mtetra
.63211 .5177 .63403 .51986 .63789 .51869 .63598 .51653 Mtetra
.63598 .51653 .63789 .51869 .64177 .51752 .63986 .51535 Mtetra
.63986 .51535 .64177 .51752 .64565 .51634 .64374 .51417 Mtetra
.64374 .51417 .64565 .51634 .65192 .57914 .64763 .51299 Mtetra
.082 .014 .473 r
.64763 .51299 .65192 .57914 .65589 .57799 .65396 .57585 Mtetra
.656 .751 .92 r
.65396 .57585 .65589 .57799 .65986 .57683 .65793 .57469 Mtetra
.65793 .57469 .65986 .57683 .66384 .57567 .66191 .57353 Mtetra
.66191 .57353 .66384 .57567 .66782 .57451 .6659 .57237 Mtetra
.6659 .57237 .66782 .57451 .67181 .57335 .66989 .5712 Mtetra
.66989 .5712 .67181 .57335 .6758 .57219 .67389 .57004 Mtetra
.67389 .57004 .6758 .57219 .6798 .57102 .67789 .56887 Mtetra
.67789 .56887 .6798 .57102 .68381 .56986 .6819 .5677 Mtetra
.6819 .5677 .68381 .56986 .68782 .56869 .68592 .56653 Mtetra
.68592 .56653 .68782 .56869 .69184 .56752 .68994 .56535 Mtetra
.68994 .56535 .69184 .56752 .69586 .56635 .69397 .56418 Mtetra
.69397 .56418 .69586 .56635 .69989 .56517 .698 .563 Mtetra
.698 .563 .69989 .56517 .70392 .564 .70204 .56183 Mtetra
.70204 .56183 .70392 .564 .70796 .56282 .70608 .56065 Mtetra
.70608 .56065 .70796 .56282 .71201 .56164 .71013 .55947 Mtetra
.71013 .55947 .71201 .56164 .71606 .56046 .71419 .55828 Mtetra
.71419 .55828 .71606 .56046 .72012 .55928 .71825 .5571 Mtetra
.71825 .5571 .72012 .55928 .72418 .5581 .72231 .55591 Mtetra
.72231 .55591 .72418 .5581 .72825 .55692 .72639 .55472 Mtetra
.72639 .55472 .72825 .55692 .73232 .55573 .73047 .55353 Mtetra
.73047 .55353 .73232 .55573 .7364 .55454 .73455 .55234 Mtetra
.73455 .55234 .7364 .55454 .74212 .57882 .73864 .55115 Mtetra
.17 .109 .541 r
.73864 .55115 .74212 .57882 .74624 .57764 .74438 .57545 Mtetra
.654 .754 .923 r
.74438 .57545 .74624 .57764 .75037 .57645 .74852 .57426 Mtetra
.74852 .57426 .75037 .57645 .75451 .57527 .75266 .57307 Mtetra
.75266 .57307 .75451 .57527 .75865 .57408 .7568 .57188 Mtetra
.7568 .57188 .75865 .57408 .7628 .57289 .76096 .57069 Mtetra
.76096 .57069 .7628 .57289 .76695 .5717 .76512 .5695 Mtetra
.76512 .5695 .76695 .5717 .77111 .57051 .76928 .5683 Mtetra
.76928 .5683 .77111 .57051 .77528 .56931 .77345 .5671 Mtetra
.77345 .5671 .77528 .56931 .77945 .56812 .77763 .5659 Mtetra
.77763 .5659 .77945 .56812 .78363 .56692 .78181 .5647 Mtetra
.929 .553 .163 r
.78181 .5647 .78363 .56692 .78942 .58646 .7876 .58426 Mtetra
.652 .756 .926 r
.7876 .58426 .78942 .58646 .79364 .58527 .79182 .58306 Mtetra
.79182 .58306 .79364 .58527 .79786 .58407 .79605 .58186 Mtetra
.79605 .58186 .79786 .58407 .80209 .58287 .80028 .58066 Mtetra
.80028 .58066 .80209 .58287 .80633 .58168 .80452 .57946 Mtetra
.80452 .57946 .80633 .58168 .81057 .58048 .80877 .57825 Mtetra
.80877 .57825 .81057 .58048 .81482 .57927 .81302 .57705 Mtetra
.81302 .57705 .81482 .57927 .81907 .57807 .81728 .57584 Mtetra
.81728 .57584 .81907 .57807 .82333 .57686 .82155 .57463 Mtetra
.82155 .57463 .82333 .57686 .8276 .57566 .82582 .57342 Mtetra
.82582 .57342 .8276 .57566 .83187 .57445 .83009 .57221 Mtetra
.83009 .57221 .83187 .57445 .83615 .57324 .83438 .57099 Mtetra
.83438 .57099 .83615 .57324 .84044 .57202 .83867 .56978 Mtetra
.83867 .56978 .84044 .57202 .84473 .57081 .84297 .56856 Mtetra
.84297 .56856 .84473 .57081 .84903 .56959 .84727 .56734 Mtetra
.84727 .56734 .84903 .56959 .85334 .56837 .85158 .56612 Mtetra
.85158 .56612 .85334 .56837 .85765 .56715 .85589 .5649 Mtetra
.85589 .5649 .85765 .56715 .86196 .56593 .86022 .56367 Mtetra
.86022 .56367 .86196 .56593 .86629 .56471 .86455 .56244 Mtetra
.86455 .56244 .86629 .56471 .87062 .56348 .86888 .56121 Mtetra
.86888 .56121 .87062 .56348 .87496 .56225 .87322 .55998 Mtetra
.87322 .55998 .87496 .56225 .8793 .56103 .87757 .55875 Mtetra
.87757 .55875 .8793 .56103 .88365 .55979 .88193 .55752 Mtetra
.88193 .55752 .88365 .55979 .88801 .55856 .88629 .55628 Mtetra
.88629 .55628 .88801 .55856 .89237 .55733 .89065 .55504 Mtetra
.89065 .55504 .89237 .55733 .89674 .55609 .89503 .5538 Mtetra
.89503 .5538 .89674 .55609 .90111 .55485 .89941 .55256 Mtetra
.89941 .55256 .90111 .55485 .9055 .55361 .9038 .55132 Mtetra
.9038 .55132 .9055 .55361 .90988 .55237 .90819 .55007 Mtetra
.90819 .55007 .90988 .55237 .91428 .55113 .91259 .54882 Mtetra
.91259 .54882 .91428 .55113 .91868 .54988 .917 .54758 Mtetra
.917 .54758 .91868 .54988 .92309 .54863 .92141 .54632 Mtetra
.92141 .54632 .92309 .54863 .92751 .54738 .92583 .54507 Mtetra
.92583 .54507 .92751 .54738 .93193 .54613 .93026 .54382 Mtetra
.93026 .54382 .93193 .54613 .93636 .54488 .93469 .54256 Mtetra
.93469 .54256 .93636 .54488 .94079 .54362 .93913 .5413 Mtetra
.93913 .5413 .94079 .54362 .94523 .54237 .94358 .54004 Mtetra
.94358 .54004 .94523 .54237 .94968 .54111 .94803 .53878 Mtetra
.94803 .53878 .94968 .54111 .95414 .53985 .95249 .53751 Mtetra
.95249 .53751 .95414 .53985 .9586 .53858 .95696 .53625 Mtetra
.652 .755 .925 r
.35254 .70012 .35477 .70202 .35838 .70099 .35615 .6991 Mtetra
.35615 .6991 .35838 .70099 .36199 .69997 .35976 .69807 Mtetra
.35976 .69807 .36199 .69997 .3656 .69894 .36338 .69704 Mtetra
.36338 .69704 .3656 .69894 .36922 .69791 .36701 .696 Mtetra
.36701 .696 .36922 .69791 .37285 .69688 .37063 .69497 Mtetra
.37063 .69497 .37285 .69688 .37648 .69585 .37427 .69394 Mtetra
.37427 .69394 .37648 .69585 .38011 .69481 .37791 .6929 Mtetra
.37791 .6929 .38011 .69481 .38375 .69378 .38155 .69186 Mtetra
.38155 .69186 .38375 .69378 .38481 .75903 .3852 .69082 Mtetra
.574 .375 .574 r
.3852 .69082 .38481 .75903 .38852 .75802 .38885 .68978 Mtetra
.38885 .68978 .38852 .75802 .39225 .75701 .39251 .68874 Mtetra
.39251 .68874 .39225 .75701 .39597 .75599 .39617 .6877 Mtetra
.39617 .6877 .39597 .75599 .39971 .75498 .39984 .68665 Mtetra
.39984 .68665 .39971 .75498 .40344 .75396 .40351 .6856 Mtetra
.40351 .6856 .40344 .75396 .40719 .75294 .40719 .68456 Mtetra
.40719 .68456 .40719 .75294 .41094 .75192 .41088 .68351 Mtetra
0 0 .383 r
.41088 .68351 .41094 .75192 .41469 .7509 .41247 .74901 Mtetra
.646 .762 .934 r
.41247 .74901 .41469 .7509 .41845 .74988 .41623 .74799 Mtetra
.41623 .74799 .41845 .74988 .42221 .74885 .42 .74696 Mtetra
.942 .696 .537 r
.42 .74696 .42221 .74885 .42598 .74783 .42637 .65433 Mtetra
.572 .371 .569 r
.42637 .65433 .42598 .74783 .4322 .65523 .43005 .65326 Mtetra
.655 .753 .922 r
.43005 .65326 .4322 .65523 .43588 .65416 .43374 .65219 Mtetra
.43374 .65219 .43588 .65416 .43957 .6531 .43743 .65112 Mtetra
.43743 .65112 .43957 .6531 .44327 .65203 .44113 .65005 Mtetra
.44113 .65005 .44327 .65203 .44696 .65096 .44483 .64898 Mtetra
.44483 .64898 .44696 .65096 .45067 .64989 .44854 .64791 Mtetra
.44854 .64791 .45067 .64989 .45438 .64882 .45225 .64683 Mtetra
.45225 .64683 .45438 .64882 .45809 .64774 .45597 .64576 Mtetra
.45597 .64576 .45809 .64774 .46181 .64667 .45969 .64468 Mtetra
.45969 .64468 .46181 .64667 .46554 .64559 .46342 .6436 Mtetra
.46342 .6436 .46554 .64559 .46927 .64451 .46715 .64252 Mtetra
.46715 .64252 .46927 .64451 .473 .64344 .47089 .64144 Mtetra
.47089 .64144 .473 .64344 .47674 .64235 .47464 .64035 Mtetra
.47464 .64035 .47674 .64235 .48049 .64127 .47838 .63927 Mtetra
.47838 .63927 .48049 .64127 .48424 .64019 .48214 .63818 Mtetra
.48214 .63818 .48424 .64019 .488 .6391 .4859 .6371 Mtetra
.4859 .6371 .488 .6391 .49176 .63802 .48966 .63601 Mtetra
.48966 .63601 .49176 .63802 .49552 .63693 .49343 .63491 Mtetra
.49343 .63491 .49552 .63693 .49929 .63584 .49721 .63382 Mtetra
.49721 .63382 .49929 .63584 .50307 .63475 .50098 .63273 Mtetra
.50098 .63273 .50307 .63475 .50685 .63365 .50477 .63163 Mtetra
.50477 .63163 .50685 .63365 .51064 .63256 .50856 .63054 Mtetra
.50856 .63054 .51064 .63256 .51443 .63146 .51236 .62944 Mtetra
.51236 .62944 .51443 .63146 .51823 .63037 .51616 .62834 Mtetra
.95 .611 .336 r
.51616 .62834 .51823 .63037 .52201 .64939 .51993 .64737 Mtetra
.653 .755 .925 r
.51993 .64737 .52201 .64939 .52584 .6483 .52377 .64628 Mtetra
.52377 .64628 .52584 .6483 .52968 .6472 .52761 .64518 Mtetra
.52761 .64518 .52968 .6472 .53352 .64611 .53145 .64408 Mtetra
.53145 .64408 .53352 .64611 .53737 .64501 .5353 .64298 Mtetra
.5353 .64298 .53737 .64501 .54122 .64391 .53916 .64188 Mtetra
.53916 .64188 .54122 .64391 .54508 .64281 .54302 .64078 Mtetra
.54302 .64078 .54508 .64281 .54894 .64171 .54688 .63967 Mtetra
.54688 .63967 .54894 .64171 .55281 .64061 .55075 .63856 Mtetra
.55075 .63856 .55281 .64061 .55668 .6395 .55463 .63746 Mtetra
.55463 .63746 .55668 .6395 .56056 .63839 .55851 .63635 Mtetra
.55851 .63635 .56056 .63839 .56444 .63729 .5624 .63524 Mtetra
.5624 .63524 .56444 .63729 .56833 .63618 .56629 .63412 Mtetra
.56629 .63412 .56833 .63618 .57223 .63506 .57019 .63301 Mtetra
.57019 .63301 .57223 .63506 .57613 .63395 .5741 .63189 Mtetra
.5741 .63189 .57613 .63395 .58003 .63284 .57801 .63078 Mtetra
.57801 .63078 .58003 .63284 .58394 .63172 .58192 .62966 Mtetra
.58192 .62966 .58394 .63172 .58786 .6306 .58584 .62854 Mtetra
.58584 .62854 .58786 .6306 .59178 .62949 .58977 .62741 Mtetra
.961 .7 .494 r
.58977 .62741 .59178 .62949 .59571 .62836 .59172 .52721 Mtetra
.572 .37 .568 r
.59172 .52721 .59571 .62836 .5975 .52819 .59554 .52605 Mtetra
.661 .745 .912 r
.59554 .52605 .5975 .52819 .60132 .52703 .59937 .52489 Mtetra
.59937 .52489 .60132 .52703 .60515 .52587 .60321 .52372 Mtetra
.60321 .52372 .60515 .52587 .60899 .52471 .60704 .52256 Mtetra
.60704 .52256 .60899 .52471 .61283 .52355 .61089 .52139 Mtetra
.61089 .52139 .61283 .52355 .61667 .52238 .61474 .52022 Mtetra
.61474 .52022 .61667 .52238 .62052 .52121 .61859 .51905 Mtetra
.61859 .51905 .62052 .52121 .62438 .52004 .62245 .51788 Mtetra
.62245 .51788 .62438 .52004 .62824 .51887 .62632 .51671 Mtetra
.62632 .51671 .62824 .51887 .63211 .5177 .63019 .51553 Mtetra
.63019 .51553 .63211 .5177 .63598 .51653 .63406 .51435 Mtetra
.63406 .51435 .63598 .51653 .63986 .51535 .63794 .51318 Mtetra
.63794 .51318 .63986 .51535 .64374 .51417 .64183 .512 Mtetra
.64183 .512 .64374 .51417 .64763 .51299 .64572 .51081 Mtetra
.64572 .51081 .64763 .51299 .65396 .57585 .64962 .50963 Mtetra
.082 .014 .473 r
.64962 .50963 .65396 .57585 .65793 .57469 .656 .57255 Mtetra
.656 .751 .92 r
.656 .57255 .65793 .57469 .66191 .57353 .65998 .57138 Mtetra
.65998 .57138 .66191 .57353 .6659 .57237 .66397 .57022 Mtetra
.66397 .57022 .6659 .57237 .66989 .5712 .66797 .56905 Mtetra
.66797 .56905 .66989 .5712 .67389 .57004 .67197 .56788 Mtetra
.67197 .56788 .67389 .57004 .67789 .56887 .67598 .56671 Mtetra
.67598 .56671 .67789 .56887 .6819 .5677 .67999 .56554 Mtetra
.67999 .56554 .6819 .5677 .68592 .56653 .68401 .56436 Mtetra
.68401 .56436 .68592 .56653 .68994 .56535 .68804 .56319 Mtetra
.68804 .56319 .68994 .56535 .69397 .56418 .69207 .56201 Mtetra
.69207 .56201 .69397 .56418 .698 .563 .6961 .56083 Mtetra
.6961 .56083 .698 .563 .70204 .56183 .70015 .55965 Mtetra
.70015 .55965 .70204 .56183 .70608 .56065 .70419 .55846 Mtetra
.70419 .55846 .70608 .56065 .71013 .55947 .70825 .55728 Mtetra
.70825 .55728 .71013 .55947 .71419 .55828 .71231 .55609 Mtetra
.71231 .55609 .71419 .55828 .71825 .5571 .71637 .55491 Mtetra
.71637 .55491 .71825 .5571 .72231 .55591 .72044 .55372 Mtetra
.72044 .55372 .72231 .55591 .72639 .55472 .72452 .55253 Mtetra
.72452 .55253 .72639 .55472 .73047 .55353 .7286 .55133 Mtetra
.7286 .55133 .73047 .55353 .73455 .55234 .73269 .55014 Mtetra
.73269 .55014 .73455 .55234 .73864 .55115 .73679 .54894 Mtetra
.95 .595 .243 r
.73679 .54894 .73864 .55115 .74438 .57545 .74252 .57326 Mtetra
.654 .754 .923 r
.74252 .57326 .74438 .57545 .74852 .57426 .74666 .57207 Mtetra
.74666 .57207 .74852 .57426 .75266 .57307 .7508 .57087 Mtetra
.7508 .57087 .75266 .57307 .7568 .57188 .75496 .56968 Mtetra
.75496 .56968 .7568 .57188 .76096 .57069 .75911 .56849 Mtetra
.75911 .56849 .76096 .57069 .76512 .5695 .76327 .56729 Mtetra
.76327 .56729 .76512 .5695 .76928 .5683 .76744 .56609 Mtetra
.76744 .56609 .76928 .5683 .77345 .5671 .77162 .56489 Mtetra
.77162 .56489 .77345 .5671 .77763 .5659 .7758 .56369 Mtetra
.7758 .56369 .77763 .5659 .78181 .5647 .77999 .56248 Mtetra
.929 .553 .163 r
.77999 .56248 .78181 .5647 .7876 .58426 .78577 .58204 Mtetra
.652 .756 .926 r
.78577 .58204 .7876 .58426 .79182 .58306 .79 .58084 Mtetra
.79 .58084 .79182 .58306 .79605 .58186 .79423 .57964 Mtetra
.79423 .57964 .79605 .58186 .80028 .58066 .79847 .57844 Mtetra
.79847 .57844 .80028 .58066 .80452 .57946 .80271 .57723 Mtetra
.80271 .57723 .80452 .57946 .80877 .57825 .80696 .57603 Mtetra
.80696 .57603 .80877 .57825 .81302 .57705 .81122 .57482 Mtetra
.81122 .57482 .81302 .57705 .81728 .57584 .81548 .57361 Mtetra
.81548 .57361 .81728 .57584 .82155 .57463 .81975 .5724 Mtetra
.81975 .5724 .82155 .57463 .82582 .57342 .82403 .57118 Mtetra
.82403 .57118 .82582 .57342 .83009 .57221 .82831 .56997 Mtetra
.82831 .56997 .83009 .57221 .83438 .57099 .8326 .56875 Mtetra
.8326 .56875 .83438 .57099 .83867 .56978 .83689 .56753 Mtetra
.83689 .56753 .83867 .56978 .84297 .56856 .8412 .56631 Mtetra
.8412 .56631 .84297 .56856 .84727 .56734 .8455 .56508 Mtetra
.8455 .56508 .84727 .56734 .85158 .56612 .84982 .56386 Mtetra
.84982 .56386 .85158 .56612 .85589 .5649 .85414 .56263 Mtetra
.85414 .56263 .85589 .5649 .86022 .56367 .85847 .5614 Mtetra
.85847 .5614 .86022 .56367 .86455 .56244 .8628 .56017 Mtetra
.8628 .56017 .86455 .56244 .86888 .56121 .86714 .55894 Mtetra
.86714 .55894 .86888 .56121 .87322 .55998 .87148 .55771 Mtetra
.87148 .55771 .87322 .55998 .87757 .55875 .87584 .55647 Mtetra
.87584 .55647 .87757 .55875 .88193 .55752 .8802 .55523 Mtetra
.8802 .55523 .88193 .55752 .88629 .55628 .88456 .55399 Mtetra
.88456 .55399 .88629 .55628 .89065 .55504 .88893 .55275 Mtetra
.88893 .55275 .89065 .55504 .89503 .5538 .89331 .55151 Mtetra
.89331 .55151 .89503 .5538 .89941 .55256 .8977 .55026 Mtetra
.8977 .55026 .89941 .55256 .9038 .55132 .90209 .54902 Mtetra
.90209 .54902 .9038 .55132 .90819 .55007 .90649 .54777 Mtetra
.90649 .54777 .90819 .55007 .91259 .54882 .91089 .54652 Mtetra
.91089 .54652 .91259 .54882 .917 .54758 .91531 .54526 Mtetra
.91531 .54526 .917 .54758 .92141 .54632 .91972 .54401 Mtetra
.91972 .54401 .92141 .54632 .92583 .54507 .92415 .54275 Mtetra
.92415 .54275 .92583 .54507 .93026 .54382 .92858 .5415 Mtetra
.92858 .5415 .93026 .54382 .93469 .54256 .93302 .54024 Mtetra
.93302 .54024 .93469 .54256 .93913 .5413 .93746 .53897 Mtetra
.93746 .53897 .93913 .5413 .94358 .54004 .94192 .53771 Mtetra
.94192 .53771 .94358 .54004 .94803 .53878 .94637 .53644 Mtetra
.94637 .53644 .94803 .53878 .95249 .53751 .95084 .53518 Mtetra
.95084 .53518 .95249 .53751 .95696 .53625 .95531 .53391 Mtetra
.652 .755 .925 r
.35031 .69823 .35254 .70012 .35615 .6991 .35392 .6972 Mtetra
.35392 .6972 .35615 .6991 .35976 .69807 .35754 .69616 Mtetra
.35754 .69616 .35976 .69807 .36338 .69704 .36116 .69513 Mtetra
.36116 .69513 .36338 .69704 .36701 .696 .36478 .6941 Mtetra
.36478 .6941 .36701 .696 .37063 .69497 .36842 .69306 Mtetra
.36842 .69306 .37063 .69497 .37427 .69394 .37205 .69202 Mtetra
.37205 .69202 .37427 .69394 .37791 .6929 .37569 .69098 Mtetra
.37569 .69098 .37791 .6929 .38155 .69186 .37934 .68994 Mtetra
.37934 .68994 .38155 .69186 .3852 .69082 .38299 .6889 Mtetra
.38299 .6889 .3852 .69082 .38885 .68978 .38665 .68786 Mtetra
.38665 .68786 .38885 .68978 .39251 .68874 .39031 .68681 Mtetra
.39031 .68681 .39251 .68874 .39617 .6877 .39397 .68577 Mtetra
.39397 .68577 .39617 .6877 .39984 .68665 .39765 .68472 Mtetra
.39765 .68472 .39984 .68665 .40351 .6856 .40132 .68367 Mtetra
.40132 .68367 .40351 .6856 .40719 .68456 .405 .68262 Mtetra
.405 .68262 .40719 .68456 .41088 .68351 .40869 .68157 Mtetra
.40869 .68157 .41088 .68351 .41247 .74901 .41238 .68051 Mtetra
.574 .375 .574 r
.41238 .68051 .41247 .74901 .41623 .74799 .41608 .67946 Mtetra
.41608 .67946 .41623 .74799 .42 .74696 .41978 .6784 Mtetra
.669 .452 .581 r
.41978 .6784 .42 .74696 .42637 .65433 .42421 .65236 Mtetra
.655 .753 .922 r
.42421 .65236 .42637 .65433 .43005 .65326 .4279 .65129 Mtetra
.4279 .65129 .43005 .65326 .43374 .65219 .43159 .65022 Mtetra
.43159 .65022 .43374 .65219 .43743 .65112 .43528 .64915 Mtetra
.43528 .64915 .43743 .65112 .44113 .65005 .43898 .64807 Mtetra
.43898 .64807 .44113 .65005 .44483 .64898 .44269 .647 Mtetra
.44269 .647 .44483 .64898 .44854 .64791 .4464 .64592 Mtetra
.4464 .64592 .44854 .64791 .45225 .64683 .45012 .64485 Mtetra
.45012 .64485 .45225 .64683 .45597 .64576 .45384 .64377 Mtetra
.45384 .64377 .45597 .64576 .45969 .64468 .45756 .64269 Mtetra
.45756 .64269 .45969 .64468 .46342 .6436 .4613 .64161 Mtetra
.4613 .64161 .46342 .6436 .46715 .64252 .46503 .64052 Mtetra
.46503 .64052 .46715 .64252 .47089 .64144 .46877 .63944 Mtetra
.46877 .63944 .47089 .64144 .47464 .64035 .47252 .63835 Mtetra
.47252 .63835 .47464 .64035 .47838 .63927 .47627 .63726 Mtetra
.47627 .63726 .47838 .63927 .48214 .63818 .48003 .63617 Mtetra
.48003 .63617 .48214 .63818 .4859 .6371 .48379 .63508 Mtetra
.48379 .63508 .4859 .6371 .48966 .63601 .48756 .63399 Mtetra
.48756 .63399 .48966 .63601 .49343 .63491 .49133 .6329 Mtetra
.49133 .6329 .49343 .63491 .49721 .63382 .49511 .6318 Mtetra
.49511 .6318 .49721 .63382 .50098 .63273 .49889 .6307 Mtetra
.49889 .6307 .50098 .63273 .50477 .63163 .50268 .62961 Mtetra
.50268 .62961 .50477 .63163 .50856 .63054 .50648 .62851 Mtetra
.50648 .62851 .50856 .63054 .51236 .62944 .51028 .6274 Mtetra
.51028 .6274 .51236 .62944 .51616 .62834 .51408 .6263 Mtetra
.51408 .6263 .51616 .62834 .51993 .64737 .51789 .6252 Mtetra
.085 .045 .51 r
.51789 .6252 .51993 .64737 .52377 .64628 .52169 .64425 Mtetra
.653 .755 .925 r
.52169 .64425 .52377 .64628 .52761 .64518 .52553 .64315 Mtetra
.52553 .64315 .52761 .64518 .53145 .64408 .52938 .64205 Mtetra
.52938 .64205 .53145 .64408 .5353 .64298 .53323 .64095 Mtetra
.53323 .64095 .5353 .64298 .53916 .64188 .53709 .63984 Mtetra
.53709 .63984 .53916 .64188 .54302 .64078 .54095 .63873 Mtetra
.54095 .63873 .54302 .64078 .54688 .63967 .54482 .63763 Mtetra
.54482 .63763 .54688 .63967 .55075 .63856 .5487 .63652 Mtetra
.5487 .63652 .55075 .63856 .55463 .63746 .55258 .63541 Mtetra
.55258 .63541 .55463 .63746 .55851 .63635 .55646 .63429 Mtetra
.55646 .63429 .55851 .63635 .5624 .63524 .56035 .63318 Mtetra
.56035 .63318 .5624 .63524 .56629 .63412 .56425 .63207 Mtetra
.56425 .63207 .56629 .63412 .57019 .63301 .56815 .63095 Mtetra
.56815 .63095 .57019 .63301 .5741 .63189 .57206 .62983 Mtetra
.57206 .62983 .5741 .63189 .57801 .63078 .57597 .62871 Mtetra
.57597 .62871 .57801 .63078 .58192 .62966 .57989 .62759 Mtetra
.57989 .62759 .58192 .62966 .58584 .62854 .58382 .62646 Mtetra
.96 .7 .495 r
.58382 .62646 .58584 .62854 .58977 .62741 .58594 .52623 Mtetra
.571 .369 .568 r
.58594 .52623 .58977 .62741 .59172 .52721 .58976 .52507 Mtetra
.661 .745 .912 r
.58976 .52507 .59172 .52721 .59554 .52605 .59359 .5239 Mtetra
.59359 .5239 .59554 .52605 .59937 .52489 .59742 .52274 Mtetra
.59742 .52274 .59937 .52489 .60321 .52372 .60125 .52157 Mtetra
.60125 .52157 .60321 .52372 .60704 .52256 .6051 .5204 Mtetra
.6051 .5204 .60704 .52256 .61089 .52139 .60894 .51923 Mtetra
.60894 .51923 .61089 .52139 .61474 .52022 .6128 .51806 Mtetra
.6128 .51806 .61474 .52022 .61859 .51905 .61665 .51689 Mtetra
.61665 .51689 .61859 .51905 .62245 .51788 .62052 .51571 Mtetra
.62052 .51571 .62245 .51788 .62632 .51671 .62439 .51454 Mtetra
.62439 .51454 .62632 .51671 .63019 .51553 .62826 .51336 Mtetra
.62826 .51336 .63019 .51553 .63406 .51435 .63214 .51218 Mtetra
.63214 .51218 .63406 .51435 .63794 .51318 .63602 .511 Mtetra
.63602 .511 .63794 .51318 .64183 .512 .63991 .50981 Mtetra
.63991 .50981 .64183 .512 .64572 .51081 .64381 .50863 Mtetra
.64381 .50863 .64572 .51081 .64962 .50963 .64771 .50744 Mtetra
.64771 .50744 .64962 .50963 .656 .57255 .65162 .50625 Mtetra
.574 .376 .575 r
.65162 .50625 .656 .57255 .65998 .57138 .65553 .50506 Mtetra
.084 .016 .474 r
.65553 .50506 .65998 .57138 .66397 .57022 .66204 .56806 Mtetra
.656 .751 .92 r
.66204 .56806 .66397 .57022 .66797 .56905 .66604 .56689 Mtetra
.66604 .56689 .66797 .56905 .67197 .56788 .67005 .56572 Mtetra
.67005 .56572 .67197 .56788 .67598 .56671 .67406 .56454 Mtetra
.67406 .56454 .67598 .56671 .67999 .56554 .67808 .56337 Mtetra
.67808 .56337 .67999 .56554 .68401 .56436 .6821 .56219 Mtetra
.6821 .56219 .68401 .56436 .68804 .56319 .68613 .56101 Mtetra
.68613 .56101 .68804 .56319 .69207 .56201 .69016 .55983 Mtetra
.69016 .55983 .69207 .56201 .6961 .56083 .69421 .55865 Mtetra
.69421 .55865 .6961 .56083 .70015 .55965 .69825 .55746 Mtetra
.69825 .55746 .70015 .55965 .70419 .55846 .7023 .55628 Mtetra
.7023 .55628 .70419 .55846 .70825 .55728 .70636 .55509 Mtetra
.70636 .55509 .70825 .55728 .71231 .55609 .71042 .5539 Mtetra
.71042 .5539 .71231 .55609 .71637 .55491 .71449 .55271 Mtetra
.71449 .55271 .71637 .55491 .72044 .55372 .71857 .55152 Mtetra
.71857 .55152 .72044 .55372 .72452 .55253 .72265 .55032 Mtetra
.72265 .55032 .72452 .55253 .7286 .55133 .72674 .54913 Mtetra
.72674 .54913 .7286 .55133 .73269 .55014 .73083 .54793 Mtetra
.73083 .54793 .73269 .55014 .73679 .54894 .73493 .54673 Mtetra
.95 .595 .243 r
.73493 .54673 .73679 .54894 .74252 .57326 .74066 .57106 Mtetra
.654 .754 .923 r
.74066 .57106 .74252 .57326 .74666 .57207 .7448 .56986 Mtetra
.7448 .56986 .74666 .57207 .7508 .57087 .74895 .56867 Mtetra
.74895 .56867 .7508 .57087 .75496 .56968 .7531 .56747 Mtetra
.7531 .56747 .75496 .56968 .75911 .56849 .75726 .56627 Mtetra
.75726 .56627 .75911 .56849 .76327 .56729 .76143 .56507 Mtetra
.76143 .56507 .76327 .56729 .76744 .56609 .7656 .56387 Mtetra
.7656 .56387 .76744 .56609 .77162 .56489 .76978 .56267 Mtetra
.76978 .56267 .77162 .56489 .7758 .56369 .77397 .56146 Mtetra
.93 .555 .166 r
.77397 .56146 .7758 .56369 .77999 .56248 .77971 .58103 Mtetra
.536 .285 .482 r
.77971 .58103 .77999 .56248 .78577 .58204 .78394 .57983 Mtetra
.652 .756 .926 r
.78394 .57983 .78577 .58204 .79 .58084 .78817 .57862 Mtetra
.78817 .57862 .79 .58084 .79423 .57964 .7924 .57742 Mtetra
.7924 .57742 .79423 .57964 .79847 .57844 .79665 .57621 Mtetra
.79665 .57621 .79847 .57844 .80271 .57723 .8009 .575 Mtetra
.8009 .575 .80271 .57723 .80696 .57603 .80515 .57379 Mtetra
.80515 .57379 .80696 .57603 .81122 .57482 .80941 .57258 Mtetra
.80941 .57258 .81122 .57482 .81548 .57361 .81368 .57137 Mtetra
.81368 .57137 .81548 .57361 .81975 .5724 .81795 .57015 Mtetra
.81795 .57015 .81975 .5724 .82403 .57118 .82224 .56894 Mtetra
.82224 .56894 .82403 .57118 .82831 .56997 .82652 .56772 Mtetra
.82652 .56772 .82831 .56997 .8326 .56875 .83082 .56649 Mtetra
.83082 .56649 .8326 .56875 .83689 .56753 .83511 .56527 Mtetra
.83511 .56527 .83689 .56753 .8412 .56631 .83942 .56405 Mtetra
.83942 .56405 .8412 .56631 .8455 .56508 .84373 .56282 Mtetra
.84373 .56282 .8455 .56508 .84982 .56386 .84805 .56159 Mtetra
.84805 .56159 .84982 .56386 .85414 .56263 .85238 .56036 Mtetra
.85238 .56036 .85414 .56263 .85847 .5614 .85671 .55913 Mtetra
.85671 .55913 .85847 .5614 .8628 .56017 .86105 .5579 Mtetra
.86105 .5579 .8628 .56017 .86714 .55894 .86539 .55666 Mtetra
.86539 .55666 .86714 .55894 .87148 .55771 .86974 .55542 Mtetra
.86974 .55542 .87148 .55771 .87584 .55647 .8741 .55418 Mtetra
.8741 .55418 .87584 .55647 .8802 .55523 .87846 .55294 Mtetra
.87846 .55294 .8802 .55523 .88456 .55399 .88283 .5517 Mtetra
.88283 .5517 .88456 .55399 .88893 .55275 .88721 .55046 Mtetra
.88721 .55046 .88893 .55275 .89331 .55151 .89159 .54921 Mtetra
.89159 .54921 .89331 .55151 .8977 .55026 .89598 .54796 Mtetra
.89598 .54796 .8977 .55026 .90209 .54902 .90038 .54671 Mtetra
.90038 .54671 .90209 .54902 .90649 .54777 .90478 .54546 Mtetra
.90478 .54546 .90649 .54777 .91089 .54652 .90919 .5442 Mtetra
.90919 .5442 .91089 .54652 .91531 .54526 .91361 .54295 Mtetra
.91361 .54295 .91531 .54526 .91972 .54401 .91803 .54169 Mtetra
.91803 .54169 .91972 .54401 .92415 .54275 .92246 .54043 Mtetra
.92246 .54043 .92415 .54275 .92858 .5415 .9269 .53917 Mtetra
.9269 .53917 .92858 .5415 .93302 .54024 .93134 .5379 Mtetra
.93134 .5379 .93302 .54024 .93746 .53897 .93579 .53664 Mtetra
.93579 .53664 .93746 .53897 .94192 .53771 .94025 .53537 Mtetra
.94025 .53537 .94192 .53771 .94637 .53644 .94471 .5341 Mtetra
.94471 .5341 .94637 .53644 .95084 .53518 .94918 .53283 Mtetra
.94918 .53283 .95084 .53518 .95531 .53391 .95366 .53156 Mtetra
.652 .755 .925 r
.34807 .69632 .35031 .69823 .35392 .6972 .35168 .69529 Mtetra
.35168 .69529 .35392 .6972 .35754 .69616 .3553 .69425 Mtetra
.3553 .69425 .35754 .69616 .36116 .69513 .35893 .69322 Mtetra
.35893 .69322 .36116 .69513 .36478 .6941 .36256 .69218 Mtetra
.36256 .69218 .36478 .6941 .36842 .69306 .36619 .69114 Mtetra
.36619 .69114 .36842 .69306 .37205 .69202 .36983 .6901 Mtetra
.36983 .6901 .37205 .69202 .37569 .69098 .37347 .68906 Mtetra
.37347 .68906 .37569 .69098 .37934 .68994 .37712 .68802 Mtetra
.37712 .68802 .37934 .68994 .38299 .6889 .38078 .68697 Mtetra
.38078 .68697 .38299 .6889 .38665 .68786 .38444 .68593 Mtetra
.38444 .68593 .38665 .68786 .39031 .68681 .3881 .68488 Mtetra
.3881 .68488 .39031 .68681 .39397 .68577 .39177 .68383 Mtetra
.39177 .68383 .39397 .68577 .39765 .68472 .39545 .68278 Mtetra
.39545 .68278 .39765 .68472 .40132 .68367 .39912 .68173 Mtetra
.39912 .68173 .40132 .68367 .405 .68262 .40281 .68068 Mtetra
.40281 .68068 .405 .68262 .40869 .68157 .4065 .67962 Mtetra
.4065 .67962 .40869 .68157 .41238 .68051 .41019 .67857 Mtetra
.41019 .67857 .41238 .68051 .41608 .67946 .41389 .67751 Mtetra
.41389 .67751 .41608 .67946 .41978 .6784 .4176 .67645 Mtetra
.932 .717 .59 r
.4176 .67645 .41978 .6784 .42421 .65236 .42205 .65038 Mtetra
.655 .753 .922 r
.42205 .65038 .42421 .65236 .4279 .65129 .42574 .64931 Mtetra
.42574 .64931 .4279 .65129 .43159 .65022 .42943 .64824 Mtetra
.42943 .64824 .43159 .65022 .43528 .64915 .43313 .64716 Mtetra
.43313 .64716 .43528 .64915 .43898 .64807 .43683 .64609 Mtetra
.43683 .64609 .43898 .64807 .44269 .647 .44054 .64501 Mtetra
.44054 .64501 .44269 .647 .4464 .64592 .44426 .64393 Mtetra
.44426 .64393 .4464 .64592 .45012 .64485 .44798 .64285 Mtetra
.44798 .64285 .45012 .64485 .45384 .64377 .4517 .64177 Mtetra
.4517 .64177 .45384 .64377 .45756 .64269 .45543 .64069 Mtetra
.45543 .64069 .45756 .64269 .4613 .64161 .45917 .6396 Mtetra
.45917 .6396 .4613 .64161 .46503 .64052 .46291 .63852 Mtetra
.46291 .63852 .46503 .64052 .46877 .63944 .46665 .63743 Mtetra
.46665 .63743 .46877 .63944 .47252 .63835 .4704 .63634 Mtetra
.4704 .63634 .47252 .63835 .47627 .63726 .47416 .63525 Mtetra
.47416 .63525 .47627 .63726 .48003 .63617 .47792 .63416 Mtetra
.47792 .63416 .48003 .63617 .48379 .63508 .48168 .63306 Mtetra
.48168 .63306 .48379 .63508 .48756 .63399 .48545 .63197 Mtetra
.48545 .63197 .48756 .63399 .49133 .6329 .48923 .63087 Mtetra
.48923 .63087 .49133 .6329 .49511 .6318 .49301 .62977 Mtetra
.49301 .62977 .49511 .6318 .49889 .6307 .4968 .62868 Mtetra
.4968 .62868 .49889 .6307 .50268 .62961 .50059 .62757 Mtetra
.50059 .62757 .50268 .62961 .50648 .62851 .50439 .62647 Mtetra
.50439 .62647 .50648 .62851 .51028 .6274 .50819 .62537 Mtetra
.50819 .62537 .51028 .6274 .51408 .6263 .512 .62426 Mtetra
.512 .62426 .51408 .6263 .51789 .6252 .51581 .62315 Mtetra
.953 .699 .516 r
.51581 .62315 .51789 .6252 .52169 .64425 .51976 .5341 Mtetra
0 0 .411 r
.51976 .5341 .52169 .64425 .52553 .64315 .52344 .64112 Mtetra
.653 .755 .925 r
.52344 .64112 .52553 .64315 .52938 .64205 .52729 .64001 Mtetra
.52729 .64001 .52938 .64205 .53323 .64095 .53115 .63891 Mtetra
.53115 .63891 .53323 .64095 .53709 .63984 .53501 .6378 Mtetra
.53501 .6378 .53709 .63984 .54095 .63873 .53888 .63669 Mtetra
.53888 .63669 .54095 .63873 .54482 .63763 .54275 .63558 Mtetra
.54275 .63558 .54482 .63763 .5487 .63652 .54663 .63447 Mtetra
.54663 .63447 .5487 .63652 .55258 .63541 .55052 .63335 Mtetra
.55052 .63335 .55258 .63541 .55646 .63429 .55441 .63224 Mtetra
.55441 .63224 .55646 .63429 .56035 .63318 .5583 .63112 Mtetra
.5583 .63112 .56035 .63318 .56425 .63207 .5622 .63 Mtetra
.5622 .63 .56425 .63207 .56815 .63095 .56611 .62888 Mtetra
.56611 .62888 .56815 .63095 .57206 .62983 .57002 .62776 Mtetra
.57002 .62776 .57206 .62983 .57597 .62871 .57394 .62664 Mtetra
.57394 .62664 .57597 .62871 .57989 .62759 .57786 .62551 Mtetra
.96 .699 .497 r
.57786 .62551 .57989 .62759 .58382 .62646 .58015 .52525 Mtetra
.571 .369 .568 r
.58015 .52525 .58382 .62646 .58594 .52623 .58397 .52408 Mtetra
.661 .745 .912 r
.58397 .52408 .58594 .52623 .58976 .52507 .58779 .52292 Mtetra
.58779 .52292 .58976 .52507 .59359 .5239 .59162 .52175 Mtetra
.59162 .52175 .59359 .5239 .59742 .52274 .59546 .52058 Mtetra
.59546 .52058 .59742 .52274 .60125 .52157 .5993 .51941 Mtetra
.5993 .51941 .60125 .52157 .6051 .5204 .60314 .51824 Mtetra
.60314 .51824 .6051 .5204 .60894 .51923 .60699 .51707 Mtetra
.60699 .51707 .60894 .51923 .6128 .51806 .61085 .51589 Mtetra
.61085 .51589 .6128 .51806 .61665 .51689 .61471 .51472 Mtetra
.61471 .51472 .61665 .51689 .62052 .51571 .61858 .51354 Mtetra
.61858 .51354 .62052 .51571 .62439 .51454 .62245 .51236 Mtetra
.62245 .51236 .62439 .51454 .62826 .51336 .62633 .51118 Mtetra
.62633 .51118 .62826 .51336 .63214 .51218 .63021 .50999 Mtetra
.63021 .50999 .63214 .51218 .63602 .511 .6341 .50881 Mtetra
.6341 .50881 .63602 .511 .63991 .50981 .63799 .50762 Mtetra
.63799 .50762 .63991 .50981 .64381 .50863 .64189 .50643 Mtetra
.64189 .50643 .64381 .50863 .64771 .50744 .6458 .50525 Mtetra
.6458 .50525 .64771 .50744 .65162 .50625 .64971 .50405 Mtetra
.64971 .50405 .65162 .50625 .65553 .50506 .65362 .50286 Mtetra
.65362 .50286 .65553 .50506 .66204 .56806 .65754 .50167 Mtetra
.574 .375 .574 r
.65754 .50167 .66204 .56806 .66604 .56689 .66147 .50047 Mtetra
.66147 .50047 .66604 .56689 .67005 .56572 .6654 .49927 Mtetra
.6654 .49927 .67005 .56572 .67406 .56454 .66934 .49807 Mtetra
.66934 .49807 .67406 .56454 .67808 .56337 .67328 .49687 Mtetra
.67328 .49687 .67808 .56337 .6821 .56219 .67723 .49567 Mtetra
.67723 .49567 .6821 .56219 .68613 .56101 .68119 .49446 Mtetra
.68119 .49446 .68613 .56101 .69016 .55983 .68514 .49326 Mtetra
.68514 .49326 .69016 .55983 .69421 .55865 .68911 .49205 Mtetra
.68911 .49205 .69421 .55865 .69825 .55746 .69308 .49084 Mtetra
.69308 .49084 .69825 .55746 .7023 .55628 .69706 .48963 Mtetra
.69706 .48963 .7023 .55628 .70636 .55509 .70104 .48842 Mtetra
.70104 .48842 .70636 .55509 .71042 .5539 .70503 .4872 Mtetra
.70503 .4872 .71042 .5539 .71449 .55271 .70902 .48598 Mtetra
.11 .038 .487 r
.70902 .48598 .71449 .55271 .71857 .55152 .71669 .54931 Mtetra
.656 .751 .92 r
.71669 .54931 .71857 .55152 .72265 .55032 .72077 .54811 Mtetra
.72077 .54811 .72265 .55032 .72674 .54913 .72486 .54691 Mtetra
.72486 .54691 .72674 .54913 .73083 .54793 .72896 .54571 Mtetra
.72896 .54571 .73083 .54793 .73493 .54673 .73306 .54451 Mtetra
.73306 .54451 .73493 .54673 .74066 .57106 .73717 .54331 Mtetra
.167 .106 .54 r
.73717 .54331 .74066 .57106 .7448 .56986 .74293 .56766 Mtetra
.654 .754 .923 r
.74293 .56766 .7448 .56986 .74895 .56867 .74708 .56646 Mtetra
.74708 .56646 .74895 .56867 .7531 .56747 .75124 .56526 Mtetra
.75124 .56526 .7531 .56747 .75726 .56627 .75541 .56406 Mtetra
.75541 .56406 .75726 .56627 .76143 .56507 .75958 .56285 Mtetra
.75958 .56285 .76143 .56507 .7656 .56387 .76376 .56165 Mtetra
.76376 .56165 .7656 .56387 .76978 .56267 .76794 .56044 Mtetra
.76794 .56044 .76978 .56267 .77397 .56146 .77213 .55923 Mtetra
.93 .555 .166 r
.77213 .55923 .77397 .56146 .77971 .58103 .77787 .57881 Mtetra
.652 .756 .926 r
.77787 .57881 .77971 .58103 .78394 .57983 .7821 .57761 Mtetra
.7821 .57761 .78394 .57983 .78817 .57862 .78633 .5764 Mtetra
.78633 .5764 .78817 .57862 .7924 .57742 .79057 .57519 Mtetra
.79057 .57519 .7924 .57742 .79665 .57621 .79482 .57398 Mtetra
.79482 .57398 .79665 .57621 .8009 .575 .79907 .57277 Mtetra
.79907 .57277 .8009 .575 .80515 .57379 .80333 .57156 Mtetra
.80333 .57156 .80515 .57379 .80941 .57258 .8076 .57034 Mtetra
.8076 .57034 .80941 .57258 .81368 .57137 .81187 .56912 Mtetra
.81187 .56912 .81368 .57137 .81795 .57015 .81615 .5679 Mtetra
.81615 .5679 .81795 .57015 .82224 .56894 .82044 .56668 Mtetra
.82044 .56668 .82224 .56894 .82652 .56772 .82473 .56546 Mtetra
.82473 .56546 .82652 .56772 .83082 .56649 .82903 .56424 Mtetra
.82903 .56424 .83082 .56649 .83511 .56527 .83333 .56301 Mtetra
.83333 .56301 .83511 .56527 .83942 .56405 .83764 .56178 Mtetra
.83764 .56178 .83942 .56405 .84373 .56282 .84196 .56055 Mtetra
.84196 .56055 .84373 .56282 .84805 .56159 .84628 .55932 Mtetra
.84628 .55932 .84805 .56159 .85238 .56036 .85061 .55809 Mtetra
.85061 .55809 .85238 .56036 .85671 .55913 .85495 .55685 Mtetra
.85495 .55685 .85671 .55913 .86105 .5579 .85929 .55561 Mtetra
.85929 .55561 .86105 .5579 .86539 .55666 .86364 .55438 Mtetra
.86364 .55438 .86539 .55666 .86974 .55542 .86799 .55313 Mtetra
.86799 .55313 .86974 .55542 .8741 .55418 .87236 .55189 Mtetra
.87236 .55189 .8741 .55418 .87846 .55294 .87673 .55065 Mtetra
.87673 .55065 .87846 .55294 .88283 .5517 .8811 .5494 Mtetra
.8811 .5494 .88283 .5517 .88721 .55046 .88548 .54815 Mtetra
.88548 .54815 .88721 .55046 .89159 .54921 .88987 .5469 Mtetra
.88987 .5469 .89159 .54921 .89598 .54796 .89427 .54565 Mtetra
.89427 .54565 .89598 .54796 .90038 .54671 .89867 .5444 Mtetra
.89867 .5444 .90038 .54671 .90478 .54546 .90308 .54314 Mtetra
.90308 .54314 .90478 .54546 .90919 .5442 .90749 .54188 Mtetra
.90749 .54188 .90919 .5442 .91361 .54295 .91191 .54062 Mtetra
.91191 .54062 .91361 .54295 .91803 .54169 .91634 .53936 Mtetra
.91634 .53936 .91803 .54169 .92246 .54043 .92077 .5381 Mtetra
.92077 .5381 .92246 .54043 .9269 .53917 .92522 .53683 Mtetra
.92522 .53683 .9269 .53917 .93134 .5379 .92966 .53557 Mtetra
.92966 .53557 .93134 .5379 .93579 .53664 .93412 .5343 Mtetra
.93412 .5343 .93579 .53664 .94025 .53537 .93858 .53303 Mtetra
.93858 .53303 .94025 .53537 .94471 .5341 .94305 .53175 Mtetra
.94305 .53175 .94471 .5341 .94918 .53283 .94752 .53048 Mtetra
.94752 .53048 .94918 .53283 .95366 .53156 .952 .5292 Mtetra
.652 .755 .925 r
.34582 .69441 .34807 .69632 .35168 .69529 .34944 .69338 Mtetra
.34944 .69338 .35168 .69529 .3553 .69425 .35306 .69234 Mtetra
.35306 .69234 .3553 .69425 .35893 .69322 .35669 .6913 Mtetra
.35669 .6913 .35893 .69322 .36256 .69218 .36032 .69026 Mtetra
.36032 .69026 .36256 .69218 .36619 .69114 .36396 .68922 Mtetra
.36396 .68922 .36619 .69114 .36983 .6901 .3676 .68818 Mtetra
.3676 .68818 .36983 .6901 .37347 .68906 .37125 .68713 Mtetra
.37125 .68713 .37347 .68906 .37712 .68802 .3749 .68609 Mtetra
.3749 .68609 .37712 .68802 .38078 .68697 .37856 .68504 Mtetra
.37856 .68504 .38078 .68697 .38444 .68593 .38222 .68399 Mtetra
.38222 .68399 .38444 .68593 .3881 .68488 .38589 .68294 Mtetra
.38589 .68294 .3881 .68488 .39177 .68383 .38956 .68189 Mtetra
.38956 .68189 .39177 .68383 .39545 .68278 .39324 .68084 Mtetra
.39324 .68084 .39545 .68278 .39912 .68173 .39692 .67978 Mtetra
.39692 .67978 .39912 .68173 .40281 .68068 .40061 .67873 Mtetra
.40061 .67873 .40281 .68068 .4065 .67962 .4043 .67767 Mtetra
.4043 .67767 .4065 .67962 .41019 .67857 .408 .67661 Mtetra
.408 .67661 .41019 .67857 .41389 .67751 .4117 .67555 Mtetra
.4117 .67555 .41389 .67751 .4176 .67645 .41541 .67449 Mtetra
.932 .717 .59 r
.41541 .67449 .4176 .67645 .42205 .65038 .41988 .6484 Mtetra
.655 .753 .922 r
.41988 .6484 .42205 .65038 .42574 .64931 .42357 .64733 Mtetra
.42357 .64733 .42574 .64931 .42943 .64824 .42727 .64625 Mtetra
.42727 .64625 .42943 .64824 .43313 .64716 .43097 .64518 Mtetra
.43097 .64518 .43313 .64716 .43683 .64609 .43468 .6441 Mtetra
.43468 .6441 .43683 .64609 .44054 .64501 .43839 .64302 Mtetra
.43839 .64302 .44054 .64501 .44426 .64393 .44211 .64194 Mtetra
.44211 .64194 .44426 .64393 .44798 .64285 .44583 .64086 Mtetra
.44583 .64086 .44798 .64285 .4517 .64177 .44956 .63977 Mtetra
.44956 .63977 .4517 .64177 .45543 .64069 .45329 .63869 Mtetra
.45329 .63869 .45543 .64069 .45917 .6396 .45703 .6376 Mtetra
.45703 .6376 .45917 .6396 .46291 .63852 .46077 .63651 Mtetra
.46077 .63651 .46291 .63852 .46665 .63743 .46452 .63542 Mtetra
.46452 .63542 .46665 .63743 .4704 .63634 .46828 .63433 Mtetra
.46828 .63433 .4704 .63634 .47416 .63525 .47203 .63323 Mtetra
.47203 .63323 .47416 .63525 .47792 .63416 .4758 .63214 Mtetra
.4758 .63214 .47792 .63416 .48168 .63306 .47957 .63104 Mtetra
.47957 .63104 .48168 .63306 .48545 .63197 .48334 .62994 Mtetra
.48334 .62994 .48545 .63197 .48923 .63087 .48712 .62884 Mtetra
.48712 .62884 .48923 .63087 .49301 .62977 .49091 .62774 Mtetra
.49091 .62774 .49301 .62977 .4968 .62868 .4947 .62664 Mtetra
.4947 .62664 .4968 .62868 .50059 .62757 .49849 .62554 Mtetra
.49849 .62554 .50059 .62757 .50439 .62647 .50229 .62443 Mtetra
.50229 .62443 .50439 .62647 .50819 .62537 .5061 .62332 Mtetra
.5061 .62332 .50819 .62537 .512 .62426 .50991 .62222 Mtetra
.952 .699 .517 r
.50991 .62222 .512 .62426 .51581 .62315 .51401 .53313 Mtetra
.571 .37 .569 r
.51401 .53313 .51581 .62315 .51976 .5341 .51773 .53199 Mtetra
.662 .744 .911 r
.51773 .53199 .51976 .5341 .52344 .64112 .52146 .53085 Mtetra
.57 .367 .566 r
.52146 .53085 .52344 .64112 .52729 .64001 .5252 .5297 Mtetra
.5252 .5297 .52729 .64001 .53115 .63891 .52894 .52855 Mtetra
.52894 .52855 .53115 .63891 .53501 .6378 .53268 .5274 Mtetra
0 0 .416 r
.53268 .5274 .53501 .6378 .53888 .63669 .53681 .63464 Mtetra
.653 .755 .925 r
.53681 .63464 .53888 .63669 .54275 .63558 .54068 .63352 Mtetra
.54068 .63352 .54275 .63558 .54663 .63447 .54456 .63241 Mtetra
.54456 .63241 .54663 .63447 .55052 .63335 .54845 .63129 Mtetra
.54845 .63129 .55052 .63335 .55441 .63224 .55234 .63017 Mtetra
.55234 .63017 .55441 .63224 .5583 .63112 .55624 .62905 Mtetra
.55624 .62905 .5583 .63112 .5622 .63 .56015 .62793 Mtetra
.56015 .62793 .5622 .63 .56611 .62888 .56406 .62681 Mtetra
.56406 .62681 .56611 .62888 .57002 .62776 .56797 .62569 Mtetra
.56797 .62569 .57002 .62776 .57394 .62664 .57189 .62456 Mtetra
.959 .699 .498 r
.57189 .62456 .57394 .62664 .57786 .62551 .57435 .52426 Mtetra
.571 .368 .567 r
.57435 .52426 .57786 .62551 .58015 .52525 .57817 .5231 Mtetra
.661 .745 .912 r
.57817 .5231 .58015 .52525 .58397 .52408 .58199 .52193 Mtetra
.58199 .52193 .58397 .52408 .58779 .52292 .58582 .52076 Mtetra
.58582 .52076 .58779 .52292 .59162 .52175 .58965 .51959 Mtetra
.58965 .51959 .59162 .52175 .59546 .52058 .59349 .51842 Mtetra
.59349 .51842 .59546 .52058 .5993 .51941 .59734 .51725 Mtetra
.59734 .51725 .5993 .51941 .60314 .51824 .60119 .51607 Mtetra
.60119 .51607 .60314 .51824 .60699 .51707 .60504 .5149 Mtetra
.60504 .5149 .60699 .51707 .61085 .51589 .6089 .51372 Mtetra
.6089 .51372 .61085 .51589 .61471 .51472 .61276 .51254 Mtetra
.61276 .51254 .61471 .51472 .61858 .51354 .61664 .51136 Mtetra
.61664 .51136 .61858 .51354 .62245 .51236 .62051 .51018 Mtetra
.62051 .51018 .62245 .51236 .62633 .51118 .62439 .50899 Mtetra
.62439 .50899 .62633 .51118 .63021 .50999 .62828 .50781 Mtetra
.62828 .50781 .63021 .50999 .6341 .50881 .63217 .50662 Mtetra
.63217 .50662 .6341 .50881 .63799 .50762 .63607 .50543 Mtetra
.63607 .50543 .63799 .50762 .64189 .50643 .63997 .50424 Mtetra
.63997 .50424 .64189 .50643 .6458 .50525 .64388 .50304 Mtetra
.64388 .50304 .6458 .50525 .64971 .50405 .64779 .50185 Mtetra
.64779 .50185 .64971 .50405 .65362 .50286 .65171 .50065 Mtetra
.65171 .50065 .65362 .50286 .65754 .50167 .65564 .49946 Mtetra
.65564 .49946 .65754 .50167 .66147 .50047 .65957 .49826 Mtetra
.65957 .49826 .66147 .50047 .6654 .49927 .6635 .49706 Mtetra
.6635 .49706 .6654 .49927 .66934 .49807 .66744 .49585 Mtetra
.66744 .49585 .66934 .49807 .67328 .49687 .67139 .49465 Mtetra
.67139 .49465 .67328 .49687 .67723 .49567 .67534 .49344 Mtetra
.67534 .49344 .67723 .49567 .68119 .49446 .6793 .49224 Mtetra
.6793 .49224 .68119 .49446 .68514 .49326 .68326 .49103 Mtetra
.68326 .49103 .68514 .49326 .68911 .49205 .68723 .48981 Mtetra
.68723 .48981 .68911 .49205 .69308 .49084 .69121 .4886 Mtetra
.69121 .4886 .69308 .49084 .69706 .48963 .69519 .48739 Mtetra
.69519 .48739 .69706 .48963 .70104 .48842 .69917 .48617 Mtetra
.69917 .48617 .70104 .48842 .70503 .4872 .70316 .48495 Mtetra
.70316 .48495 .70503 .4872 .70902 .48598 .70716 .48373 Mtetra
.70716 .48373 .70902 .48598 .71669 .54931 .71116 .48251 Mtetra
.573 .375 .574 r
.71116 .48251 .71669 .54931 .72077 .54811 .71517 .48129 Mtetra
.71517 .48129 .72077 .54811 .72486 .54691 .71918 .48006 Mtetra
.71918 .48006 .72486 .54691 .72896 .54571 .7232 .47884 Mtetra
.7232 .47884 .72896 .54571 .73306 .54451 .72723 .47761 Mtetra
.72723 .47761 .73306 .54451 .73717 .54331 .73126 .47638 Mtetra
0 0 .401 r
.73126 .47638 .73717 .54331 .74293 .56766 .74106 .56544 Mtetra
.654 .754 .923 r
.74106 .56544 .74293 .56766 .74708 .56646 .74522 .56424 Mtetra
.74522 .56424 .74708 .56646 .75124 .56526 .74938 .56304 Mtetra
.74938 .56304 .75124 .56526 .75541 .56406 .75355 .56183 Mtetra
.75355 .56183 .75541 .56406 .75958 .56285 .75772 .56063 Mtetra
.75772 .56063 .75958 .56285 .76376 .56165 .7619 .55942 Mtetra
.7619 .55942 .76376 .56165 .76794 .56044 .76609 .55821 Mtetra
.931 .556 .169 r
.76609 .55821 .76794 .56044 .77213 .55923 .7718 .57779 Mtetra
.535 .284 .481 r
.7718 .57779 .77213 .55923 .77787 .57881 .77602 .57658 Mtetra
.652 .756 .926 r
.77602 .57658 .77787 .57881 .7821 .57761 .78026 .57538 Mtetra
.78026 .57538 .7821 .57761 .78633 .5764 .78449 .57417 Mtetra
.78449 .57417 .78633 .5764 .79057 .57519 .78874 .57296 Mtetra
.78874 .57296 .79057 .57519 .79482 .57398 .79299 .57174 Mtetra
.79299 .57174 .79482 .57398 .79907 .57277 .79725 .57053 Mtetra
.79725 .57053 .79907 .57277 .80333 .57156 .80151 .56931 Mtetra
.80151 .56931 .80333 .57156 .8076 .57034 .80578 .56809 Mtetra
.80578 .56809 .8076 .57034 .81187 .56912 .81006 .56687 Mtetra
.81006 .56687 .81187 .56912 .81615 .5679 .81434 .56565 Mtetra
.81434 .56565 .81615 .5679 .82044 .56668 .81863 .56442 Mtetra
.81863 .56442 .82044 .56668 .82473 .56546 .82293 .5632 Mtetra
.82293 .5632 .82473 .56546 .82903 .56424 .82723 .56197 Mtetra
.82723 .56197 .82903 .56424 .83333 .56301 .83154 .56074 Mtetra
.83154 .56074 .83333 .56301 .83764 .56178 .83586 .55951 Mtetra
.83586 .55951 .83764 .56178 .84196 .56055 .84018 .55828 Mtetra
.84018 .55828 .84196 .56055 .84628 .55932 .84451 .55704 Mtetra
.84451 .55704 .84628 .55932 .85061 .55809 .84884 .5558 Mtetra
.84884 .5558 .85061 .55809 .85495 .55685 .85318 .55457 Mtetra
.85318 .55457 .85495 .55685 .85929 .55561 .85753 .55333 Mtetra
.85753 .55333 .85929 .55561 .86364 .55438 .86188 .55208 Mtetra
.86188 .55208 .86364 .55438 .86799 .55313 .86624 .55084 Mtetra
.86624 .55084 .86799 .55313 .87236 .55189 .87061 .54959 Mtetra
.87061 .54959 .87236 .55189 .87673 .55065 .87498 .54834 Mtetra
.959 .788 .627 r
.87498 .54834 .87673 .55065 .8811 .5494 .87825 .53657 Mtetra
.602 .455 .654 r
.87825 .53657 .8811 .5494 .88548 .54815 .88263 .53531 Mtetra
.88263 .53531 .88548 .54815 .88987 .5469 .88701 .53405 Mtetra
.88701 .53405 .88987 .5469 .89427 .54565 .89139 .53279 Mtetra
.89139 .53279 .89427 .54565 .89867 .5444 .89578 .53153 Mtetra
.89578 .53153 .89867 .5444 .90308 .54314 .90018 .53027 Mtetra
.90018 .53027 .90308 .54314 .90749 .54188 .90458 .529 Mtetra
.90458 .529 .90749 .54188 .91191 .54062 .909 .52774 Mtetra
.909 .52774 .91191 .54062 .91634 .53936 .91341 .52647 Mtetra
.91341 .52647 .91634 .53936 .92077 .5381 .91784 .5252 Mtetra
.91784 .5252 .92077 .5381 .92522 .53683 .92227 .52392 Mtetra
.92227 .52392 .92522 .53683 .92966 .53557 .92671 .52265 Mtetra
.92671 .52265 .92966 .53557 .93412 .5343 .93115 .52137 Mtetra
.93115 .52137 .93412 .5343 .93858 .53303 .9356 .52009 Mtetra
.9356 .52009 .93858 .53303 .94305 .53175 .94006 .51881 Mtetra
.94006 .51881 .94305 .53175 .94752 .53048 .94453 .51753 Mtetra
.94453 .51753 .94752 .53048 .952 .5292 .949 .51625 Mtetra
.652 .755 .925 r
.34357 .6925 .34582 .69441 .34944 .69338 .34719 .69146 Mtetra
.34719 .69146 .34944 .69338 .35306 .69234 .35082 .69042 Mtetra
.35082 .69042 .35306 .69234 .35669 .6913 .35445 .68938 Mtetra
.35445 .68938 .35669 .6913 .36032 .69026 .35808 .68834 Mtetra
.35808 .68834 .36032 .69026 .36396 .68922 .36172 .68729 Mtetra
.36172 .68729 .36396 .68922 .3676 .68818 .36537 .68625 Mtetra
.36537 .68625 .3676 .68818 .37125 .68713 .36902 .6852 Mtetra
.36902 .6852 .37125 .68713 .3749 .68609 .37267 .68415 Mtetra
.37267 .68415 .3749 .68609 .37856 .68504 .37633 .6831 Mtetra
.37633 .6831 .37856 .68504 .38222 .68399 .38 .68205 Mtetra
.38 .68205 .38222 .68399 .38589 .68294 .38367 .681 Mtetra
.38367 .681 .38589 .68294 .38956 .68189 .38735 .67995 Mtetra
.38735 .67995 .38956 .68189 .39324 .68084 .39103 .67889 Mtetra
.39103 .67889 .39324 .68084 .39692 .67978 .39471 .67783 Mtetra
.39471 .67783 .39692 .67978 .40061 .67873 .3984 .67677 Mtetra
.3984 .67677 .40061 .67873 .4043 .67767 .4021 .67572 Mtetra
.4021 .67572 .4043 .67767 .408 .67661 .4058 .67465 Mtetra
.4058 .67465 .408 .67661 .4117 .67555 .40951 .67359 Mtetra
.40951 .67359 .4117 .67555 .41541 .67449 .41322 .67253 Mtetra
.932 .717 .59 r
.41322 .67253 .41541 .67449 .41988 .6484 .41771 .64642 Mtetra
.655 .753 .922 r
.41771 .64642 .41988 .6484 .42357 .64733 .4214 .64534 Mtetra
.4214 .64534 .42357 .64733 .42727 .64625 .4251 .64427 Mtetra
.4251 .64427 .42727 .64625 .43097 .64518 .42881 .64319 Mtetra
.42881 .64319 .43097 .64518 .43468 .6441 .43252 .6421 Mtetra
.43252 .6421 .43468 .6441 .43839 .64302 .43624 .64102 Mtetra
.43624 .64102 .43839 .64302 .44211 .64194 .43996 .63994 Mtetra
.43996 .63994 .44211 .64194 .44583 .64086 .44368 .63885 Mtetra
.44368 .63885 .44583 .64086 .44956 .63977 .44741 .63777 Mtetra
.44741 .63777 .44956 .63977 .45329 .63869 .45115 .63668 Mtetra
.45115 .63668 .45329 .63869 .45703 .6376 .45489 .63559 Mtetra
.45489 .63559 .45703 .6376 .46077 .63651 .45864 .63449 Mtetra
.45864 .63449 .46077 .63651 .46452 .63542 .46239 .6334 Mtetra
.46239 .6334 .46452 .63542 .46828 .63433 .46615 .63231 Mtetra
.46615 .63231 .46828 .63433 .47203 .63323 .46991 .63121 Mtetra
.46991 .63121 .47203 .63323 .4758 .63214 .47367 .63011 Mtetra
.47367 .63011 .4758 .63214 .47957 .63104 .47745 .62901 Mtetra
.47745 .62901 .47957 .63104 .48334 .62994 .48122 .62791 Mtetra
.48122 .62791 .48334 .62994 .48712 .62884 .48501 .62681 Mtetra
.48501 .62681 .48712 .62884 .49091 .62774 .4888 .62571 Mtetra
.4888 .62571 .49091 .62774 .4947 .62664 .49259 .6246 Mtetra
.49259 .6246 .4947 .62664 .49849 .62554 .49639 .62349 Mtetra
.49639 .62349 .49849 .62554 .50229 .62443 .50019 .62239 Mtetra
.50019 .62239 .50229 .62443 .5061 .62332 .504 .62128 Mtetra
.504 .62128 .5061 .62332 .50991 .62222 .50782 .62017 Mtetra
.952 .699 .517 r
.50782 .62017 .50991 .62222 .51401 .53313 .51197 .53102 Mtetra
.662 .744 .911 r
.51197 .53102 .51401 .53313 .51773 .53199 .5157 .52988 Mtetra
.5157 .52988 .51773 .53199 .52146 .53085 .51943 .52873 Mtetra
.51943 .52873 .52146 .53085 .5252 .5297 .52317 .52758 Mtetra
.52317 .52758 .5252 .5297 .52894 .52855 .52691 .52643 Mtetra
.52691 .52643 .52894 .52855 .53268 .5274 .53066 .52528 Mtetra
.53066 .52528 .53268 .5274 .53681 .63464 .53442 .52412 Mtetra
.57 .367 .566 r
.53442 .52412 .53681 .63464 .54068 .63352 .53817 .52297 Mtetra
.53817 .52297 .54068 .63352 .54456 .63241 .54194 .52181 Mtetra
.54194 .52181 .54456 .63241 .54845 .63129 .54571 .52065 Mtetra
.001 0 .42 r
.54571 .52065 .54845 .63129 .55234 .63017 .55028 .62811 Mtetra
.653 .755 .925 r
.55028 .62811 .55234 .63017 .55624 .62905 .55418 .62698 Mtetra
.55418 .62698 .55624 .62905 .56015 .62793 .55809 .62586 Mtetra
.55809 .62586 .56015 .62793 .56406 .62681 .562 .62473 Mtetra
.562 .62473 .56406 .62681 .56797 .62569 .56592 .62361 Mtetra
.56592 .62361 .56797 .62569 .57189 .62456 .56984 .62248 Mtetra
.959 .699 .498 r
.56984 .62248 .57189 .62456 .57435 .52426 .57236 .52211 Mtetra
.661 .745 .912 r
.57236 .52211 .57435 .52426 .57817 .5231 .57619 .52094 Mtetra
.57619 .52094 .57817 .5231 .58199 .52193 .58001 .51977 Mtetra
.58001 .51977 .58199 .52193 .58582 .52076 .58384 .5186 Mtetra
.58384 .5186 .58582 .52076 .58965 .51959 .58768 .51743 Mtetra
.58768 .51743 .58965 .51959 .59349 .51842 .59152 .51625 Mtetra
.59152 .51625 .59349 .51842 .59734 .51725 .59537 .51508 Mtetra
.59537 .51508 .59734 .51725 .60119 .51607 .59922 .5139 Mtetra
.59922 .5139 .60119 .51607 .60504 .5149 .60308 .51272 Mtetra
.60308 .51272 .60504 .5149 .6089 .51372 .60694 .51154 Mtetra
.60694 .51154 .6089 .51372 .61276 .51254 .61081 .51036 Mtetra
.61081 .51036 .61276 .51254 .61664 .51136 .61469 .50917 Mtetra
.61469 .50917 .61664 .51136 .62051 .51018 .61857 .50799 Mtetra
.61857 .50799 .62051 .51018 .62439 .50899 .62245 .5068 Mtetra
.62245 .5068 .62439 .50899 .62828 .50781 .62634 .50561 Mtetra
.62634 .50561 .62828 .50781 .63217 .50662 .63024 .50442 Mtetra
.63024 .50442 .63217 .50662 .63607 .50543 .63414 .50323 Mtetra
.63414 .50323 .63607 .50543 .63997 .50424 .63804 .50203 Mtetra
.63804 .50203 .63997 .50424 .64388 .50304 .64196 .50084 Mtetra
.64196 .50084 .64388 .50304 .64779 .50185 .64587 .49964 Mtetra
.64587 .49964 .64779 .50185 .65171 .50065 .6498 .49844 Mtetra
.6498 .49844 .65171 .50065 .65564 .49946 .65373 .49724 Mtetra
.65373 .49724 .65564 .49946 .65957 .49826 .65766 .49604 Mtetra
.65766 .49604 .65957 .49826 .6635 .49706 .6616 .49483 Mtetra
.6616 .49483 .6635 .49706 .66744 .49585 .66554 .49363 Mtetra
.66554 .49363 .66744 .49585 .67139 .49465 .66949 .49242 Mtetra
.66949 .49242 .67139 .49465 .67534 .49344 .67345 .49121 Mtetra
.67345 .49121 .67534 .49344 .6793 .49224 .67741 .49 Mtetra
.67741 .49 .6793 .49224 .68326 .49103 .68138 .48879 Mtetra
.68138 .48879 .68326 .49103 .68723 .48981 .68535 .48757 Mtetra
.68535 .48757 .68723 .48981 .69121 .4886 .68933 .48636 Mtetra
.68933 .48636 .69121 .4886 .69519 .48739 .69331 .48514 Mtetra
.69331 .48514 .69519 .48739 .69917 .48617 .6973 .48392 Mtetra
.6973 .48392 .69917 .48617 .70316 .48495 .7013 .4827 Mtetra
.7013 .4827 .70316 .48495 .70716 .48373 .7053 .48148 Mtetra
.7053 .48148 .70716 .48373 .71116 .48251 .7093 .48025 Mtetra
.7093 .48025 .71116 .48251 .71517 .48129 .71332 .47903 Mtetra
.71332 .47903 .71517 .48129 .71918 .48006 .71733 .4778 Mtetra
.71733 .4778 .71918 .48006 .7232 .47884 .72136 .47657 Mtetra
.72136 .47657 .7232 .47884 .72723 .47761 .72539 .47534 Mtetra
.72539 .47534 .72723 .47761 .73126 .47638 .72942 .4741 Mtetra
.72942 .4741 .73126 .47638 .74106 .56544 .73346 .47287 Mtetra
.571 .369 .568 r
.73346 .47287 .74106 .56544 .74522 .56424 .73751 .47163 Mtetra
.111 .037 .484 r
.73751 .47163 .74522 .56424 .74938 .56304 .74751 .56081 Mtetra
.654 .754 .923 r
.74751 .56081 .74938 .56304 .75355 .56183 .75168 .5596 Mtetra
.75168 .5596 .75355 .56183 .75772 .56063 .75586 .55839 Mtetra
.75586 .55839 .75772 .56063 .7619 .55942 .76005 .55718 Mtetra
.976 .699 .436 r
.76005 .55718 .7619 .55942 .76609 .55821 .75748 .46053 Mtetra
0 0 .444 r
.75748 .46053 .76609 .55821 .7718 .57779 .76994 .57556 Mtetra
.652 .756 .926 r
.76994 .57556 .7718 .57779 .77602 .57658 .77417 .57435 Mtetra
.77417 .57435 .77602 .57658 .78026 .57538 .77841 .57314 Mtetra
.77841 .57314 .78026 .57538 .78449 .57417 .78265 .57193 Mtetra
.78265 .57193 .78449 .57417 .78874 .57296 .7869 .57071 Mtetra
.7869 .57071 .78874 .57296 .79299 .57174 .79116 .5695 Mtetra
.79116 .5695 .79299 .57174 .79725 .57053 .79542 .56828 Mtetra
.79542 .56828 .79725 .57053 .80151 .56931 .79969 .56706 Mtetra
.79969 .56706 .80151 .56931 .80578 .56809 .80396 .56584 Mtetra
.80396 .56584 .80578 .56809 .81006 .56687 .80824 .56461 Mtetra
.80824 .56461 .81006 .56687 .81434 .56565 .81253 .56339 Mtetra
.81253 .56339 .81434 .56565 .81863 .56442 .81683 .56216 Mtetra
.81683 .56216 .81863 .56442 .82293 .5632 .82113 .56093 Mtetra
.82113 .56093 .82293 .5632 .82723 .56197 .82543 .5597 Mtetra
.82543 .5597 .82723 .56197 .83154 .56074 .82975 .55847 Mtetra
.82975 .55847 .83154 .56074 .83586 .55951 .83407 .55723 Mtetra
.83407 .55723 .83586 .55951 .84018 .55828 .83839 .556 Mtetra
.83839 .556 .84018 .55828 .84451 .55704 .84272 .55476 Mtetra
.84272 .55476 .84451 .55704 .84884 .5558 .84706 .55352 Mtetra
.84706 .55352 .84884 .5558 .85318 .55457 .85141 .55227 Mtetra
.85141 .55227 .85318 .55457 .85753 .55333 .85576 .55103 Mtetra
.85576 .55103 .85753 .55333 .86188 .55208 .86012 .54978 Mtetra
.86012 .54978 .86188 .55208 .86624 .55084 .86449 .54854 Mtetra
.86449 .54854 .86624 .55084 .87061 .54959 .86886 .54729 Mtetra
.958 .787 .628 r
.86886 .54729 .87061 .54959 .87498 .54834 .87215 .5355 Mtetra
.602 .455 .654 r
.87215 .5355 .87498 .54834 .87825 .53657 .87652 .53425 Mtetra
.653 .755 .925 r
.87652 .53425 .87825 .53657 .88263 .53531 .88089 .53299 Mtetra
.88089 .53299 .88263 .53531 .88701 .53405 .88528 .53173 Mtetra
.88528 .53173 .88701 .53405 .89139 .53279 .88967 .53046 Mtetra
.88967 .53046 .89139 .53279 .89578 .53153 .89406 .5292 Mtetra
.89406 .5292 .89578 .53153 .90018 .53027 .89847 .52793 Mtetra
.89847 .52793 .90018 .53027 .90458 .529 .90287 .52666 Mtetra
.90287 .52666 .90458 .529 .909 .52774 .90729 .52539 Mtetra
.90729 .52539 .909 .52774 .91341 .52647 .91171 .52412 Mtetra
.91171 .52412 .91341 .52647 .91784 .5252 .91614 .52285 Mtetra
.91614 .52285 .91784 .5252 .92227 .52392 .92058 .52157 Mtetra
.92058 .52157 .92227 .52392 .92671 .52265 .92502 .52029 Mtetra
.92502 .52029 .92671 .52265 .93115 .52137 .92947 .51901 Mtetra
.92947 .51901 .93115 .52137 .9356 .52009 .93393 .51773 Mtetra
.93393 .51773 .9356 .52009 .94006 .51881 .93839 .51644 Mtetra
.93839 .51644 .94006 .51881 .94453 .51753 .94286 .51516 Mtetra
.94286 .51516 .94453 .51753 .949 .51625 .94734 .51387 Mtetra
.652 .755 .925 r
.34131 .69058 .34357 .6925 .34719 .69146 .34494 .68954 Mtetra
.34494 .68954 .34719 .69146 .35082 .69042 .34856 .6885 Mtetra
.34856 .6885 .35082 .69042 .35445 .68938 .3522 .68746 Mtetra
.3522 .68746 .35445 .68938 .35808 .68834 .35584 .68641 Mtetra
.35584 .68641 .35808 .68834 .36172 .68729 .35948 .68536 Mtetra
.35948 .68536 .36172 .68729 .36537 .68625 .36313 .68432 Mtetra
.36313 .68432 .36537 .68625 .36902 .6852 .36678 .68327 Mtetra
.36678 .68327 .36902 .6852 .37267 .68415 .37044 .68221 Mtetra
.37044 .68221 .37267 .68415 .37633 .6831 .37411 .68116 Mtetra
.37411 .68116 .37633 .6831 .38 .68205 .37777 .68011 Mtetra
.37777 .68011 .38 .68205 .38367 .681 .38145 .67905 Mtetra
.38145 .67905 .38367 .681 .38735 .67995 .38513 .678 Mtetra
.38513 .678 .38735 .67995 .39103 .67889 .38881 .67694 Mtetra
.38881 .67694 .39103 .67889 .39471 .67783 .3925 .67588 Mtetra
.3925 .67588 .39471 .67783 .3984 .67677 .39619 .67482 Mtetra
.39619 .67482 .3984 .67677 .4021 .67572 .39989 .67375 Mtetra
.39989 .67375 .4021 .67572 .4058 .67465 .4036 .67269 Mtetra
.4036 .67269 .4058 .67465 .40951 .67359 .40731 .67162 Mtetra
.40731 .67162 .40951 .67359 .41322 .67253 .41102 .67056 Mtetra
.932 .717 .59 r
.41102 .67056 .41322 .67253 .41771 .64642 .41553 .64443 Mtetra
.655 .753 .922 r
.41553 .64443 .41771 .64642 .4214 .64534 .41923 .64335 Mtetra
.41923 .64335 .4214 .64534 .4251 .64427 .42293 .64227 Mtetra
.42293 .64227 .4251 .64427 .42881 .64319 .42664 .64119 Mtetra
.42664 .64119 .42881 .64319 .43252 .6421 .43035 .6401 Mtetra
.43035 .6401 .43252 .6421 .43624 .64102 .43407 .63902 Mtetra
.43407 .63902 .43624 .64102 .43996 .63994 .4378 .63793 Mtetra
.4378 .63793 .43996 .63994 .44368 .63885 .44153 .63684 Mtetra
.44153 .63684 .44368 .63885 .44741 .63777 .44526 .63575 Mtetra
.44526 .63575 .44741 .63777 .45115 .63668 .449 .63466 Mtetra
.449 .63466 .45115 .63668 .45489 .63559 .45274 .63357 Mtetra
.45274 .63357 .45489 .63559 .45864 .63449 .45649 .63248 Mtetra
.45649 .63248 .45864 .63449 .46239 .6334 .46025 .63138 Mtetra
.46025 .63138 .46239 .6334 .46615 .63231 .46401 .63028 Mtetra
.46401 .63028 .46615 .63231 .46991 .63121 .46777 .62918 Mtetra
.46777 .62918 .46991 .63121 .47367 .63011 .47155 .62808 Mtetra
.47155 .62808 .47367 .63011 .47745 .62901 .47532 .62698 Mtetra
.47532 .62698 .47745 .62901 .48122 .62791 .4791 .62588 Mtetra
.4791 .62588 .48122 .62791 .48501 .62681 .48289 .62477 Mtetra
.48289 .62477 .48501 .62681 .4888 .62571 .48668 .62367 Mtetra
.48668 .62367 .4888 .62571 .49259 .6246 .49048 .62256 Mtetra
.49048 .62256 .49259 .6246 .49639 .62349 .49428 .62145 Mtetra
.49428 .62145 .49639 .62349 .50019 .62239 .49809 .62034 Mtetra
.49809 .62034 .50019 .62239 .504 .62128 .5019 .61922 Mtetra
.5019 .61922 .504 .62128 .50782 .62017 .50572 .61811 Mtetra
.952 .699 .517 r
.50572 .61811 .50782 .62017 .51197 .53102 .50993 .52891 Mtetra
.662 .744 .911 r
.50993 .52891 .51197 .53102 .5157 .52988 .51366 .52776 Mtetra
.51366 .52776 .5157 .52988 .51943 .52873 .5174 .52661 Mtetra
.5174 .52661 .51943 .52873 .52317 .52758 .52114 .52546 Mtetra
.52114 .52546 .52317 .52758 .52691 .52643 .52489 .5243 Mtetra
.52489 .5243 .52691 .52643 .53066 .52528 .52864 .52315 Mtetra
.52864 .52315 .53066 .52528 .53442 .52412 .53239 .52199 Mtetra
.53239 .52199 .53442 .52412 .53817 .52297 .53616 .52083 Mtetra
.53616 .52083 .53817 .52297 .54194 .52181 .53992 .51967 Mtetra
.53992 .51967 .54194 .52181 .54571 .52065 .54369 .51851 Mtetra
.54369 .51851 .54571 .52065 .55028 .62811 .54747 .51735 Mtetra
.57 .366 .565 r
.54747 .51735 .55028 .62811 .55418 .62698 .55125 .51618 Mtetra
.55125 .51618 .55418 .62698 .55809 .62586 .55504 .51502 Mtetra
.006 0 .423 r
.55504 .51502 .55809 .62586 .562 .62473 .55994 .62265 Mtetra
.653 .755 .925 r
.55994 .62265 .562 .62473 .56592 .62361 .56386 .62152 Mtetra
.959 .699 .499 r
.56386 .62152 .56592 .62361 .56984 .62248 .56655 .52112 Mtetra
.57 .367 .567 r
.56655 .52112 .56984 .62248 .57236 .52211 .57037 .51995 Mtetra
.661 .745 .912 r
.57037 .51995 .57236 .52211 .57619 .52094 .5742 .51878 Mtetra
.5742 .51878 .57619 .52094 .58001 .51977 .57803 .51761 Mtetra
.57803 .51761 .58001 .51977 .58384 .5186 .58186 .51644 Mtetra
.58186 .51644 .58384 .5186 .58768 .51743 .5857 .51526 Mtetra
.5857 .51526 .58768 .51743 .59152 .51625 .58955 .51408 Mtetra
.58955 .51408 .59152 .51625 .59537 .51508 .5934 .5129 Mtetra
.5934 .5129 .59537 .51508 .59922 .5139 .59725 .51172 Mtetra
.59725 .51172 .59922 .5139 .60308 .51272 .60112 .51054 Mtetra
.60112 .51054 .60308 .51272 .60694 .51154 .60498 .50936 Mtetra
.60498 .50936 .60694 .51154 .61081 .51036 .60886 .50817 Mtetra
.60886 .50817 .61081 .51036 .61469 .50917 .61273 .50698 Mtetra
.61273 .50698 .61469 .50917 .61857 .50799 .61662 .50579 Mtetra
.61662 .50579 .61857 .50799 .62245 .5068 .6205 .5046 Mtetra
.6205 .5046 .62245 .5068 .62634 .50561 .6244 .50341 Mtetra
.6244 .50341 .62634 .50561 .63024 .50442 .6283 .50222 Mtetra
.6283 .50222 .63024 .50442 .63414 .50323 .6322 .50102 Mtetra
.6322 .50102 .63414 .50323 .63804 .50203 .63611 .49983 Mtetra
.63611 .49983 .63804 .50203 .64196 .50084 .64003 .49863 Mtetra
.64003 .49863 .64196 .50084 .64587 .49964 .64395 .49743 Mtetra
.64395 .49743 .64587 .49964 .6498 .49844 .64788 .49622 Mtetra
.64788 .49622 .6498 .49844 .65373 .49724 .65181 .49502 Mtetra
.65181 .49502 .65373 .49724 .65766 .49604 .65575 .49381 Mtetra
.65575 .49381 .65766 .49604 .6616 .49483 .65969 .49261 Mtetra
.65969 .49261 .6616 .49483 .66554 .49363 .66364 .4914 Mtetra
.66364 .4914 .66554 .49363 .66949 .49242 .66759 .49019 Mtetra
.66759 .49019 .66949 .49242 .67345 .49121 .67155 .48898 Mtetra
.67155 .48898 .67345 .49121 .67741 .49 .67552 .48776 Mtetra
.67552 .48776 .67741 .49 .68138 .48879 .67949 .48655 Mtetra
.67949 .48655 .68138 .48879 .68535 .48757 .68346 .48533 Mtetra
.68346 .48533 .68535 .48757 .68933 .48636 .68745 .48411 Mtetra
.68745 .48411 .68933 .48636 .69331 .48514 .69143 .48289 Mtetra
.69143 .48289 .69331 .48514 .6973 .48392 .69543 .48167 Mtetra
.69543 .48167 .6973 .48392 .7013 .4827 .69943 .48044 Mtetra
.69943 .48044 .7013 .4827 .7053 .48148 .70343 .47922 Mtetra
.70343 .47922 .7053 .48148 .7093 .48025 .70744 .47799 Mtetra
.70744 .47799 .7093 .48025 .71332 .47903 .71146 .47676 Mtetra
.71146 .47676 .71332 .47903 .71733 .4778 .71548 .47553 Mtetra
.71548 .47553 .71733 .4778 .72136 .47657 .71951 .47429 Mtetra
.71951 .47429 .72136 .47657 .72539 .47534 .72354 .47306 Mtetra
.72354 .47306 .72539 .47534 .72942 .4741 .72758 .47182 Mtetra
.72758 .47182 .72942 .4741 .73346 .47287 .73162 .47058 Mtetra
.73162 .47058 .73346 .47287 .73751 .47163 .73567 .46934 Mtetra
.887 .788 .745 r
.73567 .46934 .73751 .47163 .74751 .56081 .73941 .46322 Mtetra
.57 .368 .567 r
.73941 .46322 .74751 .56081 .75168 .5596 .74346 .46197 Mtetra
.74346 .46197 .75168 .5596 .75586 .55839 .74753 .46073 Mtetra
.74753 .46073 .75586 .55839 .76005 .55718 .75159 .45948 Mtetra
.75159 .45948 .76005 .55718 .75748 .46053 .75567 .45823 Mtetra
.661 .745 .912 r
.75567 .45823 .75748 .46053 .76994 .57556 .75974 .45697 Mtetra
.569 .366 .565 r
.75974 .45697 .76994 .57556 .77417 .57435 .76383 .45572 Mtetra
.76383 .45572 .77417 .57435 .77841 .57314 .76792 .45446 Mtetra
.119 .042 .486 r
.76792 .45446 .77841 .57314 .78265 .57193 .7808 .56968 Mtetra
.652 .756 .926 r
.7808 .56968 .78265 .57193 .7869 .57071 .78506 .56847 Mtetra
.78506 .56847 .7869 .57071 .79116 .5695 .78932 .56725 Mtetra
.78932 .56725 .79116 .5695 .79542 .56828 .79358 .56602 Mtetra
.79358 .56602 .79542 .56828 .79969 .56706 .79786 .5648 Mtetra
.79786 .5648 .79969 .56706 .80396 .56584 .80214 .56358 Mtetra
.80214 .56358 .80396 .56584 .80824 .56461 .80642 .56235 Mtetra
.80642 .56235 .80824 .56461 .81253 .56339 .81071 .56112 Mtetra
.81071 .56112 .81253 .56339 .81683 .56216 .81501 .55989 Mtetra
.81501 .55989 .81683 .56216 .82113 .56093 .81932 .55866 Mtetra
.81932 .55866 .82113 .56093 .82543 .5597 .82363 .55742 Mtetra
.82363 .55742 .82543 .5597 .82975 .55847 .82795 .55619 Mtetra
.82795 .55619 .82975 .55847 .83407 .55723 .83227 .55495 Mtetra
.83227 .55495 .83407 .55723 .83839 .556 .8366 .55371 Mtetra
.8366 .55371 .83839 .556 .84272 .55476 .84094 .55247 Mtetra
.84094 .55247 .84272 .55476 .84706 .55352 .84528 .55122 Mtetra
.84528 .55122 .84706 .55352 .85141 .55227 .84963 .54998 Mtetra
.84963 .54998 .85141 .55227 .85576 .55103 .85399 .54873 Mtetra
.85399 .54873 .85576 .55103 .86012 .54978 .85835 .54748 Mtetra
.85835 .54748 .86012 .54978 .86449 .54854 .86272 .54623 Mtetra
.958 .787 .628 r
.86272 .54623 .86449 .54854 .86886 .54729 .86603 .53444 Mtetra
.602 .454 .653 r
.86603 .53444 .86886 .54729 .87215 .5355 .8704 .53318 Mtetra
.653 .755 .925 r
.8704 .53318 .87215 .5355 .87652 .53425 .87477 .53192 Mtetra
.87477 .53192 .87652 .53425 .88089 .53299 .87915 .53066 Mtetra
.87915 .53066 .88089 .53299 .88528 .53173 .88354 .52939 Mtetra
.88354 .52939 .88528 .53173 .88967 .53046 .88794 .52813 Mtetra
.88794 .52813 .88967 .53046 .89406 .5292 .89234 .52686 Mtetra
.89234 .52686 .89406 .5292 .89847 .52793 .89675 .52559 Mtetra
.89675 .52559 .89847 .52793 .90287 .52666 .90116 .52432 Mtetra
.90116 .52432 .90287 .52666 .90729 .52539 .90558 .52304 Mtetra
.90558 .52304 .90729 .52539 .91171 .52412 .91001 .52177 Mtetra
.91001 .52177 .91171 .52412 .91614 .52285 .91444 .52049 Mtetra
.91444 .52049 .91614 .52285 .92058 .52157 .91888 .51921 Mtetra
.91888 .51921 .92058 .52157 .92502 .52029 .92333 .51793 Mtetra
.92333 .51793 .92502 .52029 .92947 .51901 .92779 .51664 Mtetra
.92779 .51664 .92947 .51901 .93393 .51773 .93225 .51536 Mtetra
.93225 .51536 .93393 .51773 .93839 .51644 .93672 .51407 Mtetra
.93672 .51407 .93839 .51644 .94286 .51516 .94119 .51278 Mtetra
.94119 .51278 .94286 .51516 .94734 .51387 .94567 .51149 Mtetra
.652 .755 .925 r
.33905 .68866 .34131 .69058 .34494 .68954 .34268 .68762 Mtetra
.34268 .68762 .34494 .68954 .34856 .6885 .34631 .68657 Mtetra
.34631 .68657 .34856 .6885 .3522 .68746 .34994 .68552 Mtetra
.34994 .68552 .3522 .68746 .35584 .68641 .35359 .68448 Mtetra
.35359 .68448 .35584 .68641 .35948 .68536 .35723 .68343 Mtetra
.35723 .68343 .35948 .68536 .36313 .68432 .36088 .68238 Mtetra
.36088 .68238 .36313 .68432 .36678 .68327 .36454 .68132 Mtetra
.36454 .68132 .36678 .68327 .37044 .68221 .3682 .68027 Mtetra
.3682 .68027 .37044 .68221 .37411 .68116 .37187 .67922 Mtetra
.37187 .67922 .37411 .68116 .37777 .68011 .37554 .67816 Mtetra
.37554 .67816 .37777 .68011 .38145 .67905 .37922 .6771 Mtetra
.37922 .6771 .38145 .67905 .38513 .678 .3829 .67604 Mtetra
.3829 .67604 .38513 .678 .38881 .67694 .38659 .67498 Mtetra
.38659 .67498 .38881 .67694 .3925 .67588 .39028 .67392 Mtetra
.39028 .67392 .3925 .67588 .39619 .67482 .39398 .67285 Mtetra
.39398 .67285 .39619 .67482 .39989 .67375 .39768 .67179 Mtetra
.39768 .67179 .39989 .67375 .4036 .67269 .40139 .67072 Mtetra
.40139 .67072 .4036 .67269 .40731 .67162 .4051 .66965 Mtetra
.4051 .66965 .40731 .67162 .41102 .67056 .40882 .66858 Mtetra
.40882 .66858 .41102 .67056 .41553 .64443 .41254 .66751 Mtetra
0 0 .18 r
.41254 .66751 .41553 .64443 .41923 .64335 .41705 .64136 Mtetra
.655 .753 .922 r
.41705 .64136 .41923 .64335 .42293 .64227 .42075 .64027 Mtetra
.42075 .64027 .42293 .64227 .42664 .64119 .42447 .63919 Mtetra
.42447 .63919 .42664 .64119 .43035 .6401 .42818 .6381 Mtetra
.42818 .6381 .43035 .6401 .43407 .63902 .43191 .63701 Mtetra
.43191 .63701 .43407 .63902 .4378 .63793 .43563 .63592 Mtetra
.43563 .63592 .4378 .63793 .44153 .63684 .43937 .63483 Mtetra
.43937 .63483 .44153 .63684 .44526 .63575 .4431 .63374 Mtetra
.4431 .63374 .44526 .63575 .449 .63466 .44685 .63264 Mtetra
.44685 .63264 .449 .63466 .45274 .63357 .45059 .63155 Mtetra
.45059 .63155 .45274 .63357 .45649 .63248 .45435 .63045 Mtetra
.45435 .63045 .45649 .63248 .46025 .63138 .4581 .62935 Mtetra
.4581 .62935 .46025 .63138 .46401 .63028 .46187 .62825 Mtetra
.46187 .62825 .46401 .63028 .46777 .62918 .46564 .62715 Mtetra
.46564 .62715 .46777 .62918 .47155 .62808 .46941 .62605 Mtetra
.46941 .62605 .47155 .62808 .47532 .62698 .47319 .62494 Mtetra
.47319 .62494 .47532 .62698 .4791 .62588 .47697 .62384 Mtetra
.47697 .62384 .4791 .62588 .48289 .62477 .48076 .62273 Mtetra
.48076 .62273 .48289 .62477 .48668 .62367 .48456 .62162 Mtetra
.48456 .62162 .48668 .62367 .49048 .62256 .48836 .62051 Mtetra
.48836 .62051 .49048 .62256 .49428 .62145 .49216 .61939 Mtetra
.49216 .61939 .49428 .62145 .49809 .62034 .49598 .61828 Mtetra
.49598 .61828 .49809 .62034 .5019 .61922 .49979 .61716 Mtetra
.952 .699 .518 r
.49979 .61716 .5019 .61922 .50572 .61811 .50416 .52793 Mtetra
.57 .368 .568 r
.50416 .52793 .50572 .61811 .50993 .52891 .50789 .52678 Mtetra
.662 .744 .911 r
.50789 .52678 .50993 .52891 .51366 .52776 .51162 .52563 Mtetra
.51162 .52563 .51366 .52776 .5174 .52661 .51536 .52448 Mtetra
.51536 .52448 .5174 .52661 .52114 .52546 .5191 .52332 Mtetra
.5191 .52332 .52114 .52546 .52489 .5243 .52285 .52217 Mtetra
.52285 .52217 .52489 .5243 .52864 .52315 .52661 .52101 Mtetra
.52661 .52101 .52864 .52315 .53239 .52199 .53037 .51985 Mtetra
.53037 .51985 .53239 .52199 .53616 .52083 .53413 .51869 Mtetra
.53413 .51869 .53616 .52083 .53992 .51967 .5379 .51753 Mtetra
.5379 .51753 .53992 .51967 .54369 .51851 .54168 .51636 Mtetra
.54168 .51636 .54369 .51851 .54747 .51735 .54546 .5152 Mtetra
.54546 .5152 .54747 .51735 .55125 .51618 .54924 .51403 Mtetra
.54924 .51403 .55125 .51618 .55504 .51502 .55303 .51286 Mtetra
.55303 .51286 .55504 .51502 .55994 .62265 .55683 .51169 Mtetra
.569 .366 .565 r
.55683 .51169 .55994 .62265 .56386 .62152 .56063 .51052 Mtetra
.539 .342 .562 r
.56063 .51052 .56386 .62152 .56655 .52112 .56455 .51896 Mtetra
.661 .745 .912 r
.56455 .51896 .56655 .52112 .57037 .51995 .56837 .51779 Mtetra
.56837 .51779 .57037 .51995 .5742 .51878 .5722 .51662 Mtetra
.5722 .51662 .5742 .51878 .57803 .51761 .57604 .51544 Mtetra
.57604 .51544 .57803 .51761 .58186 .51644 .57987 .51426 Mtetra
.57987 .51426 .58186 .51644 .5857 .51526 .58372 .51308 Mtetra
.58372 .51308 .5857 .51526 .58955 .51408 .58757 .5119 Mtetra
.58757 .5119 .58955 .51408 .5934 .5129 .59142 .51072 Mtetra
.59142 .51072 .5934 .5129 .59725 .51172 .59528 .50954 Mtetra
.59528 .50954 .59725 .51172 .60112 .51054 .59915 .50835 Mtetra
.59915 .50835 .60112 .51054 .60498 .50936 .60302 .50717 Mtetra
.60302 .50717 .60498 .50936 .60886 .50817 .60689 .50598 Mtetra
.60689 .50598 .60886 .50817 .61273 .50698 .61077 .50479 Mtetra
.61077 .50479 .61273 .50698 .61662 .50579 .61466 .5036 Mtetra
.61466 .5036 .61662 .50579 .6205 .5046 .61855 .5024 Mtetra
.61855 .5024 .6205 .5046 .6244 .50341 .62245 .50121 Mtetra
.62245 .50121 .6244 .50341 .6283 .50222 .62635 .50001 Mtetra
.62635 .50001 .6283 .50222 .6322 .50102 .63026 .49881 Mtetra
.63026 .49881 .6322 .50102 .63611 .49983 .63418 .49761 Mtetra
.63418 .49761 .63611 .49983 .64003 .49863 .6381 .49641 Mtetra
.6381 .49641 .64003 .49863 .64395 .49743 .64202 .49521 Mtetra
.64202 .49521 .64395 .49743 .64788 .49622 .64595 .494 Mtetra
.64595 .494 .64788 .49622 .65181 .49502 .64989 .49279 Mtetra
.64989 .49279 .65181 .49502 .65575 .49381 .65383 .49158 Mtetra
.65383 .49158 .65575 .49381 .65969 .49261 .65777 .49037 Mtetra
.65777 .49037 .65969 .49261 .66364 .4914 .66173 .48916 Mtetra
.66173 .48916 .66364 .4914 .66759 .49019 .66569 .48795 Mtetra
.66569 .48795 .66759 .49019 .67155 .48898 .66965 .48673 Mtetra
.66965 .48673 .67155 .48898 .67552 .48776 .67362 .48552 Mtetra
.67362 .48552 .67552 .48776 .67949 .48655 .67759 .4843 Mtetra
.67759 .4843 .67949 .48655 .68346 .48533 .68157 .48308 Mtetra
.68157 .48308 .68346 .48533 .68745 .48411 .68556 .48185 Mtetra
.68556 .48185 .68745 .48411 .69143 .48289 .68955 .48063 Mtetra
.68955 .48063 .69143 .48289 .69543 .48167 .69355 .4794 Mtetra
.69355 .4794 .69543 .48167 .69943 .48044 .69755 .47818 Mtetra
.69755 .47818 .69943 .48044 .70343 .47922 .70156 .47695 Mtetra
.70156 .47695 .70343 .47922 .70744 .47799 .70557 .47572 Mtetra
.70557 .47572 .70744 .47799 .71146 .47676 .70959 .47448 Mtetra
.70959 .47448 .71146 .47676 .71548 .47553 .71362 .47325 Mtetra
.71362 .47325 .71548 .47553 .71951 .47429 .71765 .47201 Mtetra
.71765 .47201 .71951 .47429 .72354 .47306 .72169 .47077 Mtetra
.72169 .47077 .72354 .47306 .72758 .47182 .72573 .46953 Mtetra
.72573 .46953 .72758 .47182 .73162 .47058 .72978 .46829 Mtetra
.72978 .46829 .73162 .47058 .73567 .46934 .73383 .46705 Mtetra
.887 .788 .745 r
.73383 .46705 .73567 .46934 .73941 .46322 .73757 .46092 Mtetra
.661 .745 .912 r
.73757 .46092 .73941 .46322 .74346 .46197 .74163 .45967 Mtetra
.74163 .45967 .74346 .46197 .74753 .46073 .7457 .45842 Mtetra
.7457 .45842 .74753 .46073 .75159 .45948 .74977 .45717 Mtetra
.74977 .45717 .75159 .45948 .75567 .45823 .75385 .45591 Mtetra
.75385 .45591 .75567 .45823 .75974 .45697 .75793 .45466 Mtetra
.75793 .45466 .75974 .45697 .76383 .45572 .76202 .4534 Mtetra
.76202 .4534 .76383 .45572 .76792 .45446 .76611 .45214 Mtetra
.76611 .45214 .76792 .45446 .7808 .56968 .77021 .45088 Mtetra
.569 .365 .565 r
.77021 .45088 .7808 .56968 .78506 .56847 .77432 .44962 Mtetra
.121 .043 .487 r
.77432 .44962 .78506 .56847 .78932 .56725 .78747 .56499 Mtetra
.652 .756 .926 r
.78747 .56499 .78932 .56725 .79358 .56602 .79174 .56376 Mtetra
.79174 .56376 .79358 .56602 .79786 .5648 .79602 .56254 Mtetra
.79602 .56254 .79786 .5648 .80214 .56358 .8003 .56131 Mtetra
.8003 .56131 .80214 .56358 .80642 .56235 .8046 .56008 Mtetra
.8046 .56008 .80642 .56235 .81071 .56112 .80889 .55885 Mtetra
.80889 .55885 .81071 .56112 .81501 .55989 .8132 .55761 Mtetra
.8132 .55761 .81501 .55989 .81932 .55866 .8175 .55638 Mtetra
.8175 .55638 .81932 .55866 .82363 .55742 .82182 .55514 Mtetra
.82182 .55514 .82363 .55742 .82795 .55619 .82614 .5539 Mtetra
.82614 .5539 .82795 .55619 .83227 .55495 .83047 .55266 Mtetra
.981 .719 .456 r
.83047 .55266 .83227 .55495 .8366 .55371 .83098 .50974 Mtetra
.576 .384 .584 r
.83098 .50974 .8366 .55371 .84094 .55247 .83527 .50848 Mtetra
.83527 .50848 .84094 .55247 .84528 .55122 .83956 .50722 Mtetra
.83956 .50722 .84528 .55122 .84963 .54998 .84385 .50596 Mtetra
.84385 .50596 .84963 .54998 .85399 .54873 .84816 .50469 Mtetra
.84816 .50469 .85399 .54873 .85835 .54748 .85247 .50342 Mtetra
.302 .192 .559 r
.85247 .50342 .85835 .54748 .86272 .54623 .8599 .53337 Mtetra
.602 .454 .653 r
.8599 .53337 .86272 .54623 .86603 .53444 .86427 .53211 Mtetra
.653 .755 .925 r
.86427 .53211 .86603 .53444 .8704 .53318 .86864 .53085 Mtetra
.86864 .53085 .8704 .53318 .87477 .53192 .87302 .52959 Mtetra
.87302 .52959 .87477 .53192 .87915 .53066 .87741 .52832 Mtetra
.87741 .52832 .87915 .53066 .88354 .52939 .8818 .52705 Mtetra
.8818 .52705 .88354 .52939 .88794 .52813 .8862 .52578 Mtetra
.8862 .52578 .88794 .52813 .89234 .52686 .89061 .52451 Mtetra
.89061 .52451 .89234 .52686 .89675 .52559 .89502 .52324 Mtetra
.89502 .52324 .89675 .52559 .90116 .52432 .89944 .52196 Mtetra
.89944 .52196 .90116 .52432 .90558 .52304 .90387 .52068 Mtetra
.90387 .52068 .90558 .52304 .91001 .52177 .9083 .5194 Mtetra
.9083 .5194 .91001 .52177 .91444 .52049 .91274 .51812 Mtetra
.91274 .51812 .91444 .52049 .91888 .51921 .91718 .51684 Mtetra
.91718 .51684 .91888 .51921 .92333 .51793 .92164 .51555 Mtetra
.92164 .51555 .92333 .51793 .92779 .51664 .9261 .51427 Mtetra
.9261 .51427 .92779 .51664 .93225 .51536 .93056 .51298 Mtetra
.93056 .51298 .93225 .51536 .93672 .51407 .93503 .51169 Mtetra
.93503 .51169 .93672 .51407 .94119 .51278 .93951 .51039 Mtetra
.93951 .51039 .94119 .51278 .94567 .51149 .944 .5091 Mtetra
.652 .755 .925 r
.33678 .68673 .33905 .68866 .34268 .68762 .34041 .68569 Mtetra
.34041 .68569 .34268 .68762 .34631 .68657 .34404 .68464 Mtetra
.34404 .68464 .34631 .68657 .34994 .68552 .34768 .68359 Mtetra
.34768 .68359 .34994 .68552 .35359 .68448 .35133 .68254 Mtetra
.35133 .68254 .35359 .68448 .35723 .68343 .35498 .68149 Mtetra
.35498 .68149 .35723 .68343 .36088 .68238 .35863 .68043 Mtetra
.35863 .68043 .36088 .68238 .36454 .68132 .36229 .67938 Mtetra
.36229 .67938 .36454 .68132 .3682 .68027 .36596 .67832 Mtetra
.36596 .67832 .3682 .68027 .37187 .67922 .36963 .67726 Mtetra
.36963 .67726 .37187 .67922 .37554 .67816 .3733 .6762 Mtetra
.3733 .6762 .37554 .67816 .37922 .6771 .37698 .67514 Mtetra
.37698 .67514 .37922 .6771 .3829 .67604 .38067 .67408 Mtetra
.38067 .67408 .3829 .67604 .38659 .67498 .38436 .67302 Mtetra
.38436 .67302 .38659 .67498 .39028 .67392 .38805 .67195 Mtetra
.38805 .67195 .39028 .67392 .39398 .67285 .39175 .67089 Mtetra
.39175 .67089 .39398 .67285 .39768 .67179 .39546 .66982 Mtetra
.39546 .66982 .39768 .67179 .40139 .67072 .39917 .66875 Mtetra
.39917 .66875 .40139 .67072 .4051 .66965 .40289 .66768 Mtetra
.40289 .66768 .4051 .66965 .40882 .66858 .40661 .66661 Mtetra
.40661 .66661 .40882 .66858 .41254 .66751 .41033 .66553 Mtetra
.933 .718 .589 r
.41033 .66553 .41254 .66751 .41705 .64136 .41486 .63935 Mtetra
.655 .753 .922 r
.41486 .63935 .41705 .64136 .42075 .64027 .41857 .63827 Mtetra
.41857 .63827 .42075 .64027 .42447 .63919 .42229 .63718 Mtetra
.42229 .63718 .42447 .63919 .42818 .6381 .42601 .63609 Mtetra
.42601 .63609 .42818 .6381 .43191 .63701 .42973 .635 Mtetra
.42973 .635 .43191 .63701 .43563 .63592 .43346 .63391 Mtetra
.43346 .63391 .43563 .63592 .43937 .63483 .4372 .63281 Mtetra
.4372 .63281 .43937 .63483 .4431 .63374 .44094 .63172 Mtetra
.44094 .63172 .4431 .63374 .44685 .63264 .44469 .63062 Mtetra
.44469 .63062 .44685 .63264 .45059 .63155 .44844 .62952 Mtetra
.44844 .62952 .45059 .63155 .45435 .63045 .45219 .62842 Mtetra
.45219 .62842 .45435 .63045 .4581 .62935 .45595 .62732 Mtetra
.45595 .62732 .4581 .62935 .46187 .62825 .45972 .62622 Mtetra
.45972 .62622 .46187 .62825 .46564 .62715 .46349 .62511 Mtetra
.46349 .62511 .46564 .62715 .46941 .62605 .46727 .62401 Mtetra
.46727 .62401 .46941 .62605 .47319 .62494 .47105 .6229 Mtetra
.47105 .6229 .47319 .62494 .47697 .62384 .47484 .62179 Mtetra
.47484 .62179 .47697 .62384 .48076 .62273 .47863 .62068 Mtetra
.47863 .62068 .48076 .62273 .48456 .62162 .48243 .61957 Mtetra
.48243 .61957 .48456 .62162 .48836 .62051 .48624 .61845 Mtetra
.48624 .61845 .48836 .62051 .49216 .61939 .49004 .61734 Mtetra
.49004 .61734 .49216 .61939 .49598 .61828 .49386 .61622 Mtetra
.49386 .61622 .49598 .61828 .49979 .61716 .49768 .6151 Mtetra
.952 .699 .518 r
.49768 .6151 .49979 .61716 .50416 .52793 .5021 .52581 Mtetra
.662 .744 .911 r
.5021 .52581 .50416 .52793 .50789 .52678 .50584 .52466 Mtetra
.50584 .52466 .50789 .52678 .51162 .52563 .50957 .5235 Mtetra
.50957 .5235 .51162 .52563 .51536 .52448 .51332 .52235 Mtetra
.51332 .52235 .51536 .52448 .5191 .52332 .51706 .52119 Mtetra
.51706 .52119 .5191 .52332 .52285 .52217 .52082 .52003 Mtetra
.52082 .52003 .52285 .52217 .52661 .52101 .52457 .51887 Mtetra
.52457 .51887 .52661 .52101 .53037 .51985 .52834 .51771 Mtetra
.52834 .51771 .53037 .51985 .53413 .51869 .5321 .51654 Mtetra
.5321 .51654 .53413 .51869 .5379 .51753 .53588 .51538 Mtetra
.53588 .51538 .5379 .51753 .54168 .51636 .53966 .51421 Mtetra
.53966 .51421 .54168 .51636 .54546 .5152 .54344 .51304 Mtetra
.54344 .51304 .54546 .5152 .54924 .51403 .54723 .51187 Mtetra
.54723 .51187 .54924 .51403 .55303 .51286 .55102 .5107 Mtetra
.55102 .5107 .55303 .51286 .55683 .51169 .55482 .50952 Mtetra
.55482 .50952 .55683 .51169 .56063 .51052 .55863 .50835 Mtetra
.868 .436 .025 r
.55863 .50835 .56063 .51052 .56455 .51896 .56255 .5168 Mtetra
.661 .745 .912 r
.56255 .5168 .56455 .51896 .56837 .51779 .56637 .51562 Mtetra
.56637 .51562 .56837 .51779 .5722 .51662 .5702 .51444 Mtetra
.5702 .51444 .5722 .51662 .57604 .51544 .57404 .51327 Mtetra
.57404 .51327 .57604 .51544 .57987 .51426 .57788 .51209 Mtetra
.57788 .51209 .57987 .51426 .58372 .51308 .58173 .5109 Mtetra
.58173 .5109 .58372 .51308 .58757 .5119 .58558 .50972 Mtetra
.58558 .50972 .58757 .5119 .59142 .51072 .58944 .50854 Mtetra
.58944 .50854 .59142 .51072 .59528 .50954 .5933 .50735 Mtetra
.5933 .50735 .59528 .50954 .59915 .50835 .59717 .50616 Mtetra
.59717 .50616 .59915 .50835 .60302 .50717 .60105 .50497 Mtetra
.60105 .50497 .60302 .50717 .60689 .50598 .60493 .50378 Mtetra
.60493 .50378 .60689 .50598 .61077 .50479 .60881 .50259 Mtetra
.60881 .50259 .61077 .50479 .61466 .5036 .6127 .50139 Mtetra
.6127 .50139 .61466 .5036 .61855 .5024 .6166 .50019 Mtetra
.6166 .50019 .61855 .5024 .62245 .50121 .6205 .499 Mtetra
.6205 .499 .62245 .50121 .62635 .50001 .6244 .4978 Mtetra
.6244 .4978 .62635 .50001 .63026 .49881 .62832 .49659 Mtetra
.62832 .49659 .63026 .49881 .63418 .49761 .63223 .49539 Mtetra
.63223 .49539 .63418 .49761 .6381 .49641 .63616 .49419 Mtetra
.63616 .49419 .6381 .49641 .64202 .49521 .64009 .49298 Mtetra
.64009 .49298 .64202 .49521 .64595 .494 .64402 .49177 Mtetra
.64402 .49177 .64595 .494 .64989 .49279 .64796 .49056 Mtetra
.64796 .49056 .64989 .49279 .65383 .49158 .6519 .48935 Mtetra
.6519 .48935 .65383 .49158 .65777 .49037 .65586 .48814 Mtetra
.65586 .48814 .65777 .49037 .66173 .48916 .65981 .48692 Mtetra
.65981 .48692 .66173 .48916 .66569 .48795 .66377 .4857 Mtetra
.66377 .4857 .66569 .48795 .66965 .48673 .66774 .48448 Mtetra
.66774 .48448 .66965 .48673 .67362 .48552 .67171 .48326 Mtetra
.67171 .48326 .67362 .48552 .67759 .4843 .67569 .48204 Mtetra
.67569 .48204 .67759 .4843 .68157 .48308 .67968 .48082 Mtetra
.67968 .48082 .68157 .48308 .68556 .48185 .68367 .47959 Mtetra
.68367 .47959 .68556 .48185 .68955 .48063 .68766 .47837 Mtetra
.68766 .47837 .68955 .48063 .69355 .4794 .69166 .47714 Mtetra
.69166 .47714 .69355 .4794 .69755 .47818 .69567 .47591 Mtetra
.69567 .47591 .69755 .47818 .70156 .47695 .69968 .47467 Mtetra
.69968 .47467 .70156 .47695 .70557 .47572 .7037 .47344 Mtetra
.7037 .47344 .70557 .47572 .70959 .47448 .70772 .4722 Mtetra
.70772 .4722 .70959 .47448 .71362 .47325 .71175 .47097 Mtetra
.71175 .47097 .71362 .47325 .71765 .47201 .71579 .46973 Mtetra
.71579 .46973 .71765 .47201 .72169 .47077 .71983 .46848 Mtetra
.71983 .46848 .72169 .47077 .72573 .46953 .72388 .46724 Mtetra
.72388 .46724 .72573 .46953 .72978 .46829 .72793 .466 Mtetra
.887 .788 .745 r
.72793 .466 .72978 .46829 .73383 .46705 .73168 .45986 Mtetra
.624 .52 .715 r
.73168 .45986 .73383 .46705 .73757 .46092 .73574 .45861 Mtetra
.661 .745 .912 r
.73574 .45861 .73757 .46092 .74163 .45967 .7398 .45736 Mtetra
.7398 .45736 .74163 .45967 .7457 .45842 .74387 .45611 Mtetra
.74387 .45611 .7457 .45842 .74977 .45717 .74794 .45485 Mtetra
.74794 .45485 .74977 .45717 .75385 .45591 .75202 .45359 Mtetra
.75202 .45359 .75385 .45591 .75793 .45466 .75611 .45233 Mtetra
.75611 .45233 .75793 .45466 .76202 .4534 .7602 .45107 Mtetra
.7602 .45107 .76202 .4534 .76611 .45214 .7643 .44981 Mtetra
.7643 .44981 .76611 .45214 .77021 .45088 .76841 .44855 Mtetra
.76841 .44855 .77021 .45088 .77432 .44962 .77252 .44728 Mtetra
.77252 .44728 .77432 .44962 .78747 .56499 .77663 .44601 Mtetra
.569 .364 .564 r
.77663 .44601 .78747 .56499 .79174 .56376 .78075 .44474 Mtetra
.314 .181 .534 r
.78075 .44474 .79174 .56376 .79602 .56254 .79087 .51871 Mtetra
.576 .384 .583 r
.79087 .51871 .79602 .56254 .8003 .56131 .7951 .51746 Mtetra
.7951 .51746 .8003 .56131 .8046 .56008 .79934 .51621 Mtetra
.79934 .51621 .8046 .56008 .80889 .55885 .80359 .51496 Mtetra
.80359 .51496 .80889 .55885 .8132 .55761 .80784 .51371 Mtetra
.80784 .51371 .8132 .55761 .8175 .55638 .8121 .51245 Mtetra
.8121 .51245 .8175 .55638 .82182 .55514 .81637 .5112 Mtetra
.81637 .5112 .82182 .55514 .82614 .5539 .82064 .50994 Mtetra
.82064 .50994 .82614 .5539 .83047 .55266 .82491 .50868 Mtetra
.82491 .50868 .83047 .55266 .83098 .50974 .8292 .50741 Mtetra
.655 .752 .921 r
.8292 .50741 .83098 .50974 .83527 .50848 .83349 .50615 Mtetra
.83349 .50615 .83527 .50848 .83956 .50722 .83778 .50488 Mtetra
.83778 .50488 .83956 .50722 .84385 .50596 .84209 .50362 Mtetra
.84209 .50362 .84385 .50596 .84816 .50469 .84639 .50235 Mtetra
.84639 .50235 .84816 .50469 .85247 .50342 .85071 .50107 Mtetra
.94 .581 .185 r
.85071 .50107 .85247 .50342 .8599 .53337 .85814 .53105 Mtetra
.653 .755 .925 r
.85814 .53105 .8599 .53337 .86427 .53211 .86251 .52978 Mtetra
.86251 .52978 .86427 .53211 .86864 .53085 .86689 .52852 Mtetra
.86689 .52852 .86864 .53085 .87302 .52959 .87127 .52725 Mtetra
.87127 .52725 .87302 .52959 .87741 .52832 .87566 .52598 Mtetra
.87566 .52598 .87741 .52832 .8818 .52705 .88006 .52471 Mtetra
.88006 .52471 .8818 .52705 .8862 .52578 .88446 .52343 Mtetra
.88446 .52343 .8862 .52578 .89061 .52451 .88887 .52216 Mtetra
.88887 .52216 .89061 .52451 .89502 .52324 .89329 .52088 Mtetra
.89329 .52088 .89502 .52324 .89944 .52196 .89772 .5196 Mtetra
.89772 .5196 .89944 .52196 .90387 .52068 .90215 .51832 Mtetra
.90215 .51832 .90387 .52068 .9083 .5194 .90658 .51704 Mtetra
.90658 .51704 .9083 .5194 .91274 .51812 .91103 .51575 Mtetra
.91103 .51575 .91274 .51812 .91718 .51684 .91548 .51447 Mtetra
.91548 .51447 .91718 .51684 .92164 .51555 .91994 .51318 Mtetra
.91994 .51318 .92164 .51555 .9261 .51427 .9244 .51189 Mtetra
.9244 .51189 .9261 .51427 .93056 .51298 .92887 .51059 Mtetra
.92887 .51059 .93056 .51298 .93503 .51169 .93335 .5093 Mtetra
.93335 .5093 .93503 .51169 .93951 .51039 .93783 .508 Mtetra
.93783 .508 .93951 .51039 .944 .5091 .94233 .5067 Mtetra
.652 .755 .925 r
.33451 .6848 .33678 .68673 .34041 .68569 .33814 .68375 Mtetra
.33814 .68375 .34041 .68569 .34404 .68464 .34178 .6827 Mtetra
.34178 .6827 .34404 .68464 .34768 .68359 .34542 .68165 Mtetra
.34542 .68165 .34768 .68359 .35133 .68254 .34907 .68059 Mtetra
.34907 .68059 .35133 .68254 .35498 .68149 .35272 .67954 Mtetra
.35272 .67954 .35498 .68149 .35863 .68043 .35638 .67848 Mtetra
.35638 .67848 .35863 .68043 .36229 .67938 .36004 .67743 Mtetra
.36004 .67743 .36229 .67938 .36596 .67832 .36371 .67637 Mtetra
.36371 .67637 .36596 .67832 .36963 .67726 .36738 .67531 Mtetra
.36738 .67531 .36963 .67726 .3733 .6762 .37106 .67425 Mtetra
.37106 .67425 .3733 .6762 .37698 .67514 .37474 .67318 Mtetra
.37474 .67318 .37698 .67514 .38067 .67408 .37843 .67212 Mtetra
.37843 .67212 .38067 .67408 .38436 .67302 .38212 .67105 Mtetra
.38212 .67105 .38436 .67302 .38805 .67195 .38582 .66998 Mtetra
.38582 .66998 .38805 .67195 .39175 .67089 .38953 .66891 Mtetra
.38953 .66891 .39175 .67089 .39546 .66982 .39324 .66784 Mtetra
.39324 .66784 .39546 .66982 .39917 .66875 .39695 .66677 Mtetra
.39695 .66677 .39917 .66875 .40289 .66768 .40067 .6657 Mtetra
.40067 .6657 .40289 .66768 .40661 .66661 .40439 .66462 Mtetra
.40439 .66462 .40661 .66661 .41033 .66553 .40812 .66354 Mtetra
.933 .718 .589 r
.40812 .66354 .41033 .66553 .41486 .63935 .41267 .63735 Mtetra
.655 .753 .922 r
.41267 .63735 .41486 .63935 .41857 .63827 .41638 .63626 Mtetra
.41638 .63626 .41857 .63827 .42229 .63718 .4201 .63517 Mtetra
.4201 .63517 .42229 .63718 .42601 .63609 .42383 .63407 Mtetra
.42383 .63407 .42601 .63609 .42973 .635 .42755 .63298 Mtetra
.42755 .63298 .42973 .635 .43346 .63391 .43129 .63189 Mtetra
.43129 .63189 .43346 .63391 .4372 .63281 .43503 .63079 Mtetra
.43503 .63079 .4372 .63281 .44094 .63172 .43877 .62969 Mtetra
.43877 .62969 .44094 .63172 .44469 .63062 .44252 .62859 Mtetra
.44252 .62859 .44469 .63062 .44844 .62952 .44627 .62749 Mtetra
.44627 .62749 .44844 .62952 .45219 .62842 .45003 .62639 Mtetra
.45003 .62639 .45219 .62842 .45595 .62732 .4538 .62528 Mtetra
.4538 .62528 .45595 .62732 .45972 .62622 .45757 .62418 Mtetra
.45757 .62418 .45972 .62622 .46349 .62511 .46134 .62307 Mtetra
.46134 .62307 .46349 .62511 .46727 .62401 .46512 .62196 Mtetra
.46512 .62196 .46727 .62401 .47105 .6229 .46891 .62085 Mtetra
.46891 .62085 .47105 .6229 .47484 .62179 .4727 .61974 Mtetra
.4727 .61974 .47484 .62179 .47863 .62068 .4765 .61862 Mtetra
.4765 .61862 .47863 .62068 .48243 .61957 .4803 .61751 Mtetra
.4803 .61751 .48243 .61957 .48624 .61845 .48411 .61639 Mtetra
.48411 .61639 .48624 .61845 .49004 .61734 .48792 .61527 Mtetra
.48792 .61527 .49004 .61734 .49386 .61622 .49174 .61415 Mtetra
.951 .699 .519 r
.49174 .61415 .49386 .61622 .49768 .6151 .49631 .52483 Mtetra
.57 .367 .567 r
.49631 .52483 .49768 .6151 .5021 .52581 .50004 .52368 Mtetra
.662 .744 .911 r
.50004 .52368 .5021 .52581 .50584 .52466 .50378 .52252 Mtetra
.50378 .52252 .50584 .52466 .50957 .5235 .50752 .52137 Mtetra
.50752 .52137 .50957 .5235 .51332 .52235 .51127 .52021 Mtetra
.51127 .52021 .51332 .52235 .51706 .52119 .51502 .51905 Mtetra
.51502 .51905 .51706 .52119 .52082 .52003 .51877 .51788 Mtetra
.51877 .51788 .52082 .52003 .52457 .51887 .52253 .51672 Mtetra
.52253 .51672 .52457 .51887 .52834 .51771 .5263 .51556 Mtetra
.5263 .51556 .52834 .51771 .5321 .51654 .53007 .51439 Mtetra
.53007 .51439 .5321 .51654 .53588 .51538 .53385 .51322 Mtetra
.53385 .51322 .53588 .51538 .53966 .51421 .53763 .51205 Mtetra
.53763 .51205 .53966 .51421 .54344 .51304 .54142 .51088 Mtetra
.54142 .51088 .54344 .51304 .54723 .51187 .54521 .5097 Mtetra
.54521 .5097 .54723 .51187 .55102 .5107 .54901 .50853 Mtetra
.54901 .50853 .55102 .5107 .55482 .50952 .55281 .50735 Mtetra
.55281 .50735 .55482 .50952 .55863 .50835 .55662 .50617 Mtetra
.868 .436 .025 r
.55662 .50617 .55863 .50835 .56255 .5168 .56053 .51463 Mtetra
.661 .745 .912 r
.56053 .51463 .56255 .5168 .56637 .51562 .56436 .51345 Mtetra
.56436 .51345 .56637 .51562 .5702 .51444 .5682 .51227 Mtetra
.5682 .51227 .5702 .51444 .57404 .51327 .57204 .51109 Mtetra
.57204 .51109 .57404 .51327 .57788 .51209 .57588 .5099 Mtetra
.57588 .5099 .57788 .51209 .58173 .5109 .57974 .50872 Mtetra
.57974 .50872 .58173 .5109 .58558 .50972 .58359 .50753 Mtetra
.58359 .50753 .58558 .50972 .58944 .50854 .58745 .50634 Mtetra
.58745 .50634 .58944 .50854 .5933 .50735 .59132 .50515 Mtetra
.59132 .50515 .5933 .50735 .59717 .50616 .59519 .50396 Mtetra
.59519 .50396 .59717 .50616 .60105 .50497 .59907 .50277 Mtetra
.59907 .50277 .60105 .50497 .60493 .50378 .60295 .50157 Mtetra
.60295 .50157 .60493 .50378 .60881 .50259 .60684 .50038 Mtetra
.60684 .50038 .60881 .50259 .6127 .50139 .61074 .49918 Mtetra
.61074 .49918 .6127 .50139 .6166 .50019 .61464 .49798 Mtetra
.61464 .49798 .6166 .50019 .6205 .499 .61854 .49678 Mtetra
.61854 .49678 .6205 .499 .6244 .4978 .62245 .49558 Mtetra
.62245 .49558 .6244 .4978 .62832 .49659 .62637 .49437 Mtetra
.62637 .49437 .62832 .49659 .63223 .49539 .63029 .49316 Mtetra
.63029 .49316 .63223 .49539 .63616 .49419 .63421 .49196 Mtetra
.63421 .49196 .63616 .49419 .64009 .49298 .63815 .49075 Mtetra
.63815 .49075 .64009 .49298 .64402 .49177 .64208 .48954 Mtetra
.64208 .48954 .64402 .49177 .64796 .49056 .64603 .48832 Mtetra
.64603 .48832 .64796 .49056 .6519 .48935 .64998 .48711 Mtetra
.64998 .48711 .6519 .48935 .65586 .48814 .65393 .48589 Mtetra
.65393 .48589 .65586 .48814 .65981 .48692 .65789 .48467 Mtetra
.65789 .48467 .65981 .48692 .66377 .4857 .66186 .48345 Mtetra
.66186 .48345 .66377 .4857 .66774 .48448 .66583 .48223 Mtetra
.66583 .48223 .66774 .48448 .67171 .48326 .6698 .48101 Mtetra
.6698 .48101 .67171 .48326 .67569 .48204 .67379 .47978 Mtetra
.67379 .47978 .67569 .48204 .67968 .48082 .67777 .47855 Mtetra
.67777 .47855 .67968 .48082 .68367 .47959 .68177 .47733 Mtetra
.68177 .47733 .68367 .47959 .68766 .47837 .68577 .4761 Mtetra
.68577 .4761 .68766 .47837 .69166 .47714 .68977 .47486 Mtetra
.68977 .47486 .69166 .47714 .69567 .47591 .69378 .47363 Mtetra
.69378 .47363 .69567 .47591 .69968 .47467 .6978 .47239 Mtetra
.6978 .47239 .69968 .47467 .7037 .47344 .70182 .47116 Mtetra
.70182 .47116 .7037 .47344 .70772 .4722 .70585 .46992 Mtetra
.70585 .46992 .70772 .4722 .71175 .47097 .70988 .46868 Mtetra
.70988 .46868 .71175 .47097 .71579 .46973 .71392 .46743 Mtetra
.71392 .46743 .71579 .46973 .71983 .46848 .71797 .46619 Mtetra
.71797 .46619 .71983 .46848 .72388 .46724 .72202 .46494 Mtetra
.72202 .46494 .72388 .46724 .72793 .466 .72607 .46369 Mtetra
.887 .788 .745 r
.72607 .46369 .72793 .466 .73168 .45986 .72983 .45755 Mtetra
.661 .745 .912 r
.72983 .45755 .73168 .45986 .73574 .45861 .73389 .4563 Mtetra
.73389 .4563 .73574 .45861 .7398 .45736 .73796 .45504 Mtetra
.73796 .45504 .7398 .45736 .74387 .45611 .74203 .45379 Mtetra
.74203 .45379 .74387 .45611 .74794 .45485 .74611 .45253 Mtetra
.74611 .45253 .74794 .45485 .75202 .45359 .7502 .45127 Mtetra
.7502 .45127 .75202 .45359 .75611 .45233 .75429 .45001 Mtetra
.75429 .45001 .75611 .45233 .7602 .45107 .75838 .44874 Mtetra
.75838 .44874 .7602 .45107 .7643 .44981 .76249 .44748 Mtetra
.76249 .44748 .7643 .44981 .76841 .44855 .76659 .44621 Mtetra
.76659 .44621 .76841 .44855 .77252 .44728 .77071 .44494 Mtetra
.77071 .44494 .77252 .44728 .77663 .44601 .77483 .44367 Mtetra
.77483 .44367 .77663 .44601 .78075 .44474 .77896 .44239 Mtetra
.97 .651 .326 r
.77896 .44239 .78075 .44474 .79087 .51871 .78904 .5164 Mtetra
.655 .752 .921 r
.78904 .5164 .79087 .51871 .7951 .51746 .79328 .51515 Mtetra
.79328 .51515 .7951 .51746 .79934 .51621 .79752 .5139 Mtetra
.79752 .5139 .79934 .51621 .80359 .51496 .80178 .51265 Mtetra
.80178 .51265 .80359 .51496 .80784 .51371 .80603 .51139 Mtetra
.80603 .51139 .80784 .51371 .8121 .51245 .81029 .51013 Mtetra
.81029 .51013 .8121 .51245 .81637 .5112 .81456 .50887 Mtetra
.81456 .50887 .81637 .5112 .82064 .50994 .81884 .50761 Mtetra
.81884 .50761 .82064 .50994 .82491 .50868 .82312 .50634 Mtetra
.82312 .50634 .82491 .50868 .8292 .50741 .82741 .50508 Mtetra
.82741 .50508 .8292 .50741 .83349 .50615 .8317 .50381 Mtetra
.8317 .50381 .83349 .50615 .83778 .50488 .836 .50254 Mtetra
.836 .50254 .83778 .50488 .84209 .50362 .84031 .50127 Mtetra
.84031 .50127 .84209 .50362 .84639 .50235 .84463 .5 Mtetra
.84463 .5 .84639 .50235 .85071 .50107 .84895 .49872 Mtetra
.94 .581 .185 r
.84895 .49872 .85071 .50107 .85814 .53105 .85636 .52871 Mtetra
.653 .755 .925 r
.85636 .52871 .85814 .53105 .86251 .52978 .86074 .52744 Mtetra
.86074 .52744 .86251 .52978 .86689 .52852 .86512 .52617 Mtetra
.86512 .52617 .86689 .52852 .87127 .52725 .86951 .5249 Mtetra
.86951 .5249 .87127 .52725 .87566 .52598 .87391 .52363 Mtetra
.87391 .52363 .87566 .52598 .88006 .52471 .87831 .52235 Mtetra
.87831 .52235 .88006 .52471 .88446 .52343 .88272 .52108 Mtetra
.88272 .52108 .88446 .52343 .88887 .52216 .88713 .5198 Mtetra
.88713 .5198 .88887 .52216 .89329 .52088 .89156 .51852 Mtetra
.89156 .51852 .89329 .52088 .89772 .5196 .89599 .51723 Mtetra
.89599 .51723 .89772 .5196 .90215 .51832 .90042 .51595 Mtetra
.90042 .51595 .90215 .51832 .90658 .51704 .90486 .51466 Mtetra
.90486 .51466 .90658 .51704 .91103 .51575 .90931 .51337 Mtetra
.90931 .51337 .91103 .51575 .91548 .51447 .91377 .51208 Mtetra
.91377 .51208 .91548 .51447 .91994 .51318 .91823 .51079 Mtetra
.91823 .51079 .91994 .51318 .9244 .51189 .9227 .5095 Mtetra
.9227 .5095 .9244 .51189 .92887 .51059 .92718 .5082 Mtetra
.92718 .5082 .92887 .51059 .93335 .5093 .93166 .5069 Mtetra
.93166 .5069 .93335 .5093 .93783 .508 .93615 .5056 Mtetra
.93615 .5056 .93783 .508 .94233 .5067 .94065 .5043 Mtetra
.652 .755 .925 r
.33223 .68286 .33451 .6848 .33814 .68375 .33586 .68181 Mtetra
.33586 .68181 .33814 .68375 .34178 .6827 .3395 .68076 Mtetra
.3395 .68076 .34178 .6827 .34542 .68165 .34315 .6797 Mtetra
.34315 .6797 .34542 .68165 .34907 .68059 .3468 .67865 Mtetra
.3468 .67865 .34907 .68059 .35272 .67954 .35045 .67759 Mtetra
.35045 .67759 .35272 .67954 .35638 .67848 .35412 .67653 Mtetra
.35412 .67653 .35638 .67848 .36004 .67743 .35778 .67547 Mtetra
.35778 .67547 .36004 .67743 .36371 .67637 .36145 .67441 Mtetra
.36145 .67441 .36371 .67637 .36738 .67531 .36513 .67335 Mtetra
.36513 .67335 .36738 .67531 .37106 .67425 .36881 .67228 Mtetra
.36881 .67228 .37106 .67425 .37474 .67318 .3725 .67121 Mtetra
.3725 .67121 .37474 .67318 .37843 .67212 .37619 .67015 Mtetra
.37619 .67015 .37843 .67212 .38212 .67105 .37988 .66908 Mtetra
.37988 .66908 .38212 .67105 .38582 .66998 .38359 .66801 Mtetra
.38359 .66801 .38582 .66998 .38953 .66891 .38729 .66694 Mtetra
.38729 .66694 .38953 .66891 .39324 .66784 .391 .66586 Mtetra
.391 .66586 .39324 .66784 .39695 .66677 .39472 .66479 Mtetra
.39472 .66479 .39695 .66677 .40067 .6657 .39844 .66371 Mtetra
.39844 .66371 .40067 .6657 .40439 .66462 .40217 .66263 Mtetra
.40217 .66263 .40439 .66462 .40812 .66354 .4059 .66155 Mtetra
.933 .718 .589 r
.4059 .66155 .40812 .66354 .41267 .63735 .41047 .63533 Mtetra
.655 .753 .922 r
.41047 .63533 .41267 .63735 .41638 .63626 .41419 .63424 Mtetra
.41419 .63424 .41638 .63626 .4201 .63517 .41791 .63315 Mtetra
.41791 .63315 .4201 .63517 .42383 .63407 .42164 .63205 Mtetra
.42164 .63205 .42383 .63407 .42755 .63298 .42537 .63096 Mtetra
.42537 .63096 .42755 .63298 .43129 .63189 .42911 .62986 Mtetra
.42911 .62986 .43129 .63189 .43503 .63079 .43285 .62876 Mtetra
.43285 .62876 .43503 .63079 .43877 .62969 .4366 .62766 Mtetra
.4366 .62766 .43877 .62969 .44252 .62859 .44035 .62656 Mtetra
.44035 .62656 .44252 .62859 .44627 .62749 .44411 .62545 Mtetra
.44411 .62545 .44627 .62749 .45003 .62639 .44787 .62435 Mtetra
.44787 .62435 .45003 .62639 .4538 .62528 .45164 .62324 Mtetra
.45164 .62324 .4538 .62528 .45757 .62418 .45541 .62213 Mtetra
.45541 .62213 .45757 .62418 .46134 .62307 .45919 .62102 Mtetra
.45919 .62102 .46134 .62307 .46512 .62196 .46297 .61991 Mtetra
.46297 .61991 .46512 .62196 .46891 .62085 .46676 .61879 Mtetra
.46676 .61879 .46891 .62085 .4727 .61974 .47056 .61768 Mtetra
.47056 .61768 .4727 .61974 .4765 .61862 .47436 .61656 Mtetra
.47436 .61656 .4765 .61862 .4803 .61751 .47816 .61545 Mtetra
.47816 .61545 .4803 .61751 .48411 .61639 .48197 .61433 Mtetra
.48197 .61433 .48411 .61639 .48792 .61527 .48579 .6132 Mtetra
.48579 .6132 .48792 .61527 .49174 .61415 .48961 .61208 Mtetra
.951 .699 .519 r
.48961 .61208 .49174 .61415 .49631 .52483 .49424 .5227 Mtetra
.662 .744 .911 r
.49424 .5227 .49631 .52483 .50004 .52368 .49798 .52154 Mtetra
.49798 .52154 .50004 .52368 .50378 .52252 .50172 .52039 Mtetra
.50172 .52039 .50378 .52252 .50752 .52137 .50546 .51923 Mtetra
.50546 .51923 .50752 .52137 .51127 .52021 .50921 .51806 Mtetra
.50921 .51806 .51127 .52021 .51502 .51905 .51296 .5169 Mtetra
.51296 .5169 .51502 .51905 .51877 .51788 .51672 .51574 Mtetra
.51672 .51574 .51877 .51788 .52253 .51672 .52049 .51457 Mtetra
.52049 .51457 .52253 .51672 .5263 .51556 .52426 .5134 Mtetra
.52426 .5134 .5263 .51556 .53007 .51439 .52803 .51223 Mtetra
.52803 .51223 .53007 .51439 .53385 .51322 .53181 .51106 Mtetra
.53181 .51106 .53385 .51322 .53763 .51205 .5356 .50989 Mtetra
.5356 .50989 .53763 .51205 .54142 .51088 .53939 .50871 Mtetra
.53939 .50871 .54142 .51088 .54521 .5097 .54318 .50753 Mtetra
.54318 .50753 .54521 .5097 .54901 .50853 .54699 .50636 Mtetra
.54699 .50636 .54901 .50853 .55281 .50735 .55079 .50518 Mtetra
.55079 .50518 .55281 .50735 .55662 .50617 .5546 .504 Mtetra
.5546 .504 .55662 .50617 .56053 .51463 .55842 .50281 Mtetra
.206 .182 .609 r
.55842 .50281 .56053 .51463 .56436 .51345 .56235 .51127 Mtetra
.661 .745 .912 r
.56235 .51127 .56436 .51345 .5682 .51227 .56619 .51008 Mtetra
.56619 .51008 .5682 .51227 .57204 .51109 .57003 .5089 Mtetra
.57003 .5089 .57204 .51109 .57588 .5099 .57388 .50771 Mtetra
.57388 .50771 .57588 .5099 .57974 .50872 .57774 .50653 Mtetra
.57774 .50653 .57974 .50872 .58359 .50753 .5816 .50534 Mtetra
.5816 .50534 .58359 .50753 .58745 .50634 .58546 .50415 Mtetra
.58546 .50415 .58745 .50634 .59132 .50515 .58933 .50295 Mtetra
.58933 .50295 .59132 .50515 .59519 .50396 .59321 .50176 Mtetra
.59321 .50176 .59519 .50396 .59907 .50277 .59709 .50056 Mtetra
.59709 .50056 .59907 .50277 .60295 .50157 .60098 .49936 Mtetra
.60098 .49936 .60295 .50157 .60684 .50038 .60487 .49817 Mtetra
.60487 .49817 .60684 .50038 .61074 .49918 .60877 .49696 Mtetra
.60877 .49696 .61074 .49918 .61464 .49798 .61267 .49576 Mtetra
.61267 .49576 .61464 .49798 .61854 .49678 .61658 .49456 Mtetra
.61658 .49456 .61854 .49678 .62245 .49558 .62049 .49335 Mtetra
.62049 .49335 .62245 .49558 .62637 .49437 .62441 .49214 Mtetra
.62441 .49214 .62637 .49437 .63029 .49316 .62834 .49093 Mtetra
.62834 .49093 .63029 .49316 .63421 .49196 .63227 .48972 Mtetra
.63227 .48972 .63421 .49196 .63815 .49075 .6362 .48851 Mtetra
.6362 .48851 .63815 .49075 .64208 .48954 .64014 .48729 Mtetra
.64014 .48729 .64208 .48954 .64603 .48832 .64409 .48608 Mtetra
.64409 .48608 .64603 .48832 .64998 .48711 .64804 .48486 Mtetra
.64804 .48486 .64998 .48711 .65393 .48589 .652 .48364 Mtetra
.652 .48364 .65393 .48589 .65789 .48467 .65597 .48242 Mtetra
.65597 .48242 .65789 .48467 .66186 .48345 .65993 .48119 Mtetra
.65993 .48119 .66186 .48345 .66583 .48223 .66391 .47997 Mtetra
.66391 .47997 .66583 .48223 .6698 .48101 .66789 .47874 Mtetra
.66789 .47874 .6698 .48101 .67379 .47978 .67188 .47751 Mtetra
.67188 .47751 .67379 .47978 .67777 .47855 .67587 .47628 Mtetra
.67587 .47628 .67777 .47855 .68177 .47733 .67987 .47505 Mtetra
.67987 .47505 .68177 .47733 .68577 .4761 .68387 .47382 Mtetra
.68387 .47382 .68577 .4761 .68977 .47486 .68788 .47258 Mtetra
.68788 .47258 .68977 .47486 .69378 .47363 .69189 .47135 Mtetra
.69189 .47135 .69378 .47363 .6978 .47239 .69591 .47011 Mtetra
.69591 .47011 .6978 .47239 .70182 .47116 .69994 .46887 Mtetra
.69994 .46887 .70182 .47116 .70585 .46992 .70397 .46762 Mtetra
.70397 .46762 .70585 .46992 .70988 .46868 .70801 .46638 Mtetra
.70801 .46638 .70988 .46868 .71392 .46743 .71205 .46513 Mtetra
.71205 .46513 .71392 .46743 .71797 .46619 .7161 .46389 Mtetra
.7161 .46389 .71797 .46619 .72202 .46494 .72015 .46264 Mtetra
.972 .719 .492 r
.72015 .46264 .72202 .46494 .72607 .46369 .72186 .42264 Mtetra
.206 .118 .529 r
.72186 .42264 .72607 .46369 .72983 .45755 .72798 .45524 Mtetra
.661 .745 .912 r
.72798 .45524 .72983 .45755 .73389 .4563 .73204 .45398 Mtetra
.73204 .45398 .73389 .4563 .73796 .45504 .73611 .45272 Mtetra
.73611 .45272 .73796 .45504 .74203 .45379 .74019 .45146 Mtetra
.74019 .45146 .74203 .45379 .74611 .45253 .74428 .4502 Mtetra
.74428 .4502 .74611 .45253 .7502 .45127 .74836 .44894 Mtetra
.74836 .44894 .7502 .45127 .75429 .45001 .75246 .44767 Mtetra
.75246 .44767 .75429 .45001 .75838 .44874 .75656 .4464 Mtetra
.75656 .4464 .75838 .44874 .76249 .44748 .76067 .44513 Mtetra
.76067 .44513 .76249 .44748 .76659 .44621 .76478 .44386 Mtetra
.76478 .44386 .76659 .44621 .77071 .44494 .7689 .44259 Mtetra
.7689 .44259 .77071 .44494 .77483 .44367 .77302 .44132 Mtetra
.77302 .44132 .77483 .44367 .77896 .44239 .77715 .44004 Mtetra
.97 .651 .326 r
.77715 .44004 .77896 .44239 .78904 .5164 .78721 .51409 Mtetra
.655 .752 .921 r
.78721 .51409 .78904 .5164 .79328 .51515 .79145 .51284 Mtetra
.79145 .51284 .79328 .51515 .79752 .5139 .7957 .51158 Mtetra
.7957 .51158 .79752 .5139 .80178 .51265 .79996 .51032 Mtetra
.79996 .51032 .80178 .51265 .80603 .51139 .80422 .50906 Mtetra
.80422 .50906 .80603 .51139 .81029 .51013 .80848 .5078 Mtetra
.80848 .5078 .81029 .51013 .81456 .50887 .81276 .50654 Mtetra
.81276 .50654 .81456 .50887 .81884 .50761 .81704 .50527 Mtetra
.81704 .50527 .81884 .50761 .82312 .50634 .82132 .50401 Mtetra
.82132 .50401 .82312 .50634 .82741 .50508 .82562 .50274 Mtetra
.82562 .50274 .82741 .50508 .8317 .50381 .82992 .50147 Mtetra
.82992 .50147 .8317 .50381 .836 .50254 .83422 .50019 Mtetra
.83422 .50019 .836 .50254 .84031 .50127 .83853 .49892 Mtetra
.83853 .49892 .84031 .50127 .84463 .5 .84285 .49764 Mtetra
.84285 .49764 .84463 .5 .84895 .49872 .84718 .49636 Mtetra
.84718 .49636 .84895 .49872 .85636 .52871 .85151 .49508 Mtetra
.191 .123 .545 r
.85151 .49508 .85636 .52871 .86074 .52744 .85897 .5251 Mtetra
.653 .755 .925 r
.85897 .5251 .86074 .52744 .86512 .52617 .86335 .52383 Mtetra
.86335 .52383 .86512 .52617 .86951 .5249 .86775 .52255 Mtetra
.86775 .52255 .86951 .5249 .87391 .52363 .87215 .52127 Mtetra
.87215 .52127 .87391 .52363 .87831 .52235 .87656 .52 Mtetra
.87656 .52 .87831 .52235 .88272 .52108 .88097 .51871 Mtetra
.88097 .51871 .88272 .52108 .88713 .5198 .88539 .51743 Mtetra
.88539 .51743 .88713 .5198 .89156 .51852 .88982 .51615 Mtetra
.88982 .51615 .89156 .51852 .89599 .51723 .89425 .51486 Mtetra
.89425 .51486 .89599 .51723 .90042 .51595 .89869 .51357 Mtetra
.89869 .51357 .90042 .51595 .90486 .51466 .90314 .51228 Mtetra
.90314 .51228 .90486 .51466 .90931 .51337 .90759 .51099 Mtetra
.90759 .51099 .90931 .51337 .91377 .51208 .91205 .5097 Mtetra
.91205 .5097 .91377 .51208 .91823 .51079 .91652 .5084 Mtetra
.91652 .5084 .91823 .51079 .9227 .5095 .921 .5071 Mtetra
.921 .5071 .9227 .5095 .92718 .5082 .92548 .5058 Mtetra
.92548 .5058 .92718 .5082 .93166 .5069 .92996 .5045 Mtetra
.92996 .5045 .93166 .5069 .93615 .5056 .93446 .5032 Mtetra
.93446 .5032 .93615 .5056 .94065 .5043 .93896 .50189 Mtetra
.652 .755 .925 r
.32994 .68092 .33223 .68286 .33586 .68181 .33358 .67986 Mtetra
.33358 .67986 .33586 .68181 .3395 .68076 .33722 .67881 Mtetra
.33722 .67881 .3395 .68076 .34315 .6797 .34087 .67775 Mtetra
.34087 .67775 .34315 .6797 .3468 .67865 .34453 .67669 Mtetra
.34453 .67669 .3468 .67865 .35045 .67759 .34818 .67563 Mtetra
.34818 .67563 .35045 .67759 .35412 .67653 .35185 .67457 Mtetra
.35185 .67457 .35412 .67653 .35778 .67547 .35552 .67351 Mtetra
.35552 .67351 .35778 .67547 .36145 .67441 .35919 .67244 Mtetra
.35919 .67244 .36145 .67441 .36513 .67335 .36287 .67138 Mtetra
.36287 .67138 .36513 .67335 .36881 .67228 .36656 .67031 Mtetra
.36656 .67031 .36881 .67228 .3725 .67121 .37024 .66924 Mtetra
.37024 .66924 .3725 .67121 .37619 .67015 .37394 .66817 Mtetra
.37394 .66817 .37619 .67015 .37988 .66908 .37764 .6671 Mtetra
.37764 .6671 .37988 .66908 .38359 .66801 .38134 .66603 Mtetra
.38134 .66603 .38359 .66801 .38729 .66694 .38505 .66495 Mtetra
.38505 .66495 .38729 .66694 .391 .66586 .38877 .66388 Mtetra
.38877 .66388 .391 .66586 .39472 .66479 .39249 .6628 Mtetra
.39249 .6628 .39472 .66479 .39844 .66371 .39621 .66172 Mtetra
.39621 .66172 .39844 .66371 .40217 .66263 .39994 .66064 Mtetra
.39994 .66064 .40217 .66263 .4059 .66155 .40368 .65956 Mtetra
.933 .718 .589 r
.40368 .65956 .4059 .66155 .41047 .63533 .40827 .63332 Mtetra
.655 .753 .922 r
.40827 .63332 .41047 .63533 .41419 .63424 .41199 .63222 Mtetra
.41199 .63222 .41419 .63424 .41791 .63315 .41571 .63113 Mtetra
.41571 .63113 .41791 .63315 .42164 .63205 .41944 .63003 Mtetra
.41944 .63003 .42164 .63205 .42537 .63096 .42318 .62893 Mtetra
.42318 .62893 .42537 .63096 .42911 .62986 .42692 .62783 Mtetra
.42692 .62783 .42911 .62986 .43285 .62876 .43067 .62673 Mtetra
.43067 .62673 .43285 .62876 .4366 .62766 .43442 .62562 Mtetra
.43442 .62562 .4366 .62766 .44035 .62656 .43817 .62452 Mtetra
.43817 .62452 .44035 .62656 .44411 .62545 .44193 .62341 Mtetra
.44193 .62341 .44411 .62545 .44787 .62435 .4457 .6223 Mtetra
.4457 .6223 .44787 .62435 .45164 .62324 .44947 .62119 Mtetra
.44947 .62119 .45164 .62324 .45541 .62213 .45325 .62008 Mtetra
.45325 .62008 .45541 .62213 .45919 .62102 .45703 .61897 Mtetra
.45703 .61897 .45919 .62102 .46297 .61991 .46082 .61785 Mtetra
.46082 .61785 .46297 .61991 .46676 .61879 .46461 .61674 Mtetra
.46461 .61674 .46676 .61879 .47056 .61768 .46841 .61562 Mtetra
.46841 .61562 .47056 .61768 .47436 .61656 .47221 .6145 Mtetra
.47221 .6145 .47436 .61656 .47816 .61545 .47602 .61338 Mtetra
.47602 .61338 .47816 .61545 .48197 .61433 .47983 .61225 Mtetra
.47983 .61225 .48197 .61433 .48579 .6132 .48365 .61113 Mtetra
.48365 .61113 .48579 .6132 .48961 .61208 .48748 .61001 Mtetra
.951 .699 .519 r
.48748 .61001 .48961 .61208 .49424 .5227 .49217 .52056 Mtetra
.662 .744 .911 r
.49217 .52056 .49424 .5227 .49798 .52154 .49591 .5194 Mtetra
.49591 .5194 .49798 .52154 .50172 .52039 .49965 .51824 Mtetra
.49965 .51824 .50172 .52039 .50546 .51923 .5034 .51708 Mtetra
.5034 .51708 .50546 .51923 .50921 .51806 .50715 .51591 Mtetra
.50715 .51591 .50921 .51806 .51296 .5169 .51091 .51475 Mtetra
.51091 .51475 .51296 .5169 .51672 .51574 .51467 .51358 Mtetra
.51467 .51358 .51672 .51574 .52049 .51457 .51844 .51241 Mtetra
.51844 .51241 .52049 .51457 .52426 .5134 .52221 .51124 Mtetra
.52221 .51124 .52426 .5134 .52803 .51223 .52599 .51007 Mtetra
.52599 .51007 .52803 .51223 .53181 .51106 .52977 .50889 Mtetra
.52977 .50889 .53181 .51106 .5356 .50989 .53356 .50772 Mtetra
.53356 .50772 .5356 .50989 .53939 .50871 .53736 .50654 Mtetra
.53736 .50654 .53939 .50871 .54318 .50753 .54115 .50536 Mtetra
.54115 .50536 .54318 .50753 .54699 .50636 .54496 .50418 Mtetra
.54496 .50418 .54699 .50636 .55079 .50518 .54877 .50299 Mtetra
.54877 .50299 .55079 .50518 .5546 .504 .55258 .50181 Mtetra
.55258 .50181 .5546 .504 .55842 .50281 .5564 .50062 Mtetra
.867 .434 .021 r
.5564 .50062 .55842 .50281 .56235 .51127 .56033 .50908 Mtetra
.661 .745 .912 r
.56033 .50908 .56235 .51127 .56619 .51008 .56417 .5079 Mtetra
.56417 .5079 .56619 .51008 .57003 .5089 .56802 .50671 Mtetra
.56802 .50671 .57003 .5089 .57388 .50771 .57187 .50552 Mtetra
.57187 .50552 .57388 .50771 .57774 .50653 .57573 .50433 Mtetra
.57573 .50433 .57774 .50653 .5816 .50534 .5796 .50314 Mtetra
.5796 .50314 .5816 .50534 .58546 .50415 .58346 .50194 Mtetra
.58346 .50194 .58546 .50415 .58933 .50295 .58734 .50075 Mtetra
.58734 .50075 .58933 .50295 .59321 .50176 .59122 .49955 Mtetra
.59122 .49955 .59321 .50176 .59709 .50056 .5951 .49835 Mtetra
.5951 .49835 .59709 .50056 .60098 .49936 .59899 .49715 Mtetra
.59899 .49715 .60098 .49936 .60487 .49817 .60289 .49595 Mtetra
.60289 .49595 .60487 .49817 .60877 .49696 .60679 .49474 Mtetra
.60679 .49474 .60877 .49696 .61267 .49576 .6107 .49354 Mtetra
.6107 .49354 .61267 .49576 .61658 .49456 .61461 .49233 Mtetra
.61461 .49233 .61658 .49456 .62049 .49335 .61853 .49112 Mtetra
.61853 .49112 .62049 .49335 .62441 .49214 .62245 .48991 Mtetra
.62245 .48991 .62441 .49214 .62834 .49093 .62638 .4887 Mtetra
.62638 .4887 .62834 .49093 .63227 .48972 .63031 .48748 Mtetra
.63031 .48748 .63227 .48972 .6362 .48851 .63425 .48626 Mtetra
.63425 .48626 .6362 .48851 .64014 .48729 .6382 .48505 Mtetra
.6382 .48505 .64014 .48729 .64409 .48608 .64215 .48383 Mtetra
.64215 .48383 .64409 .48608 .64804 .48486 .64611 .48261 Mtetra
.64611 .48261 .64804 .48486 .652 .48364 .65007 .48138 Mtetra
.65007 .48138 .652 .48364 .65597 .48242 .65403 .48016 Mtetra
.65403 .48016 .65597 .48242 .65993 .48119 .65801 .47893 Mtetra
.65801 .47893 .65993 .48119 .66391 .47997 .66199 .4777 Mtetra
.66199 .4777 .66391 .47997 .66789 .47874 .66597 .47647 Mtetra
.66597 .47647 .66789 .47874 .67188 .47751 .66996 .47524 Mtetra
.66996 .47524 .67188 .47751 .67587 .47628 .67396 .47401 Mtetra
.67396 .47401 .67587 .47628 .67987 .47505 .67796 .47277 Mtetra
.67796 .47277 .67987 .47505 .68387 .47382 .68197 .47154 Mtetra
.68197 .47154 .68387 .47382 .68788 .47258 .68598 .4703 Mtetra
.68598 .4703 .68788 .47258 .69189 .47135 .69 .46906 Mtetra
.69 .46906 .69189 .47135 .69591 .47011 .69402 .46782 Mtetra
.69402 .46782 .69591 .47011 .69994 .46887 .69805 .46657 Mtetra
.69805 .46657 .69994 .46887 .70397 .46762 .70209 .46533 Mtetra
.70209 .46533 .70397 .46762 .70801 .46638 .70613 .46408 Mtetra
.70613 .46408 .70801 .46638 .71205 .46513 .71017 .46283 Mtetra
.71017 .46283 .71205 .46513 .7161 .46389 .71423 .46158 Mtetra
.972 .719 .493 r
.71423 .46158 .7161 .46389 .72015 .46264 .716 .42157 Mtetra
.576 .383 .583 r
.716 .42157 .72015 .46264 .72186 .42264 .72002 .4203 Mtetra
.96 .621 .284 r
.72002 .4203 .72186 .42264 .72798 .45524 .72612 .45292 Mtetra
.661 .745 .912 r
.72612 .45292 .72798 .45524 .73204 .45398 .73019 .45166 Mtetra
.73019 .45166 .73204 .45398 .73611 .45272 .73427 .45039 Mtetra
.73427 .45039 .73611 .45272 .74019 .45146 .73835 .44913 Mtetra
.73835 .44913 .74019 .45146 .74428 .4502 .74243 .44787 Mtetra
.74243 .44787 .74428 .4502 .74836 .44894 .74653 .4466 Mtetra
.74653 .4466 .74836 .44894 .75246 .44767 .75063 .44533 Mtetra
.75063 .44533 .75246 .44767 .75656 .4464 .75473 .44406 Mtetra
.75473 .44406 .75656 .4464 .76067 .44513 .75884 .44279 Mtetra
.75884 .44279 .76067 .44513 .76478 .44386 .76296 .44151 Mtetra
.76296 .44151 .76478 .44386 .7689 .44259 .76708 .44024 Mtetra
.76708 .44024 .7689 .44259 .77302 .44132 .77121 .43896 Mtetra
.77121 .43896 .77302 .44132 .77715 .44004 .77534 .43768 Mtetra
.97 .651 .326 r
.77534 .43768 .77715 .44004 .78721 .51409 .78537 .51178 Mtetra
.655 .752 .921 r
.78537 .51178 .78721 .51409 .79145 .51284 .78962 .51052 Mtetra
.78962 .51052 .79145 .51284 .7957 .51158 .79387 .50926 Mtetra
.79387 .50926 .7957 .51158 .79996 .51032 .79813 .508 Mtetra
.79813 .508 .79996 .51032 .80422 .50906 .8024 .50673 Mtetra
.8024 .50673 .80422 .50906 .80848 .5078 .80667 .50547 Mtetra
.80667 .50547 .80848 .5078 .81276 .50654 .81095 .5042 Mtetra
.81095 .5042 .81276 .50654 .81704 .50527 .81523 .50293 Mtetra
.81523 .50293 .81704 .50527 .82132 .50401 .81952 .50166 Mtetra
.81952 .50166 .82132 .50401 .82562 .50274 .82382 .50039 Mtetra
.82382 .50039 .82562 .50274 .82992 .50147 .82812 .49911 Mtetra
.82812 .49911 .82992 .50147 .83422 .50019 .83243 .49784 Mtetra
.83243 .49784 .83422 .50019 .83853 .49892 .83675 .49656 Mtetra
.83675 .49656 .83853 .49892 .84285 .49764 .84107 .49528 Mtetra
.84107 .49528 .84285 .49764 .84718 .49636 .8454 .494 Mtetra
.8454 .494 .84718 .49636 .85151 .49508 .84974 .49271 Mtetra
.939 .58 .182 r
.84974 .49271 .85151 .49508 .85897 .5251 .85719 .52275 Mtetra
.653 .755 .925 r
.85719 .52275 .85897 .5251 .86335 .52383 .86158 .52147 Mtetra
.86158 .52147 .86335 .52383 .86775 .52255 .86598 .52019 Mtetra
.86598 .52019 .86775 .52255 .87215 .52127 .87039 .51891 Mtetra
.87039 .51891 .87215 .52127 .87656 .52 .8748 .51763 Mtetra
.8748 .51763 .87656 .52 .88097 .51871 .87922 .51635 Mtetra
.87922 .51635 .88097 .51871 .88539 .51743 .88364 .51506 Mtetra
.88364 .51506 .88539 .51743 .88982 .51615 .88807 .51377 Mtetra
.88807 .51377 .88982 .51615 .89425 .51486 .89251 .51248 Mtetra
.89251 .51248 .89425 .51486 .89869 .51357 .89696 .51119 Mtetra
.89696 .51119 .89869 .51357 .90314 .51228 .90141 .5099 Mtetra
.90141 .5099 .90314 .51228 .90759 .51099 .90587 .5086 Mtetra
.90587 .5086 .90759 .51099 .91205 .5097 .91033 .5073 Mtetra
.91033 .5073 .91205 .5097 .91652 .5084 .91481 .506 Mtetra
.91481 .506 .91652 .5084 .921 .5071 .91929 .5047 Mtetra
.91929 .5047 .921 .5071 .92548 .5058 .92377 .5034 Mtetra
.92377 .5034 .92548 .5058 .92996 .5045 .92827 .50209 Mtetra
.92827 .50209 .92996 .5045 .93446 .5032 .93277 .50078 Mtetra
.93277 .50078 .93446 .5032 .93896 .50189 .93727 .49947 Mtetra
.652 .755 .925 r
.32765 .67897 .32994 .68092 .33358 .67986 .33129 .67791 Mtetra
.33129 .67791 .33358 .67986 .33722 .67881 .33494 .67686 Mtetra
.33494 .67686 .33722 .67881 .34087 .67775 .33859 .6758 Mtetra
.33859 .6758 .34087 .67775 .34453 .67669 .34225 .67474 Mtetra
.34225 .67474 .34453 .67669 .34818 .67563 .34591 .67367 Mtetra
.34591 .67367 .34818 .67563 .35185 .67457 .34958 .67261 Mtetra
.34958 .67261 .35185 .67457 .35552 .67351 .35325 .67154 Mtetra
.35325 .67154 .35552 .67351 .35919 .67244 .35692 .67048 Mtetra
.35692 .67048 .35919 .67244 .36287 .67138 .36061 .66941 Mtetra
.36061 .66941 .36287 .67138 .36656 .67031 .36429 .66834 Mtetra
.36429 .66834 .36656 .67031 .37024 .66924 .36799 .66727 Mtetra
.36799 .66727 .37024 .66924 .37394 .66817 .37168 .66619 Mtetra
.37168 .66619 .37394 .66817 .37764 .6671 .37539 .66512 Mtetra
.37539 .66512 .37764 .6671 .38134 .66603 .3791 .66404 Mtetra
.3791 .66404 .38134 .66603 .38505 .66495 .38281 .66296 Mtetra
.38281 .66296 .38505 .66495 .38877 .66388 .38653 .66189 Mtetra
.38653 .66189 .38877 .66388 .39249 .6628 .39025 .66081 Mtetra
.39025 .66081 .39249 .6628 .39621 .66172 .39398 .65972 Mtetra
.39398 .65972 .39621 .66172 .39994 .66064 .39771 .65864 Mtetra
.39771 .65864 .39994 .66064 .40368 .65956 .40145 .65755 Mtetra
.933 .718 .589 r
.40145 .65755 .40368 .65956 .40827 .63332 .40606 .6313 Mtetra
.655 .753 .922 r
.40606 .6313 .40827 .63332 .41199 .63222 .40978 .6302 Mtetra
.40978 .6302 .41199 .63222 .41571 .63113 .41351 .6291 Mtetra
.41351 .6291 .41571 .63113 .41944 .63003 .41725 .628 Mtetra
.41725 .628 .41944 .63003 .42318 .62893 .42098 .6269 Mtetra
.42098 .6269 .42318 .62893 .42692 .62783 .42473 .62579 Mtetra
.42473 .62579 .42692 .62783 .43067 .62673 .42848 .62469 Mtetra
.42848 .62469 .43067 .62673 .43442 .62562 .43223 .62358 Mtetra
.43223 .62358 .43442 .62562 .43817 .62452 .43599 .62247 Mtetra
.43599 .62247 .43817 .62452 .44193 .62341 .43975 .62136 Mtetra
.43975 .62136 .44193 .62341 .4457 .6223 .44352 .62025 Mtetra
.44352 .62025 .4457 .6223 .44947 .62119 .4473 .61914 Mtetra
.4473 .61914 .44947 .62119 .45325 .62008 .45108 .61802 Mtetra
.45108 .61802 .45325 .62008 .45703 .61897 .45486 .61691 Mtetra
.45486 .61691 .45703 .61897 .46082 .61785 .45865 .61579 Mtetra
.45865 .61579 .46082 .61785 .46461 .61674 .46245 .61467 Mtetra
.46245 .61467 .46461 .61674 .46841 .61562 .46625 .61355 Mtetra
.46625 .61355 .46841 .61562 .47221 .6145 .47006 .61243 Mtetra
.47006 .61243 .47221 .6145 .47602 .61338 .47387 .6113 Mtetra
.47387 .6113 .47602 .61338 .47983 .61225 .47769 .61018 Mtetra
.47769 .61018 .47983 .61225 .48365 .61113 .48151 .60905 Mtetra
.951 .699 .52 r
.48151 .60905 .48365 .61113 .48748 .61001 .48636 .51958 Mtetra
.568 .366 .566 r
.48636 .51958 .48748 .61001 .49217 .52056 .49009 .51842 Mtetra
.662 .744 .911 r
.49009 .51842 .49217 .52056 .49591 .5194 .49383 .51726 Mtetra
.49383 .51726 .49591 .5194 .49965 .51824 .49758 .51609 Mtetra
.49758 .51609 .49965 .51824 .5034 .51708 .50133 .51493 Mtetra
.50133 .51493 .5034 .51708 .50715 .51591 .50508 .51376 Mtetra
.50508 .51376 .50715 .51591 .51091 .51475 .50885 .51259 Mtetra
.50885 .51259 .51091 .51475 .51467 .51358 .51261 .51142 Mtetra
.51261 .51142 .51467 .51358 .51844 .51241 .51638 .51025 Mtetra
.51638 .51025 .51844 .51241 .52221 .51124 .52016 .50907 Mtetra
.52016 .50907 .52221 .51124 .52599 .51007 .52394 .5079 Mtetra
.52394 .5079 .52599 .51007 .52977 .50889 .52773 .50672 Mtetra
.52773 .50672 .52977 .50889 .53356 .50772 .53152 .50554 Mtetra
.53152 .50554 .53356 .50772 .53736 .50654 .53532 .50436 Mtetra
.53532 .50436 .53736 .50654 .54115 .50536 .53912 .50318 Mtetra
.53912 .50318 .54115 .50536 .54496 .50418 .54293 .50199 Mtetra
.54293 .50199 .54496 .50418 .54877 .50299 .54674 .50081 Mtetra
.54674 .50081 .54877 .50299 .55258 .50181 .55056 .49962 Mtetra
.55056 .49962 .55258 .50181 .5564 .50062 .55438 .49843 Mtetra
.55438 .49843 .5564 .50062 .56033 .50908 .55821 .49724 Mtetra
.204 .181 .608 r
.55821 .49724 .56033 .50908 .56417 .5079 .56215 .5057 Mtetra
.661 .745 .912 r
.56215 .5057 .56417 .5079 .56802 .50671 .566 .50451 Mtetra
.566 .50451 .56802 .50671 .57187 .50552 .56986 .50332 Mtetra
.56986 .50332 .57187 .50552 .57573 .50433 .57372 .50213 Mtetra
.57372 .50213 .57573 .50433 .5796 .50314 .57759 .50093 Mtetra
.57759 .50093 .5796 .50314 .58346 .50194 .58146 .49973 Mtetra
.58146 .49973 .58346 .50194 .58734 .50075 .58534 .49853 Mtetra
.58534 .49853 .58734 .50075 .59122 .49955 .58922 .49733 Mtetra
.58922 .49733 .59122 .49955 .5951 .49835 .59311 .49613 Mtetra
.59311 .49613 .5951 .49835 .59899 .49715 .59701 .49493 Mtetra
.59701 .49493 .59899 .49715 .60289 .49595 .6009 .49372 Mtetra
.6009 .49372 .60289 .49595 .60679 .49474 .60481 .49251 Mtetra
.60481 .49251 .60679 .49474 .6107 .49354 .60872 .49131 Mtetra
.60872 .49131 .6107 .49354 .61461 .49233 .61264 .49009 Mtetra
.61264 .49009 .61461 .49233 .61853 .49112 .61656 .48888 Mtetra
.61656 .48888 .61853 .49112 .62245 .48991 .62048 .48767 Mtetra
.62048 .48767 .62245 .48991 .62638 .4887 .62442 .48645 Mtetra
.62442 .48645 .62638 .4887 .63031 .48748 .62835 .48523 Mtetra
.62835 .48523 .63031 .48748 .63425 .48626 .6323 .48402 Mtetra
.6323 .48402 .63425 .48626 .6382 .48505 .63625 .48279 Mtetra
.63625 .48279 .6382 .48505 .64215 .48383 .6402 .48157 Mtetra
.6402 .48157 .64215 .48383 .64611 .48261 .64416 .48035 Mtetra
.64416 .48035 .64611 .48261 .65007 .48138 .64813 .47912 Mtetra
.64813 .47912 .65007 .48138 .65403 .48016 .6521 .47789 Mtetra
.6521 .47789 .65403 .48016 .65801 .47893 .65608 .47666 Mtetra
.65608 .47666 .65801 .47893 .66199 .4777 .66006 .47543 Mtetra
.66006 .47543 .66199 .4777 .66597 .47647 .66405 .4742 Mtetra
.66405 .4742 .66597 .47647 .66996 .47524 .66804 .47296 Mtetra
.66804 .47296 .66996 .47524 .67396 .47401 .67204 .47173 Mtetra
.67204 .47173 .67396 .47401 .67796 .47277 .67605 .47049 Mtetra
.67605 .47049 .67796 .47277 .68197 .47154 .68006 .46925 Mtetra
.68006 .46925 .68197 .47154 .68598 .4703 .68407 .46801 Mtetra
.68407 .46801 .68598 .4703 .69 .46906 .6881 .46676 Mtetra
.6881 .46676 .69 .46906 .69402 .46782 .69212 .46552 Mtetra
.69212 .46552 .69402 .46782 .69805 .46657 .69616 .46427 Mtetra
.69616 .46427 .69805 .46657 .70209 .46533 .7002 .46302 Mtetra
.7002 .46302 .70209 .46533 .70613 .46408 .70424 .46177 Mtetra
.971 .719 .496 r
.70424 .46177 .70613 .46408 .71017 .46283 .70613 .42177 Mtetra
.576 .383 .583 r
.70613 .42177 .71017 .46283 .71423 .46158 .71014 .4205 Mtetra
.71014 .4205 .71423 .46158 .716 .42157 .71415 .41923 Mtetra
.664 .741 .908 r
.71415 .41923 .716 .42157 .72002 .4203 .71817 .41796 Mtetra
.96 .621 .284 r
.71817 .41796 .72002 .4203 .72612 .45292 .72426 .45059 Mtetra
.661 .745 .912 r
.72426 .45059 .72612 .45292 .73019 .45166 .72833 .44933 Mtetra
.72833 .44933 .73019 .45166 .73427 .45039 .73241 .44806 Mtetra
.73241 .44806 .73427 .45039 .73835 .44913 .7365 .44679 Mtetra
.7365 .44679 .73835 .44913 .74243 .44787 .74059 .44553 Mtetra
.74059 .44553 .74243 .44787 .74653 .4466 .74468 .44426 Mtetra
.74468 .44426 .74653 .4466 .75063 .44533 .74879 .44298 Mtetra
.74879 .44298 .75063 .44533 .75473 .44406 .7529 .44171 Mtetra
.7529 .44171 .75473 .44406 .75884 .44279 .75701 .44043 Mtetra
.75701 .44043 .75884 .44279 .76296 .44151 .76113 .43916 Mtetra
.76113 .43916 .76296 .44151 .76708 .44024 .76526 .43788 Mtetra
.76526 .43788 .76708 .44024 .77121 .43896 .76939 .43659 Mtetra
.76939 .43659 .77121 .43896 .77534 .43768 .77353 .43531 Mtetra
.97 .651 .326 r
.77353 .43531 .77534 .43768 .78537 .51178 .78353 .50945 Mtetra
.655 .752 .921 r
.78353 .50945 .78537 .51178 .78962 .51052 .78778 .50819 Mtetra
.78778 .50819 .78962 .51052 .79387 .50926 .79204 .50693 Mtetra
.79204 .50693 .79387 .50926 .79813 .508 .7963 .50566 Mtetra
.7963 .50566 .79813 .508 .8024 .50673 .80057 .5044 Mtetra
.80057 .5044 .8024 .50673 .80667 .50547 .80485 .50313 Mtetra
.80485 .50313 .80667 .50547 .81095 .5042 .80913 .50186 Mtetra
.80913 .50186 .81095 .5042 .81523 .50293 .81342 .50059 Mtetra
.81342 .50059 .81523 .50293 .81952 .50166 .81771 .49931 Mtetra
.81771 .49931 .81952 .50166 .82382 .50039 .82202 .49803 Mtetra
.82202 .49803 .82382 .50039 .82812 .49911 .82632 .49676 Mtetra
.82632 .49676 .82812 .49911 .83243 .49784 .83064 .49548 Mtetra
.83064 .49548 .83243 .49784 .83675 .49656 .83496 .4942 Mtetra
.83496 .4942 .83675 .49656 .84107 .49528 .83929 .49291 Mtetra
.83929 .49291 .84107 .49528 .8454 .494 .84362 .49163 Mtetra
.84362 .49163 .8454 .494 .84974 .49271 .84796 .49034 Mtetra
.939 .58 .182 r
.84796 .49034 .84974 .49271 .85719 .52275 .85541 .52039 Mtetra
.653 .755 .925 r
.85541 .52039 .85719 .52275 .86158 .52147 .8598 .51911 Mtetra
.8598 .51911 .86158 .52147 .86598 .52019 .86421 .51783 Mtetra
.86421 .51783 .86598 .52019 .87039 .51891 .86862 .51654 Mtetra
.86862 .51654 .87039 .51891 .8748 .51763 .87303 .51526 Mtetra
.87303 .51526 .8748 .51763 .87922 .51635 .87746 .51397 Mtetra
.87746 .51397 .87922 .51635 .88364 .51506 .88189 .51268 Mtetra
.88189 .51268 .88364 .51506 .88807 .51377 .88632 .51139 Mtetra
.88632 .51139 .88807 .51377 .89251 .51248 .89077 .51009 Mtetra
.89077 .51009 .89251 .51248 .89696 .51119 .89522 .5088 Mtetra
.89522 .5088 .89696 .51119 .90141 .5099 .89968 .5075 Mtetra
.89968 .5075 .90141 .5099 .90587 .5086 .90414 .5062 Mtetra
.90414 .5062 .90587 .5086 .91033 .5073 .90861 .5049 Mtetra
.90861 .5049 .91033 .5073 .91481 .506 .91309 .5036 Mtetra
.91309 .5036 .91481 .506 .91929 .5047 .91757 .50229 Mtetra
.91757 .50229 .91929 .5047 .92377 .5034 .92206 .50098 Mtetra
.92206 .50098 .92377 .5034 .92827 .50209 .92656 .49967 Mtetra
.92656 .49967 .92827 .50209 .93277 .50078 .93107 .49836 Mtetra
.93107 .49836 .93277 .50078 .93727 .49947 .93558 .49705 Mtetra
.652 .755 .925 r
.32535 .67702 .32765 .67897 .33129 .67791 .32899 .67596 Mtetra
.32899 .67596 .33129 .67791 .33494 .67686 .33265 .6749 Mtetra
.33265 .6749 .33494 .67686 .33859 .6758 .3363 .67384 Mtetra
.3363 .67384 .33859 .6758 .34225 .67474 .33996 .67277 Mtetra
.33996 .67277 .34225 .67474 .34591 .67367 .34363 .67171 Mtetra
.34363 .67171 .34591 .67367 .34958 .67261 .3473 .67064 Mtetra
.3473 .67064 .34958 .67261 .35325 .67154 .35097 .66957 Mtetra
.35097 .66957 .35325 .67154 .35692 .67048 .35465 .6685 Mtetra
.35465 .6685 .35692 .67048 .36061 .66941 .35834 .66743 Mtetra
.35834 .66743 .36061 .66941 .36429 .66834 .36203 .66636 Mtetra
.36203 .66636 .36429 .66834 .36799 .66727 .36572 .66528 Mtetra
.36572 .66528 .36799 .66727 .37168 .66619 .36942 .66421 Mtetra
.36942 .66421 .37168 .66619 .37539 .66512 .37313 .66313 Mtetra
.37313 .66313 .37539 .66512 .3791 .66404 .37684 .66205 Mtetra
.37684 .66205 .3791 .66404 .38281 .66296 .38056 .66097 Mtetra
.38056 .66097 .38281 .66296 .38653 .66189 .38428 .65989 Mtetra
.38428 .65989 .38653 .66189 .39025 .66081 .38801 .65881 Mtetra
.38801 .65881 .39025 .66081 .39398 .65972 .39174 .65772 Mtetra
.39174 .65772 .39398 .65972 .39771 .65864 .39547 .65664 Mtetra
.39547 .65664 .39771 .65864 .40145 .65755 .39922 .65555 Mtetra
.948 .637 .412 r
.39922 .65555 .40145 .65755 .40606 .6313 .40207 .68002 Mtetra
0 0 .249 r
.40207 .68002 .40606 .6313 .40978 .6302 .40757 .62817 Mtetra
.655 .753 .922 r
.40757 .62817 .40978 .6302 .41351 .6291 .4113 .62707 Mtetra
.4113 .62707 .41351 .6291 .41725 .628 .41504 .62596 Mtetra
.41504 .62596 .41725 .628 .42098 .6269 .41878 .62486 Mtetra
.41878 .62486 .42098 .6269 .42473 .62579 .42253 .62375 Mtetra
.42253 .62375 .42473 .62579 .42848 .62469 .42628 .62264 Mtetra
.42628 .62264 .42848 .62469 .43223 .62358 .43004 .62153 Mtetra
.43004 .62153 .43223 .62358 .43599 .62247 .4338 .62042 Mtetra
.4338 .62042 .43599 .62247 .43975 .62136 .43757 .61931 Mtetra
.43757 .61931 .43975 .62136 .44352 .62025 .44134 .61819 Mtetra
.44134 .61819 .44352 .62025 .4473 .61914 .44512 .61708 Mtetra
.44512 .61708 .4473 .61914 .45108 .61802 .4489 .61596 Mtetra
.4489 .61596 .45108 .61802 .45486 .61691 .45269 .61484 Mtetra
.45269 .61484 .45486 .61691 .45865 .61579 .45649 .61372 Mtetra
.45649 .61372 .45865 .61579 .46245 .61467 .46029 .6126 Mtetra
.46029 .6126 .46245 .61467 .46625 .61355 .46409 .61148 Mtetra
.46409 .61148 .46625 .61355 .47006 .61243 .4679 .61035 Mtetra
.4679 .61035 .47006 .61243 .47387 .6113 .47172 .60922 Mtetra
.47172 .60922 .47387 .6113 .47769 .61018 .47554 .6081 Mtetra
.47554 .6081 .47769 .61018 .48151 .60905 .47936 .60697 Mtetra
.951 .699 .52 r
.47936 .60697 .48151 .60905 .48636 .51958 .48427 .51744 Mtetra
.662 .744 .911 r
.48427 .51744 .48636 .51958 .49009 .51842 .48801 .51627 Mtetra
.48801 .51627 .49009 .51842 .49383 .51726 .49175 .51511 Mtetra
.49175 .51511 .49383 .51726 .49758 .51609 .4955 .51394 Mtetra
.4955 .51394 .49758 .51609 .50133 .51493 .49925 .51277 Mtetra
.49925 .51277 .50133 .51493 .50508 .51376 .50301 .5116 Mtetra
.50301 .5116 .50508 .51376 .50885 .51259 .50678 .51043 Mtetra
.50678 .51043 .50885 .51259 .51261 .51142 .51055 .50925 Mtetra
.51055 .50925 .51261 .51142 .51638 .51025 .51432 .50808 Mtetra
.51432 .50808 .51638 .51025 .52016 .50907 .5181 .5069 Mtetra
.5181 .5069 .52016 .50907 .52394 .5079 .52189 .50572 Mtetra
.52189 .50572 .52394 .5079 .52773 .50672 .52568 .50454 Mtetra
.52568 .50454 .52773 .50672 .53152 .50554 .52947 .50336 Mtetra
.52947 .50336 .53152 .50554 .53532 .50436 .53327 .50217 Mtetra
.53327 .50217 .53532 .50436 .53912 .50318 .53708 .50099 Mtetra
.53708 .50099 .53912 .50318 .54293 .50199 .54089 .4998 Mtetra
.54089 .4998 .54293 .50199 .54674 .50081 .54471 .49861 Mtetra
.54471 .49861 .54674 .50081 .55056 .49962 .54853 .49742 Mtetra
.54853 .49742 .55056 .49962 .55438 .49843 .55236 .49623 Mtetra
.55236 .49623 .55438 .49843 .55821 .49724 .55619 .49504 Mtetra
.865 .432 .018 r
.55619 .49504 .55821 .49724 .56215 .5057 .56013 .5035 Mtetra
.661 .745 .912 r
.56013 .5035 .56215 .5057 .566 .50451 .56398 .50231 Mtetra
.56398 .50231 .566 .50451 .56986 .50332 .56784 .50111 Mtetra
.56784 .50111 .56986 .50332 .57372 .50213 .57171 .49992 Mtetra
.57171 .49992 .57372 .50213 .57759 .50093 .57558 .49872 Mtetra
.57558 .49872 .57759 .50093 .58146 .49973 .57945 .49752 Mtetra
.57945 .49752 .58146 .49973 .58534 .49853 .58334 .49632 Mtetra
.58334 .49632 .58534 .49853 .58922 .49733 .58722 .49511 Mtetra
.58722 .49511 .58922 .49733 .59311 .49613 .59111 .49391 Mtetra
.59111 .49391 .59311 .49613 .59701 .49493 .59501 .4927 Mtetra
.59501 .4927 .59701 .49493 .6009 .49372 .59892 .49149 Mtetra
.59892 .49149 .6009 .49372 .60481 .49251 .60282 .49028 Mtetra
.60282 .49028 .60481 .49251 .60872 .49131 .60674 .48907 Mtetra
.60674 .48907 .60872 .49131 .61264 .49009 .61066 .48785 Mtetra
.61066 .48785 .61264 .49009 .61656 .48888 .61458 .48664 Mtetra
.61458 .48664 .61656 .48888 .62048 .48767 .61851 .48542 Mtetra
.61851 .48542 .62048 .48767 .62442 .48645 .62245 .4842 Mtetra
.62245 .4842 .62442 .48645 .62835 .48523 .62639 .48298 Mtetra
.62639 .48298 .62835 .48523 .6323 .48402 .63034 .48176 Mtetra
.63034 .48176 .6323 .48402 .63625 .48279 .63429 .48054 Mtetra
.63429 .48054 .63625 .48279 .6402 .48157 .63825 .47931 Mtetra
.63825 .47931 .6402 .48157 .64416 .48035 .64221 .47808 Mtetra
.64221 .47808 .64416 .48035 .64813 .47912 .64618 .47685 Mtetra
.64618 .47685 .64813 .47912 .6521 .47789 .65016 .47562 Mtetra
.65016 .47562 .6521 .47789 .65608 .47666 .65414 .47439 Mtetra
.65414 .47439 .65608 .47666 .66006 .47543 .65813 .47315 Mtetra
.65813 .47315 .66006 .47543 .66405 .4742 .66212 .47192 Mtetra
.66212 .47192 .66405 .4742 .66804 .47296 .66612 .47068 Mtetra
.66612 .47068 .66804 .47296 .67204 .47173 .67012 .46944 Mtetra
.67012 .46944 .67204 .47173 .67605 .47049 .67413 .4682 Mtetra
.67413 .4682 .67605 .47049 .68006 .46925 .67814 .46695 Mtetra
.67814 .46695 .68006 .46925 .68407 .46801 .68216 .46571 Mtetra
.68216 .46571 .68407 .46801 .6881 .46676 .68619 .46446 Mtetra
.68619 .46446 .6881 .46676 .69212 .46552 .69022 .46321 Mtetra
.69022 .46321 .69212 .46552 .69616 .46427 .69426 .46196 Mtetra
.69426 .46196 .69616 .46427 .7002 .46302 .6983 .46071 Mtetra
.971 .719 .497 r
.6983 .46071 .7002 .46302 .70424 .46177 .70026 .42069 Mtetra
.575 .382 .583 r
.70026 .42069 .70424 .46177 .70613 .42177 .70426 .41943 Mtetra
.664 .741 .908 r
.70426 .41943 .70613 .42177 .71014 .4205 .70827 .41816 Mtetra
.70827 .41816 .71014 .4205 .71415 .41923 .71229 .41688 Mtetra
.71229 .41688 .71415 .41923 .71817 .41796 .71631 .41561 Mtetra
.96 .621 .284 r
.71631 .41561 .71817 .41796 .72426 .45059 .72239 .44826 Mtetra
.661 .745 .912 r
.72239 .44826 .72426 .45059 .72833 .44933 .72647 .44699 Mtetra
.72647 .44699 .72833 .44933 .73241 .44806 .73055 .44572 Mtetra
.73055 .44572 .73241 .44806 .7365 .44679 .73464 .44445 Mtetra
.73464 .44445 .7365 .44679 .74059 .44553 .73874 .44318 Mtetra
.73874 .44318 .74059 .44553 .74468 .44426 .74284 .4419 Mtetra
.74284 .4419 .74468 .44426 .74879 .44298 .74694 .44063 Mtetra
.74694 .44063 .74879 .44298 .7529 .44171 .75106 .43935 Mtetra
.75106 .43935 .7529 .44171 .75701 .44043 .75518 .43807 Mtetra
.75518 .43807 .75701 .44043 .76113 .43916 .7593 .43679 Mtetra
.7593 .43679 .76113 .43916 .76526 .43788 .76343 .43551 Mtetra
.76343 .43551 .76526 .43788 .76939 .43659 .76757 .43422 Mtetra
.76757 .43422 .76939 .43659 .77353 .43531 .77171 .43294 Mtetra
.97 .651 .326 r
.77171 .43294 .77353 .43531 .78353 .50945 .78168 .50712 Mtetra
.655 .752 .921 r
.78168 .50712 .78353 .50945 .78778 .50819 .78594 .50586 Mtetra
.78594 .50586 .78778 .50819 .79204 .50693 .7902 .50459 Mtetra
.7902 .50459 .79204 .50693 .7963 .50566 .79447 .50332 Mtetra
.79447 .50332 .7963 .50566 .80057 .5044 .79874 .50205 Mtetra
.79874 .50205 .80057 .5044 .80485 .50313 .80302 .50078 Mtetra
.80302 .50078 .80485 .50313 .80913 .50186 .80731 .49951 Mtetra
.80731 .49951 .80913 .50186 .81342 .50059 .8116 .49823 Mtetra
.8116 .49823 .81342 .50059 .81771 .49931 .8159 .49695 Mtetra
.8159 .49695 .81771 .49931 .82202 .49803 .82021 .49567 Mtetra
.82021 .49567 .82202 .49803 .82632 .49676 .82452 .49439 Mtetra
.82452 .49439 .82632 .49676 .83064 .49548 .82884 .49311 Mtetra
.82884 .49311 .83064 .49548 .83496 .4942 .83317 .49182 Mtetra
.83317 .49182 .83496 .4942 .83929 .49291 .8375 .49054 Mtetra
.8375 .49054 .83929 .49291 .84362 .49163 .84184 .48925 Mtetra
.84184 .48925 .84362 .49163 .84796 .49034 .84618 .48796 Mtetra
.939 .58 .182 r
.84618 .48796 .84796 .49034 .85541 .52039 .85362 .51802 Mtetra
.653 .755 .925 r
.85362 .51802 .85541 .52039 .8598 .51911 .85802 .51674 Mtetra
.85802 .51674 .8598 .51911 .86421 .51783 .86243 .51546 Mtetra
.86243 .51546 .86421 .51783 .86862 .51654 .86684 .51417 Mtetra
.86684 .51417 .86862 .51654 .87303 .51526 .87127 .51288 Mtetra
.87127 .51288 .87303 .51526 .87746 .51397 .87569 .51159 Mtetra
.87569 .51159 .87746 .51397 .88189 .51268 .88013 .51029 Mtetra
.88013 .51029 .88189 .51268 .88632 .51139 .88457 .509 Mtetra
.88457 .509 .88632 .51139 .89077 .51009 .88902 .5077 Mtetra
.88902 .5077 .89077 .51009 .89522 .5088 .89347 .5064 Mtetra
.89347 .5064 .89522 .5088 .89968 .5075 .89794 .5051 Mtetra
.89794 .5051 .89968 .5075 .90414 .5062 .90241 .5038 Mtetra
.90241 .5038 .90414 .5062 .90861 .5049 .90688 .50249 Mtetra
.90688 .50249 .90861 .5049 .91309 .5036 .91136 .50119 Mtetra
.91136 .50119 .91309 .5036 .91757 .50229 .91585 .49988 Mtetra
.91585 .49988 .91757 .50229 .92206 .50098 .92035 .49857 Mtetra
.92035 .49857 .92206 .50098 .92656 .49967 .92485 .49725 Mtetra
.92485 .49725 .92656 .49967 .93107 .49836 .92936 .49594 Mtetra
.92936 .49594 .93107 .49836 .93558 .49705 .93388 .49462 Mtetra
.652 .755 .925 r
.32305 .67506 .32535 .67702 .32899 .67596 .32669 .674 Mtetra
.32669 .674 .32899 .67596 .33265 .6749 .33035 .67294 Mtetra
.33035 .67294 .33265 .6749 .3363 .67384 .33401 .67187 Mtetra
.33401 .67187 .3363 .67384 .33996 .67277 .33767 .6708 Mtetra
.33767 .6708 .33996 .67277 .34363 .67171 .34134 .66974 Mtetra
.34134 .66974 .34363 .67171 .3473 .67064 .34501 .66867 Mtetra
.34501 .66867 .3473 .67064 .35097 .66957 .34869 .6676 Mtetra
.34869 .6676 .35097 .66957 .35465 .6685 .35237 .66652 Mtetra
.35237 .66652 .35465 .6685 .35834 .66743 .35606 .66545 Mtetra
.35606 .66545 .35834 .66743 .36203 .66636 .35976 .66437 Mtetra
.35976 .66437 .36203 .66636 .36572 .66528 .36345 .6633 Mtetra
.36345 .6633 .36572 .66528 .36942 .66421 .36716 .66222 Mtetra
.36716 .66222 .36942 .66421 .37313 .66313 .37087 .66114 Mtetra
.37087 .66114 .37313 .66313 .37684 .66205 .37458 .66006 Mtetra
.37458 .66006 .37684 .66205 .38056 .66097 .3783 .65897 Mtetra
.3783 .65897 .38056 .66097 .38428 .65989 .38203 .65789 Mtetra
.38203 .65789 .38428 .65989 .38801 .65881 .38576 .6568 Mtetra
.38576 .6568 .38801 .65881 .39174 .65772 .38949 .65572 Mtetra
.38949 .65572 .39174 .65772 .39547 .65664 .39323 .65463 Mtetra
.948 .638 .414 r
.39323 .65463 .39547 .65664 .39922 .65555 .39604 .6791 Mtetra
.537 .292 .492 r
.39604 .6791 .39922 .65555 .40207 .68002 .39981 .67802 Mtetra
.65 .758 .928 r
.39981 .67802 .40207 .68002 .40757 .62817 .4036 .67694 Mtetra
0 0 .249 r
.4036 .67694 .40757 .62817 .4113 .62707 .40909 .62503 Mtetra
.655 .753 .922 r
.40909 .62503 .4113 .62707 .41504 .62596 .41283 .62392 Mtetra
.41283 .62392 .41504 .62596 .41878 .62486 .41658 .62281 Mtetra
.41658 .62281 .41878 .62486 .42253 .62375 .42033 .6217 Mtetra
.42033 .6217 .42253 .62375 .42628 .62264 .42408 .62059 Mtetra
.42408 .62059 .42628 .62264 .43004 .62153 .42784 .61948 Mtetra
.42784 .61948 .43004 .62153 .4338 .62042 .43161 .61837 Mtetra
.43161 .61837 .4338 .62042 .43757 .61931 .43538 .61725 Mtetra
.43538 .61725 .43757 .61931 .44134 .61819 .43915 .61613 Mtetra
.43915 .61613 .44134 .61819 .44512 .61708 .44294 .61502 Mtetra
.44294 .61502 .44512 .61708 .4489 .61596 .44672 .61389 Mtetra
.44672 .61389 .4489 .61596 .45269 .61484 .45052 .61277 Mtetra
.45052 .61277 .45269 .61484 .45649 .61372 .45431 .61165 Mtetra
.45431 .61165 .45649 .61372 .46029 .6126 .45812 .61052 Mtetra
.45812 .61052 .46029 .6126 .46409 .61148 .46192 .6094 Mtetra
.46192 .6094 .46409 .61148 .4679 .61035 .46574 .60827 Mtetra
.46574 .60827 .4679 .61035 .47172 .60922 .46956 .60714 Mtetra
.46956 .60714 .47172 .60922 .47554 .6081 .47338 .60601 Mtetra
.951 .699 .521 r
.47338 .60601 .47554 .6081 .47936 .60697 .47844 .51645 Mtetra
.568 .364 .565 r
.47844 .51645 .47936 .60697 .48427 .51744 .48218 .51529 Mtetra
.662 .744 .911 r
.48218 .51529 .48427 .51744 .48801 .51627 .48592 .51412 Mtetra
.48592 .51412 .48801 .51627 .49175 .51511 .48967 .51295 Mtetra
.48967 .51295 .49175 .51511 .4955 .51394 .49342 .51178 Mtetra
.49342 .51178 .4955 .51394 .49925 .51277 .49717 .51061 Mtetra
.49717 .51061 .49925 .51277 .50301 .5116 .50094 .50943 Mtetra
.50094 .50943 .50301 .5116 .50678 .51043 .5047 .50826 Mtetra
.5047 .50826 .50678 .51043 .51055 .50925 .50848 .50708 Mtetra
.50848 .50708 .51055 .50925 .51432 .50808 .51226 .5059 Mtetra
.51226 .5059 .51432 .50808 .5181 .5069 .51604 .50472 Mtetra
.51604 .50472 .5181 .5069 .52189 .50572 .51983 .50354 Mtetra
.51983 .50354 .52189 .50572 .52568 .50454 .52362 .50236 Mtetra
.52362 .50236 .52568 .50454 .52947 .50336 .52742 .50117 Mtetra
.52742 .50117 .52947 .50336 .53327 .50217 .53122 .49999 Mtetra
.53122 .49999 .53327 .50217 .53708 .50099 .53503 .4988 Mtetra
.53503 .4988 .53708 .50099 .54089 .4998 .53885 .49761 Mtetra
.53885 .49761 .54089 .4998 .54471 .49861 .54267 .49642 Mtetra
.54267 .49642 .54471 .49861 .54853 .49742 .54649 .49522 Mtetra
.54649 .49522 .54853 .49742 .55236 .49623 .55032 .49403 Mtetra
.55032 .49403 .55236 .49623 .55619 .49504 .55416 .49283 Mtetra
.865 .432 .018 r
.55416 .49283 .55619 .49504 .56013 .5035 .5581 .5013 Mtetra
.661 .745 .912 r
.5581 .5013 .56013 .5035 .56398 .50231 .56196 .5001 Mtetra
.56196 .5001 .56398 .50231 .56784 .50111 .56582 .4989 Mtetra
.56582 .4989 .56784 .50111 .57171 .49992 .56969 .4977 Mtetra
.56969 .4977 .57171 .49992 .57558 .49872 .57356 .4965 Mtetra
.57356 .4965 .57558 .49872 .57945 .49752 .57744 .4953 Mtetra
.57744 .4953 .57945 .49752 .58334 .49632 .58133 .49409 Mtetra
.58133 .49409 .58334 .49632 .58722 .49511 .58522 .49289 Mtetra
.58522 .49289 .58722 .49511 .59111 .49391 .58911 .49168 Mtetra
.58911 .49168 .59111 .49391 .59501 .4927 .59301 .49047 Mtetra
.59301 .49047 .59501 .4927 .59892 .49149 .59692 .48926 Mtetra
.59692 .48926 .59892 .49149 .60282 .49028 .60083 .48804 Mtetra
.96 .716 .523 r
.60083 .48804 .60282 .49028 .60674 .48907 .60382 .44834 Mtetra
.575 .382 .582 r
.60382 .44834 .60674 .48907 .61066 .48785 .6077 .44711 Mtetra
.6077 .44711 .61066 .48785 .61458 .48664 .61158 .44588 Mtetra
.61158 .44588 .61458 .48664 .61851 .48542 .61547 .44465 Mtetra
.61547 .44465 .61851 .48542 .62245 .4842 .61936 .44341 Mtetra
.078 .019 .481 r
.61936 .44341 .62245 .4842 .62639 .48298 .62442 .48072 Mtetra
.661 .745 .912 r
.62442 .48072 .62639 .48298 .63034 .48176 .62837 .4795 Mtetra
.62837 .4795 .63034 .48176 .63429 .48054 .63233 .47827 Mtetra
.63233 .47827 .63429 .48054 .63825 .47931 .63629 .47704 Mtetra
.63629 .47704 .63825 .47931 .64221 .47808 .64026 .47581 Mtetra
.64026 .47581 .64221 .47808 .64618 .47685 .64423 .47458 Mtetra
.64423 .47458 .64618 .47685 .65016 .47562 .64821 .47334 Mtetra
.64821 .47334 .65016 .47562 .65414 .47439 .6522 .47211 Mtetra
.6522 .47211 .65414 .47439 .65813 .47315 .65619 .47087 Mtetra
.65619 .47087 .65813 .47315 .66212 .47192 .66018 .46963 Mtetra
.66018 .46963 .66212 .47192 .66612 .47068 .66419 .46839 Mtetra
.66419 .46839 .66612 .47068 .67012 .46944 .66819 .46715 Mtetra
.66819 .46715 .67012 .46944 .67413 .4682 .67221 .4659 Mtetra
.67221 .4659 .67413 .4682 .67814 .46695 .67622 .46465 Mtetra
.67622 .46465 .67814 .46695 .68216 .46571 .68025 .46341 Mtetra
.68025 .46341 .68216 .46571 .68619 .46446 .68428 .46216 Mtetra
.68428 .46216 .68619 .46446 .69022 .46321 .68831 .4609 Mtetra
.68831 .4609 .69022 .46321 .69426 .46196 .69236 .45965 Mtetra
.97 .719 .498 r
.69236 .45965 .69426 .46196 .6983 .46071 .69438 .41962 Mtetra
.575 .382 .582 r
.69438 .41962 .6983 .46071 .70026 .42069 .69838 .41835 Mtetra
.664 .741 .908 r
.69838 .41835 .70026 .42069 .70426 .41943 .70239 .41708 Mtetra
.70239 .41708 .70426 .41943 .70827 .41816 .70641 .41581 Mtetra
.70641 .41581 .70827 .41816 .71229 .41688 .71043 .41453 Mtetra
.71043 .41453 .71229 .41688 .71631 .41561 .71445 .41325 Mtetra
.96 .621 .284 r
.71445 .41325 .71631 .41561 .72239 .44826 .72052 .44592 Mtetra
.661 .745 .912 r
.72052 .44592 .72239 .44826 .72647 .44699 .7246 .44465 Mtetra
.7246 .44465 .72647 .44699 .73055 .44572 .72869 .44337 Mtetra
.72869 .44337 .73055 .44572 .73464 .44445 .73278 .4421 Mtetra
.73278 .4421 .73464 .44445 .73874 .44318 .73688 .44083 Mtetra
.73688 .44083 .73874 .44318 .74284 .4419 .74099 .43955 Mtetra
.74099 .43955 .74284 .4419 .74694 .44063 .7451 .43827 Mtetra
.7451 .43827 .74694 .44063 .75106 .43935 .74921 .43699 Mtetra
.74921 .43699 .75106 .43935 .75518 .43807 .75334 .43571 Mtetra
.75334 .43571 .75518 .43807 .7593 .43679 .75747 .43442 Mtetra
.75747 .43442 .7593 .43679 .76343 .43551 .7616 .43314 Mtetra
.7616 .43314 .76343 .43551 .76757 .43422 .76574 .43185 Mtetra
.76574 .43185 .76757 .43422 .77171 .43294 .76989 .43056 Mtetra
.76989 .43056 .77171 .43294 .78168 .50712 .77404 .42926 Mtetra
.124 .049 .493 r
.77404 .42926 .78168 .50712 .78594 .50586 .78409 .50352 Mtetra
.655 .752 .921 r
.78409 .50352 .78594 .50586 .7902 .50459 .78835 .50225 Mtetra
.78835 .50225 .7902 .50459 .79447 .50332 .79263 .50098 Mtetra
.79263 .50098 .79447 .50332 .79874 .50205 .79691 .4997 Mtetra
.79691 .4997 .79874 .50205 .80302 .50078 .80119 .49843 Mtetra
.80119 .49843 .80302 .50078 .80731 .49951 .80548 .49715 Mtetra
.80548 .49715 .80731 .49951 .8116 .49823 .80978 .49587 Mtetra
.80978 .49587 .8116 .49823 .8159 .49695 .81409 .49459 Mtetra
.81409 .49459 .8159 .49695 .82021 .49567 .8184 .49331 Mtetra
.8184 .49331 .82021 .49567 .82452 .49439 .82271 .49202 Mtetra
.82271 .49202 .82452 .49439 .82884 .49311 .82704 .49073 Mtetra
.82704 .49073 .82884 .49311 .83317 .49182 .83137 .48945 Mtetra
.83137 .48945 .83317 .49182 .8375 .49054 .8357 .48815 Mtetra
.8357 .48815 .8375 .49054 .84184 .48925 .84005 .48686 Mtetra
.84005 .48686 .84184 .48925 .84618 .48796 .8444 .48557 Mtetra
.939 .58 .182 r
.8444 .48557 .84618 .48796 .85362 .51802 .85183 .51565 Mtetra
.653 .755 .925 r
.85183 .51565 .85362 .51802 .85802 .51674 .85623 .51437 Mtetra
.85623 .51437 .85802 .51674 .86243 .51546 .86065 .51308 Mtetra
.86065 .51308 .86243 .51546 .86684 .51417 .86507 .51179 Mtetra
.86507 .51179 .86684 .51417 .87127 .51288 .86949 .51049 Mtetra
.86949 .51049 .87127 .51288 .87569 .51159 .87393 .5092 Mtetra
.87393 .5092 .87569 .51159 .88013 .51029 .87837 .5079 Mtetra
.87837 .5079 .88013 .51029 .88457 .509 .88281 .5066 Mtetra
.88281 .5066 .88457 .509 .88902 .5077 .88727 .5053 Mtetra
.88727 .5053 .88902 .5077 .89347 .5064 .89173 .504 Mtetra
.89173 .504 .89347 .5064 .89794 .5051 .89619 .50269 Mtetra
.89619 .50269 .89794 .5051 .90241 .5038 .90067 .50139 Mtetra
.90067 .50139 .90241 .5038 .90688 .50249 .90515 .50008 Mtetra
.90515 .50008 .90688 .50249 .91136 .50119 .90963 .49877 Mtetra
.90963 .49877 .91136 .50119 .91585 .49988 .91413 .49745 Mtetra
.91413 .49745 .91585 .49988 .92035 .49857 .91863 .49614 Mtetra
.91863 .49614 .92035 .49857 .92485 .49725 .92314 .49482 Mtetra
.92314 .49482 .92485 .49725 .92936 .49594 .92765 .4935 Mtetra
.92765 .4935 .92936 .49594 .93388 .49462 .93217 .49218 Mtetra
.652 .755 .925 r
.32074 .6731 .32305 .67506 .32669 .674 .32439 .67203 Mtetra
.32439 .67203 .32669 .674 .33035 .67294 .32804 .67097 Mtetra
.32804 .67097 .33035 .67294 .33401 .67187 .33171 .6699 Mtetra
.33171 .6699 .33401 .67187 .33767 .6708 .33537 .66883 Mtetra
.33537 .66883 .33767 .6708 .34134 .66974 .33904 .66776 Mtetra
.33904 .66776 .34134 .66974 .34501 .66867 .34272 .66669 Mtetra
.34272 .66669 .34501 .66867 .34869 .6676 .3464 .66561 Mtetra
.3464 .66561 .34869 .6676 .35237 .66652 .35009 .66454 Mtetra
.35009 .66454 .35237 .66652 .35606 .66545 .35378 .66346 Mtetra
.35378 .66346 .35606 .66545 .35976 .66437 .35748 .66238 Mtetra
.35748 .66238 .35976 .66437 .36345 .6633 .36118 .6613 Mtetra
.36118 .6613 .36345 .6633 .36716 .66222 .36489 .66022 Mtetra
.36489 .66022 .36716 .66222 .37087 .66114 .3686 .65914 Mtetra
.3686 .65914 .37087 .66114 .37458 .66006 .37232 .65806 Mtetra
.37232 .65806 .37458 .66006 .3783 .65897 .37604 .65697 Mtetra
.37604 .65697 .3783 .65897 .38203 .65789 .37977 .65588 Mtetra
.37977 .65588 .38203 .65789 .38576 .6568 .3835 .65479 Mtetra
.3835 .65479 .38576 .6568 .38949 .65572 .38724 .6537 Mtetra
.948 .638 .415 r
.38724 .6537 .38949 .65572 .39323 .65463 .39 .67819 Mtetra
.537 .292 .491 r
.39 .67819 .39323 .65463 .39604 .6791 .39377 .67711 Mtetra
.65 .758 .928 r
.39377 .67711 .39604 .6791 .39981 .67802 .39755 .67602 Mtetra
.39755 .67602 .39981 .67802 .4036 .67694 .40134 .67493 Mtetra
.40134 .67493 .4036 .67694 .40909 .62503 .40513 .67385 Mtetra
.55 .322 .522 r
.40513 .67385 .40909 .62503 .41283 .62392 .40893 .67276 Mtetra
0 0 .251 r
.40893 .67276 .41283 .62392 .41658 .62281 .41436 .62076 Mtetra
.655 .753 .922 r
.41436 .62076 .41658 .62281 .42033 .6217 .41812 .61965 Mtetra
.41812 .61965 .42033 .6217 .42408 .62059 .42188 .61854 Mtetra
.42188 .61854 .42408 .62059 .42784 .61948 .42564 .61742 Mtetra
.42564 .61742 .42784 .61948 .43161 .61837 .42941 .61631 Mtetra
.42941 .61631 .43161 .61837 .43538 .61725 .43318 .61519 Mtetra
.43318 .61519 .43538 .61725 .43915 .61613 .43696 .61407 Mtetra
.43696 .61407 .43915 .61613 .44294 .61502 .44075 .61295 Mtetra
.44075 .61295 .44294 .61502 .44672 .61389 .44454 .61182 Mtetra
.44454 .61182 .44672 .61389 .45052 .61277 .44833 .6107 Mtetra
.44833 .6107 .45052 .61277 .45431 .61165 .45213 .60957 Mtetra
.45213 .60957 .45431 .61165 .45812 .61052 .45594 .60844 Mtetra
.45594 .60844 .45812 .61052 .46192 .6094 .45975 .60731 Mtetra
.45975 .60731 .46192 .6094 .46574 .60827 .46357 .60618 Mtetra
.46357 .60618 .46574 .60827 .46956 .60714 .46739 .60505 Mtetra
.951 .697 .518 r
.46739 .60505 .46956 .60714 .47338 .60601 .47283 .50117 Mtetra
.515 .322 .556 r
.47283 .50117 .47338 .60601 .47844 .51645 .47634 .5143 Mtetra
.662 .744 .911 r
.47634 .5143 .47844 .51645 .48218 .51529 .48008 .51313 Mtetra
.48008 .51313 .48218 .51529 .48592 .51412 .48382 .51196 Mtetra
.48382 .51196 .48592 .51412 .48967 .51295 .48757 .51079 Mtetra
.48757 .51079 .48967 .51295 .49342 .51178 .49133 .50961 Mtetra
.49133 .50961 .49342 .51178 .49717 .51061 .49509 .50844 Mtetra
.49509 .50844 .49717 .51061 .50094 .50943 .49886 .50726 Mtetra
.49886 .50726 .50094 .50943 .5047 .50826 .50263 .50608 Mtetra
.50263 .50608 .5047 .50826 .50848 .50708 .5064 .5049 Mtetra
.5064 .5049 .50848 .50708 .51226 .5059 .51018 .50372 Mtetra
.51018 .50372 .51226 .5059 .51604 .50472 .51397 .50254 Mtetra
.51397 .50254 .51604 .50472 .51983 .50354 .51776 .50135 Mtetra
.51776 .50135 .51983 .50354 .52362 .50236 .52156 .50017 Mtetra
.52156 .50017 .52362 .50236 .52742 .50117 .52536 .49898 Mtetra
.52536 .49898 .52742 .50117 .53122 .49999 .52917 .49779 Mtetra
.52917 .49779 .53122 .49999 .53503 .4988 .53298 .4966 Mtetra
.53298 .4966 .53503 .4988 .53885 .49761 .5368 .49541 Mtetra
.5368 .49541 .53885 .49761 .54267 .49642 .54062 .49421 Mtetra
.54062 .49421 .54267 .49642 .54649 .49522 .54445 .49301 Mtetra
.54445 .49301 .54649 .49522 .55032 .49403 .54829 .49182 Mtetra
.54829 .49182 .55032 .49403 .55416 .49283 .55213 .49062 Mtetra
.55213 .49062 .55416 .49283 .5581 .5013 .55597 .48941 Mtetra
.202 .178 .607 r
.55597 .48941 .5581 .5013 .56196 .5001 .55992 .49789 Mtetra
.661 .745 .912 r
.55992 .49789 .56196 .5001 .56582 .4989 .56379 .49669 Mtetra
.56379 .49669 .56582 .4989 .56969 .4977 .56766 .49548 Mtetra
.56766 .49548 .56969 .4977 .57356 .4965 .57154 .49428 Mtetra
.57154 .49428 .57356 .4965 .57744 .4953 .57542 .49307 Mtetra
.958 .715 .529 r
.57542 .49307 .57744 .4953 .58133 .49409 .57868 .45343 Mtetra
.575 .382 .582 r
.57868 .45343 .58133 .49409 .58522 .49289 .58253 .45221 Mtetra
.58253 .45221 .58522 .49289 .58911 .49168 .58638 .45098 Mtetra
.58638 .45098 .58911 .49168 .59301 .49047 .59024 .44976 Mtetra
.59024 .44976 .59301 .49047 .59692 .48926 .59411 .44853 Mtetra
.59411 .44853 .59692 .48926 .60083 .48804 .59798 .4473 Mtetra
.59798 .4473 .60083 .48804 .60382 .44834 .60185 .44607 Mtetra
.664 .741 .908 r
.60185 .44607 .60382 .44834 .6077 .44711 .60573 .44484 Mtetra
.60573 .44484 .6077 .44711 .61158 .44588 .60962 .4436 Mtetra
.60962 .4436 .61158 .44588 .61547 .44465 .61351 .44237 Mtetra
.61351 .44237 .61547 .44465 .61936 .44341 .61741 .44113 Mtetra
.61741 .44113 .61936 .44341 .62442 .48072 .62131 .43989 Mtetra
.078 .019 .481 r
.62131 .43989 .62442 .48072 .62837 .4795 .6264 .47723 Mtetra
.661 .745 .912 r
.6264 .47723 .62837 .4795 .63233 .47827 .63036 .476 Mtetra
.63036 .476 .63233 .47827 .63629 .47704 .63433 .47477 Mtetra
.63433 .47477 .63629 .47704 .64026 .47581 .6383 .47353 Mtetra
.6383 .47353 .64026 .47581 .64423 .47458 .64228 .4723 Mtetra
.64228 .4723 .64423 .47458 .64821 .47334 .64626 .47106 Mtetra
.64626 .47106 .64821 .47334 .6522 .47211 .65025 .46982 Mtetra
.65025 .46982 .6522 .47211 .65619 .47087 .65424 .46858 Mtetra
.65424 .46858 .65619 .47087 .66018 .46963 .65824 .46734 Mtetra
.65824 .46734 .66018 .46963 .66419 .46839 .66225 .46609 Mtetra
.66225 .46609 .66419 .46839 .66819 .46715 .66626 .46485 Mtetra
.66626 .46485 .66819 .46715 .67221 .4659 .67028 .4636 Mtetra
.67028 .4636 .67221 .4659 .67622 .46465 .6743 .46235 Mtetra
.6743 .46235 .67622 .46465 .68025 .46341 .67833 .4611 Mtetra
.67833 .4611 .68025 .46341 .68428 .46216 .68236 .45984 Mtetra
.68236 .45984 .68428 .46216 .68831 .4609 .6864 .45859 Mtetra
.97 .718 .499 r
.6864 .45859 .68831 .4609 .69236 .45965 .68849 .41855 Mtetra
.575 .382 .582 r
.68849 .41855 .69236 .45965 .69438 .41962 .69249 .41728 Mtetra
.664 .741 .908 r
.69249 .41728 .69438 .41962 .69838 .41835 .6965 .416 Mtetra
.6965 .416 .69838 .41835 .70239 .41708 .70051 .41473 Mtetra
.70051 .41473 .70239 .41708 .70641 .41581 .70453 .41345 Mtetra
.70453 .41345 .70641 .41581 .71043 .41453 .70856 .41217 Mtetra
.70856 .41217 .71043 .41453 .71445 .41325 .71259 .41089 Mtetra
.71259 .41089 .71445 .41325 .72052 .44592 .71663 .40961 Mtetra
.133 .069 .512 r
.71663 .40961 .72052 .44592 .7246 .44465 .72273 .4423 Mtetra
.661 .745 .912 r
.72273 .4423 .7246 .44465 .72869 .44337 .72682 .44102 Mtetra
.72682 .44102 .72869 .44337 .73278 .4421 .73092 .43975 Mtetra
.73092 .43975 .73278 .4421 .73688 .44083 .73502 .43847 Mtetra
.73502 .43847 .73688 .44083 .74099 .43955 .73913 .43719 Mtetra
.73913 .43719 .74099 .43955 .7451 .43827 .74324 .4359 Mtetra
.74324 .4359 .7451 .43827 .74921 .43699 .74737 .43462 Mtetra
.74737 .43462 .74921 .43699 .75334 .43571 .75149 .43333 Mtetra
.75149 .43333 .75334 .43571 .75747 .43442 .75563 .43205 Mtetra
.75563 .43205 .75747 .43442 .7616 .43314 .75977 .43076 Mtetra
.75977 .43076 .7616 .43314 .76574 .43185 .76391 .42946 Mtetra
.76391 .42946 .76574 .43185 .76989 .43056 .76806 .42817 Mtetra
.76806 .42817 .76989 .43056 .77404 .42926 .77222 .42687 Mtetra
.969 .65 .324 r
.77222 .42687 .77404 .42926 .78409 .50352 .78224 .50117 Mtetra
.655 .752 .921 r
.78224 .50117 .78409 .50352 .78835 .50225 .78651 .4999 Mtetra
.78651 .4999 .78835 .50225 .79263 .50098 .79078 .49862 Mtetra
.79078 .49862 .79263 .50098 .79691 .4997 .79507 .49735 Mtetra
.79507 .49735 .79691 .4997 .80119 .49843 .79936 .49607 Mtetra
.79936 .49607 .80119 .49843 .80548 .49715 .80365 .49479 Mtetra
.80365 .49479 .80548 .49715 .80978 .49587 .80795 .4935 Mtetra
.80795 .4935 .80978 .49587 .81409 .49459 .81226 .49222 Mtetra
.81226 .49222 .81409 .49459 .8184 .49331 .81658 .49093 Mtetra
.81658 .49093 .8184 .49331 .82271 .49202 .8209 .48964 Mtetra
.8209 .48964 .82271 .49202 .82704 .49073 .82523 .48835 Mtetra
.82523 .48835 .82704 .49073 .83137 .48945 .82956 .48706 Mtetra
.82956 .48706 .83137 .48945 .8357 .48815 .83391 .48577 Mtetra
.83391 .48577 .8357 .48815 .84005 .48686 .83825 .48447 Mtetra
.83825 .48447 .84005 .48686 .8444 .48557 .84261 .48317 Mtetra
.939 .58 .182 r
.84261 .48317 .8444 .48557 .85183 .51565 .85003 .51328 Mtetra
.653 .755 .925 r
.85003 .51328 .85183 .51565 .85623 .51437 .85444 .51198 Mtetra
.85444 .51198 .85623 .51437 .86065 .51308 .85886 .51069 Mtetra
.85886 .51069 .86065 .51308 .86507 .51179 .86328 .5094 Mtetra
.86328 .5094 .86507 .51179 .86949 .51049 .86771 .5081 Mtetra
.86771 .5081 .86949 .51049 .87393 .5092 .87215 .5068 Mtetra
.87215 .5068 .87393 .5092 .87837 .5079 .8766 .5055 Mtetra
.8766 .5055 .87837 .5079 .88281 .5066 .88105 .5042 Mtetra
.88105 .5042 .88281 .5066 .88727 .5053 .88551 .50289 Mtetra
.88551 .50289 .88727 .5053 .89173 .504 .88997 .50159 Mtetra
.88997 .50159 .89173 .504 .89619 .50269 .89444 .50028 Mtetra
.89444 .50028 .89619 .50269 .90067 .50139 .89892 .49897 Mtetra
.89892 .49897 .90067 .50139 .90515 .50008 .90341 .49766 Mtetra
.90341 .49766 .90515 .50008 .90963 .49877 .9079 .49634 Mtetra
.9079 .49634 .90963 .49877 .91413 .49745 .9124 .49503 Mtetra
.9124 .49503 .91413 .49745 .91863 .49614 .91691 .49371 Mtetra
.91691 .49371 .91863 .49614 .92314 .49482 .92142 .49239 Mtetra
.92142 .49239 .92314 .49482 .92765 .4935 .92594 .49106 Mtetra
.92594 .49106 .92765 .4935 .93217 .49218 .93047 .48974 Mtetra
.652 .755 .925 r
.31842 .67113 .32074 .6731 .32439 .67203 .32208 .67006 Mtetra
.32208 .67006 .32439 .67203 .32804 .67097 .32574 .669 Mtetra
.32574 .669 .32804 .67097 .33171 .6699 .3294 .66793 Mtetra
.3294 .66793 .33171 .6699 .33537 .66883 .33307 .66685 Mtetra
.33307 .66685 .33537 .66883 .33904 .66776 .33674 .66578 Mtetra
.33674 .66578 .33904 .66776 .34272 .66669 .34042 .6647 Mtetra
.34042 .6647 .34272 .66669 .3464 .66561 .34411 .66363 Mtetra
.34411 .66363 .3464 .66561 .35009 .66454 .3478 .66255 Mtetra
.3478 .66255 .35009 .66454 .35378 .66346 .35149 .66147 Mtetra
.35149 .66147 .35378 .66346 .35748 .66238 .35519 .66039 Mtetra
.35519 .66039 .35748 .66238 .36118 .6613 .3589 .65931 Mtetra
.3589 .65931 .36118 .6613 .36489 .66022 .36261 .65822 Mtetra
.36261 .65822 .36489 .66022 .3686 .65914 .36632 .65714 Mtetra
.36632 .65714 .3686 .65914 .37232 .65806 .37004 .65605 Mtetra
.37004 .65605 .37232 .65806 .37604 .65697 .37377 .65496 Mtetra
.37377 .65496 .37604 .65697 .37977 .65588 .3775 .65387 Mtetra
.947 .638 .418 r
.3775 .65387 .37977 .65588 .3835 .65479 .38018 .67836 Mtetra
.536 .291 .49 r
.38018 .67836 .3835 .65479 .38724 .6537 .38395 .67727 Mtetra
.38395 .67727 .38724 .6537 .39 .67819 .38772 .67619 Mtetra
.65 .758 .928 r
.38772 .67619 .39 .67819 .39377 .67711 .3915 .6751 Mtetra
.3915 .6751 .39377 .67711 .39755 .67602 .39529 .67401 Mtetra
.39529 .67401 .39755 .67602 .40134 .67493 .39908 .67292 Mtetra
.39908 .67292 .40134 .67493 .40513 .67385 .40287 .67183 Mtetra
.40287 .67183 .40513 .67385 .40893 .67276 .40667 .67074 Mtetra
.40667 .67074 .40893 .67276 .41436 .62076 .41048 .66965 Mtetra
.549 .321 .522 r
.41048 .66965 .41436 .62076 .41812 .61965 .41429 .66855 Mtetra
0 0 .254 r
.41429 .66855 .41812 .61965 .42188 .61854 .41966 .61648 Mtetra
.655 .753 .922 r
.41966 .61648 .42188 .61854 .42564 .61742 .42343 .61536 Mtetra
.42343 .61536 .42564 .61742 .42941 .61631 .4272 .61424 Mtetra
.4272 .61424 .42941 .61631 .43318 .61519 .43098 .61312 Mtetra
.43098 .61312 .43318 .61519 .43696 .61407 .43476 .612 Mtetra
.43476 .612 .43696 .61407 .44075 .61295 .43855 .61087 Mtetra
.43855 .61087 .44075 .61295 .44454 .61182 .44235 .60975 Mtetra
.44235 .60975 .44454 .61182 .44833 .6107 .44614 .60862 Mtetra
.44614 .60862 .44833 .6107 .45213 .60957 .44995 .60749 Mtetra
.949 .697 .522 r
.44995 .60749 .45213 .60957 .45594 .60844 .45589 .50368 Mtetra
.566 .361 .562 r
.45589 .50368 .45594 .60844 .45975 .60731 .45959 .50252 Mtetra
.45959 .50252 .45975 .60731 .46357 .60618 .4633 .50135 Mtetra
.4633 .50135 .46357 .60618 .46739 .60505 .46701 .50017 Mtetra
.46701 .50017 .46739 .60505 .47283 .50117 .47073 .499 Mtetra
.663 .743 .91 r
.47073 .499 .47283 .50117 .47634 .5143 .47445 .49783 Mtetra
.099 .07 .534 r
.47445 .49783 .47634 .5143 .48008 .51313 .47797 .51097 Mtetra
.662 .744 .911 r
.47797 .51097 .48008 .51313 .48382 .51196 .48172 .5098 Mtetra
.48172 .5098 .48382 .51196 .48757 .51079 .48548 .50862 Mtetra
.48548 .50862 .48757 .51079 .49133 .50961 .48924 .50744 Mtetra
.48924 .50744 .49133 .50961 .49509 .50844 .493 .50627 Mtetra
.493 .50627 .49509 .50844 .49886 .50726 .49677 .50509 Mtetra
.49677 .50509 .49886 .50726 .50263 .50608 .50054 .5039 Mtetra
.50054 .5039 .50263 .50608 .5064 .5049 .50432 .50272 Mtetra
.50432 .50272 .5064 .5049 .51018 .50372 .50811 .50154 Mtetra
.50811 .50154 .51018 .50372 .51397 .50254 .5119 .50035 Mtetra
.5119 .50035 .51397 .50254 .51776 .50135 .51569 .49916 Mtetra
.51569 .49916 .51776 .50135 .52156 .50017 .51949 .49797 Mtetra
.51949 .49797 .52156 .50017 .52536 .49898 .5233 .49678 Mtetra
.5233 .49678 .52536 .49898 .52917 .49779 .52711 .49559 Mtetra
.52711 .49559 .52917 .49779 .53298 .4966 .53093 .49439 Mtetra
.53093 .49439 .53298 .4966 .5368 .49541 .53475 .4932 Mtetra
.53475 .4932 .5368 .49541 .54062 .49421 .53858 .492 Mtetra
.53858 .492 .54062 .49421 .54445 .49301 .54241 .4908 Mtetra
.54241 .4908 .54445 .49301 .54829 .49182 .54625 .4896 Mtetra
.54625 .4896 .54829 .49182 .55213 .49062 .55009 .4884 Mtetra
.55009 .4884 .55213 .49062 .55597 .48941 .55394 .48719 Mtetra
.952 .721 .552 r
.55394 .48719 .55597 .48941 .55992 .49789 .55751 .45728 Mtetra
.574 .381 .582 r
.55751 .45728 .55992 .49789 .56379 .49669 .56133 .45606 Mtetra
.56133 .45606 .56379 .49669 .56766 .49548 .56516 .45484 Mtetra
.56516 .45484 .56766 .49548 .57154 .49428 .569 .45362 Mtetra
.569 .45362 .57154 .49428 .57542 .49307 .57284 .4524 Mtetra
.57284 .4524 .57542 .49307 .57868 .45343 .57668 .45117 Mtetra
.664 .741 .908 r
.57668 .45117 .57868 .45343 .58253 .45221 .58054 .44995 Mtetra
.58054 .44995 .58253 .45221 .58638 .45098 .58439 .44872 Mtetra
.58439 .44872 .58638 .45098 .59024 .44976 .58826 .44749 Mtetra
.58826 .44749 .59024 .44976 .59411 .44853 .59212 .44626 Mtetra
.59212 .44626 .59411 .44853 .59798 .4473 .596 .44503 Mtetra
.596 .44503 .59798 .4473 .60185 .44607 .59988 .44379 Mtetra
.59988 .44379 .60185 .44607 .60573 .44484 .60376 .44256 Mtetra
.60376 .44256 .60573 .44484 .60962 .4436 .60765 .44132 Mtetra
.60765 .44132 .60962 .4436 .61351 .44237 .61155 .44008 Mtetra
.61155 .44008 .61351 .44237 .61741 .44113 .61545 .43884 Mtetra
.61545 .43884 .61741 .44113 .62131 .43989 .61935 .4376 Mtetra
.964 .644 .354 r
.61935 .4376 .62131 .43989 .6264 .47723 .62443 .47496 Mtetra
.661 .745 .912 r
.62443 .47496 .6264 .47723 .63036 .476 .62839 .47372 Mtetra
.62839 .47372 .63036 .476 .63433 .47477 .63236 .47249 Mtetra
.63236 .47249 .63433 .47477 .6383 .47353 .63634 .47125 Mtetra
.63634 .47125 .6383 .47353 .64228 .4723 .64032 .47001 Mtetra
.64032 .47001 .64228 .4723 .64626 .47106 .64431 .46877 Mtetra
.64431 .46877 .64626 .47106 .65025 .46982 .6483 .46753 Mtetra
.6483 .46753 .65025 .46982 .65424 .46858 .6523 .46628 Mtetra
.6523 .46628 .65424 .46858 .65824 .46734 .6563 .46504 Mtetra
.6563 .46504 .65824 .46734 .66225 .46609 .66031 .46379 Mtetra
.66031 .46379 .66225 .46609 .66626 .46485 .66432 .46254 Mtetra
.66432 .46254 .66626 .46485 .67028 .4636 .66835 .46129 Mtetra
.66835 .46129 .67028 .4636 .6743 .46235 .67237 .46004 Mtetra
.67237 .46004 .6743 .46235 .67833 .4611 .6764 .45878 Mtetra
.6764 .45878 .67833 .4611 .68236 .45984 .68044 .45752 Mtetra
.969 .718 .501 r
.68044 .45752 .68236 .45984 .6864 .45859 .6826 .41747 Mtetra
.574 .381 .582 r
.6826 .41747 .6864 .45859 .68849 .41855 .6866 .4162 Mtetra
.664 .741 .908 r
.6866 .4162 .68849 .41855 .69249 .41728 .6906 .41492 Mtetra
.6906 .41492 .69249 .41728 .6965 .416 .69462 .41365 Mtetra
.69462 .41365 .6965 .416 .70051 .41473 .69863 .41237 Mtetra
.69863 .41237 .70051 .41473 .70453 .41345 .70266 .41109 Mtetra
.70266 .41109 .70453 .41345 .70856 .41217 .70669 .40981 Mtetra
.70669 .40981 .70856 .41217 .71259 .41089 .71072 .40852 Mtetra
.71072 .40852 .71259 .41089 .71663 .40961 .71476 .40724 Mtetra
.959 .621 .281 r
.71476 .40724 .71663 .40961 .72273 .4423 .72085 .43994 Mtetra
.661 .745 .912 r
.72085 .43994 .72273 .4423 .72682 .44102 .72494 .43866 Mtetra
.72494 .43866 .72682 .44102 .73092 .43975 .72905 .43738 Mtetra
.72905 .43738 .73092 .43975 .73502 .43847 .73315 .4361 Mtetra
.73315 .4361 .73502 .43847 .73913 .43719 .73727 .43482 Mtetra
.73727 .43482 .73913 .43719 .74324 .4359 .74139 .43353 Mtetra
.74139 .43353 .74324 .4359 .74737 .43462 .74551 .43224 Mtetra
.74551 .43224 .74737 .43462 .75149 .43333 .74964 .43095 Mtetra
.74964 .43095 .75149 .43333 .75563 .43205 .75378 .42966 Mtetra
.75378 .42966 .75563 .43205 .75977 .43076 .75792 .42837 Mtetra
.75792 .42837 .75977 .43076 .76391 .42946 .76207 .42707 Mtetra
.76207 .42707 .76391 .42946 .76806 .42817 .76623 .42578 Mtetra
.76623 .42578 .76806 .42817 .77222 .42687 .77039 .42448 Mtetra
.969 .65 .324 r
.77039 .42448 .77222 .42687 .78224 .50117 .78038 .49882 Mtetra
.655 .752 .921 r
.78038 .49882 .78224 .50117 .78651 .4999 .78465 .49754 Mtetra
.78465 .49754 .78651 .4999 .79078 .49862 .78893 .49626 Mtetra
.78893 .49626 .79078 .49862 .79507 .49735 .79322 .49498 Mtetra
.79322 .49498 .79507 .49735 .79936 .49607 .79752 .4937 Mtetra
.79752 .4937 .79936 .49607 .80365 .49479 .80182 .49242 Mtetra
.80182 .49242 .80365 .49479 .80795 .4935 .80612 .49113 Mtetra
.80612 .49113 .80795 .4935 .81226 .49222 .81044 .48984 Mtetra
.81044 .48984 .81226 .49222 .81658 .49093 .81476 .48855 Mtetra
.81476 .48855 .81658 .49093 .8209 .48964 .81908 .48726 Mtetra
.81908 .48726 .8209 .48964 .82523 .48835 .82342 .48597 Mtetra
.82342 .48597 .82523 .48835 .82956 .48706 .82776 .48467 Mtetra
.82776 .48467 .82956 .48706 .83391 .48577 .8321 .48337 Mtetra
.8321 .48337 .83391 .48577 .83825 .48447 .83645 .48207 Mtetra
.83645 .48207 .83825 .48447 .84261 .48317 .84081 .48077 Mtetra
.939 .58 .182 r
.84081 .48077 .84261 .48317 .85003 .51328 .84823 .51089 Mtetra
.653 .755 .925 r
.84823 .51089 .85003 .51328 .85444 .51198 .85264 .5096 Mtetra
.85264 .5096 .85444 .51198 .85886 .51069 .85707 .5083 Mtetra
.85707 .5083 .85886 .51069 .86328 .5094 .86149 .507 Mtetra
.86149 .507 .86328 .5094 .86771 .5081 .86593 .5057 Mtetra
.86593 .5057 .86771 .5081 .87215 .5068 .87037 .5044 Mtetra
.87037 .5044 .87215 .5068 .8766 .5055 .87482 .5031 Mtetra
.87482 .5031 .8766 .5055 .88105 .5042 .87928 .50179 Mtetra
.87928 .50179 .88105 .5042 .88551 .50289 .88374 .50048 Mtetra
.88374 .50048 .88551 .50289 .88997 .50159 .88821 .49917 Mtetra
.88821 .49917 .88997 .50159 .89444 .50028 .89269 .49786 Mtetra
.89269 .49786 .89444 .50028 .89892 .49897 .89717 .49654 Mtetra
.89717 .49654 .89892 .49897 .90341 .49766 .90166 .49523 Mtetra
.90166 .49523 .90341 .49766 .9079 .49634 .90616 .49391 Mtetra
.90616 .49391 .9079 .49634 .9124 .49503 .91067 .49259 Mtetra
.91067 .49259 .9124 .49503 .91691 .49371 .91518 .49127 Mtetra
.91518 .49127 .91691 .49371 .92142 .49239 .9197 .48994 Mtetra
.9197 .48994 .92142 .49239 .92594 .49106 .92422 .48862 Mtetra
.92422 .48862 .92594 .49106 .93047 .48974 .92875 .48729 Mtetra
.652 .755 .925 r
.3161 .66916 .31842 .67113 .32208 .67006 .31976 .66809 Mtetra
.31976 .66809 .32208 .67006 .32574 .669 .32342 .66702 Mtetra
.32342 .66702 .32574 .669 .3294 .66793 .32709 .66594 Mtetra
.32709 .66594 .3294 .66793 .33307 .66685 .33076 .66487 Mtetra
.33076 .66487 .33307 .66685 .33674 .66578 .33444 .66379 Mtetra
.33444 .66379 .33674 .66578 .34042 .6647 .33812 .66272 Mtetra
.33812 .66272 .34042 .6647 .34411 .66363 .34181 .66164 Mtetra
.34181 .66164 .34411 .66363 .3478 .66255 .3455 .66056 Mtetra
.3455 .66056 .3478 .66255 .35149 .66147 .3492 .65947 Mtetra
.3492 .65947 .35149 .66147 .35519 .66039 .3529 .65839 Mtetra
.3529 .65839 .35519 .66039 .3589 .65931 .35661 .6573 Mtetra
.35661 .6573 .3589 .65931 .36261 .65822 .36032 .65622 Mtetra
.36032 .65622 .36261 .65822 .36632 .65714 .36404 .65513 Mtetra
.36404 .65513 .36632 .65714 .37004 .65605 .36777 .65404 Mtetra
.36777 .65404 .37004 .65605 .37377 .65496 .3715 .65295 Mtetra
.947 .638 .419 r
.3715 .65295 .37377 .65496 .3775 .65387 .37413 .67744 Mtetra
.536 .29 .49 r
.37413 .67744 .3775 .65387 .38018 .67836 .3779 .67635 Mtetra
.65 .758 .928 r
.3779 .67635 .38018 .67836 .38395 .67727 .38167 .67527 Mtetra
.38167 .67527 .38395 .67727 .38772 .67619 .38544 .67418 Mtetra
.38544 .67418 .38772 .67619 .3915 .6751 .38923 .67309 Mtetra
.38923 .67309 .3915 .6751 .39529 .67401 .39301 .672 Mtetra
.39301 .672 .39529 .67401 .39908 .67292 .39681 .67091 Mtetra
.39681 .67091 .39908 .67292 .40287 .67183 .4006 .66982 Mtetra
.4006 .66982 .40287 .67183 .40667 .67074 .40441 .66872 Mtetra
.40441 .66872 .40667 .67074 .41048 .66965 .40822 .66762 Mtetra
.40822 .66762 .41048 .66965 .41429 .66855 .41203 .66652 Mtetra
.41203 .66652 .41429 .66855 .41966 .61648 .41585 .66542 Mtetra
0 0 .254 r
.41585 .66542 .41966 .61648 .42343 .61536 .42122 .61329 Mtetra
.655 .753 .922 r
.42122 .61329 .42343 .61536 .4272 .61424 .42499 .61217 Mtetra
.42499 .61217 .4272 .61424 .43098 .61312 .42877 .61104 Mtetra
.42877 .61104 .43098 .61312 .43476 .612 .43256 .60992 Mtetra
.947 .696 .525 r
.43256 .60992 .43476 .612 .43855 .61087 .439 .5062 Mtetra
.566 .361 .562 r
.439 .5062 .43855 .61087 .44235 .60975 .44268 .50503 Mtetra
.44268 .50503 .44235 .60975 .44614 .60862 .44637 .50386 Mtetra
.44637 .50386 .44614 .60862 .44995 .60749 .45007 .5027 Mtetra
.45007 .5027 .44995 .60749 .45589 .50368 .45377 .50153 Mtetra
.663 .743 .91 r
.45377 .50153 .45589 .50368 .45959 .50252 .45747 .50036 Mtetra
.45747 .50036 .45959 .50252 .4633 .50135 .46118 .49918 Mtetra
.46118 .49918 .4633 .50135 .46701 .50017 .4649 .49801 Mtetra
.4649 .49801 .46701 .50017 .47073 .499 .46862 .49683 Mtetra
.46862 .49683 .47073 .499 .47445 .49783 .47235 .49565 Mtetra
.47235 .49565 .47445 .49783 .47797 .51097 .47608 .49447 Mtetra
.099 .07 .534 r
.47608 .49447 .47797 .51097 .48172 .5098 .47962 .50762 Mtetra
.662 .744 .911 r
.47962 .50762 .48172 .5098 .48548 .50862 .48338 .50645 Mtetra
.48338 .50645 .48548 .50862 .48924 .50744 .48714 .50527 Mtetra
.48714 .50527 .48924 .50744 .493 .50627 .4909 .50409 Mtetra
.4909 .50409 .493 .50627 .49677 .50509 .49468 .5029 Mtetra
.49468 .5029 .49677 .50509 .50054 .5039 .49845 .50172 Mtetra
.49845 .50172 .50054 .5039 .50432 .50272 .50224 .50053 Mtetra
.50224 .50053 .50432 .50272 .50811 .50154 .50603 .49935 Mtetra
.50603 .49935 .50811 .50154 .5119 .50035 .50982 .49816 Mtetra
.50982 .49816 .5119 .50035 .51569 .49916 .51362 .49697 Mtetra
.51362 .49697 .51569 .49916 .51949 .49797 .51742 .49577 Mtetra
.51742 .49577 .51949 .49797 .5233 .49678 .52123 .49458 Mtetra
.52123 .49458 .5233 .49678 .52711 .49559 .52505 .49338 Mtetra
.52505 .49338 .52711 .49559 .53093 .49439 .52887 .49218 Mtetra
.52887 .49218 .53093 .49439 .53475 .4932 .53269 .49099 Mtetra
.53269 .49099 .53475 .4932 .53858 .492 .53652 .48978 Mtetra
.53652 .48978 .53858 .492 .54241 .4908 .54036 .48858 Mtetra
.54036 .48858 .54241 .4908 .54625 .4896 .5442 .48738 Mtetra
.5442 .48738 .54625 .4896 .55009 .4884 .54804 .48617 Mtetra
.54804 .48617 .55009 .4884 .55394 .48719 .5519 .48496 Mtetra
.952 .721 .552 r
.5519 .48496 .55394 .48719 .55751 .45728 .55549 .45503 Mtetra
.664 .741 .908 r
.55549 .45503 .55751 .45728 .56133 .45606 .55931 .45381 Mtetra
.55931 .45381 .56133 .45606 .56516 .45484 .56315 .45258 Mtetra
.56315 .45258 .56516 .45484 .569 .45362 .56699 .45136 Mtetra
.56699 .45136 .569 .45362 .57284 .4524 .57083 .45014 Mtetra
.57083 .45014 .57284 .4524 .57668 .45117 .57468 .44891 Mtetra
.57468 .44891 .57668 .45117 .58054 .44995 .57854 .44768 Mtetra
.57854 .44768 .58054 .44995 .58439 .44872 .5824 .44645 Mtetra
.5824 .44645 .58439 .44872 .58826 .44749 .58627 .44522 Mtetra
.58627 .44522 .58826 .44749 .59212 .44626 .59014 .44398 Mtetra
.59014 .44398 .59212 .44626 .596 .44503 .59401 .44275 Mtetra
.59401 .44275 .596 .44503 .59988 .44379 .5979 .44151 Mtetra
.5979 .44151 .59988 .44379 .60376 .44256 .60178 .44027 Mtetra
.60178 .44027 .60376 .44256 .60765 .44132 .60568 .43903 Mtetra
.60568 .43903 .60765 .44132 .61155 .44008 .60958 .43779 Mtetra
.60958 .43779 .61155 .44008 .61545 .43884 .61348 .43654 Mtetra
.61348 .43654 .61545 .43884 .61935 .4376 .61739 .4353 Mtetra
.61739 .4353 .61935 .4376 .62443 .47496 .62131 .43405 Mtetra
.076 .017 .48 r
.62131 .43405 .62443 .47496 .62839 .47372 .62642 .47144 Mtetra
.661 .745 .912 r
.62642 .47144 .62839 .47372 .63236 .47249 .63039 .4702 Mtetra
.63039 .4702 .63236 .47249 .63634 .47125 .63437 .46896 Mtetra
.63437 .46896 .63634 .47125 .64032 .47001 .63835 .46772 Mtetra
.63835 .46772 .64032 .47001 .64431 .46877 .64234 .46648 Mtetra
.64234 .46648 .64431 .46877 .6483 .46753 .64634 .46523 Mtetra
.64634 .46523 .6483 .46753 .6523 .46628 .65034 .46398 Mtetra
.65034 .46398 .6523 .46628 .6563 .46504 .65435 .46273 Mtetra
.65435 .46273 .6563 .46504 .66031 .46379 .65836 .46148 Mtetra
.65836 .46148 .66031 .46379 .66432 .46254 .66238 .46023 Mtetra
.66238 .46023 .66432 .46254 .66835 .46129 .66641 .45897 Mtetra
.66641 .45897 .66835 .46129 .67237 .46004 .67044 .45772 Mtetra
.968 .718 .503 r
.67044 .45772 .67237 .46004 .6764 .45878 .6727 .41767 Mtetra
.574 .381 .581 r
.6727 .41767 .6764 .45878 .68044 .45752 .6767 .41639 Mtetra
.6767 .41639 .68044 .45752 .6826 .41747 .6807 .41512 Mtetra
.664 .741 .908 r
.6807 .41512 .6826 .41747 .6866 .4162 .6847 .41384 Mtetra
.6847 .41384 .6866 .4162 .6906 .41492 .68871 .41257 Mtetra
.68871 .41257 .6906 .41492 .69462 .41365 .69273 .41129 Mtetra
.69273 .41129 .69462 .41365 .69863 .41237 .69675 .41 Mtetra
.69675 .41 .69863 .41237 .70266 .41109 .70077 .40872 Mtetra
.70077 .40872 .70266 .41109 .70669 .40981 .70481 .40743 Mtetra
.70481 .40743 .70669 .40981 .71072 .40852 .70885 .40615 Mtetra
.70885 .40615 .71072 .40852 .71476 .40724 .71289 .40486 Mtetra
.959 .621 .281 r
.71289 .40486 .71476 .40724 .72085 .43994 .71896 .43758 Mtetra
.661 .745 .912 r
.71896 .43758 .72085 .43994 .72494 .43866 .72306 .4363 Mtetra
.72306 .4363 .72494 .43866 .72905 .43738 .72717 .43501 Mtetra
.72717 .43501 .72905 .43738 .73315 .4361 .73128 .43373 Mtetra
.73128 .43373 .73315 .4361 .73727 .43482 .7354 .43244 Mtetra
.7354 .43244 .73727 .43482 .74139 .43353 .73952 .43115 Mtetra
.73952 .43115 .74139 .43353 .74551 .43224 .74365 .42986 Mtetra
.74365 .42986 .74551 .43224 .74964 .43095 .74779 .42857 Mtetra
.74779 .42857 .74964 .43095 .75378 .42966 .75193 .42727 Mtetra
.75193 .42727 .75378 .42966 .75792 .42837 .75608 .42598 Mtetra
.75608 .42598 .75792 .42837 .76207 .42707 .76023 .42468 Mtetra
.76023 .42468 .76207 .42707 .76623 .42578 .76439 .42338 Mtetra
.76439 .42338 .76623 .42578 .77039 .42448 .76856 .42208 Mtetra
.969 .65 .324 r
.76856 .42208 .77039 .42448 .78038 .49882 .77851 .49646 Mtetra
.655 .752 .921 r
.77851 .49646 .78038 .49882 .78465 .49754 .78279 .49518 Mtetra
.78279 .49518 .78465 .49754 .78893 .49626 .78708 .4939 Mtetra
.78708 .4939 .78893 .49626 .79322 .49498 .79137 .49261 Mtetra
.79137 .49261 .79322 .49498 .79752 .4937 .79567 .49133 Mtetra
.79567 .49133 .79752 .4937 .80182 .49242 .79997 .49004 Mtetra
.79997 .49004 .80182 .49242 .80612 .49113 .80429 .48875 Mtetra
.80429 .48875 .80612 .49113 .81044 .48984 .8086 .48746 Mtetra
.8086 .48746 .81044 .48984 .81476 .48855 .81293 .48617 Mtetra
.81293 .48617 .81476 .48855 .81908 .48726 .81726 .48487 Mtetra
.81726 .48487 .81908 .48726 .82342 .48597 .8216 .48357 Mtetra
.8216 .48357 .82342 .48597 .82776 .48467 .82594 .48227 Mtetra
.82594 .48227 .82776 .48467 .8321 .48337 .83029 .48097 Mtetra
.83029 .48097 .8321 .48337 .83645 .48207 .83465 .47967 Mtetra
.83465 .47967 .83645 .48207 .84081 .48077 .83901 .47836 Mtetra
.939 .58 .182 r
.83901 .47836 .84081 .48077 .84823 .51089 .84642 .5085 Mtetra
.653 .755 .925 r
.84642 .5085 .84823 .51089 .85264 .5096 .85084 .5072 Mtetra
.85084 .5072 .85264 .5096 .85707 .5083 .85527 .5059 Mtetra
.85527 .5059 .85707 .5083 .86149 .507 .8597 .5046 Mtetra
.8597 .5046 .86149 .507 .86593 .5057 .86414 .5033 Mtetra
.86414 .5033 .86593 .5057 .87037 .5044 .86859 .50199 Mtetra
.86859 .50199 .87037 .5044 .87482 .5031 .87304 .50068 Mtetra
.87304 .50068 .87482 .5031 .87928 .50179 .87751 .49937 Mtetra
.87751 .49937 .87928 .50179 .88374 .50048 .88197 .49806 Mtetra
.88197 .49806 .88374 .50048 .88821 .49917 .88645 .49675 Mtetra
.88645 .49675 .88821 .49917 .89269 .49786 .89093 .49543 Mtetra
.89093 .49543 .89269 .49786 .89717 .49654 .89542 .49411 Mtetra
.89542 .49411 .89717 .49654 .90166 .49523 .89992 .49279 Mtetra
.89992 .49279 .90166 .49523 .90616 .49391 .90442 .49147 Mtetra
.90442 .49147 .90616 .49391 .91067 .49259 .90893 .49015 Mtetra
.90893 .49015 .91067 .49259 .91518 .49127 .91344 .48882 Mtetra
.91344 .48882 .91518 .49127 .9197 .48994 .91797 .48749 Mtetra
.91797 .48749 .9197 .48994 .92422 .48862 .9225 .48616 Mtetra
.9225 .48616 .92422 .48862 .92875 .48729 .92703 .48483 Mtetra
.652 .755 .925 r
.31377 .66718 .3161 .66916 .31976 .66809 .31743 .66611 Mtetra
.31743 .66611 .31976 .66809 .32342 .66702 .3211 .66504 Mtetra
.3211 .66504 .32342 .66702 .32709 .66594 .32477 .66396 Mtetra
.32477 .66396 .32709 .66594 .33076 .66487 .32845 .66288 Mtetra
.32845 .66288 .33076 .66487 .33444 .66379 .33213 .6618 Mtetra
.33213 .6618 .33444 .66379 .33812 .66272 .33581 .66072 Mtetra
.33581 .66072 .33812 .66272 .34181 .66164 .3395 .65964 Mtetra
.3395 .65964 .34181 .66164 .3455 .66056 .3432 .65856 Mtetra
.3432 .65856 .3455 .66056 .3492 .65947 .3469 .65747 Mtetra
.3469 .65747 .3492 .65947 .3529 .65839 .35061 .65638 Mtetra
.35061 .65638 .3529 .65839 .35661 .6573 .35432 .6553 Mtetra
.35432 .6553 .35661 .6573 .36032 .65622 .35804 .65421 Mtetra
.35804 .65421 .36032 .65622 .36404 .65513 .36176 .65312 Mtetra
.36176 .65312 .36404 .65513 .36777 .65404 .36548 .65202 Mtetra
.947 .639 .421 r
.36548 .65202 .36777 .65404 .3715 .65295 .36807 .67652 Mtetra
.535 .289 .489 r
.36807 .67652 .3715 .65295 .37413 .67744 .37183 .67544 Mtetra
.65 .758 .928 r
.37183 .67544 .37413 .67744 .3779 .67635 .3756 .67435 Mtetra
.3756 .67435 .3779 .67635 .38167 .67527 .37938 .67326 Mtetra
.37938 .67326 .38167 .67527 .38544 .67418 .38316 .67217 Mtetra
.38316 .67217 .38544 .67418 .38923 .67309 .38694 .67108 Mtetra
.38694 .67108 .38923 .67309 .39301 .672 .39074 .66998 Mtetra
.39074 .66998 .39301 .672 .39681 .67091 .39453 .66889 Mtetra
.39453 .66889 .39681 .67091 .4006 .66982 .39833 .66779 Mtetra
.39833 .66779 .4006 .66982 .40441 .66872 .40214 .66669 Mtetra
.40214 .66669 .40441 .66872 .40822 .66762 .40595 .66559 Mtetra
.40595 .66559 .40822 .66762 .41203 .66652 .40977 .66449 Mtetra
.40977 .66449 .41203 .66652 .41585 .66542 .41359 .66339 Mtetra
.41359 .66339 .41585 .66542 .42122 .61329 .41742 .66229 Mtetra
.99 .767 .383 r
.41742 .66229 .42122 .61329 .42499 .61217 .42583 .50754 Mtetra
.565 .36 .562 r
.42583 .50754 .42499 .61217 .42877 .61104 .4295 .50638 Mtetra
.4295 .50638 .42877 .61104 .43256 .60992 .43318 .50521 Mtetra
.43318 .50521 .43256 .60992 .439 .5062 .43686 .50404 Mtetra
.663 .743 .91 r
.43686 .50404 .439 .5062 .44268 .50503 .44055 .50288 Mtetra
.44055 .50288 .44268 .50503 .44637 .50386 .44424 .50171 Mtetra
.44424 .50171 .44637 .50386 .45007 .5027 .44794 .50054 Mtetra
.44794 .50054 .45007 .5027 .45377 .50153 .45165 .49936 Mtetra
.45165 .49936 .45377 .50153 .45747 .50036 .45535 .49819 Mtetra
.45535 .49819 .45747 .50036 .46118 .49918 .45907 .49701 Mtetra
.45907 .49701 .46118 .49918 .4649 .49801 .46279 .49583 Mtetra
.46279 .49583 .4649 .49801 .46862 .49683 .46651 .49466 Mtetra
.46651 .49466 .46862 .49683 .47235 .49565 .47024 .49348 Mtetra
.47024 .49348 .47235 .49565 .47608 .49447 .47397 .49229 Mtetra
.47397 .49229 .47608 .49447 .47962 .50762 .47771 .49111 Mtetra
.099 .07 .534 r
.47771 .49111 .47962 .50762 .48338 .50645 .48127 .50427 Mtetra
.662 .744 .911 r
.48127 .50427 .48338 .50645 .48714 .50527 .48503 .50309 Mtetra
.48503 .50309 .48714 .50527 .4909 .50409 .4888 .5019 Mtetra
.4888 .5019 .4909 .50409 .49468 .5029 .49258 .50072 Mtetra
.49258 .50072 .49468 .5029 .49845 .50172 .49636 .49953 Mtetra
.49636 .49953 .49845 .50172 .50224 .50053 .50015 .49834 Mtetra
.50015 .49834 .50224 .50053 .50603 .49935 .50394 .49715 Mtetra
.50394 .49715 .50603 .49935 .50982 .49816 .50774 .49596 Mtetra
.50774 .49596 .50982 .49816 .51362 .49697 .51154 .49476 Mtetra
.51154 .49476 .51362 .49697 .51742 .49577 .51535 .49357 Mtetra
.51535 .49357 .51742 .49577 .52123 .49458 .51916 .49237 Mtetra
.51916 .49237 .52123 .49458 .52505 .49338 .52298 .49117 Mtetra
.52298 .49117 .52505 .49338 .52887 .49218 .5268 .48997 Mtetra
.5268 .48997 .52887 .49218 .53269 .49099 .53063 .48877 Mtetra
.53063 .48877 .53269 .49099 .53652 .48978 .53446 .48756 Mtetra
.53446 .48756 .53652 .48978 .54036 .48858 .5383 .48636 Mtetra
.5383 .48636 .54036 .48858 .5442 .48738 .54215 .48515 Mtetra
.54215 .48515 .5442 .48738 .54804 .48617 .546 .48394 Mtetra
.952 .721 .553 r
.546 .48394 .54804 .48617 .5519 .48496 .54963 .45399 Mtetra
.578 .39 .591 r
.54963 .45399 .5519 .48496 .55549 .45503 .55346 .45277 Mtetra
.664 .741 .908 r
.55346 .45277 .55549 .45503 .55931 .45381 .55729 .45155 Mtetra
.55729 .45155 .55931 .45381 .56315 .45258 .56113 .45032 Mtetra
.56113 .45032 .56315 .45258 .56699 .45136 .56497 .4491 Mtetra
.56497 .4491 .56699 .45136 .57083 .45014 .56882 .44787 Mtetra
.56882 .44787 .57083 .45014 .57468 .44891 .57268 .44664 Mtetra
.57268 .44664 .57468 .44891 .57854 .44768 .57654 .44541 Mtetra
.57654 .44541 .57854 .44768 .5824 .44645 .5804 .44417 Mtetra
.5804 .44417 .5824 .44645 .58627 .44522 .58427 .44294 Mtetra
.58427 .44294 .58627 .44522 .59014 .44398 .58814 .4417 Mtetra
.58814 .4417 .59014 .44398 .59401 .44275 .59203 .44046 Mtetra
.59203 .44046 .59401 .44275 .5979 .44151 .59591 .43922 Mtetra
.59591 .43922 .5979 .44151 .60178 .44027 .5998 .43798 Mtetra
.5998 .43798 .60178 .44027 .60568 .43903 .6037 .43673 Mtetra
.6037 .43673 .60568 .43903 .60958 .43779 .6076 .43549 Mtetra
.6076 .43549 .60958 .43779 .61348 .43654 .61151 .43424 Mtetra
.61151 .43424 .61348 .43654 .61739 .4353 .61542 .43299 Mtetra
.61542 .43299 .61739 .4353 .62131 .43405 .61934 .43174 Mtetra
.61934 .43174 .62131 .43405 .62642 .47144 .62327 .43049 Mtetra
.076 .017 .48 r
.62327 .43049 .62642 .47144 .63039 .4702 .62841 .46791 Mtetra
.661 .745 .912 r
.62841 .46791 .63039 .4702 .63437 .46896 .6324 .46667 Mtetra
.6324 .46667 .63437 .46896 .63835 .46772 .63638 .46542 Mtetra
.63638 .46542 .63835 .46772 .64234 .46648 .64038 .46417 Mtetra
.64038 .46417 .64234 .46648 .64634 .46523 .64438 .46293 Mtetra
.64438 .46293 .64634 .46523 .65034 .46398 .64838 .46167 Mtetra
.64838 .46167 .65034 .46398 .65435 .46273 .6524 .46042 Mtetra
.6524 .46042 .65435 .46273 .65836 .46148 .65641 .45917 Mtetra
.65641 .45917 .65836 .46148 .66238 .46023 .66044 .45791 Mtetra
.66044 .45791 .66238 .46023 .66641 .45897 .66446 .45665 Mtetra
.968 .718 .504 r
.66446 .45665 .66641 .45897 .67044 .45772 .6668 .41659 Mtetra
.574 .38 .581 r
.6668 .41659 .67044 .45772 .6727 .41767 .67079 .41532 Mtetra
.664 .741 .908 r
.67079 .41532 .6727 .41767 .6767 .41639 .67479 .41404 Mtetra
.67479 .41404 .6767 .41639 .6807 .41512 .67879 .41276 Mtetra
.67879 .41276 .6807 .41512 .6847 .41384 .6828 .41148 Mtetra
.6828 .41148 .6847 .41384 .68871 .41257 .68681 .4102 Mtetra
.68681 .4102 .68871 .41257 .69273 .41129 .69083 .40892 Mtetra
.69083 .40892 .69273 .41129 .69675 .41 .69486 .40763 Mtetra
.69486 .40763 .69675 .41 .70077 .40872 .69889 .40635 Mtetra
.69889 .40635 .70077 .40872 .70481 .40743 .70292 .40506 Mtetra
.70292 .40506 .70481 .40743 .70885 .40615 .70697 .40377 Mtetra
.70697 .40377 .70885 .40615 .71289 .40486 .71101 .40247 Mtetra
.959 .621 .281 r
.71101 .40247 .71289 .40486 .71896 .43758 .71708 .43521 Mtetra
.661 .745 .912 r
.71708 .43521 .71896 .43758 .72306 .4363 .72118 .43393 Mtetra
.72118 .43393 .72306 .4363 .72717 .43501 .72529 .43264 Mtetra
.72529 .43264 .72717 .43501 .73128 .43373 .72941 .43135 Mtetra
.72941 .43135 .73128 .43373 .7354 .43244 .73353 .43006 Mtetra
.73353 .43006 .7354 .43244 .73952 .43115 .73766 .42877 Mtetra
.73766 .42877 .73952 .43115 .74365 .42986 .74179 .42747 Mtetra
.74179 .42747 .74365 .42986 .74779 .42857 .74593 .42618 Mtetra
.74593 .42618 .74779 .42857 .75193 .42727 .75008 .42488 Mtetra
.75008 .42488 .75193 .42727 .75608 .42598 .75423 .42358 Mtetra
.75423 .42358 .75608 .42598 .76023 .42468 .75838 .42228 Mtetra
.75838 .42228 .76023 .42468 .76439 .42338 .76255 .42097 Mtetra
.76255 .42097 .76439 .42338 .76856 .42208 .76672 .41967 Mtetra
.969 .65 .324 r
.76672 .41967 .76856 .42208 .77851 .49646 .77664 .4941 Mtetra
.655 .752 .921 r
.77664 .4941 .77851 .49646 .78279 .49518 .78093 .49281 Mtetra
.78093 .49281 .78279 .49518 .78708 .4939 .78522 .49153 Mtetra
.78522 .49153 .78708 .4939 .79137 .49261 .78952 .49024 Mtetra
.78952 .49024 .79137 .49261 .79567 .49133 .79382 .48895 Mtetra
.79382 .48895 .79567 .49133 .79997 .49004 .79813 .48766 Mtetra
.79813 .48766 .79997 .49004 .80429 .48875 .80244 .48636 Mtetra
.80244 .48636 .80429 .48875 .8086 .48746 .80677 .48507 Mtetra
.80677 .48507 .8086 .48746 .81293 .48617 .8111 .48377 Mtetra
.8111 .48377 .81293 .48617 .81726 .48487 .81543 .48247 Mtetra
.81543 .48247 .81726 .48487 .8216 .48357 .81977 .48117 Mtetra
.81977 .48117 .8216 .48357 .82594 .48227 .82412 .47987 Mtetra
.82412 .47987 .82594 .48227 .83029 .48097 .82848 .47856 Mtetra
.82848 .47856 .83029 .48097 .83465 .47967 .83284 .47726 Mtetra
.83284 .47726 .83465 .47967 .83901 .47836 .83721 .47595 Mtetra
.83721 .47595 .83901 .47836 .84642 .5085 .84158 .47464 Mtetra
.18 .113 .54 r
.84158 .47464 .84642 .5085 .85084 .5072 .84903 .5048 Mtetra
.653 .755 .925 r
.84903 .5048 .85084 .5072 .85527 .5059 .85346 .5035 Mtetra
.85346 .5035 .85527 .5059 .8597 .5046 .8579 .50219 Mtetra
.8579 .50219 .8597 .5046 .86414 .5033 .86235 .50088 Mtetra
.86235 .50088 .86414 .5033 .86859 .50199 .8668 .49957 Mtetra
.8668 .49957 .86859 .50199 .87304 .50068 .87126 .49826 Mtetra
.87126 .49826 .87304 .50068 .87751 .49937 .87573 .49695 Mtetra
.87573 .49695 .87751 .49937 .88197 .49806 .8802 .49563 Mtetra
.8802 .49563 .88197 .49806 .88645 .49675 .88468 .49432 Mtetra
.88468 .49432 .88645 .49675 .89093 .49543 .88917 .493 Mtetra
.88917 .493 .89093 .49543 .89542 .49411 .89366 .49167 Mtetra
.89366 .49167 .89542 .49411 .89992 .49279 .89816 .49035 Mtetra
.89816 .49035 .89992 .49279 .90442 .49147 .90267 .48902 Mtetra
.90267 .48902 .90442 .49147 .90893 .49015 .90718 .4877 Mtetra
.90718 .4877 .90893 .49015 .91344 .48882 .91171 .48637 Mtetra
.91171 .48637 .91344 .48882 .91797 .48749 .91623 .48504 Mtetra
.91623 .48504 .91797 .48749 .9225 .48616 .92077 .4837 Mtetra
.92077 .4837 .9225 .48616 .92703 .48483 .92531 .48237 Mtetra
.652 .755 .925 r
.31144 .6652 .31377 .66718 .31743 .66611 .3151 .66412 Mtetra
.3151 .66412 .31743 .66611 .3211 .66504 .31877 .66305 Mtetra
.31877 .66305 .3211 .66504 .32477 .66396 .32245 .66197 Mtetra
.32245 .66197 .32477 .66396 .32845 .66288 .32613 .66089 Mtetra
.32613 .66089 .32845 .66288 .33213 .6618 .32981 .65981 Mtetra
.32981 .65981 .33213 .6618 .33581 .66072 .3335 .65872 Mtetra
.3335 .65872 .33581 .66072 .3395 .65964 .33719 .65764 Mtetra
.33719 .65764 .3395 .65964 .3432 .65856 .34089 .65655 Mtetra
.34089 .65655 .3432 .65856 .3469 .65747 .3446 .65546 Mtetra
.3446 .65546 .3469 .65747 .35061 .65638 .34831 .65437 Mtetra
.34831 .65437 .35061 .65638 .35432 .6553 .35202 .65328 Mtetra
.35202 .65328 .35432 .6553 .35804 .65421 .35574 .65219 Mtetra
.35574 .65219 .35804 .65421 .36176 .65312 .35946 .6511 Mtetra
.946 .639 .422 r
.35946 .6511 .36176 .65312 .36548 .65202 .362 .6756 Mtetra
.535 .288 .488 r
.362 .6756 .36548 .65202 .36807 .67652 .36577 .67452 Mtetra
.65 .758 .928 r
.36577 .67452 .36807 .67652 .37183 .67544 .36953 .67343 Mtetra
.36953 .67343 .37183 .67544 .3756 .67435 .37331 .67234 Mtetra
.37331 .67234 .3756 .67435 .37938 .67326 .37708 .67125 Mtetra
.37708 .67125 .37938 .67326 .38316 .67217 .38087 .67015 Mtetra
.38087 .67015 .38316 .67217 .38694 .67108 .38466 .66906 Mtetra
.38466 .66906 .38694 .67108 .39074 .66998 .38845 .66796 Mtetra
.38845 .66796 .39074 .66998 .39453 .66889 .39225 .66686 Mtetra
.39225 .66686 .39453 .66889 .39833 .66779 .39606 .66576 Mtetra
.39606 .66576 .39833 .66779 .40214 .66669 .39987 .66466 Mtetra
.39987 .66466 .40214 .66669 .40595 .66559 .40368 .66356 Mtetra
.40368 .66356 .40595 .66559 .40977 .66449 .4075 .66246 Mtetra
.4075 .66246 .40977 .66449 .41359 .66339 .41133 .66135 Mtetra
.41133 .66135 .41359 .66339 .41742 .66229 .41516 .66024 Mtetra
.947 .693 .521 r
.41516 .66024 .41742 .66229 .42583 .50754 .42368 .50539 Mtetra
.663 .743 .91 r
.42368 .50539 .42583 .50754 .4295 .50638 .42735 .50422 Mtetra
.42735 .50422 .4295 .50638 .43318 .50521 .43103 .50306 Mtetra
.43103 .50306 .43318 .50521 .43686 .50404 .43472 .50189 Mtetra
.43472 .50189 .43686 .50404 .44055 .50288 .43841 .50072 Mtetra
.43841 .50072 .44055 .50288 .44424 .50171 .44211 .49954 Mtetra
.44211 .49954 .44424 .50171 .44794 .50054 .44581 .49837 Mtetra
.44581 .49837 .44794 .50054 .45165 .49936 .44952 .49719 Mtetra
.44952 .49719 .45165 .49936 .45535 .49819 .45323 .49602 Mtetra
.45323 .49602 .45535 .49819 .45907 .49701 .45694 .49484 Mtetra
.45694 .49484 .45907 .49701 .46279 .49583 .46067 .49366 Mtetra
.46067 .49366 .46279 .49583 .46651 .49466 .46439 .49247 Mtetra
.46439 .49247 .46651 .49466 .47024 .49348 .46813 .49129 Mtetra
.46813 .49129 .47024 .49348 .47397 .49229 .47186 .49011 Mtetra
.47186 .49011 .47397 .49229 .47771 .49111 .4756 .48892 Mtetra
.4756 .48892 .47771 .49111 .48127 .50427 .47935 .48773 Mtetra
.099 .07 .534 r
.47935 .48773 .48127 .50427 .48503 .50309 .48292 .5009 Mtetra
.662 .744 .911 r
.48292 .5009 .48503 .50309 .4888 .5019 .4867 .49971 Mtetra
.4867 .49971 .4888 .5019 .49258 .50072 .49048 .49852 Mtetra
.49048 .49852 .49258 .50072 .49636 .49953 .49426 .49733 Mtetra
.49426 .49733 .49636 .49953 .50015 .49834 .49805 .49614 Mtetra
.49805 .49614 .50015 .49834 .50394 .49715 .50185 .49495 Mtetra
.50185 .49495 .50394 .49715 .50774 .49596 .50565 .49375 Mtetra
.50565 .49375 .50774 .49596 .51154 .49476 .50945 .49255 Mtetra
.50945 .49255 .51154 .49476 .51535 .49357 .51326 .49135 Mtetra
.51326 .49135 .51535 .49357 .51916 .49237 .51708 .49015 Mtetra
.51708 .49015 .51916 .49237 .52298 .49117 .5209 .48895 Mtetra
.5209 .48895 .52298 .49117 .5268 .48997 .52473 .48775 Mtetra
.52473 .48775 .5268 .48997 .53063 .48877 .52856 .48654 Mtetra
.52856 .48654 .53063 .48877 .53446 .48756 .5324 .48534 Mtetra
.5324 .48534 .53446 .48756 .5383 .48636 .53624 .48413 Mtetra
.53624 .48413 .5383 .48636 .54215 .48515 .54009 .48292 Mtetra
.54009 .48292 .54215 .48515 .546 .48394 .54394 .4817 Mtetra
.952 .721 .553 r
.54394 .4817 .546 .48394 .54963 .45399 .5476 .45174 Mtetra
.664 .741 .908 r
.5476 .45174 .54963 .45399 .55346 .45277 .55143 .45051 Mtetra
.55143 .45051 .55346 .45277 .55729 .45155 .55527 .44929 Mtetra
.55527 .44929 .55729 .45155 .56113 .45032 .55911 .44806 Mtetra
.55911 .44806 .56113 .45032 .56497 .4491 .56295 .44683 Mtetra
.56295 .44683 .56497 .4491 .56882 .44787 .56681 .4456 Mtetra
.56681 .4456 .56882 .44787 .57268 .44664 .57066 .44436 Mtetra
.57066 .44436 .57268 .44664 .57654 .44541 .57453 .44313 Mtetra
.57453 .44313 .57654 .44541 .5804 .44417 .57839 .44189 Mtetra
.57839 .44189 .5804 .44417 .58427 .44294 .58227 .44065 Mtetra
.58227 .44065 .58427 .44294 .58814 .4417 .58615 .43941 Mtetra
.58615 .43941 .58814 .4417 .59203 .44046 .59003 .43817 Mtetra
.59003 .43817 .59203 .44046 .59591 .43922 .59392 .43693 Mtetra
.59392 .43693 .59591 .43922 .5998 .43798 .59782 .43568 Mtetra
.59782 .43568 .5998 .43798 .6037 .43673 .60172 .43443 Mtetra
.60172 .43443 .6037 .43673 .6076 .43549 .60562 .43318 Mtetra
.60562 .43318 .6076 .43549 .61151 .43424 .60953 .43193 Mtetra
.60953 .43193 .61151 .43424 .61542 .43299 .61345 .43068 Mtetra
.61345 .43068 .61542 .43299 .61934 .43174 .61737 .42943 Mtetra
.61737 .42943 .61934 .43174 .62327 .43049 .6213 .42817 Mtetra
.964 .643 .35 r
.6213 .42817 .62327 .43049 .62841 .46791 .62643 .46561 Mtetra
.661 .745 .912 r
.62643 .46561 .62841 .46791 .6324 .46667 .63042 .46437 Mtetra
.63042 .46437 .6324 .46667 .63638 .46542 .63441 .46312 Mtetra
.63441 .46312 .63638 .46542 .64038 .46417 .63841 .46187 Mtetra
.63841 .46187 .64038 .46417 .64438 .46293 .64241 .46061 Mtetra
.64241 .46061 .64438 .46293 .64838 .46167 .64642 .45936 Mtetra
.64642 .45936 .64838 .46167 .6524 .46042 .65044 .4581 Mtetra
.65044 .4581 .6524 .46042 .65641 .45917 .65446 .45685 Mtetra
.65446 .45685 .65641 .45917 .66044 .45791 .65848 .45559 Mtetra
.968 .718 .505 r
.65848 .45559 .66044 .45791 .66446 .45665 .66089 .41551 Mtetra
.573 .38 .581 r
.66089 .41551 .66446 .45665 .6668 .41659 .66488 .41424 Mtetra
.664 .741 .908 r
.66488 .41424 .6668 .41659 .67079 .41532 .66887 .41296 Mtetra
.66887 .41296 .67079 .41532 .67479 .41404 .67287 .41168 Mtetra
.67287 .41168 .67479 .41404 .67879 .41276 .67688 .4104 Mtetra
.67688 .4104 .67879 .41276 .6828 .41148 .68089 .40912 Mtetra
.68089 .40912 .6828 .41148 .68681 .4102 .68491 .40783 Mtetra
.68491 .40783 .68681 .4102 .69083 .40892 .68893 .40654 Mtetra
.68893 .40654 .69083 .40892 .69486 .40763 .69296 .40526 Mtetra
.69296 .40526 .69486 .40763 .69889 .40635 .69699 .40396 Mtetra
.69699 .40396 .69889 .40635 .70292 .40506 .70104 .40267 Mtetra
.70104 .40267 .70292 .40506 .70697 .40377 .70508 .40138 Mtetra
.70508 .40138 .70697 .40377 .71101 .40247 .70913 .40008 Mtetra
.70913 .40008 .71101 .40247 .71708 .43521 .71319 .39879 Mtetra
.128 .064 .51 r
.71319 .39879 .71708 .43521 .72118 .43393 .71929 .43155 Mtetra
.661 .745 .912 r
.71929 .43155 .72118 .43393 .72529 .43264 .7234 .43026 Mtetra
.7234 .43026 .72529 .43264 .72941 .43135 .72753 .42897 Mtetra
.72753 .42897 .72941 .43135 .73353 .43006 .73165 .42767 Mtetra
.73165 .42767 .73353 .43006 .73766 .42877 .73578 .42638 Mtetra
.73578 .42638 .73766 .42877 .74179 .42747 .73992 .42508 Mtetra
.73992 .42508 .74179 .42747 .74593 .42618 .74407 .42378 Mtetra
.74407 .42378 .74593 .42618 .75008 .42488 .74822 .42248 Mtetra
.74822 .42248 .75008 .42488 .75423 .42358 .75237 .42117 Mtetra
.75237 .42117 .75423 .42358 .75838 .42228 .75653 .41987 Mtetra
.75653 .41987 .75838 .42228 .76255 .42097 .7607 .41856 Mtetra
.7607 .41856 .76255 .42097 .76672 .41967 .76488 .41725 Mtetra
.969 .65 .324 r
.76488 .41725 .76672 .41967 .77664 .4941 .77477 .49172 Mtetra
.655 .752 .921 r
.77477 .49172 .77664 .4941 .78093 .49281 .77906 .49044 Mtetra
.77906 .49044 .78093 .49281 .78522 .49153 .78335 .48915 Mtetra
.78335 .48915 .78522 .49153 .78952 .49024 .78766 .48786 Mtetra
.78766 .48786 .78952 .49024 .79382 .48895 .79196 .48656 Mtetra
.79196 .48656 .79382 .48895 .79813 .48766 .79628 .48527 Mtetra
.79628 .48527 .79813 .48766 .80244 .48636 .8006 .48397 Mtetra
.8006 .48397 .80244 .48636 .80677 .48507 .80493 .48267 Mtetra
.80493 .48267 .80677 .48507 .8111 .48377 .80926 .48137 Mtetra
.80926 .48137 .8111 .48377 .81543 .48247 .8136 .48007 Mtetra
.8136 .48007 .81543 .48247 .81977 .48117 .81795 .47876 Mtetra
.81795 .47876 .81977 .48117 .82412 .47987 .8223 .47746 Mtetra
.8223 .47746 .82412 .47987 .82848 .47856 .82666 .47615 Mtetra
.82666 .47615 .82848 .47856 .83284 .47726 .83103 .47484 Mtetra
.83103 .47484 .83284 .47726 .83721 .47595 .8354 .47352 Mtetra
.8354 .47352 .83721 .47595 .84158 .47464 .83978 .47221 Mtetra
.938 .579 .178 r
.83978 .47221 .84158 .47464 .84903 .5048 .84722 .50239 Mtetra
.653 .755 .925 r
.84722 .50239 .84903 .5048 .85346 .5035 .85166 .50108 Mtetra
.85166 .50108 .85346 .5035 .8579 .50219 .8561 .49978 Mtetra
.8561 .49978 .8579 .50219 .86235 .50088 .86055 .49846 Mtetra
.86055 .49846 .86235 .50088 .8668 .49957 .86501 .49715 Mtetra
.86501 .49715 .8668 .49957 .87126 .49826 .86947 .49584 Mtetra
.86947 .49584 .87126 .49826 .87573 .49695 .87394 .49452 Mtetra
.87394 .49452 .87573 .49695 .8802 .49563 .87842 .4932 Mtetra
.87842 .4932 .8802 .49563 .88468 .49432 .88291 .49188 Mtetra
.88291 .49188 .88468 .49432 .88917 .493 .8874 .49055 Mtetra
.8874 .49055 .88917 .493 .89366 .49167 .8919 .48923 Mtetra
.8919 .48923 .89366 .49167 .89816 .49035 .8964 .4879 Mtetra
.8964 .4879 .89816 .49035 .90267 .48902 .90092 .48657 Mtetra
.90092 .48657 .90267 .48902 .90718 .4877 .90544 .48524 Mtetra
.90544 .48524 .90718 .4877 .91171 .48637 .90996 .48391 Mtetra
.90996 .48391 .91171 .48637 .91623 .48504 .9145 .48257 Mtetra
.9145 .48257 .91623 .48504 .92077 .4837 .91904 .48123 Mtetra
.91904 .48123 .92077 .4837 .92531 .48237 .92358 .47989 Mtetra
.652 .755 .925 r
.3091 .66321 .31144 .6652 .3151 .66412 .31277 .66213 Mtetra
.31277 .66213 .3151 .66412 .31877 .66305 .31644 .66105 Mtetra
.31644 .66105 .31877 .66305 .32245 .66197 .32012 .65997 Mtetra
.32012 .65997 .32245 .66197 .32613 .66089 .3238 .65889 Mtetra
.3238 .65889 .32613 .66089 .32981 .65981 .32749 .65781 Mtetra
.32749 .65781 .32981 .65981 .3335 .65872 .33118 .65672 Mtetra
.33118 .65672 .3335 .65872 .33719 .65764 .33487 .65563 Mtetra
.33487 .65563 .33719 .65764 .34089 .65655 .33858 .65454 Mtetra
.33858 .65454 .34089 .65655 .3446 .65546 .34228 .65345 Mtetra
.34228 .65345 .3446 .65546 .34831 .65437 .346 .65236 Mtetra
.346 .65236 .34831 .65437 .35202 .65328 .34972 .65127 Mtetra
.946 .639 .425 r
.34972 .65127 .35202 .65328 .35574 .65219 .35217 .67577 Mtetra
.534 .287 .488 r
.35217 .67577 .35574 .65219 .35946 .6511 .35593 .67468 Mtetra
.35593 .67468 .35946 .6511 .362 .6756 .35969 .67359 Mtetra
.65 .758 .928 r
.35969 .67359 .362 .6756 .36577 .67452 .36346 .6725 Mtetra
.36346 .6725 .36577 .67452 .36953 .67343 .36723 .67141 Mtetra
.36723 .67141 .36953 .67343 .37331 .67234 .371 .67032 Mtetra
.371 .67032 .37331 .67234 .37708 .67125 .37478 .66923 Mtetra
.37478 .66923 .37708 .67125 .38087 .67015 .37857 .66813 Mtetra
.37857 .66813 .38087 .67015 .38466 .66906 .38236 .66703 Mtetra
.38236 .66703 .38466 .66906 .38845 .66796 .38616 .66593 Mtetra
.38616 .66593 .38845 .66796 .39225 .66686 .38996 .66483 Mtetra
.38996 .66483 .39225 .66686 .39606 .66576 .39377 .66373 Mtetra
.39377 .66373 .39606 .66576 .39987 .66466 .39759 .66263 Mtetra
.39759 .66263 .39987 .66466 .40368 .66356 .4014 .66152 Mtetra
.4014 .66152 .40368 .66356 .4075 .66246 .40523 .66041 Mtetra
.40523 .66041 .4075 .66246 .41133 .66135 .40906 .6593 Mtetra
.40906 .6593 .41133 .66135 .41516 .66024 .4129 .65819 Mtetra
.947 .693 .521 r
.4129 .65819 .41516 .66024 .42368 .50539 .42152 .50324 Mtetra
.663 .743 .91 r
.42152 .50324 .42368 .50539 .42735 .50422 .4252 .50207 Mtetra
.4252 .50207 .42735 .50422 .43103 .50306 .42888 .5009 Mtetra
.42888 .5009 .43103 .50306 .43472 .50189 .43257 .49972 Mtetra
.43257 .49972 .43472 .50189 .43841 .50072 .43627 .49855 Mtetra
.43627 .49855 .43841 .50072 .44211 .49954 .43997 .49737 Mtetra
.43997 .49737 .44211 .49954 .44581 .49837 .44367 .4962 Mtetra
.44367 .4962 .44581 .49837 .44952 .49719 .44738 .49502 Mtetra
.44738 .49502 .44952 .49719 .45323 .49602 .4511 .49384 Mtetra
.4511 .49384 .45323 .49602 .45694 .49484 .45482 .49266 Mtetra
.45482 .49266 .45694 .49484 .46067 .49366 .45854 .49147 Mtetra
.45854 .49147 .46067 .49366 .46439 .49247 .46227 .49029 Mtetra
.46227 .49029 .46439 .49247 .46813 .49129 .46601 .4891 Mtetra
.46601 .4891 .46813 .49129 .47186 .49011 .46975 .48791 Mtetra
.46975 .48791 .47186 .49011 .4756 .48892 .47349 .48672 Mtetra
.47349 .48672 .4756 .48892 .47935 .48773 .47724 .48553 Mtetra
.47724 .48553 .47935 .48773 .48292 .5009 .481 .48434 Mtetra
.099 .07 .534 r
.481 .48434 .48292 .5009 .4867 .49971 .48459 .49752 Mtetra
.662 .744 .911 r
.48459 .49752 .4867 .49971 .49048 .49852 .48837 .49632 Mtetra
.48837 .49632 .49048 .49852 .49426 .49733 .49216 .49513 Mtetra
.49216 .49513 .49426 .49733 .49805 .49614 .49595 .49393 Mtetra
.49595 .49393 .49805 .49614 .50185 .49495 .49975 .49274 Mtetra
.49975 .49274 .50185 .49495 .50565 .49375 .50355 .49154 Mtetra
.50355 .49154 .50565 .49375 .50945 .49255 .50736 .49034 Mtetra
.50736 .49034 .50945 .49255 .51326 .49135 .51118 .48914 Mtetra
.51118 .48914 .51326 .49135 .51708 .49015 .51499 .48793 Mtetra
.51499 .48793 .51708 .49015 .5209 .48895 .51882 .48673 Mtetra
.51882 .48673 .5209 .48895 .52473 .48775 .52265 .48552 Mtetra
.52265 .48552 .52473 .48775 .52856 .48654 .52649 .48431 Mtetra
.52649 .48431 .52856 .48654 .5324 .48534 .53033 .4831 Mtetra
.53033 .4831 .5324 .48534 .53624 .48413 .53417 .48189 Mtetra
.53417 .48189 .53624 .48413 .54009 .48292 .53802 .48068 Mtetra
.951 .721 .554 r
.53802 .48068 .54009 .48292 .54394 .4817 .54173 .4507 Mtetra
.577 .389 .59 r
.54173 .4507 .54394 .4817 .5476 .45174 .54556 .44948 Mtetra
.664 .741 .908 r
.54556 .44948 .5476 .45174 .55143 .45051 .5494 .44825 Mtetra
.5494 .44825 .55143 .45051 .55527 .44929 .55324 .44702 Mtetra
.55324 .44702 .55527 .44929 .55911 .44806 .55708 .44579 Mtetra
.55708 .44579 .55911 .44806 .56295 .44683 .56093 .44455 Mtetra
.56093 .44455 .56295 .44683 .56681 .4456 .56479 .44332 Mtetra
.56479 .44332 .56681 .4456 .57066 .44436 .56865 .44208 Mtetra
.56865 .44208 .57066 .44436 .57453 .44313 .57251 .44084 Mtetra
.57251 .44084 .57453 .44313 .57839 .44189 .57638 .4396 Mtetra
.57638 .4396 .57839 .44189 .58227 .44065 .58026 .43836 Mtetra
.58026 .43836 .58227 .44065 .58615 .43941 .58414 .43712 Mtetra
.58414 .43712 .58615 .43941 .59003 .43817 .58803 .43587 Mtetra
.58803 .43587 .59003 .43817 .59392 .43693 .59192 .43462 Mtetra
.59192 .43462 .59392 .43693 .59782 .43568 .59582 .43338 Mtetra
.59582 .43338 .59782 .43568 .60172 .43443 .59973 .43213 Mtetra
.59973 .43213 .60172 .43443 .60562 .43318 .60364 .43087 Mtetra
.60364 .43087 .60562 .43318 .60953 .43193 .60755 .42962 Mtetra
.60755 .42962 .60953 .43193 .61345 .43068 .61147 .42836 Mtetra
.61147 .42836 .61345 .43068 .61737 .42943 .6154 .42711 Mtetra
.6154 .42711 .61737 .42943 .6213 .42817 .61933 .42585 Mtetra
.61933 .42585 .6213 .42817 .62643 .46561 .62327 .42459 Mtetra
.074 .015 .479 r
.62327 .42459 .62643 .46561 .63042 .46437 .62843 .46206 Mtetra
.661 .745 .912 r
.62843 .46206 .63042 .46437 .63441 .46312 .63243 .46081 Mtetra
.63243 .46081 .63441 .46312 .63841 .46187 .63643 .45955 Mtetra
.63643 .45955 .63841 .46187 .64241 .46061 .64044 .4583 Mtetra
.64044 .4583 .64241 .46061 .64642 .45936 .64445 .45704 Mtetra
.64445 .45704 .64642 .45936 .65044 .4581 .64847 .45578 Mtetra
.64847 .45578 .65044 .4581 .65446 .45685 .6525 .45452 Mtetra
.967 .718 .506 r
.6525 .45452 .65446 .45685 .65848 .45559 .65497 .41443 Mtetra
.573 .379 .58 r
.65497 .41443 .65848 .45559 .66089 .41551 .65895 .41316 Mtetra
.664 .741 .908 r
.65895 .41316 .66089 .41551 .66488 .41424 .66295 .41188 Mtetra
.66295 .41188 .66488 .41424 .66887 .41296 .66695 .4106 Mtetra
.66695 .4106 .66887 .41296 .67287 .41168 .67095 .40931 Mtetra
.67095 .40931 .67287 .41168 .67688 .4104 .67496 .40803 Mtetra
.67496 .40803 .67688 .4104 .68089 .40912 .67898 .40674 Mtetra
.67898 .40674 .68089 .40912 .68491 .40783 .683 .40545 Mtetra
.683 .40545 .68491 .40783 .68893 .40654 .68703 .40416 Mtetra
.68703 .40416 .68893 .40654 .69296 .40526 .69106 .40287 Mtetra
.69106 .40287 .69296 .40526 .69699 .40396 .6951 .40158 Mtetra
.6951 .40158 .69699 .40396 .70104 .40267 .69914 .40028 Mtetra
.69914 .40028 .70104 .40267 .70508 .40138 .70319 .39899 Mtetra
.70319 .39899 .70508 .40138 .70913 .40008 .70725 .39769 Mtetra
.70725 .39769 .70913 .40008 .71319 .39879 .71131 .39638 Mtetra
.959 .62 .279 r
.71131 .39638 .71319 .39879 .71929 .43155 .7174 .42917 Mtetra
.661 .745 .912 r
.7174 .42917 .71929 .43155 .7234 .43026 .72151 .42787 Mtetra
.72151 .42787 .7234 .43026 .72753 .42897 .72564 .42658 Mtetra
.72564 .42658 .72753 .42897 .73165 .42767 .72977 .42528 Mtetra
.72977 .42528 .73165 .42767 .73578 .42638 .73391 .42398 Mtetra
.73391 .42398 .73578 .42638 .73992 .42508 .73805 .42268 Mtetra
.73805 .42268 .73992 .42508 .74407 .42378 .7422 .42137 Mtetra
.7422 .42137 .74407 .42378 .74822 .42248 .74635 .42007 Mtetra
.74635 .42007 .74822 .42248 .75237 .42117 .75051 .41876 Mtetra
.75051 .41876 .75237 .42117 .75653 .41987 .75468 .41745 Mtetra
.75468 .41745 .75653 .41987 .7607 .41856 .75885 .41614 Mtetra
.75885 .41614 .7607 .41856 .76488 .41725 .76303 .41483 Mtetra
.969 .65 .324 r
.76303 .41483 .76488 .41725 .77477 .49172 .77289 .48935 Mtetra
.655 .752 .921 r
.77289 .48935 .77477 .49172 .77906 .49044 .77718 .48806 Mtetra
.77718 .48806 .77906 .49044 .78335 .48915 .78148 .48676 Mtetra
.78148 .48676 .78335 .48915 .78766 .48786 .78579 .48547 Mtetra
.78579 .48547 .78766 .48786 .79196 .48656 .7901 .48417 Mtetra
.7901 .48417 .79196 .48656 .79628 .48527 .79442 .48287 Mtetra
.79442 .48287 .79628 .48527 .8006 .48397 .79875 .48157 Mtetra
.79875 .48157 .8006 .48397 .80493 .48267 .80308 .48027 Mtetra
.80308 .48027 .80493 .48267 .80926 .48137 .80742 .47896 Mtetra
.80742 .47896 .80926 .48137 .8136 .48007 .81176 .47766 Mtetra
.81176 .47766 .8136 .48007 .81795 .47876 .81611 .47635 Mtetra
.81611 .47635 .81795 .47876 .8223 .47746 .82047 .47504 Mtetra
.82047 .47504 .8223 .47746 .82666 .47615 .82484 .47373 Mtetra
.82484 .47373 .82666 .47615 .83103 .47484 .82921 .47241 Mtetra
.82921 .47241 .83103 .47484 .8354 .47352 .83358 .4711 Mtetra
.83358 .4711 .8354 .47352 .83978 .47221 .83797 .46978 Mtetra
.938 .579 .178 r
.83797 .46978 .83978 .47221 .84722 .50239 .8454 .49998 Mtetra
.653 .755 .925 r
.8454 .49998 .84722 .50239 .85166 .50108 .84984 .49867 Mtetra
.84984 .49867 .85166 .50108 .8561 .49978 .85429 .49735 Mtetra
.85429 .49735 .8561 .49978 .86055 .49846 .85875 .49604 Mtetra
.85875 .49604 .86055 .49846 .86501 .49715 .86321 .49472 Mtetra
.86321 .49472 .86501 .49715 .86947 .49584 .86768 .4934 Mtetra
.86768 .4934 .86947 .49584 .87394 .49452 .87216 .49208 Mtetra
.87216 .49208 .87394 .49452 .87842 .4932 .87664 .49076 Mtetra
.87664 .49076 .87842 .4932 .88291 .49188 .88113 .48943 Mtetra
.88113 .48943 .88291 .49188 .8874 .49055 .88563 .48811 Mtetra
.88563 .48811 .8874 .49055 .8919 .48923 .89013 .48678 Mtetra
.89013 .48678 .8919 .48923 .8964 .4879 .89464 .48545 Mtetra
.89464 .48545 .8964 .4879 .90092 .48657 .89916 .48411 Mtetra
.89916 .48411 .90092 .48657 .90544 .48524 .90368 .48278 Mtetra
.90368 .48278 .90544 .48524 .90996 .48391 .90821 .48144 Mtetra
.90821 .48144 .90996 .48391 .9145 .48257 .91275 .4801 Mtetra
.91275 .4801 .9145 .48257 .91904 .48123 .9173 .47876 Mtetra
.9173 .47876 .91904 .48123 .92358 .47989 .92185 .47741 Mtetra
.652 .755 .925 r
.30676 .66122 .3091 .66321 .31277 .66213 .31043 .66014 Mtetra
.31043 .66014 .31277 .66213 .31644 .66105 .3141 .65906 Mtetra
.3141 .65906 .31644 .66105 .32012 .65997 .31778 .65797 Mtetra
.31778 .65797 .32012 .65997 .3238 .65889 .32147 .65689 Mtetra
.32147 .65689 .3238 .65889 .32749 .65781 .32516 .6558 Mtetra
.32516 .6558 .32749 .65781 .33118 .65672 .32885 .65471 Mtetra
.32885 .65471 .33118 .65672 .33487 .65563 .33255 .65362 Mtetra
.33255 .65362 .33487 .65563 .33858 .65454 .33626 .65253 Mtetra
.33626 .65253 .33858 .65454 .34228 .65345 .33997 .65143 Mtetra
.33997 .65143 .34228 .65345 .346 .65236 .34368 .65034 Mtetra
.945 .639 .426 r
.34368 .65034 .346 .65236 .34972 .65127 .3461 .67485 Mtetra
.533 .287 .487 r
.3461 .67485 .34972 .65127 .35217 .67577 .34985 .67376 Mtetra
.65 .758 .928 r
.34985 .67376 .35217 .67577 .35593 .67468 .35361 .67267 Mtetra
.35361 .67267 .35593 .67468 .35969 .67359 .35737 .67158 Mtetra
.35737 .67158 .35969 .67359 .36346 .6725 .36114 .67049 Mtetra
.36114 .67049 .36346 .6725 .36723 .67141 .36491 .66939 Mtetra
.36491 .66939 .36723 .67141 .371 .67032 .36869 .6683 Mtetra
.36869 .6683 .371 .67032 .37478 .66923 .37248 .6672 Mtetra
.37248 .6672 .37478 .66923 .37857 .66813 .37627 .6661 Mtetra
.37627 .6661 .37857 .66813 .38236 .66703 .38006 .665 Mtetra
.38006 .665 .38236 .66703 .38616 .66593 .38386 .6639 Mtetra
.38386 .6639 .38616 .66593 .38996 .66483 .38767 .6628 Mtetra
.38767 .6628 .38996 .66483 .39377 .66373 .39148 .66169 Mtetra
.39148 .66169 .39377 .66373 .39759 .66263 .3953 .66058 Mtetra
.3953 .66058 .39759 .66263 .4014 .66152 .39912 .65948 Mtetra
.39912 .65948 .4014 .66152 .40523 .66041 .40295 .65837 Mtetra
.40295 .65837 .40523 .66041 .40906 .6593 .40678 .65725 Mtetra
.40678 .65725 .40906 .6593 .4129 .65819 .41062 .65614 Mtetra
.947 .693 .521 r
.41062 .65614 .4129 .65819 .42152 .50324 .41936 .50108 Mtetra
.663 .743 .91 r
.41936 .50108 .42152 .50324 .4252 .50207 .42304 .4999 Mtetra
.42304 .4999 .4252 .50207 .42888 .5009 .42673 .49873 Mtetra
.42673 .49873 .42888 .5009 .43257 .49972 .43042 .49756 Mtetra
.43042 .49756 .43257 .49972 .43627 .49855 .43412 .49638 Mtetra
.43412 .49638 .43627 .49855 .43997 .49737 .43782 .4952 Mtetra
.43782 .4952 .43997 .49737 .44367 .4962 .44153 .49402 Mtetra
.44153 .49402 .44367 .4962 .44738 .49502 .44524 .49284 Mtetra
.44524 .49284 .44738 .49502 .4511 .49384 .44896 .49166 Mtetra
.44896 .49166 .4511 .49384 .45482 .49266 .45268 .49047 Mtetra
.45268 .49047 .45482 .49266 .45854 .49147 .45641 .48928 Mtetra
.45641 .48928 .45854 .49147 .46227 .49029 .46014 .4881 Mtetra
.46014 .4881 .46227 .49029 .46601 .4891 .46388 .48691 Mtetra
.46388 .48691 .46601 .4891 .46975 .48791 .46763 .48571 Mtetra
.46763 .48571 .46975 .48791 .47349 .48672 .47138 .48452 Mtetra
.47138 .48452 .47349 .48672 .47724 .48553 .47513 .48333 Mtetra
.47513 .48333 .47724 .48553 .481 .48434 .47889 .48213 Mtetra
.938 .567 .249 r
.47889 .48213 .481 .48434 .48459 .49752 .48247 .49531 Mtetra
.662 .744 .911 r
.48247 .49531 .48459 .49752 .48837 .49632 .48626 .49412 Mtetra
.48626 .49412 .48837 .49632 .49216 .49513 .49005 .49292 Mtetra
.49005 .49292 .49216 .49513 .49595 .49393 .49384 .49172 Mtetra
.49384 .49172 .49595 .49393 .49975 .49274 .49765 .49052 Mtetra
.49765 .49052 .49975 .49274 .50355 .49154 .50145 .48932 Mtetra
.50145 .48932 .50355 .49154 .50736 .49034 .50526 .48812 Mtetra
.50526 .48812 .50736 .49034 .51118 .48914 .50908 .48691 Mtetra
.50908 .48691 .51118 .48914 .51499 .48793 .51291 .48571 Mtetra
.51291 .48571 .51499 .48793 .51882 .48673 .51673 .4845 Mtetra
.51673 .4845 .51882 .48673 .52265 .48552 .52057 .48329 Mtetra
.52057 .48329 .52265 .48552 .52649 .48431 .52441 .48208 Mtetra
.52441 .48208 .52649 .48431 .53033 .4831 .52825 .48086 Mtetra
.52825 .48086 .53033 .4831 .53417 .48189 .5321 .47965 Mtetra
.5321 .47965 .53417 .48189 .53802 .48068 .53596 .47843 Mtetra
.951 .721 .554 r
.53596 .47843 .53802 .48068 .54173 .4507 .53969 .44844 Mtetra
.664 .741 .908 r
.53969 .44844 .54173 .4507 .54556 .44948 .54352 .44721 Mtetra
.54352 .44721 .54556 .44948 .5494 .44825 .54736 .44598 Mtetra
.54736 .44598 .5494 .44825 .55324 .44702 .5512 .44474 Mtetra
.5512 .44474 .55324 .44702 .55708 .44579 .55505 .44351 Mtetra
.55505 .44351 .55708 .44579 .56093 .44455 .5589 .44227 Mtetra
.5589 .44227 .56093 .44455 .56479 .44332 .56276 .44103 Mtetra
.56276 .44103 .56479 .44332 .56865 .44208 .56662 .43979 Mtetra
.56662 .43979 .56865 .44208 .57251 .44084 .57049 .43855 Mtetra
.57049 .43855 .57251 .44084 .57638 .4396 .57437 .43731 Mtetra
.57437 .43731 .57638 .4396 .58026 .43836 .57825 .43606 Mtetra
.57825 .43606 .58026 .43836 .58414 .43712 .58214 .43482 Mtetra
.58214 .43482 .58414 .43712 .58803 .43587 .58603 .43357 Mtetra
.58603 .43357 .58803 .43587 .59192 .43462 .58992 .43232 Mtetra
.58992 .43232 .59192 .43462 .59582 .43338 .59383 .43107 Mtetra
.59383 .43107 .59582 .43338 .59973 .43213 .59773 .42981 Mtetra
.59773 .42981 .59973 .43213 .60364 .43087 .60165 .42856 Mtetra
.60165 .42856 .60364 .43087 .60755 .42962 .60557 .4273 Mtetra
.60557 .4273 .60755 .42962 .61147 .42836 .60949 .42604 Mtetra
.60949 .42604 .61147 .42836 .6154 .42711 .61342 .42478 Mtetra
.61342 .42478 .6154 .42711 .61933 .42585 .61736 .42352 Mtetra
.61736 .42352 .61933 .42585 .62327 .42459 .6213 .42225 Mtetra
.6213 .42225 .62327 .42459 .62843 .46206 .62524 .42099 Mtetra
.573 .379 .58 r
.62524 .42099 .62843 .46206 .63243 .46081 .6292 .41972 Mtetra
.6292 .41972 .63243 .46081 .63643 .45955 .63315 .41845 Mtetra
.63315 .41845 .63643 .45955 .64044 .4583 .63712 .41718 Mtetra
.63712 .41718 .64044 .4583 .64445 .45704 .64109 .4159 Mtetra
.64109 .4159 .64445 .45704 .64847 .45578 .64506 .41463 Mtetra
.64506 .41463 .64847 .45578 .6525 .45452 .64904 .41335 Mtetra
.64904 .41335 .6525 .45452 .65497 .41443 .65303 .41207 Mtetra
.664 .741 .908 r
.65303 .41207 .65497 .41443 .65895 .41316 .65702 .41079 Mtetra
.65702 .41079 .65895 .41316 .66295 .41188 .66101 .40951 Mtetra
.66101 .40951 .66295 .41188 .66695 .4106 .66502 .40823 Mtetra
.66502 .40823 .66695 .4106 .67095 .40931 .66903 .40694 Mtetra
.66903 .40694 .67095 .40931 .67496 .40803 .67304 .40565 Mtetra
.67304 .40565 .67496 .40803 .67898 .40674 .67706 .40436 Mtetra
.67706 .40436 .67898 .40674 .683 .40545 .68108 .40307 Mtetra
.68108 .40307 .683 .40545 .68703 .40416 .68512 .40178 Mtetra
.68512 .40178 .68703 .40416 .69106 .40287 .68915 .40048 Mtetra
.68915 .40048 .69106 .40287 .6951 .40158 .6932 .39918 Mtetra
.6932 .39918 .6951 .40158 .69914 .40028 .69724 .39789 Mtetra
.69724 .39789 .69914 .40028 .70319 .39899 .7013 .39659 Mtetra
.7013 .39659 .70319 .39899 .70725 .39769 .70536 .39528 Mtetra
.70536 .39528 .70725 .39769 .71131 .39638 .70942 .39398 Mtetra
.959 .62 .279 r
.70942 .39398 .71131 .39638 .7174 .42917 .7155 .42678 Mtetra
.661 .745 .912 r
.7155 .42678 .7174 .42917 .72151 .42787 .71962 .42548 Mtetra
.71962 .42548 .72151 .42787 .72564 .42658 .72375 .42418 Mtetra
.72375 .42418 .72564 .42658 .72977 .42528 .72788 .42288 Mtetra
.72788 .42288 .72977 .42528 .73391 .42398 .73202 .42157 Mtetra
.73202 .42157 .73391 .42398 .73805 .42268 .73617 .42027 Mtetra
.73617 .42027 .73805 .42268 .7422 .42137 .74032 .41896 Mtetra
.74032 .41896 .7422 .42137 .74635 .42007 .74448 .41765 Mtetra
.74448 .41765 .74635 .42007 .75051 .41876 .74864 .41634 Mtetra
.74864 .41634 .75051 .41876 .75468 .41745 .75281 .41503 Mtetra
.75281 .41503 .75468 .41745 .75885 .41614 .75699 .41372 Mtetra
.75699 .41372 .75885 .41614 .76303 .41483 .76117 .4124 Mtetra
.969 .65 .324 r
.76117 .4124 .76303 .41483 .77289 .48935 .77101 .48696 Mtetra
.655 .752 .921 r
.77101 .48696 .77289 .48935 .77718 .48806 .7753 .48567 Mtetra
.7753 .48567 .77718 .48806 .78148 .48676 .77961 .48437 Mtetra
.77961 .48437 .78148 .48676 .78579 .48547 .78392 .48307 Mtetra
.78392 .48307 .78579 .48547 .7901 .48417 .78824 .48177 Mtetra
.78824 .48177 .7901 .48417 .79442 .48287 .79256 .48047 Mtetra
.79256 .48047 .79442 .48287 .79875 .48157 .79689 .47917 Mtetra
.79689 .47917 .79875 .48157 .80308 .48027 .80123 .47786 Mtetra
.80123 .47786 .80308 .48027 .80742 .47896 .80557 .47655 Mtetra
.80557 .47655 .80742 .47896 .81176 .47766 .80992 .47524 Mtetra
.80992 .47524 .81176 .47766 .81611 .47635 .81427 .47393 Mtetra
.81427 .47393 .81611 .47635 .82047 .47504 .81864 .47261 Mtetra
.81864 .47261 .82047 .47504 .82484 .47373 .82301 .4713 Mtetra
.82301 .4713 .82484 .47373 .82921 .47241 .82738 .46998 Mtetra
.82738 .46998 .82921 .47241 .83358 .4711 .83177 .46866 Mtetra
.83177 .46866 .83358 .4711 .83797 .46978 .83615 .46734 Mtetra
.938 .579 .178 r
.83615 .46734 .83797 .46978 .8454 .49998 .84358 .49756 Mtetra
.653 .755 .925 r
.84358 .49756 .8454 .49998 .84984 .49867 .84802 .49624 Mtetra
.84802 .49624 .84984 .49867 .85429 .49735 .85248 .49492 Mtetra
.85248 .49492 .85429 .49735 .85875 .49604 .85694 .49361 Mtetra
.85694 .49361 .85875 .49604 .86321 .49472 .86141 .49228 Mtetra
.86141 .49228 .86321 .49472 .86768 .4934 .86588 .49096 Mtetra
.86588 .49096 .86768 .4934 .87216 .49208 .87036 .48964 Mtetra
.87036 .48964 .87216 .49208 .87664 .49076 .87485 .48831 Mtetra
.87485 .48831 .87664 .49076 .88113 .48943 .87934 .48698 Mtetra
.87934 .48698 .88113 .48943 .88563 .48811 .88385 .48565 Mtetra
.88385 .48565 .88563 .48811 .89013 .48678 .88836 .48432 Mtetra
.88836 .48432 .89013 .48678 .89464 .48545 .89287 .48298 Mtetra
.89287 .48298 .89464 .48545 .89916 .48411 .89739 .48165 Mtetra
.89739 .48165 .89916 .48411 .90368 .48278 .90192 .48031 Mtetra
.90192 .48031 .90368 .48278 .90821 .48144 .90646 .47896 Mtetra
.90646 .47896 .90821 .48144 .91275 .4801 .911 .47762 Mtetra
.911 .47762 .91275 .4801 .9173 .47876 .91555 .47628 Mtetra
.91555 .47628 .9173 .47876 .92185 .47741 .92011 .47493 Mtetra
.652 .755 .925 r
.30441 .65922 .30676 .66122 .31043 .66014 .30808 .65814 Mtetra
.30808 .65814 .31043 .66014 .3141 .65906 .31176 .65705 Mtetra
.31176 .65705 .3141 .65906 .31778 .65797 .31544 .65597 Mtetra
.31544 .65597 .31778 .65797 .32147 .65689 .31913 .65488 Mtetra
.31913 .65488 .32147 .65689 .32516 .6558 .32282 .65379 Mtetra
.32282 .65379 .32516 .6558 .32885 .65471 .32652 .6527 Mtetra
.32652 .6527 .32885 .65471 .33255 .65362 .33022 .6516 Mtetra
.33022 .6516 .33255 .65362 .33626 .65253 .33393 .65051 Mtetra
.33393 .65051 .33626 .65253 .33997 .65143 .33764 .64941 Mtetra
.945 .639 .427 r
.33764 .64941 .33997 .65143 .34368 .65034 .34001 .67393 Mtetra
.533 .286 .486 r
.34001 .67393 .34368 .65034 .3461 .67485 .34376 .67284 Mtetra
.65 .758 .928 r
.34376 .67284 .3461 .67485 .34985 .67376 .34752 .67175 Mtetra
.34752 .67175 .34985 .67376 .35361 .67267 .35128 .67066 Mtetra
.35128 .67066 .35361 .67267 .35737 .67158 .35504 .66956 Mtetra
.35504 .66956 .35737 .67158 .36114 .67049 .35882 .66847 Mtetra
.35882 .66847 .36114 .67049 .36491 .66939 .36259 .66737 Mtetra
.36259 .66737 .36491 .66939 .36869 .6683 .36638 .66627 Mtetra
.36638 .66627 .36869 .6683 .37248 .6672 .37017 .66517 Mtetra
.37017 .66517 .37248 .6672 .37627 .6661 .37396 .66407 Mtetra
.37396 .66407 .37627 .6661 .38006 .665 .37776 .66297 Mtetra
.37776 .66297 .38006 .665 .38386 .6639 .38156 .66186 Mtetra
.38156 .66186 .38386 .6639 .38767 .6628 .38537 .66075 Mtetra
.38537 .66075 .38767 .6628 .39148 .66169 .38919 .65965 Mtetra
.38919 .65965 .39148 .66169 .3953 .66058 .39301 .65854 Mtetra
.39301 .65854 .3953 .66058 .39912 .65948 .39683 .65742 Mtetra
.39683 .65742 .39912 .65948 .40295 .65837 .40066 .65631 Mtetra
.40066 .65631 .40295 .65837 .40678 .65725 .4045 .6552 Mtetra
.4045 .6552 .40678 .65725 .41062 .65614 .40834 .65408 Mtetra
.947 .693 .521 r
.40834 .65408 .41062 .65614 .41936 .50108 .41719 .49891 Mtetra
.663 .743 .91 r
.41719 .49891 .41936 .50108 .42304 .4999 .42087 .49774 Mtetra
.42087 .49774 .42304 .4999 .42673 .49873 .42456 .49656 Mtetra
.42456 .49656 .42673 .49873 .43042 .49756 .42826 .49538 Mtetra
.42826 .49538 .43042 .49756 .43412 .49638 .43196 .4942 Mtetra
.43196 .4942 .43412 .49638 .43782 .4952 .43567 .49302 Mtetra
.43567 .49302 .43782 .4952 .44153 .49402 .43938 .49184 Mtetra
.43938 .49184 .44153 .49402 .44524 .49284 .44309 .49065 Mtetra
.44309 .49065 .44524 .49284 .44896 .49166 .44682 .48947 Mtetra
.44682 .48947 .44896 .49166 .45268 .49047 .45054 .48828 Mtetra
.45054 .48828 .45268 .49047 .45641 .48928 .45427 .48709 Mtetra
.45427 .48709 .45641 .48928 .46014 .4881 .45801 .4859 Mtetra
.45801 .4859 .46014 .4881 .46388 .48691 .46175 .48471 Mtetra
.46175 .48471 .46388 .48691 .46763 .48571 .4655 .48351 Mtetra
.4655 .48351 .46763 .48571 .47138 .48452 .46925 .48231 Mtetra
.46925 .48231 .47138 .48452 .47513 .48333 .47301 .48112 Mtetra
.47301 .48112 .47513 .48333 .47889 .48213 .47677 .47992 Mtetra
.47677 .47992 .47889 .48213 .48247 .49531 .48054 .47872 Mtetra
.097 .069 .533 r
.48054 .47872 .48247 .49531 .48626 .49412 .48414 .49191 Mtetra
.662 .744 .911 r
.48414 .49191 .48626 .49412 .49005 .49292 .48793 .49071 Mtetra
.48793 .49071 .49005 .49292 .49384 .49172 .49173 .48951 Mtetra
.49173 .48951 .49384 .49172 .49765 .49052 .49554 .4883 Mtetra
.49554 .4883 .49765 .49052 .50145 .48932 .49935 .4871 Mtetra
.49935 .4871 .50145 .48932 .50526 .48812 .50316 .48589 Mtetra
.50316 .48589 .50526 .48812 .50908 .48691 .50698 .48469 Mtetra
.50698 .48469 .50908 .48691 .51291 .48571 .51081 .48348 Mtetra
.51081 .48348 .51291 .48571 .51673 .4845 .51464 .48226 Mtetra
.51464 .48226 .51673 .4845 .52057 .48329 .51848 .48105 Mtetra
.51848 .48105 .52057 .48329 .52441 .48208 .52232 .47984 Mtetra
.52232 .47984 .52441 .48208 .52825 .48086 .52617 .47862 Mtetra
.52617 .47862 .52825 .48086 .5321 .47965 .53002 .4774 Mtetra
.951 .721 .554 r
.53002 .4774 .5321 .47965 .53596 .47843 .5338 .4474 Mtetra
.576 .388 .59 r
.5338 .4474 .53596 .47843 .53969 .44844 .53763 .44616 Mtetra
.664 .741 .908 r
.53763 .44616 .53969 .44844 .54352 .44721 .54147 .44493 Mtetra
.54147 .44493 .54352 .44721 .54736 .44598 .54531 .4437 Mtetra
.54531 .4437 .54736 .44598 .5512 .44474 .54916 .44246 Mtetra
.54916 .44246 .5512 .44474 .55505 .44351 .55301 .44122 Mtetra
.55301 .44122 .55505 .44351 .5589 .44227 .55687 .43998 Mtetra
.55687 .43998 .5589 .44227 .56276 .44103 .56073 .43874 Mtetra
.56073 .43874 .56276 .44103 .56662 .43979 .5646 .4375 Mtetra
.5646 .4375 .56662 .43979 .57049 .43855 .56847 .43626 Mtetra
.56847 .43626 .57049 .43855 .57437 .43731 .57235 .43501 Mtetra
.57235 .43501 .57437 .43731 .57825 .43606 .57623 .43376 Mtetra
.57623 .43376 .57825 .43606 .58214 .43482 .58012 .43251 Mtetra
.58012 .43251 .58214 .43482 .58603 .43357 .58402 .43126 Mtetra
.58402 .43126 .58603 .43357 .58992 .43232 .58792 .43001 Mtetra
.58792 .43001 .58992 .43232 .59383 .43107 .59182 .42875 Mtetra
.59182 .42875 .59383 .43107 .59773 .42981 .59574 .42749 Mtetra
.59574 .42749 .59773 .42981 .60165 .42856 .59965 .42623 Mtetra
.59965 .42623 .60165 .42856 .60557 .4273 .60357 .42497 Mtetra
.60357 .42497 .60557 .4273 .60949 .42604 .6075 .42371 Mtetra
.6075 .42371 .60949 .42604 .61342 .42478 .61144 .42245 Mtetra
.61144 .42245 .61342 .42478 .61736 .42352 .61538 .42118 Mtetra
.61538 .42118 .61736 .42352 .6213 .42225 .61932 .41991 Mtetra
.61932 .41991 .6213 .42225 .62524 .42099 .62327 .41864 Mtetra
.62327 .41864 .62524 .42099 .6292 .41972 .62723 .41737 Mtetra
.62723 .41737 .6292 .41972 .63315 .41845 .63119 .4161 Mtetra
.63119 .4161 .63315 .41845 .63712 .41718 .63515 .41482 Mtetra
.63515 .41482 .63712 .41718 .64109 .4159 .63913 .41355 Mtetra
.63913 .41355 .64109 .4159 .64506 .41463 .64311 .41227 Mtetra
.64311 .41227 .64506 .41463 .64904 .41335 .64709 .41099 Mtetra
.64709 .41099 .64904 .41335 .65303 .41207 .65108 .40971 Mtetra
.65108 .40971 .65303 .41207 .65702 .41079 .65507 .40842 Mtetra
.65507 .40842 .65702 .41079 .66101 .40951 .65908 .40714 Mtetra
.65908 .40714 .66101 .40951 .66502 .40823 .66308 .40585 Mtetra
.66308 .40585 .66502 .40823 .66903 .40694 .66709 .40456 Mtetra
.66709 .40456 .66903 .40694 .67304 .40565 .67111 .40327 Mtetra
.67111 .40327 .67304 .40565 .67706 .40436 .67514 .40198 Mtetra
.67514 .40198 .67706 .40436 .68108 .40307 .67917 .40068 Mtetra
.67917 .40068 .68108 .40307 .68512 .40178 .6832 .39938 Mtetra
.6832 .39938 .68512 .40178 .68915 .40048 .68724 .39809 Mtetra
.68724 .39809 .68915 .40048 .6932 .39918 .69129 .39679 Mtetra
.69129 .39679 .6932 .39918 .69724 .39789 .69534 .39548 Mtetra
.69534 .39548 .69724 .39789 .7013 .39659 .6994 .39418 Mtetra
.6994 .39418 .7013 .39659 .70536 .39528 .70346 .39287 Mtetra
.70346 .39287 .70536 .39528 .70942 .39398 .70753 .39156 Mtetra
.959 .62 .279 r
.70753 .39156 .70942 .39398 .7155 .42678 .71359 .42438 Mtetra
.661 .745 .912 r
.71359 .42438 .7155 .42678 .71962 .42548 .71772 .42308 Mtetra
.71772 .42308 .71962 .42548 .72375 .42418 .72185 .42177 Mtetra
.72185 .42177 .72375 .42418 .72788 .42288 .72599 .42047 Mtetra
.72599 .42047 .72788 .42288 .73202 .42157 .73013 .41916 Mtetra
.73013 .41916 .73202 .42157 .73617 .42027 .73429 .41785 Mtetra
.73429 .41785 .73617 .42027 .74032 .41896 .73844 .41654 Mtetra
.73844 .41654 .74032 .41896 .74448 .41765 .7426 .41523 Mtetra
.7426 .41523 .74448 .41765 .74864 .41634 .74677 .41392 Mtetra
.74677 .41392 .74864 .41634 .75281 .41503 .75095 .4126 Mtetra
.75095 .4126 .75281 .41503 .75699 .41372 .75513 .41128 Mtetra
.75513 .41128 .75699 .41372 .76117 .4124 .75932 .40996 Mtetra
.75932 .40996 .76117 .4124 .77101 .48696 .76351 .40864 Mtetra
.111 .038 .486 r
.76351 .40864 .77101 .48696 .7753 .48567 .77342 .48327 Mtetra
.655 .752 .921 r
.77342 .48327 .7753 .48567 .77961 .48437 .77773 .48197 Mtetra
.77773 .48197 .77961 .48437 .78392 .48307 .78204 .48067 Mtetra
.78204 .48067 .78392 .48307 .78824 .48177 .78636 .47937 Mtetra
.78636 .47937 .78824 .48177 .79256 .48047 .79069 .47806 Mtetra
.79069 .47806 .79256 .48047 .79689 .47917 .79503 .47675 Mtetra
.79503 .47675 .79689 .47917 .80123 .47786 .79937 .47544 Mtetra
.79937 .47544 .80123 .47786 .80557 .47655 .80372 .47413 Mtetra
.80372 .47413 .80557 .47655 .80992 .47524 .80807 .47282 Mtetra
.80807 .47282 .80992 .47524 .81427 .47393 .81243 .4715 Mtetra
.81243 .4715 .81427 .47393 .81864 .47261 .8168 .47018 Mtetra
.8168 .47018 .81864 .47261 .82301 .4713 .82117 .46886 Mtetra
.82117 .46886 .82301 .4713 .82738 .46998 .82555 .46754 Mtetra
.82555 .46754 .82738 .46998 .83177 .46866 .82994 .46622 Mtetra
.82994 .46622 .83177 .46866 .83615 .46734 .83433 .46489 Mtetra
.938 .579 .178 r
.83433 .46489 .83615 .46734 .84358 .49756 .84175 .49513 Mtetra
.653 .755 .925 r
.84175 .49513 .84358 .49756 .84802 .49624 .8462 .49381 Mtetra
.8462 .49381 .84802 .49624 .85248 .49492 .85066 .49249 Mtetra
.85066 .49249 .85248 .49492 .85694 .49361 .85513 .49117 Mtetra
.85513 .49117 .85694 .49361 .86141 .49228 .8596 .48984 Mtetra
.8596 .48984 .86141 .49228 .86588 .49096 .86408 .48851 Mtetra
.86408 .48851 .86588 .49096 .87036 .48964 .86856 .48719 Mtetra
.86856 .48719 .87036 .48964 .87485 .48831 .87306 .48586 Mtetra
.87306 .48586 .87485 .48831 .87934 .48698 .87756 .48452 Mtetra
.87756 .48452 .87934 .48698 .88385 .48565 .88206 .48319 Mtetra
.88206 .48319 .88385 .48565 .88836 .48432 .88658 .48185 Mtetra
.88658 .48185 .88836 .48432 .89287 .48298 .8911 .48051 Mtetra
.8911 .48051 .89287 .48298 .89739 .48165 .89563 .47917 Mtetra
.89563 .47917 .89739 .48165 .90192 .48031 .90016 .47783 Mtetra
.90016 .47783 .90192 .48031 .90646 .47896 .9047 .47648 Mtetra
.9047 .47648 .90646 .47896 .911 .47762 .90925 .47514 Mtetra
.90925 .47514 .911 .47762 .91555 .47628 .91381 .47379 Mtetra
.91381 .47379 .91555 .47628 .92011 .47493 .91837 .47244 Mtetra
.652 .755 .925 r
.30205 .65722 .30441 .65922 .30808 .65814 .30572 .65613 Mtetra
.30572 .65613 .30808 .65814 .31176 .65705 .30941 .65504 Mtetra
.30941 .65504 .31176 .65705 .31544 .65597 .31309 .65395 Mtetra
.31309 .65395 .31544 .65597 .31913 .65488 .31678 .65286 Mtetra
.31678 .65286 .31913 .65488 .32282 .65379 .32048 .65177 Mtetra
.32048 .65177 .32282 .65379 .32652 .6527 .32418 .65068 Mtetra
.32418 .65068 .32652 .6527 .33022 .6516 .32789 .64958 Mtetra
.32789 .64958 .33022 .6516 .33393 .65051 .3316 .64848 Mtetra
.945 .64 .429 r
.3316 .64848 .33393 .65051 .33764 .64941 .33392 .67301 Mtetra
.532 .285 .486 r
.33392 .67301 .33764 .64941 .34001 .67393 .33766 .67192 Mtetra
.65 .758 .928 r
.33766 .67192 .34001 .67393 .34376 .67284 .34142 .67083 Mtetra
.34142 .67083 .34376 .67284 .34752 .67175 .34518 .66973 Mtetra
.34518 .66973 .34752 .67175 .35128 .67066 .34894 .66864 Mtetra
.34894 .66864 .35128 .67066 .35504 .66956 .35271 .66754 Mtetra
.35271 .66754 .35504 .66956 .35882 .66847 .35649 .66644 Mtetra
.35649 .66644 .35882 .66847 .36259 .66737 .36027 .66534 Mtetra
.36027 .66534 .36259 .66737 .36638 .66627 .36406 .66424 Mtetra
.36406 .66424 .36638 .66627 .37017 .66517 .36785 .66314 Mtetra
.36785 .66314 .37017 .66517 .37396 .66407 .37164 .66203 Mtetra
.37164 .66203 .37396 .66407 .37776 .66297 .37545 .66092 Mtetra
.37545 .66092 .37776 .66297 .38156 .66186 .37925 .65982 Mtetra
.37925 .65982 .38156 .66186 .38537 .66075 .38307 .65871 Mtetra
.38307 .65871 .38537 .66075 .38919 .65965 .38688 .6576 Mtetra
.38688 .6576 .38919 .65965 .39301 .65854 .39071 .65648 Mtetra
.39071 .65648 .39301 .65854 .39683 .65742 .39454 .65537 Mtetra
.39454 .65537 .39683 .65742 .40066 .65631 .39837 .65425 Mtetra
.39837 .65425 .40066 .65631 .4045 .6552 .40221 .65314 Mtetra
.40221 .65314 .4045 .6552 .40834 .65408 .40606 .65202 Mtetra
.40606 .65202 .40834 .65408 .41719 .49891 .40991 .6509 Mtetra
0 0 .294 r
.40991 .6509 .41719 .49891 .42087 .49774 .4187 .49556 Mtetra
.663 .743 .91 r
.4187 .49556 .42087 .49774 .42456 .49656 .4224 .49438 Mtetra
.4224 .49438 .42456 .49656 .42826 .49538 .4261 .4932 Mtetra
.4261 .4932 .42826 .49538 .43196 .4942 .4298 .49202 Mtetra
.4298 .49202 .43196 .4942 .43567 .49302 .43351 .49084 Mtetra
.43351 .49084 .43567 .49302 .43938 .49184 .43722 .48965 Mtetra
.43722 .48965 .43938 .49184 .44309 .49065 .44094 .48846 Mtetra
.44094 .48846 .44309 .49065 .44682 .48947 .44467 .48727 Mtetra
.44467 .48727 .44682 .48947 .45054 .48828 .4484 .48608 Mtetra
.4484 .48608 .45054 .48828 .45427 .48709 .45213 .48489 Mtetra
.45213 .48489 .45427 .48709 .45801 .4859 .45587 .48369 Mtetra
.45587 .48369 .45801 .4859 .46175 .48471 .45962 .4825 Mtetra
.45962 .4825 .46175 .48471 .4655 .48351 .46337 .4813 Mtetra
.46337 .4813 .4655 .48351 .46925 .48231 .46712 .4801 Mtetra
.46712 .4801 .46925 .48231 .47301 .48112 .47089 .4789 Mtetra
.47089 .4789 .47301 .48112 .47677 .47992 .47465 .4777 Mtetra
.47465 .4777 .47677 .47992 .48054 .47872 .47842 .47649 Mtetra
.47842 .47649 .48054 .47872 .48414 .49191 .4822 .47529 Mtetra
.759 .546 .607 r
.4822 .47529 .48414 .49191 .48793 .49071 .48615 .4598 Mtetra
.576 .388 .589 r
.48615 .4598 .48793 .49071 .49173 .48951 .48992 .45858 Mtetra
.48992 .45858 .49173 .48951 .49554 .4883 .4937 .45737 Mtetra
.4937 .45737 .49554 .4883 .49935 .4871 .49748 .45615 Mtetra
.49748 .45615 .49935 .4871 .50316 .48589 .50126 .45493 Mtetra
.50126 .45493 .50316 .48589 .50698 .48469 .50505 .45371 Mtetra
.50505 .45371 .50698 .48469 .51081 .48348 .50885 .45249 Mtetra
.50885 .45249 .51081 .48348 .51464 .48226 .51265 .45127 Mtetra
.51265 .45127 .51464 .48226 .51848 .48105 .51646 .45004 Mtetra
.033 0 .465 r
.51646 .45004 .51848 .48105 .52232 .47984 .52023 .47759 Mtetra
.662 .744 .911 r
.52023 .47759 .52232 .47984 .52617 .47862 .52408 .47637 Mtetra
.95 .72 .555 r
.52408 .47637 .52617 .47862 .53002 .4774 .52791 .44635 Mtetra
.576 .388 .589 r
.52791 .44635 .53002 .4774 .5338 .4474 .53174 .44512 Mtetra
.664 .741 .908 r
.53174 .44512 .5338 .4474 .53763 .44616 .53558 .44389 Mtetra
.53558 .44389 .53763 .44616 .54147 .44493 .53942 .44265 Mtetra
.53942 .44265 .54147 .44493 .54531 .4437 .54326 .44141 Mtetra
.54326 .44141 .54531 .4437 .54916 .44246 .54711 .44018 Mtetra
.54711 .44018 .54916 .44246 .55301 .44122 .55097 .43893 Mtetra
.55097 .43893 .55301 .44122 .55687 .43998 .55483 .43769 Mtetra
.55483 .43769 .55687 .43998 .56073 .43874 .55869 .43645 Mtetra
.55869 .43645 .56073 .43874 .5646 .4375 .56256 .4352 Mtetra
.56256 .4352 .5646 .4375 .56847 .43626 .56644 .43395 Mtetra
.56644 .43395 .56847 .43626 .57235 .43501 .57032 .4327 Mtetra
.57032 .4327 .57235 .43501 .57623 .43376 .57421 .43145 Mtetra
.57421 .43145 .57623 .43376 .58012 .43251 .5781 .4302 Mtetra
.5781 .4302 .58012 .43251 .58402 .43126 .582 .42894 Mtetra
.582 .42894 .58402 .43126 .58792 .43001 .58591 .42769 Mtetra
.58591 .42769 .58792 .43001 .59182 .42875 .58982 .42643 Mtetra
.58982 .42643 .59182 .42875 .59574 .42749 .59373 .42517 Mtetra
.59373 .42517 .59574 .42749 .59965 .42623 .59765 .42391 Mtetra
.59765 .42391 .59965 .42623 .60357 .42497 .60158 .42264 Mtetra
.60158 .42264 .60357 .42497 .6075 .42371 .60551 .42138 Mtetra
.60551 .42138 .6075 .42371 .61144 .42245 .60945 .42011 Mtetra
.60945 .42011 .61144 .42245 .61538 .42118 .61339 .41884 Mtetra
.61339 .41884 .61538 .42118 .61932 .41991 .61734 .41757 Mtetra
.61734 .41757 .61932 .41991 .62327 .41864 .62129 .4163 Mtetra
.62129 .4163 .62327 .41864 .62723 .41737 .62525 .41502 Mtetra
.62525 .41502 .62723 .41737 .63119 .4161 .62922 .41374 Mtetra
.62922 .41374 .63119 .4161 .63515 .41482 .63319 .41247 Mtetra
.63319 .41247 .63515 .41482 .63913 .41355 .63716 .41119 Mtetra
.63716 .41119 .63913 .41355 .64311 .41227 .64115 .4099 Mtetra
.64115 .4099 .64311 .41227 .64709 .41099 .64513 .40862 Mtetra
.64513 .40862 .64709 .41099 .65108 .40971 .64913 .40734 Mtetra
.64913 .40734 .65108 .40971 .65507 .40842 .65313 .40605 Mtetra
.65313 .40605 .65507 .40842 .65908 .40714 .65713 .40476 Mtetra
.65713 .40476 .65908 .40714 .66308 .40585 .66114 .40347 Mtetra
.66114 .40347 .66308 .40585 .66709 .40456 .66516 .40218 Mtetra
.66516 .40218 .66709 .40456 .67111 .40327 .66918 .40088 Mtetra
.66918 .40088 .67111 .40327 .67514 .40198 .67321 .39958 Mtetra
.67321 .39958 .67514 .40198 .67917 .40068 .67724 .39829 Mtetra
.67724 .39829 .67917 .40068 .6832 .39938 .68128 .39699 Mtetra
.68128 .39699 .6832 .39938 .68724 .39809 .68533 .39568 Mtetra
.68533 .39568 .68724 .39809 .69129 .39679 .68938 .39438 Mtetra
.68938 .39438 .69129 .39679 .69534 .39548 .69343 .39307 Mtetra
.69343 .39307 .69534 .39548 .6994 .39418 .6975 .39177 Mtetra
.6975 .39177 .6994 .39418 .70346 .39287 .70156 .39046 Mtetra
.70156 .39046 .70346 .39287 .70753 .39156 .70564 .38915 Mtetra
.959 .62 .279 r
.70564 .38915 .70753 .39156 .71359 .42438 .71168 .42198 Mtetra
.661 .745 .912 r
.71168 .42198 .71359 .42438 .71772 .42308 .71581 .42067 Mtetra
.71581 .42067 .71772 .42308 .72185 .42177 .71995 .41936 Mtetra
.71995 .41936 .72185 .42177 .72599 .42047 .72409 .41806 Mtetra
.72409 .41806 .72599 .42047 .73013 .41916 .72824 .41675 Mtetra
.72824 .41675 .73013 .41916 .73429 .41785 .7324 .41543 Mtetra
.7324 .41543 .73429 .41785 .73844 .41654 .73656 .41412 Mtetra
.73656 .41412 .73844 .41654 .7426 .41523 .74072 .4128 Mtetra
.74072 .4128 .7426 .41523 .74677 .41392 .7449 .41149 Mtetra
.7449 .41149 .74677 .41392 .75095 .4126 .74908 .41017 Mtetra
.74908 .41017 .75095 .4126 .75513 .41128 .75326 .40885 Mtetra
.75326 .40885 .75513 .41128 .75932 .40996 .75745 .40752 Mtetra
.75745 .40752 .75932 .40996 .76351 .40864 .76165 .4062 Mtetra
.969 .65 .321 r
.76165 .4062 .76351 .40864 .77342 .48327 .77153 .48087 Mtetra
.655 .752 .921 r
.77153 .48087 .77342 .48327 .77773 .48197 .77584 .47957 Mtetra
.77584 .47957 .77773 .48197 .78204 .48067 .78016 .47826 Mtetra
.78016 .47826 .78204 .48067 .78636 .47937 .78449 .47695 Mtetra
.78449 .47695 .78636 .47937 .79069 .47806 .78882 .47564 Mtetra
.78882 .47564 .79069 .47806 .79503 .47675 .79316 .47433 Mtetra
.79316 .47433 .79503 .47675 .79937 .47544 .79751 .47302 Mtetra
.79751 .47302 .79937 .47544 .80372 .47413 .80186 .4717 Mtetra
.80186 .4717 .80372 .47413 .80807 .47282 .80622 .47039 Mtetra
.80622 .47039 .80807 .47282 .81243 .4715 .81058 .46907 Mtetra
.81058 .46907 .81243 .4715 .8168 .47018 .81495 .46775 Mtetra
.81495 .46775 .8168 .47018 .82117 .46886 .81933 .46642 Mtetra
.81933 .46642 .82117 .46886 .82555 .46754 .82372 .4651 Mtetra
.82372 .4651 .82555 .46754 .82994 .46622 .82811 .46377 Mtetra
.82811 .46377 .82994 .46622 .83433 .46489 .83251 .46244 Mtetra
.938 .579 .178 r
.83251 .46244 .83433 .46489 .84175 .49513 .83992 .49269 Mtetra
.653 .755 .925 r
.83992 .49269 .84175 .49513 .8462 .49381 .84437 .49137 Mtetra
.84437 .49137 .8462 .49381 .85066 .49249 .84884 .49004 Mtetra
.84884 .49004 .85066 .49249 .85513 .49117 .85331 .48872 Mtetra
.85331 .48872 .85513 .49117 .8596 .48984 .85778 .48739 Mtetra
.85778 .48739 .8596 .48984 .86408 .48851 .86227 .48606 Mtetra
.86227 .48606 .86408 .48851 .86856 .48719 .86676 .48473 Mtetra
.86676 .48473 .86856 .48719 .87306 .48586 .87126 .48339 Mtetra
.87126 .48339 .87306 .48586 .87756 .48452 .87576 .48206 Mtetra
.87576 .48206 .87756 .48452 .88206 .48319 .88027 .48072 Mtetra
.88027 .48072 .88206 .48319 .88658 .48185 .88479 .47938 Mtetra
.88479 .47938 .88658 .48185 .8911 .48051 .88932 .47804 Mtetra
.88932 .47804 .8911 .48051 .89563 .47917 .89385 .47669 Mtetra
.89385 .47669 .89563 .47917 .90016 .47783 .89839 .47534 Mtetra
.89839 .47534 .90016 .47783 .9047 .47648 .90294 .47399 Mtetra
.90294 .47399 .9047 .47648 .90925 .47514 .90749 .47264 Mtetra
.90749 .47264 .90925 .47514 .91381 .47379 .91205 .47129 Mtetra
.91205 .47129 .91381 .47379 .91837 .47244 .91662 .46994 Mtetra
.652 .755 .925 r
.29969 .65521 .30205 .65722 .30572 .65613 .30337 .65412 Mtetra
.30337 .65412 .30572 .65613 .30941 .65504 .30705 .65303 Mtetra
.30705 .65303 .30941 .65504 .31309 .65395 .31074 .65194 Mtetra
.31074 .65194 .31309 .65395 .31678 .65286 .31443 .65084 Mtetra
.31443 .65084 .31678 .65286 .32048 .65177 .31813 .64975 Mtetra
.31813 .64975 .32048 .65177 .32418 .65068 .32184 .64865 Mtetra
.944 .64 .431 r
.32184 .64865 .32418 .65068 .32789 .64958 .32407 .67318 Mtetra
.532 .284 .485 r
.32407 .67318 .32789 .64958 .3316 .64848 .32782 .67209 Mtetra
.32782 .67209 .3316 .64848 .33392 .67301 .33156 .67099 Mtetra
.65 .758 .928 r
.33156 .67099 .33392 .67301 .33766 .67192 .33531 .6699 Mtetra
.33531 .6699 .33766 .67192 .34142 .67083 .33907 .6688 Mtetra
.33907 .6688 .34142 .67083 .34518 .66973 .34283 .66771 Mtetra
.34283 .66771 .34518 .66973 .34894 .66864 .3466 .66661 Mtetra
.3466 .66661 .34894 .66864 .35271 .66754 .35038 .66551 Mtetra
.35038 .66551 .35271 .66754 .35649 .66644 .35415 .66441 Mtetra
.35415 .66441 .35649 .66644 .36027 .66534 .35794 .66331 Mtetra
.35794 .66331 .36027 .66534 .36406 .66424 .36173 .6622 Mtetra
.36173 .6622 .36406 .66424 .36785 .66314 .36552 .66109 Mtetra
.36552 .66109 .36785 .66314 .37164 .66203 .36932 .65999 Mtetra
.36932 .65999 .37164 .66203 .37545 .66092 .37313 .65888 Mtetra
.37313 .65888 .37545 .66092 .37925 .65982 .37694 .65777 Mtetra
.37694 .65777 .37925 .65982 .38307 .65871 .38076 .65665 Mtetra
.38076 .65665 .38307 .65871 .38688 .6576 .38458 .65554 Mtetra
.38458 .65554 .38688 .6576 .39071 .65648 .3884 .65442 Mtetra
.3884 .65442 .39071 .65648 .39454 .65537 .39224 .65331 Mtetra
.39224 .65331 .39454 .65537 .39837 .65425 .39608 .65219 Mtetra
.39608 .65219 .39837 .65425 .40221 .65314 .39992 .65107 Mtetra
.39992 .65107 .40221 .65314 .40606 .65202 .40377 .64995 Mtetra
.40377 .64995 .40606 .65202 .40991 .6509 .40762 .64882 Mtetra
.947 .693 .52 r
.40762 .64882 .40991 .6509 .4187 .49556 .41653 .49338 Mtetra
.663 .743 .91 r
.41653 .49338 .4187 .49556 .4224 .49438 .42022 .4922 Mtetra
.42022 .4922 .4224 .49438 .4261 .4932 .42393 .49102 Mtetra
.42393 .49102 .4261 .4932 .4298 .49202 .42763 .48983 Mtetra
.42763 .48983 .4298 .49202 .43351 .49084 .43135 .48864 Mtetra
.43135 .48864 .43351 .49084 .43722 .48965 .43506 .48746 Mtetra
.43506 .48746 .43722 .48965 .44094 .48846 .43879 .48626 Mtetra
.43879 .48626 .44094 .48846 .44467 .48727 .44251 .48507 Mtetra
.44251 .48507 .44467 .48727 .4484 .48608 .44625 .48388 Mtetra
.44625 .48388 .4484 .48608 .45213 .48489 .44999 .48268 Mtetra
.44999 .48268 .45213 .48489 .45587 .48369 .45373 .48149 Mtetra
.45373 .48149 .45587 .48369 .45962 .4825 .45748 .48029 Mtetra
.45748 .48029 .45962 .4825 .46337 .4813 .46123 .47909 Mtetra
.46123 .47909 .46337 .4813 .46712 .4801 .46499 .47788 Mtetra
.46499 .47788 .46712 .4801 .47089 .4789 .46875 .47668 Mtetra
.46875 .47668 .47089 .4789 .47465 .4777 .47252 .47547 Mtetra
.47252 .47547 .47465 .4777 .47842 .47649 .4763 .47427 Mtetra
.93 .737 .621 r
.4763 .47427 .47842 .47649 .4822 .47529 .48027 .45877 Mtetra
.59 .423 .624 r
.48027 .45877 .4822 .47529 .48615 .4598 .48404 .45756 Mtetra
.664 .741 .908 r
.48404 .45756 .48615 .4598 .48992 .45858 .48782 .45634 Mtetra
.48782 .45634 .48992 .45858 .4937 .45737 .49159 .45512 Mtetra
.49159 .45512 .4937 .45737 .49748 .45615 .49538 .4539 Mtetra
.49538 .4539 .49748 .45615 .50126 .45493 .49917 .45268 Mtetra
.49917 .45268 .50126 .45493 .50505 .45371 .50296 .45146 Mtetra
.50296 .45146 .50505 .45371 .50885 .45249 .50676 .45023 Mtetra
.50676 .45023 .50885 .45249 .51265 .45127 .51057 .449 Mtetra
.51057 .449 .51265 .45127 .51646 .45004 .51438 .44777 Mtetra
.51438 .44777 .51646 .45004 .52023 .47759 .5182 .44654 Mtetra
.576 .387 .589 r
.5182 .44654 .52023 .47759 .52408 .47637 .52202 .44531 Mtetra
.52202 .44531 .52408 .47637 .52791 .44635 .52584 .44408 Mtetra
.664 .741 .908 r
.52584 .44408 .52791 .44635 .53174 .44512 .52968 .44284 Mtetra
.52968 .44284 .53174 .44512 .53558 .44389 .53351 .4416 Mtetra
.53351 .4416 .53558 .44389 .53942 .44265 .53736 .44037 Mtetra
.53736 .44037 .53942 .44265 .54326 .44141 .5412 .43913 Mtetra
.5412 .43913 .54326 .44141 .54711 .44018 .54506 .43788 Mtetra
.54506 .43788 .54711 .44018 .55097 .43893 .54892 .43664 Mtetra
.54892 .43664 .55097 .43893 .55483 .43769 .55278 .43539 Mtetra
.55278 .43539 .55483 .43769 .55869 .43645 .55665 .43414 Mtetra
.55665 .43414 .55869 .43645 .56256 .4352 .56053 .4329 Mtetra
.56053 .4329 .56256 .4352 .56644 .43395 .56441 .43164 Mtetra
.56441 .43164 .56644 .43395 .57032 .4327 .56829 .43039 Mtetra
.56829 .43039 .57032 .4327 .57421 .43145 .57218 .42914 Mtetra
.57218 .42914 .57421 .43145 .5781 .4302 .57608 .42788 Mtetra
.57608 .42788 .5781 .4302 .582 .42894 .57998 .42662 Mtetra
.57998 .42662 .582 .42894 .58591 .42769 .58389 .42536 Mtetra
.58389 .42536 .58591 .42769 .58982 .42643 .5878 .4241 Mtetra
.5878 .4241 .58982 .42643 .59373 .42517 .59172 .42284 Mtetra
.59172 .42284 .59373 .42517 .59765 .42391 .59565 .42157 Mtetra
.59565 .42157 .59765 .42391 .60158 .42264 .59958 .4203 Mtetra
.59958 .4203 .60158 .42264 .60551 .42138 .60351 .41903 Mtetra
.60351 .41903 .60551 .42138 .60945 .42011 .60745 .41776 Mtetra
.60745 .41776 .60945 .42011 .61339 .41884 .6114 .41649 Mtetra
.6114 .41649 .61339 .41884 .61734 .41757 .61535 .41522 Mtetra
.61535 .41522 .61734 .41757 .62129 .4163 .61931 .41394 Mtetra
.61931 .41394 .62129 .4163 .62525 .41502 .62327 .41266 Mtetra
.62327 .41266 .62525 .41502 .62922 .41374 .62724 .41138 Mtetra
.62724 .41138 .62922 .41374 .63319 .41247 .63122 .4101 Mtetra
.63122 .4101 .63319 .41247 .63716 .41119 .6352 .40882 Mtetra
.6352 .40882 .63716 .41119 .64115 .4099 .63918 .40753 Mtetra
.63918 .40753 .64115 .4099 .64513 .40862 .64317 .40625 Mtetra
.64317 .40625 .64513 .40862 .64913 .40734 .64717 .40496 Mtetra
.64717 .40496 .64913 .40734 .65313 .40605 .65117 .40367 Mtetra
.65117 .40367 .65313 .40605 .65713 .40476 .65518 .40237 Mtetra
.65518 .40237 .65713 .40476 .66114 .40347 .6592 .40108 Mtetra
.6592 .40108 .66114 .40347 .66516 .40218 .66322 .39978 Mtetra
.66322 .39978 .66516 .40218 .66918 .40088 .66724 .39849 Mtetra
.66724 .39849 .66918 .40088 .67321 .39958 .67128 .39719 Mtetra
.67128 .39719 .67321 .39958 .67724 .39829 .67531 .39588 Mtetra
.67531 .39588 .67724 .39829 .68128 .39699 .67936 .39458 Mtetra
.67936 .39458 .68128 .39699 .68533 .39568 .6834 .39327 Mtetra
.6834 .39327 .68533 .39568 .68938 .39438 .68746 .39197 Mtetra
.68746 .39197 .68938 .39438 .69343 .39307 .69152 .39066 Mtetra
.69152 .39066 .69343 .39307 .6975 .39177 .69559 .38935 Mtetra
.69559 .38935 .6975 .39177 .70156 .39046 .69966 .38803 Mtetra
.69966 .38803 .70156 .39046 .70564 .38915 .70374 .38672 Mtetra
.70374 .38672 .70564 .38915 .71168 .42198 .70782 .3854 Mtetra
.12 .058 .506 r
.70782 .3854 .71168 .42198 .71581 .42067 .7139 .41826 Mtetra
.661 .745 .912 r
.7139 .41826 .71581 .42067 .71995 .41936 .71804 .41695 Mtetra
.71804 .41695 .71995 .41936 .72409 .41806 .72219 .41564 Mtetra
.72219 .41564 .72409 .41806 .72824 .41675 .72634 .41432 Mtetra
.72634 .41432 .72824 .41675 .7324 .41543 .7305 .41301 Mtetra
.7305 .41301 .7324 .41543 .73656 .41412 .73467 .41169 Mtetra
.73467 .41169 .73656 .41412 .74072 .4128 .73884 .41037 Mtetra
.73884 .41037 .74072 .4128 .7449 .41149 .74302 .40905 Mtetra
.74302 .40905 .7449 .41149 .74908 .41017 .7472 .40773 Mtetra
.7472 .40773 .74908 .41017 .75326 .40885 .75139 .4064 Mtetra
.75139 .4064 .75326 .40885 .75745 .40752 .75559 .40507 Mtetra
.75559 .40507 .75745 .40752 .76165 .4062 .75979 .40374 Mtetra
.969 .65 .321 r
.75979 .40374 .76165 .4062 .77153 .48087 .76963 .47846 Mtetra
.655 .752 .921 r
.76963 .47846 .77153 .48087 .77584 .47957 .77395 .47715 Mtetra
.77395 .47715 .77584 .47957 .78016 .47826 .77828 .47585 Mtetra
.77828 .47585 .78016 .47826 .78449 .47695 .78261 .47453 Mtetra
.78261 .47453 .78449 .47695 .78882 .47564 .78694 .47322 Mtetra
.78694 .47322 .78882 .47564 .79316 .47433 .79129 .47191 Mtetra
.79129 .47191 .79316 .47433 .79751 .47302 .79564 .47059 Mtetra
.79564 .47059 .79751 .47302 .80186 .4717 .79999 .46927 Mtetra
.79999 .46927 .80186 .4717 .80622 .47039 .80436 .46795 Mtetra
.80436 .46795 .80622 .47039 .81058 .46907 .80873 .46663 Mtetra
.80873 .46663 .81058 .46907 .81495 .46775 .81311 .4653 Mtetra
.81311 .4653 .81495 .46775 .81933 .46642 .81749 .46397 Mtetra
.81749 .46397 .81933 .46642 .82372 .4651 .82188 .46264 Mtetra
.82188 .46264 .82372 .4651 .82811 .46377 .82628 .46131 Mtetra
.82628 .46131 .82811 .46377 .83251 .46244 .83068 .45998 Mtetra
.938 .579 .178 r
.83068 .45998 .83251 .46244 .83992 .49269 .83808 .49025 Mtetra
.653 .755 .925 r
.83808 .49025 .83992 .49269 .84437 .49137 .84254 .48892 Mtetra
.84254 .48892 .84437 .49137 .84884 .49004 .84701 .48759 Mtetra
.84701 .48759 .84884 .49004 .85331 .48872 .85148 .48626 Mtetra
.85148 .48626 .85331 .48872 .85778 .48739 .85596 .48493 Mtetra
.85596 .48493 .85778 .48739 .86227 .48606 .86045 .4836 Mtetra
.86045 .4836 .86227 .48606 .86676 .48473 .86495 .48226 Mtetra
.86495 .48226 .86676 .48473 .87126 .48339 .86945 .48092 Mtetra
.86945 .48092 .87126 .48339 .87576 .48206 .87396 .47958 Mtetra
.87396 .47958 .87576 .48206 .88027 .48072 .87848 .47824 Mtetra
.87848 .47824 .88027 .48072 .88479 .47938 .883 .4769 Mtetra
.883 .4769 .88479 .47938 .88932 .47804 .88753 .47555 Mtetra
.88753 .47555 .88932 .47804 .89385 .47669 .89207 .4742 Mtetra
.89207 .4742 .89385 .47669 .89839 .47534 .89662 .47285 Mtetra
.89662 .47285 .89839 .47534 .90294 .47399 .90117 .4715 Mtetra
.90117 .4715 .90294 .47399 .90749 .47264 .90573 .47014 Mtetra
.90573 .47014 .90749 .47264 .91205 .47129 .91029 .46879 Mtetra
.91029 .46879 .91205 .47129 .91662 .46994 .91487 .46743 Mtetra
.652 .755 .925 r
.29732 .6532 .29969 .65521 .30337 .65412 .301 .65211 Mtetra
.301 .65211 .30337 .65412 .30705 .65303 .30469 .65101 Mtetra
.30469 .65101 .30705 .65303 .31074 .65194 .30838 .64992 Mtetra
.30838 .64992 .31074 .65194 .31443 .65084 .31208 .64882 Mtetra
.31208 .64882 .31443 .65084 .31813 .64975 .31578 .64772 Mtetra
.944 .64 .433 r
.31578 .64772 .31813 .64975 .32184 .64865 .31797 .67225 Mtetra
.531 .283 .484 r
.31797 .67225 .32184 .64865 .32407 .67318 .32171 .67116 Mtetra
.65 .758 .928 r
.32171 .67116 .32407 .67318 .32782 .67209 .32545 .67007 Mtetra
.32545 .67007 .32782 .67209 .33156 .67099 .3292 .66897 Mtetra
.3292 .66897 .33156 .67099 .33531 .6699 .33296 .66788 Mtetra
.33296 .66788 .33531 .6699 .33907 .6688 .33672 .66678 Mtetra
.33672 .66678 .33907 .6688 .34283 .66771 .34048 .66568 Mtetra
.34048 .66568 .34283 .66771 .3466 .66661 .34425 .66458 Mtetra
.34425 .66458 .3466 .66661 .35038 .66551 .34803 .66348 Mtetra
.34803 .66348 .35038 .66551 .35415 .66441 .35181 .66237 Mtetra
.35181 .66237 .35415 .66441 .35794 .66331 .3556 .66126 Mtetra
.3556 .66126 .35794 .66331 .36173 .6622 .35939 .66016 Mtetra
.35939 .66016 .36173 .6622 .36552 .66109 .36319 .65905 Mtetra
.36319 .65905 .36552 .66109 .36932 .65999 .367 .65794 Mtetra
.367 .65794 .36932 .65999 .37313 .65888 .3708 .65683 Mtetra
.3708 .65683 .37313 .65888 .37694 .65777 .37462 .65571 Mtetra
.37462 .65571 .37694 .65777 .38076 .65665 .37844 .6546 Mtetra
.37844 .6546 .38076 .65665 .38458 .65554 .38226 .65348 Mtetra
.38226 .65348 .38458 .65554 .3884 .65442 .38609 .65236 Mtetra
.38609 .65236 .3884 .65442 .39224 .65331 .38993 .65124 Mtetra
.38993 .65124 .39224 .65331 .39608 .65219 .39377 .65012 Mtetra
.39377 .65012 .39608 .65219 .39992 .65107 .39762 .649 Mtetra
.39762 .649 .39992 .65107 .40377 .64995 .40147 .64787 Mtetra
.40147 .64787 .40377 .64995 .40762 .64882 .40533 .64674 Mtetra
.947 .693 .52 r
.40533 .64674 .40762 .64882 .41653 .49338 .41435 .4912 Mtetra
.663 .743 .91 r
.41435 .4912 .41653 .49338 .42022 .4922 .41805 .49001 Mtetra
.41805 .49001 .42022 .4922 .42393 .49102 .42175 .48883 Mtetra
.42175 .48883 .42393 .49102 .42763 .48983 .42546 .48764 Mtetra
.42546 .48764 .42763 .48983 .43135 .48864 .42918 .48645 Mtetra
.42918 .48645 .43135 .48864 .43506 .48746 .4329 .48526 Mtetra
.4329 .48526 .43506 .48746 .43879 .48626 .43662 .48406 Mtetra
.43662 .48406 .43879 .48626 .44251 .48507 .44036 .48287 Mtetra
.44036 .48287 .44251 .48507 .44625 .48388 .44409 .48167 Mtetra
.44409 .48167 .44625 .48388 .44999 .48268 .44783 .48047 Mtetra
.44783 .48047 .44999 .48268 .45373 .48149 .45158 .47927 Mtetra
.45158 .47927 .45373 .48149 .45748 .48029 .45533 .47807 Mtetra
.45533 .47807 .45748 .48029 .46123 .47909 .45909 .47687 Mtetra
.45909 .47687 .46123 .47909 .46499 .47788 .46285 .47566 Mtetra
.46285 .47566 .46499 .47788 .46875 .47668 .46662 .47445 Mtetra
.46662 .47445 .46875 .47668 .47252 .47547 .47039 .47324 Mtetra
.47039 .47324 .47252 .47547 .4763 .47427 .47417 .47203 Mtetra
.93 .737 .621 r
.47417 .47203 .4763 .47427 .48027 .45877 .47816 .45653 Mtetra
.664 .741 .908 r
.47816 .45653 .48027 .45877 .48404 .45756 .48193 .45531 Mtetra
.48193 .45531 .48404 .45756 .48782 .45634 .48571 .45409 Mtetra
.48571 .45409 .48782 .45634 .49159 .45512 .48949 .45287 Mtetra
.48949 .45287 .49159 .45512 .49538 .4539 .49328 .45164 Mtetra
.49328 .45164 .49538 .4539 .49917 .45268 .49707 .45042 Mtetra
.49707 .45042 .49917 .45268 .50296 .45146 .50087 .44919 Mtetra
.50087 .44919 .50296 .45146 .50676 .45023 .50467 .44796 Mtetra
.50467 .44796 .50676 .45023 .51057 .449 .50848 .44673 Mtetra
.50848 .44673 .51057 .449 .51438 .44777 .51229 .4455 Mtetra
.51229 .4455 .51438 .44777 .5182 .44654 .51611 .44427 Mtetra
.51611 .44427 .5182 .44654 .52202 .44531 .51994 .44303 Mtetra
.51994 .44303 .52202 .44531 .52584 .44408 .52377 .4418 Mtetra
.52377 .4418 .52584 .44408 .52968 .44284 .5276 .44056 Mtetra
.5276 .44056 .52968 .44284 .53351 .4416 .53145 .43932 Mtetra
.53145 .43932 .53351 .4416 .53736 .44037 .53529 .43807 Mtetra
.53529 .43807 .53736 .44037 .5412 .43913 .53914 .43683 Mtetra
.53914 .43683 .5412 .43913 .54506 .43788 .543 .43558 Mtetra
.543 .43558 .54506 .43788 .54892 .43664 .54686 .43434 Mtetra
.54686 .43434 .54892 .43664 .55278 .43539 .55073 .43309 Mtetra
.55073 .43309 .55278 .43539 .55665 .43414 .5546 .43184 Mtetra
.5546 .43184 .55665 .43414 .56053 .4329 .55848 .43058 Mtetra
.55848 .43058 .56053 .4329 .56441 .43164 .56237 .42933 Mtetra
.56237 .42933 .56441 .43164 .56829 .43039 .56626 .42807 Mtetra
.56626 .42807 .56829 .43039 .57218 .42914 .57015 .42682 Mtetra
.57015 .42682 .57218 .42914 .57608 .42788 .57405 .42556 Mtetra
.57405 .42556 .57608 .42788 .57998 .42662 .57796 .42429 Mtetra
.57796 .42429 .57998 .42662 .58389 .42536 .58187 .42303 Mtetra
.58187 .42303 .58389 .42536 .5878 .4241 .58579 .42177 Mtetra
.58579 .42177 .5878 .4241 .59172 .42284 .58971 .4205 Mtetra
.58971 .4205 .59172 .42284 .59565 .42157 .59364 .41923 Mtetra
.59364 .41923 .59565 .42157 .59958 .4203 .59757 .41796 Mtetra
.59757 .41796 .59958 .4203 .60351 .41903 .60151 .41669 Mtetra
.60151 .41669 .60351 .41903 .60745 .41776 .60545 .41541 Mtetra
.60545 .41541 .60745 .41776 .6114 .41649 .6094 .41414 Mtetra
.6094 .41414 .6114 .41649 .61535 .41522 .61336 .41286 Mtetra
.61336 .41286 .61535 .41522 .61931 .41394 .61732 .41158 Mtetra
.61732 .41158 .61931 .41394 .62327 .41266 .62129 .4103 Mtetra
.62129 .4103 .62327 .41266 .62724 .41138 .62526 .40902 Mtetra
.62526 .40902 .62724 .41138 .63122 .4101 .62924 .40773 Mtetra
.62924 .40773 .63122 .4101 .6352 .40882 .63322 .40644 Mtetra
.63322 .40644 .6352 .40882 .63918 .40753 .63721 .40516 Mtetra
.63721 .40516 .63918 .40753 .64317 .40625 .64121 .40387 Mtetra
.64121 .40387 .64317 .40625 .64717 .40496 .64521 .40257 Mtetra
.64521 .40257 .64717 .40496 .65117 .40367 .64922 .40128 Mtetra
.64922 .40128 .65117 .40367 .65518 .40237 .65323 .39998 Mtetra
.65323 .39998 .65518 .40237 .6592 .40108 .65725 .39869 Mtetra
.65725 .39869 .6592 .40108 .66322 .39978 .66127 .39739 Mtetra
.66127 .39739 .66322 .39978 .66724 .39849 .6653 .39608 Mtetra
.6653 .39608 .66724 .39849 .67128 .39719 .66934 .39478 Mtetra
.66934 .39478 .67128 .39719 .67531 .39588 .67338 .39348 Mtetra
.67338 .39348 .67531 .39588 .67936 .39458 .67743 .39217 Mtetra
.67743 .39217 .67936 .39458 .6834 .39327 .68148 .39086 Mtetra
.68148 .39086 .6834 .39327 .68746 .39197 .68554 .38955 Mtetra
.68554 .38955 .68746 .39197 .69152 .39066 .6896 .38824 Mtetra
.6896 .38824 .69152 .39066 .69559 .38935 .69367 .38692 Mtetra
.69367 .38692 .69559 .38935 .69966 .38803 .69775 .38561 Mtetra
.69775 .38561 .69966 .38803 .70374 .38672 .70183 .38429 Mtetra
.70183 .38429 .70374 .38672 .70782 .3854 .70592 .38297 Mtetra
.959 .619 .276 r
.70592 .38297 .70782 .3854 .7139 .41826 .71199 .41584 Mtetra
.661 .745 .912 r
.71199 .41584 .7139 .41826 .71804 .41695 .71613 .41452 Mtetra
.71613 .41452 .71804 .41695 .72219 .41564 .72028 .41321 Mtetra
.72028 .41321 .72219 .41564 .72634 .41432 .72444 .41189 Mtetra
.72444 .41189 .72634 .41432 .7305 .41301 .7286 .41057 Mtetra
.7286 .41057 .7305 .41301 .73467 .41169 .73277 .40925 Mtetra
.73277 .40925 .73467 .41169 .73884 .41037 .73695 .40793 Mtetra
.73695 .40793 .73884 .41037 .74302 .40905 .74113 .4066 Mtetra
.74113 .4066 .74302 .40905 .7472 .40773 .74532 .40528 Mtetra
.74532 .40528 .7472 .40773 .75139 .4064 .74951 .40395 Mtetra
.74951 .40395 .75139 .4064 .75559 .40507 .75371 .40262 Mtetra
.75371 .40262 .75559 .40507 .75979 .40374 .75792 .40129 Mtetra
.969 .65 .321 r
.75792 .40129 .75979 .40374 .76963 .47846 .76773 .47605 Mtetra
.655 .752 .921 r
.76773 .47605 .76963 .47846 .77395 .47715 .77205 .47474 Mtetra
.77205 .47474 .77395 .47715 .77828 .47585 .77638 .47342 Mtetra
.77638 .47342 .77828 .47585 .78261 .47453 .78072 .47211 Mtetra
.78072 .47211 .78261 .47453 .78694 .47322 .78506 .47079 Mtetra
.78506 .47079 .78694 .47322 .79129 .47191 .78941 .46947 Mtetra
.78941 .46947 .79129 .47191 .79564 .47059 .79376 .46815 Mtetra
.79376 .46815 .79564 .47059 .79999 .46927 .79813 .46683 Mtetra
.79813 .46683 .79999 .46927 .80436 .46795 .80249 .4655 Mtetra
.80249 .4655 .80436 .46795 .80873 .46663 .80687 .46418 Mtetra
.80687 .46418 .80873 .46663 .81311 .4653 .81125 .46285 Mtetra
.81125 .46285 .81311 .4653 .81749 .46397 .81564 .46152 Mtetra
.81564 .46152 .81749 .46397 .82188 .46264 .82003 .46018 Mtetra
.82003 .46018 .82188 .46264 .82628 .46131 .82444 .45885 Mtetra
.82444 .45885 .82628 .46131 .83068 .45998 .82884 .45751 Mtetra
.82884 .45751 .83068 .45998 .83808 .49025 .83326 .45617 Mtetra
.17 .105 .535 r
.83326 .45617 .83808 .49025 .84254 .48892 .8407 .48647 Mtetra
.653 .755 .925 r
.8407 .48647 .84254 .48892 .84701 .48759 .84517 .48514 Mtetra
.84517 .48514 .84701 .48759 .85148 .48626 .84965 .4838 Mtetra
.84965 .4838 .85148 .48626 .85596 .48493 .85414 .48247 Mtetra
.85414 .48247 .85596 .48493 .86045 .4836 .85863 .48113 Mtetra
.85863 .48113 .86045 .4836 .86495 .48226 .86314 .47979 Mtetra
.86314 .47979 .86495 .48226 .86945 .48092 .86764 .47845 Mtetra
.86764 .47845 .86945 .48092 .87396 .47958 .87216 .4771 Mtetra
.87216 .4771 .87396 .47958 .87848 .47824 .87668 .47576 Mtetra
.87668 .47576 .87848 .47824 .883 .4769 .88121 .47441 Mtetra
.88121 .47441 .883 .4769 .88753 .47555 .88575 .47306 Mtetra
.88575 .47306 .88753 .47555 .89207 .4742 .89029 .47171 Mtetra
.89029 .47171 .89207 .4742 .89662 .47285 .89484 .47035 Mtetra
.89484 .47035 .89662 .47285 .90117 .4715 .8994 .469 Mtetra
.8994 .469 .90117 .4715 .90573 .47014 .90396 .46764 Mtetra
.90396 .46764 .90573 .47014 .91029 .46879 .90853 .46628 Mtetra
.90853 .46628 .91029 .46879 .91487 .46743 .91311 .46491 Mtetra
.652 .755 .925 r
.29494 .65118 .29732 .6532 .301 .65211 .29863 .65009 Mtetra
.29863 .65009 .301 .65211 .30469 .65101 .30232 .64899 Mtetra
.30232 .64899 .30469 .65101 .30838 .64992 .30601 .64789 Mtetra
.30601 .64789 .30838 .64992 .31208 .64882 .30971 .64679 Mtetra
.943 .64 .434 r
.30971 .64679 .31208 .64882 .31578 .64772 .31186 .67133 Mtetra
.531 .282 .484 r
.31186 .67133 .31578 .64772 .31797 .67225 .31559 .67024 Mtetra
.65 .758 .928 r
.31559 .67024 .31797 .67225 .32171 .67116 .31933 .66914 Mtetra
.31933 .66914 .32171 .67116 .32545 .67007 .32308 .66805 Mtetra
.32308 .66805 .32545 .67007 .3292 .66897 .32684 .66695 Mtetra
.32684 .66695 .3292 .66897 .33296 .66788 .33059 .66585 Mtetra
.33059 .66585 .33296 .66788 .33672 .66678 .33436 .66475 Mtetra
.33436 .66475 .33672 .66678 .34048 .66568 .33813 .66364 Mtetra
.33813 .66364 .34048 .66568 .34425 .66458 .3419 .66254 Mtetra
.3419 .66254 .34425 .66458 .34803 .66348 .34568 .66144 Mtetra
.34568 .66144 .34803 .66348 .35181 .66237 .34947 .66033 Mtetra
.34947 .66033 .35181 .66237 .3556 .66126 .35326 .65922 Mtetra
.35326 .65922 .3556 .66126 .35939 .66016 .35705 .65811 Mtetra
.35705 .65811 .35939 .66016 .36319 .65905 .36085 .657 Mtetra
.36085 .657 .36319 .65905 .367 .65794 .36466 .65588 Mtetra
.36466 .65588 .367 .65794 .3708 .65683 .36847 .65477 Mtetra
.36847 .65477 .3708 .65683 .37462 .65571 .37229 .65365 Mtetra
.37229 .65365 .37462 .65571 .37844 .6546 .37611 .65253 Mtetra
.37611 .65253 .37844 .6546 .38226 .65348 .37994 .65141 Mtetra
.37994 .65141 .38226 .65348 .38609 .65236 .38378 .65029 Mtetra
.38378 .65029 .38609 .65236 .38993 .65124 .38762 .64917 Mtetra
.38762 .64917 .38993 .65124 .39377 .65012 .39146 .64804 Mtetra
.39146 .64804 .39377 .65012 .39762 .649 .39531 .64692 Mtetra
.39531 .64692 .39762 .649 .40147 .64787 .39917 .64579 Mtetra
.39917 .64579 .40147 .64787 .40533 .64674 .40303 .64466 Mtetra
.947 .693 .52 r
.40303 .64466 .40533 .64674 .41435 .4912 .41216 .48901 Mtetra
.663 .743 .91 r
.41216 .48901 .41435 .4912 .41805 .49001 .41586 .48782 Mtetra
.41586 .48782 .41805 .49001 .42175 .48883 .41957 .48663 Mtetra
.41957 .48663 .42175 .48883 .42546 .48764 .42328 .48544 Mtetra
.42328 .48544 .42546 .48764 .42918 .48645 .427 .48425 Mtetra
.427 .48425 .42918 .48645 .4329 .48526 .43073 .48305 Mtetra
.43073 .48305 .4329 .48526 .43662 .48406 .43446 .48185 Mtetra
.43446 .48185 .43662 .48406 .44036 .48287 .43819 .48066 Mtetra
.43819 .48066 .44036 .48287 .44409 .48167 .44193 .47946 Mtetra
.44193 .47946 .44409 .48167 .44783 .48047 .44568 .47825 Mtetra
.44568 .47825 .44783 .48047 .45158 .47927 .44943 .47705 Mtetra
.44943 .47705 .45158 .47927 .45533 .47807 .45318 .47585 Mtetra
.45318 .47585 .45533 .47807 .45909 .47687 .45694 .47464 Mtetra
.45694 .47464 .45909 .47687 .46285 .47566 .46071 .47343 Mtetra
.46071 .47343 .46285 .47566 .46662 .47445 .46448 .47222 Mtetra
.46448 .47222 .46662 .47445 .47039 .47324 .46825 .47101 Mtetra
.929 .737 .622 r
.46825 .47101 .47039 .47324 .47417 .47203 .47226 .4555 Mtetra
.589 .423 .624 r
.47226 .4555 .47417 .47203 .47816 .45653 .47603 .45428 Mtetra
.664 .741 .908 r
.47603 .45428 .47816 .45653 .48193 .45531 .47981 .45306 Mtetra
.47981 .45306 .48193 .45531 .48571 .45409 .48359 .45183 Mtetra
.48359 .45183 .48571 .45409 .48949 .45287 .48738 .45061 Mtetra
.48738 .45061 .48949 .45287 .49328 .45164 .49117 .44938 Mtetra
.49117 .44938 .49328 .45164 .49707 .45042 .49496 .44815 Mtetra
.49496 .44815 .49707 .45042 .50087 .44919 .49877 .44692 Mtetra
.49877 .44692 .50087 .44919 .50467 .44796 .50257 .44569 Mtetra
.50257 .44569 .50467 .44796 .50848 .44673 .50639 .44446 Mtetra
.50639 .44446 .50848 .44673 .51229 .4455 .5102 .44322 Mtetra
.5102 .44322 .51229 .4455 .51611 .44427 .51403 .44199 Mtetra
.51403 .44199 .51611 .44427 .51994 .44303 .51785 .44075 Mtetra
.51785 .44075 .51994 .44303 .52377 .4418 .52169 .43951 Mtetra
.52169 .43951 .52377 .4418 .5276 .44056 .52553 .43827 Mtetra
.52553 .43827 .5276 .44056 .53145 .43932 .52937 .43702 Mtetra
.52937 .43702 .53145 .43932 .53529 .43807 .53322 .43578 Mtetra
.53322 .43578 .53529 .43807 .53914 .43683 .53708 .43453 Mtetra
.53708 .43453 .53914 .43683 .543 .43558 .54094 .43328 Mtetra
.54094 .43328 .543 .43558 .54686 .43434 .5448 .43203 Mtetra
.5448 .43203 .54686 .43434 .55073 .43309 .54867 .43078 Mtetra
.54867 .43078 .55073 .43309 .5546 .43184 .55255 .42952 Mtetra
.55255 .42952 .5546 .43184 .55848 .43058 .55643 .42827 Mtetra
.55643 .42827 .55848 .43058 .56237 .42933 .56032 .42701 Mtetra
.56032 .42701 .56237 .42933 .56626 .42807 .56421 .42575 Mtetra
.56421 .42575 .56626 .42807 .57015 .42682 .56811 .42449 Mtetra
.56811 .42449 .57015 .42682 .57405 .42556 .57202 .42323 Mtetra
.57202 .42323 .57405 .42556 .57796 .42429 .57593 .42196 Mtetra
.57593 .42196 .57796 .42429 .58187 .42303 .57984 .42069 Mtetra
.57984 .42069 .58187 .42303 .58579 .42177 .58376 .41943 Mtetra
.58376 .41943 .58579 .42177 .58971 .4205 .58769 .41816 Mtetra
.58769 .41816 .58971 .4205 .59364 .41923 .59162 .41688 Mtetra
.59162 .41688 .59364 .41923 .59757 .41796 .59556 .41561 Mtetra
.59556 .41561 .59757 .41796 .60151 .41669 .5995 .41433 Mtetra
.5995 .41433 .60151 .41669 .60545 .41541 .60345 .41306 Mtetra
.60345 .41306 .60545 .41541 .6094 .41414 .6074 .41178 Mtetra
.6074 .41178 .6094 .41414 .61336 .41286 .61136 .4105 Mtetra
.61136 .4105 .61336 .41286 .61732 .41158 .61533 .40921 Mtetra
.61533 .40921 .61732 .41158 .62129 .4103 .6193 .40793 Mtetra
.6193 .40793 .62129 .4103 .62526 .40902 .62328 .40664 Mtetra
.62328 .40664 .62526 .40902 .62924 .40773 .62726 .40535 Mtetra
.62726 .40535 .62924 .40773 .63322 .40644 .63125 .40406 Mtetra
.63125 .40406 .63322 .40644 .63721 .40516 .63524 .40277 Mtetra
.63524 .40277 .63721 .40516 .64121 .40387 .63924 .40148 Mtetra
.63924 .40148 .64121 .40387 .64521 .40257 .64324 .40018 Mtetra
.64324 .40018 .64521 .40257 .64922 .40128 .64725 .39889 Mtetra
.64725 .39889 .64922 .40128 .65323 .39998 .65127 .39759 Mtetra
.65127 .39759 .65323 .39998 .65725 .39869 .65529 .39628 Mtetra
.65529 .39628 .65725 .39869 .66127 .39739 .65932 .39498 Mtetra
.65932 .39498 .66127 .39739 .6653 .39608 .66335 .39368 Mtetra
.66335 .39368 .6653 .39608 .66934 .39478 .66739 .39237 Mtetra
.66739 .39237 .66934 .39478 .67338 .39348 .67144 .39106 Mtetra
.67144 .39106 .67338 .39348 .67743 .39217 .67549 .38975 Mtetra
.67549 .38975 .67743 .39217 .68148 .39086 .67955 .38844 Mtetra
.67955 .38844 .68148 .39086 .68554 .38955 .68361 .38712 Mtetra
.68361 .38712 .68554 .38955 .6896 .38824 .68768 .38581 Mtetra
.68768 .38581 .6896 .38824 .69367 .38692 .69175 .38449 Mtetra
.69175 .38449 .69367 .38692 .69775 .38561 .69583 .38317 Mtetra
.69583 .38317 .69775 .38561 .70183 .38429 .69992 .38185 Mtetra
.69992 .38185 .70183 .38429 .70592 .38297 .70401 .38052 Mtetra
.959 .619 .276 r
.70401 .38052 .70592 .38297 .71199 .41584 .71007 .41341 Mtetra
.661 .745 .912 r
.71007 .41341 .71199 .41584 .71613 .41452 .71422 .4121 Mtetra
.71422 .4121 .71613 .41452 .72028 .41321 .71837 .41078 Mtetra
.71837 .41078 .72028 .41321 .72444 .41189 .72253 .40946 Mtetra
.72253 .40946 .72444 .41189 .7286 .41057 .7267 .40813 Mtetra
.7267 .40813 .7286 .41057 .73277 .40925 .73087 .40681 Mtetra
.73087 .40681 .73277 .40925 .73695 .40793 .73505 .40548 Mtetra
.73505 .40548 .73695 .40793 .74113 .4066 .73924 .40415 Mtetra
.73924 .40415 .74113 .4066 .74532 .40528 .74343 .40282 Mtetra
.74343 .40282 .74532 .40528 .74951 .40395 .74763 .40149 Mtetra
.74763 .40149 .74951 .40395 .75371 .40262 .75183 .40016 Mtetra
.75183 .40016 .75371 .40262 .75792 .40129 .75604 .39882 Mtetra
.969 .65 .321 r
.75604 .39882 .75792 .40129 .76773 .47605 .76583 .47363 Mtetra
.655 .752 .921 r
.76583 .47363 .76773 .47605 .77205 .47474 .77015 .47231 Mtetra
.77015 .47231 .77205 .47474 .77638 .47342 .77449 .47099 Mtetra
.77449 .47099 .77638 .47342 .78072 .47211 .77883 .46968 Mtetra
.77883 .46968 .78072 .47211 .78506 .47079 .78317 .46836 Mtetra
.78317 .46836 .78506 .47079 .78941 .46947 .78753 .46703 Mtetra
.78753 .46703 .78941 .46947 .79376 .46815 .79189 .46571 Mtetra
.79189 .46571 .79376 .46815 .79813 .46683 .79625 .46438 Mtetra
.79625 .46438 .79813 .46683 .80249 .4655 .80063 .46305 Mtetra
.80063 .46305 .80249 .4655 .80687 .46418 .80501 .46172 Mtetra
.80501 .46172 .80687 .46418 .81125 .46285 .80939 .46039 Mtetra
.80939 .46039 .81125 .46285 .81564 .46152 .81378 .45906 Mtetra
.81378 .45906 .81564 .46152 .82003 .46018 .81818 .45772 Mtetra
.81818 .45772 .82003 .46018 .82444 .45885 .82259 .45638 Mtetra
.82259 .45638 .82444 .45885 .82884 .45751 .827 .45504 Mtetra
.827 .45504 .82884 .45751 .83326 .45617 .83142 .4537 Mtetra
.937 .577 .175 r
.83142 .4537 .83326 .45617 .8407 .48647 .83886 .48401 Mtetra
.653 .755 .925 r
.83886 .48401 .8407 .48647 .84517 .48514 .84333 .48267 Mtetra
.84333 .48267 .84517 .48514 .84965 .4838 .84782 .48134 Mtetra
.84782 .48134 .84965 .4838 .85414 .48247 .85231 .48 Mtetra
.85231 .48 .85414 .48247 .85863 .48113 .85681 .47866 Mtetra
.85681 .47866 .85863 .48113 .86314 .47979 .86132 .47731 Mtetra
.86132 .47731 .86314 .47979 .86764 .47845 .86583 .47597 Mtetra
.86583 .47597 .86764 .47845 .87216 .4771 .87035 .47462 Mtetra
.87035 .47462 .87216 .4771 .87668 .47576 .87488 .47327 Mtetra
.87488 .47327 .87668 .47576 .88121 .47441 .87941 .47192 Mtetra
.87941 .47192 .88121 .47441 .88575 .47306 .88395 .47056 Mtetra
.88395 .47056 .88575 .47306 .89029 .47171 .8885 .4692 Mtetra
.8885 .4692 .89029 .47171 .89484 .47035 .89306 .46785 Mtetra
.89306 .46785 .89484 .47035 .8994 .469 .89762 .46649 Mtetra
.89762 .46649 .8994 .469 .90396 .46764 .90219 .46512 Mtetra
.90219 .46512 .90396 .46764 .90853 .46628 .90676 .46376 Mtetra
.90676 .46376 .90853 .46628 .91311 .46491 .91135 .46239 Mtetra
.652 .755 .925 r
.29256 .64916 .29494 .65118 .29863 .65009 .29625 .64806 Mtetra
.29625 .64806 .29863 .65009 .30232 .64899 .29994 .64696 Mtetra
.943 .641 .437 r
.29994 .64696 .30232 .64899 .30601 .64789 .302 .6715 Mtetra
.53 .282 .483 r
.302 .6715 .30601 .64789 .30971 .64679 .30573 .6704 Mtetra
.30573 .6704 .30971 .64679 .31186 .67133 .30947 .66931 Mtetra
.65 .758 .928 r
.30947 .66931 .31186 .67133 .31559 .67024 .31321 .66821 Mtetra
.31321 .66821 .31559 .67024 .31933 .66914 .31696 .66712 Mtetra
.31696 .66712 .31933 .66914 .32308 .66805 .32071 .66602 Mtetra
.32071 .66602 .32308 .66805 .32684 .66695 .32446 .66492 Mtetra
.32446 .66492 .32684 .66695 .33059 .66585 .32822 .66381 Mtetra
.32822 .66381 .33059 .66585 .33436 .66475 .33199 .66271 Mtetra
.33199 .66271 .33436 .66475 .33813 .66364 .33576 .66161 Mtetra
.33576 .66161 .33813 .66364 .3419 .66254 .33954 .6605 Mtetra
.33954 .6605 .3419 .66254 .34568 .66144 .34333 .65939 Mtetra
.34333 .65939 .34568 .66144 .34947 .66033 .34711 .65828 Mtetra
.34711 .65828 .34947 .66033 .35326 .65922 .35091 .65717 Mtetra
.35091 .65717 .35326 .65922 .35705 .65811 .35471 .65605 Mtetra
.35471 .65605 .35705 .65811 .36085 .657 .35851 .65494 Mtetra
.35851 .65494 .36085 .657 .36466 .65588 .36232 .65382 Mtetra
.36232 .65382 .36466 .65588 .36847 .65477 .36614 .65271 Mtetra
.36614 .65271 .36847 .65477 .37229 .65365 .36996 .65159 Mtetra
.36996 .65159 .37229 .65365 .37611 .65253 .37379 .65046 Mtetra
.37379 .65046 .37611 .65253 .37994 .65141 .37762 .64934 Mtetra
.37762 .64934 .37994 .65141 .38378 .65029 .38146 .64822 Mtetra
.38146 .64822 .38378 .65029 .38762 .64917 .3853 .64709 Mtetra
.3853 .64709 .38762 .64917 .39146 .64804 .38915 .64596 Mtetra
.38915 .64596 .39146 .64804 .39531 .64692 .393 .64483 Mtetra
.393 .64483 .39531 .64692 .39917 .64579 .39686 .6437 Mtetra
.39686 .6437 .39917 .64579 .40303 .64466 .40073 .64257 Mtetra
.947 .693 .52 r
.40073 .64257 .40303 .64466 .41216 .48901 .40997 .48681 Mtetra
.663 .743 .91 r
.40997 .48681 .41216 .48901 .41586 .48782 .41367 .48562 Mtetra
.41367 .48562 .41586 .48782 .41957 .48663 .41738 .48443 Mtetra
.41738 .48443 .41957 .48663 .42328 .48544 .4211 .48323 Mtetra
.4211 .48323 .42328 .48544 .427 .48425 .42482 .48204 Mtetra
.42482 .48204 .427 .48425 .43073 .48305 .42855 .48084 Mtetra
.42855 .48084 .43073 .48305 .43446 .48185 .43228 .47964 Mtetra
.43228 .47964 .43446 .48185 .43819 .48066 .43602 .47844 Mtetra
.43602 .47844 .43819 .48066 .44193 .47946 .43976 .47724 Mtetra
.43976 .47724 .44193 .47946 .44568 .47825 .44351 .47603 Mtetra
.44351 .47603 .44568 .47825 .44943 .47705 .44727 .47482 Mtetra
.44727 .47482 .44943 .47705 .45318 .47585 .45102 .47362 Mtetra
.45102 .47362 .45318 .47585 .45694 .47464 .45479 .47241 Mtetra
.45479 .47241 .45694 .47464 .46071 .47343 .45856 .4712 Mtetra
.45856 .4712 .46071 .47343 .46448 .47222 .46233 .46998 Mtetra
.46233 .46998 .46448 .47222 .46825 .47101 .46611 .46877 Mtetra
.929 .737 .622 r
.46611 .46877 .46825 .47101 .47226 .4555 .47013 .45324 Mtetra
.664 .741 .908 r
.47013 .45324 .47226 .4555 .47603 .45428 .47391 .45202 Mtetra
.47391 .45202 .47603 .45428 .47981 .45306 .47769 .4508 Mtetra
.47769 .4508 .47981 .45306 .48359 .45183 .48147 .44957 Mtetra
.48147 .44957 .48359 .45183 .48738 .45061 .48526 .44834 Mtetra
.48526 .44834 .48738 .45061 .49117 .44938 .48905 .44711 Mtetra
.48905 .44711 .49117 .44938 .49496 .44815 .49285 .44588 Mtetra
.49285 .44588 .49496 .44815 .49877 .44692 .49666 .44465 Mtetra
.49666 .44465 .49877 .44692 .50257 .44569 .50047 .44341 Mtetra
.50047 .44341 .50257 .44569 .50639 .44446 .50429 .44218 Mtetra
.50429 .44218 .50639 .44446 .5102 .44322 .50811 .44094 Mtetra
.50811 .44094 .5102 .44322 .51403 .44199 .51193 .4397 Mtetra
.51193 .4397 .51403 .44199 .51785 .44075 .51576 .43846 Mtetra
.51576 .43846 .51785 .44075 .52169 .43951 .5196 .43721 Mtetra
.5196 .43721 .52169 .43951 .52553 .43827 .52344 .43597 Mtetra
.52344 .43597 .52553 .43827 .52937 .43702 .52729 .43472 Mtetra
.52729 .43472 .52937 .43702 .53322 .43578 .53115 .43347 Mtetra
.53115 .43347 .53322 .43578 .53708 .43453 .535 .43222 Mtetra
.535 .43222 .53708 .43453 .54094 .43328 .53887 .43097 Mtetra
.53887 .43097 .54094 .43328 .5448 .43203 .54274 .42972 Mtetra
.54274 .42972 .5448 .43203 .54867 .43078 .54661 .42846 Mtetra
.54661 .42846 .54867 .43078 .55255 .42952 .55049 .4272 Mtetra
.55049 .4272 .55255 .42952 .55643 .42827 .55438 .42594 Mtetra
.55438 .42594 .55643 .42827 .56032 .42701 .55827 .42468 Mtetra
.55827 .42468 .56032 .42701 .56421 .42575 .56217 .42342 Mtetra
.56217 .42342 .56421 .42575 .56811 .42449 .56607 .42216 Mtetra
.56607 .42216 .56811 .42449 .57202 .42323 .56998 .42089 Mtetra
.56998 .42089 .57202 .42323 .57593 .42196 .57389 .41962 Mtetra
.57389 .41962 .57593 .42196 .57984 .42069 .57781 .41835 Mtetra
.57781 .41835 .57984 .42069 .58376 .41943 .58173 .41708 Mtetra
.58173 .41708 .58376 .41943 .58769 .41816 .58566 .41581 Mtetra
.58566 .41581 .58769 .41816 .59162 .41688 .5896 .41453 Mtetra
.5896 .41453 .59162 .41688 .59556 .41561 .59354 .41325 Mtetra
.59354 .41325 .59556 .41561 .5995 .41433 .59749 .41197 Mtetra
.59749 .41197 .5995 .41433 .60345 .41306 .60144 .41069 Mtetra
.60144 .41069 .60345 .41306 .6074 .41178 .6054 .40941 Mtetra
.6054 .40941 .6074 .41178 .61136 .4105 .60936 .40813 Mtetra
.60936 .40813 .61136 .4105 .61533 .40921 .61333 .40684 Mtetra
.61333 .40684 .61533 .40921 .6193 .40793 .6173 .40555 Mtetra
.6173 .40555 .6193 .40793 .62328 .40664 .62128 .40426 Mtetra
.62128 .40426 .62328 .40664 .62726 .40535 .62527 .40297 Mtetra
.62527 .40297 .62726 .40535 .63125 .40406 .62926 .40168 Mtetra
.62926 .40168 .63125 .40406 .63524 .40277 .63326 .40038 Mtetra
.63326 .40038 .63524 .40277 .63924 .40148 .63726 .39909 Mtetra
.63726 .39909 .63924 .40148 .64324 .40018 .64127 .39779 Mtetra
.64127 .39779 .64324 .40018 .64725 .39889 .64529 .39649 Mtetra
.64529 .39649 .64725 .39889 .65127 .39759 .64931 .39518 Mtetra
.64931 .39518 .65127 .39759 .65529 .39628 .65333 .39388 Mtetra
.65333 .39388 .65529 .39628 .65932 .39498 .65736 .39257 Mtetra
.65736 .39257 .65932 .39498 .66335 .39368 .6614 .39126 Mtetra
.6614 .39126 .66335 .39368 .66739 .39237 .66545 .38995 Mtetra
.66545 .38995 .66739 .39237 .67144 .39106 .66949 .38864 Mtetra
.66949 .38864 .67144 .39106 .67549 .38975 .67355 .38733 Mtetra
.67355 .38733 .67549 .38975 .67955 .38844 .67761 .38601 Mtetra
.67761 .38601 .67955 .38844 .68361 .38712 .68168 .38469 Mtetra
.68168 .38469 .68361 .38712 .68768 .38581 .68575 .38337 Mtetra
.68575 .38337 .68768 .38581 .69175 .38449 .68983 .38205 Mtetra
.68983 .38205 .69175 .38449 .69583 .38317 .69391 .38073 Mtetra
.69391 .38073 .69583 .38317 .69992 .38185 .698 .3794 Mtetra
.698 .3794 .69992 .38185 .70401 .38052 .7021 .37807 Mtetra
.959 .619 .276 r
.7021 .37807 .70401 .38052 .71007 .41341 .70814 .41098 Mtetra
.661 .745 .912 r
.70814 .41098 .71007 .41341 .71422 .4121 .71229 .40966 Mtetra
.71229 .40966 .71422 .4121 .71837 .41078 .71645 .40834 Mtetra
.71645 .40834 .71837 .41078 .72253 .40946 .72062 .40701 Mtetra
.72062 .40701 .72253 .40946 .7267 .40813 .72479 .40569 Mtetra
.72479 .40569 .7267 .40813 .73087 .40681 .72897 .40436 Mtetra
.72897 .40436 .73087 .40681 .73505 .40548 .73315 .40303 Mtetra
.73315 .40303 .73505 .40548 .73924 .40415 .73734 .4017 Mtetra
.73734 .4017 .73924 .40415 .74343 .40282 .74154 .40036 Mtetra
.74154 .40036 .74343 .40282 .74763 .40149 .74574 .39903 Mtetra
.74574 .39903 .74763 .40149 .75183 .40016 .74995 .39769 Mtetra
.963 .759 .581 r
.74995 .39769 .75183 .40016 .75604 .39882 .75311 .38153 Mtetra
.589 .422 .623 r
.75311 .38153 .75604 .39882 .76583 .47363 .75731 .38019 Mtetra
.563 .357 .56 r
.75731 .38019 .76583 .47363 .77015 .47231 .76152 .37884 Mtetra
.1 .027 .478 r
.76152 .37884 .77015 .47231 .77449 .47099 .77258 .46856 Mtetra
.655 .752 .921 r
.77258 .46856 .77449 .47099 .77883 .46968 .77693 .46724 Mtetra
.77693 .46724 .77883 .46968 .78317 .46836 .78128 .46591 Mtetra
.78128 .46591 .78317 .46836 .78753 .46703 .78564 .46459 Mtetra
.78564 .46459 .78753 .46703 .79189 .46571 .79 .46326 Mtetra
.79 .46326 .79189 .46571 .79625 .46438 .79437 .46193 Mtetra
.79437 .46193 .79625 .46438 .80063 .46305 .79875 .4606 Mtetra
.79875 .4606 .80063 .46305 .80501 .46172 .80314 .45926 Mtetra
.80314 .45926 .80501 .46172 .80939 .46039 .80753 .45792 Mtetra
.80753 .45792 .80939 .46039 .81378 .45906 .81192 .45659 Mtetra
.81192 .45659 .81378 .45906 .81818 .45772 .81633 .45525 Mtetra
.81633 .45525 .81818 .45772 .82259 .45638 .82074 .4539 Mtetra
.82074 .4539 .82259 .45638 .827 .45504 .82516 .45256 Mtetra
.82516 .45256 .827 .45504 .83142 .4537 .82958 .45121 Mtetra
.937 .577 .175 r
.82958 .45121 .83142 .4537 .83886 .48401 .83701 .48154 Mtetra
.653 .755 .925 r
.83701 .48154 .83886 .48401 .84333 .48267 .84149 .4802 Mtetra
.84149 .4802 .84333 .48267 .84782 .48134 .84598 .47886 Mtetra
.84598 .47886 .84782 .48134 .85231 .48 .85048 .47752 Mtetra
.85048 .47752 .85231 .48 .85681 .47866 .85498 .47617 Mtetra
.85498 .47617 .85681 .47866 .86132 .47731 .85949 .47483 Mtetra
.85949 .47483 .86132 .47731 .86583 .47597 .86401 .47348 Mtetra
.86401 .47348 .86583 .47597 .87035 .47462 .86854 .47212 Mtetra
.86854 .47212 .87035 .47462 .87488 .47327 .87307 .47077 Mtetra
.87307 .47077 .87488 .47327 .87941 .47192 .87761 .46941 Mtetra
.87761 .46941 .87941 .47192 .88395 .47056 .88215 .46806 Mtetra
.88215 .46806 .88395 .47056 .8885 .4692 .88671 .4667 Mtetra
.88671 .4667 .8885 .4692 .89306 .46785 .89127 .46533 Mtetra
.89127 .46533 .89306 .46785 .89762 .46649 .89583 .46397 Mtetra
.89583 .46397 .89762 .46649 .90219 .46512 .90041 .4626 Mtetra
.90041 .4626 .90219 .46512 .90676 .46376 .90499 .46123 Mtetra
.90499 .46123 .90676 .46376 .91135 .46239 .90958 .45986 Mtetra
.652 .755 .925 r
.29017 .64713 .29256 .64916 .29625 .64806 .29386 .64603 Mtetra
.942 .641 .438 r
.29386 .64603 .29625 .64806 .29994 .64696 .29588 .67057 Mtetra
.53 .281 .482 r
.29588 .67057 .29994 .64696 .302 .6715 .29961 .66948 Mtetra
.65 .758 .928 r
.29961 .66948 .302 .6715 .30573 .6704 .30334 .66838 Mtetra
.30334 .66838 .30573 .6704 .30947 .66931 .30708 .66729 Mtetra
.30708 .66729 .30947 .66931 .31321 .66821 .31082 .66619 Mtetra
.31082 .66619 .31321 .66821 .31696 .66712 .31457 .66509 Mtetra
.31457 .66509 .31696 .66712 .32071 .66602 .31832 .66398 Mtetra
.31832 .66398 .32071 .66602 .32446 .66492 .32208 .66288 Mtetra
.32208 .66288 .32446 .66492 .32822 .66381 .32585 .66178 Mtetra
.32585 .66178 .32822 .66381 .33199 .66271 .32962 .66067 Mtetra
.32962 .66067 .33199 .66271 .33576 .66161 .3334 .65956 Mtetra
.3334 .65956 .33576 .66161 .33954 .6605 .33718 .65845 Mtetra
.33718 .65845 .33954 .6605 .34333 .65939 .34096 .65734 Mtetra
.34096 .65734 .34333 .65939 .34711 .65828 .34475 .65623 Mtetra
.34475 .65623 .34711 .65828 .35091 .65717 .34855 .65511 Mtetra
.34855 .65511 .35091 .65717 .35471 .65605 .35235 .654 Mtetra
.35235 .654 .35471 .65605 .35851 .65494 .35616 .65288 Mtetra
.35616 .65288 .35851 .65494 .36232 .65382 .35998 .65176 Mtetra
.35998 .65176 .36232 .65382 .36614 .65271 .3638 .65064 Mtetra
.3638 .65064 .36614 .65271 .36996 .65159 .36762 .64951 Mtetra
.36762 .64951 .36996 .65159 .37379 .65046 .37145 .64839 Mtetra
.37145 .64839 .37379 .65046 .37762 .64934 .37529 .64726 Mtetra
.37529 .64726 .37762 .64934 .38146 .64822 .37913 .64614 Mtetra
.37913 .64614 .38146 .64822 .3853 .64709 .38297 .64501 Mtetra
.38297 .64501 .3853 .64709 .38915 .64596 .38682 .64388 Mtetra
.38682 .64388 .38915 .64596 .393 .64483 .39068 .64275 Mtetra
.39068 .64275 .393 .64483 .39686 .6437 .39455 .64161 Mtetra
.39455 .64161 .39686 .6437 .40073 .64257 .39841 .64048 Mtetra
.947 .693 .52 r
.39841 .64048 .40073 .64257 .40997 .48681 .40777 .48461 Mtetra
.663 .743 .91 r
.40777 .48461 .40997 .48681 .41367 .48562 .41148 .48342 Mtetra
.41148 .48342 .41367 .48562 .41738 .48443 .41519 .48222 Mtetra
.41519 .48222 .41738 .48443 .4211 .48323 .41891 .48102 Mtetra
.41891 .48102 .4211 .48323 .42482 .48204 .42264 .47983 Mtetra
.42264 .47983 .42482 .48204 .42855 .48084 .42637 .47862 Mtetra
.42637 .47862 .42855 .48084 .43228 .47964 .43011 .47742 Mtetra
.43011 .47742 .43228 .47964 .43602 .47844 .43385 .47622 Mtetra
.43385 .47622 .43602 .47844 .43976 .47724 .43759 .47501 Mtetra
.43759 .47501 .43976 .47724 .44351 .47603 .44134 .4738 Mtetra
.44134 .4738 .44351 .47603 .44727 .47482 .4451 .47259 Mtetra
.4451 .47259 .44727 .47482 .45102 .47362 .44886 .47138 Mtetra
.44886 .47138 .45102 .47362 .45479 .47241 .45263 .47017 Mtetra
.45263 .47017 .45479 .47241 .45856 .4712 .4564 .46895 Mtetra
.4564 .46895 .45856 .4712 .46233 .46998 .46018 .46774 Mtetra
.929 .737 .622 r
.46018 .46774 .46233 .46998 .46611 .46877 .46423 .45221 Mtetra
.589 .422 .623 r
.46423 .45221 .46611 .46877 .47013 .45324 .468 .45098 Mtetra
.664 .741 .908 r
.468 .45098 .47013 .45324 .47391 .45202 .47178 .44976 Mtetra
.47178 .44976 .47391 .45202 .47769 .4508 .47556 .44853 Mtetra
.47556 .44853 .47769 .4508 .48147 .44957 .47934 .4473 Mtetra
.47934 .4473 .48147 .44957 .48526 .44834 .48314 .44607 Mtetra
.48314 .44607 .48526 .44834 .48905 .44711 .48694 .44484 Mtetra
.48694 .44484 .48905 .44711 .49285 .44588 .49074 .4436 Mtetra
.49074 .4436 .49285 .44588 .49666 .44465 .49455 .44237 Mtetra
.49455 .44237 .49666 .44465 .50047 .44341 .49836 .44113 Mtetra
.49836 .44113 .50047 .44341 .50429 .44218 .50218 .43989 Mtetra
.50218 .43989 .50429 .44218 .50811 .44094 .506 .43865 Mtetra
.506 .43865 .50811 .44094 .51193 .4397 .50983 .4374 Mtetra
.50983 .4374 .51193 .4397 .51576 .43846 .51367 .43616 Mtetra
.51367 .43616 .51576 .43846 .5196 .43721 .51751 .43491 Mtetra
.51751 .43491 .5196 .43721 .52344 .43597 .52136 .43366 Mtetra
.52136 .43366 .52344 .43597 .52729 .43472 .52521 .43241 Mtetra
.52521 .43241 .52729 .43472 .53115 .43347 .52906 .43116 Mtetra
.52906 .43116 .53115 .43347 .535 .43222 .53293 .42991 Mtetra
.53293 .42991 .535 .43222 .53887 .43097 .53679 .42865 Mtetra
.53679 .42865 .53887 .43097 .54274 .42972 .54067 .4274 Mtetra
.54067 .4274 .54274 .42972 .54661 .42846 .54455 .42614 Mtetra
.54455 .42614 .54661 .42846 .55049 .4272 .54843 .42488 Mtetra
.54843 .42488 .55049 .4272 .55438 .42594 .55232 .42361 Mtetra
.55232 .42361 .55438 .42594 .55827 .42468 .55621 .42235 Mtetra
.55621 .42235 .55827 .42468 .56217 .42342 .56011 .42108 Mtetra
.56011 .42108 .56217 .42342 .56607 .42216 .56402 .41982 Mtetra
.56402 .41982 .56607 .42216 .56998 .42089 .56793 .41855 Mtetra
.56793 .41855 .56998 .42089 .57389 .41962 .57185 .41728 Mtetra
.57185 .41728 .57389 .41962 .57781 .41835 .57577 .416 Mtetra
.57577 .416 .57781 .41835 .58173 .41708 .5797 .41473 Mtetra
.5797 .41473 .58173 .41708 .58566 .41581 .58363 .41345 Mtetra
.58363 .41345 .58566 .41581 .5896 .41453 .58757 .41217 Mtetra
.58757 .41217 .5896 .41453 .59354 .41325 .59152 .41089 Mtetra
.59152 .41089 .59354 .41325 .59749 .41197 .59547 .40961 Mtetra
.59547 .40961 .59749 .41197 .60144 .41069 .59942 .40832 Mtetra
.59942 .40832 .60144 .41069 .6054 .40941 .60338 .40704 Mtetra
.60338 .40704 .6054 .40941 .60936 .40813 .60735 .40575 Mtetra
.60735 .40575 .60936 .40813 .61333 .40684 .61133 .40446 Mtetra
.61133 .40446 .61333 .40684 .6173 .40555 .6153 .40317 Mtetra
.6153 .40317 .6173 .40555 .62128 .40426 .61929 .40188 Mtetra
.61929 .40188 .62128 .40426 .62527 .40297 .62328 .40058 Mtetra
.62328 .40058 .62527 .40297 .62926 .40168 .62727 .39928 Mtetra
.62727 .39928 .62926 .40168 .63326 .40038 .63127 .39799 Mtetra
.63127 .39799 .63326 .40038 .63726 .39909 .63528 .39669 Mtetra
.63528 .39669 .63726 .39909 .64127 .39779 .63929 .39538 Mtetra
.63929 .39538 .64127 .39779 .64529 .39649 .64331 .39408 Mtetra
.64331 .39408 .64529 .39649 .64931 .39518 .64734 .39277 Mtetra
.64734 .39277 .64931 .39518 .65333 .39388 .65137 .39146 Mtetra
.65137 .39146 .65333 .39388 .65736 .39257 .6554 .39015 Mtetra
.6554 .39015 .65736 .39257 .6614 .39126 .65944 .38884 Mtetra
.65944 .38884 .6614 .39126 .66545 .38995 .66349 .38753 Mtetra
.66349 .38753 .66545 .38995 .66949 .38864 .66754 .38621 Mtetra
.66754 .38621 .66949 .38864 .67355 .38733 .6716 .3849 Mtetra
.6716 .3849 .67355 .38733 .67761 .38601 .67567 .38358 Mtetra
.67567 .38358 .67761 .38601 .68168 .38469 .67974 .38225 Mtetra
.67974 .38225 .68168 .38469 .68575 .38337 .68382 .38093 Mtetra
.68382 .38093 .68575 .38337 .68983 .38205 .6879 .37961 Mtetra
.6879 .37961 .68983 .38205 .69391 .38073 .69199 .37828 Mtetra
.69199 .37828 .69391 .38073 .698 .3794 .69608 .37695 Mtetra
.69608 .37695 .698 .3794 .7021 .37807 .70018 .37562 Mtetra
.959 .619 .276 r
.70018 .37562 .7021 .37807 .70814 .41098 .70621 .40854 Mtetra
.661 .745 .912 r
.70621 .40854 .70814 .41098 .71229 .40966 .71037 .40722 Mtetra
.71037 .40722 .71229 .40966 .71645 .40834 .71453 .40589 Mtetra
.71453 .40589 .71645 .40834 .72062 .40701 .7187 .40456 Mtetra
.7187 .40456 .72062 .40701 .72479 .40569 .72288 .40323 Mtetra
.72288 .40323 .72479 .40569 .72897 .40436 .72706 .4019 Mtetra
.72706 .4019 .72897 .40436 .73315 .40303 .73125 .40057 Mtetra
.73125 .40057 .73315 .40303 .73734 .4017 .73544 .39923 Mtetra
.73544 .39923 .73734 .4017 .74154 .40036 .73964 .39789 Mtetra
.962 .759 .582 r
.73964 .39789 .74154 .40036 .74574 .39903 .74284 .38174 Mtetra
.588 .422 .623 r
.74284 .38174 .74574 .39903 .74995 .39769 .74703 .3804 Mtetra
.74703 .3804 .74995 .39769 .75311 .38153 .75123 .37905 Mtetra
.662 .743 .91 r
.75123 .37905 .75311 .38153 .75731 .38019 .75544 .3777 Mtetra
.75544 .3777 .75731 .38019 .76152 .37884 .75965 .37634 Mtetra
.75965 .37634 .76152 .37884 .77258 .46856 .76387 .37499 Mtetra
.562 .357 .56 r
.76387 .37499 .77258 .46856 .77693 .46724 .76809 .37363 Mtetra
.76809 .37363 .77693 .46724 .78128 .46591 .77232 .37228 Mtetra
.104 .03 .48 r
.77232 .37228 .78128 .46591 .78564 .46459 .78374 .46213 Mtetra
.655 .752 .921 r
.78374 .46213 .78564 .46459 .79 .46326 .78811 .4608 Mtetra
.78811 .4608 .79 .46326 .79437 .46193 .79249 .45947 Mtetra
.79249 .45947 .79437 .46193 .79875 .4606 .79687 .45813 Mtetra
.79687 .45813 .79875 .4606 .80314 .45926 .80126 .45679 Mtetra
.80126 .45679 .80314 .45926 .80753 .45792 .80566 .45545 Mtetra
.80566 .45545 .80753 .45792 .81192 .45659 .81006 .45411 Mtetra
.81006 .45411 .81192 .45659 .81633 .45525 .81447 .45277 Mtetra
.81447 .45277 .81633 .45525 .82074 .4539 .81888 .45142 Mtetra
.81888 .45142 .82074 .4539 .82516 .45256 .82331 .45007 Mtetra
.82331 .45007 .82516 .45256 .82958 .45121 .82774 .44872 Mtetra
.937 .577 .175 r
.82774 .44872 .82958 .45121 .83701 .48154 .83515 .47907 Mtetra
.653 .755 .925 r
.83515 .47907 .83701 .48154 .84149 .4802 .83964 .47772 Mtetra
.83964 .47772 .84149 .4802 .84598 .47886 .84413 .47638 Mtetra
.84413 .47638 .84598 .47886 .85048 .47752 .84864 .47503 Mtetra
.84864 .47503 .85048 .47752 .85498 .47617 .85315 .47368 Mtetra
.85315 .47368 .85498 .47617 .85949 .47483 .85766 .47233 Mtetra
.85766 .47233 .85949 .47483 .86401 .47348 .86219 .47098 Mtetra
.86219 .47098 .86401 .47348 .86854 .47212 .86672 .46962 Mtetra
.86672 .46962 .86854 .47212 .87307 .47077 .87125 .46826 Mtetra
.87125 .46826 .87307 .47077 .87761 .46941 .8758 .4669 Mtetra
.8758 .4669 .87761 .46941 .88215 .46806 .88035 .46554 Mtetra
.88035 .46554 .88215 .46806 .88671 .4667 .88491 .46418 Mtetra
.88491 .46418 .88671 .4667 .89127 .46533 .88947 .46281 Mtetra
.88947 .46281 .89127 .46533 .89583 .46397 .89404 .46144 Mtetra
.89404 .46144 .89583 .46397 .90041 .4626 .89862 .46007 Mtetra
.89862 .46007 .90041 .4626 .90499 .46123 .90321 .4587 Mtetra
.90321 .4587 .90499 .46123 .90958 .45986 .90781 .45733 Mtetra
.542 .309 .511 r
.2846 .69153 .29017 .64713 .29386 .64603 .28835 .69045 Mtetra
.28835 .69045 .29386 .64603 .29588 .67057 .29209 .68936 Mtetra
.522 .263 .465 r
.29209 .68936 .29588 .67057 .29961 .66948 .29584 .68827 Mtetra
0 0 .029 r
.29584 .68827 .29961 .66948 .30334 .66838 .30094 .66636 Mtetra
.65 .758 .928 r
.30094 .66636 .30334 .66838 .30708 .66729 .30468 .66526 Mtetra
.30468 .66526 .30708 .66729 .31082 .66619 .30843 .66415 Mtetra
.30843 .66415 .31082 .66619 .31457 .66509 .31218 .66305 Mtetra
.31218 .66305 .31457 .66509 .31832 .66398 .31594 .66195 Mtetra
.31594 .66195 .31832 .66398 .32208 .66288 .3197 .66084 Mtetra
.3197 .66084 .32208 .66288 .32585 .66178 .32347 .65973 Mtetra
.32347 .65973 .32585 .66178 .32962 .66067 .32724 .65862 Mtetra
.32724 .65862 .32962 .66067 .3334 .65956 .33102 .65751 Mtetra
.33102 .65751 .3334 .65956 .33718 .65845 .3348 .6564 Mtetra
.3348 .6564 .33718 .65845 .34096 .65734 .33859 .65528 Mtetra
.33859 .65528 .34096 .65734 .34475 .65623 .34239 .65417 Mtetra
.34239 .65417 .34475 .65623 .34855 .65511 .34619 .65305 Mtetra
.34619 .65305 .34855 .65511 .35235 .654 .35 .65193 Mtetra
.35 .65193 .35235 .654 .35616 .65288 .35381 .65081 Mtetra
.35381 .65081 .35616 .65288 .35998 .65176 .35762 .64969 Mtetra
.35762 .64969 .35998 .65176 .3638 .65064 .36145 .64856 Mtetra
.36145 .64856 .3638 .65064 .36762 .64951 .36527 .64744 Mtetra
.36527 .64744 .36762 .64951 .37145 .64839 .36911 .64631 Mtetra
.36911 .64631 .37145 .64839 .37529 .64726 .37295 .64518 Mtetra
.37295 .64518 .37529 .64726 .37913 .64614 .37679 .64405 Mtetra
.37679 .64405 .37913 .64614 .38297 .64501 .38064 .64292 Mtetra
.38064 .64292 .38297 .64501 .38682 .64388 .3845 .64179 Mtetra
.3845 .64179 .38682 .64388 .39068 .64275 .38836 .64065 Mtetra
.38836 .64065 .39068 .64275 .39455 .64161 .39222 .63951 Mtetra
.39222 .63951 .39455 .64161 .39841 .64048 .3961 .63837 Mtetra
.947 .693 .52 r
.3961 .63837 .39841 .64048 .40777 .48461 .40556 .48241 Mtetra
.663 .743 .91 r
.40556 .48241 .40777 .48461 .41148 .48342 .40928 .48121 Mtetra
.40928 .48121 .41148 .48342 .41519 .48222 .413 .48001 Mtetra
.413 .48001 .41519 .48222 .41891 .48102 .41672 .47881 Mtetra
.41672 .47881 .41891 .48102 .42264 .47983 .42045 .47761 Mtetra
.42045 .47761 .42264 .47983 .42637 .47862 .42418 .4764 Mtetra
.42418 .4764 .42637 .47862 .43011 .47742 .42792 .4752 Mtetra
.42792 .4752 .43011 .47742 .43385 .47622 .43167 .47399 Mtetra
.43167 .47399 .43385 .47622 .43759 .47501 .43541 .47278 Mtetra
.43541 .47278 .43759 .47501 .44134 .4738 .43917 .47157 Mtetra
.43917 .47157 .44134 .4738 .4451 .47259 .44293 .47036 Mtetra
.44293 .47036 .4451 .47259 .44886 .47138 .44669 .46914 Mtetra
.44669 .46914 .44886 .47138 .45263 .47017 .45046 .46793 Mtetra
.45046 .46793 .45263 .47017 .4564 .46895 .45424 .46671 Mtetra
.45424 .46671 .4564 .46895 .46018 .46774 .45802 .46549 Mtetra
.929 .737 .622 r
.45802 .46549 .46018 .46774 .46423 .45221 .46208 .44995 Mtetra
.664 .741 .908 r
.46208 .44995 .46423 .45221 .468 .45098 .46586 .44872 Mtetra
.46586 .44872 .468 .45098 .47178 .44976 .46964 .44749 Mtetra
.46964 .44749 .47178 .44976 .47556 .44853 .47342 .44626 Mtetra
.47342 .44626 .47556 .44853 .47934 .4473 .47721 .44503 Mtetra
.47721 .44503 .47934 .4473 .48314 .44607 .48101 .44379 Mtetra
.48101 .44379 .48314 .44607 .48694 .44484 .48481 .44256 Mtetra
.48481 .44256 .48694 .44484 .49074 .4436 .48862 .44132 Mtetra
.48862 .44132 .49074 .4436 .49455 .44237 .49243 .44008 Mtetra
.49243 .44008 .49455 .44237 .49836 .44113 .49625 .43884 Mtetra
.49625 .43884 .49836 .44113 .50218 .43989 .50007 .4376 Mtetra
.50007 .4376 .50218 .43989 .506 .43865 .5039 .43635 Mtetra
.5039 .43635 .506 .43865 .50983 .4374 .50773 .4351 Mtetra
.50773 .4351 .50983 .4374 .51367 .43616 .51157 .43386 Mtetra
.51157 .43386 .51367 .43616 .51751 .43491 .51541 .43261 Mtetra
.51541 .43261 .51751 .43491 .52136 .43366 .51926 .43136 Mtetra
.51926 .43136 .52136 .43366 .52521 .43241 .52312 .4301 Mtetra
.52312 .4301 .52521 .43241 .52906 .43116 .52698 .42885 Mtetra
.52698 .42885 .52906 .43116 .53293 .42991 .53084 .42759 Mtetra
.53084 .42759 .53293 .42991 .53679 .42865 .53472 .42633 Mtetra
.53472 .42633 .53679 .42865 .54067 .4274 .53859 .42507 Mtetra
.53859 .42507 .54067 .4274 .54455 .42614 .54247 .42381 Mtetra
.54247 .42381 .54455 .42614 .54843 .42488 .54636 .42254 Mtetra
.54636 .42254 .54843 .42488 .55232 .42361 .55025 .42128 Mtetra
.55025 .42128 .55232 .42361 .55621 .42235 .55415 .42001 Mtetra
.55415 .42001 .55621 .42235 .56011 .42108 .55806 .41874 Mtetra
.55806 .41874 .56011 .42108 .56402 .41982 .56197 .41747 Mtetra
.56197 .41747 .56402 .41982 .56793 .41855 .56588 .4162 Mtetra
.56588 .4162 .56793 .41855 .57185 .41728 .5698 .41492 Mtetra
.5698 .41492 .57185 .41728 .57577 .416 .57373 .41365 Mtetra
.57373 .41365 .57577 .416 .5797 .41473 .57766 .41237 Mtetra
.57766 .41237 .5797 .41473 .58363 .41345 .5816 .41109 Mtetra
.5816 .41109 .58363 .41345 .58757 .41217 .58554 .40981 Mtetra
.58554 .40981 .58757 .41217 .59152 .41089 .58949 .40852 Mtetra
.58949 .40852 .59152 .41089 .59547 .40961 .59344 .40724 Mtetra
.59344 .40724 .59547 .40961 .59942 .40832 .5974 .40595 Mtetra
.5974 .40595 .59942 .40832 .60338 .40704 .60137 .40466 Mtetra
.60137 .40466 .60338 .40704 .60735 .40575 .60534 .40337 Mtetra
.60534 .40337 .60735 .40575 .61133 .40446 .60932 .40208 Mtetra
.60932 .40208 .61133 .40446 .6153 .40317 .6133 .40078 Mtetra
.6133 .40078 .6153 .40317 .61929 .40188 .61729 .39948 Mtetra
.61729 .39948 .61929 .40188 .62328 .40058 .62128 .39819 Mtetra
.62128 .39819 .62328 .40058 .62727 .39928 .62528 .39689 Mtetra
.62528 .39689 .62727 .39928 .63127 .39799 .62928 .39558 Mtetra
.62928 .39558 .63127 .39799 .63528 .39669 .6333 .39428 Mtetra
.6333 .39428 .63528 .39669 .63929 .39538 .63731 .39297 Mtetra
.63731 .39297 .63929 .39538 .64331 .39408 .64133 .39167 Mtetra
.64133 .39167 .64331 .39408 .64734 .39277 .64536 .39036 Mtetra
.64536 .39036 .64734 .39277 .65137 .39146 .6494 .38904 Mtetra
.6494 .38904 .65137 .39146 .6554 .39015 .65344 .38773 Mtetra
.65344 .38773 .6554 .39015 .65944 .38884 .65748 .38642 Mtetra
.65748 .38642 .65944 .38884 .66349 .38753 .66153 .3851 Mtetra
.66153 .3851 .66349 .38753 .66754 .38621 .66559 .38378 Mtetra
.66559 .38378 .66754 .38621 .6716 .3849 .66965 .38246 Mtetra
.66965 .38246 .6716 .3849 .67567 .38358 .67372 .38114 Mtetra
.67372 .38114 .67567 .38358 .67974 .38225 .6778 .37981 Mtetra
.6778 .37981 .67974 .38225 .68382 .38093 .68188 .37848 Mtetra
.68188 .37848 .68382 .38093 .6879 .37961 .68596 .37715 Mtetra
.68596 .37715 .6879 .37961 .69199 .37828 .69006 .37582 Mtetra
.69006 .37582 .69199 .37828 .69608 .37695 .69415 .37449 Mtetra
.69415 .37449 .69608 .37695 .70018 .37562 .69826 .37316 Mtetra
.69826 .37316 .70018 .37562 .70621 .40854 .70237 .37182 Mtetra
.113 .051 .502 r
.70237 .37182 .70621 .40854 .71037 .40722 .70844 .40477 Mtetra
.661 .745 .912 r
.70844 .40477 .71037 .40722 .71453 .40589 .7126 .40344 Mtetra
.7126 .40344 .71453 .40589 .7187 .40456 .71678 .40211 Mtetra
.71678 .40211 .7187 .40456 .72288 .40323 .72096 .40077 Mtetra
.72096 .40077 .72288 .40323 .72706 .4019 .72514 .39944 Mtetra
.72514 .39944 .72706 .4019 .73125 .40057 .72934 .3981 Mtetra
.961 .758 .584 r
.72934 .3981 .73125 .40057 .73544 .39923 .73257 .38195 Mtetra
.588 .421 .623 r
.73257 .38195 .73544 .39923 .73964 .39789 .73676 .3806 Mtetra
.73676 .3806 .73964 .39789 .74284 .38174 .74095 .37925 Mtetra
.662 .743 .91 r
.74095 .37925 .74284 .38174 .74703 .3804 .74515 .37791 Mtetra
.74515 .37791 .74703 .3804 .75123 .37905 .74935 .37655 Mtetra
.74935 .37655 .75123 .37905 .75544 .3777 .75356 .3752 Mtetra
.75356 .3752 .75544 .3777 .75965 .37634 .75778 .37384 Mtetra
.75778 .37384 .75965 .37634 .76387 .37499 .762 .37249 Mtetra
.762 .37249 .76387 .37499 .76809 .37363 .76623 .37113 Mtetra
.76623 .37113 .76809 .37363 .77232 .37228 .77046 .36976 Mtetra
.77046 .36976 .77232 .37228 .78374 .46213 .7747 .3684 Mtetra
.562 .356 .559 r
.7747 .3684 .78374 .46213 .78811 .4608 .77895 .36703 Mtetra
.77895 .36703 .78811 .4608 .79249 .45947 .7832 .36567 Mtetra
.108 .034 .482 r
.7832 .36567 .79249 .45947 .79687 .45813 .79499 .45566 Mtetra
.655 .752 .921 r
.79499 .45566 .79687 .45813 .80126 .45679 .79938 .45432 Mtetra
.79938 .45432 .80126 .45679 .80566 .45545 .80378 .45297 Mtetra
.80378 .45297 .80566 .45545 .81006 .45411 .80819 .45163 Mtetra
.80819 .45163 .81006 .45411 .81447 .45277 .8126 .45028 Mtetra
.8126 .45028 .81447 .45277 .81888 .45142 .81702 .44893 Mtetra
.81702 .44893 .81888 .45142 .82331 .45007 .82145 .44758 Mtetra
.82145 .44758 .82331 .45007 .82774 .44872 .82588 .44622 Mtetra
.937 .577 .175 r
.82588 .44622 .82774 .44872 .83515 .47907 .83329 .47659 Mtetra
.653 .755 .925 r
.83329 .47659 .83515 .47907 .83964 .47772 .83778 .47524 Mtetra
.83778 .47524 .83964 .47772 .84413 .47638 .84228 .47389 Mtetra
.84228 .47389 .84413 .47638 .84864 .47503 .84679 .47254 Mtetra
.84679 .47254 .84864 .47503 .85315 .47368 .85131 .47119 Mtetra
.85131 .47119 .85315 .47368 .85766 .47233 .85583 .46983 Mtetra
.85583 .46983 .85766 .47233 .86219 .47098 .86036 .46847 Mtetra
.86036 .46847 .86219 .47098 .86672 .46962 .86489 .46711 Mtetra
.86489 .46711 .86672 .46962 .87125 .46826 .86943 .46575 Mtetra
.86943 .46575 .87125 .46826 .8758 .4669 .87398 .46439 Mtetra
.87398 .46439 .8758 .4669 .88035 .46554 .87854 .46302 Mtetra
.87854 .46302 .88035 .46554 .88491 .46418 .8831 .46165 Mtetra
.8831 .46165 .88491 .46418 .88947 .46281 .88767 .46028 Mtetra
.88767 .46028 .88947 .46281 .89404 .46144 .89225 .45891 Mtetra
.89225 .45891 .89404 .46144 .89862 .46007 .89684 .45754 Mtetra
.89684 .45754 .89862 .46007 .90321 .4587 .90143 .45616 Mtetra
.90143 .45616 .90321 .4587 .90781 .45733 .90603 .45478 Mtetra
.648 .76 .931 r
.28217 .68953 .2846 .69153 .28835 .69045 .28591 .68844 Mtetra
.28591 .68844 .28835 .69045 .29209 .68936 .28966 .68735 Mtetra
.28966 .68735 .29209 .68936 .29584 .68827 .29342 .68626 Mtetra
.29342 .68626 .29584 .68827 .30094 .66636 .29718 .68516 Mtetra
.521 .263 .464 r
.29718 .68516 .30094 .66636 .30468 .66526 .30094 .68407 Mtetra
0 0 .032 r
.30094 .68407 .30468 .66526 .30843 .66415 .30603 .66212 Mtetra
.65 .758 .928 r
.30603 .66212 .30843 .66415 .31218 .66305 .30978 .66101 Mtetra
.30978 .66101 .31218 .66305 .31594 .66195 .31354 .6599 Mtetra
.31354 .6599 .31594 .66195 .3197 .66084 .31731 .65879 Mtetra
.31731 .65879 .3197 .66084 .32347 .65973 .32108 .65768 Mtetra
.32108 .65768 .32347 .65973 .32724 .65862 .32486 .65657 Mtetra
.32486 .65657 .32724 .65862 .33102 .65751 .32864 .65545 Mtetra
.32864 .65545 .33102 .65751 .3348 .6564 .33243 .65434 Mtetra
.33243 .65434 .3348 .6564 .33859 .65528 .33622 .65322 Mtetra
.33622 .65322 .33859 .65528 .34239 .65417 .34002 .6521 Mtetra
.34002 .6521 .34239 .65417 .34619 .65305 .34382 .65098 Mtetra
.34382 .65098 .34619 .65305 .35 .65193 .34763 .64986 Mtetra
.34763 .64986 .35 .65193 .35381 .65081 .35145 .64874 Mtetra
.35145 .64874 .35381 .65081 .35762 .64969 .35527 .64761 Mtetra
.35527 .64761 .35762 .64969 .36145 .64856 .35909 .64648 Mtetra
.35909 .64648 .36145 .64856 .36527 .64744 .36292 .64536 Mtetra
.36292 .64536 .36527 .64744 .36911 .64631 .36676 .64423 Mtetra
.36676 .64423 .36911 .64631 .37295 .64518 .3706 .64309 Mtetra
.3706 .64309 .37295 .64518 .37679 .64405 .37445 .64196 Mtetra
.37445 .64196 .37679 .64405 .38064 .64292 .3783 .64083 Mtetra
.3783 .64083 .38064 .64292 .3845 .64179 .38216 .63969 Mtetra
.38216 .63969 .3845 .64179 .38836 .64065 .38603 .63855 Mtetra
.38603 .63855 .38836 .64065 .39222 .63951 .3899 .63741 Mtetra
.947 .693 .52 r
.3899 .63741 .39222 .63951 .3961 .63837 .39982 .47663 Mtetra
.559 .349 .552 r
.39982 .47663 .3961 .63837 .40556 .48241 .40353 .47543 Mtetra
.622 .518 .715 r
.40353 .47543 .40556 .48241 .40928 .48121 .40724 .47423 Mtetra
.292 .309 .706 r
.40724 .47423 .40928 .48121 .413 .48001 .41079 .47779 Mtetra
.663 .743 .91 r
.41079 .47779 .413 .48001 .41672 .47881 .41452 .47659 Mtetra
.41452 .47659 .41672 .47881 .42045 .47761 .41825 .47538 Mtetra
.41825 .47538 .42045 .47761 .42418 .4764 .42199 .47417 Mtetra
.42199 .47417 .42418 .4764 .42792 .4752 .42573 .47297 Mtetra
.42573 .47297 .42792 .4752 .43167 .47399 .42948 .47175 Mtetra
.42948 .47175 .43167 .47399 .43541 .47278 .43323 .47054 Mtetra
.43323 .47054 .43541 .47278 .43917 .47157 .43699 .46933 Mtetra
.43699 .46933 .43917 .47157 .44293 .47036 .44075 .46811 Mtetra
.44075 .46811 .44293 .47036 .44669 .46914 .44452 .4669 Mtetra
.44452 .4669 .44669 .46914 .45046 .46793 .44829 .46568 Mtetra
.44829 .46568 .45046 .46793 .45424 .46671 .45207 .46446 Mtetra
.928 .736 .622 r
.45207 .46446 .45424 .46671 .45802 .46549 .45616 .44891 Mtetra
.588 .421 .623 r
.45616 .44891 .45802 .46549 .46208 .44995 .45993 .44768 Mtetra
.664 .741 .908 r
.45993 .44768 .46208 .44995 .46586 .44872 .46371 .44645 Mtetra
.46371 .44645 .46586 .44872 .46964 .44749 .46749 .44522 Mtetra
.46749 .44522 .46964 .44749 .47342 .44626 .47128 .44398 Mtetra
.47128 .44398 .47342 .44626 .47721 .44503 .47508 .44275 Mtetra
.47508 .44275 .47721 .44503 .48101 .44379 .47888 .44151 Mtetra
.47888 .44151 .48101 .44379 .48481 .44256 .48268 .44027 Mtetra
.48268 .44027 .48481 .44256 .48862 .44132 .48649 .43903 Mtetra
.48649 .43903 .48862 .44132 .49243 .44008 .49031 .43779 Mtetra
.49031 .43779 .49243 .44008 .49625 .43884 .49413 .43654 Mtetra
.49413 .43654 .49625 .43884 .50007 .4376 .49795 .4353 Mtetra
.49795 .4353 .50007 .4376 .5039 .43635 .50179 .43405 Mtetra
.50179 .43405 .5039 .43635 .50773 .4351 .50562 .4328 Mtetra
.50562 .4328 .50773 .4351 .51157 .43386 .50946 .43155 Mtetra
.50946 .43155 .51157 .43386 .51541 .43261 .51331 .43029 Mtetra
.51331 .43029 .51541 .43261 .51926 .43136 .51716 .42904 Mtetra
.51716 .42904 .51926 .43136 .52312 .4301 .52102 .42778 Mtetra
.52102 .42778 .52312 .4301 .52698 .42885 .52489 .42652 Mtetra
.52489 .42652 .52698 .42885 .53084 .42759 .52876 .42526 Mtetra
.52876 .42526 .53084 .42759 .53472 .42633 .53263 .424 Mtetra
.53263 .424 .53472 .42633 .53859 .42507 .53651 .42274 Mtetra
.53651 .42274 .53859 .42507 .54247 .42381 .5404 .42147 Mtetra
.5404 .42147 .54247 .42381 .54636 .42254 .54429 .42021 Mtetra
.54429 .42021 .54636 .42254 .55025 .42128 .54818 .41894 Mtetra
.54818 .41894 .55025 .42128 .55415 .42001 .55209 .41767 Mtetra
.55209 .41767 .55415 .42001 .55806 .41874 .55599 .41639 Mtetra
.55599 .41639 .55806 .41874 .56197 .41747 .55991 .41512 Mtetra
.55991 .41512 .56197 .41747 .56588 .4162 .56383 .41384 Mtetra
.56383 .41384 .56588 .4162 .5698 .41492 .56775 .41257 Mtetra
.56775 .41257 .5698 .41492 .57373 .41365 .57168 .41129 Mtetra
.57168 .41129 .57373 .41365 .57766 .41237 .57562 .41 Mtetra
.57562 .41 .57766 .41237 .5816 .41109 .57956 .40872 Mtetra
.57956 .40872 .5816 .41109 .58554 .40981 .5835 .40743 Mtetra
.5835 .40743 .58554 .40981 .58949 .40852 .58746 .40615 Mtetra
.58746 .40615 .58949 .40852 .59344 .40724 .59141 .40486 Mtetra
.59141 .40486 .59344 .40724 .5974 .40595 .59538 .40357 Mtetra
.59538 .40357 .5974 .40595 .60137 .40466 .59935 .40227 Mtetra
.59935 .40227 .60137 .40466 .60534 .40337 .60332 .40098 Mtetra
.60332 .40098 .60534 .40337 .60932 .40208 .6073 .39968 Mtetra
.6073 .39968 .60932 .40208 .6133 .40078 .61129 .39839 Mtetra
.61129 .39839 .6133 .40078 .61729 .39948 .61528 .39709 Mtetra
.61528 .39709 .61729 .39948 .62128 .39819 .61928 .39578 Mtetra
.61928 .39578 .62128 .39819 .62528 .39689 .62328 .39448 Mtetra
.62328 .39448 .62528 .39689 .62928 .39558 .62729 .39317 Mtetra
.62729 .39317 .62928 .39558 .6333 .39428 .6313 .39187 Mtetra
.6313 .39187 .6333 .39428 .63731 .39297 .63532 .39056 Mtetra
.63532 .39056 .63731 .39297 .64133 .39167 .63935 .38925 Mtetra
.63935 .38925 .64133 .39167 .64536 .39036 .64338 .38793 Mtetra
.64338 .38793 .64536 .39036 .6494 .38904 .64742 .38662 Mtetra
.64742 .38662 .6494 .38904 .65344 .38773 .65146 .3853 Mtetra
.65146 .3853 .65344 .38773 .65748 .38642 .65551 .38398 Mtetra
.65551 .38398 .65748 .38642 .66153 .3851 .65957 .38266 Mtetra
.65957 .38266 .66153 .3851 .66559 .38378 .66363 .38134 Mtetra
.66363 .38134 .66559 .38378 .66965 .38246 .6677 .38001 Mtetra
.6677 .38001 .66965 .38246 .67372 .38114 .67177 .37869 Mtetra
.67177 .37869 .67372 .38114 .6778 .37981 .67585 .37736 Mtetra
.67585 .37736 .6778 .37981 .68188 .37848 .67993 .37603 Mtetra
.67993 .37603 .68188 .37848 .68596 .37715 .68402 .3747 Mtetra
.68402 .3747 .68596 .37715 .69006 .37582 .68812 .37336 Mtetra
.68812 .37336 .69006 .37582 .69415 .37449 .69222 .37203 Mtetra
.69222 .37203 .69415 .37449 .69826 .37316 .69633 .37069 Mtetra
.69633 .37069 .69826 .37316 .70237 .37182 .70045 .36935 Mtetra
.70045 .36935 .70237 .37182 .70844 .40477 .70457 .36801 Mtetra
.113 .051 .502 r
.70457 .36801 .70844 .40477 .7126 .40344 .71067 .40098 Mtetra
.661 .745 .912 r
.71067 .40098 .7126 .40344 .71678 .40211 .71485 .39964 Mtetra
.71485 .39964 .71678 .40211 .72096 .40077 .71903 .39831 Mtetra
.96 .757 .585 r
.71903 .39831 .72096 .40077 .72514 .39944 .72231 .38216 Mtetra
.588 .421 .623 r
.72231 .38216 .72514 .39944 .72934 .3981 .72649 .38081 Mtetra
.72649 .38081 .72934 .3981 .73257 .38195 .73067 .37946 Mtetra
.662 .743 .91 r
.73067 .37946 .73257 .38195 .73676 .3806 .73486 .37811 Mtetra
.73486 .37811 .73676 .3806 .74095 .37925 .73905 .37676 Mtetra
.73905 .37676 .74095 .37925 .74515 .37791 .74326 .37541 Mtetra
.74326 .37541 .74515 .37791 .74935 .37655 .74746 .37405 Mtetra
.74746 .37405 .74935 .37655 .75356 .3752 .75168 .37269 Mtetra
.75168 .37269 .75356 .3752 .75778 .37384 .7559 .37133 Mtetra
.7559 .37133 .75778 .37384 .762 .37249 .76012 .36997 Mtetra
.76012 .36997 .762 .37249 .76623 .37113 .76436 .36861 Mtetra
.76436 .36861 .76623 .37113 .77046 .36976 .76859 .36724 Mtetra
.76859 .36724 .77046 .36976 .7747 .3684 .77284 .36588 Mtetra
.77284 .36588 .7747 .3684 .77895 .36703 .77709 .36451 Mtetra
.77709 .36451 .77895 .36703 .7832 .36567 .78135 .36313 Mtetra
.78135 .36313 .7832 .36567 .79499 .45566 .78561 .36176 Mtetra
.562 .356 .559 r
.78561 .36176 .79499 .45566 .79938 .45432 .78988 .36039 Mtetra
.78988 .36039 .79938 .45432 .80378 .45297 .79416 .35901 Mtetra
.79416 .35901 .80378 .45297 .80819 .45163 .79844 .35763 Mtetra
.114 .039 .485 r
.79844 .35763 .80819 .45163 .8126 .45028 .81073 .44779 Mtetra
.655 .752 .921 r
.81073 .44779 .8126 .45028 .81702 .44893 .81516 .44643 Mtetra
.81516 .44643 .81702 .44893 .82145 .44758 .81959 .44508 Mtetra
.81959 .44508 .82145 .44758 .82588 .44622 .82403 .44372 Mtetra
.937 .577 .175 r
.82403 .44372 .82588 .44622 .83329 .47659 .83143 .4741 Mtetra
.653 .755 .925 r
.83143 .4741 .83329 .47659 .83778 .47524 .83592 .47275 Mtetra
.83592 .47275 .83778 .47524 .84228 .47389 .84043 .47139 Mtetra
.84043 .47139 .84228 .47389 .84679 .47254 .84494 .47004 Mtetra
.84494 .47004 .84679 .47254 .85131 .47119 .84946 .46868 Mtetra
.84946 .46868 .85131 .47119 .85583 .46983 .85399 .46732 Mtetra
.85399 .46732 .85583 .46983 .86036 .46847 .85852 .46596 Mtetra
.85852 .46596 .86036 .46847 .86489 .46711 .86306 .4646 Mtetra
.86306 .4646 .86489 .46711 .86943 .46575 .86761 .46323 Mtetra
.86761 .46323 .86943 .46575 .87398 .46439 .87216 .46187 Mtetra
.87216 .46187 .87398 .46439 .87854 .46302 .87672 .4605 Mtetra
.87672 .4605 .87854 .46302 .8831 .46165 .88129 .45912 Mtetra
.88129 .45912 .8831 .46165 .88767 .46028 .88587 .45775 Mtetra
.88587 .45775 .88767 .46028 .89225 .45891 .89045 .45637 Mtetra
.89045 .45637 .89225 .45891 .89684 .45754 .89504 .45499 Mtetra
.89504 .45499 .89684 .45754 .90143 .45616 .89964 .45361 Mtetra
.89964 .45361 .90143 .45616 .90603 .45478 .90424 .45223 Mtetra
.648 .76 .931 r
.27972 .68752 .28217 .68953 .28591 .68844 .28347 .68642 Mtetra
.28347 .68642 .28591 .68844 .28966 .68735 .28723 .68533 Mtetra
.28723 .68533 .28966 .68735 .29342 .68626 .29098 .68424 Mtetra
.29098 .68424 .29342 .68626 .29718 .68516 .29475 .68314 Mtetra
.29475 .68314 .29718 .68516 .30094 .68407 .29852 .68204 Mtetra
.29852 .68204 .30094 .68407 .30603 .66212 .30229 .68094 Mtetra
0 0 .032 r
.30229 .68094 .30603 .66212 .30978 .66101 .30738 .65896 Mtetra
.65 .758 .928 r
.30738 .65896 .30978 .66101 .31354 .6599 .31114 .65785 Mtetra
.31114 .65785 .31354 .6599 .31731 .65879 .31491 .65674 Mtetra
.31491 .65674 .31731 .65879 .32108 .65768 .31869 .65563 Mtetra
.31869 .65563 .32108 .65768 .32486 .65657 .32247 .65451 Mtetra
.32247 .65451 .32486 .65657 .32864 .65545 .32625 .65339 Mtetra
.32625 .65339 .32864 .65545 .33243 .65434 .33004 .65228 Mtetra
.33004 .65228 .33243 .65434 .33622 .65322 .33384 .65115 Mtetra
.33384 .65115 .33622 .65322 .34002 .6521 .33764 .65003 Mtetra
.33764 .65003 .34002 .6521 .34382 .65098 .34145 .64891 Mtetra
.34145 .64891 .34382 .65098 .34763 .64986 .34526 .64778 Mtetra
.34526 .64778 .34763 .64986 .35145 .64874 .34908 .64666 Mtetra
.34908 .64666 .35145 .64874 .35527 .64761 .3529 .64553 Mtetra
.3529 .64553 .35527 .64761 .35909 .64648 .35673 .6444 Mtetra
.35673 .6444 .35909 .64648 .36292 .64536 .36057 .64327 Mtetra
.36057 .64327 .36292 .64536 .36676 .64423 .36441 .64213 Mtetra
.36441 .64213 .36676 .64423 .3706 .64309 .36825 .641 Mtetra
.36825 .641 .3706 .64309 .37445 .64196 .3721 .63986 Mtetra
.3721 .63986 .37445 .64196 .3783 .64083 .37596 .63873 Mtetra
.37596 .63873 .3783 .64083 .38216 .63969 .37982 .63759 Mtetra
.37982 .63759 .38216 .63969 .38603 .63855 .38369 .63644 Mtetra
.946 .693 .521 r
.38369 .63644 .38603 .63855 .3899 .63741 .39391 .47561 Mtetra
.558 .348 .552 r
.39391 .47561 .3899 .63741 .39982 .47663 .39761 .47441 Mtetra
.663 .742 .909 r
.39761 .47441 .39982 .47663 .40353 .47543 .40132 .47321 Mtetra
.40132 .47321 .40353 .47543 .40724 .47423 .40503 .472 Mtetra
.40503 .472 .40724 .47423 .41079 .47779 .40875 .47079 Mtetra
.622 .518 .715 r
.40875 .47079 .41079 .47779 .41452 .47659 .41248 .46959 Mtetra
.293 .309 .707 r
.41248 .46959 .41452 .47659 .41825 .47538 .41605 .47315 Mtetra
.663 .743 .91 r
.41605 .47315 .41825 .47538 .42199 .47417 .41979 .47194 Mtetra
.41979 .47194 .42199 .47417 .42573 .47297 .42354 .47073 Mtetra
.42354 .47073 .42573 .47297 .42948 .47175 .42729 .46952 Mtetra
.42729 .46952 .42948 .47175 .43323 .47054 .43104 .4683 Mtetra
.43104 .4683 .43323 .47054 .43699 .46933 .4348 .46708 Mtetra
.4348 .46708 .43699 .46933 .44075 .46811 .43857 .46586 Mtetra
.43857 .46586 .44075 .46811 .44452 .4669 .44234 .46464 Mtetra
.44234 .46464 .44452 .4669 .44829 .46568 .44612 .46342 Mtetra
.44612 .46342 .44829 .46568 .45207 .46446 .4499 .4622 Mtetra
.928 .736 .622 r
.4499 .4622 .45207 .46446 .45616 .44891 .454 .44664 Mtetra
.664 .741 .908 r
.454 .44664 .45616 .44891 .45993 .44768 .45778 .44541 Mtetra
.45778 .44541 .45993 .44768 .46371 .44645 .46156 .44417 Mtetra
.46156 .44417 .46371 .44645 .46749 .44522 .46534 .44294 Mtetra
.46534 .44294 .46749 .44522 .47128 .44398 .46914 .4417 Mtetra
.46914 .4417 .47128 .44398 .47508 .44275 .47293 .44046 Mtetra
.47293 .44046 .47508 .44275 .47888 .44151 .47674 .43922 Mtetra
.47674 .43922 .47888 .44151 .48268 .44027 .48055 .43798 Mtetra
.48055 .43798 .48268 .44027 .48649 .43903 .48436 .43673 Mtetra
.48436 .43673 .48649 .43903 .49031 .43779 .48818 .43549 Mtetra
.48818 .43549 .49031 .43779 .49413 .43654 .492 .43424 Mtetra
.492 .43424 .49413 .43654 .49795 .4353 .49583 .43299 Mtetra
.49583 .43299 .49795 .4353 .50179 .43405 .49967 .43174 Mtetra
.49967 .43174 .50179 .43405 .50562 .4328 .50351 .43049 Mtetra
.50351 .43049 .50562 .4328 .50946 .43155 .50735 .42923 Mtetra
.50735 .42923 .50946 .43155 .51331 .43029 .5112 .42798 Mtetra
.5112 .42798 .51331 .43029 .51716 .42904 .51506 .42672 Mtetra
.51506 .42672 .51716 .42904 .52102 .42778 .51892 .42546 Mtetra
.51892 .42546 .52102 .42778 .52489 .42652 .52279 .4242 Mtetra
.52279 .4242 .52489 .42652 .52876 .42526 .52666 .42293 Mtetra
.52666 .42293 .52876 .42526 .53263 .424 .53054 .42167 Mtetra
.53054 .42167 .53263 .424 .53651 .42274 .53442 .4204 Mtetra
.53442 .4204 .53651 .42274 .5404 .42147 .53831 .41913 Mtetra
.53831 .41913 .5404 .42147 .54429 .42021 .54221 .41786 Mtetra
.54221 .41786 .54429 .42021 .54818 .41894 .54611 .41659 Mtetra
.54611 .41659 .54818 .41894 .55209 .41767 .55001 .41532 Mtetra
.55001 .41532 .55209 .41767 .55599 .41639 .55393 .41404 Mtetra
.55393 .41404 .55599 .41639 .55991 .41512 .55784 .41276 Mtetra
.55784 .41276 .55991 .41512 .56383 .41384 .56177 .41148 Mtetra
.56177 .41148 .56383 .41384 .56775 .41257 .56569 .4102 Mtetra
.56569 .4102 .56775 .41257 .57168 .41129 .56963 .40892 Mtetra
.56963 .40892 .57168 .41129 .57562 .41 .57357 .40763 Mtetra
.57357 .40763 .57562 .41 .57956 .40872 .57751 .40635 Mtetra
.57751 .40635 .57956 .40872 .5835 .40743 .58146 .40506 Mtetra
.58146 .40506 .5835 .40743 .58746 .40615 .58542 .40377 Mtetra
.58542 .40377 .58746 .40615 .59141 .40486 .58938 .40247 Mtetra
.58938 .40247 .59141 .40486 .59538 .40357 .59335 .40118 Mtetra
.59335 .40118 .59538 .40357 .59935 .40227 .59732 .39988 Mtetra
.59732 .39988 .59935 .40227 .60332 .40098 .6013 .39859 Mtetra
.6013 .39859 .60332 .40098 .6073 .39968 .60528 .39729 Mtetra
.60528 .39729 .6073 .39968 .61129 .39839 .60927 .39598 Mtetra
.60927 .39598 .61129 .39839 .61528 .39709 .61327 .39468 Mtetra
.61327 .39468 .61528 .39709 .61928 .39578 .61727 .39338 Mtetra
.61727 .39338 .61928 .39578 .62328 .39448 .62128 .39207 Mtetra
.62128 .39207 .62328 .39448 .62729 .39317 .62529 .39076 Mtetra
.62529 .39076 .62729 .39317 .6313 .39187 .62931 .38945 Mtetra
.62931 .38945 .6313 .39187 .63532 .39056 .63333 .38814 Mtetra
.63333 .38814 .63532 .39056 .63935 .38925 .63736 .38682 Mtetra
.63736 .38682 .63935 .38925 .64338 .38793 .6414 .3855 Mtetra
.6414 .3855 .64338 .38793 .64742 .38662 .64544 .38419 Mtetra
.64544 .38419 .64742 .38662 .65146 .3853 .64949 .38286 Mtetra
.64949 .38286 .65146 .3853 .65551 .38398 .65354 .38154 Mtetra
.65354 .38154 .65551 .38398 .65957 .38266 .6576 .38022 Mtetra
.6576 .38022 .65957 .38266 .66363 .38134 .66166 .37889 Mtetra
.66166 .37889 .66363 .38134 .6677 .38001 .66574 .37756 Mtetra
.66574 .37756 .6677 .38001 .67177 .37869 .66981 .37623 Mtetra
.66981 .37623 .67177 .37869 .67585 .37736 .6739 .3749 Mtetra
.6739 .3749 .67585 .37736 .67993 .37603 .67798 .37357 Mtetra
.67798 .37357 .67993 .37603 .68402 .3747 .68208 .37223 Mtetra
.68208 .37223 .68402 .3747 .68812 .37336 .68618 .37089 Mtetra
.68618 .37089 .68812 .37336 .69222 .37203 .69029 .36955 Mtetra
.69029 .36955 .69222 .37203 .69633 .37069 .6944 .36821 Mtetra
.6944 .36821 .69633 .37069 .70045 .36935 .69852 .36687 Mtetra
.69852 .36687 .70045 .36935 .70457 .36801 .70264 .36552 Mtetra
.70264 .36552 .70457 .36801 .71067 .40098 .70677 .36418 Mtetra
.351 .22 .559 r
.70677 .36418 .71067 .40098 .71485 .39964 .71205 .38236 Mtetra
.588 .42 .622 r
.71205 .38236 .71485 .39964 .71903 .39831 .71622 .38102 Mtetra
.71622 .38102 .71903 .39831 .72231 .38216 .72039 .37967 Mtetra
.662 .743 .91 r
.72039 .37967 .72231 .38216 .72649 .38081 .72457 .37832 Mtetra
.72457 .37832 .72649 .38081 .73067 .37946 .72876 .37697 Mtetra
.72876 .37697 .73067 .37946 .73486 .37811 .73295 .37562 Mtetra
.73295 .37562 .73486 .37811 .73905 .37676 .73715 .37426 Mtetra
.73715 .37426 .73905 .37676 .74326 .37541 .74136 .3729 Mtetra
.74136 .3729 .74326 .37541 .74746 .37405 .74557 .37154 Mtetra
.74557 .37154 .74746 .37405 .75168 .37269 .74979 .37018 Mtetra
.74979 .37018 .75168 .37269 .7559 .37133 .75401 .36882 Mtetra
.75401 .36882 .7559 .37133 .76012 .36997 .75824 .36745 Mtetra
.75824 .36745 .76012 .36997 .76436 .36861 .76248 .36609 Mtetra
.76248 .36609 .76436 .36861 .76859 .36724 .76672 .36472 Mtetra
.76672 .36472 .76859 .36724 .77284 .36588 .77097 .36335 Mtetra
.77097 .36335 .77284 .36588 .77709 .36451 .77523 .36197 Mtetra
.77523 .36197 .77709 .36451 .78135 .36313 .77949 .3606 Mtetra
.77949 .3606 .78135 .36313 .78561 .36176 .78376 .35922 Mtetra
.78376 .35922 .78561 .36176 .78988 .36039 .78803 .35784 Mtetra
.78803 .35784 .78988 .36039 .79416 .35901 .79231 .35646 Mtetra
.79231 .35646 .79416 .35901 .79844 .35763 .7966 .35508 Mtetra
.7966 .35508 .79844 .35763 .81073 .44779 .8009 .35369 Mtetra
.561 .355 .559 r
.8009 .35369 .81073 .44779 .81516 .44643 .8052 .3523 Mtetra
.8052 .3523 .81516 .44643 .81959 .44508 .8095 .35091 Mtetra
0 0 .436 r
.8095 .35091 .81959 .44508 .82403 .44372 .82457 .46762 Mtetra
.527 .277 .479 r
.82457 .46762 .82403 .44372 .83143 .4741 .82906 .46627 Mtetra
.618 .515 .715 r
.82906 .46627 .83143 .4741 .83592 .47275 .83356 .46491 Mtetra
.83356 .46491 .83592 .47275 .84043 .47139 .83806 .46355 Mtetra
.83806 .46355 .84043 .47139 .84494 .47004 .84257 .46219 Mtetra
.84257 .46219 .84494 .47004 .84946 .46868 .84709 .46083 Mtetra
.84709 .46083 .84946 .46868 .85399 .46732 .85161 .45946 Mtetra
.85161 .45946 .85399 .46732 .85852 .46596 .85614 .4581 Mtetra
.85614 .4581 .85852 .46596 .86306 .4646 .86068 .45673 Mtetra
.86068 .45673 .86306 .4646 .86761 .46323 .86522 .45535 Mtetra
.86522 .45535 .86761 .46323 .87216 .46187 .86977 .45398 Mtetra
.86977 .45398 .87216 .46187 .87672 .4605 .87433 .45261 Mtetra
.87433 .45261 .87672 .4605 .88129 .45912 .8789 .45123 Mtetra
.8789 .45123 .88129 .45912 .88587 .45775 .88347 .44985 Mtetra
.88347 .44985 .88587 .45775 .89045 .45637 .88805 .44847 Mtetra
.88805 .44847 .89045 .45637 .89504 .45499 .89264 .44708 Mtetra
.89264 .44708 .89504 .45499 .89964 .45361 .89723 .44569 Mtetra
.89723 .44569 .89964 .45361 .90424 .45223 .90184 .44431 Mtetra
.648 .76 .931 r
.27728 .6855 .27972 .68752 .28347 .68642 .28103 .68441 Mtetra
.28103 .68441 .28347 .68642 .28723 .68533 .28478 .68331 Mtetra
.28478 .68331 .28723 .68533 .29098 .68424 .28855 .68221 Mtetra
.28855 .68221 .29098 .68424 .29475 .68314 .29231 .68111 Mtetra
.29231 .68111 .29475 .68314 .29852 .68204 .29609 .68001 Mtetra
.29609 .68001 .29852 .68204 .30229 .68094 .29986 .67891 Mtetra
.29986 .67891 .30229 .68094 .30738 .65896 .30365 .67781 Mtetra
.52 .261 .462 r
.30365 .67781 .30738 .65896 .31114 .65785 .30744 .6767 Mtetra
0 0 .035 r
.30744 .6767 .31114 .65785 .31491 .65674 .31251 .65468 Mtetra
.65 .758 .928 r
.31251 .65468 .31491 .65674 .31869 .65563 .31628 .65357 Mtetra
.31628 .65357 .31869 .65563 .32247 .65451 .32007 .65245 Mtetra
.32007 .65245 .32247 .65451 .32625 .65339 .32386 .65133 Mtetra
.32386 .65133 .32625 .65339 .33004 .65228 .32765 .65021 Mtetra
.32765 .65021 .33004 .65228 .33384 .65115 .33145 .64908 Mtetra
.33145 .64908 .33384 .65115 .33764 .65003 .33526 .64796 Mtetra
.33526 .64796 .33764 .65003 .34145 .64891 .33907 .64683 Mtetra
.33907 .64683 .34145 .64891 .34526 .64778 .34288 .6457 Mtetra
.34288 .6457 .34526 .64778 .34908 .64666 .3467 .64457 Mtetra
.3467 .64457 .34908 .64666 .3529 .64553 .35053 .64344 Mtetra
.35053 .64344 .3529 .64553 .35673 .6444 .35436 .64231 Mtetra
.35436 .64231 .35673 .6444 .36057 .64327 .3582 .64117 Mtetra
.3582 .64117 .36057 .64327 .36441 .64213 .36205 .64004 Mtetra
.36205 .64004 .36441 .64213 .36825 .641 .36589 .6389 Mtetra
.36589 .6389 .36825 .641 .3721 .63986 .36975 .63776 Mtetra
.36975 .63776 .3721 .63986 .37596 .63873 .37361 .63662 Mtetra
.37361 .63662 .37596 .63873 .37982 .63759 .37748 .63548 Mtetra
.946 .693 .522 r
.37748 .63548 .37982 .63759 .38369 .63644 .38798 .4746 Mtetra
.558 .348 .551 r
.38798 .4746 .38369 .63644 .39391 .47561 .39168 .47339 Mtetra
.663 .742 .909 r
.39168 .47339 .39391 .47561 .39761 .47441 .39539 .47219 Mtetra
.39539 .47219 .39761 .47441 .40132 .47321 .3991 .47098 Mtetra
.3991 .47098 .40132 .47321 .40503 .472 .40282 .46977 Mtetra
.40282 .46977 .40503 .472 .40875 .47079 .40654 .46856 Mtetra
.40654 .46856 .40875 .47079 .41248 .46959 .41027 .46735 Mtetra
.41027 .46735 .41248 .46959 .41605 .47315 .414 .46614 Mtetra
.622 .518 .715 r
.414 .46614 .41605 .47315 .41979 .47194 .41774 .46492 Mtetra
.294 .31 .707 r
.41774 .46492 .41979 .47194 .42354 .47073 .42133 .46849 Mtetra
.663 .743 .91 r
.42133 .46849 .42354 .47073 .42729 .46952 .42509 .46727 Mtetra
.42509 .46727 .42729 .46952 .43104 .4683 .42885 .46605 Mtetra
.42885 .46605 .43104 .4683 .4348 .46708 .43261 .46483 Mtetra
.43261 .46483 .4348 .46708 .43857 .46586 .43638 .46361 Mtetra
.43638 .46361 .43857 .46586 .44234 .46464 .44016 .46239 Mtetra
.44016 .46239 .44234 .46464 .44612 .46342 .44394 .46116 Mtetra
.44394 .46116 .44612 .46342 .4499 .4622 .44772 .45993 Mtetra
.928 .736 .622 r
.44772 .45993 .4499 .4622 .454 .44664 .45183 .44436 Mtetra
.664 .741 .908 r
.45183 .44436 .454 .44664 .45778 .44541 .45561 .44313 Mtetra
.45561 .44313 .45778 .44541 .46156 .44417 .4594 .44189 Mtetra
.4594 .44189 .46156 .44417 .46534 .44294 .46319 .44065 Mtetra
.46319 .44065 .46534 .44294 .46914 .4417 .46699 .43941 Mtetra
.46699 .43941 .46914 .4417 .47293 .44046 .47079 .43817 Mtetra
.47079 .43817 .47293 .44046 .47674 .43922 .47459 .43693 Mtetra
.47459 .43693 .47674 .43922 .48055 .43798 .4784 .43568 Mtetra
.4784 .43568 .48055 .43798 .48436 .43673 .48222 .43443 Mtetra
.48222 .43443 .48436 .43673 .48818 .43549 .48604 .43318 Mtetra
.48604 .43318 .48818 .43549 .492 .43424 .48987 .43193 Mtetra
.48987 .43193 .492 .43424 .49583 .43299 .4937 .43068 Mtetra
.4937 .43068 .49583 .43299 .49967 .43174 .49754 .42943 Mtetra
.49754 .42943 .49967 .43174 .50351 .43049 .50139 .42817 Mtetra
.50139 .42817 .50351 .43049 .50735 .42923 .50524 .42691 Mtetra
.50524 .42691 .50735 .42923 .5112 .42798 .50909 .42565 Mtetra
.50909 .42565 .5112 .42798 .51506 .42672 .51295 .42439 Mtetra
.51295 .42439 .51506 .42672 .51892 .42546 .51682 .42313 Mtetra
.51682 .42313 .51892 .42546 .52279 .4242 .52069 .42186 Mtetra
.52069 .42186 .52279 .4242 .52666 .42293 .52456 .4206 Mtetra
.52456 .4206 .52666 .42293 .53054 .42167 .52845 .41933 Mtetra
.52845 .41933 .53054 .42167 .53442 .4204 .53233 .41806 Mtetra
.53233 .41806 .53442 .4204 .53831 .41913 .53623 .41679 Mtetra
.53623 .41679 .53831 .41913 .54221 .41786 .54012 .41551 Mtetra
.54012 .41551 .54221 .41786 .54611 .41659 .54403 .41424 Mtetra
.54403 .41424 .54611 .41659 .55001 .41532 .54794 .41296 Mtetra
.54794 .41296 .55001 .41532 .55393 .41404 .55185 .41168 Mtetra
.55185 .41168 .55393 .41404 .55784 .41276 .55577 .4104 Mtetra
.55577 .4104 .55784 .41276 .56177 .41148 .5597 .40912 Mtetra
.5597 .40912 .56177 .41148 .56569 .4102 .56363 .40783 Mtetra
.56363 .40783 .56569 .4102 .56963 .40892 .56757 .40654 Mtetra
.56757 .40654 .56963 .40892 .57357 .40763 .57151 .40526 Mtetra
.57151 .40526 .57357 .40763 .57751 .40635 .57546 .40396 Mtetra
.57546 .40396 .57751 .40635 .58146 .40506 .57941 .40267 Mtetra
.57941 .40267 .58146 .40506 .58542 .40377 .58337 .40138 Mtetra
.58337 .40138 .58542 .40377 .58938 .40247 .58734 .40008 Mtetra
.58734 .40008 .58938 .40247 .59335 .40118 .59131 .39879 Mtetra
.59131 .39879 .59335 .40118 .59732 .39988 .59529 .39749 Mtetra
.59529 .39749 .59732 .39988 .6013 .39859 .59927 .39618 Mtetra
.59927 .39618 .6013 .39859 .60528 .39729 .60326 .39488 Mtetra
.60326 .39488 .60528 .39729 .60927 .39598 .60725 .39358 Mtetra
.60725 .39358 .60927 .39598 .61327 .39468 .61125 .39227 Mtetra
.61125 .39227 .61327 .39468 .61727 .39338 .61525 .39096 Mtetra
.61525 .39096 .61727 .39338 .62128 .39207 .61927 .38965 Mtetra
.61927 .38965 .62128 .39207 .62529 .39076 .62328 .38834 Mtetra
.62328 .38834 .62529 .39076 .62931 .38945 .6273 .38702 Mtetra
.6273 .38702 .62931 .38945 .63333 .38814 .63133 .38571 Mtetra
.63133 .38571 .63333 .38814 .63736 .38682 .63537 .38439 Mtetra
.63537 .38439 .63736 .38682 .6414 .3855 .63941 .38307 Mtetra
.63941 .38307 .6414 .3855 .64544 .38419 .64345 .38175 Mtetra
.64345 .38175 .64544 .38419 .64949 .38286 .6475 .38042 Mtetra
.6475 .38042 .64949 .38286 .65354 .38154 .65156 .3791 Mtetra
.65156 .3791 .65354 .38154 .6576 .38022 .65563 .37777 Mtetra
.65563 .37777 .6576 .38022 .66166 .37889 .65969 .37644 Mtetra
.65969 .37644 .66166 .37889 .66574 .37756 .66377 .37511 Mtetra
.66377 .37511 .66574 .37756 .66981 .37623 .66785 .37377 Mtetra
.66785 .37377 .66981 .37623 .6739 .3749 .67194 .37244 Mtetra
.67194 .37244 .6739 .3749 .67798 .37357 .67603 .3711 Mtetra
.67603 .3711 .67798 .37357 .68208 .37223 .68013 .36976 Mtetra
.68013 .36976 .68208 .37223 .68618 .37089 .68423 .36842 Mtetra
.68423 .36842 .68618 .37089 .69029 .36955 .68834 .36708 Mtetra
.68834 .36708 .69029 .36955 .6944 .36821 .69246 .36573 Mtetra
.69246 .36573 .6944 .36821 .69852 .36687 .69658 .36438 Mtetra
.69658 .36438 .69852 .36687 .70264 .36552 .70071 .36303 Mtetra
.70071 .36303 .70264 .36552 .70677 .36418 .70485 .36168 Mtetra
.925 .547 .147 r
.70485 .36168 .70677 .36418 .71205 .38236 .71012 .37988 Mtetra
.662 .743 .91 r
.71012 .37988 .71205 .38236 .71622 .38102 .71429 .37853 Mtetra
.71429 .37853 .71622 .38102 .72039 .37967 .71847 .37718 Mtetra
.71847 .37718 .72039 .37967 .72457 .37832 .72266 .37582 Mtetra
.72266 .37582 .72457 .37832 .72876 .37697 .72685 .37447 Mtetra
.72685 .37447 .72876 .37697 .73295 .37562 .73104 .37311 Mtetra
.73104 .37311 .73295 .37562 .73715 .37426 .73525 .37175 Mtetra
.73525 .37175 .73715 .37426 .74136 .3729 .73946 .37039 Mtetra
.73946 .37039 .74136 .3729 .74557 .37154 .74367 .36903 Mtetra
.74367 .36903 .74557 .37154 .74979 .37018 .7479 .36766 Mtetra
.7479 .36766 .74979 .37018 .75401 .36882 .75213 .3663 Mtetra
.75213 .3663 .75401 .36882 .75824 .36745 .75636 .36493 Mtetra
.75636 .36493 .75824 .36745 .76248 .36609 .7606 .36356 Mtetra
.7606 .36356 .76248 .36609 .76672 .36472 .76485 .36218 Mtetra
.76485 .36218 .76672 .36472 .77097 .36335 .7691 .36081 Mtetra
.7691 .36081 .77097 .36335 .77523 .36197 .77336 .35943 Mtetra
.77336 .35943 .77523 .36197 .77949 .3606 .77763 .35805 Mtetra
.77763 .35805 .77949 .3606 .78376 .35922 .7819 .35667 Mtetra
.7819 .35667 .78376 .35922 .78803 .35784 .78618 .35529 Mtetra
.78618 .35529 .78803 .35784 .79231 .35646 .79047 .3539 Mtetra
.79047 .3539 .79231 .35646 .7966 .35508 .79476 .35252 Mtetra
.79476 .35252 .7966 .35508 .8009 .35369 .79906 .35113 Mtetra
.79906 .35113 .8009 .35369 .8052 .3523 .80336 .34973 Mtetra
.80336 .34973 .8052 .3523 .8095 .35091 .80767 .34834 Mtetra
.97 .651 .305 r
.80767 .34834 .8095 .35091 .82457 .46762 .82269 .46512 Mtetra
.653 .754 .924 r
.82269 .46512 .82457 .46762 .82906 .46627 .82719 .46376 Mtetra
.82719 .46376 .82906 .46627 .83356 .46491 .83169 .4624 Mtetra
.83169 .4624 .83356 .46491 .83806 .46355 .8362 .46104 Mtetra
.8362 .46104 .83806 .46355 .84257 .46219 .84071 .45967 Mtetra
.84071 .45967 .84257 .46219 .84709 .46083 .84523 .45831 Mtetra
.84523 .45831 .84709 .46083 .85161 .45946 .84976 .45694 Mtetra
.84976 .45694 .85161 .45946 .85614 .4581 .8543 .45557 Mtetra
.8543 .45557 .85614 .4581 .86068 .45673 .85884 .45419 Mtetra
.85884 .45419 .86068 .45673 .86522 .45535 .86339 .45282 Mtetra
.86339 .45282 .86522 .45535 .86977 .45398 .86795 .45144 Mtetra
.86795 .45144 .86977 .45398 .87433 .45261 .87251 .45006 Mtetra
.87251 .45006 .87433 .45261 .8789 .45123 .87708 .44868 Mtetra
.87708 .44868 .8789 .45123 .88347 .44985 .88166 .44729 Mtetra
.88166 .44729 .88347 .44985 .88805 .44847 .88624 .44591 Mtetra
.88624 .44591 .88805 .44847 .89264 .44708 .89084 .44452 Mtetra
.89084 .44452 .89264 .44708 .89723 .44569 .89544 .44313 Mtetra
.89544 .44313 .89723 .44569 .90184 .44431 .90004 .44174 Mtetra
.648 .76 .931 r
.27482 .68348 .27728 .6855 .28103 .68441 .27857 .68238 Mtetra
.27857 .68238 .28103 .68441 .28478 .68331 .28233 .68128 Mtetra
.28233 .68128 .28478 .68331 .28855 .68221 .2861 .68018 Mtetra
.2861 .68018 .28855 .68221 .29231 .68111 .28987 .67908 Mtetra
.28987 .67908 .29231 .68111 .29609 .68001 .29365 .67798 Mtetra
.29365 .67798 .29609 .68001 .29986 .67891 .29743 .67687 Mtetra
.29743 .67687 .29986 .67891 .30365 .67781 .30121 .67576 Mtetra
.30121 .67576 .30365 .67781 .30744 .6767 .30501 .67466 Mtetra
.30501 .67466 .30744 .6767 .31251 .65468 .3088 .67355 Mtetra
0 0 .035 r
.3088 .67355 .31251 .65468 .31628 .65357 .31388 .6515 Mtetra
.65 .758 .928 r
.31388 .6515 .31628 .65357 .32007 .65245 .31766 .65038 Mtetra
.31766 .65038 .32007 .65245 .32386 .65133 .32146 .64926 Mtetra
.32146 .64926 .32386 .65133 .32765 .65021 .32525 .64813 Mtetra
.32525 .64813 .32765 .65021 .33145 .64908 .32906 .647 Mtetra
.32906 .647 .33145 .64908 .33526 .64796 .33287 .64588 Mtetra
.33287 .64588 .33526 .64796 .33907 .64683 .33668 .64475 Mtetra
.33668 .64475 .33907 .64683 .34288 .6457 .3405 .64362 Mtetra
.3405 .64362 .34288 .6457 .3467 .64457 .34432 .64248 Mtetra
.34432 .64248 .3467 .64457 .35053 .64344 .34815 .64135 Mtetra
.34815 .64135 .35053 .64344 .35436 .64231 .35199 .64021 Mtetra
.35199 .64021 .35436 .64231 .3582 .64117 .35583 .63908 Mtetra
.35583 .63908 .3582 .64117 .36205 .64004 .35968 .63794 Mtetra
.35968 .63794 .36205 .64004 .36589 .6389 .36353 .6368 Mtetra
.36353 .6368 .36589 .6389 .36975 .63776 .36739 .63565 Mtetra
.36739 .63565 .36975 .63776 .37361 .63662 .37125 .63451 Mtetra
.946 .693 .523 r
.37125 .63451 .37361 .63662 .37748 .63548 .38205 .47358 Mtetra
.558 .347 .551 r
.38205 .47358 .37748 .63548 .38798 .4746 .38575 .47237 Mtetra
.663 .742 .909 r
.38575 .47237 .38798 .4746 .39168 .47339 .38945 .47117 Mtetra
.38945 .47117 .39168 .47339 .39539 .47219 .39316 .46996 Mtetra
.39316 .46996 .39539 .47219 .3991 .47098 .39688 .46875 Mtetra
.39688 .46875 .3991 .47098 .40282 .46977 .4006 .46754 Mtetra
.4006 .46754 .40282 .46977 .40654 .46856 .40433 .46632 Mtetra
.40433 .46632 .40654 .46856 .41027 .46735 .40806 .46511 Mtetra
.40806 .46511 .41027 .46735 .414 .46614 .41179 .46389 Mtetra
.41179 .46389 .414 .46614 .41774 .46492 .41553 .46267 Mtetra
.41553 .46267 .41774 .46492 .42133 .46849 .41928 .46145 Mtetra
.621 .518 .715 r
.41928 .46145 .42133 .46849 .42509 .46727 .42303 .46023 Mtetra
.295 .311 .707 r
.42303 .46023 .42509 .46727 .42885 .46605 .42665 .4638 Mtetra
.663 .743 .91 r
.42665 .4638 .42885 .46605 .43261 .46483 .43042 .46257 Mtetra
.43042 .46257 .43261 .46483 .43638 .46361 .43419 .46135 Mtetra
.43419 .46135 .43638 .46361 .44016 .46239 .43797 .46012 Mtetra
.43797 .46012 .44016 .46239 .44394 .46116 .44175 .45889 Mtetra
.928 .736 .623 r
.44175 .45889 .44394 .46116 .44772 .45993 .44589 .44332 Mtetra
.587 .42 .622 r
.44589 .44332 .44772 .45993 .45183 .44436 .44966 .44208 Mtetra
.664 .741 .908 r
.44966 .44208 .45183 .44436 .45561 .44313 .45345 .44084 Mtetra
.45345 .44084 .45561 .44313 .4594 .44189 .45724 .4396 Mtetra
.45724 .4396 .4594 .44189 .46319 .44065 .46103 .43836 Mtetra
.46103 .43836 .46319 .44065 .46699 .43941 .46483 .43712 Mtetra
.46483 .43712 .46699 .43941 .47079 .43817 .46863 .43587 Mtetra
.46863 .43587 .47079 .43817 .47459 .43693 .47244 .43462 Mtetra
.47244 .43462 .47459 .43693 .4784 .43568 .47626 .43338 Mtetra
.47626 .43338 .4784 .43568 .48222 .43443 .48008 .43213 Mtetra
.48008 .43213 .48222 .43443 .48604 .43318 .4839 .43087 Mtetra
.4839 .43087 .48604 .43318 .48987 .43193 .48774 .42962 Mtetra
.48774 .42962 .48987 .43193 .4937 .43068 .49157 .42836 Mtetra
.49157 .42836 .4937 .43068 .49754 .42943 .49541 .42711 Mtetra
.49541 .42711 .49754 .42943 .50139 .42817 .49926 .42585 Mtetra
.49926 .42585 .50139 .42817 .50524 .42691 .50311 .42459 Mtetra
.50311 .42459 .50524 .42691 .50909 .42565 .50697 .42332 Mtetra
.50697 .42332 .50909 .42565 .51295 .42439 .51084 .42206 Mtetra
.51084 .42206 .51295 .42439 .51682 .42313 .5147 .42079 Mtetra
.5147 .42079 .51682 .42313 .52069 .42186 .51858 .41952 Mtetra
.51858 .41952 .52069 .42186 .52456 .4206 .52246 .41825 Mtetra
.52246 .41825 .52456 .4206 .52845 .41933 .52634 .41698 Mtetra
.52634 .41698 .52845 .41933 .53233 .41806 .53024 .41571 Mtetra
.53024 .41571 .53233 .41806 .53623 .41679 .53413 .41443 Mtetra
.53413 .41443 .53623 .41679 .54012 .41551 .53803 .41316 Mtetra
.53803 .41316 .54012 .41551 .54403 .41424 .54194 .41188 Mtetra
.54194 .41188 .54403 .41424 .54794 .41296 .54585 .4106 Mtetra
.54585 .4106 .54794 .41296 .55185 .41168 .54977 .40931 Mtetra
.54977 .40931 .55185 .41168 .55577 .4104 .5537 .40803 Mtetra
.5537 .40803 .55577 .4104 .5597 .40912 .55763 .40674 Mtetra
.55763 .40674 .5597 .40912 .56363 .40783 .56156 .40545 Mtetra
.56156 .40545 .56363 .40783 .56757 .40654 .5655 .40416 Mtetra
.5655 .40416 .56757 .40654 .57151 .40526 .56945 .40287 Mtetra
.56945 .40287 .57151 .40526 .57546 .40396 .5734 .40158 Mtetra
.5734 .40158 .57546 .40396 .57941 .40267 .57736 .40028 Mtetra
.57736 .40028 .57941 .40267 .58337 .40138 .58132 .39899 Mtetra
.58132 .39899 .58337 .40138 .58734 .40008 .58529 .39769 Mtetra
.58529 .39769 .58734 .40008 .59131 .39879 .58927 .39638 Mtetra
.58927 .39638 .59131 .39879 .59529 .39749 .59325 .39508 Mtetra
.59325 .39508 .59529 .39749 .59927 .39618 .59723 .39378 Mtetra
.59723 .39378 .59927 .39618 .60326 .39488 .60123 .39247 Mtetra
.60123 .39247 .60326 .39488 .60725 .39358 .60522 .39116 Mtetra
.60522 .39116 .60725 .39358 .61125 .39227 .60923 .38985 Mtetra
.60923 .38985 .61125 .39227 .61525 .39096 .61324 .38854 Mtetra
.61324 .38854 .61525 .39096 .61927 .38965 .61725 .38723 Mtetra
.61725 .38723 .61927 .38965 .62328 .38834 .62127 .38591 Mtetra
.62127 .38591 .62328 .38834 .6273 .38702 .6253 .38459 Mtetra
.6253 .38459 .6273 .38702 .63133 .38571 .62933 .38327 Mtetra
.62933 .38327 .63133 .38571 .63537 .38439 .63337 .38195 Mtetra
.63337 .38195 .63537 .38439 .63941 .38307 .63741 .38063 Mtetra
.63741 .38063 .63941 .38307 .64345 .38175 .64146 .3793 Mtetra
.64146 .3793 .64345 .38175 .6475 .38042 .64552 .37797 Mtetra
.64552 .37797 .6475 .38042 .65156 .3791 .64958 .37664 Mtetra
.64958 .37664 .65156 .3791 .65563 .37777 .65365 .37531 Mtetra
.65365 .37531 .65563 .37777 .65969 .37644 .65772 .37398 Mtetra
.65772 .37398 .65969 .37644 .66377 .37511 .6618 .37264 Mtetra
.6618 .37264 .66377 .37511 .66785 .37377 .66588 .37131 Mtetra
.66588 .37131 .66785 .37377 .67194 .37244 .66997 .36997 Mtetra
.66997 .36997 .67194 .37244 .67603 .3711 .67407 .36863 Mtetra
.67407 .36863 .67603 .3711 .68013 .36976 .67817 .36728 Mtetra
.67817 .36728 .68013 .36976 .68423 .36842 .68228 .36594 Mtetra
.68228 .36594 .68423 .36842 .68834 .36708 .6864 .36459 Mtetra
.6864 .36459 .68834 .36708 .69246 .36573 .69052 .36324 Mtetra
.69052 .36324 .69246 .36573 .69658 .36438 .69464 .36189 Mtetra
.69464 .36189 .69658 .36438 .70071 .36303 .69878 .36054 Mtetra
.69878 .36054 .70071 .36303 .70485 .36168 .70292 .35918 Mtetra
.925 .547 .147 r
.70292 .35918 .70485 .36168 .71012 .37988 .70818 .37739 Mtetra
.662 .743 .91 r
.70818 .37739 .71012 .37988 .71429 .37853 .71236 .37603 Mtetra
.71236 .37603 .71429 .37853 .71847 .37718 .71654 .37468 Mtetra
.71654 .37468 .71847 .37718 .72266 .37582 .72073 .37332 Mtetra
.72073 .37332 .72266 .37582 .72685 .37447 .72493 .37196 Mtetra
.72493 .37196 .72685 .37447 .73104 .37311 .72913 .3706 Mtetra
.72913 .3706 .73104 .37311 .73525 .37175 .73334 .36924 Mtetra
.73334 .36924 .73525 .37175 .73946 .37039 .73755 .36787 Mtetra
.73755 .36787 .73946 .37039 .74367 .36903 .74177 .36651 Mtetra
.74177 .36651 .74367 .36903 .7479 .36766 .746 .36514 Mtetra
.746 .36514 .7479 .36766 .75213 .3663 .75023 .36377 Mtetra
.75023 .36377 .75213 .3663 .75636 .36493 .75447 .3624 Mtetra
.75447 .3624 .75636 .36493 .7606 .36356 .75872 .36102 Mtetra
.75872 .36102 .7606 .36356 .76485 .36218 .76297 .35964 Mtetra
.76297 .35964 .76485 .36218 .7691 .36081 .76723 .35826 Mtetra
.76723 .35826 .7691 .36081 .77336 .35943 .77149 .35688 Mtetra
.77149 .35688 .77336 .35943 .77763 .35805 .77576 .3555 Mtetra
.77576 .3555 .77763 .35805 .7819 .35667 .78004 .35412 Mtetra
.78004 .35412 .7819 .35667 .78618 .35529 .78432 .35273 Mtetra
.78432 .35273 .78618 .35529 .79047 .3539 .78861 .35134 Mtetra
.78861 .35134 .79047 .3539 .79476 .35252 .79291 .34995 Mtetra
.79291 .34995 .79476 .35252 .79906 .35113 .79721 .34855 Mtetra
.79721 .34855 .79906 .35113 .80336 .34973 .80152 .34716 Mtetra
.97 .652 .307 r
.80152 .34716 .80336 .34973 .80767 .34834 .81632 .46397 Mtetra
.548 .326 .529 r
.81632 .46397 .80767 .34834 .82269 .46512 .82081 .46261 Mtetra
.653 .754 .924 r
.82081 .46261 .82269 .46512 .82719 .46376 .82531 .46125 Mtetra
.82531 .46125 .82719 .46376 .83169 .4624 .82981 .45988 Mtetra
.82981 .45988 .83169 .4624 .8362 .46104 .83433 .45852 Mtetra
.83433 .45852 .8362 .46104 .84071 .45967 .83885 .45715 Mtetra
.83885 .45715 .84071 .45967 .84523 .45831 .84337 .45578 Mtetra
.84337 .45578 .84523 .45831 .84976 .45694 .84791 .4544 Mtetra
.84791 .4544 .84976 .45694 .8543 .45557 .85245 .45303 Mtetra
.85245 .45303 .8543 .45557 .85884 .45419 .85699 .45165 Mtetra
.85699 .45165 .85884 .45419 .86339 .45282 .86155 .45027 Mtetra
.86155 .45027 .86339 .45282 .86795 .45144 .86611 .44889 Mtetra
.86611 .44889 .86795 .45144 .87251 .45006 .87068 .44751 Mtetra
.87068 .44751 .87251 .45006 .87708 .44868 .87526 .44612 Mtetra
.87526 .44612 .87708 .44868 .88166 .44729 .87984 .44473 Mtetra
.87984 .44473 .88166 .44729 .88624 .44591 .88443 .44334 Mtetra
.88443 .44334 .88624 .44591 .89084 .44452 .88903 .44195 Mtetra
.88903 .44195 .89084 .44452 .89544 .44313 .89363 .44056 Mtetra
.89363 .44056 .89544 .44313 .90004 .44174 .89825 .43916 Mtetra
.648 .76 .931 r
.27236 .68145 .27482 .68348 .27857 .68238 .27612 .68035 Mtetra
.27612 .68035 .27857 .68238 .28233 .68128 .27988 .67925 Mtetra
.27988 .67925 .28233 .68128 .2861 .68018 .28365 .67815 Mtetra
.28365 .67815 .2861 .68018 .28987 .67908 .28742 .67704 Mtetra
.28742 .67704 .28987 .67908 .29365 .67798 .2912 .67594 Mtetra
.2912 .67594 .29365 .67798 .29743 .67687 .29498 .67483 Mtetra
.29498 .67483 .29743 .67687 .30121 .67576 .29877 .67372 Mtetra
.29877 .67372 .30121 .67576 .30501 .67466 .30257 .67261 Mtetra
.30257 .67261 .30501 .67466 .3088 .67355 .30637 .67149 Mtetra
.30637 .67149 .3088 .67355 .31388 .6515 .31018 .67038 Mtetra
.519 .259 .461 r
.31018 .67038 .31388 .6515 .31766 .65038 .31399 .66926 Mtetra
0 0 .039 r
.31399 .66926 .31766 .65038 .32146 .64926 .31905 .64718 Mtetra
.65 .758 .928 r
.31905 .64718 .32146 .64926 .32525 .64813 .32285 .64605 Mtetra
.32285 .64605 .32525 .64813 .32906 .647 .32666 .64492 Mtetra
.32666 .64492 .32906 .647 .33287 .64588 .33047 .64379 Mtetra
.33047 .64379 .33287 .64588 .33668 .64475 .33429 .64266 Mtetra
.33429 .64266 .33668 .64475 .3405 .64362 .33811 .64152 Mtetra
.33811 .64152 .3405 .64362 .34432 .64248 .34194 .64039 Mtetra
.34194 .64039 .34432 .64248 .34815 .64135 .34577 .63925 Mtetra
.34577 .63925 .34815 .64135 .35199 .64021 .34961 .63811 Mtetra
.34961 .63811 .35199 .64021 .35583 .63908 .35345 .63697 Mtetra
.35345 .63697 .35583 .63908 .35968 .63794 .35731 .63583 Mtetra
.35731 .63583 .35968 .63794 .36353 .6368 .36116 .63468 Mtetra
.36116 .63468 .36353 .6368 .36739 .63565 .36502 .63354 Mtetra
.945 .692 .524 r
.36502 .63354 .36739 .63565 .37125 .63451 .37611 .47256 Mtetra
.557 .347 .551 r
.37611 .47256 .37125 .63451 .38205 .47358 .37981 .47135 Mtetra
.663 .742 .909 r
.37981 .47135 .38205 .47358 .38575 .47237 .38351 .47014 Mtetra
.38351 .47014 .38575 .47237 .38945 .47117 .38722 .46893 Mtetra
.38722 .46893 .38945 .47117 .39316 .46996 .39093 .46772 Mtetra
.39093 .46772 .39316 .46996 .39688 .46875 .39465 .46651 Mtetra
.39465 .46651 .39688 .46875 .4006 .46754 .39837 .4653 Mtetra
.39837 .4653 .4006 .46754 .40433 .46632 .4021 .46408 Mtetra
.4021 .46408 .40433 .46632 .40806 .46511 .40584 .46286 Mtetra
.40584 .46286 .40806 .46511 .41179 .46389 .40958 .46164 Mtetra
.40958 .46164 .41179 .46389 .41553 .46267 .41332 .46042 Mtetra
.41332 .46042 .41553 .46267 .41928 .46145 .41707 .4592 Mtetra
.41707 .4592 .41928 .46145 .42303 .46023 .42083 .45797 Mtetra
.42083 .45797 .42303 .46023 .42665 .4638 .42459 .45675 Mtetra
.621 .517 .715 r
.42459 .45675 .42665 .4638 .43042 .46257 .42835 .45552 Mtetra
.42835 .45552 .43042 .46257 .43419 .46135 .43213 .45429 Mtetra
.297 .312 .707 r
.43213 .45429 .43419 .46135 .43797 .46012 .43577 .45785 Mtetra
.663 .743 .91 r
.43577 .45785 .43797 .46012 .44175 .45889 .43956 .45662 Mtetra
.928 .736 .623 r
.43956 .45662 .44175 .45889 .44589 .44332 .44371 .44103 Mtetra
.664 .741 .908 r
.44371 .44103 .44589 .44332 .44966 .44208 .44749 .43979 Mtetra
.44749 .43979 .44966 .44208 .45345 .44084 .45128 .43855 Mtetra
.45128 .43855 .45345 .44084 .45724 .4396 .45507 .43731 Mtetra
.45507 .43731 .45724 .4396 .46103 .43836 .45886 .43606 Mtetra
.45886 .43606 .46103 .43836 .46483 .43712 .46267 .43482 Mtetra
.46267 .43482 .46483 .43712 .46863 .43587 .46647 .43357 Mtetra
.46647 .43357 .46863 .43587 .47244 .43462 .47029 .43232 Mtetra
.47029 .43232 .47244 .43462 .47626 .43338 .47411 .43107 Mtetra
.47411 .43107 .47626 .43338 .48008 .43213 .47793 .42981 Mtetra
.47793 .42981 .48008 .43213 .4839 .43087 .48176 .42856 Mtetra
.48176 .42856 .4839 .43087 .48774 .42962 .48559 .4273 Mtetra
.48559 .4273 .48774 .42962 .49157 .42836 .48943 .42604 Mtetra
.48943 .42604 .49157 .42836 .49541 .42711 .49328 .42478 Mtetra
.49328 .42478 .49541 .42711 .49926 .42585 .49713 .42352 Mtetra
.49713 .42352 .49926 .42585 .50311 .42459 .50099 .42225 Mtetra
.50099 .42225 .50311 .42459 .50697 .42332 .50485 .42099 Mtetra
.50485 .42099 .50697 .42332 .51084 .42206 .50872 .41972 Mtetra
.50872 .41972 .51084 .42206 .5147 .42079 .51259 .41845 Mtetra
.51259 .41845 .5147 .42079 .51858 .41952 .51647 .41718 Mtetra
.51647 .41718 .51858 .41952 .52246 .41825 .52035 .4159 Mtetra
.52035 .4159 .52246 .41825 .52634 .41698 .52424 .41463 Mtetra
.52424 .41463 .52634 .41698 .53024 .41571 .52813 .41335 Mtetra
.52813 .41335 .53024 .41571 .53413 .41443 .53203 .41207 Mtetra
.53203 .41207 .53413 .41443 .53803 .41316 .53594 .41079 Mtetra
.53594 .41079 .53803 .41316 .54194 .41188 .53985 .40951 Mtetra
.53985 .40951 .54194 .41188 .54585 .4106 .54377 .40823 Mtetra
.54377 .40823 .54585 .4106 .54977 .40931 .54769 .40694 Mtetra
.54769 .40694 .54977 .40931 .5537 .40803 .55162 .40565 Mtetra
.55162 .40565 .5537 .40803 .55763 .40674 .55555 .40436 Mtetra
.55555 .40436 .55763 .40674 .56156 .40545 .55949 .40307 Mtetra
.55949 .40307 .56156 .40545 .5655 .40416 .56343 .40178 Mtetra
.56343 .40178 .5655 .40416 .56945 .40287 .56738 .40048 Mtetra
.56738 .40048 .56945 .40287 .5734 .40158 .57134 .39918 Mtetra
.57134 .39918 .5734 .40158 .57736 .40028 .5753 .39789 Mtetra
.5753 .39789 .57736 .40028 .58132 .39899 .57927 .39659 Mtetra
.57927 .39659 .58132 .39899 .58529 .39769 .58324 .39528 Mtetra
.58324 .39528 .58529 .39769 .58927 .39638 .58722 .39398 Mtetra
.58722 .39398 .58927 .39638 .59325 .39508 .5912 .39267 Mtetra
.5912 .39267 .59325 .39508 .59723 .39378 .59519 .39136 Mtetra
.59519 .39136 .59723 .39378 .60123 .39247 .59919 .39005 Mtetra
.59919 .39005 .60123 .39247 .60522 .39116 .60319 .38874 Mtetra
.60319 .38874 .60522 .39116 .60923 .38985 .6072 .38743 Mtetra
.6072 .38743 .60923 .38985 .61324 .38854 .61121 .38611 Mtetra
.61121 .38611 .61324 .38854 .61725 .38723 .61523 .38479 Mtetra
.61523 .38479 .61725 .38723 .62127 .38591 .61925 .38347 Mtetra
.61925 .38347 .62127 .38591 .6253 .38459 .62328 .38215 Mtetra
.62328 .38215 .6253 .38459 .62933 .38327 .62732 .38083 Mtetra
.62732 .38083 .62933 .38327 .63337 .38195 .63136 .3795 Mtetra
.63136 .3795 .63337 .38195 .63741 .38063 .63541 .37818 Mtetra
.63541 .37818 .63741 .38063 .64146 .3793 .63946 .37685 Mtetra
.63946 .37685 .64146 .3793 .64552 .37797 .64352 .37552 Mtetra
.64352 .37552 .64552 .37797 .64958 .37664 .64759 .37418 Mtetra
.64759 .37418 .64958 .37664 .65365 .37531 .65166 .37285 Mtetra
.65166 .37285 .65365 .37531 .65772 .37398 .65574 .37151 Mtetra
.65574 .37151 .65772 .37398 .6618 .37264 .65982 .37017 Mtetra
.65982 .37017 .6618 .37264 .66588 .37131 .66391 .36883 Mtetra
.66391 .36883 .66588 .37131 .66997 .36997 .668 .36749 Mtetra
.668 .36749 .66997 .36997 .67407 .36863 .67211 .36615 Mtetra
.67211 .36615 .67407 .36863 .67817 .36728 .67621 .3648 Mtetra
.67621 .3648 .67817 .36728 .68228 .36594 .68033 .36345 Mtetra
.68033 .36345 .68228 .36594 .6864 .36459 .68444 .3621 Mtetra
.68444 .3621 .6864 .36459 .69052 .36324 .68857 .36075 Mtetra
.68857 .36075 .69052 .36324 .69464 .36189 .6927 .35939 Mtetra
.6927 .35939 .69464 .36189 .69878 .36054 .69684 .35804 Mtetra
.69684 .35804 .69878 .36054 .70292 .35918 .70098 .35668 Mtetra
.925 .547 .147 r
.70098 .35668 .70292 .35918 .70818 .37739 .70624 .37489 Mtetra
.662 .743 .91 r
.70624 .37489 .70818 .37739 .71236 .37603 .71042 .37353 Mtetra
.71042 .37353 .71236 .37603 .71654 .37468 .71461 .37217 Mtetra
.71461 .37217 .71654 .37468 .72073 .37332 .7188 .37081 Mtetra
.7188 .37081 .72073 .37332 .72493 .37196 .723 .36945 Mtetra
.723 .36945 .72493 .37196 .72913 .3706 .72721 .36808 Mtetra
.72721 .36808 .72913 .3706 .73334 .36924 .73142 .36672 Mtetra
.73142 .36672 .73334 .36924 .73755 .36787 .73564 .36535 Mtetra
.73564 .36535 .73755 .36787 .74177 .36651 .73986 .36398 Mtetra
.73986 .36398 .74177 .36651 .746 .36514 .74409 .36261 Mtetra
.74409 .36261 .746 .36514 .75023 .36377 .74833 .36123 Mtetra
.74833 .36123 .75023 .36377 .75447 .3624 .75258 .35986 Mtetra
.75258 .35986 .75447 .3624 .75872 .36102 .75683 .35848 Mtetra
.75683 .35848 .75872 .36102 .76297 .35964 .76108 .3571 Mtetra
.76108 .3571 .76297 .35964 .76723 .35826 .76534 .35571 Mtetra
.76534 .35571 .76723 .35826 .77149 .35688 .76961 .35433 Mtetra
.76961 .35433 .77149 .35688 .77576 .3555 .77389 .35294 Mtetra
.77389 .35294 .77576 .3555 .78004 .35412 .77817 .35155 Mtetra
.77817 .35155 .78004 .35412 .78432 .35273 .78246 .35016 Mtetra
.78246 .35016 .78432 .35273 .78861 .35134 .78675 .34877 Mtetra
.78675 .34877 .78861 .35134 .79291 .34995 .79105 .34737 Mtetra
.79105 .34737 .79291 .34995 .79721 .34855 .79536 .34598 Mtetra
.79536 .34598 .79721 .34855 .80152 .34716 .79968 .34458 Mtetra
.97 .652 .307 r
.79968 .34458 .80152 .34716 .81632 .46397 .81442 .46146 Mtetra
.653 .754 .924 r
.81442 .46146 .81632 .46397 .82081 .46261 .81892 .46009 Mtetra
.81892 .46009 .82081 .46261 .82531 .46125 .82342 .45873 Mtetra
.82342 .45873 .82531 .46125 .82981 .45988 .82793 .45736 Mtetra
.82793 .45736 .82981 .45988 .83433 .45852 .83245 .45599 Mtetra
.83245 .45599 .83433 .45852 .83885 .45715 .83698 .45462 Mtetra
.83698 .45462 .83885 .45715 .84337 .45578 .84151 .45324 Mtetra
.84151 .45324 .84337 .45578 .84791 .4544 .84605 .45186 Mtetra
.84605 .45186 .84791 .4544 .85245 .45303 .85059 .45048 Mtetra
.85059 .45048 .85245 .45303 .85699 .45165 .85515 .4491 Mtetra
.85515 .4491 .85699 .45165 .86155 .45027 .85971 .44772 Mtetra
.85971 .44772 .86155 .45027 .86611 .44889 .86427 .44633 Mtetra
.86427 .44633 .86611 .44889 .87068 .44751 .86885 .44495 Mtetra
.86885 .44495 .87068 .44751 .87526 .44612 .87343 .44356 Mtetra
.87343 .44356 .87526 .44612 .87984 .44473 .87802 .44216 Mtetra
.87802 .44216 .87984 .44473 .88443 .44334 .88261 .44077 Mtetra
.88261 .44077 .88443 .44334 .88903 .44195 .88722 .43937 Mtetra
.88722 .43937 .88903 .44195 .89363 .44056 .89183 .43798 Mtetra
.89183 .43798 .89363 .44056 .89825 .43916 .89644 .43657 Mtetra
.648 .76 .931 r
.26989 .67942 .27236 .68145 .27612 .68035 .27365 .67832 Mtetra
.27365 .67832 .27612 .68035 .27988 .67925 .27742 .67721 Mtetra
.27742 .67721 .27988 .67925 .28365 .67815 .28119 .67611 Mtetra
.28119 .67611 .28365 .67815 .28742 .67704 .28496 .675 Mtetra
.28496 .675 .28742 .67704 .2912 .67594 .28875 .67389 Mtetra
.28875 .67389 .2912 .67594 .29498 .67483 .29253 .67278 Mtetra
.29253 .67278 .29498 .67483 .29877 .67372 .29633 .67167 Mtetra
.29633 .67167 .29877 .67372 .30257 .67261 .30013 .67055 Mtetra
.30013 .67055 .30257 .67261 .30637 .67149 .30393 .66944 Mtetra
.30393 .66944 .30637 .67149 .31018 .67038 .30774 .66832 Mtetra
.30774 .66832 .31018 .67038 .31399 .66926 .31156 .6672 Mtetra
.31156 .6672 .31399 .66926 .31905 .64718 .31538 .66608 Mtetra
.518 .258 .46 r
.31538 .66608 .31905 .64718 .32285 .64605 .3192 .66496 Mtetra
0 0 .042 r
.3192 .66496 .32285 .64605 .32666 .64492 .32425 .64283 Mtetra
.65 .758 .928 r
.32425 .64283 .32666 .64492 .33047 .64379 .32807 .6417 Mtetra
.32807 .6417 .33047 .64379 .33429 .64266 .33189 .64056 Mtetra
.33189 .64056 .33429 .64266 .33811 .64152 .33571 .63943 Mtetra
.33571 .63943 .33811 .64152 .34194 .64039 .33954 .63829 Mtetra
.33954 .63829 .34194 .64039 .34577 .63925 .34338 .63715 Mtetra
.34338 .63715 .34577 .63925 .34961 .63811 .34722 .636 Mtetra
.34722 .636 .34961 .63811 .35345 .63697 .35107 .63486 Mtetra
.35107 .63486 .35345 .63697 .35731 .63583 .35493 .63372 Mtetra
.35493 .63372 .35731 .63583 .36116 .63468 .35879 .63257 Mtetra
.945 .692 .525 r
.35879 .63257 .36116 .63468 .36502 .63354 .37016 .47154 Mtetra
.557 .346 .55 r
.37016 .47154 .36502 .63354 .37611 .47256 .37386 .47033 Mtetra
.663 .742 .909 r
.37386 .47033 .37611 .47256 .37981 .47135 .37756 .46912 Mtetra
.37756 .46912 .37981 .47135 .38351 .47014 .38126 .46791 Mtetra
.38126 .46791 .38351 .47014 .38722 .46893 .38498 .4667 Mtetra
.38498 .4667 .38722 .46893 .39093 .46772 .38869 .46548 Mtetra
.38869 .46548 .39093 .46772 .39465 .46651 .39242 .46427 Mtetra
.39242 .46427 .39465 .46651 .39837 .4653 .39614 .46305 Mtetra
.39614 .46305 .39837 .4653 .4021 .46408 .39988 .46183 Mtetra
.39988 .46183 .4021 .46408 .40584 .46286 .40361 .46061 Mtetra
.40361 .46061 .40584 .46286 .40958 .46164 .40736 .45939 Mtetra
.40736 .45939 .40958 .46164 .41332 .46042 .4111 .45816 Mtetra
.4111 .45816 .41332 .46042 .41707 .4592 .41486 .45694 Mtetra
.41486 .45694 .41707 .4592 .42083 .45797 .41862 .45571 Mtetra
.41862 .45571 .42083 .45797 .42459 .45675 .42238 .45448 Mtetra
.42238 .45448 .42459 .45675 .42835 .45552 .42615 .45325 Mtetra
.42615 .45325 .42835 .45552 .43213 .45429 .42992 .45201 Mtetra
.42992 .45201 .43213 .45429 .43577 .45785 .4337 .45078 Mtetra
.819 .63 .647 r
.4337 .45078 .43577 .45785 .43956 .45662 .43774 .43998 Mtetra
.587 .42 .622 r
.43774 .43998 .43956 .45662 .44371 .44103 .44152 .43874 Mtetra
.664 .741 .908 r
.44152 .43874 .44371 .44103 .44749 .43979 .44531 .4375 Mtetra
.44531 .4375 .44749 .43979 .45128 .43855 .4491 .43626 Mtetra
.4491 .43626 .45128 .43855 .45507 .43731 .45289 .43501 Mtetra
.45289 .43501 .45507 .43731 .45886 .43606 .45669 .43376 Mtetra
.45669 .43376 .45886 .43606 .46267 .43482 .4605 .43251 Mtetra
.4605 .43251 .46267 .43482 .46647 .43357 .46431 .43126 Mtetra
.46431 .43126 .46647 .43357 .47029 .43232 .46813 .43001 Mtetra
.46813 .43001 .47029 .43232 .47411 .43107 .47195 .42875 Mtetra
.47195 .42875 .47411 .43107 .47793 .42981 .47578 .42749 Mtetra
.47578 .42749 .47793 .42981 .48176 .42856 .47961 .42623 Mtetra
.47961 .42623 .48176 .42856 .48559 .4273 .48345 .42497 Mtetra
.48345 .42497 .48559 .4273 .48943 .42604 .48729 .42371 Mtetra
.48729 .42371 .48943 .42604 .49328 .42478 .49114 .42245 Mtetra
.49114 .42245 .49328 .42478 .49713 .42352 .49499 .42118 Mtetra
.49499 .42118 .49713 .42352 .50099 .42225 .49885 .41991 Mtetra
.49885 .41991 .50099 .42225 .50485 .42099 .50272 .41864 Mtetra
.50272 .41864 .50485 .42099 .50872 .41972 .50659 .41737 Mtetra
.50659 .41737 .50872 .41972 .51259 .41845 .51046 .4161 Mtetra
.51046 .4161 .51259 .41845 .51647 .41718 .51435 .41482 Mtetra
.51435 .41482 .51647 .41718 .52035 .4159 .51823 .41355 Mtetra
.51823 .41355 .52035 .4159 .52424 .41463 .52213 .41227 Mtetra
.52213 .41227 .52424 .41463 .52813 .41335 .52602 .41099 Mtetra
.52602 .41099 .52813 .41335 .53203 .41207 .52993 .40971 Mtetra
.52993 .40971 .53203 .41207 .53594 .41079 .53384 .40842 Mtetra
.53384 .40842 .53594 .41079 .53985 .40951 .53775 .40714 Mtetra
.53775 .40714 .53985 .40951 .54377 .40823 .54167 .40585 Mtetra
.54167 .40585 .54377 .40823 .54769 .40694 .5456 .40456 Mtetra
.5456 .40456 .54769 .40694 .55162 .40565 .54953 .40327 Mtetra
.54953 .40327 .55162 .40565 .55555 .40436 .55347 .40198 Mtetra
.55347 .40198 .55555 .40436 .55949 .40307 .55741 .40068 Mtetra
.55741 .40068 .55949 .40307 .56343 .40178 .56136 .39938 Mtetra
.966 .668 .411 r
.56136 .39938 .56343 .40178 .56738 .40048 .5663 .47701 Mtetra
.545 .318 .522 r
.5663 .47701 .56738 .40048 .57134 .39918 .57036 .47573 Mtetra
.57036 .47573 .57134 .39918 .5753 .39789 .57442 .47446 Mtetra
.57442 .47446 .5753 .39789 .57927 .39659 .57849 .47318 Mtetra
0 0 .345 r
.57849 .47318 .57927 .39659 .58324 .39528 .58118 .39287 Mtetra
.664 .741 .908 r
.58118 .39287 .58324 .39528 .58722 .39398 .58517 .39156 Mtetra
.58517 .39156 .58722 .39398 .5912 .39267 .58916 .39025 Mtetra
.58916 .39025 .5912 .39267 .59519 .39136 .59315 .38894 Mtetra
.59315 .38894 .59519 .39136 .59919 .39005 .59715 .38763 Mtetra
.59715 .38763 .59919 .39005 .60319 .38874 .60115 .38631 Mtetra
.60115 .38631 .60319 .38874 .6072 .38743 .60516 .385 Mtetra
.60516 .385 .6072 .38743 .61121 .38611 .60918 .38368 Mtetra
.60918 .38368 .61121 .38611 .61523 .38479 .6132 .38236 Mtetra
.6132 .38236 .61523 .38479 .61925 .38347 .61723 .38103 Mtetra
.61723 .38103 .61925 .38347 .62328 .38215 .62127 .37971 Mtetra
.62127 .37971 .62328 .38215 .62732 .38083 .62531 .37838 Mtetra
.62531 .37838 .62732 .38083 .63136 .3795 .62935 .37705 Mtetra
.62935 .37705 .63136 .3795 .63541 .37818 .6334 .37572 Mtetra
.6334 .37572 .63541 .37818 .63946 .37685 .63746 .37439 Mtetra
.63746 .37439 .63946 .37685 .64352 .37552 .64153 .37305 Mtetra
.64153 .37305 .64352 .37552 .64759 .37418 .64559 .37172 Mtetra
.64559 .37172 .64759 .37418 .65166 .37285 .64967 .37038 Mtetra
.64967 .37038 .65166 .37285 .65574 .37151 .65375 .36904 Mtetra
.65375 .36904 .65574 .37151 .65982 .37017 .65784 .3677 Mtetra
.65784 .3677 .65982 .37017 .66391 .36883 .66193 .36635 Mtetra
.66193 .36635 .66391 .36883 .668 .36749 .66603 .36501 Mtetra
.66603 .36501 .668 .36749 .67211 .36615 .67014 .36366 Mtetra
.67014 .36366 .67211 .36615 .67621 .3648 .67425 .36231 Mtetra
.67425 .36231 .67621 .3648 .68033 .36345 .67836 .36096 Mtetra
.67836 .36096 .68033 .36345 .68444 .3621 .68249 .3596 Mtetra
.68249 .3596 .68444 .3621 .68857 .36075 .68662 .35825 Mtetra
.68662 .35825 .68857 .36075 .6927 .35939 .69075 .35689 Mtetra
.69075 .35689 .6927 .35939 .69684 .35804 .69489 .35553 Mtetra
.69489 .35553 .69684 .35804 .70098 .35668 .69904 .35416 Mtetra
.925 .547 .147 r
.69904 .35416 .70098 .35668 .70624 .37489 .70429 .37238 Mtetra
.662 .743 .91 r
.70429 .37238 .70624 .37489 .71042 .37353 .70848 .37102 Mtetra
.70848 .37102 .71042 .37353 .71461 .37217 .71267 .36966 Mtetra
.71267 .36966 .71461 .37217 .7188 .37081 .71687 .36829 Mtetra
.71687 .36829 .7188 .37081 .723 .36945 .72107 .36693 Mtetra
.72107 .36693 .723 .36945 .72721 .36808 .72528 .36556 Mtetra
.72528 .36556 .72721 .36808 .73142 .36672 .7295 .36419 Mtetra
.7295 .36419 .73142 .36672 .73564 .36535 .73372 .36282 Mtetra
.73372 .36282 .73564 .36535 .73986 .36398 .73795 .36144 Mtetra
.73795 .36144 .73986 .36398 .74409 .36261 .74219 .36007 Mtetra
.74219 .36007 .74409 .36261 .74833 .36123 .74643 .35869 Mtetra
.74643 .35869 .74833 .36123 .75258 .35986 .75068 .35731 Mtetra
.75068 .35731 .75258 .35986 .75683 .35848 .75493 .35593 Mtetra
.75493 .35593 .75683 .35848 .76108 .3571 .75919 .35454 Mtetra
.75919 .35454 .76108 .3571 .76534 .35571 .76346 .35316 Mtetra
.76346 .35316 .76534 .35571 .76961 .35433 .76773 .35177 Mtetra
.76773 .35177 .76961 .35433 .77389 .35294 .77201 .35038 Mtetra
.77201 .35038 .77389 .35294 .77817 .35155 .7763 .34898 Mtetra
.7763 .34898 .77817 .35155 .78246 .35016 .78059 .34759 Mtetra
.78059 .34759 .78246 .35016 .78675 .34877 .78489 .34619 Mtetra
.78489 .34619 .78675 .34877 .79105 .34737 .78919 .34479 Mtetra
.78919 .34479 .79105 .34737 .79536 .34598 .79351 .34339 Mtetra
.79351 .34339 .79536 .34598 .79968 .34458 .79782 .34199 Mtetra
.97 .652 .307 r
.79782 .34199 .79968 .34458 .81442 .46146 .81252 .45894 Mtetra
.653 .754 .924 r
.81252 .45894 .81442 .46146 .81892 .46009 .81703 .45757 Mtetra
.81703 .45757 .81892 .46009 .82342 .45873 .82153 .4562 Mtetra
.82153 .4562 .82342 .45873 .82793 .45736 .82605 .45483 Mtetra
.82605 .45483 .82793 .45736 .83245 .45599 .83057 .45345 Mtetra
.83057 .45345 .83245 .45599 .83698 .45462 .8351 .45208 Mtetra
.8351 .45208 .83698 .45462 .84151 .45324 .83964 .4507 Mtetra
.83964 .4507 .84151 .45324 .84605 .45186 .84418 .44932 Mtetra
.84418 .44932 .84605 .45186 .85059 .45048 .84873 .44793 Mtetra
.84873 .44793 .85059 .45048 .85515 .4491 .85329 .44655 Mtetra
.85329 .44655 .85515 .4491 .85971 .44772 .85786 .44516 Mtetra
.85786 .44516 .85971 .44772 .86427 .44633 .86243 .44377 Mtetra
.86243 .44377 .86427 .44633 .86885 .44495 .86701 .44238 Mtetra
.86701 .44238 .86885 .44495 .87343 .44356 .8716 .44099 Mtetra
.8716 .44099 .87343 .44356 .87802 .44216 .87619 .43959 Mtetra
.87619 .43959 .87802 .44216 .88261 .44077 .88079 .43819 Mtetra
.88079 .43819 .88261 .44077 .88722 .43937 .8854 .43679 Mtetra
.8854 .43679 .88722 .43937 .89183 .43798 .89001 .43539 Mtetra
.89001 .43539 .89183 .43798 .89644 .43657 .89464 .43398 Mtetra
.648 .76 .931 r
.26741 .67738 .26989 .67942 .27365 .67832 .27118 .67628 Mtetra
.27118 .67628 .27365 .67832 .27742 .67721 .27495 .67517 Mtetra
.27495 .67517 .27742 .67721 .28119 .67611 .27872 .67406 Mtetra
.27872 .67406 .28119 .67611 .28496 .675 .2825 .67295 Mtetra
.2825 .67295 .28496 .675 .28875 .67389 .28629 .67184 Mtetra
.28629 .67184 .28875 .67389 .29253 .67278 .29008 .67072 Mtetra
.29008 .67072 .29253 .67278 .29633 .67167 .29388 .66961 Mtetra
.29388 .66961 .29633 .67167 .30013 .67055 .29768 .66849 Mtetra
.29768 .66849 .30013 .67055 .30393 .66944 .30149 .66737 Mtetra
.30149 .66737 .30393 .66944 .30774 .66832 .3053 .66625 Mtetra
.3053 .66625 .30774 .66832 .31156 .6672 .30912 .66513 Mtetra
.30912 .66513 .31156 .6672 .31538 .66608 .31294 .66401 Mtetra
.31294 .66401 .31538 .66608 .3192 .66496 .31677 .66288 Mtetra
.31677 .66288 .3192 .66496 .32425 .64283 .32061 .66175 Mtetra
0 0 .042 r
.32061 .66175 .32425 .64283 .32807 .6417 .32566 .6396 Mtetra
.65 .758 .928 r
.32566 .6396 .32807 .6417 .33189 .64056 .32948 .63846 Mtetra
.32948 .63846 .33189 .64056 .33571 .63943 .33331 .63732 Mtetra
.33331 .63732 .33571 .63943 .33954 .63829 .33714 .63618 Mtetra
.33714 .63618 .33954 .63829 .34338 .63715 .34098 .63504 Mtetra
.34098 .63504 .34338 .63715 .34722 .636 .34483 .63389 Mtetra
.34483 .63389 .34722 .636 .35107 .63486 .34868 .63275 Mtetra
.34868 .63275 .35107 .63486 .35493 .63372 .35254 .6316 Mtetra
.944 .692 .526 r
.35254 .6316 .35493 .63372 .35879 .63257 .36421 .47052 Mtetra
.556 .345 .55 r
.36421 .47052 .35879 .63257 .37016 .47154 .3679 .46931 Mtetra
.663 .742 .909 r
.3679 .46931 .37016 .47154 .37386 .47033 .3716 .4681 Mtetra
.3716 .4681 .37386 .47033 .37756 .46912 .37531 .46688 Mtetra
.37531 .46688 .37756 .46912 .38126 .46791 .37902 .46567 Mtetra
.37902 .46567 .38126 .46791 .38498 .4667 .38273 .46445 Mtetra
.38273 .46445 .38498 .4667 .38869 .46548 .38645 .46324 Mtetra
.38645 .46324 .38869 .46548 .39242 .46427 .39018 .46202 Mtetra
.39018 .46202 .39242 .46427 .39614 .46305 .39391 .4608 Mtetra
.39391 .4608 .39614 .46305 .39988 .46183 .39764 .45957 Mtetra
.39764 .45957 .39988 .46183 .40361 .46061 .40138 .45835 Mtetra
.40138 .45835 .40361 .46061 .40736 .45939 .40513 .45712 Mtetra
.40513 .45712 .40736 .45939 .4111 .45816 .40888 .4559 Mtetra
.40888 .4559 .4111 .45816 .41486 .45694 .41264 .45467 Mtetra
.41264 .45467 .41486 .45694 .41862 .45571 .4164 .45344 Mtetra
.4164 .45344 .41862 .45571 .42238 .45448 .42017 .4522 Mtetra
.42017 .4522 .42238 .45448 .42615 .45325 .42394 .45097 Mtetra
.42394 .45097 .42615 .45325 .42992 .45201 .42772 .44973 Mtetra
.42772 .44973 .42992 .45201 .4337 .45078 .4315 .44849 Mtetra
.4315 .44849 .4337 .45078 .43774 .43998 .43529 .44725 Mtetra
0 0 0 r
.43529 .44725 .43774 .43998 .44152 .43874 .43933 .43645 Mtetra
.664 .741 .908 r
.43933 .43645 .44152 .43874 .44531 .4375 .44312 .4352 Mtetra
.44312 .4352 .44531 .4375 .4491 .43626 .44691 .43395 Mtetra
.44691 .43395 .4491 .43626 .45289 .43501 .45071 .4327 Mtetra
.45071 .4327 .45289 .43501 .45669 .43376 .45452 .43145 Mtetra
.45452 .43145 .45669 .43376 .4605 .43251 .45833 .4302 Mtetra
.45833 .4302 .4605 .43251 .46431 .43126 .46214 .42894 Mtetra
.46214 .42894 .46431 .43126 .46813 .43001 .46596 .42769 Mtetra
.46596 .42769 .46813 .43001 .47195 .42875 .46979 .42643 Mtetra
.46979 .42643 .47195 .42875 .47578 .42749 .47362 .42517 Mtetra
.47362 .42517 .47578 .42749 .47961 .42623 .47745 .42391 Mtetra
.47745 .42391 .47961 .42623 .48345 .42497 .48129 .42264 Mtetra
.48129 .42264 .48345 .42497 .48729 .42371 .48514 .42138 Mtetra
.48514 .42138 .48729 .42371 .49114 .42245 .48899 .42011 Mtetra
.48899 .42011 .49114 .42245 .49499 .42118 .49285 .41884 Mtetra
.49285 .41884 .49499 .42118 .49885 .41991 .49671 .41757 Mtetra
.49671 .41757 .49885 .41991 .50272 .41864 .50058 .4163 Mtetra
.50058 .4163 .50272 .41864 .50659 .41737 .50446 .41502 Mtetra
.50446 .41502 .50659 .41737 .51046 .4161 .50834 .41374 Mtetra
.50834 .41374 .51046 .4161 .51435 .41482 .51222 .41247 Mtetra
.51222 .41247 .51435 .41482 .51823 .41355 .51611 .41119 Mtetra
.51611 .41119 .51823 .41355 .52213 .41227 .52001 .4099 Mtetra
.52001 .4099 .52213 .41227 .52602 .41099 .52391 .40862 Mtetra
.52391 .40862 .52602 .41099 .52993 .40971 .52782 .40734 Mtetra
.52782 .40734 .52993 .40971 .53384 .40842 .53173 .40605 Mtetra
.53173 .40605 .53384 .40842 .53775 .40714 .53565 .40476 Mtetra
.53565 .40476 .53775 .40714 .54167 .40585 .53957 .40347 Mtetra
.53957 .40347 .54167 .40585 .5456 .40456 .5435 .40218 Mtetra
.5435 .40218 .5456 .40456 .54953 .40327 .54744 .40088 Mtetra
.54744 .40088 .54953 .40327 .55347 .40198 .55138 .39958 Mtetra
.55138 .39958 .55347 .40198 .55741 .40068 .55533 .39829 Mtetra
.966 .669 .413 r
.55533 .39829 .55741 .40068 .56136 .39938 .56012 .47593 Mtetra
.544 .317 .522 r
.56012 .47593 .56136 .39938 .5663 .47701 .56418 .47465 Mtetra
.658 .749 .917 r
.56418 .47465 .5663 .47701 .57036 .47573 .56824 .47337 Mtetra
.56824 .47337 .57036 .47573 .57442 .47446 .5723 .47209 Mtetra
.5723 .47209 .57442 .47446 .57849 .47318 .57638 .47081 Mtetra
.57638 .47081 .57849 .47318 .58118 .39287 .58046 .46953 Mtetra
.544 .317 .522 r
.58046 .46953 .58118 .39287 .58517 .39156 .58454 .46824 Mtetra
0 0 .346 r
.58454 .46824 .58517 .39156 .58916 .39025 .5871 .38783 Mtetra
.664 .741 .908 r
.5871 .38783 .58916 .39025 .59315 .38894 .5911 .38652 Mtetra
.5911 .38652 .59315 .38894 .59715 .38763 .5951 .3852 Mtetra
.5951 .3852 .59715 .38763 .60115 .38631 .59911 .38388 Mtetra
.59911 .38388 .60115 .38631 .60516 .385 .60313 .38256 Mtetra
.60313 .38256 .60516 .385 .60918 .38368 .60715 .38124 Mtetra
.60715 .38124 .60918 .38368 .6132 .38236 .61117 .37991 Mtetra
.61117 .37991 .6132 .38236 .61723 .38103 .61521 .37859 Mtetra
.61521 .37859 .61723 .38103 .62127 .37971 .61924 .37726 Mtetra
.61924 .37726 .62127 .37971 .62531 .37838 .62329 .37593 Mtetra
.62329 .37593 .62531 .37838 .62935 .37705 .62734 .37459 Mtetra
.62734 .37459 .62935 .37705 .6334 .37572 .63139 .37326 Mtetra
.63139 .37326 .6334 .37572 .63746 .37439 .63545 .37192 Mtetra
.63545 .37192 .63746 .37439 .64153 .37305 .63952 .37059 Mtetra
.63952 .37059 .64153 .37305 .64559 .37172 .6436 .36925 Mtetra
.6436 .36925 .64559 .37172 .64967 .37038 .64767 .3679 Mtetra
.64767 .3679 .64967 .37038 .65375 .36904 .65176 .36656 Mtetra
.65176 .36656 .65375 .36904 .65784 .3677 .65585 .36521 Mtetra
.65585 .36521 .65784 .3677 .66193 .36635 .65995 .36387 Mtetra
.65995 .36387 .66193 .36635 .66603 .36501 .66405 .36252 Mtetra
.66405 .36252 .66603 .36501 .67014 .36366 .66816 .36116 Mtetra
.66816 .36116 .67014 .36366 .67425 .36231 .67228 .35981 Mtetra
.67228 .35981 .67425 .36231 .67836 .36096 .6764 .35845 Mtetra
.6764 .35845 .67836 .36096 .68249 .3596 .68052 .3571 Mtetra
.68052 .3571 .68249 .3596 .68662 .35825 .68466 .35574 Mtetra
.68466 .35574 .68662 .35825 .69075 .35689 .6888 .35437 Mtetra
.6888 .35437 .69075 .35689 .69489 .35553 .69294 .35301 Mtetra
.69294 .35301 .69489 .35553 .69904 .35416 .69709 .35165 Mtetra
.925 .547 .147 r
.69709 .35165 .69904 .35416 .70429 .37238 .70234 .36987 Mtetra
.662 .743 .91 r
.70234 .36987 .70429 .37238 .70848 .37102 .70653 .3685 Mtetra
.70653 .3685 .70848 .37102 .71267 .36966 .71072 .36714 Mtetra
.71072 .36714 .71267 .36966 .71687 .36829 .71493 .36577 Mtetra
.71493 .36577 .71687 .36829 .72107 .36693 .71914 .3644 Mtetra
.71914 .3644 .72107 .36693 .72528 .36556 .72335 .36303 Mtetra
.72335 .36303 .72528 .36556 .7295 .36419 .72757 .36166 Mtetra
.72757 .36166 .7295 .36419 .73372 .36282 .7318 .36028 Mtetra
.7318 .36028 .73372 .36282 .73795 .36144 .73603 .3589 Mtetra
.73603 .3589 .73795 .36144 .74219 .36007 .74027 .35752 Mtetra
.74027 .35752 .74219 .36007 .74643 .35869 .74452 .35614 Mtetra
.74452 .35614 .74643 .35869 .75068 .35731 .74877 .35476 Mtetra
.74877 .35476 .75068 .35731 .75493 .35593 .75303 .35337 Mtetra
.75303 .35337 .75493 .35593 .75919 .35454 .7573 .35198 Mtetra
.7573 .35198 .75919 .35454 .76346 .35316 .76157 .35059 Mtetra
.76157 .35059 .76346 .35316 .76773 .35177 .76584 .3492 Mtetra
.76584 .3492 .76773 .35177 .77201 .35038 .77013 .3478 Mtetra
.77013 .3478 .77201 .35038 .7763 .34898 .77442 .34641 Mtetra
.77442 .34641 .7763 .34898 .78059 .34759 .77872 .34501 Mtetra
.77872 .34501 .78059 .34759 .78489 .34619 .78302 .34361 Mtetra
.78302 .34361 .78489 .34619 .78919 .34479 .78733 .34221 Mtetra
.78733 .34221 .78919 .34479 .79351 .34339 .79165 .3408 Mtetra
.97 .653 .31 r
.79165 .3408 .79351 .34339 .79782 .34199 .80612 .45778 Mtetra
.547 .324 .528 r
.80612 .45778 .79782 .34199 .81252 .45894 .81062 .45641 Mtetra
.653 .754 .924 r
.81062 .45641 .81252 .45894 .81703 .45757 .81512 .45504 Mtetra
.81512 .45504 .81703 .45757 .82153 .4562 .81964 .45366 Mtetra
.81964 .45366 .82153 .4562 .82605 .45483 .82416 .45229 Mtetra
.82416 .45229 .82605 .45483 .83057 .45345 .82869 .45091 Mtetra
.82869 .45091 .83057 .45345 .8351 .45208 .83322 .44953 Mtetra
.83322 .44953 .8351 .45208 .83964 .4507 .83776 .44815 Mtetra
.83776 .44815 .83964 .4507 .84418 .44932 .84231 .44676 Mtetra
.84231 .44676 .84418 .44932 .84873 .44793 .84687 .44537 Mtetra
.84687 .44537 .84873 .44793 .85329 .44655 .85143 .44398 Mtetra
.85143 .44398 .85329 .44655 .85786 .44516 .856 .44259 Mtetra
.856 .44259 .85786 .44516 .86243 .44377 .86058 .4412 Mtetra
.86058 .4412 .86243 .44377 .86701 .44238 .86516 .4398 Mtetra
.86516 .4398 .86701 .44238 .8716 .44099 .86976 .43841 Mtetra
.86976 .43841 .8716 .44099 .87619 .43959 .87436 .43701 Mtetra
.87436 .43701 .87619 .43959 .88079 .43819 .87896 .4356 Mtetra
.87896 .4356 .88079 .43819 .8854 .43679 .88358 .4342 Mtetra
.88358 .4342 .8854 .43679 .89001 .43539 .8882 .43279 Mtetra
.8882 .43279 .89001 .43539 .89464 .43398 .89282 .43138 Mtetra
.648 .76 .931 r
.26493 .67534 .26741 .67738 .27118 .67628 .2687 .67423 Mtetra
.2687 .67423 .27118 .67628 .27495 .67517 .27247 .67312 Mtetra
.27247 .67312 .27495 .67517 .27872 .67406 .27625 .67201 Mtetra
.27625 .67201 .27872 .67406 .2825 .67295 .28003 .67089 Mtetra
.28003 .67089 .2825 .67295 .28629 .67184 .28382 .66978 Mtetra
.28382 .66978 .28629 .67184 .29008 .67072 .28762 .66866 Mtetra
.28762 .66866 .29008 .67072 .29388 .66961 .29142 .66754 Mtetra
.29142 .66754 .29388 .66961 .29768 .66849 .29522 .66642 Mtetra
.29522 .66642 .29768 .66849 .30149 .66737 .29903 .6653 Mtetra
.29903 .6653 .30149 .66737 .3053 .66625 .30285 .66418 Mtetra
.30285 .66418 .3053 .66625 .30912 .66513 .30667 .66305 Mtetra
.30667 .66305 .30912 .66513 .31294 .66401 .3105 .66193 Mtetra
.3105 .66193 .31294 .66401 .31677 .66288 .31433 .6608 Mtetra
.31433 .6608 .31677 .66288 .32061 .66175 .31817 .65967 Mtetra
.31817 .65967 .32061 .66175 .32566 .6396 .32201 .65854 Mtetra
.517 .256 .458 r
.32201 .65854 .32566 .6396 .32948 .63846 .32586 .6574 Mtetra
0 0 .045 r
.32586 .6574 .32948 .63846 .33331 .63732 .3309 .63521 Mtetra
.65 .758 .928 r
.3309 .63521 .33331 .63732 .33714 .63618 .33474 .63407 Mtetra
.33474 .63407 .33714 .63618 .34098 .63504 .33858 .63292 Mtetra
.33858 .63292 .34098 .63504 .34483 .63389 .34243 .63177 Mtetra
.34243 .63177 .34483 .63389 .34868 .63275 .34629 .63062 Mtetra
.944 .692 .526 r
.34629 .63062 .34868 .63275 .35254 .6316 .35825 .46949 Mtetra
.556 .345 .549 r
.35825 .46949 .35254 .6316 .36421 .47052 .36194 .46828 Mtetra
.663 .742 .909 r
.36194 .46828 .36421 .47052 .3679 .46931 .36564 .46707 Mtetra
.36564 .46707 .3679 .46931 .3716 .4681 .36934 .46586 Mtetra
.36934 .46586 .3716 .4681 .37531 .46688 .37305 .46464 Mtetra
.37305 .46464 .37531 .46688 .37902 .46567 .37676 .46342 Mtetra
.37676 .46342 .37902 .46567 .38273 .46445 .38048 .46221 Mtetra
.38048 .46221 .38273 .46445 .38645 .46324 .3842 .46098 Mtetra
.3842 .46098 .38645 .46324 .39018 .46202 .38793 .45976 Mtetra
.38793 .45976 .39018 .46202 .39391 .4608 .39166 .45854 Mtetra
.39166 .45854 .39391 .4608 .39764 .45957 .3954 .45731 Mtetra
.3954 .45731 .39764 .45957 .40138 .45835 .39915 .45609 Mtetra
.39915 .45609 .40138 .45835 .40513 .45712 .4029 .45486 Mtetra
.4029 .45486 .40513 .45712 .40888 .4559 .40665 .45363 Mtetra
.40665 .45363 .40888 .4559 .41264 .45467 .41041 .45239 Mtetra
.41041 .45239 .41264 .45467 .4164 .45344 .41418 .45116 Mtetra
.41418 .45116 .4164 .45344 .42017 .4522 .41795 .44992 Mtetra
.41795 .44992 .42017 .4522 .42394 .45097 .42172 .44869 Mtetra
.42172 .44869 .42394 .45097 .42772 .44973 .4255 .44745 Mtetra
.4255 .44745 .42772 .44973 .4315 .44849 .42929 .4462 Mtetra
.42929 .4462 .4315 .44849 .43529 .44725 .43308 .44496 Mtetra
.912 .748 .665 r
.43308 .44496 .43529 .44725 .43933 .43645 .43714 .43414 Mtetra
.664 .741 .908 r
.43714 .43414 .43933 .43645 .44312 .4352 .44093 .4329 Mtetra
.44093 .4329 .44312 .4352 .44691 .43395 .44472 .43164 Mtetra
.44472 .43164 .44691 .43395 .45071 .4327 .44853 .43039 Mtetra
.44853 .43039 .45071 .4327 .45452 .43145 .45233 .42914 Mtetra
.45233 .42914 .45452 .43145 .45833 .4302 .45615 .42788 Mtetra
.45615 .42788 .45833 .4302 .46214 .42894 .45996 .42662 Mtetra
.45996 .42662 .46214 .42894 .46596 .42769 .46379 .42536 Mtetra
.46379 .42536 .46596 .42769 .46979 .42643 .46762 .4241 Mtetra
.46762 .4241 .46979 .42643 .47362 .42517 .47145 .42284 Mtetra
.47145 .42284 .47362 .42517 .47745 .42391 .47529 .42157 Mtetra
.47529 .42157 .47745 .42391 .48129 .42264 .47914 .4203 Mtetra
.47914 .4203 .48129 .42264 .48514 .42138 .48299 .41903 Mtetra
.48299 .41903 .48514 .42138 .48899 .42011 .48684 .41776 Mtetra
.48684 .41776 .48899 .42011 .49285 .41884 .4907 .41649 Mtetra
.4907 .41649 .49285 .41884 .49671 .41757 .49457 .41522 Mtetra
.49457 .41522 .49671 .41757 .50058 .4163 .49844 .41394 Mtetra
.49844 .41394 .50058 .4163 .50446 .41502 .50232 .41266 Mtetra
.50232 .41266 .50446 .41502 .50834 .41374 .5062 .41138 Mtetra
.5062 .41138 .50834 .41374 .51222 .41247 .51009 .4101 Mtetra
.51009 .4101 .51222 .41247 .51611 .41119 .51399 .40882 Mtetra
.51399 .40882 .51611 .41119 .52001 .4099 .51789 .40753 Mtetra
.51789 .40753 .52001 .4099 .52391 .40862 .52179 .40625 Mtetra
.52179 .40625 .52391 .40862 .52782 .40734 .5257 .40496 Mtetra
.5257 .40496 .52782 .40734 .53173 .40605 .52962 .40367 Mtetra
.52962 .40367 .53173 .40605 .53565 .40476 .53354 .40237 Mtetra
.53354 .40237 .53565 .40476 .53957 .40347 .53747 .40108 Mtetra
.53747 .40108 .53957 .40347 .5435 .40218 .5414 .39978 Mtetra
.5414 .39978 .5435 .40218 .54744 .40088 .54534 .39849 Mtetra
.54534 .39849 .54744 .40088 .55138 .39958 .54928 .39719 Mtetra
.54928 .39719 .55138 .39958 .55533 .39829 .55324 .39588 Mtetra
.966 .669 .413 r
.55324 .39588 .55533 .39829 .56012 .47593 .55798 .47357 Mtetra
.658 .749 .917 r
.55798 .47357 .56012 .47593 .56418 .47465 .56204 .47229 Mtetra
.56204 .47229 .56418 .47465 .56824 .47337 .56611 .47101 Mtetra
.56611 .47101 .56824 .47337 .5723 .47209 .57018 .46973 Mtetra
.57018 .46973 .5723 .47209 .57638 .47081 .57426 .46844 Mtetra
.57426 .46844 .57638 .47081 .58046 .46953 .57834 .46715 Mtetra
.57834 .46715 .58046 .46953 .58454 .46824 .58243 .46586 Mtetra
.58243 .46586 .58454 .46824 .5871 .38783 .58653 .46457 Mtetra
.544 .317 .521 r
.58653 .46457 .5871 .38783 .5911 .38652 .59063 .46328 Mtetra
0 0 .348 r
.59063 .46328 .5911 .38652 .5951 .3852 .59305 .38276 Mtetra
.664 .741 .908 r
.59305 .38276 .5951 .3852 .59911 .38388 .59706 .38144 Mtetra
.59706 .38144 .59911 .38388 .60313 .38256 .60108 .38012 Mtetra
.60108 .38012 .60313 .38256 .60715 .38124 .60511 .37879 Mtetra
.60511 .37879 .60715 .38124 .61117 .37991 .60914 .37746 Mtetra
.60914 .37746 .61117 .37991 .61521 .37859 .61317 .37613 Mtetra
.61317 .37613 .61521 .37859 .61924 .37726 .61721 .3748 Mtetra
.61721 .3748 .61924 .37726 .62329 .37593 .62126 .37347 Mtetra
.62126 .37347 .62329 .37593 .62734 .37459 .62532 .37213 Mtetra
.62532 .37213 .62734 .37459 .63139 .37326 .62938 .37079 Mtetra
.62938 .37079 .63139 .37326 .63545 .37192 .63344 .36945 Mtetra
.63344 .36945 .63545 .37192 .63952 .37059 .63751 .36811 Mtetra
.63751 .36811 .63952 .37059 .6436 .36925 .64159 .36677 Mtetra
.64159 .36677 .6436 .36925 .64767 .3679 .64567 .36542 Mtetra
.64567 .36542 .64767 .3679 .65176 .36656 .64976 .36407 Mtetra
.64976 .36407 .65176 .36656 .65585 .36521 .65386 .36272 Mtetra
.65386 .36272 .65585 .36521 .65995 .36387 .65796 .36137 Mtetra
.65796 .36137 .65995 .36387 .66405 .36252 .66207 .36002 Mtetra
.66207 .36002 .66405 .36252 .66816 .36116 .66618 .35866 Mtetra
.66618 .35866 .66816 .36116 .67228 .35981 .6703 .35731 Mtetra
.6703 .35731 .67228 .35981 .6764 .35845 .67442 .35595 Mtetra
.67442 .35595 .6764 .35845 .68052 .3571 .67855 .35458 Mtetra
.67855 .35458 .68052 .3571 .68466 .35574 .68269 .35322 Mtetra
.68269 .35322 .68466 .35574 .6888 .35437 .68684 .35186 Mtetra
.68684 .35186 .6888 .35437 .69294 .35301 .69098 .35049 Mtetra
.69098 .35049 .69294 .35301 .69709 .35165 .69514 .34912 Mtetra
.925 .547 .147 r
.69514 .34912 .69709 .35165 .70234 .36987 .70038 .36735 Mtetra
.662 .743 .91 r
.70038 .36735 .70234 .36987 .70653 .3685 .70457 .36598 Mtetra
.70457 .36598 .70653 .3685 .71072 .36714 .70878 .36461 Mtetra
.70878 .36461 .71072 .36714 .71493 .36577 .71298 .36324 Mtetra
.71298 .36324 .71493 .36577 .71914 .3644 .71719 .36187 Mtetra
.71719 .36187 .71914 .3644 .72335 .36303 .72141 .36049 Mtetra
.72141 .36049 .72335 .36303 .72757 .36166 .72564 .35911 Mtetra
.72564 .35911 .72757 .36166 .7318 .36028 .72987 .35773 Mtetra
.72987 .35773 .7318 .36028 .73603 .3589 .73411 .35635 Mtetra
.73411 .35635 .73603 .3589 .74027 .35752 .73835 .35497 Mtetra
.73835 .35497 .74027 .35752 .74452 .35614 .7426 .35358 Mtetra
.7426 .35358 .74452 .35614 .74877 .35476 .74686 .35219 Mtetra
.74686 .35219 .74877 .35476 .75303 .35337 .75112 .3508 Mtetra
.75112 .3508 .75303 .35337 .7573 .35198 .75539 .34941 Mtetra
.75539 .34941 .7573 .35198 .76157 .35059 .75967 .34802 Mtetra
.75967 .34802 .76157 .35059 .76584 .3492 .76395 .34662 Mtetra
.76395 .34662 .76584 .3492 .77013 .3478 .76824 .34522 Mtetra
.76824 .34522 .77013 .3478 .77442 .34641 .77254 .34382 Mtetra
.77254 .34382 .77442 .34641 .77872 .34501 .77684 .34242 Mtetra
.77684 .34242 .77872 .34501 .78302 .34361 .78115 .34102 Mtetra
.78115 .34102 .78302 .34361 .78733 .34221 .78546 .33961 Mtetra
.78546 .33961 .78733 .34221 .79165 .3408 .78978 .3382 Mtetra
.97 .653 .31 r
.78978 .3382 .79165 .3408 .80612 .45778 .8042 .45525 Mtetra
.653 .754 .924 r
.8042 .45525 .80612 .45778 .81062 .45641 .80871 .45388 Mtetra
.80871 .45388 .81062 .45641 .81512 .45504 .81322 .4525 Mtetra
.81322 .4525 .81512 .45504 .81964 .45366 .81774 .45112 Mtetra
.81774 .45112 .81964 .45366 .82416 .45229 .82226 .44974 Mtetra
.82226 .44974 .82416 .45229 .82869 .45091 .8268 .44836 Mtetra
.8268 .44836 .82869 .45091 .83322 .44953 .83134 .44697 Mtetra
.83134 .44697 .83322 .44953 .83776 .44815 .83588 .44559 Mtetra
.83588 .44559 .83776 .44815 .84231 .44676 .84044 .4442 Mtetra
.84044 .4442 .84231 .44676 .84687 .44537 .845 .44281 Mtetra
.845 .44281 .84687 .44537 .85143 .44398 .84957 .44141 Mtetra
.84957 .44141 .85143 .44398 .856 .44259 .85414 .44002 Mtetra
.85414 .44002 .856 .44259 .86058 .4412 .85872 .43862 Mtetra
.85872 .43862 .86058 .4412 .86516 .4398 .86331 .43722 Mtetra
.86331 .43722 .86516 .4398 .86976 .43841 .86791 .43582 Mtetra
.86791 .43582 .86976 .43841 .87436 .43701 .87252 .43442 Mtetra
.87252 .43442 .87436 .43701 .87896 .4356 .87713 .43301 Mtetra
.87713 .43301 .87896 .4356 .88358 .4342 .88175 .4316 Mtetra
.88175 .4316 .88358 .4342 .8882 .43279 .88637 .43019 Mtetra
.88637 .43019 .8882 .43279 .89282 .43138 .89101 .42878 Mtetra
.648 .76 .931 r
.26244 .67329 .26493 .67534 .2687 .67423 .26621 .67218 Mtetra
.26621 .67218 .2687 .67423 .27247 .67312 .26999 .67107 Mtetra
.26999 .67107 .27247 .67312 .27625 .67201 .27377 .66995 Mtetra
.27377 .66995 .27625 .67201 .28003 .67089 .27756 .66883 Mtetra
.27756 .66883 .28003 .67089 .28382 .66978 .28135 .66772 Mtetra
.28135 .66772 .28382 .66978 .28762 .66866 .28515 .6666 Mtetra
.28515 .6666 .28762 .66866 .29142 .66754 .28895 .66547 Mtetra
.28895 .66547 .29142 .66754 .29522 .66642 .29276 .66435 Mtetra
.29276 .66435 .29522 .66642 .29903 .6653 .29657 .66323 Mtetra
.29657 .66323 .29903 .6653 .30285 .66418 .30039 .6621 Mtetra
.30039 .6621 .30285 .66418 .30667 .66305 .30422 .66097 Mtetra
.30422 .66097 .30667 .66305 .3105 .66193 .30805 .65984 Mtetra
.30805 .65984 .3105 .66193 .31433 .6608 .31189 .65871 Mtetra
.31189 .65871 .31433 .6608 .31817 .65967 .31573 .65758 Mtetra
.31573 .65758 .31817 .65967 .32201 .65854 .31958 .65644 Mtetra
.31958 .65644 .32201 .65854 .32586 .6574 .32343 .65531 Mtetra
.32343 .65531 .32586 .6574 .3309 .63521 .32729 .65417 Mtetra
.516 .255 .458 r
.32729 .65417 .3309 .63521 .33474 .63407 .33115 .65303 Mtetra
0 0 .048 r
.33115 .65303 .33474 .63407 .33858 .63292 .33617 .6308 Mtetra
.65 .758 .928 r
.33617 .6308 .33858 .63292 .34243 .63177 .34003 .62965 Mtetra
.943 .692 .527 r
.34003 .62965 .34243 .63177 .34629 .63062 .35228 .46847 Mtetra
.555 .344 .549 r
.35228 .46847 .34629 .63062 .35825 .46949 .35597 .46726 Mtetra
.663 .742 .909 r
.35597 .46726 .35825 .46949 .36194 .46828 .35966 .46604 Mtetra
.35966 .46604 .36194 .46828 .36564 .46707 .36337 .46483 Mtetra
.36337 .46483 .36564 .46707 .36934 .46586 .36707 .46361 Mtetra
.36707 .46361 .36934 .46586 .37305 .46464 .37078 .46239 Mtetra
.37078 .46239 .37305 .46464 .37676 .46342 .3745 .46117 Mtetra
.3745 .46117 .37676 .46342 .38048 .46221 .37822 .45995 Mtetra
.37822 .45995 .38048 .46221 .3842 .46098 .38195 .45873 Mtetra
.38195 .45873 .3842 .46098 .38793 .45976 .38568 .4575 Mtetra
.38568 .4575 .38793 .45976 .39166 .45854 .38942 .45627 Mtetra
.38942 .45627 .39166 .45854 .3954 .45731 .39316 .45505 Mtetra
.39316 .45505 .3954 .45731 .39915 .45609 .39691 .45381 Mtetra
.39691 .45381 .39915 .45609 .4029 .45486 .40066 .45258 Mtetra
.40066 .45258 .4029 .45486 .40665 .45363 .40442 .45135 Mtetra
.40442 .45135 .40665 .45363 .41041 .45239 .40818 .45011 Mtetra
.40818 .45011 .41041 .45239 .41418 .45116 .41195 .44888 Mtetra
.41195 .44888 .41418 .45116 .41795 .44992 .41572 .44764 Mtetra
.41572 .44764 .41795 .44992 .42172 .44869 .4195 .4464 Mtetra
.4195 .4464 .42172 .44869 .4255 .44745 .42329 .44515 Mtetra
.42329 .44515 .4255 .44745 .42929 .4462 .42707 .44391 Mtetra
.42707 .44391 .42929 .4462 .43308 .44496 .43087 .44266 Mtetra
.912 .748 .665 r
.43087 .44266 .43308 .44496 .43714 .43414 .43493 .43184 Mtetra
.664 .741 .908 r
.43493 .43184 .43714 .43414 .44093 .4329 .43873 .43058 Mtetra
.43873 .43058 .44093 .4329 .44472 .43164 .44253 .42933 Mtetra
.44253 .42933 .44472 .43164 .44853 .43039 .44633 .42807 Mtetra
.44633 .42807 .44853 .43039 .45233 .42914 .45015 .42682 Mtetra
.45015 .42682 .45233 .42914 .45615 .42788 .45396 .42556 Mtetra
.45396 .42556 .45615 .42788 .45996 .42662 .45778 .42429 Mtetra
.45778 .42429 .45996 .42662 .46379 .42536 .46161 .42303 Mtetra
.46161 .42303 .46379 .42536 .46762 .4241 .46544 .42177 Mtetra
.46544 .42177 .46762 .4241 .47145 .42284 .46928 .4205 Mtetra
.46928 .4205 .47145 .42284 .47529 .42157 .47312 .41923 Mtetra
.47312 .41923 .47529 .42157 .47914 .4203 .47697 .41796 Mtetra
.47697 .41796 .47914 .4203 .48299 .41903 .48083 .41669 Mtetra
.48083 .41669 .48299 .41903 .48684 .41776 .48468 .41541 Mtetra
.48468 .41541 .48684 .41776 .4907 .41649 .48855 .41414 Mtetra
.48855 .41414 .4907 .41649 .49457 .41522 .49242 .41286 Mtetra
.49242 .41286 .49457 .41522 .49844 .41394 .4963 .41158 Mtetra
.4963 .41158 .49844 .41394 .50232 .41266 .50018 .4103 Mtetra
.50018 .4103 .50232 .41266 .5062 .41138 .50406 .40902 Mtetra
.50406 .40902 .5062 .41138 .51009 .4101 .50796 .40773 Mtetra
.50796 .40773 .51009 .4101 .51399 .40882 .51185 .40644 Mtetra
.51185 .40644 .51399 .40882 .51789 .40753 .51576 .40516 Mtetra
.51576 .40516 .51789 .40753 .52179 .40625 .51967 .40387 Mtetra
.51967 .40387 .52179 .40625 .5257 .40496 .52358 .40257 Mtetra
.52358 .40257 .5257 .40496 .52962 .40367 .5275 .40128 Mtetra
.5275 .40128 .52962 .40367 .53354 .40237 .53143 .39998 Mtetra
.53143 .39998 .53354 .40237 .53747 .40108 .53536 .39869 Mtetra
.53536 .39869 .53747 .40108 .5414 .39978 .53929 .39739 Mtetra
.53929 .39739 .5414 .39978 .54534 .39849 .54324 .39608 Mtetra
.54324 .39608 .54534 .39849 .54928 .39719 .54719 .39478 Mtetra
.966 .669 .414 r
.54719 .39478 .54928 .39719 .55324 .39588 .55178 .47249 Mtetra
.543 .316 .52 r
.55178 .47249 .55324 .39588 .55798 .47357 .55584 .47121 Mtetra
.658 .749 .917 r
.55584 .47121 .55798 .47357 .56204 .47229 .55991 .46992 Mtetra
.55991 .46992 .56204 .47229 .56611 .47101 .56397 .46864 Mtetra
.56397 .46864 .56611 .47101 .57018 .46973 .56805 .46735 Mtetra
.56805 .46735 .57018 .46973 .57426 .46844 .57213 .46606 Mtetra
.57213 .46606 .57426 .46844 .57834 .46715 .57622 .46477 Mtetra
.57622 .46477 .57834 .46715 .58243 .46586 .58031 .46348 Mtetra
.58031 .46348 .58243 .46586 .58653 .46457 .58441 .46219 Mtetra
.58441 .46219 .58653 .46457 .59063 .46328 .58852 .46089 Mtetra
.58852 .46089 .59063 .46328 .59305 .38276 .59263 .45959 Mtetra
.543 .316 .52 r
.59263 .45959 .59305 .38276 .59706 .38144 .59675 .45829 Mtetra
0 0 .35 r
.59675 .45829 .59706 .38144 .60108 .38012 .59903 .37767 Mtetra
.664 .741 .908 r
.59903 .37767 .60108 .38012 .60511 .37879 .60306 .37634 Mtetra
.60306 .37634 .60511 .37879 .60914 .37746 .60709 .375 Mtetra
.60709 .375 .60914 .37746 .61317 .37613 .61113 .37367 Mtetra
.61113 .37367 .61317 .37613 .61721 .3748 .61518 .37233 Mtetra
.61518 .37233 .61721 .3748 .62126 .37347 .61923 .371 Mtetra
.61923 .371 .62126 .37347 .62532 .37213 .62329 .36966 Mtetra
.62329 .36966 .62532 .37213 .62938 .37079 .62735 .36832 Mtetra
.62735 .36832 .62938 .37079 .63344 .36945 .63142 .36697 Mtetra
.63142 .36697 .63344 .36945 .63751 .36811 .6355 .36563 Mtetra
.6355 .36563 .63751 .36811 .64159 .36677 .63958 .36428 Mtetra
.63958 .36428 .64159 .36677 .64567 .36542 .64367 .36293 Mtetra
.64367 .36293 .64567 .36542 .64976 .36407 .64776 .36158 Mtetra
.64776 .36158 .64976 .36407 .65386 .36272 .65186 .36023 Mtetra
.65186 .36023 .65386 .36272 .65796 .36137 .65596 .35887 Mtetra
.65596 .35887 .65796 .36137 .66207 .36002 .66008 .35751 Mtetra
.66008 .35751 .66207 .36002 .66618 .35866 .66419 .35615 Mtetra
.66419 .35615 .66618 .35866 .6703 .35731 .66832 .35479 Mtetra
.66832 .35479 .6703 .35731 .67442 .35595 .67245 .35343 Mtetra
.67245 .35343 .67442 .35595 .67855 .35458 .67658 .35207 Mtetra
.67658 .35207 .67855 .35458 .68269 .35322 .68072 .3507 Mtetra
.68072 .3507 .68269 .35322 .68684 .35186 .68487 .34933 Mtetra
.68487 .34933 .68684 .35186 .69098 .35049 .68902 .34796 Mtetra
.68902 .34796 .69098 .35049 .69514 .34912 .69318 .34658 Mtetra
.925 .547 .147 r
.69318 .34658 .69514 .34912 .70038 .36735 .69842 .36482 Mtetra
.662 .743 .91 r
.69842 .36482 .70038 .36735 .70457 .36598 .70262 .36345 Mtetra
.70262 .36345 .70457 .36598 .70878 .36461 .70682 .36208 Mtetra
.70682 .36208 .70878 .36461 .71298 .36324 .71103 .3607 Mtetra
.71103 .3607 .71298 .36324 .71719 .36187 .71525 .35933 Mtetra
.71525 .35933 .71719 .36187 .72141 .36049 .71947 .35795 Mtetra
.71947 .35795 .72141 .36049 .72564 .35911 .7237 .35657 Mtetra
.7237 .35657 .72564 .35911 .72987 .35773 .72794 .35518 Mtetra
.72794 .35518 .72987 .35773 .73411 .35635 .73218 .3538 Mtetra
.73218 .3538 .73411 .35635 .73835 .35497 .73643 .35241 Mtetra
.73643 .35241 .73835 .35497 .7426 .35358 .74068 .35102 Mtetra
.74068 .35102 .7426 .35358 .74686 .35219 .74495 .34963 Mtetra
.74495 .34963 .74686 .35219 .75112 .3508 .74921 .34823 Mtetra
.74921 .34823 .75112 .3508 .75539 .34941 .75349 .34684 Mtetra
.75349 .34684 .75539 .34941 .75967 .34802 .75777 .34544 Mtetra
.75777 .34544 .75967 .34802 .76395 .34662 .76205 .34404 Mtetra
.76205 .34404 .76395 .34662 .76824 .34522 .76635 .34264 Mtetra
.76635 .34264 .76824 .34522 .77254 .34382 .77065 .34123 Mtetra
.77065 .34123 .77254 .34382 .77684 .34242 .77495 .33983 Mtetra
.77495 .33983 .77684 .34242 .78115 .34102 .77927 .33842 Mtetra
.77927 .33842 .78115 .34102 .78546 .33961 .78359 .33701 Mtetra
.78359 .33701 .78546 .33961 .78978 .3382 .78791 .33559 Mtetra
.97 .653 .31 r
.78791 .33559 .78978 .3382 .8042 .45525 .80228 .45271 Mtetra
.653 .754 .924 r
.80228 .45271 .8042 .45525 .80871 .45388 .80679 .45133 Mtetra
.80679 .45133 .80871 .45388 .81322 .4525 .81131 .44995 Mtetra
.81131 .44995 .81322 .4525 .81774 .45112 .81583 .44857 Mtetra
.81583 .44857 .81774 .45112 .82226 .44974 .82036 .44719 Mtetra
.82036 .44719 .82226 .44974 .8268 .44836 .8249 .4458 Mtetra
.8249 .4458 .8268 .44836 .83134 .44697 .82944 .44441 Mtetra
.82944 .44441 .83134 .44697 .83588 .44559 .834 .44302 Mtetra
.834 .44302 .83588 .44559 .84044 .4442 .83856 .44163 Mtetra
.83856 .44163 .84044 .4442 .845 .44281 .84312 .44023 Mtetra
.84312 .44023 .845 .44281 .84957 .44141 .8477 .43884 Mtetra
.8477 .43884 .84957 .44141 .85414 .44002 .85228 .43744 Mtetra
.85228 .43744 .85414 .44002 .85872 .43862 .85686 .43604 Mtetra
.85686 .43604 .85872 .43862 .86331 .43722 .86146 .43463 Mtetra
.86146 .43463 .86331 .43722 .86791 .43582 .86606 .43323 Mtetra
.86606 .43323 .86791 .43582 .87252 .43442 .87067 .43182 Mtetra
.87067 .43182 .87252 .43442 .87713 .43301 .87529 .43041 Mtetra
.87529 .43041 .87713 .43301 .88175 .4316 .87991 .42899 Mtetra
.87991 .42899 .88175 .4316 .88637 .43019 .88454 .42758 Mtetra
.88454 .42758 .88637 .43019 .89101 .42878 .88918 .42616 Mtetra
.648 .76 .931 r
.25995 .67124 .26244 .67329 .26621 .67218 .26372 .67012 Mtetra
.26372 .67012 .26621 .67218 .26999 .67107 .2675 .66901 Mtetra
.2675 .66901 .26999 .67107 .27377 .66995 .27129 .66789 Mtetra
.27129 .66789 .27377 .66995 .27756 .66883 .27508 .66677 Mtetra
.27508 .66677 .27756 .66883 .28135 .66772 .27887 .66565 Mtetra
.27887 .66565 .28135 .66772 .28515 .6666 .28267 .66452 Mtetra
.28267 .66452 .28515 .6666 .28895 .66547 .28648 .6634 Mtetra
.28648 .6634 .28895 .66547 .29276 .66435 .29029 .66227 Mtetra
.29029 .66227 .29276 .66435 .29657 .66323 .29411 .66115 Mtetra
.29411 .66115 .29657 .66323 .30039 .6621 .29793 .66002 Mtetra
.29793 .66002 .30039 .6621 .30422 .66097 .30176 .65889 Mtetra
.30176 .65889 .30422 .66097 .30805 .65984 .30559 .65775 Mtetra
.30559 .65775 .30805 .65984 .31189 .65871 .30943 .65662 Mtetra
.30943 .65662 .31189 .65871 .31573 .65758 .31328 .65548 Mtetra
.31328 .65548 .31573 .65758 .31958 .65644 .31713 .65434 Mtetra
.31713 .65434 .31958 .65644 .32343 .65531 .32099 .65321 Mtetra
.32099 .65321 .32343 .65531 .32729 .65417 .32485 .65206 Mtetra
.32485 .65206 .32729 .65417 .33115 .65303 .32872 .65092 Mtetra
.32872 .65092 .33115 .65303 .33617 .6308 .33259 .64978 Mtetra
.971 .723 .503 r
.33259 .64978 .33617 .6308 .34003 .62965 .3463 .46744 Mtetra
.555 .344 .548 r
.3463 .46744 .34003 .62965 .35228 .46847 .34999 .46623 Mtetra
.663 .742 .909 r
.34999 .46623 .35228 .46847 .35597 .46726 .35369 .46502 Mtetra
.35369 .46502 .35597 .46726 .35966 .46604 .35738 .4638 Mtetra
.35738 .4638 .35966 .46604 .36337 .46483 .36109 .46258 Mtetra
.36109 .46258 .36337 .46483 .36707 .46361 .3648 .46136 Mtetra
.3648 .46136 .36707 .46361 .37078 .46239 .36851 .46014 Mtetra
.36851 .46014 .37078 .46239 .3745 .46117 .37223 .45892 Mtetra
.37223 .45892 .3745 .46117 .37822 .45995 .37596 .45769 Mtetra
.37596 .45769 .37822 .45995 .38195 .45873 .37969 .45646 Mtetra
.37969 .45646 .38195 .45873 .38568 .4575 .38342 .45523 Mtetra
.38342 .45523 .38568 .4575 .38942 .45627 .38716 .454 Mtetra
.38716 .454 .38942 .45627 .39316 .45505 .39091 .45277 Mtetra
.39091 .45277 .39316 .45505 .39691 .45381 .39466 .45154 Mtetra
.39466 .45154 .39691 .45381 .40066 .45258 .39841 .4503 Mtetra
.39841 .4503 .40066 .45258 .40442 .45135 .40218 .44907 Mtetra
.40218 .44907 .40442 .45135 .40818 .45011 .40594 .44783 Mtetra
.40594 .44783 .40818 .45011 .41195 .44888 .40971 .44659 Mtetra
.40971 .44659 .41195 .44888 .41572 .44764 .41349 .44534 Mtetra
.41349 .44534 .41572 .44764 .4195 .4464 .41727 .4441 Mtetra
.41727 .4441 .4195 .4464 .42329 .44515 .42106 .44285 Mtetra
.42106 .44285 .42329 .44515 .42707 .44391 .42485 .44161 Mtetra
.42485 .44161 .42707 .44391 .43087 .44266 .42865 .44036 Mtetra
.42865 .44036 .43087 .44266 .43493 .43184 .43246 .43911 Mtetra
0 0 0 r
.43246 .43911 .43493 .43184 .43873 .43058 .43653 .42827 Mtetra
.664 .741 .908 r
.43653 .42827 .43873 .43058 .44253 .42933 .44033 .42701 Mtetra
.44033 .42701 .44253 .42933 .44633 .42807 .44414 .42575 Mtetra
.44414 .42575 .44633 .42807 .45015 .42682 .44795 .42449 Mtetra
.44795 .42449 .45015 .42682 .45396 .42556 .45177 .42323 Mtetra
.45177 .42323 .45396 .42556 .45778 .42429 .4556 .42196 Mtetra
.4556 .42196 .45778 .42429 .46161 .42303 .45943 .42069 Mtetra
.45943 .42069 .46161 .42303 .46544 .42177 .46326 .41943 Mtetra
.46326 .41943 .46544 .42177 .46928 .4205 .4671 .41816 Mtetra
.4671 .41816 .46928 .4205 .47312 .41923 .47095 .41688 Mtetra
.47095 .41688 .47312 .41923 .47697 .41796 .4748 .41561 Mtetra
.4748 .41561 .47697 .41796 .48083 .41669 .47866 .41433 Mtetra
.47866 .41433 .48083 .41669 .48468 .41541 .48252 .41306 Mtetra
.48252 .41306 .48468 .41541 .48855 .41414 .48639 .41178 Mtetra
.48639 .41178 .48855 .41414 .49242 .41286 .49026 .4105 Mtetra
.49026 .4105 .49242 .41286 .4963 .41158 .49414 .40921 Mtetra
.49414 .40921 .4963 .41158 .50018 .4103 .49803 .40793 Mtetra
.49803 .40793 .50018 .4103 .50406 .40902 .50192 .40664 Mtetra
.50192 .40664 .50406 .40902 .50796 .40773 .50581 .40535 Mtetra
.50581 .40535 .50796 .40773 .51185 .40644 .50972 .40406 Mtetra
.50972 .40406 .51185 .40644 .51576 .40516 .51362 .40277 Mtetra
.51362 .40277 .51576 .40516 .51967 .40387 .51754 .40148 Mtetra
.51754 .40148 .51967 .40387 .52358 .40257 .52145 .40018 Mtetra
.52145 .40018 .52358 .40257 .5275 .40128 .52538 .39889 Mtetra
.52538 .39889 .5275 .40128 .53143 .39998 .52931 .39759 Mtetra
.52931 .39759 .53143 .39998 .53536 .39869 .53324 .39628 Mtetra
.53324 .39628 .53536 .39869 .53929 .39739 .53718 .39498 Mtetra
.53718 .39498 .53929 .39739 .54324 .39608 .54113 .39368 Mtetra
.965 .669 .416 r
.54113 .39368 .54324 .39608 .54719 .39478 .54558 .4714 Mtetra
.543 .315 .52 r
.54558 .4714 .54719 .39478 .55178 .47249 .54963 .47012 Mtetra
.658 .749 .917 r
.54963 .47012 .55178 .47249 .55584 .47121 .55369 .46884 Mtetra
.55369 .46884 .55584 .47121 .55991 .46992 .55776 .46755 Mtetra
.55776 .46755 .55991 .46992 .56397 .46864 .56183 .46626 Mtetra
.56183 .46626 .56397 .46864 .56805 .46735 .56591 .46497 Mtetra
.56591 .46497 .56805 .46735 .57213 .46606 .57 .46368 Mtetra
.57 .46368 .57213 .46606 .57622 .46477 .57409 .46238 Mtetra
.57409 .46238 .57622 .46477 .58031 .46348 .57819 .46109 Mtetra
.57819 .46109 .58031 .46348 .58441 .46219 .58229 .45979 Mtetra
.58229 .45979 .58441 .46219 .58852 .46089 .5864 .45849 Mtetra
.5864 .45849 .58852 .46089 .59263 .45959 .59052 .45719 Mtetra
.59052 .45719 .59263 .45959 .59675 .45829 .59464 .45588 Mtetra
.59464 .45588 .59675 .45829 .59903 .37767 .59877 .45458 Mtetra
.543 .315 .52 r
.59877 .45458 .59903 .37767 .60306 .37634 .6029 .45327 Mtetra
.6029 .45327 .60306 .37634 .60709 .375 .60704 .45196 Mtetra
0 0 .353 r
.60704 .45196 .60709 .375 .61113 .37367 .60909 .3712 Mtetra
.664 .741 .908 r
.60909 .3712 .61113 .37367 .61518 .37233 .61314 .36986 Mtetra
.61314 .36986 .61518 .37233 .61923 .371 .6172 .36852 Mtetra
.6172 .36852 .61923 .371 .62329 .36966 .62126 .36718 Mtetra
.62126 .36718 .62329 .36966 .62735 .36832 .62533 .36583 Mtetra
.62533 .36583 .62735 .36832 .63142 .36697 .6294 .36449 Mtetra
.6294 .36449 .63142 .36697 .6355 .36563 .63348 .36314 Mtetra
.63348 .36314 .6355 .36563 .63958 .36428 .63756 .36179 Mtetra
.63756 .36179 .63958 .36428 .64367 .36293 .64166 .36043 Mtetra
.64166 .36043 .64367 .36293 .64776 .36158 .64575 .35908 Mtetra
.64575 .35908 .64776 .36158 .65186 .36023 .64986 .35772 Mtetra
.64986 .35772 .65186 .36023 .65596 .35887 .65397 .35636 Mtetra
.65397 .35636 .65596 .35887 .66008 .35751 .65808 .355 Mtetra
.65808 .355 .66008 .35751 .66419 .35615 .6622 .35364 Mtetra
.6622 .35364 .66419 .35615 .66832 .35479 .66633 .35228 Mtetra
.66633 .35228 .66832 .35479 .67245 .35343 .67046 .35091 Mtetra
.67046 .35091 .67245 .35343 .67658 .35207 .6746 .34954 Mtetra
.6746 .34954 .67658 .35207 .68072 .3507 .67875 .34817 Mtetra
.67875 .34817 .68072 .3507 .68487 .34933 .6829 .3468 Mtetra
.6829 .3468 .68487 .34933 .68902 .34796 .68706 .34542 Mtetra
.68706 .34542 .68902 .34796 .69318 .34658 .69122 .34404 Mtetra
.69122 .34404 .69318 .34658 .69842 .36482 .69539 .34267 Mtetra
.147 .097 .54 r
.69539 .34267 .69842 .36482 .70262 .36345 .70065 .36091 Mtetra
.662 .743 .91 r
.70065 .36091 .70262 .36345 .70682 .36208 .70486 .35954 Mtetra
.70486 .35954 .70682 .36208 .71103 .3607 .70908 .35816 Mtetra
.70908 .35816 .71103 .3607 .71525 .35933 .7133 .35678 Mtetra
.7133 .35678 .71525 .35933 .71947 .35795 .71752 .35539 Mtetra
.71752 .35539 .71947 .35795 .7237 .35657 .72176 .35401 Mtetra
.72176 .35401 .7237 .35657 .72794 .35518 .726 .35262 Mtetra
.726 .35262 .72794 .35518 .73218 .3538 .73025 .35123 Mtetra
.73025 .35123 .73218 .3538 .73643 .35241 .7345 .34984 Mtetra
.7345 .34984 .73643 .35241 .74068 .35102 .73876 .34845 Mtetra
.73876 .34845 .74068 .35102 .74495 .34963 .74302 .34705 Mtetra
.74302 .34705 .74495 .34963 .74921 .34823 .7473 .34565 Mtetra
.7473 .34565 .74921 .34823 .75349 .34684 .75158 .34425 Mtetra
.75158 .34425 .75349 .34684 .75777 .34544 .75586 .34285 Mtetra
.75586 .34285 .75777 .34544 .76205 .34404 .76015 .34145 Mtetra
.76015 .34145 .76205 .34404 .76635 .34264 .76445 .34004 Mtetra
.76445 .34004 .76635 .34264 .77065 .34123 .76875 .33863 Mtetra
.76875 .33863 .77065 .34123 .77495 .33983 .77306 .33722 Mtetra
.77306 .33722 .77495 .33983 .77927 .33842 .77738 .33581 Mtetra
.77738 .33581 .77927 .33842 .78359 .33701 .78171 .3344 Mtetra
.971 .653 .313 r
.78171 .3344 .78359 .33701 .78791 .33559 .79585 .45155 Mtetra
.545 .321 .526 r
.79585 .45155 .78791 .33559 .80228 .45271 .80035 .45017 Mtetra
.653 .754 .924 r
.80035 .45017 .80228 .45271 .80679 .45133 .80487 .44878 Mtetra
.80487 .44878 .80679 .45133 .81131 .44995 .80939 .4474 Mtetra
.80939 .4474 .81131 .44995 .81583 .44857 .81392 .44601 Mtetra
.81392 .44601 .81583 .44857 .82036 .44719 .81846 .44463 Mtetra
.81846 .44463 .82036 .44719 .8249 .4458 .823 .44324 Mtetra
.823 .44324 .8249 .4458 .82944 .44441 .82755 .44184 Mtetra
.82755 .44184 .82944 .44441 .834 .44302 .83211 .44045 Mtetra
.83211 .44045 .834 .44302 .83856 .44163 .83667 .43905 Mtetra
.83667 .43905 .83856 .44163 .84312 .44023 .84124 .43765 Mtetra
.84124 .43765 .84312 .44023 .8477 .43884 .84582 .43625 Mtetra
.84582 .43625 .8477 .43884 .85228 .43744 .85041 .43485 Mtetra
.85041 .43485 .85228 .43744 .85686 .43604 .855 .43344 Mtetra
.855 .43344 .85686 .43604 .86146 .43463 .8596 .43203 Mtetra
.8596 .43203 .86146 .43463 .86606 .43323 .86421 .43062 Mtetra
.86421 .43062 .86606 .43323 .87067 .43182 .86882 .42921 Mtetra
.86882 .42921 .87067 .43182 .87529 .43041 .87344 .4278 Mtetra
.87344 .4278 .87529 .43041 .87991 .42899 .87807 .42638 Mtetra
.87807 .42638 .87991 .42899 .88454 .42758 .88271 .42496 Mtetra
.88271 .42496 .88454 .42758 .88918 .42616 .88735 .42354 Mtetra
.648 .76 .931 r
.25745 .66918 .25995 .67124 .26372 .67012 .26122 .66806 Mtetra
.26122 .66806 .26372 .67012 .2675 .66901 .26501 .66694 Mtetra
.26501 .66694 .2675 .66901 .27129 .66789 .26879 .66582 Mtetra
.26879 .66582 .27129 .66789 .27508 .66677 .27259 .6647 Mtetra
.27259 .6647 .27508 .66677 .27887 .66565 .27639 .66357 Mtetra
.27639 .66357 .27887 .66565 .28267 .66452 .28019 .66245 Mtetra
.28019 .66245 .28267 .66452 .28648 .6634 .284 .66132 Mtetra
.284 .66132 .28648 .6634 .29029 .66227 .28782 .66019 Mtetra
.28782 .66019 .29029 .66227 .29411 .66115 .29164 .65906 Mtetra
.29164 .65906 .29411 .66115 .29793 .66002 .29546 .65793 Mtetra
.29546 .65793 .29793 .66002 .30176 .65889 .29929 .65679 Mtetra
.29929 .65679 .30176 .65889 .30559 .65775 .30313 .65566 Mtetra
.30313 .65566 .30559 .65775 .30943 .65662 .30698 .65452 Mtetra
.30698 .65452 .30943 .65662 .31328 .65548 .31082 .65338 Mtetra
.31082 .65338 .31328 .65548 .31713 .65434 .31468 .65224 Mtetra
.31468 .65224 .31713 .65434 .32099 .65321 .31854 .6511 Mtetra
.31854 .6511 .32099 .65321 .32485 .65206 .3224 .64995 Mtetra
.3224 .64995 .32485 .65206 .32872 .65092 .32627 .64881 Mtetra
.32627 .64881 .32872 .65092 .33259 .64978 .33015 .64766 Mtetra
.33015 .64766 .33259 .64978 .3463 .46744 .33403 .64651 Mtetra
0 0 .238 r
.33403 .64651 .3463 .46744 .34999 .46623 .3477 .46399 Mtetra
.663 .742 .909 r
.3477 .46399 .34999 .46623 .35369 .46502 .3514 .46277 Mtetra
.3514 .46277 .35369 .46502 .35738 .4638 .3551 .46155 Mtetra
.3551 .46155 .35738 .4638 .36109 .46258 .35881 .46033 Mtetra
.35881 .46033 .36109 .46258 .3648 .46136 .36252 .4591 Mtetra
.36252 .4591 .3648 .46136 .36851 .46014 .36624 .45788 Mtetra
.36624 .45788 .36851 .46014 .37223 .45892 .36996 .45665 Mtetra
.36996 .45665 .37223 .45892 .37596 .45769 .37369 .45542 Mtetra
.37369 .45542 .37596 .45769 .37969 .45646 .37742 .45419 Mtetra
.37742 .45419 .37969 .45646 .38342 .45523 .38116 .45296 Mtetra
.38116 .45296 .38342 .45523 .38716 .454 .3849 .45173 Mtetra
.3849 .45173 .38716 .454 .39091 .45277 .38865 .45049 Mtetra
.38865 .45049 .39091 .45277 .39466 .45154 .3924 .44926 Mtetra
.3924 .44926 .39466 .45154 .39841 .4503 .39616 .44802 Mtetra
.39616 .44802 .39841 .4503 .40218 .44907 .39993 .44678 Mtetra
.39993 .44678 .40218 .44907 .40594 .44783 .4037 .44554 Mtetra
.4037 .44554 .40594 .44783 .40971 .44659 .40747 .44429 Mtetra
.40747 .44429 .40971 .44659 .41349 .44534 .41125 .44305 Mtetra
.41125 .44305 .41349 .44534 .41727 .4441 .41504 .4418 Mtetra
.41504 .4418 .41727 .4441 .42106 .44285 .41883 .44055 Mtetra
.41883 .44055 .42106 .44285 .42485 .44161 .42263 .4393 Mtetra
.42263 .4393 .42485 .44161 .42865 .44036 .42643 .43805 Mtetra
.42643 .43805 .42865 .44036 .43246 .43911 .43024 .43679 Mtetra
.912 .748 .665 r
.43024 .43679 .43246 .43911 .43653 .42827 .43432 .42594 Mtetra
.664 .741 .908 r
.43432 .42594 .43653 .42827 .44033 .42701 .43812 .42468 Mtetra
.43812 .42468 .44033 .42701 .44414 .42575 .44193 .42342 Mtetra
.44193 .42342 .44414 .42575 .44795 .42449 .44575 .42216 Mtetra
.44575 .42216 .44795 .42449 .45177 .42323 .44958 .42089 Mtetra
.44958 .42089 .45177 .42323 .4556 .42196 .4534 .41962 Mtetra
.4534 .41962 .4556 .42196 .45943 .42069 .45724 .41835 Mtetra
.45724 .41835 .45943 .42069 .46326 .41943 .46108 .41708 Mtetra
.46108 .41708 .46326 .41943 .4671 .41816 .46492 .41581 Mtetra
.46492 .41581 .4671 .41816 .47095 .41688 .46877 .41453 Mtetra
.46877 .41453 .47095 .41688 .4748 .41561 .47263 .41325 Mtetra
.47263 .41325 .4748 .41561 .47866 .41433 .47649 .41197 Mtetra
.47649 .41197 .47866 .41433 .48252 .41306 .48035 .41069 Mtetra
.48035 .41069 .48252 .41306 .48639 .41178 .48423 .40941 Mtetra
.48423 .40941 .48639 .41178 .49026 .4105 .4881 .40813 Mtetra
.4881 .40813 .49026 .4105 .49414 .40921 .49199 .40684 Mtetra
.49199 .40684 .49414 .40921 .49803 .40793 .49587 .40555 Mtetra
.49587 .40555 .49803 .40793 .50192 .40664 .49977 .40426 Mtetra
.49977 .40426 .50192 .40664 .50581 .40535 .50367 .40297 Mtetra
.50367 .40297 .50581 .40535 .50972 .40406 .50757 .40168 Mtetra
.50757 .40168 .50972 .40406 .51362 .40277 .51148 .40038 Mtetra
.51148 .40038 .51362 .40277 .51754 .40148 .5154 .39909 Mtetra
.5154 .39909 .51754 .40148 .52145 .40018 .51932 .39779 Mtetra
.51932 .39779 .52145 .40018 .52538 .39889 .52325 .39649 Mtetra
.52325 .39649 .52538 .39889 .52931 .39759 .52718 .39518 Mtetra
.52718 .39518 .52931 .39759 .53324 .39628 .53112 .39388 Mtetra
.53112 .39388 .53324 .39628 .53718 .39498 .53506 .39257 Mtetra
.53506 .39257 .53718 .39498 .54113 .39368 .53901 .39126 Mtetra
.965 .669 .416 r
.53901 .39126 .54113 .39368 .54558 .4714 .54342 .46903 Mtetra
.658 .749 .917 r
.54342 .46903 .54558 .4714 .54963 .47012 .54747 .46775 Mtetra
.54747 .46775 .54963 .47012 .55369 .46884 .55154 .46646 Mtetra
.55154 .46646 .55369 .46884 .55776 .46755 .55561 .46517 Mtetra
.55561 .46517 .55776 .46755 .56183 .46626 .55969 .46388 Mtetra
.55969 .46388 .56183 .46626 .56591 .46497 .56377 .46258 Mtetra
.56377 .46258 .56591 .46497 .57 .46368 .56786 .46129 Mtetra
.56786 .46129 .57 .46368 .57409 .46238 .57196 .45999 Mtetra
.57196 .45999 .57409 .46238 .57819 .46109 .57606 .45869 Mtetra
.57606 .45869 .57819 .46109 .58229 .45979 .58016 .45739 Mtetra
.58016 .45739 .58229 .45979 .5864 .45849 .58428 .45609 Mtetra
.58428 .45609 .5864 .45849 .59052 .45719 .5884 .45478 Mtetra
.5884 .45478 .59052 .45719 .59464 .45588 .59252 .45347 Mtetra
.59252 .45347 .59464 .45588 .59877 .45458 .59666 .45216 Mtetra
.59666 .45216 .59877 .45458 .6029 .45327 .60079 .45085 Mtetra
.60079 .45085 .6029 .45327 .60704 .45196 .60494 .44954 Mtetra
.60494 .44954 .60704 .45196 .60909 .3712 .60909 .44822 Mtetra
.542 .314 .519 r
.60909 .44822 .60909 .3712 .61314 .36986 .61324 .44691 Mtetra
0 0 .355 r
.61324 .44691 .61314 .36986 .6172 .36852 .61516 .36604 Mtetra
.664 .741 .908 r
.61516 .36604 .6172 .36852 .62126 .36718 .61922 .3647 Mtetra
.61922 .3647 .62126 .36718 .62533 .36583 .62329 .36335 Mtetra
.62329 .36335 .62533 .36583 .6294 .36449 .62737 .362 Mtetra
.62737 .362 .6294 .36449 .63348 .36314 .63145 .36064 Mtetra
.63145 .36064 .63348 .36314 .63756 .36179 .63554 .35929 Mtetra
.63554 .35929 .63756 .36179 .64166 .36043 .63964 .35793 Mtetra
.63964 .35793 .64166 .36043 .64575 .35908 .64374 .35657 Mtetra
.64374 .35657 .64575 .35908 .64986 .35772 .64785 .35521 Mtetra
.64785 .35521 .64986 .35772 .65397 .35636 .65196 .35385 Mtetra
.65196 .35385 .65397 .35636 .65808 .355 .65608 .35249 Mtetra
.65608 .35249 .65808 .355 .6622 .35364 .66021 .35112 Mtetra
.66021 .35112 .6622 .35364 .66633 .35228 .66434 .34975 Mtetra
.66434 .34975 .66633 .35228 .67046 .35091 .66847 .34838 Mtetra
.66847 .34838 .67046 .35091 .6746 .34954 .67262 .34701 Mtetra
.67262 .34701 .6746 .34954 .67875 .34817 .67677 .34563 Mtetra
.67677 .34563 .67875 .34817 .6829 .3468 .68092 .34426 Mtetra
.68092 .34426 .6829 .3468 .68706 .34542 .68509 .34288 Mtetra
.68509 .34288 .68706 .34542 .69122 .34404 .68925 .3415 Mtetra
.68925 .3415 .69122 .34404 .69539 .34267 .69343 .34011 Mtetra
.69343 .34011 .69539 .34267 .70065 .36091 .69761 .33873 Mtetra
.147 .097 .54 r
.69761 .33873 .70065 .36091 .70486 .35954 .70289 .35699 Mtetra
.662 .743 .91 r
.70289 .35699 .70486 .35954 .70908 .35816 .70711 .35561 Mtetra
.70711 .35561 .70908 .35816 .7133 .35678 .71134 .35422 Mtetra
.71134 .35422 .7133 .35678 .71752 .35539 .71557 .35284 Mtetra
.71557 .35284 .71752 .35539 .72176 .35401 .71981 .35145 Mtetra
.71981 .35145 .72176 .35401 .726 .35262 .72406 .35006 Mtetra
.72406 .35006 .726 .35262 .73025 .35123 .72831 .34866 Mtetra
.72831 .34866 .73025 .35123 .7345 .34984 .73256 .34727 Mtetra
.73256 .34727 .7345 .34984 .73876 .34845 .73683 .34587 Mtetra
.73683 .34587 .73876 .34845 .74302 .34705 .7411 .34447 Mtetra
.7411 .34447 .74302 .34705 .7473 .34565 .74537 .34307 Mtetra
.74537 .34307 .7473 .34565 .75158 .34425 .74966 .34167 Mtetra
.74966 .34167 .75158 .34425 .75586 .34285 .75395 .34026 Mtetra
.75395 .34026 .75586 .34285 .76015 .34145 .75824 .33885 Mtetra
.75824 .33885 .76015 .34145 .76445 .34004 .76255 .33744 Mtetra
.76255 .33744 .76445 .34004 .76875 .33863 .76685 .33603 Mtetra
.76685 .33603 .76875 .33863 .77306 .33722 .77117 .33462 Mtetra
.77117 .33462 .77306 .33722 .77738 .33581 .77549 .3332 Mtetra
.77549 .3332 .77738 .33581 .78171 .3344 .77982 .33178 Mtetra
.971 .653 .313 r
.77982 .33178 .78171 .3344 .79585 .45155 .79391 .449 Mtetra
.653 .754 .924 r
.79391 .449 .79585 .45155 .80035 .45017 .79842 .44761 Mtetra
.79842 .44761 .80035 .45017 .80487 .44878 .80294 .44623 Mtetra
.80294 .44623 .80487 .44878 .80939 .4474 .80747 .44484 Mtetra
.80747 .44484 .80939 .4474 .81392 .44601 .812 .44345 Mtetra
.812 .44345 .81392 .44601 .81846 .44463 .81654 .44206 Mtetra
.81654 .44206 .81846 .44463 .823 .44324 .82109 .44066 Mtetra
.82109 .44066 .823 .44324 .82755 .44184 .82565 .43927 Mtetra
.82565 .43927 .82755 .44184 .83211 .44045 .83021 .43787 Mtetra
.83021 .43787 .83211 .44045 .83667 .43905 .83478 .43647 Mtetra
.83478 .43647 .83667 .43905 .84124 .43765 .83935 .43506 Mtetra
.83935 .43506 .84124 .43765 .84582 .43625 .84394 .43366 Mtetra
.84394 .43366 .84582 .43625 .85041 .43485 .84853 .43225 Mtetra
.84853 .43225 .85041 .43485 .855 .43344 .85313 .43084 Mtetra
.85313 .43084 .855 .43344 .8596 .43203 .85773 .42943 Mtetra
.85773 .42943 .8596 .43203 .86421 .43062 .86235 .42801 Mtetra
.86235 .42801 .86421 .43062 .86882 .42921 .86697 .4266 Mtetra
.86697 .4266 .86882 .42921 .87344 .4278 .87159 .42518 Mtetra
.87159 .42518 .87344 .4278 .87807 .42638 .87623 .42376 Mtetra
.87623 .42376 .87807 .42638 .88271 .42496 .88087 .42233 Mtetra
.88087 .42233 .88271 .42496 .88735 .42354 .88552 .42091 Mtetra
.648 .76 .931 r
.25494 .66711 .25745 .66918 .26122 .66806 .25872 .66599 Mtetra
.25872 .66599 .26122 .66806 .26501 .66694 .26251 .66487 Mtetra
.26251 .66487 .26501 .66694 .26879 .66582 .2663 .66375 Mtetra
.2663 .66375 .26879 .66582 .27259 .6647 .27009 .66262 Mtetra
.27009 .66262 .27259 .6647 .27639 .66357 .27389 .66149 Mtetra
.27389 .66149 .27639 .66357 .28019 .66245 .2777 .66036 Mtetra
.2777 .66036 .28019 .66245 .284 .66132 .28151 .65923 Mtetra
.28151 .65923 .284 .66132 .28782 .66019 .28533 .6581 Mtetra
.28533 .6581 .28782 .66019 .29164 .65906 .28916 .65697 Mtetra
.28916 .65697 .29164 .65906 .29546 .65793 .29299 .65583 Mtetra
.29299 .65583 .29546 .65793 .29929 .65679 .29682 .65469 Mtetra
.29682 .65469 .29929 .65679 .30313 .65566 .30066 .65356 Mtetra
.30066 .65356 .30313 .65566 .30698 .65452 .30451 .65242 Mtetra
.30451 .65242 .30698 .65452 .31082 .65338 .30836 .65127 Mtetra
.30836 .65127 .31082 .65338 .31468 .65224 .31222 .65013 Mtetra
.31222 .65013 .31468 .65224 .31854 .6511 .31608 .64898 Mtetra
.31608 .64898 .31854 .6511 .3224 .64995 .31995 .64784 Mtetra
.31995 .64784 .3224 .64995 .32627 .64881 .32383 .64669 Mtetra
.32383 .64669 .32627 .64881 .33015 .64766 .32771 .64554 Mtetra
.32771 .64554 .33015 .64766 .33403 .64651 .33159 .64439 Mtetra
.944 .691 .526 r
.33159 .64439 .33403 .64651 .3477 .46399 .3454 .46174 Mtetra
.663 .742 .909 r
.3454 .46174 .3477 .46399 .3514 .46277 .3491 .46051 Mtetra
.3491 .46051 .3514 .46277 .3551 .46155 .35281 .45929 Mtetra
.35281 .45929 .3551 .46155 .35881 .46033 .35652 .45807 Mtetra
.35652 .45807 .35881 .46033 .36252 .4591 .36023 .45684 Mtetra
.36023 .45684 .36252 .4591 .36624 .45788 .36395 .45561 Mtetra
.36395 .45561 .36624 .45788 .36996 .45665 .36768 .45438 Mtetra
.36768 .45438 .36996 .45665 .37369 .45542 .37141 .45315 Mtetra
.37141 .45315 .37369 .45542 .37742 .45419 .37515 .45192 Mtetra
.37515 .45192 .37742 .45419 .38116 .45296 .37889 .45068 Mtetra
.37889 .45068 .38116 .45296 .3849 .45173 .38264 .44945 Mtetra
.38264 .44945 .3849 .45173 .38865 .45049 .38639 .44821 Mtetra
.38639 .44821 .38865 .45049 .3924 .44926 .39015 .44697 Mtetra
.39015 .44697 .3924 .44926 .39616 .44802 .39391 .44573 Mtetra
.39391 .44573 .39616 .44802 .39993 .44678 .39768 .44448 Mtetra
.39768 .44448 .39993 .44678 .4037 .44554 .40145 .44324 Mtetra
.40145 .44324 .4037 .44554 .40747 .44429 .40523 .44199 Mtetra
.40523 .44199 .40747 .44429 .41125 .44305 .40901 .44074 Mtetra
.40901 .44074 .41125 .44305 .41504 .4418 .4128 .43949 Mtetra
.4128 .43949 .41504 .4418 .41883 .44055 .41659 .43824 Mtetra
.41659 .43824 .41883 .44055 .42263 .4393 .42039 .43698 Mtetra
.42039 .43698 .42263 .4393 .42643 .43805 .4242 .43573 Mtetra
.4242 .43573 .42643 .43805 .43024 .43679 .42801 .43447 Mtetra
.912 .748 .665 r
.42801 .43447 .43024 .43679 .43432 .42594 .4321 .42361 Mtetra
.664 .741 .908 r
.4321 .42361 .43432 .42594 .43812 .42468 .43591 .42235 Mtetra
.43591 .42235 .43812 .42468 .44193 .42342 .43973 .42108 Mtetra
.43973 .42108 .44193 .42342 .44575 .42216 .44355 .41982 Mtetra
.44355 .41982 .44575 .42216 .44958 .42089 .44737 .41855 Mtetra
.44737 .41855 .44958 .42089 .4534 .41962 .4512 .41728 Mtetra
.4512 .41728 .4534 .41962 .45724 .41835 .45504 .416 Mtetra
.45504 .416 .45724 .41835 .46108 .41708 .45888 .41473 Mtetra
.45888 .41473 .46108 .41708 .46492 .41581 .46273 .41345 Mtetra
.46273 .41345 .46492 .41581 .46877 .41453 .46659 .41217 Mtetra
.46659 .41217 .46877 .41453 .47263 .41325 .47045 .41089 Mtetra
.47045 .41089 .47263 .41325 .47649 .41197 .47431 .40961 Mtetra
.47431 .40961 .47649 .41197 .48035 .41069 .47818 .40832 Mtetra
.47818 .40832 .48035 .41069 .48423 .40941 .48205 .40704 Mtetra
.48205 .40704 .48423 .40941 .4881 .40813 .48594 .40575 Mtetra
.48594 .40575 .4881 .40813 .49199 .40684 .48982 .40446 Mtetra
.48982 .40446 .49199 .40684 .49587 .40555 .49371 .40317 Mtetra
.49371 .40317 .49587 .40555 .49977 .40426 .49761 .40188 Mtetra
.49761 .40188 .49977 .40426 .50367 .40297 .50151 .40058 Mtetra
.50151 .40058 .50367 .40297 .50757 .40168 .50542 .39928 Mtetra
.50542 .39928 .50757 .40168 .51148 .40038 .50934 .39799 Mtetra
.50934 .39799 .51148 .40038 .5154 .39909 .51326 .39669 Mtetra
.51326 .39669 .5154 .39909 .51932 .39779 .51718 .39538 Mtetra
.51718 .39538 .51932 .39779 .52325 .39649 .52111 .39408 Mtetra
.964 .676 .435 r
.52111 .39408 .52325 .39649 .52718 .39518 .52506 .50761 Mtetra
.544 .32 .525 r
.52506 .50761 .52718 .39518 .53112 .39388 .52914 .50634 Mtetra
.52914 .50634 .53112 .39388 .53506 .39257 .53323 .50507 Mtetra
.53323 .50507 .53506 .39257 .53901 .39126 .53732 .50379 Mtetra
.41 .214 .501 r
.53732 .50379 .53901 .39126 .54342 .46903 .54125 .46666 Mtetra
.658 .749 .917 r
.54125 .46666 .54342 .46903 .54747 .46775 .54531 .46537 Mtetra
.54531 .46537 .54747 .46775 .55154 .46646 .54938 .46408 Mtetra
.54938 .46408 .55154 .46646 .55561 .46517 .55346 .46278 Mtetra
.55346 .46278 .55561 .46517 .55969 .46388 .55754 .46149 Mtetra
.55754 .46149 .55969 .46388 .56377 .46258 .56162 .46019 Mtetra
.56162 .46019 .56377 .46258 .56786 .46129 .56572 .45889 Mtetra
.56572 .45889 .56786 .46129 .57196 .45999 .56982 .45759 Mtetra
.56982 .45759 .57196 .45999 .57606 .45869 .57392 .45629 Mtetra
.57392 .45629 .57606 .45869 .58016 .45739 .57803 .45498 Mtetra
.57803 .45498 .58016 .45739 .58428 .45609 .58215 .45367 Mtetra
.58215 .45367 .58428 .45609 .5884 .45478 .58627 .45236 Mtetra
.58627 .45236 .5884 .45478 .59252 .45347 .5904 .45105 Mtetra
.5904 .45105 .59252 .45347 .59666 .45216 .59454 .44974 Mtetra
.59454 .44974 .59666 .45216 .60079 .45085 .59868 .44843 Mtetra
.59868 .44843 .60079 .45085 .60494 .44954 .60283 .44711 Mtetra
.60283 .44711 .60494 .44954 .60909 .44822 .60698 .44579 Mtetra
.60698 .44579 .60909 .44822 .61324 .44691 .61115 .44447 Mtetra
.61115 .44447 .61324 .44691 .61516 .36604 .61531 .44315 Mtetra
0 0 .355 r
.61531 .44315 .61516 .36604 .61922 .3647 .61718 .3622 Mtetra
.664 .741 .908 r
.61718 .3622 .61922 .3647 .62329 .36335 .62125 .36085 Mtetra
.62125 .36085 .62329 .36335 .62737 .362 .62534 .3595 Mtetra
.62534 .3595 .62737 .362 .63145 .36064 .62942 .35814 Mtetra
.62942 .35814 .63145 .36064 .63554 .35929 .63352 .35678 Mtetra
.63352 .35678 .63554 .35929 .63964 .35793 .63762 .35542 Mtetra
.63762 .35542 .63964 .35793 .64374 .35657 .64172 .35406 Mtetra
.64172 .35406 .64374 .35657 .64785 .35521 .64583 .3527 Mtetra
.64583 .3527 .64785 .35521 .65196 .35385 .64995 .35133 Mtetra
.64995 .35133 .65196 .35385 .65608 .35249 .65407 .34996 Mtetra
.65407 .34996 .65608 .35249 .66021 .35112 .6582 .34859 Mtetra
.6582 .34859 .66021 .35112 .66434 .34975 .66234 .34722 Mtetra
.66234 .34722 .66434 .34975 .66847 .34838 .66648 .34584 Mtetra
.66648 .34584 .66847 .34838 .67262 .34701 .67063 .34447 Mtetra
.67063 .34447 .67262 .34701 .67677 .34563 .67478 .34309 Mtetra
.67478 .34309 .67677 .34563 .68092 .34426 .67894 .34171 Mtetra
.67894 .34171 .68092 .34426 .68509 .34288 .68311 .34033 Mtetra
.68311 .34033 .68509 .34288 .68925 .3415 .68728 .33894 Mtetra
.68728 .33894 .68925 .3415 .69343 .34011 .69146 .33756 Mtetra
.69146 .33756 .69343 .34011 .69761 .33873 .69564 .33617 Mtetra
.69564 .33617 .69761 .33873 .70289 .35699 .69983 .33478 Mtetra
.147 .097 .54 r
.69983 .33478 .70289 .35699 .70711 .35561 .70515 .35305 Mtetra
.662 .743 .91 r
.70515 .35305 .70711 .35561 .71134 .35422 .70938 .35166 Mtetra
.70938 .35166 .71134 .35422 .71557 .35284 .71361 .35027 Mtetra
.71361 .35027 .71557 .35284 .71981 .35145 .71786 .34888 Mtetra
.71786 .34888 .71981 .35145 .72406 .35006 .72211 .34748 Mtetra
.72211 .34748 .72406 .35006 .72831 .34866 .72636 .34608 Mtetra
.72636 .34608 .72831 .34866 .73256 .34727 .73062 .34469 Mtetra
.73062 .34469 .73256 .34727 .73683 .34587 .73489 .34328 Mtetra
.73489 .34328 .73683 .34587 .7411 .34447 .73917 .34188 Mtetra
.73917 .34188 .7411 .34447 .74537 .34307 .74345 .34048 Mtetra
.74345 .34048 .74537 .34307 .74966 .34167 .74774 .33907 Mtetra
.74774 .33907 .74966 .34167 .75395 .34026 .75203 .33766 Mtetra
.75203 .33766 .75395 .34026 .75824 .33885 .75633 .33625 Mtetra
.75633 .33625 .75824 .33885 .76255 .33744 .76064 .33483 Mtetra
.76064 .33483 .76255 .33744 .76685 .33603 .76495 .33342 Mtetra
.76495 .33342 .76685 .33603 .77117 .33462 .76927 .332 Mtetra
.76927 .332 .77117 .33462 .77549 .3332 .7736 .33058 Mtetra
.971 .654 .315 r
.7736 .33058 .77549 .3332 .77982 .33178 .78746 .44783 Mtetra
.544 .32 .525 r
.78746 .44783 .77982 .33178 .79391 .449 .79197 .44644 Mtetra
.653 .754 .924 r
.79197 .44644 .79391 .449 .79842 .44761 .79648 .44505 Mtetra
.79648 .44505 .79842 .44761 .80294 .44623 .80101 .44366 Mtetra
.80101 .44366 .80294 .44623 .80747 .44484 .80554 .44227 Mtetra
.80554 .44227 .80747 .44484 .812 .44345 .81008 .44088 Mtetra
.81008 .44088 .812 .44345 .81654 .44206 .81463 .43948 Mtetra
.81463 .43948 .81654 .44206 .82109 .44066 .81918 .43808 Mtetra
.81918 .43808 .82109 .44066 .82565 .43927 .82374 .43668 Mtetra
.82374 .43668 .82565 .43927 .83021 .43787 .82831 .43528 Mtetra
.82831 .43528 .83021 .43787 .83478 .43647 .83288 .43387 Mtetra
.83288 .43387 .83478 .43647 .83935 .43506 .83746 .43247 Mtetra
.83746 .43247 .83935 .43506 .84394 .43366 .84205 .43106 Mtetra
.84205 .43106 .84394 .43366 .84853 .43225 .84665 .42965 Mtetra
.84665 .42965 .84853 .43225 .85313 .43084 .85125 .42823 Mtetra
.85125 .42823 .85313 .43084 .85773 .42943 .85586 .42682 Mtetra
.85586 .42682 .85773 .42943 .86235 .42801 .86048 .4254 Mtetra
.86048 .4254 .86235 .42801 .86697 .4266 .86511 .42398 Mtetra
.86511 .42398 .86697 .4266 .87159 .42518 .86974 .42255 Mtetra
.86974 .42255 .87159 .42518 .87623 .42376 .87438 .42113 Mtetra
.87438 .42113 .87623 .42376 .88087 .42233 .87903 .4197 Mtetra
.87903 .4197 .88087 .42233 .88552 .42091 .88368 .41827 Mtetra
.648 .76 .931 r
.25242 .66504 .25494 .66711 .25872 .66599 .25621 .66392 Mtetra
.25621 .66392 .25872 .66599 .26251 .66487 .26 .66279 Mtetra
.26 .66279 .26251 .66487 .2663 .66375 .26379 .66167 Mtetra
.26379 .66167 .2663 .66375 .27009 .66262 .26759 .66054 Mtetra
.26759 .66054 .27009 .66262 .27389 .66149 .2714 .65941 Mtetra
.2714 .65941 .27389 .66149 .2777 .66036 .27521 .65828 Mtetra
.27521 .65828 .2777 .66036 .28151 .65923 .27902 .65714 Mtetra
.27902 .65714 .28151 .65923 .28533 .6581 .28284 .65601 Mtetra
.28284 .65601 .28533 .6581 .28916 .65697 .28667 .65487 Mtetra
.28667 .65487 .28916 .65697 .29299 .65583 .29051 .65373 Mtetra
.29051 .65373 .29299 .65583 .29682 .65469 .29434 .65259 Mtetra
.29434 .65259 .29682 .65469 .30066 .65356 .29819 .65145 Mtetra
.29819 .65145 .30066 .65356 .30451 .65242 .30204 .65031 Mtetra
.30204 .65031 .30451 .65242 .30836 .65127 .30589 .64916 Mtetra
.30589 .64916 .30836 .65127 .31222 .65013 .30975 .64801 Mtetra
.30975 .64801 .31222 .65013 .31608 .64898 .31362 .64687 Mtetra
.31362 .64687 .31608 .64898 .31995 .64784 .31749 .64572 Mtetra
.31749 .64572 .31995 .64784 .32383 .64669 .32137 .64456 Mtetra
.32137 .64456 .32383 .64669 .32771 .64554 .32526 .64341 Mtetra
.32526 .64341 .32771 .64554 .33159 .64439 .32914 .64225 Mtetra
.944 .691 .526 r
.32914 .64225 .33159 .64439 .3454 .46174 .3431 .45948 Mtetra
.663 .742 .909 r
.3431 .45948 .3454 .46174 .3491 .46051 .3468 .45826 Mtetra
.3468 .45826 .3491 .46051 .35281 .45929 .35051 .45703 Mtetra
.35051 .45703 .35281 .45929 .35652 .45807 .35422 .4558 Mtetra
.35422 .4558 .35652 .45807 .36023 .45684 .35794 .45457 Mtetra
.35794 .45457 .36023 .45684 .36395 .45561 .36167 .45334 Mtetra
.36167 .45334 .36395 .45561 .36768 .45438 .3654 .45211 Mtetra
.3654 .45211 .36768 .45438 .37141 .45315 .36913 .45087 Mtetra
.36913 .45087 .37141 .45315 .37515 .45192 .37287 .44964 Mtetra
.37287 .44964 .37515 .45192 .37889 .45068 .37661 .4484 Mtetra
.37661 .4484 .37889 .45068 .38264 .44945 .38036 .44716 Mtetra
.38036 .44716 .38264 .44945 .38639 .44821 .38412 .44592 Mtetra
.38412 .44592 .38639 .44821 .39015 .44697 .38788 .44467 Mtetra
.38788 .44467 .39015 .44697 .39391 .44573 .39165 .44343 Mtetra
.39165 .44343 .39391 .44573 .39768 .44448 .39542 .44218 Mtetra
.39542 .44218 .39768 .44448 .40145 .44324 .39919 .44093 Mtetra
.39919 .44093 .40145 .44324 .40523 .44199 .40298 .43968 Mtetra
.40298 .43968 .40523 .44199 .40901 .44074 .40676 .43843 Mtetra
.40676 .43843 .40901 .44074 .4128 .43949 .41056 .43718 Mtetra
.41056 .43718 .4128 .43949 .41659 .43824 .41435 .43592 Mtetra
.41435 .43592 .41659 .43824 .42039 .43698 .41816 .43466 Mtetra
.41816 .43466 .42039 .43698 .4242 .43573 .42196 .43341 Mtetra
.42196 .43341 .4242 .43573 .42801 .43447 .42578 .43214 Mtetra
.869 .765 .745 r
.42578 .43214 .42801 .43447 .4321 .42361 .42974 .42607 Mtetra
.189 0 0 r
.42974 .42607 .4321 .42361 .43591 .42235 .43356 .42481 Mtetra
.43356 .42481 .43591 .42235 .43973 .42108 .43738 .42354 Mtetra
.43738 .42354 .43973 .42108 .44355 .41982 .44121 .42227 Mtetra
.44121 .42227 .44355 .41982 .44737 .41855 .44505 .421 Mtetra
.44505 .421 .44737 .41855 .4512 .41728 .44889 .41973 Mtetra
.44889 .41973 .4512 .41728 .45504 .416 .45273 .41845 Mtetra
.45273 .41845 .45504 .416 .45888 .41473 .45659 .41717 Mtetra
.45659 .41717 .45888 .41473 .46273 .41345 .46044 .41589 Mtetra
.46044 .41589 .46273 .41345 .46659 .41217 .46431 .41461 Mtetra
.46431 .41461 .46659 .41217 .47045 .41089 .46817 .41333 Mtetra
.46817 .41333 .47045 .41089 .47431 .40961 .47205 .41205 Mtetra
.47205 .41205 .47431 .40961 .47818 .40832 .47593 .41076 Mtetra
.47593 .41076 .47818 .40832 .48205 .40704 .47981 .40947 Mtetra
.47981 .40947 .48205 .40704 .48594 .40575 .4837 .40818 Mtetra
.797 .937 .576 r
.4837 .40818 .48594 .40575 .48982 .40446 .48765 .40208 Mtetra
.664 .741 .908 r
.48765 .40208 .48982 .40446 .49371 .40317 .49155 .40078 Mtetra
.49155 .40078 .49371 .40317 .49761 .40188 .49545 .39948 Mtetra
.49545 .39948 .49761 .40188 .50151 .40058 .49936 .39819 Mtetra
.963 .676 .443 r
.49936 .39819 .50151 .40058 .50542 .39928 .5025 .5116 Mtetra
.544 .319 .524 r
.5025 .5116 .50542 .39928 .50934 .39799 .50656 .51034 Mtetra
.50656 .51034 .50934 .39799 .51326 .39669 .51062 .50907 Mtetra
.51062 .50907 .51326 .39669 .51718 .39538 .51469 .5078 Mtetra
.51469 .5078 .51718 .39538 .52111 .39408 .51876 .50653 Mtetra
.51876 .50653 .52111 .39408 .52506 .50761 .52284 .50526 Mtetra
.655 .752 .922 r
.52284 .50526 .52506 .50761 .52914 .50634 .52693 .50399 Mtetra
.52693 .50399 .52914 .50634 .53323 .50507 .53102 .50271 Mtetra
.53102 .50271 .53323 .50507 .53732 .50379 .53512 .50144 Mtetra
.959 .719 .532 r
.53512 .50144 .53732 .50379 .54125 .46666 .53907 .46428 Mtetra
.658 .749 .917 r
.53907 .46428 .54125 .46666 .54531 .46537 .54314 .46298 Mtetra
.54314 .46298 .54531 .46537 .54938 .46408 .54721 .46169 Mtetra
.54721 .46169 .54938 .46408 .55346 .46278 .55129 .46039 Mtetra
.55129 .46039 .55346 .46278 .55754 .46149 .55538 .45909 Mtetra
.55538 .45909 .55754 .46149 .56162 .46019 .55947 .45779 Mtetra
.55947 .45779 .56162 .46019 .56572 .45889 .56357 .45649 Mtetra
.56357 .45649 .56572 .45889 .56982 .45759 .56767 .45518 Mtetra
.56767 .45518 .56982 .45759 .57392 .45629 .57178 .45388 Mtetra
.57178 .45388 .57392 .45629 .57803 .45498 .5759 .45257 Mtetra
.5759 .45257 .57803 .45498 .58215 .45367 .58002 .45126 Mtetra
.58002 .45126 .58215 .45367 .58627 .45236 .58414 .44994 Mtetra
.58414 .44994 .58627 .45236 .5904 .45105 .58828 .44863 Mtetra
.58828 .44863 .5904 .45105 .59454 .44974 .59242 .44731 Mtetra
.59242 .44731 .59454 .44974 .59868 .44843 .59656 .44599 Mtetra
.59656 .44599 .59868 .44843 .60283 .44711 .60072 .44467 Mtetra
.60072 .44467 .60283 .44711 .60698 .44579 .60488 .44335 Mtetra
.60488 .44335 .60698 .44579 .61115 .44447 .60904 .44203 Mtetra
.60904 .44203 .61115 .44447 .61531 .44315 .61321 .4407 Mtetra
.971 .703 .469 r
.61321 .4407 .61531 .44315 .61718 .3622 .61513 .35971 Mtetra
.664 .741 .908 r
.61513 .35971 .61718 .3622 .62125 .36085 .61921 .35835 Mtetra
.61921 .35835 .62125 .36085 .62534 .3595 .62329 .35699 Mtetra
.62329 .35699 .62534 .3595 .62942 .35814 .62739 .35563 Mtetra
.62739 .35563 .62942 .35814 .63352 .35678 .63148 .35427 Mtetra
.63148 .35427 .63352 .35678 .63762 .35542 .63559 .35291 Mtetra
.63559 .35291 .63762 .35542 .64172 .35406 .6397 .35154 Mtetra
.6397 .35154 .64172 .35406 .64583 .3527 .64381 .35017 Mtetra
.64381 .35017 .64583 .3527 .64995 .35133 .64793 .3488 Mtetra
.64793 .3488 .64995 .35133 .65407 .34996 .65206 .34743 Mtetra
.65206 .34743 .65407 .34996 .6582 .34859 .6562 .34606 Mtetra
.6562 .34606 .6582 .34859 .66234 .34722 .66033 .34468 Mtetra
.66033 .34468 .66234 .34722 .66648 .34584 .66448 .3433 Mtetra
.66448 .3433 .66648 .34584 .67063 .34447 .66863 .34192 Mtetra
.66863 .34192 .67063 .34447 .67478 .34309 .67279 .34054 Mtetra
.67279 .34054 .67478 .34309 .67894 .34171 .67696 .33916 Mtetra
.67696 .33916 .67894 .34171 .68311 .34033 .68113 .33777 Mtetra
.68113 .33777 .68311 .34033 .68728 .33894 .6853 .33638 Mtetra
.6853 .33638 .68728 .33894 .69146 .33756 .68948 .33499 Mtetra
.68948 .33499 .69146 .33756 .69564 .33617 .69367 .3336 Mtetra
.69367 .3336 .69564 .33617 .69983 .33478 .69787 .3322 Mtetra
.69787 .3322 .69983 .33478 .70515 .35305 .70207 .33081 Mtetra
.147 .097 .54 r
.70207 .33081 .70515 .35305 .70938 .35166 .70741 .34909 Mtetra
.662 .743 .91 r
.70741 .34909 .70938 .35166 .71361 .35027 .71165 .3477 Mtetra
.71165 .3477 .71361 .35027 .71786 .34888 .7159 .3463 Mtetra
.7159 .3463 .71786 .34888 .72211 .34748 .72015 .3449 Mtetra
.72015 .3449 .72211 .34748 .72636 .34608 .72441 .3435 Mtetra
.72441 .3435 .72636 .34608 .73062 .34469 .72868 .3421 Mtetra
.72868 .3421 .73062 .34469 .73489 .34328 .73295 .34069 Mtetra
.73295 .34069 .73489 .34328 .73917 .34188 .73723 .33928 Mtetra
.73723 .33928 .73917 .34188 .74345 .34048 .74152 .33788 Mtetra
.74152 .33788 .74345 .34048 .74774 .33907 .74581 .33646 Mtetra
.74581 .33646 .74774 .33907 .75203 .33766 .75011 .33505 Mtetra
.75011 .33505 .75203 .33766 .75633 .33625 .75441 .33363 Mtetra
.75441 .33363 .75633 .33625 .76064 .33483 .75872 .33222 Mtetra
.75872 .33222 .76064 .33483 .76495 .33342 .76304 .3308 Mtetra
.76304 .3308 .76495 .33342 .76927 .332 .76736 .32938 Mtetra
.76736 .32938 .76927 .332 .7736 .33058 .7717 .32795 Mtetra
.971 .654 .315 r
.7717 .32795 .7736 .33058 .78746 .44783 .7855 .44527 Mtetra
.653 .754 .924 r
.7855 .44527 .78746 .44783 .79197 .44644 .79002 .44388 Mtetra
.79002 .44388 .79197 .44644 .79648 .44505 .79454 .44249 Mtetra
.79454 .44249 .79648 .44505 .80101 .44366 .79907 .44109 Mtetra
.79907 .44109 .80101 .44366 .80554 .44227 .80361 .4397 Mtetra
.80361 .4397 .80554 .44227 .81008 .44088 .80815 .4383 Mtetra
.80815 .4383 .81008 .44088 .81463 .43948 .8127 .4369 Mtetra
.8127 .4369 .81463 .43948 .81918 .43808 .81726 .4355 Mtetra
.81726 .4355 .81918 .43808 .82374 .43668 .82183 .43409 Mtetra
.82183 .43409 .82374 .43668 .82831 .43528 .8264 .43268 Mtetra
.8264 .43268 .82831 .43528 .83288 .43387 .83098 .43128 Mtetra
.83098 .43128 .83288 .43387 .83746 .43247 .83556 .42986 Mtetra
.83556 .42986 .83746 .43247 .84205 .43106 .84016 .42845 Mtetra
.84016 .42845 .84205 .43106 .84665 .42965 .84476 .42703 Mtetra
.84476 .42703 .84665 .42965 .85125 .42823 .84937 .42562 Mtetra
.84937 .42562 .85125 .42823 .85586 .42682 .85398 .4242 Mtetra
.85398 .4242 .85586 .42682 .86048 .4254 .85861 .42277 Mtetra
.85861 .42277 .86048 .4254 .86511 .42398 .86324 .42135 Mtetra
.86324 .42135 .86511 .42398 .86974 .42255 .86788 .41992 Mtetra
.86788 .41992 .86974 .42255 .87438 .42113 .87252 .41849 Mtetra
.87252 .41849 .87438 .42113 .87903 .4197 .87718 .41706 Mtetra
.87718 .41706 .87903 .4197 .88368 .41827 .88184 .41563 Mtetra
.648 .76 .931 r
.2499 .66297 .25242 .66504 .25621 .66392 .25369 .66184 Mtetra
.25369 .66184 .25621 .66392 .26 .66279 .25748 .66071 Mtetra
.25748 .66071 .26 .66279 .26379 .66167 .26128 .65958 Mtetra
.26128 .65958 .26379 .66167 .26759 .66054 .26508 .65845 Mtetra
.26508 .65845 .26759 .66054 .2714 .65941 .26889 .65732 Mtetra
.26889 .65732 .2714 .65941 .27521 .65828 .2727 .65618 Mtetra
.2727 .65618 .27521 .65828 .27902 .65714 .27652 .65504 Mtetra
.27652 .65504 .27902 .65714 .28284 .65601 .28035 .65391 Mtetra
.28035 .65391 .28284 .65601 .28667 .65487 .28418 .65277 Mtetra
.28418 .65277 .28667 .65487 .29051 .65373 .28802 .65163 Mtetra
.28802 .65163 .29051 .65373 .29434 .65259 .29186 .65048 Mtetra
.29186 .65048 .29434 .65259 .29819 .65145 .29571 .64934 Mtetra
.29571 .64934 .29819 .65145 .30204 .65031 .29956 .64819 Mtetra
.29956 .64819 .30204 .65031 .30589 .64916 .30342 .64704 Mtetra
.30342 .64704 .30589 .64916 .30975 .64801 .30728 .64589 Mtetra
.30728 .64589 .30975 .64801 .31362 .64687 .31115 .64474 Mtetra
.31115 .64474 .31362 .64687 .31749 .64572 .31503 .64359 Mtetra
.31503 .64359 .31749 .64572 .32137 .64456 .31891 .64243 Mtetra
.31891 .64243 .32137 .64456 .32526 .64341 .3228 .64128 Mtetra
.3228 .64128 .32526 .64341 .32914 .64225 .32669 .64012 Mtetra
.32669 .64012 .32914 .64225 .3431 .45948 .33059 .63896 Mtetra
0 0 .233 r
.33059 .63896 .3431 .45948 .3468 .45826 .3445 .45599 Mtetra
.663 .742 .909 r
.3445 .45599 .3468 .45826 .35051 .45703 .34821 .45476 Mtetra
.34821 .45476 .35051 .45703 .35422 .4558 .35192 .45353 Mtetra
.35192 .45353 .35422 .4558 .35794 .45457 .35565 .4523 Mtetra
.35565 .4523 .35794 .45457 .36167 .45334 .35937 .45106 Mtetra
.35937 .45106 .36167 .45334 .3654 .45211 .36311 .44983 Mtetra
.36311 .44983 .3654 .45211 .36913 .45087 .36684 .44859 Mtetra
.36684 .44859 .36913 .45087 .37287 .44964 .37059 .44735 Mtetra
.37059 .44735 .37287 .44964 .37661 .4484 .37433 .44611 Mtetra
.37433 .44611 .37661 .4484 .38036 .44716 .37809 .44487 Mtetra
.37809 .44487 .38036 .44716 .38412 .44592 .38185 .44362 Mtetra
.38185 .44362 .38412 .44592 .38788 .44467 .38561 .44237 Mtetra
.38561 .44237 .38788 .44467 .39165 .44343 .38938 .44113 Mtetra
.38938 .44113 .39165 .44343 .39542 .44218 .39315 .43988 Mtetra
.39315 .43988 .39542 .44218 .39919 .44093 .39693 .43862 Mtetra
.39693 .43862 .39919 .44093 .40298 .43968 .40072 .43737 Mtetra
.40072 .43737 .40298 .43968 .40676 .43843 .40451 .43612 Mtetra
.40451 .43612 .40676 .43843 .41056 .43718 .4083 .43486 Mtetra
.4083 .43486 .41056 .43718 .41435 .43592 .41211 .4336 Mtetra
.41211 .4336 .41435 .43592 .41816 .43466 .41591 .43234 Mtetra
.41591 .43234 .41816 .43466 .42196 .43341 .41972 .43108 Mtetra
.869 .764 .745 r
.41972 .43108 .42196 .43341 .42578 .43214 .42369 .425 Mtetra
.62 .517 .715 r
.42369 .425 .42578 .43214 .42974 .42607 .42751 .42373 Mtetra
.663 .742 .908 r
.42751 .42373 .42974 .42607 .43356 .42481 .43133 .42247 Mtetra
.43133 .42247 .43356 .42481 .43738 .42354 .43516 .42119 Mtetra
.43516 .42119 .43738 .42354 .44121 .42227 .43899 .41992 Mtetra
.43899 .41992 .44121 .42227 .44505 .421 .44283 .41865 Mtetra
.44283 .41865 .44505 .421 .44889 .41973 .44667 .41737 Mtetra
.44667 .41737 .44889 .41973 .45273 .41845 .45052 .41609 Mtetra
.45052 .41609 .45273 .41845 .45659 .41717 .45438 .41481 Mtetra
.45438 .41481 .45659 .41717 .46044 .41589 .45824 .41353 Mtetra
.45824 .41353 .46044 .41589 .46431 .41461 .46211 .41225 Mtetra
.46211 .41225 .46431 .41461 .46817 .41333 .46598 .41096 Mtetra
.46598 .41096 .46817 .41333 .47205 .41205 .46986 .40967 Mtetra
.46986 .40967 .47205 .41205 .47593 .41076 .47374 .40838 Mtetra
.47374 .40838 .47593 .41076 .47981 .40947 .47763 .40709 Mtetra
.47763 .40709 .47981 .40947 .4837 .40818 .48152 .4058 Mtetra
.48152 .4058 .4837 .40818 .48765 .40208 .48542 .4045 Mtetra
.951 .664 .46 r
.48542 .4045 .48765 .40208 .49155 .40078 .48811 .51305 Mtetra
.543 .319 .524 r
.48811 .51305 .49155 .40078 .49545 .39948 .49216 .51179 Mtetra
.49216 .51179 .49545 .39948 .49936 .39819 .49621 .51053 Mtetra
.49621 .51053 .49936 .39819 .5025 .5116 .50026 .50926 Mtetra
.655 .752 .922 r
.50026 .50926 .5025 .5116 .50656 .51034 .50432 .508 Mtetra
.50432 .508 .50656 .51034 .51062 .50907 .50839 .50673 Mtetra
.50839 .50673 .51062 .50907 .51469 .5078 .51246 .50546 Mtetra
.51246 .50546 .51469 .5078 .51876 .50653 .51654 .50418 Mtetra
.51654 .50418 .51876 .50653 .52284 .50526 .52063 .50291 Mtetra
.52063 .50291 .52284 .50526 .52693 .50399 .52472 .50163 Mtetra
.52472 .50163 .52693 .50399 .53102 .50271 .52881 .50035 Mtetra
.52881 .50035 .53102 .50271 .53512 .50144 .53292 .49907 Mtetra
.53292 .49907 .53512 .50144 .53907 .46428 .53703 .49779 Mtetra
0 0 .261 r
.53703 .49779 .53907 .46428 .54314 .46298 .54097 .46059 Mtetra
.658 .749 .917 r
.54097 .46059 .54314 .46298 .54721 .46169 .54504 .45929 Mtetra
.54504 .45929 .54721 .46169 .55129 .46039 .54913 .45799 Mtetra
.54913 .45799 .55129 .46039 .55538 .45909 .55322 .45669 Mtetra
.55322 .45669 .55538 .45909 .55947 .45779 .55731 .45538 Mtetra
.55731 .45538 .55947 .45779 .56357 .45649 .56141 .45408 Mtetra
.56141 .45408 .56357 .45649 .56767 .45518 .56552 .45277 Mtetra
.56552 .45277 .56767 .45518 .57178 .45388 .56963 .45146 Mtetra
.56963 .45146 .57178 .45388 .5759 .45257 .57375 .45015 Mtetra
.57375 .45015 .5759 .45257 .58002 .45126 .57788 .44883 Mtetra
.57788 .44883 .58002 .45126 .58414 .44994 .58201 .44751 Mtetra
.58201 .44751 .58414 .44994 .58828 .44863 .58615 .4462 Mtetra
.58615 .4462 .58828 .44863 .59242 .44731 .59029 .44488 Mtetra
.59029 .44488 .59242 .44731 .59656 .44599 .59444 .44355 Mtetra
.59444 .44355 .59656 .44599 .60072 .44467 .5986 .44223 Mtetra
.5986 .44223 .60072 .44467 .60488 .44335 .60276 .4409 Mtetra
.60276 .4409 .60488 .44335 .60904 .44203 .60693 .43958 Mtetra
.60693 .43958 .60904 .44203 .61321 .4407 .61111 .43825 Mtetra
.61111 .43825 .61321 .4407 .61513 .35971 .61529 .43691 Mtetra
0 0 .353 r
.61529 .43691 .61513 .35971 .61921 .35835 .61716 .35584 Mtetra
.664 .741 .908 r
.61716 .35584 .61921 .35835 .62329 .35699 .62125 .35448 Mtetra
.62125 .35448 .62329 .35699 .62739 .35563 .62534 .35312 Mtetra
.62534 .35312 .62739 .35563 .63148 .35427 .62945 .35175 Mtetra
.62945 .35175 .63148 .35427 .63559 .35291 .63355 .35038 Mtetra
.63355 .35038 .63559 .35291 .6397 .35154 .63767 .34901 Mtetra
.63767 .34901 .6397 .35154 .64381 .35017 .64179 .34764 Mtetra
.64179 .34764 .64381 .35017 .64793 .3488 .64591 .34627 Mtetra
.64591 .34627 .64793 .3488 .65206 .34743 .65004 .34489 Mtetra
.65004 .34489 .65206 .34743 .6562 .34606 .65418 .34351 Mtetra
.65418 .34351 .6562 .34606 .66033 .34468 .65833 .34213 Mtetra
.65833 .34213 .66033 .34468 .66448 .3433 .66248 .34075 Mtetra
.66248 .34075 .66448 .3433 .66863 .34192 .66663 .33937 Mtetra
.66663 .33937 .66863 .34192 .67279 .34054 .67079 .33798 Mtetra
.67079 .33798 .67279 .34054 .67696 .33916 .67496 .3366 Mtetra
.67496 .3366 .67696 .33916 .68113 .33777 .67914 .33521 Mtetra
.67914 .33521 .68113 .33777 .6853 .33638 .68332 .33381 Mtetra
.68332 .33381 .6853 .33638 .68948 .33499 .68751 .33242 Mtetra
.68751 .33242 .68948 .33499 .69367 .3336 .6917 .33102 Mtetra
.6917 .33102 .69367 .3336 .69787 .3322 .6959 .32963 Mtetra
.6959 .32963 .69787 .3322 .70207 .33081 .7001 .32823 Mtetra
.7001 .32823 .70207 .33081 .70741 .34909 .70431 .32682 Mtetra
.147 .097 .54 r
.70431 .32682 .70741 .34909 .71165 .3477 .70968 .34512 Mtetra
.662 .743 .91 r
.70968 .34512 .71165 .3477 .7159 .3463 .71393 .34372 Mtetra
.71393 .34372 .7159 .3463 .72015 .3449 .71819 .34231 Mtetra
.71819 .34231 .72015 .3449 .72441 .3435 .72246 .34091 Mtetra
.72246 .34091 .72441 .3435 .72868 .3421 .72673 .3395 Mtetra
.72673 .3395 .72868 .3421 .73295 .34069 .731 .33809 Mtetra
.731 .33809 .73295 .34069 .73723 .33928 .73529 .33668 Mtetra
.73529 .33668 .73723 .33928 .74152 .33788 .73958 .33527 Mtetra
.73958 .33527 .74152 .33788 .74581 .33646 .74387 .33385 Mtetra
.74387 .33385 .74581 .33646 .75011 .33505 .74818 .33244 Mtetra
.74818 .33244 .75011 .33505 .75441 .33363 .75249 .33102 Mtetra
.75249 .33102 .75441 .33363 .75872 .33222 .7568 .32959 Mtetra
0 .255 .761 r
.7568 .32959 .75872 .33222 .76304 .3308 .7615 .33315 Mtetra
.197 0 0 r
.7615 .33315 .76304 .3308 .76736 .32938 .76583 .33173 Mtetra
.76583 .33173 .76736 .32938 .7717 .32795 .77018 .3303 Mtetra
.967 .647 .343 r
.77018 .3303 .7717 .32795 .7855 .44527 .78354 .4427 Mtetra
.653 .754 .924 r
.78354 .4427 .7855 .44527 .79002 .44388 .78806 .44131 Mtetra
.78806 .44131 .79002 .44388 .79454 .44249 .79259 .43991 Mtetra
.79259 .43991 .79454 .44249 .79907 .44109 .79713 .43851 Mtetra
.79713 .43851 .79907 .44109 .80361 .4397 .80167 .43711 Mtetra
.80167 .43711 .80361 .4397 .80815 .4383 .80622 .43571 Mtetra
.80622 .43571 .80815 .4383 .8127 .4369 .81077 .43431 Mtetra
.81077 .43431 .8127 .4369 .81726 .4355 .81534 .4329 Mtetra
.81534 .4329 .81726 .4355 .82183 .43409 .81991 .43149 Mtetra
.81991 .43149 .82183 .43409 .8264 .43268 .82448 .43008 Mtetra
.82448 .43008 .8264 .43268 .83098 .43128 .82907 .42867 Mtetra
.82907 .42867 .83098 .43128 .83556 .42986 .83366 .42725 Mtetra
.83366 .42725 .83556 .42986 .84016 .42845 .83826 .42583 Mtetra
.83826 .42583 .84016 .42845 .84476 .42703 .84287 .42441 Mtetra
.84287 .42441 .84476 .42703 .84937 .42562 .84748 .42299 Mtetra
.84748 .42299 .84937 .42562 .85398 .4242 .8521 .42157 Mtetra
.8521 .42157 .85398 .4242 .85861 .42277 .85673 .42014 Mtetra
.85673 .42014 .85861 .42277 .86324 .42135 .86137 .41871 Mtetra
.86137 .41871 .86324 .42135 .86788 .41992 .86601 .41728 Mtetra
.86601 .41728 .86788 .41992 .87252 .41849 .87066 .41585 Mtetra
.87066 .41585 .87252 .41849 .87718 .41706 .87532 .41441 Mtetra
.87532 .41441 .87718 .41706 .88184 .41563 .87999 .41297 Mtetra
.648 .76 .931 r
.24737 .66088 .2499 .66297 .25369 .66184 .25116 .65976 Mtetra
.25116 .65976 .25369 .66184 .25748 .66071 .25496 .65862 Mtetra
.25496 .65862 .25748 .66071 .26128 .65958 .25876 .65749 Mtetra
.25876 .65749 .26128 .65958 .26508 .65845 .26257 .65636 Mtetra
.26257 .65636 .26508 .65845 .26889 .65732 .26638 .65522 Mtetra
.26638 .65522 .26889 .65732 .2727 .65618 .2702 .65408 Mtetra
.2702 .65408 .2727 .65618 .27652 .65504 .27402 .65294 Mtetra
.27402 .65294 .27652 .65504 .28035 .65391 .27785 .6518 Mtetra
.27785 .6518 .28035 .65391 .28418 .65277 .28168 .65066 Mtetra
.28168 .65066 .28418 .65277 .28802 .65163 .28552 .64951 Mtetra
.28552 .64951 .28802 .65163 .29186 .65048 .28937 .64837 Mtetra
.28937 .64837 .29186 .65048 .29571 .64934 .29322 .64722 Mtetra
.29322 .64722 .29571 .64934 .29956 .64819 .29707 .64607 Mtetra
.29707 .64607 .29956 .64819 .30342 .64704 .30094 .64492 Mtetra
.30094 .64492 .30342 .64704 .30728 .64589 .3048 .64376 Mtetra
.3048 .64376 .30728 .64589 .31115 .64474 .30868 .64261 Mtetra
.30868 .64261 .31115 .64474 .31503 .64359 .31256 .64145 Mtetra
.31256 .64145 .31503 .64359 .31891 .64243 .31644 .6403 Mtetra
.31644 .6403 .31891 .64243 .3228 .64128 .32033 .63914 Mtetra
.32033 .63914 .3228 .64128 .32669 .64012 .32423 .63797 Mtetra
.32423 .63797 .32669 .64012 .33059 .63896 .32813 .63681 Mtetra
.944 .692 .525 r
.32813 .63681 .33059 .63896 .3445 .45599 .34218 .45372 Mtetra
.663 .742 .909 r
.34218 .45372 .3445 .45599 .34821 .45476 .3459 .45249 Mtetra
.3459 .45249 .34821 .45476 .35192 .45353 .34962 .45125 Mtetra
.34962 .45125 .35192 .45353 .35565 .4523 .35334 .45002 Mtetra
.35334 .45002 .35565 .4523 .35937 .45106 .35707 .44878 Mtetra
.35707 .44878 .35937 .45106 .36311 .44983 .36081 .44754 Mtetra
.36081 .44754 .36311 .44983 .36684 .44859 .36455 .4463 Mtetra
.36455 .4463 .36684 .44859 .37059 .44735 .3683 .44506 Mtetra
.3683 .44506 .37059 .44735 .37433 .44611 .37205 .44381 Mtetra
.37205 .44381 .37433 .44611 .37809 .44487 .3758 .44257 Mtetra
.3758 .44257 .37809 .44487 .38185 .44362 .37957 .44132 Mtetra
.37957 .44132 .38185 .44362 .38561 .44237 .38333 .44007 Mtetra
.38333 .44007 .38561 .44237 .38938 .44113 .38711 .43882 Mtetra
.38711 .43882 .38938 .44113 .39315 .43988 .39088 .43756 Mtetra
.39088 .43756 .39315 .43988 .39693 .43862 .39467 .43631 Mtetra
.39467 .43631 .39693 .43862 .40072 .43737 .39845 .43505 Mtetra
.39845 .43505 .40072 .43737 .40451 .43612 .40225 .43379 Mtetra
.40225 .43379 .40451 .43612 .4083 .43486 .40605 .43253 Mtetra
.40605 .43253 .4083 .43486 .41211 .4336 .40985 .43127 Mtetra
.40985 .43127 .41211 .4336 .41591 .43234 .41366 .43001 Mtetra
.41366 .43001 .41591 .43234 .41972 .43108 .41748 .42874 Mtetra
.869 .764 .745 r
.41748 .42874 .41972 .43108 .42369 .425 .42145 .42266 Mtetra
.663 .742 .908 r
.42145 .42266 .42369 .425 .42751 .42373 .42527 .42139 Mtetra
.42527 .42139 .42751 .42373 .43133 .42247 .4291 .42012 Mtetra
.4291 .42012 .43133 .42247 .43516 .42119 .43293 .41884 Mtetra
.43293 .41884 .43516 .42119 .43899 .41992 .43677 .41757 Mtetra
.43677 .41757 .43899 .41992 .44283 .41865 .44061 .41629 Mtetra
.44061 .41629 .44283 .41865 .44667 .41737 .44446 .41501 Mtetra
.44446 .41501 .44667 .41737 .45052 .41609 .44831 .41373 Mtetra
.44831 .41373 .45052 .41609 .45438 .41481 .45217 .41244 Mtetra
.45217 .41244 .45438 .41481 .45824 .41353 .45603 .41116 Mtetra
.45603 .41116 .45824 .41353 .46211 .41225 .4599 .40987 Mtetra
.4599 .40987 .46211 .41225 .46598 .41096 .46378 .40858 Mtetra
.46378 .40858 .46598 .41096 .46986 .40967 .46766 .40729 Mtetra
.46766 .40729 .46986 .40967 .47374 .40838 .47154 .406 Mtetra
.47154 .406 .47374 .40838 .47763 .40709 .47544 .4047 Mtetra
.47544 .4047 .47763 .40709 .48152 .4058 .47933 .40341 Mtetra
.47933 .40341 .48152 .4058 .48542 .4045 .48324 .40211 Mtetra
.962 .676 .446 r
.48324 .40211 .48542 .4045 .48811 .51305 .48586 .51072 Mtetra
.655 .752 .922 r
.48586 .51072 .48811 .51305 .49216 .51179 .4899 .50946 Mtetra
.4899 .50946 .49216 .51179 .49621 .51053 .49396 .50819 Mtetra
.49396 .50819 .49621 .51053 .50026 .50926 .49802 .50692 Mtetra
.49802 .50692 .50026 .50926 .50432 .508 .50208 .50565 Mtetra
.50208 .50565 .50432 .508 .50839 .50673 .50615 .50438 Mtetra
.50615 .50438 .50839 .50673 .51246 .50546 .51023 .50311 Mtetra
.51023 .50311 .51246 .50546 .51654 .50418 .51431 .50183 Mtetra
.51431 .50183 .51654 .50418 .52063 .50291 .5184 .50055 Mtetra
.5184 .50055 .52063 .50291 .52472 .50163 .5225 .49927 Mtetra
.5225 .49927 .52472 .50163 .52881 .50035 .5266 .49799 Mtetra
.5266 .49799 .52881 .50035 .53292 .49907 .5307 .49671 Mtetra
.5307 .49671 .53292 .49907 .53703 .49779 .53482 .49542 Mtetra
.96 .719 .531 r
.53482 .49542 .53703 .49779 .54097 .46059 .53878 .45819 Mtetra
.658 .749 .917 r
.53878 .45819 .54097 .46059 .54504 .45929 .54287 .45689 Mtetra
.54287 .45689 .54504 .45929 .54913 .45799 .54695 .45558 Mtetra
.54695 .45558 .54913 .45799 .55322 .45669 .55105 .45428 Mtetra
.55105 .45428 .55322 .45669 .55731 .45538 .55515 .45297 Mtetra
.55515 .45297 .55731 .45538 .56141 .45408 .55925 .45166 Mtetra
.55925 .45166 .56141 .45408 .56552 .45277 .56336 .45035 Mtetra
.56336 .45035 .56552 .45277 .56963 .45146 .56748 .44903 Mtetra
.56748 .44903 .56963 .45146 .57375 .45015 .5716 .44772 Mtetra
.5716 .44772 .57375 .45015 .57788 .44883 .57573 .4464 Mtetra
.57573 .4464 .57788 .44883 .58201 .44751 .57987 .44508 Mtetra
.57987 .44508 .58201 .44751 .58615 .4462 .58401 .44376 Mtetra
.58401 .44376 .58615 .4462 .59029 .44488 .58816 .44243 Mtetra
.58816 .44243 .59029 .44488 .59444 .44355 .59231 .44111 Mtetra
.59231 .44111 .59444 .44355 .5986 .44223 .59647 .43978 Mtetra
.59647 .43978 .5986 .44223 .60276 .4409 .60064 .43845 Mtetra
.60064 .43845 .60276 .4409 .60693 .43958 .60481 .43712 Mtetra
.60481 .43712 .60693 .43958 .61111 .43825 .60899 .43579 Mtetra
.60899 .43579 .61111 .43825 .61529 .43691 .61318 .43445 Mtetra
.971 .703 .467 r
.61318 .43445 .61529 .43691 .61716 .35584 .6151 .35333 Mtetra
.664 .741 .908 r
.6151 .35333 .61716 .35584 .62125 .35448 .6192 .35196 Mtetra
.6192 .35196 .62125 .35448 .62534 .35312 .6233 .35059 Mtetra
.6233 .35059 .62534 .35312 .62945 .35175 .6274 .34922 Mtetra
.6274 .34922 .62945 .35175 .63355 .35038 .63151 .34785 Mtetra
.63151 .34785 .63355 .35038 .63767 .34901 .63563 .34648 Mtetra
.63563 .34648 .63767 .34901 .64179 .34764 .63976 .3451 Mtetra
.63976 .3451 .64179 .34764 .64591 .34627 .64389 .34373 Mtetra
.64389 .34373 .64591 .34627 .65004 .34489 .64802 .34235 Mtetra
.64802 .34235 .65004 .34489 .65418 .34351 .65216 .34097 Mtetra
.65216 .34097 .65418 .34351 .65833 .34213 .65631 .33958 Mtetra
.65631 .33958 .65833 .34213 .66248 .34075 .66047 .3382 Mtetra
.66047 .3382 .66248 .34075 .66663 .33937 .66463 .33681 Mtetra
.66463 .33681 .66663 .33937 .67079 .33798 .66879 .33542 Mtetra
.66879 .33542 .67079 .33798 .67496 .3366 .67297 .33403 Mtetra
.67297 .33403 .67496 .3366 .67914 .33521 .67714 .33263 Mtetra
.67714 .33263 .67914 .33521 .68332 .33381 .68133 .33124 Mtetra
.68133 .33124 .68332 .33381 .68751 .33242 .68552 .32984 Mtetra
.68552 .32984 .68751 .33242 .6917 .33102 .68972 .32844 Mtetra
.68972 .32844 .6917 .33102 .6959 .32963 .69392 .32704 Mtetra
.69392 .32704 .6959 .32963 .7001 .32823 .69813 .32563 Mtetra
.69813 .32563 .7001 .32823 .70431 .32682 .70235 .32423 Mtetra
.70235 .32423 .70431 .32682 .70968 .34512 .70657 .32282 Mtetra
.577 .398 .602 r
.70657 .32282 .70968 .34512 .71393 .34372 .7108 .32141 Mtetra
.149 .099 .541 r
.7108 .32141 .71393 .34372 .71819 .34231 .71623 .33972 Mtetra
.662 .743 .91 r
.71623 .33972 .71819 .34231 .72246 .34091 .7205 .33831 Mtetra
.7205 .33831 .72246 .34091 .72673 .3395 .72477 .3369 Mtetra
.72477 .3369 .72673 .3395 .731 .33809 .72905 .33549 Mtetra
.72905 .33549 .731 .33809 .73529 .33668 .73334 .33407 Mtetra
.73334 .33407 .73529 .33668 .73958 .33527 .73763 .33265 Mtetra
0 .246 .754 r
.73763 .33265 .73958 .33527 .74387 .33385 .74228 .33621 Mtetra
.195 0 0 r
.74228 .33621 .74387 .33385 .74818 .33244 .74659 .33479 Mtetra
.74659 .33479 .74818 .33244 .75249 .33102 .75091 .33337 Mtetra
.75091 .33337 .75249 .33102 .7568 .32959 .75524 .33195 Mtetra
.75524 .33195 .7568 .32959 .7615 .33315 .75958 .33052 Mtetra
.662 .744 .911 r
.75958 .33052 .7615 .33315 .76583 .33173 .76392 .32909 Mtetra
.76392 .32909 .76583 .33173 .77018 .3303 .76826 .32766 Mtetra
.76826 .32766 .77018 .3303 .78354 .4427 .77262 .32623 Mtetra
.081 .009 .466 r
.77262 .32623 .78354 .4427 .78806 .44131 .7861 .43873 Mtetra
.653 .754 .924 r
.7861 .43873 .78806 .44131 .79259 .43991 .79064 .43733 Mtetra
.79064 .43733 .79259 .43991 .79713 .43851 .79518 .43593 Mtetra
.79518 .43593 .79713 .43851 .80167 .43711 .79972 .43452 Mtetra
.79972 .43452 .80167 .43711 .80622 .43571 .80428 .43312 Mtetra
.80428 .43312 .80622 .43571 .81077 .43431 .80884 .43171 Mtetra
.80884 .43171 .81077 .43431 .81534 .4329 .81341 .4303 Mtetra
.81341 .4303 .81534 .4329 .81991 .43149 .81798 .42889 Mtetra
.81798 .42889 .81991 .43149 .82448 .43008 .82256 .42747 Mtetra
.82256 .42747 .82448 .43008 .82907 .42867 .82715 .42605 Mtetra
.82715 .42605 .82907 .42867 .83366 .42725 .83175 .42463 Mtetra
.83175 .42463 .83366 .42725 .83826 .42583 .83636 .42321 Mtetra
.83636 .42321 .83826 .42583 .84287 .42441 .84097 .42179 Mtetra
.84097 .42179 .84287 .42441 .84748 .42299 .84559 .42036 Mtetra
.84559 .42036 .84748 .42299 .8521 .42157 .85021 .41893 Mtetra
.85021 .41893 .8521 .42157 .85673 .42014 .85485 .4175 Mtetra
.85485 .4175 .85673 .42014 .86137 .41871 .85949 .41607 Mtetra
.85949 .41607 .86137 .41871 .86601 .41728 .86414 .41463 Mtetra
.86414 .41463 .86601 .41728 .87066 .41585 .8688 .41319 Mtetra
.8688 .41319 .87066 .41585 .87532 .41441 .87346 .41175 Mtetra
.87346 .41175 .87532 .41441 .87999 .41297 .87813 .41031 Mtetra
.648 .76 .931 r
.24484 .6588 .24737 .66088 .25116 .65976 .24863 .65767 Mtetra
.24863 .65767 .25116 .65976 .25496 .65862 .25243 .65653 Mtetra
.25243 .65653 .25496 .65862 .25876 .65749 .25623 .65539 Mtetra
.25623 .65539 .25876 .65749 .26257 .65636 .26004 .65426 Mtetra
.26004 .65426 .26257 .65636 .26638 .65522 .26386 .65312 Mtetra
.26386 .65312 .26638 .65522 .2702 .65408 .26768 .65198 Mtetra
.26768 .65198 .2702 .65408 .27402 .65294 .27151 .65083 Mtetra
.27151 .65083 .27402 .65294 .27785 .6518 .27534 .64969 Mtetra
.27534 .64969 .27785 .6518 .28168 .65066 .27918 .64854 Mtetra
.27918 .64854 .28168 .65066 .28552 .64951 .28302 .6474 Mtetra
.28302 .6474 .28552 .64951 .28937 .64837 .28687 .64625 Mtetra
.28687 .64625 .28937 .64837 .29322 .64722 .29072 .64509 Mtetra
.29072 .64509 .29322 .64722 .29707 .64607 .29458 .64394 Mtetra
.29458 .64394 .29707 .64607 .30094 .64492 .29845 .64279 Mtetra
.29845 .64279 .30094 .64492 .3048 .64376 .30232 .64163 Mtetra
.30232 .64163 .3048 .64376 .30868 .64261 .3062 .64047 Mtetra
.3062 .64047 .30868 .64261 .31256 .64145 .31008 .63931 Mtetra
.31008 .63931 .31256 .64145 .31644 .6403 .31397 .63815 Mtetra
.31397 .63815 .31644 .6403 .32033 .63914 .31786 .63699 Mtetra
.31786 .63699 .32033 .63914 .32423 .63797 .32176 .63582 Mtetra
.32176 .63582 .32423 .63797 .32813 .63681 .32567 .63466 Mtetra
.944 .692 .526 r
.32567 .63466 .32813 .63681 .34218 .45372 .33932 .46105 Mtetra
.44 .113 .314 r
.33932 .46105 .34218 .45372 .3459 .45249 .34305 .45982 Mtetra
.34305 .45982 .3459 .45249 .34962 .45125 .34678 .45859 Mtetra
.34678 .45859 .34962 .45125 .35334 .45002 .35052 .45735 Mtetra
.35052 .45735 .35334 .45002 .35707 .44878 .35427 .45611 Mtetra
.35427 .45611 .35707 .44878 .36081 .44754 .35802 .45487 Mtetra
.35802 .45487 .36081 .44754 .36455 .4463 .36177 .45363 Mtetra
.36177 .45363 .36455 .4463 .3683 .44506 .36553 .45239 Mtetra
0 0 0 r
.36553 .45239 .3683 .44506 .37205 .44381 .36975 .44151 Mtetra
.663 .742 .909 r
.36975 .44151 .37205 .44381 .3758 .44257 .37351 .44026 Mtetra
.37351 .44026 .3758 .44257 .37957 .44132 .37728 .43901 Mtetra
.37728 .43901 .37957 .44132 .38333 .44007 .38105 .43776 Mtetra
.38105 .43776 .38333 .44007 .38711 .43882 .38483 .4365 Mtetra
.38483 .4365 .38711 .43882 .39088 .43756 .38861 .43525 Mtetra
.38861 .43525 .39088 .43756 .39467 .43631 .39239 .43399 Mtetra
.39239 .43399 .39467 .43631 .39845 .43505 .39618 .43273 Mtetra
.39618 .43273 .39845 .43505 .40225 .43379 .39998 .43147 Mtetra
.39998 .43147 .40225 .43379 .40605 .43253 .40378 .4302 Mtetra
.40378 .4302 .40605 .43253 .40985 .43127 .40759 .42894 Mtetra
.40759 .42894 .40985 .43127 .41366 .43001 .41141 .42767 Mtetra
.868 .764 .745 r
.41141 .42767 .41366 .43001 .41748 .42874 .41539 .42159 Mtetra
.62 .516 .715 r
.41539 .42159 .41748 .42874 .42145 .42266 .41921 .42031 Mtetra
.663 .742 .908 r
.41921 .42031 .42145 .42266 .42527 .42139 .42303 .41904 Mtetra
.42303 .41904 .42527 .42139 .4291 .42012 .42686 .41776 Mtetra
.42686 .41776 .4291 .42012 .43293 .41884 .43069 .41649 Mtetra
.43069 .41649 .43293 .41884 .43677 .41757 .43453 .41521 Mtetra
.43453 .41521 .43677 .41757 .44061 .41629 .43838 .41392 Mtetra
.43838 .41392 .44061 .41629 .44446 .41501 .44223 .41264 Mtetra
.44223 .41264 .44446 .41501 .44831 .41373 .44609 .41136 Mtetra
.44609 .41136 .44831 .41373 .45217 .41244 .44995 .41007 Mtetra
.44995 .41007 .45217 .41244 .45603 .41116 .45382 .40878 Mtetra
.45382 .40878 .45603 .41116 .4599 .40987 .45769 .40749 Mtetra
.45769 .40749 .4599 .40987 .46378 .40858 .46157 .4062 Mtetra
.46157 .4062 .46378 .40858 .46766 .40729 .46545 .4049 Mtetra
.46545 .4049 .46766 .40729 .47154 .406 .46934 .40361 Mtetra
.46934 .40361 .47154 .406 .47544 .4047 .47324 .40231 Mtetra
.47324 .40231 .47544 .4047 .47933 .40341 .47714 .40101 Mtetra
.47714 .40101 .47933 .40341 .48324 .40211 .48105 .39971 Mtetra
.962 .676 .446 r
.48105 .39971 .48324 .40211 .48586 .51072 .48359 .50839 Mtetra
.655 .752 .922 r
.48359 .50839 .48586 .51072 .4899 .50946 .48765 .50712 Mtetra
.48765 .50712 .4899 .50946 .49396 .50819 .4917 .50585 Mtetra
.4917 .50585 .49396 .50819 .49802 .50692 .49576 .50458 Mtetra
.49576 .50458 .49802 .50692 .50208 .50565 .49983 .5033 Mtetra
.49983 .5033 .50208 .50565 .50615 .50438 .50391 .50203 Mtetra
.50391 .50203 .50615 .50438 .51023 .50311 .50799 .50075 Mtetra
.50799 .50075 .51023 .50311 .51431 .50183 .51208 .49947 Mtetra
.51208 .49947 .51431 .50183 .5184 .50055 .51617 .49819 Mtetra
.51617 .49819 .5184 .50055 .5225 .49927 .52027 .4969 Mtetra
.52027 .4969 .5225 .49927 .5266 .49799 .52437 .49562 Mtetra
.52437 .49562 .5266 .49799 .5307 .49671 .52848 .49433 Mtetra
.52848 .49433 .5307 .49671 .53482 .49542 .5326 .49304 Mtetra
.5326 .49304 .53482 .49542 .53878 .45819 .53673 .49175 Mtetra
0 0 .259 r
.53673 .49175 .53878 .45819 .54287 .45689 .54068 .45448 Mtetra
.658 .749 .917 r
.54068 .45448 .54287 .45689 .54695 .45558 .54477 .45317 Mtetra
.54477 .45317 .54695 .45558 .55105 .45428 .54887 .45186 Mtetra
.54887 .45186 .55105 .45428 .55515 .45297 .55297 .45055 Mtetra
.55297 .45055 .55515 .45297 .55925 .45166 .55708 .44924 Mtetra
.55708 .44924 .55925 .45166 .56336 .45035 .5612 .44792 Mtetra
.5612 .44792 .56336 .45035 .56748 .44903 .56532 .4466 Mtetra
.56532 .4466 .56748 .44903 .5716 .44772 .56945 .44528 Mtetra
.56945 .44528 .5716 .44772 .57573 .4464 .57358 .44396 Mtetra
.57358 .44396 .57573 .4464 .57987 .44508 .57772 .44264 Mtetra
.57772 .44264 .57987 .44508 .58401 .44376 .58187 .44131 Mtetra
.58187 .44131 .58401 .44376 .58816 .44243 .58602 .43998 Mtetra
.58602 .43998 .58816 .44243 .59231 .44111 .59018 .43866 Mtetra
.59018 .43866 .59231 .44111 .59647 .43978 .59434 .43732 Mtetra
.59434 .43732 .59647 .43978 .60064 .43845 .59851 .43599 Mtetra
.59851 .43599 .60064 .43845 .60481 .43712 .60269 .43466 Mtetra
.60269 .43466 .60481 .43712 .60899 .43579 .60688 .43332 Mtetra
.60688 .43332 .60899 .43579 .61318 .43445 .61106 .43198 Mtetra
.61106 .43198 .61318 .43445 .6151 .35333 .61526 .43064 Mtetra
0 0 .352 r
.61526 .43064 .6151 .35333 .6192 .35196 .61714 .34943 Mtetra
.664 .741 .908 r
.61714 .34943 .6192 .35196 .6233 .35059 .62124 .34806 Mtetra
.62124 .34806 .6233 .35059 .6274 .34922 .62535 .34669 Mtetra
.62535 .34669 .6274 .34922 .63151 .34785 .62947 .34532 Mtetra
.62947 .34532 .63151 .34785 .63563 .34648 .63359 .34394 Mtetra
.63359 .34394 .63563 .34648 .63976 .3451 .63772 .34256 Mtetra
.63772 .34256 .63976 .3451 .64389 .34373 .64185 .34118 Mtetra
.64185 .34118 .64389 .34373 .64802 .34235 .64599 .3398 Mtetra
.64599 .3398 .64802 .34235 .65216 .34097 .65014 .33841 Mtetra
.65014 .33841 .65216 .34097 .65631 .33958 .65429 .33702 Mtetra
.65429 .33702 .65631 .33958 .66047 .3382 .65845 .33563 Mtetra
.65845 .33563 .66047 .3382 .66463 .33681 .66261 .33424 Mtetra
.66261 .33424 .66463 .33681 .66879 .33542 .66679 .33285 Mtetra
.66679 .33285 .66879 .33542 .67297 .33403 .67096 .33145 Mtetra
.67096 .33145 .67297 .33403 .67714 .33263 .67514 .33006 Mtetra
.67514 .33006 .67714 .33263 .68133 .33124 .67933 .32866 Mtetra
.67933 .32866 .68133 .33124 .68552 .32984 .68353 .32725 Mtetra
.68353 .32725 .68552 .32984 .68972 .32844 .68773 .32585 Mtetra
.68773 .32585 .68972 .32844 .69392 .32704 .69194 .32444 Mtetra
.69194 .32444 .69392 .32704 .69813 .32563 .69615 .32304 Mtetra
.69615 .32304 .69813 .32563 .70235 .32423 .70037 .32163 Mtetra
.70037 .32163 .70235 .32423 .70657 .32282 .7046 .32021 Mtetra
.7046 .32021 .70657 .32282 .7108 .32141 .70883 .3188 Mtetra
.70883 .3188 .7108 .32141 .71623 .33972 .71307 .31738 Mtetra
.001 0 .494 r
.71307 .31738 .71623 .33972 .7205 .33831 .71883 .34068 Mtetra
.192 0 0 r
.71883 .34068 .7205 .33831 .72477 .3369 .72312 .33926 Mtetra
.72312 .33926 .72477 .3369 .72905 .33549 .72741 .33785 Mtetra
.72741 .33785 .72905 .33549 .73334 .33407 .73171 .33643 Mtetra
.73171 .33643 .73334 .33407 .73763 .33265 .73602 .33501 Mtetra
.73602 .33501 .73763 .33265 .74228 .33621 .74033 .33359 Mtetra
.662 .744 .911 r
.74033 .33359 .74228 .33621 .74659 .33479 .74465 .33217 Mtetra
.74465 .33217 .74659 .33479 .75091 .33337 .74898 .33074 Mtetra
.74898 .33074 .75091 .33337 .75524 .33195 .75331 .32931 Mtetra
.75331 .32931 .75524 .33195 .75958 .33052 .75765 .32788 Mtetra
.75765 .32788 .75958 .33052 .76392 .32909 .76199 .32645 Mtetra
.76199 .32645 .76392 .32909 .76826 .32766 .76634 .32501 Mtetra
.76634 .32501 .76826 .32766 .77262 .32623 .7707 .32358 Mtetra
.97 .652 .311 r
.7707 .32358 .77262 .32623 .7861 .43873 .78414 .43614 Mtetra
.653 .754 .924 r
.78414 .43614 .7861 .43873 .79064 .43733 .78868 .43474 Mtetra
.78868 .43474 .79064 .43733 .79518 .43593 .79322 .43333 Mtetra
.79322 .43333 .79518 .43593 .79972 .43452 .79777 .43193 Mtetra
.79777 .43193 .79972 .43452 .80428 .43312 .80233 .43052 Mtetra
.80233 .43052 .80428 .43312 .80884 .43171 .8069 .4291 Mtetra
.8069 .4291 .80884 .43171 .81341 .4303 .81147 .42769 Mtetra
.81147 .42769 .81341 .4303 .81798 .42889 .81605 .42627 Mtetra
.81605 .42627 .81798 .42889 .82256 .42747 .82064 .42485 Mtetra
.82064 .42485 .82256 .42747 .82715 .42605 .82524 .42343 Mtetra
.82524 .42343 .82715 .42605 .83175 .42463 .82984 .42201 Mtetra
.82984 .42201 .83175 .42463 .83636 .42321 .83445 .42058 Mtetra
.83445 .42058 .83636 .42321 .84097 .42179 .83906 .41915 Mtetra
.83906 .41915 .84097 .42179 .84559 .42036 .84369 .41772 Mtetra
.84369 .41772 .84559 .42036 .85021 .41893 .84832 .41629 Mtetra
.84832 .41629 .85021 .41893 .85485 .4175 .85296 .41485 Mtetra
.85296 .41485 .85485 .4175 .85949 .41607 .85761 .41342 Mtetra
.85761 .41342 .85949 .41607 .86414 .41463 .86226 .41198 Mtetra
.86226 .41198 .86414 .41463 .8688 .41319 .86692 .41053 Mtetra
.86692 .41053 .8688 .41319 .87346 .41175 .87159 .40909 Mtetra
.87159 .40909 .87346 .41175 .87813 .41031 .87627 .40764 Mtetra
.648 .76 .931 r
.2423 .65671 .24484 .6588 .24863 .65767 .24609 .65557 Mtetra
.24609 .65557 .24863 .65767 .25243 .65653 .2499 .65443 Mtetra
.2499 .65443 .25243 .65653 .25623 .65539 .2537 .65329 Mtetra
.2537 .65329 .25623 .65539 .26004 .65426 .25752 .65215 Mtetra
.25752 .65215 .26004 .65426 .26386 .65312 .26133 .65101 Mtetra
.26133 .65101 .26386 .65312 .26768 .65198 .26516 .64987 Mtetra
.26516 .64987 .26768 .65198 .27151 .65083 .26899 .64872 Mtetra
.26899 .64872 .27151 .65083 .27534 .64969 .27282 .64757 Mtetra
.27282 .64757 .27534 .64969 .27918 .64854 .27666 .64642 Mtetra
.27666 .64642 .27918 .64854 .28302 .6474 .28051 .64527 Mtetra
.28051 .64527 .28302 .6474 .28687 .64625 .28436 .64412 Mtetra
.28436 .64412 .28687 .64625 .29072 .64509 .28822 .64297 Mtetra
.28822 .64297 .29072 .64509 .29458 .64394 .29208 .64181 Mtetra
.29208 .64181 .29458 .64394 .29845 .64279 .29595 .64065 Mtetra
.29595 .64065 .29845 .64279 .30232 .64163 .29983 .63949 Mtetra
.29983 .63949 .30232 .64163 .3062 .64047 .30371 .63833 Mtetra
.30371 .63833 .3062 .64047 .31008 .63931 .30759 .63717 Mtetra
.30759 .63717 .31008 .63931 .31397 .63815 .31148 .636 Mtetra
.31148 .636 .31397 .63815 .31786 .63699 .31538 .63484 Mtetra
.31538 .63484 .31786 .63699 .32176 .63582 .31929 .63367 Mtetra
.31929 .63367 .32176 .63582 .32567 .63466 .32319 .6325 Mtetra
.944 .692 .526 r
.32319 .6325 .32567 .63466 .33932 .46105 .33699 .45878 Mtetra
.662 .743 .91 r
.33699 .45878 .33932 .46105 .34305 .45982 .34072 .45754 Mtetra
.34072 .45754 .34305 .45982 .34678 .45859 .34446 .4563 Mtetra
.34446 .4563 .34678 .45859 .35052 .45735 .3482 .45506 Mtetra
.3482 .45506 .35052 .45735 .35427 .45611 .35195 .45382 Mtetra
.35195 .45382 .35427 .45611 .35802 .45487 .3557 .45258 Mtetra
.3557 .45258 .35802 .45487 .36177 .45363 .35946 .45134 Mtetra
.35946 .45134 .36177 .45363 .36553 .45239 .36322 .45009 Mtetra
.36322 .45009 .36553 .45239 .36975 .44151 .36699 .44884 Mtetra
.438 .112 .313 r
.36699 .44884 .36975 .44151 .37351 .44026 .37076 .44759 Mtetra
.37076 .44759 .37351 .44026 .37728 .43901 .37454 .44634 Mtetra
.37454 .44634 .37728 .43901 .38105 .43776 .37833 .44509 Mtetra
.37833 .44509 .38105 .43776 .38483 .4365 .38212 .44383 Mtetra
.38212 .44383 .38483 .4365 .38861 .43525 .38591 .44258 Mtetra
.38591 .44258 .38861 .43525 .39239 .43399 .38971 .44132 Mtetra
.38971 .44132 .39239 .43399 .39618 .43273 .39352 .44006 Mtetra
.39352 .44006 .39618 .43273 .39998 .43147 .39733 .4388 Mtetra
.39733 .4388 .39998 .43147 .40378 .4302 .40115 .43753 Mtetra
.40115 .43753 .40378 .4302 .40759 .42894 .40497 .43627 Mtetra
.40497 .43627 .40759 .42894 .41141 .42767 .4088 .435 Mtetra
.882 .837 .372 r
.4088 .435 .41141 .42767 .41539 .42159 .41313 .41923 Mtetra
.663 .742 .908 r
.41313 .41923 .41539 .42159 .41921 .42031 .41695 .41796 Mtetra
.41695 .41796 .41921 .42031 .42303 .41904 .42078 .41668 Mtetra
.42078 .41668 .42303 .41904 .42686 .41776 .42461 .4154 Mtetra
.42461 .4154 .42686 .41776 .43069 .41649 .42845 .41412 Mtetra
.42845 .41412 .43069 .41649 .43453 .41521 .4323 .41284 Mtetra
.4323 .41284 .43453 .41521 .43838 .41392 .43614 .41155 Mtetra
.43614 .41155 .43838 .41392 .44223 .41264 .44 .41027 Mtetra
.44 .41027 .44223 .41264 .44609 .41136 .44386 .40898 Mtetra
.44386 .40898 .44609 .41136 .44995 .41007 .44773 .40769 Mtetra
.44773 .40769 .44995 .41007 .45382 .40878 .4516 .4064 Mtetra
.4516 .4064 .45382 .40878 .45769 .40749 .45547 .4051 Mtetra
.45547 .4051 .45769 .40749 .46157 .4062 .45936 .40381 Mtetra
.45936 .40381 .46157 .4062 .46545 .4049 .46324 .40251 Mtetra
.46324 .40251 .46545 .4049 .46934 .40361 .46714 .40121 Mtetra
.46714 .40121 .46934 .40361 .47324 .40231 .47104 .39991 Mtetra
.47104 .39991 .47324 .40231 .47714 .40101 .47494 .3986 Mtetra
.47494 .3986 .47714 .40101 .48105 .39971 .47885 .3973 Mtetra
.962 .676 .446 r
.47885 .3973 .48105 .39971 .48359 .50839 .48133 .50604 Mtetra
.655 .752 .922 r
.48133 .50604 .48359 .50839 .48765 .50712 .48538 .50477 Mtetra
.48538 .50477 .48765 .50712 .4917 .50585 .48944 .5035 Mtetra
.48944 .5035 .4917 .50585 .49576 .50458 .49351 .50222 Mtetra
.49351 .50222 .49576 .50458 .49983 .5033 .49758 .50095 Mtetra
.49758 .50095 .49983 .5033 .50391 .50203 .50166 .49967 Mtetra
.50166 .49967 .50391 .50203 .50799 .50075 .50574 .49838 Mtetra
.50574 .49838 .50799 .50075 .51208 .49947 .50983 .4971 Mtetra
.50983 .4971 .51208 .49947 .51617 .49819 .51393 .49582 Mtetra
.51393 .49582 .51617 .49819 .52027 .4969 .51803 .49453 Mtetra
.51803 .49453 .52027 .4969 .52437 .49562 .52214 .49324 Mtetra
.52214 .49324 .52437 .49562 .52848 .49433 .52626 .49195 Mtetra
.52626 .49195 .52848 .49433 .5326 .49304 .53038 .49066 Mtetra
.53038 .49066 .5326 .49304 .53673 .49175 .53451 .48936 Mtetra
.96 .72 .53 r
.53451 .48936 .53673 .49175 .54068 .45448 .53849 .45206 Mtetra
.658 .749 .917 r
.53849 .45206 .54068 .45448 .54477 .45317 .54259 .45075 Mtetra
.54259 .45075 .54477 .45317 .54887 .45186 .54669 .44944 Mtetra
.54669 .44944 .54887 .45186 .55297 .45055 .5508 .44812 Mtetra
.5508 .44812 .55297 .45055 .55708 .44924 .55491 .44681 Mtetra
.55491 .44681 .55708 .44924 .5612 .44792 .55903 .44549 Mtetra
.55903 .44549 .5612 .44792 .56532 .4466 .56315 .44416 Mtetra
.56315 .44416 .56532 .4466 .56945 .44528 .56729 .44284 Mtetra
.56729 .44284 .56945 .44528 .57358 .44396 .57142 .44152 Mtetra
.57142 .44152 .57358 .44396 .57772 .44264 .57557 .44019 Mtetra
.57557 .44019 .57772 .44264 .58187 .44131 .57972 .43886 Mtetra
.57972 .43886 .58187 .44131 .58602 .43998 .58388 .43753 Mtetra
.58388 .43753 .58602 .43998 .59018 .43866 .58804 .4362 Mtetra
.58804 .4362 .59018 .43866 .59434 .43732 .59221 .43486 Mtetra
.59221 .43486 .59434 .43732 .59851 .43599 .59638 .43352 Mtetra
.59638 .43352 .59851 .43599 .60269 .43466 .60056 .43218 Mtetra
.60056 .43218 .60269 .43466 .60688 .43332 .60475 .43084 Mtetra
.60475 .43084 .60688 .43332 .61106 .43198 .60895 .4295 Mtetra
.60895 .4295 .61106 .43198 .61526 .43064 .61315 .42816 Mtetra
.971 .703 .466 r
.61315 .42816 .61526 .43064 .61714 .34943 .61508 .3469 Mtetra
.664 .741 .908 r
.61508 .3469 .61714 .34943 .62124 .34806 .61919 .34553 Mtetra
.61919 .34553 .62124 .34806 .62535 .34669 .6233 .34415 Mtetra
.6233 .34415 .62535 .34669 .62947 .34532 .62742 .34277 Mtetra
.62742 .34277 .62947 .34532 .63359 .34394 .63155 .34139 Mtetra
.63155 .34139 .63359 .34394 .63772 .34256 .63568 .34001 Mtetra
.63568 .34001 .63772 .34256 .64185 .34118 .63982 .33862 Mtetra
.63982 .33862 .64185 .34118 .64599 .3398 .64396 .33724 Mtetra
.64396 .33724 .64599 .3398 .65014 .33841 .64811 .33585 Mtetra
.64811 .33585 .65014 .33841 .65429 .33702 .65227 .33446 Mtetra
.65227 .33446 .65429 .33702 .65845 .33563 .65643 .33306 Mtetra
.65643 .33306 .65845 .33563 .66261 .33424 .6606 .33167 Mtetra
.6606 .33167 .66261 .33424 .66679 .33285 .66477 .33027 Mtetra
.66477 .33027 .66679 .33285 .67096 .33145 .66895 .32887 Mtetra
.66895 .32887 .67096 .33145 .67514 .33006 .67314 .32747 Mtetra
.67314 .32747 .67514 .33006 .67933 .32866 .67733 .32607 Mtetra
.67733 .32607 .67933 .32866 .68353 .32725 .68153 .32466 Mtetra
.68153 .32466 .68353 .32725 .68773 .32585 .68574 .32325 Mtetra
.68574 .32325 .68773 .32585 .69194 .32444 .68995 .32184 Mtetra
.68995 .32184 .69194 .32444 .69615 .32304 .69417 .32043 Mtetra
.69417 .32043 .69615 .32304 .70037 .32163 .6984 .31902 Mtetra
.6984 .31902 .70037 .32163 .7046 .32021 .70263 .3176 Mtetra
.70263 .3176 .7046 .32021 .70883 .3188 .70686 .31618 Mtetra
.70686 .31618 .70883 .3188 .71307 .31738 .71111 .31476 Mtetra
.937 .572 .18 r
.71111 .31476 .71307 .31738 .71883 .34068 .71686 .33807 Mtetra
.662 .744 .911 r
.71686 .33807 .71883 .34068 .72312 .33926 .72115 .33665 Mtetra
.72115 .33665 .72312 .33926 .72741 .33785 .72545 .33523 Mtetra
.72545 .33523 .72741 .33785 .73171 .33643 .72975 .33381 Mtetra
.72975 .33381 .73171 .33643 .73602 .33501 .73406 .33238 Mtetra
.73406 .33238 .73602 .33501 .74033 .33359 .73838 .33096 Mtetra
.73838 .33096 .74033 .33359 .74465 .33217 .7427 .32953 Mtetra
.7427 .32953 .74465 .33217 .74898 .33074 .74703 .3281 Mtetra
.74703 .3281 .74898 .33074 .75331 .32931 .75137 .32667 Mtetra
.75137 .32667 .75331 .32931 .75765 .32788 .75571 .32523 Mtetra
.75571 .32523 .75765 .32788 .76199 .32645 .76006 .3238 Mtetra
.76006 .3238 .76199 .32645 .76634 .32501 .76442 .32236 Mtetra
.76442 .32236 .76634 .32501 .7707 .32358 .76878 .32092 Mtetra
.76878 .32092 .7707 .32358 .78414 .43614 .77315 .31948 Mtetra
.079 .007 .465 r
.77315 .31948 .78414 .43614 .78868 .43474 .78671 .43214 Mtetra
.653 .754 .924 r
.78671 .43214 .78868 .43474 .79322 .43333 .79126 .43073 Mtetra
.79126 .43073 .79322 .43333 .79777 .43193 .79582 .42932 Mtetra
.79582 .42932 .79777 .43193 .80233 .43052 .80038 .42791 Mtetra
.80038 .42791 .80233 .43052 .8069 .4291 .80495 .42649 Mtetra
.80495 .42649 .8069 .4291 .81147 .42769 .80953 .42507 Mtetra
.80953 .42507 .81147 .42769 .81605 .42627 .81412 .42365 Mtetra
.81412 .42365 .81605 .42627 .82064 .42485 .81871 .42223 Mtetra
.81871 .42223 .82064 .42485 .82524 .42343 .82331 .4208 Mtetra
.82331 .4208 .82524 .42343 .82984 .42201 .82792 .41937 Mtetra
.82792 .41937 .82984 .42201 .83445 .42058 .83253 .41794 Mtetra
.83253 .41794 .83445 .42058 .83906 .41915 .83716 .41651 Mtetra
.83716 .41651 .83906 .41915 .84369 .41772 .84179 .41507 Mtetra
.84179 .41507 .84369 .41772 .84832 .41629 .84642 .41364 Mtetra
.84642 .41364 .84832 .41629 .85296 .41485 .85107 .4122 Mtetra
.85107 .4122 .85296 .41485 .85761 .41342 .85572 .41076 Mtetra
.85572 .41076 .85761 .41342 .86226 .41198 .86038 .40931 Mtetra
.86038 .40931 .86226 .41198 .86692 .41053 .86505 .40787 Mtetra
.86505 .40787 .86692 .41053 .87159 .40909 .86972 .40642 Mtetra
.86972 .40642 .87159 .40909 .87627 .40764 .8744 .40497 Mtetra
.648 .76 .931 r
.23975 .65461 .2423 .65671 .24609 .65557 .24355 .65347 Mtetra
.24355 .65347 .24609 .65557 .2499 .65443 .24735 .65233 Mtetra
.24735 .65233 .2499 .65443 .2537 .65329 .25116 .65119 Mtetra
.25116 .65119 .2537 .65329 .25752 .65215 .25498 .65004 Mtetra
.25498 .65004 .25752 .65215 .26133 .65101 .2588 .6489 Mtetra
.2588 .6489 .26133 .65101 .26516 .64987 .26263 .64775 Mtetra
.26263 .64775 .26516 .64987 .26899 .64872 .26646 .6466 Mtetra
.26646 .6466 .26899 .64872 .27282 .64757 .2703 .64545 Mtetra
.2703 .64545 .27282 .64757 .27666 .64642 .27414 .6443 Mtetra
.27414 .6443 .27666 .64642 .28051 .64527 .27799 .64314 Mtetra
.27799 .64314 .28051 .64527 .28436 .64412 .28185 .64199 Mtetra
.28185 .64199 .28436 .64412 .28822 .64297 .28571 .64083 Mtetra
.28571 .64083 .28822 .64297 .29208 .64181 .28958 .63967 Mtetra
.28958 .63967 .29208 .64181 .29595 .64065 .29345 .63851 Mtetra
.29345 .63851 .29595 .64065 .29983 .63949 .29733 .63735 Mtetra
.29733 .63735 .29983 .63949 .30371 .63833 .30121 .63618 Mtetra
.30121 .63618 .30371 .63833 .30759 .63717 .3051 .63502 Mtetra
.3051 .63502 .30759 .63717 .31148 .636 .309 .63385 Mtetra
.309 .63385 .31148 .636 .31538 .63484 .3129 .63268 Mtetra
.3129 .63268 .31538 .63484 .31929 .63367 .3168 .63151 Mtetra
.944 .692 .526 r
.3168 .63151 .31929 .63367 .32319 .6325 .33092 .45773 Mtetra
.551 .338 .544 r
.33092 .45773 .32319 .6325 .33699 .45878 .33465 .45649 Mtetra
.662 .743 .91 r
.33465 .45649 .33699 .45878 .34072 .45754 .33839 .45525 Mtetra
.33839 .45525 .34072 .45754 .34446 .4563 .34213 .45401 Mtetra
.34213 .45401 .34446 .4563 .3482 .45506 .34587 .45277 Mtetra
.34587 .45277 .3482 .45506 .35195 .45382 .34962 .45153 Mtetra
.34962 .45153 .35195 .45382 .3557 .45258 .35338 .45028 Mtetra
.35338 .45028 .3557 .45258 .35946 .45134 .35714 .44903 Mtetra
.35714 .44903 .35946 .45134 .36322 .45009 .36091 .44778 Mtetra
.36091 .44778 .36322 .45009 .36699 .44884 .36468 .44653 Mtetra
.36468 .44653 .36699 .44884 .37076 .44759 .36846 .44528 Mtetra
.36846 .44528 .37076 .44759 .37454 .44634 .37224 .44403 Mtetra
.37224 .44403 .37454 .44634 .37833 .44509 .37603 .44277 Mtetra
.37603 .44277 .37833 .44509 .38212 .44383 .37982 .44151 Mtetra
.37982 .44151 .38212 .44383 .38591 .44258 .38362 .44025 Mtetra
.38362 .44025 .38591 .44258 .38971 .44132 .38742 .43899 Mtetra
.38742 .43899 .38971 .44132 .39352 .44006 .39123 .43773 Mtetra
.39123 .43773 .39352 .44006 .39733 .4388 .39505 .43646 Mtetra
.39505 .43646 .39733 .4388 .40115 .43753 .39887 .43519 Mtetra
.39887 .43519 .40115 .43753 .40497 .43627 .40269 .43392 Mtetra
.40269 .43392 .40497 .43627 .4088 .435 .40652 .43265 Mtetra
.928 .736 .623 r
.40652 .43265 .4088 .435 .41313 .41923 .41087 .41688 Mtetra
.663 .742 .908 r
.41087 .41688 .41313 .41923 .41695 .41796 .4147 .4156 Mtetra
.4147 .4156 .41695 .41796 .42078 .41668 .41853 .41432 Mtetra
.41853 .41432 .42078 .41668 .42461 .4154 .42236 .41304 Mtetra
.42236 .41304 .42461 .4154 .42845 .41412 .4262 .41175 Mtetra
.4262 .41175 .42845 .41412 .4323 .41284 .43005 .41046 Mtetra
.43005 .41046 .4323 .41284 .43614 .41155 .4339 .40918 Mtetra
.4339 .40918 .43614 .41155 .44 .41027 .43776 .40789 Mtetra
.43776 .40789 .44 .41027 .44386 .40898 .44163 .40659 Mtetra
.44163 .40659 .44386 .40898 .44773 .40769 .4455 .4053 Mtetra
.4455 .4053 .44773 .40769 .4516 .4064 .44937 .40401 Mtetra
.44937 .40401 .4516 .4064 .45547 .4051 .45325 .40271 Mtetra
.45325 .40271 .45547 .4051 .45936 .40381 .45714 .40141 Mtetra
.45714 .40141 .45936 .40381 .46324 .40251 .46103 .40011 Mtetra
.46103 .40011 .46324 .40251 .46714 .40121 .46492 .3988 Mtetra
.46492 .3988 .46714 .40121 .47104 .39991 .46883 .3975 Mtetra
.46883 .3975 .47104 .39991 .47494 .3986 .47274 .39619 Mtetra
.47274 .39619 .47494 .3986 .47885 .3973 .47665 .39488 Mtetra
.962 .676 .446 r
.47665 .39488 .47885 .3973 .48133 .50604 .47905 .50369 Mtetra
.655 .752 .922 r
.47905 .50369 .48133 .50604 .48538 .50477 .48311 .50242 Mtetra
.48311 .50242 .48538 .50477 .48944 .5035 .48717 .50114 Mtetra
.48717 .50114 .48944 .5035 .49351 .50222 .49124 .49986 Mtetra
.49124 .49986 .49351 .50222 .49758 .50095 .49532 .49858 Mtetra
.49532 .49858 .49758 .50095 .50166 .49967 .4994 .4973 Mtetra
.4994 .4973 .50166 .49967 .50574 .49838 .50349 .49601 Mtetra
.50349 .49601 .50574 .49838 .50983 .4971 .50759 .49473 Mtetra
.50759 .49473 .50983 .4971 .51393 .49582 .51169 .49344 Mtetra
.51169 .49344 .51393 .49582 .51803 .49453 .5158 .49215 Mtetra
.5158 .49215 .51803 .49453 .52214 .49324 .51991 .49085 Mtetra
.51991 .49085 .52214 .49324 .52626 .49195 .52403 .48956 Mtetra
.52403 .48956 .52626 .49195 .53038 .49066 .52815 .48826 Mtetra
.52815 .48826 .53038 .49066 .53451 .48936 .53229 .48696 Mtetra
.53229 .48696 .53451 .48936 .53849 .45206 .53642 .48566 Mtetra
0 0 .257 r
.53642 .48566 .53849 .45206 .54259 .45075 .5404 .44832 Mtetra
.658 .749 .917 r
.5404 .44832 .54259 .45075 .54669 .44944 .5445 .44701 Mtetra
.5445 .44701 .54669 .44944 .5508 .44812 .54861 .44569 Mtetra
.54861 .44569 .5508 .44812 .55491 .44681 .55273 .44437 Mtetra
.55273 .44437 .55491 .44681 .55903 .44549 .55685 .44305 Mtetra
.55685 .44305 .55903 .44549 .56315 .44416 .56098 .44172 Mtetra
.56098 .44172 .56315 .44416 .56729 .44284 .56512 .44039 Mtetra
.56512 .44039 .56729 .44284 .57142 .44152 .56926 .43906 Mtetra
.56926 .43906 .57142 .44152 .57557 .44019 .57341 .43773 Mtetra
.57341 .43773 .57557 .44019 .57972 .43886 .57756 .4364 Mtetra
.57756 .4364 .57972 .43886 .58388 .43753 .58172 .43507 Mtetra
.58172 .43507 .58388 .43753 .58804 .4362 .58589 .43373 Mtetra
.58589 .43373 .58804 .4362 .59221 .43486 .59006 .43239 Mtetra
.59006 .43239 .59221 .43486 .59638 .43352 .59424 .43105 Mtetra
.59424 .43105 .59638 .43352 .60056 .43218 .59843 .42971 Mtetra
.59843 .42971 .60056 .43218 .60475 .43084 .60262 .42836 Mtetra
.60262 .42836 .60475 .43084 .60895 .4295 .60682 .42702 Mtetra
.60682 .42702 .60895 .4295 .61315 .42816 .61102 .42567 Mtetra
.971 .703 .466 r
.61102 .42567 .61315 .42816 .61508 .3469 .61301 .34436 Mtetra
.664 .741 .908 r
.61301 .34436 .61508 .3469 .61919 .34553 .61712 .34298 Mtetra
.61712 .34298 .61919 .34553 .6233 .34415 .62124 .3416 Mtetra
.62124 .3416 .6233 .34415 .62742 .34277 .62536 .34022 Mtetra
.62536 .34022 .62742 .34277 .63155 .34139 .62949 .33884 Mtetra
.62949 .33884 .63155 .34139 .63568 .34001 .63363 .33745 Mtetra
.63363 .33745 .63568 .34001 .63982 .33862 .63777 .33606 Mtetra
.63777 .33606 .63982 .33862 .64396 .33724 .64192 .33467 Mtetra
.64192 .33467 .64396 .33724 .64811 .33585 .64607 .33328 Mtetra
.64607 .33328 .64811 .33585 .65227 .33446 .65024 .33188 Mtetra
.65024 .33188 .65227 .33446 .65643 .33306 .6544 .33049 Mtetra
.6544 .33049 .65643 .33306 .6606 .33167 .65857 .32909 Mtetra
.65857 .32909 .6606 .33167 .66477 .33027 .66275 .32769 Mtetra
.66275 .32769 .66477 .33027 .66895 .32887 .66694 .32628 Mtetra
.66694 .32628 .66895 .32887 .67314 .32747 .67113 .32488 Mtetra
.67113 .32488 .67314 .32747 .67733 .32607 .67533 .32347 Mtetra
.67533 .32347 .67733 .32607 .68153 .32466 .67953 .32206 Mtetra
.67953 .32206 .68153 .32466 .68574 .32325 .68374 .32065 Mtetra
.68374 .32065 .68574 .32325 .68995 .32184 .68796 .31924 Mtetra
.68796 .31924 .68995 .32184 .69417 .32043 .69218 .31782 Mtetra
.69218 .31782 .69417 .32043 .6984 .31902 .69641 .3164 Mtetra
.69641 .3164 .6984 .31902 .70263 .3176 .70065 .31498 Mtetra
.70065 .31498 .70263 .3176 .70686 .31618 .70489 .31356 Mtetra
.938 .573 .183 r
.70489 .31356 .70686 .31618 .71111 .31476 .71059 .33687 Mtetra
.514 .258 .464 r
.71059 .33687 .71111 .31476 .71686 .33807 .71488 .33545 Mtetra
.662 .744 .911 r
.71488 .33545 .71686 .33807 .72115 .33665 .71917 .33403 Mtetra
.71917 .33403 .72115 .33665 .72545 .33523 .72348 .3326 Mtetra
.72348 .3326 .72545 .33523 .72975 .33381 .72779 .33118 Mtetra
.72779 .33118 .72975 .33381 .73406 .33238 .7321 .32975 Mtetra
.7321 .32975 .73406 .33238 .73838 .33096 .73642 .32832 Mtetra
.73642 .32832 .73838 .33096 .7427 .32953 .74075 .32689 Mtetra
.74075 .32689 .7427 .32953 .74703 .3281 .74509 .32546 Mtetra
.74509 .32546 .74703 .3281 .75137 .32667 .74943 .32402 Mtetra
.74943 .32402 .75137 .32667 .75571 .32523 .75377 .32258 Mtetra
.75377 .32258 .75571 .32523 .76006 .3238 .75813 .32114 Mtetra
.75813 .32114 .76006 .3238 .76442 .32236 .76249 .3197 Mtetra
.76249 .3197 .76442 .32236 .76878 .32092 .76686 .31825 Mtetra
.76686 .31825 .76878 .32092 .77315 .31948 .77123 .31681 Mtetra
.97 .652 .308 r
.77123 .31681 .77315 .31948 .78671 .43214 .78474 .42954 Mtetra
.653 .754 .924 r
.78474 .42954 .78671 .43214 .79126 .43073 .78929 .42812 Mtetra
.78929 .42812 .79126 .43073 .79582 .42932 .79385 .42671 Mtetra
.79385 .42671 .79582 .42932 .80038 .42791 .79842 .42529 Mtetra
.79842 .42529 .80038 .42791 .80495 .42649 .803 .42387 Mtetra
.803 .42387 .80495 .42649 .80953 .42507 .80758 .42244 Mtetra
.80758 .42244 .80953 .42507 .81412 .42365 .81217 .42102 Mtetra
.81217 .42102 .81412 .42365 .81871 .42223 .81677 .41959 Mtetra
.81677 .41959 .81871 .42223 .82331 .4208 .82138 .41816 Mtetra
.82138 .41816 .82331 .4208 .82792 .41937 .82599 .41673 Mtetra
.82599 .41673 .82792 .41937 .83253 .41794 .83061 .41529 Mtetra
.83061 .41529 .83253 .41794 .83716 .41651 .83524 .41386 Mtetra
.83524 .41386 .83716 .41651 .84179 .41507 .83988 .41242 Mtetra
.83988 .41242 .84179 .41507 .84642 .41364 .84452 .41098 Mtetra
.84452 .41098 .84642 .41364 .85107 .4122 .84917 .40953 Mtetra
.84917 .40953 .85107 .4122 .85572 .41076 .85383 .40809 Mtetra
.85383 .40809 .85572 .41076 .86038 .40931 .85849 .40664 Mtetra
.85849 .40664 .86038 .40931 .86505 .40787 .86316 .40519 Mtetra
.86316 .40519 .86505 .40787 .86972 .40642 .86784 .40374 Mtetra
.86784 .40374 .86972 .40642 .8744 .40497 .87253 .40228 Mtetra
.648 .76 .931 r
.23719 .6525 .23975 .65461 .24355 .65347 .241 .65136 Mtetra
.241 .65136 .24355 .65347 .24735 .65233 .2448 .65022 Mtetra
.2448 .65022 .24735 .65233 .25116 .65119 .24862 .64907 Mtetra
.24862 .64907 .25116 .65119 .25498 .65004 .25244 .64793 Mtetra
.25244 .64793 .25498 .65004 .2588 .6489 .25626 .64678 Mtetra
.25626 .64678 .2588 .6489 .26263 .64775 .26009 .64563 Mtetra
.26009 .64563 .26263 .64775 .26646 .6466 .26393 .64447 Mtetra
.26393 .64447 .26646 .6466 .2703 .64545 .26777 .64332 Mtetra
.26777 .64332 .2703 .64545 .27414 .6443 .27162 .64217 Mtetra
.27162 .64217 .27414 .6443 .27799 .64314 .27547 .64101 Mtetra
.27547 .64101 .27799 .64314 .28185 .64199 .27933 .63985 Mtetra
.27933 .63985 .28185 .64199 .28571 .64083 .28319 .63869 Mtetra
.28319 .63869 .28571 .64083 .28958 .63967 .28706 .63753 Mtetra
.28706 .63753 .28958 .63967 .29345 .63851 .29094 .63636 Mtetra
.29094 .63636 .29345 .63851 .29733 .63735 .29482 .6352 Mtetra
.29482 .6352 .29733 .63735 .30121 .63618 .29871 .63403 Mtetra
.29871 .63403 .30121 .63618 .3051 .63502 .3026 .63286 Mtetra
.3026 .63286 .3051 .63502 .309 .63385 .3065 .63169 Mtetra
.3065 .63169 .309 .63385 .3129 .63268 .31041 .63052 Mtetra
.31041 .63052 .3129 .63268 .3168 .63151 .31432 .62934 Mtetra
.944 .692 .526 r
.31432 .62934 .3168 .63151 .33092 .45773 .32858 .45545 Mtetra
.662 .743 .91 r
.32858 .45545 .33092 .45773 .33465 .45649 .33231 .45421 Mtetra
.33231 .45421 .33465 .45649 .33839 .45525 .33605 .45296 Mtetra
.33605 .45296 .33839 .45525 .34213 .45401 .33979 .45172 Mtetra
.33979 .45172 .34213 .45401 .34587 .45277 .34354 .45047 Mtetra
.34354 .45047 .34587 .45277 .34962 .45153 .34729 .44923 Mtetra
.34729 .44923 .34962 .45153 .35338 .45028 .35105 .44798 Mtetra
.35105 .44798 .35338 .45028 .35714 .44903 .35482 .44673 Mtetra
.35482 .44673 .35714 .44903 .36091 .44778 .35859 .44547 Mtetra
.35859 .44547 .36091 .44778 .36468 .44653 .36236 .44422 Mtetra
.36236 .44422 .36468 .44653 .36846 .44528 .36614 .44296 Mtetra
.36614 .44296 .36846 .44528 .37224 .44403 .36993 .44171 Mtetra
.36993 .44171 .37224 .44403 .37603 .44277 .37372 .44045 Mtetra
.37372 .44045 .37603 .44277 .37982 .44151 .37752 .43918 Mtetra
.37752 .43918 .37982 .44151 .38362 .44025 .38132 .43792 Mtetra
.38132 .43792 .38362 .44025 .38742 .43899 .38512 .43666 Mtetra
.38512 .43666 .38742 .43899 .39123 .43773 .38894 .43539 Mtetra
.38894 .43539 .39123 .43773 .39505 .43646 .39276 .43412 Mtetra
.39276 .43412 .39505 .43646 .39887 .43519 .39658 .43285 Mtetra
.39658 .43285 .39887 .43519 .40269 .43392 .40041 .43158 Mtetra
.40041 .43158 .40269 .43392 .40652 .43265 .40424 .4303 Mtetra
.928 .736 .623 r
.40424 .4303 .40652 .43265 .41087 .41688 .4086 .41452 Mtetra
.663 .742 .908 r
.4086 .41452 .41087 .41688 .4147 .4156 .41243 .41323 Mtetra
.41243 .41323 .4147 .4156 .41853 .41432 .41627 .41195 Mtetra
.41627 .41195 .41853 .41432 .42236 .41304 .42011 .41066 Mtetra
.42011 .41066 .42236 .41304 .4262 .41175 .42395 .40937 Mtetra
.42395 .40937 .4262 .41175 .43005 .41046 .4278 .40809 Mtetra
.4278 .40809 .43005 .41046 .4339 .40918 .43166 .40679 Mtetra
.43166 .40679 .4339 .40918 .43776 .40789 .43552 .4055 Mtetra
.43552 .4055 .43776 .40789 .44163 .40659 .43939 .4042 Mtetra
.43939 .4042 .44163 .40659 .4455 .4053 .44326 .40291 Mtetra
.44326 .40291 .4455 .4053 .44937 .40401 .44714 .40161 Mtetra
.44714 .40161 .44937 .40401 .45325 .40271 .45102 .40031 Mtetra
.45102 .40031 .45325 .40271 .45714 .40141 .45491 .39901 Mtetra
.45491 .39901 .45714 .40141 .46103 .40011 .45881 .3977 Mtetra
.45881 .3977 .46103 .40011 .46492 .3988 .46271 .39639 Mtetra
.46271 .39639 .46492 .3988 .46883 .3975 .46661 .39509 Mtetra
.46661 .39509 .46883 .3975 .47274 .39619 .47052 .39378 Mtetra
.47052 .39378 .47274 .39619 .47665 .39488 .47444 .39246 Mtetra
.962 .676 .446 r
.47444 .39246 .47665 .39488 .47905 .50369 .47677 .50134 Mtetra
.655 .752 .922 r
.47677 .50134 .47905 .50369 .48311 .50242 .48083 .50006 Mtetra
.48083 .50006 .48311 .50242 .48717 .50114 .4849 .49878 Mtetra
.4849 .49878 .48717 .50114 .49124 .49986 .48897 .4975 Mtetra
.48897 .4975 .49124 .49986 .49532 .49858 .49306 .49621 Mtetra
.49306 .49621 .49532 .49858 .4994 .4973 .49714 .49492 Mtetra
.49714 .49492 .4994 .4973 .50349 .49601 .50123 .49364 Mtetra
.50123 .49364 .50349 .49601 .50759 .49473 .50533 .49235 Mtetra
.50533 .49235 .50759 .49473 .51169 .49344 .50944 .49105 Mtetra
.50944 .49105 .51169 .49344 .5158 .49215 .51355 .48976 Mtetra
.51355 .48976 .5158 .49215 .51991 .49085 .51767 .48846 Mtetra
.51767 .48846 .51991 .49085 .52403 .48956 .52179 .48716 Mtetra
.52179 .48716 .52403 .48956 .52815 .48826 .52592 .48586 Mtetra
.52592 .48586 .52815 .48826 .53229 .48696 .53006 .48456 Mtetra
.53006 .48456 .53229 .48696 .53642 .48566 .5342 .48326 Mtetra
.96 .72 .529 r
.5342 .48326 .53642 .48566 .5404 .44832 .5382 .44589 Mtetra
.658 .749 .917 r
.5382 .44589 .5404 .44832 .5445 .44701 .54231 .44457 Mtetra
.54231 .44457 .5445 .44701 .54861 .44569 .54642 .44325 Mtetra
.54642 .44325 .54861 .44569 .55273 .44437 .55054 .44192 Mtetra
.55054 .44192 .55273 .44437 .55685 .44305 .55467 .4406 Mtetra
.55467 .4406 .55685 .44305 .56098 .44172 .55881 .43927 Mtetra
.55881 .43927 .56098 .44172 .56512 .44039 .56295 .43794 Mtetra
.56295 .43794 .56512 .44039 .56926 .43906 .56709 .43661 Mtetra
.56709 .43661 .56926 .43906 .57341 .43773 .57124 .43527 Mtetra
.57124 .43527 .57341 .43773 .57756 .4364 .5754 .43394 Mtetra
.5754 .43394 .57756 .4364 .58172 .43507 .57957 .4326 Mtetra
.57957 .4326 .58172 .43507 .58589 .43373 .58374 .43126 Mtetra
.58374 .43126 .58589 .43373 .59006 .43239 .58792 .42991 Mtetra
.58792 .42991 .59006 .43239 .59424 .43105 .5921 .42857 Mtetra
.5921 .42857 .59424 .43105 .59843 .42971 .59629 .42722 Mtetra
.59629 .42722 .59843 .42971 .60262 .42836 .60049 .42587 Mtetra
.60049 .42587 .60262 .42836 .60682 .42702 .60469 .42452 Mtetra
.962 .631 .317 r
.60469 .42452 .60682 .42702 .61102 .42567 .60984 .45944 Mtetra
.526 .282 .487 r
.60984 .45944 .61102 .42567 .61301 .34436 .6141 .4581 Mtetra
0 0 .361 r
.6141 .4581 .61301 .34436 .61712 .34298 .61505 .34043 Mtetra
.664 .741 .908 r
.61505 .34043 .61712 .34298 .62124 .3416 .61917 .33905 Mtetra
.61917 .33905 .62124 .3416 .62536 .34022 .6233 .33766 Mtetra
.6233 .33766 .62536 .34022 .62949 .33884 .62744 .33627 Mtetra
.62744 .33627 .62949 .33884 .63363 .33745 .63158 .33488 Mtetra
.63158 .33488 .63363 .33745 .63777 .33606 .63572 .33349 Mtetra
.63572 .33349 .63777 .33606 .64192 .33467 .63988 .3321 Mtetra
.63988 .3321 .64192 .33467 .64607 .33328 .64403 .3307 Mtetra
.64403 .3307 .64607 .33328 .65024 .33188 .6482 .3293 Mtetra
.6482 .3293 .65024 .33188 .6544 .33049 .65237 .3279 Mtetra
.65237 .3279 .6544 .33049 .65857 .32909 .65655 .3265 Mtetra
.65655 .3265 .65857 .32909 .66275 .32769 .66073 .32509 Mtetra
.66073 .32509 .66275 .32769 .66694 .32628 .66492 .32369 Mtetra
.66492 .32369 .66694 .32628 .67113 .32488 .66912 .32228 Mtetra
.66912 .32228 .67113 .32488 .67533 .32347 .67332 .32087 Mtetra
.67332 .32087 .67533 .32347 .67953 .32206 .67753 .31945 Mtetra
.67753 .31945 .67953 .32206 .68374 .32065 .68174 .31804 Mtetra
.68174 .31804 .68374 .32065 .68796 .31924 .68596 .31662 Mtetra
.68596 .31662 .68796 .31924 .69218 .31782 .69019 .3152 Mtetra
.69019 .3152 .69218 .31782 .69641 .3164 .69442 .31378 Mtetra
.69442 .31378 .69641 .3164 .70065 .31498 .69866 .31236 Mtetra
.69866 .31236 .70065 .31498 .70489 .31356 .70291 .31093 Mtetra
.938 .573 .183 r
.70291 .31093 .70489 .31356 .71059 .33687 .7086 .33425 Mtetra
.662 .744 .911 r
.7086 .33425 .71059 .33687 .71488 .33545 .71289 .33282 Mtetra
.71289 .33282 .71488 .33545 .71917 .33403 .71719 .3314 Mtetra
.71719 .3314 .71917 .33403 .72348 .3326 .7215 .32997 Mtetra
.7215 .32997 .72348 .3326 .72779 .33118 .72581 .32854 Mtetra
.72581 .32854 .72779 .33118 .7321 .32975 .73013 .32711 Mtetra
.73013 .32711 .7321 .32975 .73642 .32832 .73446 .32568 Mtetra
.73446 .32568 .73642 .32832 .74075 .32689 .73879 .32424 Mtetra
.73879 .32424 .74075 .32689 .74509 .32546 .74313 .3228 Mtetra
.74313 .3228 .74509 .32546 .74943 .32402 .74748 .32136 Mtetra
.74748 .32136 .74943 .32402 .75377 .32258 .75183 .31992 Mtetra
.75183 .31992 .75377 .32258 .75813 .32114 .75619 .31848 Mtetra
.75619 .31848 .75813 .32114 .76249 .3197 .76056 .31703 Mtetra
.76056 .31703 .76249 .3197 .76686 .31825 .76493 .31558 Mtetra
.76493 .31558 .76686 .31825 .77123 .31681 .76931 .31413 Mtetra
.76931 .31413 .77123 .31681 .78474 .42954 .77369 .31267 Mtetra
.077 .005 .463 r
.77369 .31267 .78474 .42954 .78929 .42812 .78732 .42551 Mtetra
.653 .754 .924 r
.78732 .42551 .78929 .42812 .79385 .42671 .79189 .42409 Mtetra
.79189 .42409 .79385 .42671 .79842 .42529 .79646 .42266 Mtetra
.79646 .42266 .79842 .42529 .803 .42387 .80104 .42124 Mtetra
.80104 .42124 .803 .42387 .80758 .42244 .80563 .41981 Mtetra
.80563 .41981 .80758 .42244 .81217 .42102 .81023 .41838 Mtetra
.81023 .41838 .81217 .42102 .81677 .41959 .81483 .41695 Mtetra
.81483 .41695 .81677 .41959 .82138 .41816 .81944 .41552 Mtetra
.81944 .41552 .82138 .41816 .82599 .41673 .82406 .41408 Mtetra
.82406 .41408 .82599 .41673 .83061 .41529 .82869 .41264 Mtetra
.82869 .41264 .83061 .41529 .83524 .41386 .83332 .4112 Mtetra
.83332 .4112 .83524 .41386 .83988 .41242 .83796 .40976 Mtetra
.83796 .40976 .83988 .41242 .84452 .41098 .84261 .40831 Mtetra
.84261 .40831 .84452 .41098 .84917 .40953 .84726 .40686 Mtetra
.84726 .40686 .84917 .40953 .85383 .40809 .85193 .40541 Mtetra
.85193 .40541 .85383 .40809 .85849 .40664 .8566 .40396 Mtetra
.8566 .40396 .85849 .40664 .86316 .40519 .86127 .40251 Mtetra
.86127 .40251 .86316 .40519 .86784 .40374 .86596 .40105 Mtetra
.86596 .40105 .86784 .40374 .87253 .40228 .87065 .39959 Mtetra
.648 .76 .931 r
.23463 .65039 .23719 .6525 .241 .65136 .23844 .64925 Mtetra
.23844 .64925 .241 .65136 .2448 .65022 .24225 .6481 Mtetra
.24225 .6481 .2448 .65022 .24862 .64907 .24607 .64695 Mtetra
.24607 .64695 .24862 .64907 .25244 .64793 .24989 .6458 Mtetra
.24989 .6458 .25244 .64793 .25626 .64678 .25372 .64465 Mtetra
.25372 .64465 .25626 .64678 .26009 .64563 .25755 .6435 Mtetra
.25755 .6435 .26009 .64563 .26393 .64447 .26139 .64234 Mtetra
.26139 .64234 .26393 .64447 .26777 .64332 .26523 .64119 Mtetra
.26523 .64119 .26777 .64332 .27162 .64217 .26909 .64003 Mtetra
.26909 .64003 .27162 .64217 .27547 .64101 .27294 .63887 Mtetra
.27294 .63887 .27547 .64101 .27933 .63985 .2768 .63771 Mtetra
.2768 .63771 .27933 .63985 .28319 .63869 .28067 .63654 Mtetra
.28067 .63654 .28319 .63869 .28706 .63753 .28455 .63538 Mtetra
.28455 .63538 .28706 .63753 .29094 .63636 .28842 .63421 Mtetra
.28842 .63421 .29094 .63636 .29482 .6352 .29231 .63304 Mtetra
.29231 .63304 .29482 .6352 .29871 .63403 .2962 .63187 Mtetra
.2962 .63187 .29871 .63403 .3026 .63286 .3001 .6307 Mtetra
.3001 .6307 .3026 .63286 .3065 .63169 .304 .62952 Mtetra
.304 .62952 .3065 .63169 .31041 .63052 .30791 .62835 Mtetra
.30791 .62835 .31041 .63052 .31432 .62934 .31182 .62717 Mtetra
.944 .692 .526 r
.31182 .62717 .31432 .62934 .32858 .45545 .32622 .45315 Mtetra
.662 .743 .91 r
.32622 .45315 .32858 .45545 .33231 .45421 .32996 .45191 Mtetra
.32996 .45191 .33231 .45421 .33605 .45296 .3337 .45067 Mtetra
.3337 .45067 .33605 .45296 .33979 .45172 .33745 .44942 Mtetra
.33745 .44942 .33979 .45172 .34354 .45047 .3412 .44817 Mtetra
.3412 .44817 .34354 .45047 .34729 .44923 .34496 .44692 Mtetra
.34496 .44692 .34729 .44923 .35105 .44798 .34872 .44567 Mtetra
.34872 .44567 .35105 .44798 .35482 .44673 .35249 .44441 Mtetra
.35249 .44441 .35482 .44673 .35859 .44547 .35626 .44316 Mtetra
.35626 .44316 .35859 .44547 .36236 .44422 .36004 .4419 Mtetra
.36004 .4419 .36236 .44422 .36614 .44296 .36382 .44064 Mtetra
.36382 .44064 .36614 .44296 .36993 .44171 .36761 .43938 Mtetra
.36761 .43938 .36993 .44171 .37372 .44045 .3714 .43811 Mtetra
.3714 .43811 .37372 .44045 .37752 .43918 .3752 .43685 Mtetra
.3752 .43685 .37752 .43918 .38132 .43792 .37901 .43558 Mtetra
.37901 .43558 .38132 .43792 .38512 .43666 .38282 .43431 Mtetra
.38282 .43431 .38512 .43666 .38894 .43539 .38664 .43304 Mtetra
.38664 .43304 .38894 .43539 .39276 .43412 .39046 .43177 Mtetra
.39046 .43177 .39276 .43412 .39658 .43285 .39429 .4305 Mtetra
.39429 .4305 .39658 .43285 .40041 .43158 .39812 .42922 Mtetra
.39812 .42922 .40041 .43158 .40424 .4303 .40196 .42795 Mtetra
.928 .736 .623 r
.40196 .42795 .40424 .4303 .4086 .41452 .40633 .41215 Mtetra
.663 .742 .908 r
.40633 .41215 .4086 .41452 .41243 .41323 .41016 .41086 Mtetra
.41016 .41086 .41243 .41323 .41627 .41195 .414 .40957 Mtetra
.414 .40957 .41627 .41195 .42011 .41066 .41784 .40828 Mtetra
.41784 .40828 .42011 .41066 .42395 .40937 .42169 .40699 Mtetra
.42169 .40699 .42395 .40937 .4278 .40809 .42555 .4057 Mtetra
.42555 .4057 .4278 .40809 .43166 .40679 .42941 .4044 Mtetra
.42941 .4044 .43166 .40679 .43552 .4055 .43327 .40311 Mtetra
.43327 .40311 .43552 .4055 .43939 .4042 .43714 .40181 Mtetra
.43714 .40181 .43939 .4042 .44326 .40291 .44102 .40051 Mtetra
.44102 .40051 .44326 .40291 .44714 .40161 .4449 .39921 Mtetra
.4449 .39921 .44714 .40161 .45102 .40031 .44879 .3979 Mtetra
.44879 .3979 .45102 .40031 .45491 .39901 .45268 .3966 Mtetra
.45268 .3966 .45491 .39901 .45881 .3977 .45658 .39529 Mtetra
.45658 .39529 .45881 .3977 .46271 .39639 .46048 .39398 Mtetra
.46048 .39398 .46271 .39639 .46661 .39509 .46439 .39267 Mtetra
.46439 .39267 .46661 .39509 .47052 .39378 .46831 .39135 Mtetra
.46831 .39135 .47052 .39378 .47444 .39246 .47223 .39004 Mtetra
.962 .676 .446 r
.47223 .39004 .47444 .39246 .47677 .50134 .47448 .49898 Mtetra
.655 .752 .922 r
.47448 .49898 .47677 .50134 .48083 .50006 .47855 .49769 Mtetra
.47855 .49769 .48083 .50006 .4849 .49878 .48262 .49641 Mtetra
.48262 .49641 .4849 .49878 .48897 .4975 .4867 .49512 Mtetra
.4867 .49512 .48897 .4975 .49306 .49621 .49078 .49383 Mtetra
.49078 .49383 .49306 .49621 .49714 .49492 .49487 .49254 Mtetra
.49487 .49254 .49714 .49492 .50123 .49364 .49897 .49125 Mtetra
.49897 .49125 .50123 .49364 .50533 .49235 .50307 .48996 Mtetra
.50307 .48996 .50533 .49235 .50944 .49105 .50718 .48866 Mtetra
.50718 .48866 .50944 .49105 .51355 .48976 .5113 .48736 Mtetra
.5113 .48736 .51355 .48976 .51767 .48846 .51542 .48606 Mtetra
.51542 .48606 .51767 .48846 .52179 .48716 .51955 .48476 Mtetra
.51955 .48476 .52179 .48716 .52592 .48586 .52368 .48346 Mtetra
.52368 .48346 .52592 .48586 .53006 .48456 .52782 .48215 Mtetra
.52782 .48215 .53006 .48456 .5342 .48326 .53197 .48085 Mtetra
.53197 .48085 .5342 .48326 .5382 .44589 .53612 .47954 Mtetra
0 0 .255 r
.53612 .47954 .5382 .44589 .54231 .44457 .54011 .44213 Mtetra
.658 .749 .917 r
.54011 .44213 .54231 .44457 .54642 .44325 .54423 .4408 Mtetra
.54423 .4408 .54642 .44325 .55054 .44192 .54835 .43947 Mtetra
.54835 .43947 .55054 .44192 .55467 .4406 .55249 .43814 Mtetra
.55249 .43814 .55467 .4406 .55881 .43927 .55662 .43681 Mtetra
.55662 .43681 .55881 .43927 .56295 .43794 .56077 .43548 Mtetra
.56077 .43548 .56295 .43794 .56709 .43661 .56492 .43414 Mtetra
.56492 .43414 .56709 .43661 .57124 .43527 .56907 .4328 Mtetra
.56907 .4328 .57124 .43527 .5754 .43394 .57324 .43146 Mtetra
.57324 .43146 .5754 .43394 .57957 .4326 .57741 .43012 Mtetra
.57741 .43012 .57957 .4326 .58374 .43126 .58158 .42878 Mtetra
.58158 .42878 .58374 .43126 .58792 .42991 .58576 .42743 Mtetra
.58576 .42743 .58792 .42991 .5921 .42857 .58995 .42608 Mtetra
.962 .632 .324 r
.58995 .42608 .5921 .42857 .59629 .42722 .59492 .46099 Mtetra
.525 .281 .487 r
.59492 .46099 .59629 .42722 .60049 .42587 .59916 .45965 Mtetra
.59916 .45965 .60049 .42587 .60469 .42452 .60342 .45831 Mtetra
.60342 .45831 .60469 .42452 .60984 .45944 .60768 .45697 Mtetra
.655 .752 .922 r
.60768 .45697 .60984 .45944 .6141 .4581 .61195 .45562 Mtetra
.61195 .45562 .6141 .4581 .61505 .34043 .61622 .45427 Mtetra
0 0 .361 r
.61622 .45427 .61505 .34043 .61917 .33905 .6171 .33649 Mtetra
.664 .741 .908 r
.6171 .33649 .61917 .33905 .6233 .33766 .62124 .3351 Mtetra
.62124 .3351 .6233 .33766 .62744 .33627 .62537 .33371 Mtetra
.62537 .33371 .62744 .33627 .63158 .33488 .62952 .33231 Mtetra
.62952 .33231 .63158 .33488 .63572 .33349 .63367 .33092 Mtetra
.63367 .33092 .63572 .33349 .63988 .3321 .63782 .32952 Mtetra
.63782 .32952 .63988 .3321 .64403 .3307 .64199 .32812 Mtetra
.64199 .32812 .64403 .3307 .6482 .3293 .64616 .32671 Mtetra
.64616 .32671 .6482 .3293 .65237 .3279 .65033 .32531 Mtetra
.65033 .32531 .65237 .3279 .65655 .3265 .65451 .3239 Mtetra
.65451 .3239 .65655 .3265 .66073 .32509 .6587 .32249 Mtetra
.6587 .32249 .66073 .32509 .66492 .32369 .66289 .32108 Mtetra
.66289 .32108 .66492 .32369 .66912 .32228 .66709 .31967 Mtetra
.66709 .31967 .66912 .32228 .67332 .32087 .6713 .31826 Mtetra
.6713 .31826 .67332 .32087 .67753 .31945 .67551 .31684 Mtetra
.67551 .31684 .67753 .31945 .68174 .31804 .67973 .31542 Mtetra
.67973 .31542 .68174 .31804 .68596 .31662 .68396 .314 Mtetra
.68396 .314 .68596 .31662 .69019 .3152 .68819 .31257 Mtetra
.68819 .31257 .69019 .3152 .69442 .31378 .69243 .31115 Mtetra
.69243 .31115 .69442 .31378 .69866 .31236 .69667 .30972 Mtetra
.69667 .30972 .69866 .31236 .70291 .31093 .70092 .30829 Mtetra
.938 .573 .183 r
.70092 .30829 .70291 .31093 .7086 .33425 .7066 .33162 Mtetra
.662 .744 .911 r
.7066 .33162 .7086 .33425 .71289 .33282 .7109 .33019 Mtetra
.7109 .33019 .71289 .33282 .71719 .3314 .71521 .32876 Mtetra
.71521 .32876 .71719 .3314 .7215 .32997 .71952 .32733 Mtetra
.71952 .32733 .7215 .32997 .72581 .32854 .72384 .3259 Mtetra
.72384 .3259 .72581 .32854 .73013 .32711 .72816 .32446 Mtetra
.72816 .32446 .73013 .32711 .73446 .32568 .73249 .32302 Mtetra
.73249 .32302 .73446 .32568 .73879 .32424 .73683 .32158 Mtetra
.73683 .32158 .73879 .32424 .74313 .3228 .74117 .32014 Mtetra
.74117 .32014 .74313 .3228 .74748 .32136 .74552 .3187 Mtetra
.74552 .3187 .74748 .32136 .75183 .31992 .74988 .31725 Mtetra
.74988 .31725 .75183 .31992 .75619 .31848 .75424 .3158 Mtetra
.75424 .3158 .75619 .31848 .76056 .31703 .75861 .31435 Mtetra
.75861 .31435 .76056 .31703 .76493 .31558 .76299 .3129 Mtetra
.76299 .3129 .76493 .31558 .76931 .31413 .76738 .31144 Mtetra
.76738 .31144 .76931 .31413 .77369 .31267 .77177 .30999 Mtetra
.97 .651 .306 r
.77177 .30999 .77369 .31267 .78732 .42551 .78534 .42288 Mtetra
.653 .754 .924 r
.78534 .42288 .78732 .42551 .79189 .42409 .78991 .42146 Mtetra
.78991 .42146 .79189 .42409 .79646 .42266 .79449 .42003 Mtetra
.79449 .42003 .79646 .42266 .80104 .42124 .79908 .4186 Mtetra
.79908 .4186 .80104 .42124 .80563 .41981 .80367 .41717 Mtetra
.80367 .41717 .80563 .41981 .81023 .41838 .80828 .41574 Mtetra
.80828 .41574 .81023 .41838 .81483 .41695 .81288 .4143 Mtetra
.81288 .4143 .81483 .41695 .81944 .41552 .8175 .41286 Mtetra
.8175 .41286 .81944 .41552 .82406 .41408 .82212 .41142 Mtetra
.82212 .41142 .82406 .41408 .82869 .41264 .82675 .40998 Mtetra
.82675 .40998 .82869 .41264 .83332 .4112 .83139 .40853 Mtetra
.83139 .40853 .83332 .4112 .83796 .40976 .83604 .40709 Mtetra
.83604 .40709 .83796 .40976 .84261 .40831 .84069 .40564 Mtetra
.84069 .40564 .84261 .40831 .84726 .40686 .84535 .40418 Mtetra
.84535 .40418 .84726 .40686 .85193 .40541 .85002 .40273 Mtetra
.85002 .40273 .85193 .40541 .8566 .40396 .8547 .40127 Mtetra
.8547 .40127 .8566 .40396 .86127 .40251 .85938 .39981 Mtetra
.85938 .39981 .86127 .40251 .86596 .40105 .86407 .39835 Mtetra
.86407 .39835 .86596 .40105 .87065 .39959 .86877 .39689 Mtetra
.648 .76 .931 r
.23206 .64828 .23463 .65039 .23844 .64925 .23587 .64713 Mtetra
.23587 .64713 .23844 .64925 .24225 .6481 .23968 .64598 Mtetra
.23968 .64598 .24225 .6481 .24607 .64695 .24351 .64483 Mtetra
.24351 .64483 .24607 .64695 .24989 .6458 .24733 .64368 Mtetra
.24733 .64368 .24989 .6458 .25372 .64465 .25116 .64252 Mtetra
.25116 .64252 .25372 .64465 .25755 .6435 .255 .64136 Mtetra
.255 .64136 .25755 .6435 .26139 .64234 .25884 .64021 Mtetra
.25884 .64021 .26139 .64234 .26523 .64119 .26269 .63905 Mtetra
.26269 .63905 .26523 .64119 .26909 .64003 .26655 .63788 Mtetra
.26655 .63788 .26909 .64003 .27294 .63887 .27041 .63672 Mtetra
.27041 .63672 .27294 .63887 .2768 .63771 .27427 .63556 Mtetra
.27427 .63556 .2768 .63771 .28067 .63654 .27814 .63439 Mtetra
.27814 .63439 .28067 .63654 .28455 .63538 .28202 .63322 Mtetra
.28202 .63322 .28455 .63538 .28842 .63421 .2859 .63205 Mtetra
.2859 .63205 .28842 .63421 .29231 .63304 .28979 .63088 Mtetra
.28979 .63088 .29231 .63304 .2962 .63187 .29368 .6297 Mtetra
.29368 .6297 .2962 .63187 .3001 .6307 .29758 .62853 Mtetra
.29758 .62853 .3001 .6307 .304 .62952 .30149 .62735 Mtetra
.30149 .62735 .304 .62952 .30791 .62835 .3054 .62617 Mtetra
.943 .692 .527 r
.3054 .62617 .30791 .62835 .31182 .62717 .32013 .4521 Mtetra
.55 .336 .543 r
.32013 .4521 .31182 .62717 .32622 .45315 .32386 .45086 Mtetra
.662 .743 .91 r
.32386 .45086 .32622 .45315 .32996 .45191 .3276 .44961 Mtetra
.3276 .44961 .32996 .45191 .3337 .45067 .33135 .44836 Mtetra
.33135 .44836 .3337 .45067 .33745 .44942 .3351 .44711 Mtetra
.3351 .44711 .33745 .44942 .3412 .44817 .33885 .44586 Mtetra
.33885 .44586 .3412 .44817 .34496 .44692 .34261 .44461 Mtetra
.34261 .44461 .34496 .44692 .34872 .44567 .34638 .44335 Mtetra
.34638 .44335 .34872 .44567 .35249 .44441 .35015 .44209 Mtetra
.35015 .44209 .35249 .44441 .35626 .44316 .35393 .44083 Mtetra
.35393 .44083 .35626 .44316 .36004 .4419 .35771 .43957 Mtetra
.35771 .43957 .36004 .4419 .36382 .44064 .36149 .43831 Mtetra
.36149 .43831 .36382 .44064 .36761 .43938 .36529 .43704 Mtetra
.36529 .43704 .36761 .43938 .3714 .43811 .36908 .43578 Mtetra
.36908 .43578 .3714 .43811 .3752 .43685 .37289 .43451 Mtetra
.37289 .43451 .3752 .43685 .37901 .43558 .3767 .43324 Mtetra
.3767 .43324 .37901 .43558 .38282 .43431 .38051 .43197 Mtetra
.38051 .43197 .38282 .43431 .38664 .43304 .38433 .43069 Mtetra
.38433 .43069 .38664 .43304 .39046 .43177 .38815 .42942 Mtetra
.38815 .42942 .39046 .43177 .39429 .4305 .39199 .42814 Mtetra
.39199 .42814 .39429 .4305 .39812 .42922 .39582 .42686 Mtetra
.39582 .42686 .39812 .42922 .40196 .42795 .39966 .42558 Mtetra
.928 .736 .623 r
.39966 .42558 .40196 .42795 .40633 .41215 .40405 .40977 Mtetra
.663 .742 .908 r
.40405 .40977 .40633 .41215 .41016 .41086 .40789 .40848 Mtetra
.40789 .40848 .41016 .41086 .414 .40957 .41173 .40719 Mtetra
.41173 .40719 .414 .40957 .41784 .40828 .41558 .4059 Mtetra
.41558 .4059 .41784 .40828 .42169 .40699 .41943 .4046 Mtetra
.41943 .4046 .42169 .40699 .42555 .4057 .42329 .40331 Mtetra
.42329 .40331 .42555 .4057 .42941 .4044 .42715 .40201 Mtetra
.42715 .40201 .42941 .4044 .43327 .40311 .43102 .40071 Mtetra
.43102 .40071 .43327 .40311 .43714 .40181 .43489 .39941 Mtetra
.43489 .39941 .43714 .40181 .44102 .40051 .43877 .3981 Mtetra
.43877 .3981 .44102 .40051 .4449 .39921 .44266 .3968 Mtetra
.44266 .3968 .4449 .39921 .44879 .3979 .44655 .39549 Mtetra
.44655 .39549 .44879 .3979 .45268 .3966 .45044 .39418 Mtetra
.45044 .39418 .45268 .3966 .45658 .39529 .45435 .39287 Mtetra
.45435 .39287 .45658 .39529 .46048 .39398 .45825 .39155 Mtetra
.45825 .39155 .46048 .39398 .46439 .39267 .46217 .39024 Mtetra
.46217 .39024 .46439 .39267 .46831 .39135 .46609 .38892 Mtetra
.46609 .38892 .46831 .39135 .47223 .39004 .47001 .3876 Mtetra
.962 .676 .446 r
.47001 .3876 .47223 .39004 .47448 .49898 .47219 .49661 Mtetra
.655 .752 .922 r
.47219 .49661 .47448 .49898 .47855 .49769 .47626 .49532 Mtetra
.47626 .49532 .47855 .49769 .48262 .49641 .48033 .49403 Mtetra
.48033 .49403 .48262 .49641 .4867 .49512 .48442 .49274 Mtetra
.48442 .49274 .4867 .49512 .49078 .49383 .48851 .49145 Mtetra
.48851 .49145 .49078 .49383 .49487 .49254 .4926 .49016 Mtetra
.4926 .49016 .49487 .49254 .49897 .49125 .4967 .48886 Mtetra
.4967 .48886 .49897 .49125 .50307 .48996 .50081 .48756 Mtetra
.50081 .48756 .50307 .48996 .50718 .48866 .50492 .48626 Mtetra
.50492 .48626 .50718 .48866 .5113 .48736 .50904 .48496 Mtetra
.50904 .48496 .5113 .48736 .51542 .48606 .51316 .48366 Mtetra
.51316 .48366 .51542 .48606 .51955 .48476 .5173 .48235 Mtetra
.5173 .48235 .51955 .48476 .52368 .48346 .52143 .48105 Mtetra
.52143 .48105 .52368 .48346 .52782 .48215 .52558 .47974 Mtetra
.52558 .47974 .52782 .48215 .53197 .48085 .52973 .47843 Mtetra
.52973 .47843 .53197 .48085 .53612 .47954 .53388 .47711 Mtetra
.961 .72 .528 r
.53388 .47711 .53612 .47954 .54011 .44213 .5379 .43968 Mtetra
.658 .749 .917 r
.5379 .43968 .54011 .44213 .54423 .4408 .54203 .43835 Mtetra
.54203 .43835 .54423 .4408 .54835 .43947 .54616 .43702 Mtetra
.54616 .43702 .54835 .43947 .55249 .43814 .55029 .43568 Mtetra
.55029 .43568 .55249 .43814 .55662 .43681 .55443 .43435 Mtetra
.55443 .43435 .55662 .43681 .56077 .43548 .55858 .43301 Mtetra
.55858 .43301 .56077 .43548 .56492 .43414 .56274 .43167 Mtetra
.56274 .43167 .56492 .43414 .56907 .4328 .5669 .43033 Mtetra
.5669 .43033 .56907 .4328 .57324 .43146 .57106 .42898 Mtetra
.962 .635 .333 r
.57106 .42898 .57324 .43146 .57741 .43012 .5758 .46387 Mtetra
.525 .28 .486 r
.5758 .46387 .57741 .43012 .58158 .42878 .58002 .46253 Mtetra
.58002 .46253 .58158 .42878 .58576 .42743 .58426 .4612 Mtetra
.58426 .4612 .58576 .42743 .58995 .42608 .5885 .45986 Mtetra
.5885 .45986 .58995 .42608 .59492 .46099 .59274 .45852 Mtetra
.655 .752 .922 r
.59274 .45852 .59492 .46099 .59916 .45965 .59699 .45717 Mtetra
.59699 .45717 .59916 .45965 .60342 .45831 .60125 .45583 Mtetra
.60125 .45583 .60342 .45831 .60768 .45697 .60552 .45448 Mtetra
.60552 .45448 .60768 .45697 .61195 .45562 .60979 .45313 Mtetra
.60979 .45313 .61195 .45562 .61622 .45427 .61407 .45178 Mtetra
.972 .698 .451 r
.61407 .45178 .61622 .45427 .6171 .33649 .61503 .33392 Mtetra
.664 .741 .908 r
.61503 .33392 .6171 .33649 .62124 .3351 .61916 .33253 Mtetra
.61916 .33253 .62124 .3351 .62537 .33371 .62331 .33113 Mtetra
.62331 .33113 .62537 .33371 .62952 .33231 .62745 .32973 Mtetra
.62745 .32973 .62952 .33231 .63367 .33092 .63161 .32833 Mtetra
.63161 .32833 .63367 .33092 .63782 .32952 .63577 .32693 Mtetra
.63577 .32693 .63782 .32952 .64199 .32812 .63994 .32553 Mtetra
.63994 .32553 .64199 .32812 .64616 .32671 .64411 .32412 Mtetra
.64411 .32412 .64616 .32671 .65033 .32531 .64829 .32271 Mtetra
.64829 .32271 .65033 .32531 .65451 .3239 .65247 .3213 Mtetra
.65247 .3213 .65451 .3239 .6587 .32249 .65667 .31989 Mtetra
.65667 .31989 .6587 .32249 .66289 .32108 .66086 .31847 Mtetra
.66086 .31847 .66289 .32108 .66709 .31967 .66507 .31706 Mtetra
.66507 .31706 .66709 .31967 .6713 .31826 .66928 .31564 Mtetra
.66928 .31564 .6713 .31826 .67551 .31684 .6735 .31422 Mtetra
.6735 .31422 .67551 .31684 .67973 .31542 .67772 .31279 Mtetra
.67772 .31279 .67973 .31542 .68396 .314 .68195 .31137 Mtetra
.68195 .31137 .68396 .314 .68819 .31257 .68618 .30994 Mtetra
.68618 .30994 .68819 .31257 .69243 .31115 .69043 .30851 Mtetra
.69043 .30851 .69243 .31115 .69667 .30972 .69467 .30708 Mtetra
.938 .574 .187 r
.69467 .30708 .69667 .30972 .70092 .30829 .70031 .33041 Mtetra
.512 .255 .462 r
.70031 .33041 .70092 .30829 .7066 .33162 .7046 .32898 Mtetra
.662 .744 .911 r
.7046 .32898 .7066 .33162 .7109 .33019 .70891 .32755 Mtetra
.70891 .32755 .7109 .33019 .71521 .32876 .71321 .32612 Mtetra
.71321 .32612 .71521 .32876 .71952 .32733 .71753 .32468 Mtetra
.71753 .32468 .71952 .32733 .72384 .3259 .72185 .32324 Mtetra
.72185 .32324 .72384 .3259 .72816 .32446 .72618 .32181 Mtetra
.72618 .32181 .72816 .32446 .73249 .32302 .73052 .32036 Mtetra
.73052 .32036 .73249 .32302 .73683 .32158 .73486 .31892 Mtetra
.73486 .31892 .73683 .32158 .74117 .32014 .73921 .31747 Mtetra
.73921 .31747 .74117 .32014 .74552 .3187 .74356 .31603 Mtetra
.74356 .31603 .74552 .3187 .74988 .31725 .74792 .31457 Mtetra
.74792 .31457 .74988 .31725 .75424 .3158 .75229 .31312 Mtetra
.75229 .31312 .75424 .3158 .75861 .31435 .75667 .31167 Mtetra
.75667 .31167 .75861 .31435 .76299 .3129 .76105 .31021 Mtetra
.76105 .31021 .76299 .3129 .76738 .31144 .76544 .30875 Mtetra
.76544 .30875 .76738 .31144 .77177 .30999 .76983 .30729 Mtetra
.76983 .30729 .77177 .30999 .78534 .42288 .77424 .30582 Mtetra
.075 .003 .462 r
.77424 .30582 .78534 .42288 .78991 .42146 .78793 .41882 Mtetra
.653 .754 .924 r
.78793 .41882 .78991 .42146 .79449 .42003 .79252 .41739 Mtetra
.79252 .41739 .79449 .42003 .79908 .4186 .79711 .41596 Mtetra
.79711 .41596 .79908 .4186 .80367 .41717 .80171 .41452 Mtetra
.80171 .41452 .80367 .41717 .80828 .41574 .80632 .41308 Mtetra
.80632 .41308 .80828 .41574 .81288 .4143 .81093 .41164 Mtetra
.81093 .41164 .81288 .4143 .8175 .41286 .81555 .4102 Mtetra
.81555 .4102 .8175 .41286 .82212 .41142 .82018 .40876 Mtetra
.82018 .40876 .82212 .41142 .82675 .40998 .82482 .40731 Mtetra
.82482 .40731 .82675 .40998 .83139 .40853 .82946 .40586 Mtetra
.82946 .40586 .83139 .40853 .83604 .40709 .83411 .40441 Mtetra
.83411 .40441 .83604 .40709 .84069 .40564 .83877 .40295 Mtetra
.83877 .40295 .84069 .40564 .84535 .40418 .84344 .4015 Mtetra
.84344 .4015 .84535 .40418 .85002 .40273 .84811 .40004 Mtetra
.84811 .40004 .85002 .40273 .8547 .40127 .85279 .39858 Mtetra
.85279 .39858 .8547 .40127 .85938 .39981 .85748 .39711 Mtetra
.85748 .39711 .85938 .39981 .86407 .39835 .86218 .39565 Mtetra
.86218 .39565 .86407 .39835 .86877 .39689 .86688 .39418 Mtetra
.648 .76 .931 r
.22948 .64616 .23206 .64828 .23587 .64713 .2333 .64501 Mtetra
.2333 .64501 .23587 .64713 .23968 .64598 .23712 .64385 Mtetra
.23712 .64385 .23968 .64598 .24351 .64483 .24094 .6427 Mtetra
.24094 .6427 .24351 .64483 .24733 .64368 .24477 .64154 Mtetra
.24477 .64154 .24733 .64368 .25116 .64252 .2486 .64038 Mtetra
.2486 .64038 .25116 .64252 .255 .64136 .25244 .63922 Mtetra
.25244 .63922 .255 .64136 .25884 .64021 .25629 .63806 Mtetra
.25629 .63806 .25884 .64021 .26269 .63905 .26014 .6369 Mtetra
.26014 .6369 .26269 .63905 .26655 .63788 .264 .63574 Mtetra
.264 .63574 .26655 .63788 .27041 .63672 .26786 .63457 Mtetra
.26786 .63457 .27041 .63672 .27427 .63556 .27173 .6334 Mtetra
.27173 .6334 .27427 .63556 .27814 .63439 .27561 .63223 Mtetra
.27561 .63223 .27814 .63439 .28202 .63322 .27949 .63106 Mtetra
.27949 .63106 .28202 .63322 .2859 .63205 .28337 .62989 Mtetra
.28337 .62989 .2859 .63205 .28979 .63088 .28726 .62871 Mtetra
.28726 .62871 .28979 .63088 .29368 .6297 .29116 .62753 Mtetra
.29116 .62753 .29368 .6297 .29758 .62853 .29507 .62635 Mtetra
.29507 .62635 .29758 .62853 .30149 .62735 .29897 .62517 Mtetra
.29897 .62517 .30149 .62735 .3054 .62617 .30289 .62399 Mtetra
.943 .692 .527 r
.30289 .62399 .3054 .62617 .32013 .4521 .31776 .4498 Mtetra
.662 .743 .91 r
.31776 .4498 .32013 .4521 .32386 .45086 .3215 .44855 Mtetra
.3215 .44855 .32386 .45086 .3276 .44961 .32524 .4473 Mtetra
.32524 .4473 .3276 .44961 .33135 .44836 .32899 .44605 Mtetra
.32899 .44605 .33135 .44836 .3351 .44711 .33274 .4448 Mtetra
.33274 .4448 .3351 .44711 .33885 .44586 .3365 .44354 Mtetra
.3365 .44354 .33885 .44586 .34261 .44461 .34026 .44229 Mtetra
.34026 .44229 .34261 .44461 .34638 .44335 .34403 .44103 Mtetra
.34403 .44103 .34638 .44335 .35015 .44209 .34781 .43977 Mtetra
.34781 .43977 .35015 .44209 .35393 .44083 .35159 .4385 Mtetra
.35159 .4385 .35393 .44083 .35771 .43957 .35537 .43724 Mtetra
.35537 .43724 .35771 .43957 .36149 .43831 .35916 .43597 Mtetra
.35916 .43597 .36149 .43831 .36529 .43704 .36296 .43471 Mtetra
.36296 .43471 .36529 .43704 .36908 .43578 .36676 .43344 Mtetra
.36676 .43344 .36908 .43578 .37289 .43451 .37056 .43216 Mtetra
.37056 .43216 .37289 .43451 .3767 .43324 .37438 .43089 Mtetra
.37438 .43089 .3767 .43324 .38051 .43197 .37819 .42962 Mtetra
.37819 .42962 .38051 .43197 .38433 .43069 .38202 .42834 Mtetra
.38202 .42834 .38433 .43069 .38815 .42942 .38585 .42706 Mtetra
.38585 .42706 .38815 .42942 .39199 .42814 .38968 .42578 Mtetra
.38968 .42578 .39199 .42814 .39582 .42686 .39352 .4245 Mtetra
.39352 .4245 .39582 .42686 .39966 .42558 .39736 .42321 Mtetra
.928 .736 .623 r
.39736 .42321 .39966 .42558 .40405 .40977 .40177 .40739 Mtetra
.663 .742 .908 r
.40177 .40739 .40405 .40977 .40789 .40848 .40561 .4061 Mtetra
.40561 .4061 .40789 .40848 .41173 .40719 .40945 .4048 Mtetra
.40945 .4048 .41173 .40719 .41558 .4059 .4133 .40351 Mtetra
.4133 .40351 .41558 .4059 .41943 .4046 .41716 .40221 Mtetra
.41716 .40221 .41943 .4046 .42329 .40331 .42102 .40091 Mtetra
.42102 .40091 .42329 .40331 .42715 .40201 .42488 .39961 Mtetra
.42488 .39961 .42715 .40201 .43102 .40071 .42876 .3983 Mtetra
.42876 .3983 .43102 .40071 .43489 .39941 .43263 .397 Mtetra
.43263 .397 .43489 .39941 .43877 .3981 .43652 .39569 Mtetra
.43652 .39569 .43877 .3981 .44266 .3968 .44041 .39438 Mtetra
.44041 .39438 .44266 .3968 .44655 .39549 .4443 .39307 Mtetra
.4443 .39307 .44655 .39549 .45044 .39418 .4482 .39176 Mtetra
.4482 .39176 .45044 .39418 .45435 .39287 .45211 .39044 Mtetra
.45211 .39044 .45435 .39287 .45825 .39155 .45602 .38912 Mtetra
.45602 .38912 .45825 .39155 .46217 .39024 .45993 .38781 Mtetra
.45993 .38781 .46217 .39024 .46609 .38892 .46386 .38648 Mtetra
.46386 .38648 .46609 .38892 .47001 .3876 .46779 .38516 Mtetra
.962 .676 .446 r
.46779 .38516 .47001 .3876 .47219 .49661 .46989 .49423 Mtetra
.655 .752 .922 r
.46989 .49423 .47219 .49661 .47626 .49532 .47396 .49294 Mtetra
.47396 .49294 .47626 .49532 .48033 .49403 .47804 .49165 Mtetra
.47804 .49165 .48033 .49403 .48442 .49274 .48213 .49036 Mtetra
.48213 .49036 .48442 .49274 .48851 .49145 .48622 .48906 Mtetra
.48622 .48906 .48851 .49145 .4926 .49016 .49032 .48776 Mtetra
.49032 .48776 .4926 .49016 .4967 .48886 .49442 .48646 Mtetra
.49442 .48646 .4967 .48886 .50081 .48756 .49853 .48516 Mtetra
.49853 .48516 .50081 .48756 .50492 .48626 .50265 .48386 Mtetra
.50265 .48386 .50492 .48626 .50904 .48496 .50677 .48256 Mtetra
.50677 .48256 .50904 .48496 .51316 .48366 .5109 .48125 Mtetra
.5109 .48125 .51316 .48366 .5173 .48235 .51504 .47994 Mtetra
.51504 .47994 .5173 .48235 .52143 .48105 .51918 .47863 Mtetra
.51918 .47863 .52143 .48105 .52558 .47974 .52333 .47732 Mtetra
.52333 .47732 .52558 .47974 .52973 .47843 .52748 .476 Mtetra
.52748 .476 .52973 .47843 .53388 .47711 .53164 .47468 Mtetra
.53164 .47468 .53388 .47711 .5379 .43968 .53581 .47336 Mtetra
0 0 .252 r
.53581 .47336 .5379 .43968 .54203 .43835 .53982 .43589 Mtetra
.658 .749 .917 r
.53982 .43589 .54203 .43835 .54616 .43702 .54395 .43455 Mtetra
.54395 .43455 .54616 .43702 .55029 .43568 .54809 .43322 Mtetra
.54809 .43322 .55029 .43568 .55443 .43435 .55224 .43188 Mtetra
.962 .637 .342 r
.55224 .43188 .55443 .43435 .55858 .43301 .55674 .46674 Mtetra
.524 .279 .485 r
.55674 .46674 .55858 .43301 .56274 .43167 .56095 .46541 Mtetra
.56095 .46541 .56274 .43167 .5669 .43033 .56516 .46408 Mtetra
.56516 .46408 .5669 .43033 .57106 .42898 .56938 .46274 Mtetra
.56938 .46274 .57106 .42898 .5758 .46387 .5736 .4614 Mtetra
.655 .752 .922 r
.5736 .4614 .5758 .46387 .58002 .46253 .57783 .46006 Mtetra
.57783 .46006 .58002 .46253 .58426 .4612 .58207 .45872 Mtetra
.58207 .45872 .58426 .4612 .5885 .45986 .58631 .45738 Mtetra
.58631 .45738 .5885 .45986 .59274 .45852 .59056 .45603 Mtetra
.59056 .45603 .59274 .45852 .59699 .45717 .59482 .45469 Mtetra
.59482 .45469 .59699 .45717 .60125 .45583 .59908 .45334 Mtetra
.59908 .45334 .60125 .45583 .60552 .45448 .60335 .45199 Mtetra
.60335 .45199 .60552 .45448 .60979 .45313 .60763 .45063 Mtetra
.60763 .45063 .60979 .45313 .61407 .45178 .61191 .44928 Mtetra
.972 .698 .451 r
.61191 .44928 .61407 .45178 .61503 .33392 .61294 .33135 Mtetra
.664 .741 .908 r
.61294 .33135 .61503 .33392 .61916 .33253 .61708 .32995 Mtetra
.61708 .32995 .61916 .33253 .62331 .33113 .62123 .32855 Mtetra
.62123 .32855 .62331 .33113 .62745 .32973 .62538 .32715 Mtetra
.62538 .32715 .62745 .32973 .63161 .32833 .62954 .32574 Mtetra
.62954 .32574 .63161 .32833 .63577 .32693 .63371 .32434 Mtetra
.63371 .32434 .63577 .32693 .63994 .32553 .63788 .32293 Mtetra
.63788 .32293 .63994 .32553 .64411 .32412 .64206 .32152 Mtetra
.64206 .32152 .64411 .32412 .64829 .32271 .64624 .32011 Mtetra
.64624 .32011 .64829 .32271 .65247 .3213 .65043 .31869 Mtetra
.65043 .31869 .65247 .3213 .65667 .31989 .65462 .31728 Mtetra
.65462 .31728 .65667 .31989 .66086 .31847 .65883 .31586 Mtetra
.65883 .31586 .66086 .31847 .66507 .31706 .66304 .31444 Mtetra
.66304 .31444 .66507 .31706 .66928 .31564 .66725 .31301 Mtetra
.66725 .31301 .66928 .31564 .6735 .31422 .67147 .31159 Mtetra
.67147 .31159 .6735 .31422 .67772 .31279 .6757 .31016 Mtetra
.6757 .31016 .67772 .31279 .68195 .31137 .67993 .30873 Mtetra
.67993 .30873 .68195 .31137 .68618 .30994 .68417 .3073 Mtetra
.68417 .3073 .68618 .30994 .69043 .30851 .68842 .30587 Mtetra
.68842 .30587 .69043 .30851 .69467 .30708 .69267 .30443 Mtetra
.938 .574 .187 r
.69267 .30443 .69467 .30708 .70031 .33041 .6983 .32777 Mtetra
.662 .744 .911 r
.6983 .32777 .70031 .33041 .7046 .32898 .7026 .32634 Mtetra
.7026 .32634 .7046 .32898 .70891 .32755 .7069 .3249 Mtetra
.7069 .3249 .70891 .32755 .71321 .32612 .71122 .32347 Mtetra
.71122 .32347 .71321 .32612 .71753 .32468 .71554 .32203 Mtetra
.71554 .32203 .71753 .32468 .72185 .32324 .71986 .32059 Mtetra
.71986 .32059 .72185 .32324 .72618 .32181 .7242 .31914 Mtetra
.7242 .31914 .72618 .32181 .73052 .32036 .72854 .3177 Mtetra
.72854 .3177 .73052 .32036 .73486 .31892 .73288 .31625 Mtetra
.73288 .31625 .73486 .31892 .73921 .31747 .73724 .3148 Mtetra
.73724 .3148 .73921 .31747 .74356 .31603 .7416 .31335 Mtetra
.7416 .31335 .74356 .31603 .74792 .31457 .74596 .31189 Mtetra
.74596 .31189 .74792 .31457 .75229 .31312 .75034 .31043 Mtetra
.75034 .31043 .75229 .31312 .75667 .31167 .75472 .30898 Mtetra
.75472 .30898 .75667 .31167 .76105 .31021 .7591 .30751 Mtetra
.7591 .30751 .76105 .31021 .76544 .30875 .7635 .30605 Mtetra
.7635 .30605 .76544 .30875 .76983 .30729 .7679 .30458 Mtetra
.7679 .30458 .76983 .30729 .77424 .30582 .7723 .30312 Mtetra
.969 .649 .301 r
.7723 .30312 .77424 .30582 .78793 .41882 .78551 .41079 Mtetra
.344 .344 .715 r
.78551 .41079 .78793 .41882 .79252 .41739 .79054 .41474 Mtetra
.653 .754 .924 r
.79054 .41474 .79252 .41739 .79711 .41596 .79514 .4133 Mtetra
.79514 .4133 .79711 .41596 .80171 .41452 .79974 .41187 Mtetra
.79974 .41187 .80171 .41452 .80632 .41308 .80435 .41042 Mtetra
.80435 .41042 .80632 .41308 .81093 .41164 .80897 .40898 Mtetra
.80897 .40898 .81093 .41164 .81555 .4102 .8136 .40753 Mtetra
.8136 .40753 .81555 .4102 .82018 .40876 .81823 .40608 Mtetra
.81823 .40608 .82018 .40876 .82482 .40731 .82287 .40463 Mtetra
.82287 .40463 .82482 .40731 .82946 .40586 .82752 .40318 Mtetra
.82752 .40318 .82946 .40586 .83411 .40441 .83218 .40172 Mtetra
.83218 .40172 .83411 .40441 .83877 .40295 .83684 .40026 Mtetra
.83684 .40026 .83877 .40295 .84344 .4015 .84151 .3988 Mtetra
.84151 .3988 .84344 .4015 .84811 .40004 .84619 .39734 Mtetra
.84619 .39734 .84811 .40004 .85279 .39858 .85088 .39587 Mtetra
.85088 .39587 .85279 .39858 .85748 .39711 .85557 .3944 Mtetra
.85557 .3944 .85748 .39711 .86218 .39565 .86028 .39293 Mtetra
.86028 .39293 .86218 .39565 .86688 .39418 .86498 .39146 Mtetra
.648 .76 .931 r
.2269 .64403 .22948 .64616 .2333 .64501 .23072 .64288 Mtetra
.23072 .64288 .2333 .64501 .23712 .64385 .23454 .64172 Mtetra
.23454 .64172 .23712 .64385 .24094 .6427 .23837 .64056 Mtetra
.23837 .64056 .24094 .6427 .24477 .64154 .2422 .6394 Mtetra
.2422 .6394 .24477 .64154 .2486 .64038 .24604 .63824 Mtetra
.24604 .63824 .2486 .64038 .25244 .63922 .24988 .63708 Mtetra
.24988 .63708 .25244 .63922 .25629 .63806 .25373 .63591 Mtetra
.25373 .63591 .25629 .63806 .26014 .6369 .25758 .63475 Mtetra
.25758 .63475 .26014 .6369 .264 .63574 .26145 .63358 Mtetra
.26145 .63358 .264 .63574 .26786 .63457 .26531 .63241 Mtetra
.26531 .63241 .26786 .63457 .27173 .6334 .26918 .63124 Mtetra
.26918 .63124 .27173 .6334 .27561 .63223 .27306 .63007 Mtetra
.27306 .63007 .27561 .63223 .27949 .63106 .27695 .62889 Mtetra
.27695 .62889 .27949 .63106 .28337 .62989 .28084 .62771 Mtetra
.28084 .62771 .28337 .62989 .28726 .62871 .28473 .62654 Mtetra
.28473 .62654 .28726 .62871 .29116 .62753 .28863 .62536 Mtetra
.28863 .62536 .29116 .62753 .29507 .62635 .29254 .62417 Mtetra
.29254 .62417 .29507 .62635 .29897 .62517 .29645 .62299 Mtetra
.29645 .62299 .29897 .62517 .30289 .62399 .30037 .6218 Mtetra
.943 .692 .527 r
.30037 .6218 .30289 .62399 .31776 .4498 .31539 .4475 Mtetra
.662 .743 .91 r
.31539 .4475 .31776 .4498 .3215 .44855 .31913 .44624 Mtetra
.31913 .44624 .3215 .44855 .32524 .4473 .32287 .44499 Mtetra
.32287 .44499 .32524 .4473 .32899 .44605 .32662 .44374 Mtetra
.32662 .44374 .32899 .44605 .33274 .4448 .33038 .44248 Mtetra
.33038 .44248 .33274 .4448 .3365 .44354 .33414 .44122 Mtetra
.33414 .44122 .3365 .44354 .34026 .44229 .33791 .43996 Mtetra
.33791 .43996 .34026 .44229 .34403 .44103 .34168 .4387 Mtetra
.34168 .4387 .34403 .44103 .34781 .43977 .34546 .43743 Mtetra
.34546 .43743 .34781 .43977 .35159 .4385 .34924 .43617 Mtetra
.34924 .43617 .35159 .4385 .35537 .43724 .35303 .4349 Mtetra
.35303 .4349 .35537 .43724 .35916 .43597 .35682 .43363 Mtetra
.35682 .43363 .35916 .43597 .36296 .43471 .36062 .43236 Mtetra
.36062 .43236 .36296 .43471 .36676 .43344 .36443 .43109 Mtetra
.36443 .43109 .36676 .43344 .37056 .43216 .36824 .42981 Mtetra
.36824 .42981 .37056 .43216 .37438 .43089 .37205 .42854 Mtetra
.37205 .42854 .37438 .43089 .37819 .42962 .37587 .42726 Mtetra
.37587 .42726 .37819 .42962 .38202 .42834 .3797 .42598 Mtetra
.3797 .42598 .38202 .42834 .38585 .42706 .38353 .42469 Mtetra
.38353 .42469 .38585 .42706 .38968 .42578 .38737 .42341 Mtetra
.38737 .42341 .38968 .42578 .39352 .4245 .39121 .42212 Mtetra
.39121 .42212 .39352 .4245 .39736 .42321 .39506 .42084 Mtetra
.935 .727 .597 r
.39506 .42084 .39736 .42321 .40177 .40739 .39966 .40018 Mtetra
.283 .302 .704 r
.39966 .40018 .40177 .40739 .40561 .4061 .40332 .40371 Mtetra
.663 .742 .908 r
.40332 .40371 .40561 .4061 .40945 .4048 .40717 .40241 Mtetra
.40717 .40241 .40945 .4048 .4133 .40351 .41102 .40111 Mtetra
.41102 .40111 .4133 .40351 .41716 .40221 .41488 .39981 Mtetra
.41488 .39981 .41716 .40221 .42102 .40091 .41874 .3985 Mtetra
.41874 .3985 .42102 .40091 .42488 .39961 .42261 .3972 Mtetra
.42261 .3972 .42488 .39961 .42876 .3983 .42649 .39589 Mtetra
.42649 .39589 .42876 .3983 .43263 .397 .43037 .39458 Mtetra
.43037 .39458 .43263 .397 .43652 .39569 .43426 .39327 Mtetra
.43426 .39327 .43652 .39569 .44041 .39438 .43815 .39196 Mtetra
.43815 .39196 .44041 .39438 .4443 .39307 .44205 .39064 Mtetra
.44205 .39064 .4443 .39307 .4482 .39176 .44595 .38933 Mtetra
.44595 .38933 .4482 .39176 .45211 .39044 .44986 .38801 Mtetra
.44986 .38801 .45211 .39044 .45602 .38912 .45378 .38669 Mtetra
.45378 .38669 .45602 .38912 .45993 .38781 .4577 .38537 Mtetra
.4577 .38537 .45993 .38781 .46386 .38648 .46162 .38404 Mtetra
.46162 .38404 .46386 .38648 .46779 .38516 .46555 .38272 Mtetra
.46555 .38272 .46779 .38516 .46989 .49423 .46949 .38139 Mtetra
0 0 .354 r
.46949 .38139 .46989 .49423 .47396 .49294 .47166 .49056 Mtetra
.655 .752 .922 r
.47166 .49056 .47396 .49294 .47804 .49165 .47574 .48926 Mtetra
.47574 .48926 .47804 .49165 .48213 .49036 .47983 .48796 Mtetra
.47983 .48796 .48213 .49036 .48622 .48906 .48393 .48666 Mtetra
.48393 .48666 .48622 .48906 .49032 .48776 .48803 .48536 Mtetra
.48803 .48536 .49032 .48776 .49442 .48646 .49214 .48406 Mtetra
.49214 .48406 .49442 .48646 .49853 .48516 .49626 .48276 Mtetra
.49626 .48276 .49853 .48516 .50265 .48386 .50038 .48145 Mtetra
.50038 .48145 .50265 .48386 .50677 .48256 .5045 .48014 Mtetra
.5045 .48014 .50677 .48256 .5109 .48125 .50864 .47883 Mtetra
.50864 .47883 .5109 .48125 .51504 .47994 .51278 .47752 Mtetra
.51278 .47752 .51504 .47994 .51918 .47863 .51692 .4762 Mtetra
.51692 .4762 .51918 .47863 .52333 .47732 .52108 .47489 Mtetra
.52108 .47489 .52333 .47732 .52748 .476 .52523 .47357 Mtetra
.52523 .47357 .52748 .476 .53164 .47468 .5294 .47225 Mtetra
.5294 .47225 .53164 .47468 .53581 .47336 .53357 .47092 Mtetra
.961 .72 .527 r
.53357 .47092 .53581 .47336 .53982 .43589 .53761 .43342 Mtetra
.962 .638 .348 r
.53761 .43342 .53982 .43589 .54395 .43455 .54193 .46827 Mtetra
.523 .278 .485 r
.54193 .46827 .54395 .43455 .54809 .43322 .54612 .46694 Mtetra
.54612 .46694 .54809 .43322 .55224 .43188 .55032 .46561 Mtetra
.55032 .46561 .55224 .43188 .55674 .46674 .55452 .46428 Mtetra
.655 .752 .922 r
.55452 .46428 .55674 .46674 .56095 .46541 .55873 .46295 Mtetra
.55873 .46295 .56095 .46541 .56516 .46408 .56294 .46161 Mtetra
.56294 .46161 .56516 .46408 .56938 .46274 .56717 .46027 Mtetra
.56717 .46027 .56938 .46274 .5736 .4614 .5714 .45893 Mtetra
.5714 .45893 .5736 .4614 .57783 .46006 .57563 .45759 Mtetra
.57563 .45759 .57783 .46006 .58207 .45872 .57987 .45624 Mtetra
.57987 .45624 .58207 .45872 .58631 .45738 .58412 .45489 Mtetra
.58412 .45489 .58631 .45738 .59056 .45603 .58837 .45354 Mtetra
.58837 .45354 .59056 .45603 .59482 .45469 .59263 .45219 Mtetra
.59263 .45219 .59482 .45469 .59908 .45334 .5969 .45084 Mtetra
.5969 .45084 .59908 .45334 .60335 .45199 .60118 .44949 Mtetra
.60118 .44949 .60335 .45199 .60763 .45063 .60546 .44813 Mtetra
.60546 .44813 .60763 .45063 .61191 .44928 .60974 .44677 Mtetra
.972 .698 .451 r
.60974 .44677 .61191 .44928 .61294 .33135 .61086 .32876 Mtetra
.664 .741 .908 r
.61086 .32876 .61294 .33135 .61708 .32995 .615 .32736 Mtetra
.615 .32736 .61708 .32995 .62123 .32855 .61915 .32596 Mtetra
.61915 .32596 .62123 .32855 .62538 .32715 .62331 .32455 Mtetra
.62331 .32455 .62538 .32715 .62954 .32574 .62747 .32315 Mtetra
.62747 .32315 .62954 .32574 .63371 .32434 .63164 .32174 Mtetra
.63164 .32174 .63371 .32434 .63788 .32293 .63581 .32032 Mtetra
.63581 .32032 .63788 .32293 .64206 .32152 .64 .31891 Mtetra
.64 .31891 .64206 .32152 .64624 .32011 .64418 .31749 Mtetra
.64418 .31749 .64624 .32011 .65043 .31869 .64838 .31607 Mtetra
.64838 .31607 .65043 .31869 .65462 .31728 .65258 .31465 Mtetra
.65258 .31465 .65462 .31728 .65883 .31586 .65679 .31323 Mtetra
.65679 .31323 .65883 .31586 .66304 .31444 .661 .31181 Mtetra
.661 .31181 .66304 .31444 .66725 .31301 .66522 .31038 Mtetra
.66522 .31038 .66725 .31301 .67147 .31159 .66944 .30895 Mtetra
.66944 .30895 .67147 .31159 .6757 .31016 .67367 .30752 Mtetra
.67367 .30752 .6757 .31016 .67993 .30873 .67791 .30609 Mtetra
.67791 .30609 .67993 .30873 .68417 .3073 .68216 .30465 Mtetra
.68216 .30465 .68417 .3073 .68842 .30587 .68641 .30321 Mtetra
.68641 .30321 .68842 .30587 .69267 .30443 .69067 .30177 Mtetra
.938 .574 .187 r
.69067 .30177 .69267 .30443 .6983 .32777 .69628 .32512 Mtetra
.662 .744 .911 r
.69628 .32512 .6983 .32777 .7026 .32634 .70058 .32369 Mtetra
.70058 .32369 .7026 .32634 .7069 .3249 .7049 .32225 Mtetra
.7049 .32225 .7069 .3249 .71122 .32347 .70921 .32081 Mtetra
.70921 .32081 .71122 .32347 .71554 .32203 .71354 .31936 Mtetra
.71354 .31936 .71554 .32203 .71986 .32059 .71787 .31792 Mtetra
.71787 .31792 .71986 .32059 .7242 .31914 .72221 .31647 Mtetra
.72221 .31647 .7242 .31914 .72854 .3177 .72655 .31502 Mtetra
.72655 .31502 .72854 .3177 .73288 .31625 .7309 .31357 Mtetra
.7309 .31357 .73288 .31625 .73724 .3148 .73526 .31211 Mtetra
.73526 .31211 .73724 .3148 .7416 .31335 .73963 .31066 Mtetra
.73963 .31066 .7416 .31335 .74596 .31189 .744 .3092 Mtetra
.744 .3092 .74596 .31189 .75034 .31043 .74837 .30774 Mtetra
.74837 .30774 .75034 .31043 .75472 .30898 .75276 .30628 Mtetra
.75276 .30628 .75472 .30898 .7591 .30751 .75715 .30481 Mtetra
.75715 .30481 .7591 .30751 .7635 .30605 .76155 .30334 Mtetra
.76155 .30334 .7635 .30605 .7679 .30458 .76595 .30187 Mtetra
.969 .65 .303 r
.76595 .30187 .7679 .30458 .7723 .30312 .77895 .40957 Mtetra
.538 .311 .518 r
.77895 .40957 .7723 .30312 .78551 .41079 .78353 .40813 Mtetra
.654 .754 .923 r
.78353 .40813 .78551 .41079 .79054 .41474 .78811 .40669 Mtetra
.615 .513 .715 r
.78811 .40669 .79054 .41474 .79514 .4133 .79271 .40525 Mtetra
.79271 .40525 .79514 .4133 .79974 .41187 .79731 .4038 Mtetra
.79731 .4038 .79974 .41187 .80435 .41042 .80192 .40236 Mtetra
.80192 .40236 .80435 .41042 .80897 .40898 .80654 .4009 Mtetra
.80654 .4009 .80897 .40898 .8136 .40753 .81116 .39945 Mtetra
.348 .347 .716 r
.81116 .39945 .8136 .40753 .81823 .40608 .81628 .4034 Mtetra
.653 .754 .924 r
.81628 .4034 .81823 .40608 .82287 .40463 .82093 .40195 Mtetra
.82093 .40195 .82287 .40463 .82752 .40318 .82558 .40049 Mtetra
.82558 .40049 .82752 .40318 .83218 .40172 .83024 .39903 Mtetra
.83024 .39903 .83218 .40172 .83684 .40026 .83491 .39756 Mtetra
.83491 .39756 .83684 .40026 .84151 .3988 .83959 .3961 Mtetra
.83959 .3961 .84151 .3988 .84619 .39734 .84427 .39463 Mtetra
.84427 .39463 .84619 .39734 .85088 .39587 .84896 .39316 Mtetra
.84896 .39316 .85088 .39587 .85557 .3944 .85366 .39169 Mtetra
.85366 .39169 .85557 .3944 .86028 .39293 .85837 .39021 Mtetra
.85837 .39021 .86028 .39293 .86498 .39146 .86308 .38874 Mtetra
.648 .76 .931 r
.22431 .6419 .2269 .64403 .23072 .64288 .22813 .64074 Mtetra
.22813 .64074 .23072 .64288 .23454 .64172 .23195 .63958 Mtetra
.23195 .63958 .23454 .64172 .23837 .64056 .23578 .63842 Mtetra
.23578 .63842 .23837 .64056 .2422 .6394 .23962 .63726 Mtetra
.23962 .63726 .2422 .6394 .24604 .63824 .24346 .63609 Mtetra
.24346 .63609 .24604 .63824 .24988 .63708 .24731 .63493 Mtetra
.24731 .63493 .24988 .63708 .25373 .63591 .25116 .63376 Mtetra
.25116 .63376 .25373 .63591 .25758 .63475 .25502 .63259 Mtetra
.25502 .63259 .25758 .63475 .26145 .63358 .25889 .63142 Mtetra
.25889 .63142 .26145 .63358 .26531 .63241 .26276 .63025 Mtetra
.26276 .63025 .26531 .63241 .26918 .63124 .26663 .62907 Mtetra
.26663 .62907 .26918 .63124 .27306 .63007 .27051 .6279 Mtetra
.27051 .6279 .27306 .63007 .27695 .62889 .2744 .62672 Mtetra
.2744 .62672 .27695 .62889 .28084 .62771 .27829 .62554 Mtetra
.27829 .62554 .28084 .62771 .28473 .62654 .28219 .62436 Mtetra
.28219 .62436 .28473 .62654 .28863 .62536 .2861 .62317 Mtetra
.2861 .62317 .28863 .62536 .29254 .62417 .29001 .62199 Mtetra
.29001 .62199 .29254 .62417 .29645 .62299 .29392 .6208 Mtetra
.943 .692 .528 r
.29392 .6208 .29645 .62299 .30037 .6218 .30927 .44644 Mtetra
.548 .334 .541 r
.30927 .44644 .30037 .6218 .31539 .4475 .313 .44518 Mtetra
.662 .743 .91 r
.313 .44518 .31539 .4475 .31913 .44624 .31675 .44393 Mtetra
.31675 .44393 .31913 .44624 .32287 .44499 .3205 .44267 Mtetra
.3205 .44267 .32287 .44499 .32662 .44374 .32425 .44141 Mtetra
.32425 .44141 .32662 .44374 .33038 .44248 .32801 .44015 Mtetra
.32801 .44015 .33038 .44248 .33414 .44122 .33178 .43889 Mtetra
.33178 .43889 .33414 .44122 .33791 .43996 .33555 .43763 Mtetra
.33555 .43763 .33791 .43996 .34168 .4387 .33932 .43636 Mtetra
.33932 .43636 .34168 .4387 .34546 .43743 .3431 .4351 Mtetra
.3431 .4351 .34546 .43743 .34924 .43617 .34689 .43383 Mtetra
.34689 .43383 .34924 .43617 .35303 .4349 .35068 .43256 Mtetra
.35068 .43256 .35303 .4349 .35682 .43363 .35448 .43128 Mtetra
.35448 .43128 .35682 .43363 .36062 .43236 .35828 .43001 Mtetra
.35828 .43001 .36062 .43236 .36443 .43109 .36209 .42873 Mtetra
.36209 .42873 .36443 .43109 .36824 .42981 .3659 .42745 Mtetra
.3659 .42745 .36824 .42981 .37205 .42854 .36972 .42617 Mtetra
.36972 .42617 .37205 .42854 .37587 .42726 .37354 .42489 Mtetra
.37354 .42489 .37587 .42726 .3797 .42598 .37737 .42361 Mtetra
.37737 .42361 .3797 .42598 .38353 .42469 .38121 .42232 Mtetra
.38121 .42232 .38353 .42469 .38737 .42341 .38505 .42103 Mtetra
.38505 .42103 .38737 .42341 .39121 .42212 .3889 .41975 Mtetra
.935 .727 .598 r
.3889 .41975 .39121 .42212 .39506 .42084 .39354 .39909 Mtetra
.574 .394 .6 r
.39354 .39909 .39506 .42084 .39966 .40018 .39737 .39779 Mtetra
.664 .741 .908 r
.39737 .39779 .39966 .40018 .40332 .40371 .40121 .39649 Mtetra
.619 .516 .715 r
.40121 .39649 .40332 .40371 .40717 .40241 .40506 .39518 Mtetra
.284 .303 .705 r
.40506 .39518 .40717 .40241 .41102 .40111 .40873 .3987 Mtetra
.663 .742 .908 r
.40873 .3987 .41102 .40111 .41488 .39981 .4126 .3974 Mtetra
.4126 .3974 .41488 .39981 .41874 .3985 .41646 .39609 Mtetra
.41646 .39609 .41874 .3985 .42261 .3972 .42034 .39478 Mtetra
.42034 .39478 .42261 .3972 .42649 .39589 .42422 .39347 Mtetra
.42422 .39347 .42649 .39589 .43037 .39458 .4281 .39216 Mtetra
.4281 .39216 .43037 .39458 .43426 .39327 .43199 .39085 Mtetra
.43199 .39085 .43426 .39327 .43815 .39196 .43589 .38953 Mtetra
.43589 .38953 .43815 .39196 .44205 .39064 .43979 .38821 Mtetra
.43979 .38821 .44205 .39064 .44595 .38933 .4437 .38689 Mtetra
.4437 .38689 .44595 .38933 .44986 .38801 .44761 .38557 Mtetra
.44761 .38557 .44986 .38801 .45378 .38669 .45153 .38425 Mtetra
.45153 .38425 .45378 .38669 .4577 .38537 .45545 .38292 Mtetra
.45545 .38292 .4577 .38537 .46162 .38404 .45938 .38159 Mtetra
.45938 .38159 .46162 .38404 .46555 .38272 .46332 .38026 Mtetra
.46332 .38026 .46555 .38272 .46949 .38139 .46726 .37893 Mtetra
.962 .676 .444 r
.46726 .37893 .46949 .38139 .47166 .49056 .46935 .48816 Mtetra
.655 .752 .922 r
.46935 .48816 .47166 .49056 .47574 .48926 .47344 .48686 Mtetra
.47344 .48686 .47574 .48926 .47983 .48796 .47753 .48556 Mtetra
.47753 .48556 .47983 .48796 .48393 .48666 .48163 .48426 Mtetra
.48163 .48426 .48393 .48666 .48803 .48536 .48574 .48296 Mtetra
.48574 .48296 .48803 .48536 .49214 .48406 .48985 .48165 Mtetra
.48985 .48165 .49214 .48406 .49626 .48276 .49397 .48034 Mtetra
.49397 .48034 .49626 .48276 .50038 .48145 .4981 .47903 Mtetra
.4981 .47903 .50038 .48145 .5045 .48014 .50223 .47772 Mtetra
.50223 .47772 .5045 .48014 .50864 .47883 .50636 .4764 Mtetra
.50636 .4764 .50864 .47883 .51278 .47752 .51051 .47509 Mtetra
.51051 .47509 .51278 .47752 .51692 .4762 .51466 .47377 Mtetra
.51466 .47377 .51692 .4762 .52108 .47489 .51881 .47245 Mtetra
.51881 .47245 .52108 .47489 .52523 .47357 .52298 .47113 Mtetra
.52298 .47113 .52523 .47357 .5294 .47225 .52715 .4698 Mtetra
.52715 .4698 .5294 .47225 .53357 .47092 .53132 .46848 Mtetra
.53132 .46848 .53357 .47092 .53761 .43342 .5355 .46715 Mtetra
.523 .277 .484 r
.5355 .46715 .53761 .43342 .54193 .46827 .53969 .46582 Mtetra
.655 .752 .922 r
.53969 .46582 .54193 .46827 .54612 .46694 .54388 .46449 Mtetra
.54388 .46449 .54612 .46694 .55032 .46561 .54809 .46315 Mtetra
.54809 .46315 .55032 .46561 .55452 .46428 .55229 .46181 Mtetra
.55229 .46181 .55452 .46428 .55873 .46295 .55651 .46048 Mtetra
.55651 .46048 .55873 .46295 .56294 .46161 .56073 .45914 Mtetra
.56073 .45914 .56294 .46161 .56717 .46027 .56495 .45779 Mtetra
.56495 .45779 .56717 .46027 .5714 .45893 .56918 .45645 Mtetra
.56918 .45645 .5714 .45893 .57563 .45759 .57342 .4551 Mtetra
.57342 .4551 .57563 .45759 .57987 .45624 .57767 .45375 Mtetra
.57767 .45375 .57987 .45624 .58412 .45489 .58192 .4524 Mtetra
.58192 .4524 .58412 .45489 .58837 .45354 .58618 .45105 Mtetra
.58618 .45105 .58837 .45354 .59263 .45219 .59045 .44969 Mtetra
.59045 .44969 .59263 .45219 .5969 .45084 .59472 .44834 Mtetra
.59472 .44834 .5969 .45084 .60118 .44949 .599 .44698 Mtetra
.599 .44698 .60118 .44949 .60546 .44813 .60328 .44562 Mtetra
.60328 .44562 .60546 .44813 .60974 .44677 .60757 .44425 Mtetra
.972 .698 .451 r
.60757 .44425 .60974 .44677 .61086 .32876 .60876 .32617 Mtetra
.664 .741 .908 r
.60876 .32617 .61086 .32876 .615 .32736 .61291 .32477 Mtetra
.61291 .32477 .615 .32736 .61915 .32596 .61707 .32336 Mtetra
.61707 .32336 .61915 .32596 .62331 .32455 .62123 .32195 Mtetra
.62123 .32195 .62331 .32455 .62747 .32315 .62539 .32054 Mtetra
.62539 .32054 .62747 .32315 .63164 .32174 .62957 .31913 Mtetra
.62957 .31913 .63164 .32174 .63581 .32032 .63375 .31771 Mtetra
.63375 .31771 .63581 .32032 .64 .31891 .63793 .31629 Mtetra
.63793 .31629 .64 .31891 .64418 .31749 .64212 .31487 Mtetra
.64212 .31487 .64418 .31749 .64838 .31607 .64632 .31345 Mtetra
.64632 .31345 .64838 .31607 .65258 .31465 .65053 .31203 Mtetra
.65053 .31203 .65258 .31465 .65679 .31323 .65474 .3106 Mtetra
.65474 .3106 .65679 .31323 .661 .31181 .65895 .30917 Mtetra
.65895 .30917 .661 .31181 .66522 .31038 .66318 .30774 Mtetra
.66318 .30774 .66522 .31038 .66944 .30895 .66741 .30631 Mtetra
.66741 .30631 .66944 .30895 .67367 .30752 .67164 .30487 Mtetra
.67164 .30487 .67367 .30752 .67791 .30609 .67589 .30344 Mtetra
.67589 .30344 .67791 .30609 .68216 .30465 .68014 .302 Mtetra
.68014 .302 .68216 .30465 .68641 .30321 .68439 .30055 Mtetra
.939 .576 .19 r
.68439 .30055 .68641 .30321 .69067 .30177 .68995 .32391 Mtetra
.51 .252 .459 r
.68995 .32391 .69067 .30177 .69628 .32512 .69426 .32247 Mtetra
.662 .744 .911 r
.69426 .32247 .69628 .32512 .70058 .32369 .69857 .32103 Mtetra
.69857 .32103 .70058 .32369 .7049 .32225 .70288 .31959 Mtetra
.70288 .31959 .7049 .32225 .70921 .32081 .7072 .31814 Mtetra
.7072 .31814 .70921 .32081 .71354 .31936 .71153 .31669 Mtetra
.71153 .31669 .71354 .31936 .71787 .31792 .71587 .31524 Mtetra
.71587 .31524 .71787 .31792 .72221 .31647 .72021 .31379 Mtetra
.72021 .31379 .72221 .31647 .72655 .31502 .72456 .31234 Mtetra
.72456 .31234 .72655 .31502 .7309 .31357 .72892 .31088 Mtetra
.72892 .31088 .7309 .31357 .73526 .31211 .73328 .30942 Mtetra
.73328 .30942 .73526 .31211 .73963 .31066 .73765 .30796 Mtetra
.73765 .30796 .73963 .31066 .744 .3092 .74202 .3065 Mtetra
.74202 .3065 .744 .3092 .74837 .30774 .74641 .30504 Mtetra
.74641 .30504 .74837 .30774 .75276 .30628 .7508 .30357 Mtetra
.7508 .30357 .75276 .30628 .75715 .30481 .75519 .3021 Mtetra
.75519 .3021 .75715 .30481 .76155 .30334 .7596 .30063 Mtetra
.7596 .30063 .76155 .30334 .76595 .30187 .76401 .29915 Mtetra
.969 .65 .303 r
.76401 .29915 .76595 .30187 .77895 .40957 .77695 .40692 Mtetra
.654 .754 .923 r
.77695 .40692 .77895 .40957 .78353 .40813 .78153 .40547 Mtetra
.78153 .40547 .78353 .40813 .78811 .40669 .78612 .40403 Mtetra
.78612 .40403 .78811 .40669 .79271 .40525 .79072 .40258 Mtetra
.79072 .40258 .79271 .40525 .79731 .4038 .79533 .40113 Mtetra
.79533 .40113 .79731 .4038 .80192 .40236 .79995 .39968 Mtetra
.79995 .39968 .80192 .40236 .80654 .4009 .80457 .39822 Mtetra
.80457 .39822 .80654 .4009 .81116 .39945 .8092 .39676 Mtetra
.8092 .39676 .81116 .39945 .81628 .4034 .81383 .3953 Mtetra
.615 .513 .715 r
.81383 .3953 .81628 .4034 .82093 .40195 .81848 .39384 Mtetra
.81848 .39384 .82093 .40195 .82558 .40049 .82313 .39238 Mtetra
.82313 .39238 .82558 .40049 .83024 .39903 .82779 .39091 Mtetra
.82779 .39091 .83024 .39903 .83491 .39756 .83245 .38944 Mtetra
.352 .349 .716 r
.83245 .38944 .83491 .39756 .83959 .3961 .83765 .39339 Mtetra
.653 .754 .924 r
.83765 .39339 .83959 .3961 .84427 .39463 .84234 .39192 Mtetra
.84234 .39192 .84427 .39463 .84896 .39316 .84704 .39044 Mtetra
.84704 .39044 .84896 .39316 .85366 .39169 .85175 .38896 Mtetra
.85175 .38896 .85366 .39169 .85837 .39021 .85646 .38749 Mtetra
.85646 .38749 .85837 .39021 .86308 .38874 .86118 .386 Mtetra
.648 .76 .931 r
.22171 .63976 .22431 .6419 .22813 .64074 .22554 .6386 Mtetra
.22554 .6386 .22813 .64074 .23195 .63958 .22936 .63744 Mtetra
.22936 .63744 .23195 .63958 .23578 .63842 .2332 .63627 Mtetra
.2332 .63627 .23578 .63842 .23962 .63726 .23704 .63511 Mtetra
.23704 .63511 .23962 .63726 .24346 .63609 .24088 .63394 Mtetra
.24088 .63394 .24346 .63609 .24731 .63493 .24473 .63277 Mtetra
.24473 .63277 .24731 .63493 .25116 .63376 .24859 .6316 Mtetra
.24859 .6316 .25116 .63376 .25502 .63259 .25245 .63043 Mtetra
.25245 .63043 .25502 .63259 .25889 .63142 .25632 .62925 Mtetra
.25632 .62925 .25889 .63142 .26276 .63025 .26019 .62808 Mtetra
.26019 .62808 .26276 .63025 .26663 .62907 .26407 .6269 Mtetra
.26407 .6269 .26663 .62907 .27051 .6279 .26795 .62572 Mtetra
.26795 .62572 .27051 .6279 .2744 .62672 .27185 .62454 Mtetra
.27185 .62454 .2744 .62672 .27829 .62554 .27574 .62335 Mtetra
.27574 .62335 .27829 .62554 .28219 .62436 .27964 .62217 Mtetra
.27964 .62217 .28219 .62436 .2861 .62317 .28355 .62098 Mtetra
.28355 .62098 .2861 .62317 .29001 .62199 .28747 .61979 Mtetra
.28747 .61979 .29001 .62199 .29392 .6208 .29139 .6186 Mtetra
.943 .692 .528 r
.29139 .6186 .29392 .6208 .30927 .44644 .30688 .44412 Mtetra
.662 .743 .91 r
.30688 .44412 .30927 .44644 .313 .44518 .31062 .44287 Mtetra
.31062 .44287 .313 .44518 .31675 .44393 .31436 .44161 Mtetra
.31436 .44161 .31675 .44393 .3205 .44267 .31812 .44035 Mtetra
.31812 .44035 .3205 .44267 .32425 .44141 .32187 .43909 Mtetra
.32187 .43909 .32425 .44141 .32801 .44015 .32564 .43782 Mtetra
.32564 .43782 .32801 .44015 .33178 .43889 .3294 .43656 Mtetra
.3294 .43656 .33178 .43889 .33555 .43763 .33318 .43529 Mtetra
.33318 .43529 .33555 .43763 .33932 .43636 .33696 .43402 Mtetra
.33696 .43402 .33932 .43636 .3431 .4351 .34074 .43275 Mtetra
.34074 .43275 .3431 .4351 .34689 .43383 .34453 .43148 Mtetra
.34453 .43148 .34689 .43383 .35068 .43256 .34832 .4302 Mtetra
.34832 .4302 .35068 .43256 .35448 .43128 .35213 .42893 Mtetra
.35213 .42893 .35448 .43128 .35828 .43001 .35593 .42765 Mtetra
.35593 .42765 .35828 .43001 .36209 .42873 .35974 .42637 Mtetra
.35974 .42637 .36209 .42873 .3659 .42745 .36356 .42509 Mtetra
.36356 .42509 .3659 .42745 .36972 .42617 .36738 .42381 Mtetra
.36738 .42381 .36972 .42617 .37354 .42489 .37121 .42252 Mtetra
.37121 .42252 .37354 .42489 .37737 .42361 .37504 .42123 Mtetra
.37504 .42123 .37737 .42361 .38121 .42232 .37888 .41994 Mtetra
.37888 .41994 .38121 .42232 .38505 .42103 .38272 .41865 Mtetra
.38272 .41865 .38505 .42103 .3889 .41975 .38657 .41736 Mtetra
.935 .727 .598 r
.38657 .41736 .3889 .41975 .39354 .39909 .39123 .39669 Mtetra
.664 .741 .908 r
.39123 .39669 .39354 .39909 .39737 .39779 .39507 .39538 Mtetra
.39507 .39538 .39737 .39779 .40121 .39649 .39892 .39408 Mtetra
.39892 .39408 .40121 .39649 .40506 .39518 .40277 .39277 Mtetra
.40277 .39277 .40506 .39518 .40873 .3987 .40662 .39146 Mtetra
.284 .303 .705 r
.40662 .39146 .40873 .3987 .4126 .3974 .41031 .39499 Mtetra
.663 .742 .908 r
.41031 .39499 .4126 .3974 .41646 .39609 .41418 .39367 Mtetra
.41418 .39367 .41646 .39609 .42034 .39478 .41806 .39236 Mtetra
.41806 .39236 .42034 .39478 .42422 .39347 .42194 .39105 Mtetra
.42194 .39105 .42422 .39347 .4281 .39216 .42583 .38973 Mtetra
.42583 .38973 .4281 .39216 .43199 .39085 .42972 .38841 Mtetra
.42972 .38841 .43199 .39085 .43589 .38953 .43362 .38709 Mtetra
.43362 .38709 .43589 .38953 .43979 .38821 .43753 .38577 Mtetra
.43753 .38577 .43979 .38821 .4437 .38689 .44144 .38445 Mtetra
.44144 .38445 .4437 .38689 .44761 .38557 .44535 .38312 Mtetra
.44535 .38312 .44761 .38557 .45153 .38425 .44927 .3818 Mtetra
.44927 .3818 .45153 .38425 .45545 .38292 .4532 .38047 Mtetra
.4532 .38047 .45545 .38292 .45938 .38159 .45714 .37914 Mtetra
.45714 .37914 .45938 .38159 .46332 .38026 .46107 .3778 Mtetra
.46107 .3778 .46332 .38026 .46726 .37893 .46502 .37647 Mtetra
.962 .676 .444 r
.46502 .37647 .46726 .37893 .46935 .48816 .46704 .48576 Mtetra
.655 .752 .922 r
.46704 .48576 .46935 .48816 .47344 .48686 .47113 .48446 Mtetra
.47113 .48446 .47344 .48686 .47753 .48556 .47523 .48316 Mtetra
.47523 .48316 .47753 .48556 .48163 .48426 .47933 .48185 Mtetra
.47933 .48185 .48163 .48426 .48574 .48296 .48344 .48054 Mtetra
.48344 .48054 .48574 .48296 .48985 .48165 .48756 .47923 Mtetra
.48756 .47923 .48985 .48165 .49397 .48034 .49168 .47792 Mtetra
.49168 .47792 .49397 .48034 .4981 .47903 .49581 .47661 Mtetra
.49581 .47661 .4981 .47903 .50223 .47772 .49994 .47529 Mtetra
.49994 .47529 .50223 .47772 .50636 .4764 .50409 .47397 Mtetra
.50409 .47397 .50636 .4764 .51051 .47509 .50823 .47265 Mtetra
.50823 .47265 .51051 .47509 .51466 .47377 .51239 .47133 Mtetra
.51239 .47133 .51466 .47377 .51881 .47245 .51655 .47001 Mtetra
.51655 .47001 .51881 .47245 .52298 .47113 .52071 .46868 Mtetra
.52071 .46868 .52298 .47113 .52715 .4698 .52489 .46735 Mtetra
.52489 .46735 .52715 .4698 .53132 .46848 .52907 .46602 Mtetra
.52907 .46602 .53132 .46848 .5355 .46715 .53325 .46469 Mtetra
.53325 .46469 .5355 .46715 .53969 .46582 .53744 .46336 Mtetra
.53744 .46336 .53969 .46582 .54388 .46449 .54164 .46202 Mtetra
.54164 .46202 .54388 .46449 .54809 .46315 .54585 .46068 Mtetra
.54585 .46068 .54809 .46315 .55229 .46181 .55006 .45934 Mtetra
.55006 .45934 .55229 .46181 .55651 .46048 .55428 .458 Mtetra
.55428 .458 .55651 .46048 .56073 .45914 .5585 .45666 Mtetra
.5585 .45666 .56073 .45914 .56495 .45779 .56273 .45531 Mtetra
.56273 .45531 .56495 .45779 .56918 .45645 .56697 .45396 Mtetra
.56697 .45396 .56918 .45645 .57342 .4551 .57121 .45261 Mtetra
.57121 .45261 .57342 .4551 .57767 .45375 .57546 .45126 Mtetra
.57546 .45126 .57767 .45375 .58192 .4524 .57972 .4499 Mtetra
.57972 .4499 .58192 .4524 .58618 .45105 .58398 .44855 Mtetra
.58398 .44855 .58618 .45105 .59045 .44969 .58825 .44719 Mtetra
.58825 .44719 .59045 .44969 .59472 .44834 .59253 .44583 Mtetra
.59253 .44583 .59472 .44834 .599 .44698 .59681 .44446 Mtetra
.59681 .44446 .599 .44698 .60328 .44562 .6011 .4431 Mtetra
.6011 .4431 .60328 .44562 .60757 .44425 .6054 .44173 Mtetra
.972 .698 .451 r
.6054 .44173 .60757 .44425 .60876 .32617 .60666 .32358 Mtetra
.664 .741 .908 r
.60666 .32358 .60876 .32617 .61291 .32477 .61082 .32217 Mtetra
.61082 .32217 .61291 .32477 .61707 .32336 .61497 .32076 Mtetra
.61497 .32076 .61707 .32336 .62123 .32195 .61914 .31934 Mtetra
.61914 .31934 .62123 .32195 .62539 .32054 .62331 .31793 Mtetra
.62331 .31793 .62539 .32054 .62957 .31913 .62749 .31651 Mtetra
.62749 .31651 .62957 .31913 .63375 .31771 .63167 .31509 Mtetra
.63167 .31509 .63375 .31771 .63793 .31629 .63586 .31367 Mtetra
.63586 .31367 .63793 .31629 .64212 .31487 .64006 .31225 Mtetra
.64006 .31225 .64212 .31487 .64632 .31345 .64426 .31082 Mtetra
.64426 .31082 .64632 .31345 .65053 .31203 .64847 .30939 Mtetra
.64847 .30939 .65053 .31203 .65474 .3106 .65268 .30796 Mtetra
.65268 .30796 .65474 .3106 .65895 .30917 .65691 .30653 Mtetra
.65691 .30653 .65895 .30917 .66318 .30774 .66113 .30509 Mtetra
.66113 .30509 .66318 .30774 .66741 .30631 .66537 .30366 Mtetra
.66537 .30366 .66741 .30631 .67164 .30487 .66961 .30222 Mtetra
.66961 .30222 .67164 .30487 .67589 .30344 .67385 .30078 Mtetra
.67385 .30078 .67589 .30344 .68014 .302 .67811 .29933 Mtetra
.67811 .29933 .68014 .302 .68439 .30055 .68237 .29789 Mtetra
.939 .576 .19 r
.68237 .29789 .68439 .30055 .68995 .32391 .68792 .32125 Mtetra
.662 .744 .911 r
.68792 .32125 .68995 .32391 .69426 .32247 .69223 .31981 Mtetra
.69223 .31981 .69426 .32247 .69857 .32103 .69654 .31836 Mtetra
.69654 .31836 .69857 .32103 .70288 .31959 .70086 .31692 Mtetra
.70086 .31692 .70288 .31959 .7072 .31814 .70519 .31547 Mtetra
.70519 .31547 .7072 .31814 .71153 .31669 .70952 .31402 Mtetra
.70952 .31402 .71153 .31669 .71587 .31524 .71386 .31256 Mtetra
.71386 .31256 .71587 .31524 .72021 .31379 .71821 .31111 Mtetra
.71821 .31111 .72021 .31379 .72456 .31234 .72257 .30965 Mtetra
.72257 .30965 .72456 .31234 .72892 .31088 .72693 .30819 Mtetra
.72693 .30819 .72892 .31088 .73328 .30942 .73129 .30673 Mtetra
.73129 .30673 .73328 .30942 .73765 .30796 .73567 .30526 Mtetra
.73567 .30526 .73765 .30796 .74202 .3065 .74005 .30379 Mtetra
.74005 .30379 .74202 .3065 .74641 .30504 .74443 .30232 Mtetra
.74443 .30232 .74641 .30504 .7508 .30357 .74883 .30085 Mtetra
.74883 .30085 .7508 .30357 .75519 .3021 .75323 .29938 Mtetra
.75323 .29938 .75519 .3021 .7596 .30063 .75764 .2979 Mtetra
.75764 .2979 .7596 .30063 .76401 .29915 .76205 .29643 Mtetra
.969 .65 .303 r
.76205 .29643 .76401 .29915 .77695 .40692 .77494 .40425 Mtetra
.654 .754 .923 r
.77494 .40425 .77695 .40692 .78153 .40547 .77953 .4028 Mtetra
.77953 .4028 .78153 .40547 .78612 .40403 .78413 .40135 Mtetra
.78413 .40135 .78612 .40403 .79072 .40258 .78873 .3999 Mtetra
.78873 .3999 .79072 .40258 .79533 .40113 .79335 .39844 Mtetra
.79335 .39844 .79533 .40113 .79995 .39968 .79797 .39699 Mtetra
.79797 .39699 .79995 .39968 .80457 .39822 .80259 .39553 Mtetra
.80259 .39553 .80457 .39822 .8092 .39676 .80723 .39407 Mtetra
.80723 .39407 .8092 .39676 .81383 .3953 .81187 .3926 Mtetra
.81187 .3926 .81383 .3953 .81848 .39384 .81652 .39114 Mtetra
.81652 .39114 .81848 .39384 .82313 .39238 .82118 .38967 Mtetra
.82118 .38967 .82313 .39238 .82779 .39091 .82584 .3882 Mtetra
.82584 .3882 .82779 .39091 .83245 .38944 .83051 .38672 Mtetra
.83051 .38672 .83245 .38944 .83765 .39339 .83519 .38525 Mtetra
.614 .513 .715 r
.83519 .38525 .83765 .39339 .84234 .39192 .83988 .38377 Mtetra
.83988 .38377 .84234 .39192 .84704 .39044 .84457 .38229 Mtetra
.84457 .38229 .84704 .39044 .85175 .38896 .84927 .38081 Mtetra
.84927 .38081 .85175 .38896 .85646 .38749 .85398 .37932 Mtetra
.85398 .37932 .85646 .38749 .86118 .386 .8587 .37783 Mtetra
.648 .76 .931 r
.21911 .63762 .22171 .63976 .22554 .6386 .22293 .63645 Mtetra
.22293 .63645 .22554 .6386 .22936 .63744 .22677 .63529 Mtetra
.22677 .63529 .22936 .63744 .2332 .63627 .2306 .63412 Mtetra
.2306 .63412 .2332 .63627 .23704 .63511 .23444 .63295 Mtetra
.23444 .63295 .23704 .63511 .24088 .63394 .23829 .63178 Mtetra
.23829 .63178 .24088 .63394 .24473 .63277 .24215 .63061 Mtetra
.24215 .63061 .24473 .63277 .24859 .6316 .24601 .62943 Mtetra
.24601 .62943 .24859 .6316 .25245 .63043 .24987 .62826 Mtetra
.24987 .62826 .25245 .63043 .25632 .62925 .25374 .62708 Mtetra
.25374 .62708 .25632 .62925 .26019 .62808 .25762 .6259 Mtetra
.25762 .6259 .26019 .62808 .26407 .6269 .2615 .62472 Mtetra
.2615 .62472 .26407 .6269 .26795 .62572 .26539 .62354 Mtetra
.26539 .62354 .26795 .62572 .27185 .62454 .26928 .62235 Mtetra
.26928 .62235 .27185 .62454 .27574 .62335 .27318 .62117 Mtetra
.27318 .62117 .27574 .62335 .27964 .62217 .27709 .61998 Mtetra
.27709 .61998 .27964 .62217 .28355 .62098 .281 .61879 Mtetra
.281 .61879 .28355 .62098 .28747 .61979 .28492 .6176 Mtetra
.28492 .6176 .28747 .61979 .29139 .6186 .28884 .6164 Mtetra
.943 .692 .528 r
.28884 .6164 .29139 .6186 .30688 .44412 .30448 .4418 Mtetra
.662 .743 .91 r
.30448 .4418 .30688 .44412 .31062 .44287 .30822 .44054 Mtetra
.30822 .44054 .31062 .44287 .31436 .44161 .31197 .43928 Mtetra
.31197 .43928 .31436 .44161 .31812 .44035 .31573 .43802 Mtetra
.31573 .43802 .31812 .44035 .32187 .43909 .31949 .43675 Mtetra
.31949 .43675 .32187 .43909 .32564 .43782 .32326 .43549 Mtetra
.32326 .43549 .32564 .43782 .3294 .43656 .32703 .43422 Mtetra
.32703 .43422 .3294 .43656 .33318 .43529 .3308 .43295 Mtetra
.3308 .43295 .33318 .43529 .33696 .43402 .33459 .43167 Mtetra
.33459 .43167 .33696 .43402 .34074 .43275 .33837 .4304 Mtetra
.33837 .4304 .34074 .43275 .34453 .43148 .34217 .42912 Mtetra
.34217 .42912 .34453 .43148 .34832 .4302 .34596 .42785 Mtetra
.34596 .42785 .34832 .4302 .35213 .42893 .34977 .42657 Mtetra
.34977 .42657 .35213 .42893 .35593 .42765 .35358 .42529 Mtetra
.35358 .42529 .35593 .42765 .35974 .42637 .35739 .424 Mtetra
.35739 .424 .35974 .42637 .36356 .42509 .36121 .42272 Mtetra
.36121 .42272 .36356 .42509 .36738 .42381 .36504 .42143 Mtetra
.36504 .42143 .36738 .42381 .37121 .42252 .36887 .42014 Mtetra
.36887 .42014 .37121 .42252 .37504 .42123 .3727 .41885 Mtetra
.3727 .41885 .37504 .42123 .37888 .41994 .37655 .41756 Mtetra
.37655 .41756 .37888 .41994 .38272 .41865 .38039 .41627 Mtetra
.934 .727 .598 r
.38039 .41627 .38272 .41865 .38657 .41736 .38509 .39558 Mtetra
.573 .393 .599 r
.38509 .39558 .38657 .41736 .39123 .39669 .38893 .39428 Mtetra
.664 .741 .908 r
.38893 .39428 .39123 .39669 .39507 .39538 .39277 .39297 Mtetra
.39277 .39297 .39507 .39538 .39892 .39408 .39661 .39167 Mtetra
.39661 .39167 .39892 .39408 .40277 .39277 .40047 .39036 Mtetra
.40047 .39036 .40277 .39277 .40662 .39146 .40432 .38904 Mtetra
.40432 .38904 .40662 .39146 .41031 .39499 .40819 .38773 Mtetra
.619 .515 .715 r
.40819 .38773 .41031 .39499 .41418 .39367 .41206 .38642 Mtetra
.285 .304 .705 r
.41206 .38642 .41418 .39367 .41806 .39236 .41577 .38993 Mtetra
.663 .742 .908 r
.41577 .38993 .41806 .39236 .42194 .39105 .41965 .38862 Mtetra
.41965 .38862 .42194 .39105 .42583 .38973 .42355 .3873 Mtetra
.42355 .3873 .42583 .38973 .42972 .38841 .42744 .38598 Mtetra
.42744 .38598 .42972 .38841 .43362 .38709 .43135 .38465 Mtetra
.43135 .38465 .43362 .38709 .43753 .38577 .43526 .38333 Mtetra
.43526 .38333 .43753 .38577 .44144 .38445 .43917 .382 Mtetra
.43917 .382 .44144 .38445 .44535 .38312 .44309 .38067 Mtetra
.44309 .38067 .44535 .38312 .44927 .3818 .44702 .37934 Mtetra
.44702 .37934 .44927 .3818 .4532 .38047 .45095 .37801 Mtetra
.45095 .37801 .4532 .38047 .45714 .37914 .45488 .37667 Mtetra
.45488 .37667 .45714 .37914 .46107 .3778 .45883 .37534 Mtetra
.45883 .37534 .46107 .3778 .46502 .37647 .46277 .374 Mtetra
.962 .676 .444 r
.46277 .374 .46502 .37647 .46704 .48576 .46471 .48336 Mtetra
.655 .752 .922 r
.46471 .48336 .46704 .48576 .47113 .48446 .46881 .48205 Mtetra
.46881 .48205 .47113 .48446 .47523 .48316 .47291 .48074 Mtetra
.47291 .48074 .47523 .48316 .47933 .48185 .47702 .47944 Mtetra
.47702 .47944 .47933 .48185 .48344 .48054 .48113 .47812 Mtetra
.48113 .47812 .48344 .48054 .48756 .47923 .48525 .47681 Mtetra
.48525 .47681 .48756 .47923 .49168 .47792 .48938 .47549 Mtetra
.48938 .47549 .49168 .47792 .49581 .47661 .49351 .47418 Mtetra
.49351 .47418 .49581 .47661 .49994 .47529 .49765 .47286 Mtetra
.49765 .47286 .49994 .47529 .50409 .47397 .5018 .47153 Mtetra
.5018 .47153 .50409 .47397 .50823 .47265 .50595 .47021 Mtetra
.50595 .47021 .50823 .47265 .51239 .47133 .51011 .46889 Mtetra
.51011 .46889 .51239 .47133 .51655 .47001 .51427 .46756 Mtetra
.51427 .46756 .51655 .47001 .52071 .46868 .51844 .46623 Mtetra
.51844 .46623 .52071 .46868 .52489 .46735 .52262 .4649 Mtetra
.52262 .4649 .52489 .46735 .52907 .46602 .52681 .46356 Mtetra
.52681 .46356 .52907 .46602 .53325 .46469 .53099 .46223 Mtetra
.53099 .46223 .53325 .46469 .53744 .46336 .53519 .46089 Mtetra
.53519 .46089 .53744 .46336 .54164 .46202 .53939 .45955 Mtetra
.53939 .45955 .54164 .46202 .54585 .46068 .5436 .45821 Mtetra
.5436 .45821 .54585 .46068 .55006 .45934 .54782 .45686 Mtetra
.54782 .45686 .55006 .45934 .55428 .458 .55204 .45552 Mtetra
.55204 .45552 .55428 .458 .5585 .45666 .55627 .45417 Mtetra
.55627 .45417 .5585 .45666 .56273 .45531 .5605 .45282 Mtetra
.5605 .45282 .56273 .45531 .56697 .45396 .56474 .45147 Mtetra
.56474 .45147 .56697 .45396 .57121 .45261 .56899 .45011 Mtetra
.56899 .45011 .57121 .45261 .57546 .45126 .57325 .44875 Mtetra
.57325 .44875 .57546 .45126 .57972 .4499 .57751 .4474 Mtetra
.57751 .4474 .57972 .4499 .58398 .44855 .58178 .44604 Mtetra
.58178 .44604 .58398 .44855 .58825 .44719 .58605 .44467 Mtetra
.58605 .44467 .58825 .44719 .59253 .44583 .59033 .44331 Mtetra
.59033 .44331 .59253 .44583 .59681 .44446 .59462 .44194 Mtetra
.59462 .44194 .59681 .44446 .6011 .4431 .59891 .44057 Mtetra
.972 .698 .452 r
.59891 .44057 .6011 .4431 .6054 .44173 .60041 .32239 Mtetra
.549 .337 .545 r
.60041 .32239 .6054 .44173 .60666 .32358 .60456 .32098 Mtetra
.664 .741 .908 r
.60456 .32098 .60666 .32358 .61082 .32217 .60871 .31956 Mtetra
.60871 .31956 .61082 .32217 .61497 .32076 .61288 .31815 Mtetra
.61288 .31815 .61497 .32076 .61914 .31934 .61705 .31673 Mtetra
.61705 .31673 .61914 .31934 .62331 .31793 .62122 .31531 Mtetra
.62122 .31531 .62331 .31793 .62749 .31651 .6254 .31389 Mtetra
.6254 .31389 .62749 .31651 .63167 .31509 .62959 .31247 Mtetra
.62959 .31247 .63167 .31509 .63586 .31367 .63379 .31104 Mtetra
.63379 .31104 .63586 .31367 .64006 .31225 .63799 .30961 Mtetra
.63799 .30961 .64006 .31225 .64426 .31082 .64219 .30818 Mtetra
.64219 .30818 .64426 .31082 .64847 .30939 .64641 .30675 Mtetra
.64641 .30675 .64847 .30939 .65268 .30796 .65063 .30531 Mtetra
.65063 .30531 .65268 .30796 .65691 .30653 .65485 .30388 Mtetra
.65485 .30388 .65691 .30653 .66113 .30509 .65908 .30244 Mtetra
.65908 .30244 .66113 .30509 .66537 .30366 .66332 .301 Mtetra
.66332 .301 .66537 .30366 .66961 .30222 .66757 .29956 Mtetra
.66757 .29956 .66961 .30222 .67385 .30078 .67182 .29811 Mtetra
.67182 .29811 .67385 .30078 .67811 .29933 .67608 .29666 Mtetra
.67608 .29666 .67811 .29933 .68237 .29789 .68034 .29521 Mtetra
.939 .576 .19 r
.68034 .29521 .68237 .29789 .68792 .32125 .68588 .31859 Mtetra
.662 .744 .911 r
.68588 .31859 .68792 .32125 .69223 .31981 .69019 .31714 Mtetra
.69019 .31714 .69223 .31981 .69654 .31836 .69451 .31569 Mtetra
.69451 .31569 .69654 .31836 .70086 .31692 .69884 .31424 Mtetra
.69884 .31424 .70086 .31692 .70519 .31547 .70317 .31279 Mtetra
.70317 .31279 .70519 .31547 .70952 .31402 .70751 .31133 Mtetra
.70751 .31133 .70952 .31402 .71386 .31256 .71185 .30987 Mtetra
.71185 .30987 .71386 .31256 .71821 .31111 .71621 .30841 Mtetra
.71621 .30841 .71821 .31111 .72257 .30965 .72056 .30695 Mtetra
.72056 .30695 .72257 .30965 .72693 .30819 .72493 .30549 Mtetra
.72493 .30549 .72693 .30819 .73129 .30673 .7293 .30402 Mtetra
.7293 .30402 .73129 .30673 .73567 .30526 .73368 .30255 Mtetra
.73368 .30255 .73567 .30526 .74005 .30379 .73806 .30108 Mtetra
.73806 .30108 .74005 .30379 .74443 .30232 .74246 .29961 Mtetra
.74246 .29961 .74443 .30232 .74883 .30085 .74685 .29813 Mtetra
.74685 .29813 .74883 .30085 .75323 .29938 .75126 .29665 Mtetra
.75126 .29665 .75323 .29938 .75764 .2979 .75567 .29517 Mtetra
.97 .651 .306 r
.75567 .29517 .75764 .2979 .76205 .29643 .76834 .40302 Mtetra
.537 .308 .516 r
.76834 .40302 .76205 .29643 .77494 .40425 .77293 .40157 Mtetra
.654 .754 .923 r
.77293 .40157 .77494 .40425 .77953 .4028 .77753 .40012 Mtetra
.77753 .40012 .77953 .4028 .78413 .40135 .78213 .39867 Mtetra
.78213 .39867 .78413 .40135 .78873 .3999 .78674 .39721 Mtetra
.78674 .39721 .78873 .3999 .79335 .39844 .79136 .39575 Mtetra
.79136 .39575 .79335 .39844 .79797 .39699 .79598 .39429 Mtetra
.79598 .39429 .79797 .39699 .80259 .39553 .80061 .39283 Mtetra
.80061 .39283 .80259 .39553 .80723 .39407 .80525 .39136 Mtetra
.80525 .39136 .80723 .39407 .81187 .3926 .8099 .38989 Mtetra
.8099 .38989 .81187 .3926 .81652 .39114 .81455 .38842 Mtetra
.81455 .38842 .81652 .39114 .82118 .38967 .81922 .38695 Mtetra
.81922 .38695 .82118 .38967 .82584 .3882 .82389 .38547 Mtetra
.82389 .38547 .82584 .3882 .83051 .38672 .82856 .384 Mtetra
.82856 .384 .83051 .38672 .83519 .38525 .83325 .38252 Mtetra
.83325 .38252 .83519 .38525 .83988 .38377 .83794 .38103 Mtetra
.83794 .38103 .83988 .38377 .84457 .38229 .84264 .37955 Mtetra
.84264 .37955 .84457 .38229 .84927 .38081 .84735 .37806 Mtetra
.84735 .37806 .84927 .38081 .85398 .37932 .85206 .37657 Mtetra
.85206 .37657 .85398 .37932 .8587 .37783 .85679 .37508 Mtetra
.648 .76 .931 r
.2165 .63547 .21911 .63762 .22293 .63645 .22033 .6343 Mtetra
.22033 .6343 .22293 .63645 .22677 .63529 .22416 .63313 Mtetra
.22416 .63313 .22677 .63529 .2306 .63412 .228 .63196 Mtetra
.228 .63196 .2306 .63412 .23444 .63295 .23185 .63079 Mtetra
.23185 .63079 .23444 .63295 .23829 .63178 .2357 .62961 Mtetra
.2357 .62961 .23829 .63178 .24215 .63061 .23956 .62844 Mtetra
.23956 .62844 .24215 .63061 .24601 .62943 .24342 .62726 Mtetra
.24342 .62726 .24601 .62943 .24987 .62826 .24729 .62608 Mtetra
.24729 .62608 .24987 .62826 .25374 .62708 .25116 .6249 Mtetra
.25116 .6249 .25374 .62708 .25762 .6259 .25504 .62372 Mtetra
.25504 .62372 .25762 .6259 .2615 .62472 .25893 .62253 Mtetra
.25893 .62253 .2615 .62472 .26539 .62354 .26282 .62135 Mtetra
.26282 .62135 .26539 .62354 .26928 .62235 .26672 .62016 Mtetra
.26672 .62016 .26928 .62235 .27318 .62117 .27062 .61897 Mtetra
.27062 .61897 .27318 .62117 .27709 .61998 .27453 .61778 Mtetra
.27453 .61778 .27709 .61998 .281 .61879 .27844 .61659 Mtetra
.27844 .61659 .281 .61879 .28492 .6176 .28237 .61539 Mtetra
.942 .691 .529 r
.28237 .61539 .28492 .6176 .28884 .6164 .29833 .44074 Mtetra
.547 .332 .54 r
.29833 .44074 .28884 .6164 .30448 .4418 .30208 .43947 Mtetra
.662 .743 .91 r
.30208 .43947 .30448 .4418 .30822 .44054 .30582 .43821 Mtetra
.30582 .43821 .30822 .44054 .31197 .43928 .30958 .43695 Mtetra
.30958 .43695 .31197 .43928 .31573 .43802 .31334 .43568 Mtetra
.31334 .43568 .31573 .43802 .31949 .43675 .3171 .43441 Mtetra
.3171 .43441 .31949 .43675 .32326 .43549 .32087 .43314 Mtetra
.32087 .43314 .32326 .43549 .32703 .43422 .32464 .43187 Mtetra
.32464 .43187 .32703 .43422 .3308 .43295 .32842 .4306 Mtetra
.32842 .4306 .3308 .43295 .33459 .43167 .33221 .42932 Mtetra
.33221 .42932 .33459 .43167 .33837 .4304 .336 .42804 Mtetra
.336 .42804 .33837 .4304 .34217 .42912 .3398 .42676 Mtetra
.3398 .42676 .34217 .42912 .34596 .42785 .3436 .42548 Mtetra
.3436 .42548 .34596 .42785 .34977 .42657 .3474 .4242 Mtetra
.3474 .4242 .34977 .42657 .35358 .42529 .35122 .42292 Mtetra
.35122 .42292 .35358 .42529 .35739 .424 .35503 .42163 Mtetra
.35503 .42163 .35739 .424 .36121 .42272 .35886 .42034 Mtetra
.35886 .42034 .36121 .42272 .36504 .42143 .36269 .41905 Mtetra
.36269 .41905 .36504 .42143 .36887 .42014 .36652 .41776 Mtetra
.36652 .41776 .36887 .42014 .3727 .41885 .37036 .41646 Mtetra
.37036 .41646 .3727 .41885 .37655 .41756 .37421 .41517 Mtetra
.934 .727 .599 r
.37421 .41517 .37655 .41756 .38039 .41627 .37894 .39448 Mtetra
.573 .393 .599 r
.37894 .39448 .38039 .41627 .38509 .39558 .38277 .39317 Mtetra
.664 .741 .908 r
.38277 .39317 .38509 .39558 .38893 .39428 .38661 .39187 Mtetra
.38661 .39187 .38893 .39428 .39277 .39297 .39046 .39056 Mtetra
.39046 .39056 .39277 .39297 .39661 .39167 .39431 .38925 Mtetra
.39431 .38925 .39661 .39167 .40047 .39036 .39816 .38793 Mtetra
.39816 .38793 .40047 .39036 .40432 .38904 .40202 .38662 Mtetra
.40202 .38662 .40432 .38904 .40819 .38773 .40589 .3853 Mtetra
.40589 .3853 .40819 .38773 .41206 .38642 .40976 .38398 Mtetra
.40976 .38398 .41206 .38642 .41577 .38993 .41364 .38266 Mtetra
.285 .304 .705 r
.41364 .38266 .41577 .38993 .41965 .38862 .41736 .38618 Mtetra
.663 .742 .908 r
.41736 .38618 .41965 .38862 .42355 .3873 .42126 .38486 Mtetra
.42126 .38486 .42355 .3873 .42744 .38598 .42516 .38353 Mtetra
.42516 .38353 .42744 .38598 .43135 .38465 .42907 .3822 Mtetra
.42907 .3822 .43135 .38465 .43526 .38333 .43298 .38088 Mtetra
.43298 .38088 .43526 .38333 .43917 .382 .4369 .37955 Mtetra
.4369 .37955 .43917 .382 .44309 .38067 .44082 .37821 Mtetra
.44082 .37821 .44309 .38067 .44702 .37934 .44475 .37688 Mtetra
.44475 .37688 .44702 .37934 .45095 .37801 .44868 .37554 Mtetra
.44868 .37554 .45095 .37801 .45488 .37667 .45263 .3742 Mtetra
.45263 .3742 .45488 .37667 .45883 .37534 .45657 .37286 Mtetra
.45657 .37286 .45883 .37534 .46277 .374 .46052 .37152 Mtetra
.962 .676 .444 r
.46052 .37152 .46277 .374 .46471 .48336 .46239 .48095 Mtetra
.655 .752 .922 r
.46239 .48095 .46471 .48336 .46881 .48205 .46649 .47964 Mtetra
.46649 .47964 .46881 .48205 .47291 .48074 .47059 .47833 Mtetra
.47059 .47833 .47291 .48074 .47702 .47944 .4747 .47701 Mtetra
.4747 .47701 .47702 .47944 .48113 .47812 .47882 .4757 Mtetra
.47882 .4757 .48113 .47812 .48525 .47681 .48295 .47438 Mtetra
.48295 .47438 .48525 .47681 .48938 .47549 .48708 .47306 Mtetra
.48708 .47306 .48938 .47549 .49351 .47418 .49121 .47174 Mtetra
.49121 .47174 .49351 .47418 .49765 .47286 .49536 .47041 Mtetra
.49536 .47041 .49765 .47286 .5018 .47153 .49951 .46909 Mtetra
.49951 .46909 .5018 .47153 .50595 .47021 .50366 .46776 Mtetra
.50366 .46776 .50595 .47021 .51011 .46889 .50783 .46643 Mtetra
.50783 .46643 .51011 .46889 .51427 .46756 .51199 .4651 Mtetra
.51199 .4651 .51427 .46756 .51844 .46623 .51617 .46377 Mtetra
.51617 .46377 .51844 .46623 .52262 .4649 .52035 .46243 Mtetra
.52035 .46243 .52262 .4649 .52681 .46356 .52454 .46109 Mtetra
.52454 .46109 .52681 .46356 .53099 .46223 .52873 .45975 Mtetra
.52873 .45975 .53099 .46223 .53519 .46089 .53293 .45841 Mtetra
.53293 .45841 .53519 .46089 .53939 .45955 .53714 .45707 Mtetra
.53714 .45707 .53939 .45955 .5436 .45821 .54135 .45572 Mtetra
.54135 .45572 .5436 .45821 .54782 .45686 .54557 .45438 Mtetra
.54557 .45438 .54782 .45686 .55204 .45552 .5498 .45303 Mtetra
.5498 .45303 .55204 .45552 .55627 .45417 .55403 .45167 Mtetra
.55403 .45167 .55627 .45417 .5605 .45282 .55827 .45032 Mtetra
.55827 .45032 .5605 .45282 .56474 .45147 .56252 .44896 Mtetra
.56252 .44896 .56474 .45147 .56899 .45011 .56677 .4476 Mtetra
.56677 .4476 .56899 .45011 .57325 .44875 .57103 .44624 Mtetra
.57103 .44624 .57325 .44875 .57751 .4474 .57529 .44488 Mtetra
.57529 .44488 .57751 .4474 .58178 .44604 .57956 .44352 Mtetra
.57956 .44352 .58178 .44604 .58605 .44467 .58384 .44215 Mtetra
.58384 .44215 .58605 .44467 .59033 .44331 .58813 .44078 Mtetra
.58813 .44078 .59033 .44331 .59462 .44194 .59242 .43941 Mtetra
.59242 .43941 .59462 .44194 .59891 .44057 .59672 .43804 Mtetra
.972 .698 .452 r
.59672 .43804 .59891 .44057 .60041 .32239 .59829 .31978 Mtetra
.664 .741 .908 r
.59829 .31978 .60041 .32239 .60456 .32098 .60245 .31836 Mtetra
.60245 .31836 .60456 .32098 .60871 .31956 .60661 .31695 Mtetra
.60661 .31695 .60871 .31956 .61288 .31815 .61077 .31553 Mtetra
.61077 .31553 .61288 .31815 .61705 .31673 .61495 .31411 Mtetra
.61495 .31411 .61705 .31673 .62122 .31531 .61913 .31268 Mtetra
.61913 .31268 .62122 .31531 .6254 .31389 .62331 .31126 Mtetra
.62331 .31126 .6254 .31389 .62959 .31247 .6275 .30983 Mtetra
.6275 .30983 .62959 .31247 .63379 .31104 .6317 .3084 Mtetra
.6317 .3084 .63379 .31104 .63799 .30961 .63591 .30697 Mtetra
.63591 .30697 .63799 .30961 .64219 .30818 .64012 .30554 Mtetra
.64012 .30554 .64219 .30818 .64641 .30675 .64434 .3041 Mtetra
.64434 .3041 .64641 .30675 .65063 .30531 .64856 .30266 Mtetra
.64856 .30266 .65063 .30531 .65485 .30388 .65279 .30122 Mtetra
.65279 .30122 .65485 .30388 .65908 .30244 .65703 .29978 Mtetra
.65703 .29978 .65908 .30244 .66332 .301 .66127 .29833 Mtetra
.66127 .29833 .66332 .301 .66757 .29956 .66552 .29689 Mtetra
.66552 .29689 .66757 .29956 .67182 .29811 .66977 .29544 Mtetra
.66977 .29544 .67182 .29811 .67608 .29666 .67404 .29399 Mtetra
.94 .577 .193 r
.67404 .29399 .67608 .29666 .68034 .29521 .67953 .31736 Mtetra
.508 .249 .457 r
.67953 .31736 .68034 .29521 .68588 .31859 .68384 .31591 Mtetra
.662 .744 .911 r
.68384 .31591 .68588 .31859 .69019 .31714 .68815 .31446 Mtetra
.68815 .31446 .69019 .31714 .69451 .31569 .69248 .31301 Mtetra
.69248 .31301 .69451 .31569 .69884 .31424 .69681 .31156 Mtetra
.69681 .31156 .69884 .31424 .70317 .31279 .70114 .3101 Mtetra
.70114 .3101 .70317 .31279 .70751 .31133 .70549 .30864 Mtetra
.70549 .30864 .70751 .31133 .71185 .30987 .70984 .30718 Mtetra
.70984 .30718 .71185 .30987 .71621 .30841 .71419 .30571 Mtetra
.71419 .30571 .71621 .30841 .72056 .30695 .71856 .30425 Mtetra
.71856 .30425 .72056 .30695 .72493 .30549 .72293 .30278 Mtetra
.72293 .30278 .72493 .30549 .7293 .30402 .7273 .30131 Mtetra
.7273 .30131 .7293 .30402 .73368 .30255 .73169 .29983 Mtetra
.73169 .29983 .73368 .30255 .73806 .30108 .73607 .29836 Mtetra
.73607 .29836 .73806 .30108 .74246 .29961 .74047 .29688 Mtetra
.74047 .29688 .74246 .29961 .74685 .29813 .74488 .2954 Mtetra
.74488 .2954 .74685 .29813 .75126 .29665 .74929 .29392 Mtetra
.74929 .29392 .75126 .29665 .75567 .29517 .7537 .29243 Mtetra
.97 .651 .306 r
.7537 .29243 .75567 .29517 .76834 .40302 .76632 .40035 Mtetra
.654 .754 .923 r
.76632 .40035 .76834 .40302 .77293 .40157 .77091 .39889 Mtetra
.77091 .39889 .77293 .40157 .77753 .40012 .77551 .39744 Mtetra
.77551 .39744 .77753 .40012 .78213 .39867 .78012 .39598 Mtetra
.78012 .39598 .78213 .39867 .78674 .39721 .78474 .39452 Mtetra
.78474 .39452 .78674 .39721 .79136 .39575 .78936 .39305 Mtetra
.78936 .39305 .79136 .39575 .79598 .39429 .79399 .39159 Mtetra
.79399 .39159 .79598 .39429 .80061 .39283 .79863 .39012 Mtetra
.79863 .39012 .80061 .39283 .80525 .39136 .80327 .38865 Mtetra
.80327 .38865 .80525 .39136 .8099 .38989 .80793 .38718 Mtetra
.80793 .38718 .8099 .38989 .81455 .38842 .81259 .3857 Mtetra
.81259 .3857 .81455 .38842 .81922 .38695 .81725 .38422 Mtetra
.81725 .38422 .81922 .38695 .82389 .38547 .82193 .38274 Mtetra
.82193 .38274 .82389 .38547 .82856 .384 .82661 .38126 Mtetra
.82661 .38126 .82856 .384 .83325 .38252 .8313 .37978 Mtetra
.8313 .37978 .83325 .38252 .83794 .38103 .836 .37829 Mtetra
.836 .37829 .83794 .38103 .84264 .37955 .8407 .3768 Mtetra
.8407 .3768 .84264 .37955 .84735 .37806 .84542 .37531 Mtetra
.84542 .37531 .84735 .37806 .85206 .37657 .85014 .37381 Mtetra
.85014 .37381 .85206 .37657 .85679 .37508 .85486 .37232 Mtetra
.648 .76 .931 r
.21388 .63331 .2165 .63547 .22033 .6343 .21771 .63214 Mtetra
.21771 .63214 .22033 .6343 .22416 .63313 .22155 .63097 Mtetra
.22155 .63097 .22416 .63313 .228 .63196 .22539 .62979 Mtetra
.22539 .62979 .228 .63196 .23185 .63079 .22924 .62862 Mtetra
.22924 .62862 .23185 .63079 .2357 .62961 .2331 .62744 Mtetra
.2331 .62744 .2357 .62961 .23956 .62844 .23696 .62626 Mtetra
.23696 .62626 .23956 .62844 .24342 .62726 .24082 .62508 Mtetra
.24082 .62508 .24342 .62726 .24729 .62608 .24469 .6239 Mtetra
.24469 .6239 .24729 .62608 .25116 .6249 .24857 .62272 Mtetra
.24857 .62272 .25116 .6249 .25504 .62372 .25246 .62153 Mtetra
.25246 .62153 .25504 .62372 .25893 .62253 .25635 .62034 Mtetra
.25635 .62034 .25893 .62253 .26282 .62135 .26024 .61915 Mtetra
.26024 .61915 .26282 .62135 .26672 .62016 .26414 .61796 Mtetra
.26414 .61796 .26672 .62016 .27062 .61897 .26805 .61677 Mtetra
.26805 .61677 .27062 .61897 .27453 .61778 .27196 .61557 Mtetra
.27196 .61557 .27453 .61778 .27844 .61659 .27588 .61438 Mtetra
.27588 .61438 .27844 .61659 .28237 .61539 .2798 .61318 Mtetra
.942 .691 .529 r
.2798 .61318 .28237 .61539 .29833 .44074 .29592 .43841 Mtetra
.662 .743 .91 r
.29592 .43841 .29833 .44074 .30208 .43947 .29967 .43714 Mtetra
.29967 .43714 .30208 .43947 .30582 .43821 .30342 .43588 Mtetra
.30342 .43588 .30582 .43821 .30958 .43695 .30717 .43461 Mtetra
.30717 .43461 .30958 .43695 .31334 .43568 .31094 .43334 Mtetra
.31094 .43334 .31334 .43568 .3171 .43441 .3147 .43207 Mtetra
.3147 .43207 .3171 .43441 .32087 .43314 .31848 .43079 Mtetra
.31848 .43079 .32087 .43314 .32464 .43187 .32225 .42952 Mtetra
.32225 .42952 .32464 .43187 .32842 .4306 .32604 .42824 Mtetra
.32604 .42824 .32842 .4306 .33221 .42932 .32983 .42696 Mtetra
.32983 .42696 .33221 .42932 .336 .42804 .33362 .42568 Mtetra
.33362 .42568 .336 .42804 .3398 .42676 .33742 .4244 Mtetra
.33742 .4244 .3398 .42676 .3436 .42548 .34122 .42311 Mtetra
.34122 .42311 .3436 .42548 .3474 .4242 .34503 .42183 Mtetra
.34503 .42183 .3474 .4242 .35122 .42292 .34885 .42054 Mtetra
.34885 .42054 .35122 .42292 .35503 .42163 .35267 .41925 Mtetra
.35267 .41925 .35503 .42163 .35886 .42034 .3565 .41796 Mtetra
.3565 .41796 .35886 .42034 .36269 .41905 .36033 .41666 Mtetra
.36033 .41666 .36269 .41905 .36652 .41776 .36417 .41537 Mtetra
.36417 .41537 .36652 .41776 .37036 .41646 .36801 .41407 Mtetra
.36801 .41407 .37036 .41646 .37421 .41517 .37186 .41277 Mtetra
.934 .727 .599 r
.37186 .41277 .37421 .41517 .37894 .39448 .37661 .39207 Mtetra
.664 .741 .908 r
.37661 .39207 .37894 .39448 .38277 .39317 .38045 .39076 Mtetra
.38045 .39076 .38277 .39317 .38661 .39187 .38429 .38945 Mtetra
.38429 .38945 .38661 .39187 .39046 .39056 .38814 .38814 Mtetra
.38814 .38814 .39046 .39056 .39431 .38925 .39199 .38682 Mtetra
.39199 .38682 .39431 .38925 .39816 .38793 .39585 .3855 Mtetra
.39585 .3855 .39816 .38793 .40202 .38662 .39972 .38419 Mtetra
.39972 .38419 .40202 .38662 .40589 .3853 .40359 .38286 Mtetra
.40359 .38286 .40589 .3853 .40976 .38398 .40746 .38154 Mtetra
.40746 .38154 .40976 .38398 .41364 .38266 .41135 .38022 Mtetra
.41135 .38022 .41364 .38266 .41736 .38618 .41523 .37889 Mtetra
.618 .515 .715 r
.41523 .37889 .41736 .38618 .42126 .38486 .41913 .37756 Mtetra
.286 .305 .705 r
.41913 .37756 .42126 .38486 .42516 .38353 .42287 .38108 Mtetra
.663 .742 .908 r
.42287 .38108 .42516 .38353 .42907 .3822 .42678 .37975 Mtetra
.42678 .37975 .42907 .3822 .43298 .38088 .4307 .37842 Mtetra
.4307 .37842 .43298 .38088 .4369 .37955 .43462 .37708 Mtetra
.43462 .37708 .4369 .37955 .44082 .37821 .43854 .37575 Mtetra
.43854 .37575 .44082 .37821 .44475 .37688 .44248 .37441 Mtetra
.44248 .37441 .44475 .37688 .44868 .37554 .44642 .37307 Mtetra
.44642 .37307 .44868 .37554 .45263 .3742 .45036 .37173 Mtetra
.45036 .37173 .45263 .3742 .45657 .37286 .45431 .37038 Mtetra
.45431 .37038 .45657 .37286 .46052 .37152 .45827 .36904 Mtetra
.962 .676 .444 r
.45827 .36904 .46052 .37152 .46239 .48095 .46005 .47853 Mtetra
.655 .752 .922 r
.46005 .47853 .46239 .48095 .46649 .47964 .46415 .47721 Mtetra
.46415 .47721 .46649 .47964 .47059 .47833 .46826 .4759 Mtetra
.46826 .4759 .47059 .47833 .4747 .47701 .47238 .47458 Mtetra
.47238 .47458 .4747 .47701 .47882 .4757 .4765 .47326 Mtetra
.4765 .47326 .47882 .4757 .48295 .47438 .48063 .47194 Mtetra
.48063 .47194 .48295 .47438 .48708 .47306 .48477 .47062 Mtetra
.48477 .47062 .48708 .47306 .49121 .47174 .48891 .46929 Mtetra
.48891 .46929 .49121 .47174 .49536 .47041 .49305 .46797 Mtetra
.49305 .46797 .49536 .47041 .49951 .46909 .49721 .46664 Mtetra
.49721 .46664 .49951 .46909 .50366 .46776 .50137 .46531 Mtetra
.50137 .46531 .50366 .46776 .50783 .46643 .50553 .46397 Mtetra
.96 .719 .531 r
.50553 .46397 .50783 .46643 .51199 .4651 .50988 .42639 Mtetra
.56 .364 .571 r
.50988 .42639 .51199 .4651 .51617 .46377 .51401 .42504 Mtetra
.51401 .42504 .51617 .46377 .52035 .46243 .51815 .42369 Mtetra
0 0 .429 r
.51815 .42369 .52035 .46243 .52454 .46109 .52226 .45862 Mtetra
.655 .752 .922 r
.52226 .45862 .52454 .46109 .52873 .45975 .52646 .45728 Mtetra
.52646 .45728 .52873 .45975 .53293 .45841 .53067 .45593 Mtetra
.53067 .45593 .53293 .45841 .53714 .45707 .53488 .45458 Mtetra
.53488 .45458 .53714 .45707 .54135 .45572 .5391 .45323 Mtetra
.5391 .45323 .54135 .45572 .54557 .45438 .54332 .45188 Mtetra
.54332 .45188 .54557 .45438 .5498 .45303 .54755 .45053 Mtetra
.54755 .45053 .5498 .45303 .55403 .45167 .55179 .44917 Mtetra
.55179 .44917 .55403 .45167 .55827 .45032 .55603 .44781 Mtetra
.55603 .44781 .55827 .45032 .56252 .44896 .56028 .44645 Mtetra
.56028 .44645 .56252 .44896 .56677 .4476 .56454 .44509 Mtetra
.56454 .44509 .56677 .4476 .57103 .44624 .5688 .44373 Mtetra
.5688 .44373 .57103 .44624 .57529 .44488 .57307 .44236 Mtetra
.57307 .44236 .57529 .44488 .57956 .44352 .57735 .44099 Mtetra
.57735 .44099 .57956 .44352 .58384 .44215 .58163 .43962 Mtetra
.58163 .43962 .58384 .44215 .58813 .44078 .58592 .43825 Mtetra
.58592 .43825 .58813 .44078 .59242 .43941 .59021 .43688 Mtetra
.59021 .43688 .59242 .43941 .59672 .43804 .59452 .4355 Mtetra
.972 .698 .452 r
.59452 .4355 .59672 .43804 .59829 .31978 .59617 .31717 Mtetra
.664 .741 .908 r
.59617 .31717 .59829 .31978 .60245 .31836 .60033 .31575 Mtetra
.60033 .31575 .60245 .31836 .60661 .31695 .60449 .31433 Mtetra
.60449 .31433 .60661 .31695 .61077 .31553 .60867 .3129 Mtetra
.60867 .3129 .61077 .31553 .61495 .31411 .61284 .31148 Mtetra
.61284 .31148 .61495 .31411 .61913 .31268 .61703 .31005 Mtetra
.61703 .31005 .61913 .31268 .62331 .31126 .62122 .30862 Mtetra
.62122 .30862 .62331 .31126 .6275 .30983 .62541 .30719 Mtetra
.62541 .30719 .6275 .30983 .6317 .3084 .62962 .30576 Mtetra
.62962 .30576 .6317 .3084 .63591 .30697 .63382 .30432 Mtetra
.63382 .30432 .63591 .30697 .64012 .30554 .63804 .30288 Mtetra
.63804 .30288 .64012 .30554 .64434 .3041 .64226 .30144 Mtetra
.64226 .30144 .64434 .3041 .64856 .30266 .64649 .3 Mtetra
.64649 .3 .64856 .30266 .65279 .30122 .65072 .29856 Mtetra
.65072 .29856 .65279 .30122 .65703 .29978 .65497 .29711 Mtetra
.65497 .29711 .65703 .29978 .66127 .29833 .65921 .29566 Mtetra
.65921 .29566 .66127 .29833 .66552 .29689 .66347 .29421 Mtetra
.66347 .29421 .66552 .29689 .66977 .29544 .66773 .29276 Mtetra
.66773 .29276 .66977 .29544 .67404 .29399 .67199 .2913 Mtetra
.94 .577 .193 r
.67199 .2913 .67404 .29399 .67953 .31736 .67747 .31469 Mtetra
.662 .744 .911 r
.67747 .31469 .67953 .31736 .68384 .31591 .68179 .31323 Mtetra
.68179 .31323 .68384 .31591 .68815 .31446 .68611 .31178 Mtetra
.68611 .31178 .68815 .31446 .69248 .31301 .69044 .31032 Mtetra
.69044 .31032 .69248 .31301 .69681 .31156 .69477 .30886 Mtetra
.69477 .30886 .69681 .31156 .70114 .3101 .69911 .3074 Mtetra
.69911 .3074 .70114 .3101 .70549 .30864 .70346 .30594 Mtetra
.70346 .30594 .70549 .30864 .70984 .30718 .70781 .30447 Mtetra
.70781 .30447 .70984 .30718 .71419 .30571 .71217 .303 Mtetra
.71217 .303 .71419 .30571 .71856 .30425 .71654 .30153 Mtetra
.71654 .30153 .71856 .30425 .72293 .30278 .72092 .30006 Mtetra
.72092 .30006 .72293 .30278 .7273 .30131 .7253 .29859 Mtetra
.7253 .29859 .7273 .30131 .73169 .29983 .72969 .29711 Mtetra
.72969 .29711 .73169 .29983 .73607 .29836 .73408 .29563 Mtetra
.73408 .29563 .73607 .29836 .74047 .29688 .73848 .29415 Mtetra
.73848 .29415 .74047 .29688 .74488 .2954 .74289 .29266 Mtetra
.74289 .29266 .74488 .2954 .74929 .29392 .7473 .29118 Mtetra
.97 .651 .309 r
.7473 .29118 .74929 .29392 .7537 .29243 .7597 .39912 Mtetra
.536 .307 .515 r
.7597 .39912 .7537 .29243 .76632 .40035 .76429 .39766 Mtetra
.654 .754 .923 r
.76429 .39766 .76632 .40035 .77091 .39889 .76889 .3962 Mtetra
.76889 .3962 .77091 .39889 .77551 .39744 .7735 .39474 Mtetra
.7735 .39474 .77551 .39744 .78012 .39598 .77811 .39328 Mtetra
.77811 .39328 .78012 .39598 .78474 .39452 .78273 .39181 Mtetra
.78273 .39181 .78474 .39452 .78936 .39305 .78736 .39035 Mtetra
.78736 .39035 .78936 .39305 .79399 .39159 .79199 .38888 Mtetra
.79199 .38888 .79399 .39159 .79863 .39012 .79664 .3874 Mtetra
.79664 .3874 .79863 .39012 .80327 .38865 .80129 .38593 Mtetra
.80129 .38593 .80327 .38865 .80793 .38718 .80594 .38445 Mtetra
.80594 .38445 .80793 .38718 .81259 .3857 .81061 .38297 Mtetra
.81061 .38297 .81259 .3857 .81725 .38422 .81528 .38149 Mtetra
.81528 .38149 .81725 .38422 .82193 .38274 .81996 .38001 Mtetra
.81996 .38001 .82193 .38274 .82661 .38126 .82465 .37852 Mtetra
.82465 .37852 .82661 .38126 .8313 .37978 .82935 .37703 Mtetra
.82935 .37703 .8313 .37978 .836 .37829 .83405 .37554 Mtetra
.83405 .37554 .836 .37829 .8407 .3768 .83876 .37404 Mtetra
.83876 .37404 .8407 .3768 .84542 .37531 .84348 .37255 Mtetra
.84348 .37255 .84542 .37531 .85014 .37381 .8482 .37105 Mtetra
.8482 .37105 .85014 .37381 .85486 .37232 .85294 .36955 Mtetra
.648 .76 .931 r
.21125 .63115 .21388 .63331 .21771 .63214 .21509 .62998 Mtetra
.21509 .62998 .21771 .63214 .22155 .63097 .21893 .6288 Mtetra
.21893 .6288 .22155 .63097 .22539 .62979 .22278 .62762 Mtetra
.22278 .62762 .22539 .62979 .22924 .62862 .22663 .62645 Mtetra
.22663 .62645 .22924 .62862 .2331 .62744 .23049 .62526 Mtetra
.23049 .62526 .2331 .62744 .23696 .62626 .23435 .62408 Mtetra
.23435 .62408 .23696 .62626 .24082 .62508 .23822 .6229 Mtetra
.23822 .6229 .24082 .62508 .24469 .6239 .2421 .62171 Mtetra
.2421 .62171 .24469 .6239 .24857 .62272 .24598 .62053 Mtetra
.24598 .62053 .24857 .62272 .25246 .62153 .24986 .61934 Mtetra
.24986 .61934 .25246 .62153 .25635 .62034 .25376 .61815 Mtetra
.25376 .61815 .25635 .62034 .26024 .61915 .25766 .61695 Mtetra
.25766 .61695 .26024 .61915 .26414 .61796 .26156 .61576 Mtetra
.26156 .61576 .26414 .61796 .26805 .61677 .26547 .61456 Mtetra
.26547 .61456 .26805 .61677 .27196 .61557 .26939 .61336 Mtetra
.26939 .61336 .27196 .61557 .27588 .61438 .27331 .61216 Mtetra
.27331 .61216 .27588 .61438 .2798 .61318 .27724 .61096 Mtetra
.942 .691 .529 r
.27724 .61096 .2798 .61318 .29592 .43841 .2935 .43607 Mtetra
.662 .743 .91 r
.2935 .43607 .29592 .43841 .29967 .43714 .29725 .4348 Mtetra
.29725 .4348 .29967 .43714 .30342 .43588 .30101 .43353 Mtetra
.30101 .43353 .30342 .43588 .30717 .43461 .30477 .43226 Mtetra
.30477 .43226 .30717 .43461 .31094 .43334 .30853 .43099 Mtetra
.30853 .43099 .31094 .43334 .3147 .43207 .3123 .42971 Mtetra
.3123 .42971 .3147 .43207 .31848 .43079 .31608 .42844 Mtetra
.31608 .42844 .31848 .43079 .32225 .42952 .31986 .42716 Mtetra
.31986 .42716 .32225 .42952 .32604 .42824 .32364 .42588 Mtetra
.32364 .42588 .32604 .42824 .32983 .42696 .32744 .4246 Mtetra
.32744 .4246 .32983 .42696 .33362 .42568 .33123 .42331 Mtetra
.33123 .42331 .33362 .42568 .33742 .4244 .33504 .42203 Mtetra
.33504 .42203 .33742 .4244 .34122 .42311 .33884 .42074 Mtetra
.33884 .42074 .34122 .42311 .34503 .42183 .34266 .41945 Mtetra
.34266 .41945 .34503 .42183 .34885 .42054 .34648 .41816 Mtetra
.34648 .41816 .34885 .42054 .35267 .41925 .3503 .41686 Mtetra
.3503 .41686 .35267 .41925 .3565 .41796 .35413 .41557 Mtetra
.35413 .41557 .3565 .41796 .36033 .41666 .35797 .41427 Mtetra
.35797 .41427 .36033 .41666 .36417 .41537 .36181 .41297 Mtetra
.36181 .41297 .36417 .41537 .36801 .41407 .36565 .41167 Mtetra
.934 .726 .599 r
.36565 .41167 .36801 .41407 .37186 .41277 .37044 .39096 Mtetra
.572 .392 .598 r
.37044 .39096 .37186 .41277 .37661 .39207 .37428 .38965 Mtetra
.664 .741 .908 r
.37428 .38965 .37661 .39207 .38045 .39076 .37812 .38834 Mtetra
.37812 .38834 .38045 .39076 .38429 .38945 .38196 .38702 Mtetra
.38196 .38702 .38429 .38945 .38814 .38814 .38581 .38571 Mtetra
.38581 .38571 .38814 .38814 .39199 .38682 .38967 .38439 Mtetra
.38967 .38439 .39199 .38682 .39585 .3855 .39353 .38307 Mtetra
.39353 .38307 .39585 .3855 .39972 .38419 .3974 .38175 Mtetra
.3974 .38175 .39972 .38419 .40359 .38286 .40128 .38042 Mtetra
.40128 .38042 .40359 .38286 .40746 .38154 .40516 .3791 Mtetra
.40516 .3791 .40746 .38154 .41135 .38022 .40904 .37777 Mtetra
.40904 .37777 .41135 .38022 .41523 .37889 .41293 .37644 Mtetra
.41293 .37644 .41523 .37889 .41913 .37756 .41683 .37511 Mtetra
.41683 .37511 .41913 .37756 .42287 .38108 .42073 .37377 Mtetra
.286 .305 .705 r
.42073 .37377 .42287 .38108 .42678 .37975 .42449 .37729 Mtetra
.663 .742 .908 r
.42449 .37729 .42678 .37975 .4307 .37842 .42841 .37595 Mtetra
.42841 .37595 .4307 .37842 .43462 .37708 .43233 .37461 Mtetra
.43233 .37461 .43462 .37708 .43854 .37575 .43626 .37328 Mtetra
.43626 .37328 .43854 .37575 .44248 .37441 .4402 .37193 Mtetra
.4402 .37193 .44248 .37441 .44642 .37307 .44414 .37059 Mtetra
.44414 .37059 .44642 .37307 .45036 .37173 .44809 .36924 Mtetra
.44809 .36924 .45036 .37173 .45431 .37038 .45204 .3679 Mtetra
.45204 .3679 .45431 .37038 .45827 .36904 .456 .36655 Mtetra
.962 .676 .444 r
.456 .36655 .45827 .36904 .46005 .47853 .45771 .4761 Mtetra
.655 .752 .922 r
.45771 .4761 .46005 .47853 .46415 .47721 .46182 .47478 Mtetra
.46182 .47478 .46415 .47721 .46826 .4759 .46593 .47347 Mtetra
.46593 .47347 .46826 .4759 .47238 .47458 .47005 .47214 Mtetra
.47005 .47214 .47238 .47458 .4765 .47326 .47418 .47082 Mtetra
.47418 .47082 .4765 .47326 .48063 .47194 .47831 .4695 Mtetra
.47831 .4695 .48063 .47194 .48477 .47062 .48245 .46817 Mtetra
.48245 .46817 .48477 .47062 .48891 .46929 .48659 .46684 Mtetra
.958 .719 .534 r
.48659 .46684 .48891 .46929 .49305 .46797 .49112 .42929 Mtetra
.56 .363 .571 r
.49112 .42929 .49305 .46797 .49721 .46664 .49523 .42795 Mtetra
.49523 .42795 .49721 .46664 .50137 .46531 .49935 .4266 Mtetra
.49935 .4266 .50137 .46531 .50553 .46397 .50348 .42525 Mtetra
.50348 .42525 .50553 .46397 .50988 .42639 .50761 .4239 Mtetra
.658 .749 .917 r
.50761 .4239 .50988 .42639 .51401 .42504 .51174 .42255 Mtetra
.51174 .42255 .51401 .42504 .51815 .42369 .51589 .42119 Mtetra
.962 .639 .352 r
.51589 .42119 .51815 .42369 .52226 .45862 .51998 .45614 Mtetra
.655 .752 .922 r
.51998 .45614 .52226 .45862 .52646 .45728 .52419 .45479 Mtetra
.52419 .45479 .52646 .45728 .53067 .45593 .52839 .45344 Mtetra
.52839 .45344 .53067 .45593 .53488 .45458 .53261 .45209 Mtetra
.53261 .45209 .53488 .45458 .5391 .45323 .53683 .45074 Mtetra
.53683 .45074 .5391 .45323 .54332 .45188 .54106 .44938 Mtetra
.54106 .44938 .54332 .45188 .54755 .45053 .54529 .44802 Mtetra
.54529 .44802 .54755 .45053 .55179 .44917 .54954 .44666 Mtetra
.54954 .44666 .55179 .44917 .55603 .44781 .55378 .4453 Mtetra
.55378 .4453 .55603 .44781 .56028 .44645 .55804 .44394 Mtetra
.55804 .44394 .56028 .44645 .56454 .44509 .5623 .44257 Mtetra
.5623 .44257 .56454 .44509 .5688 .44373 .56657 .4412 Mtetra
.56657 .4412 .5688 .44373 .57307 .44236 .57084 .43983 Mtetra
.57084 .43983 .57307 .44236 .57735 .44099 .57512 .43846 Mtetra
.57512 .43846 .57735 .44099 .58163 .43962 .57941 .43709 Mtetra
.57941 .43709 .58163 .43962 .58592 .43825 .5837 .43571 Mtetra
.5837 .43571 .58592 .43825 .59021 .43688 .588 .43433 Mtetra
.972 .698 .454 r
.588 .43433 .59021 .43688 .59452 .4355 .58989 .31597 Mtetra
.548 .335 .543 r
.58989 .31597 .59452 .4355 .59617 .31717 .59404 .31455 Mtetra
.664 .741 .908 r
.59404 .31455 .59617 .31717 .60033 .31575 .59821 .31312 Mtetra
.59821 .31312 .60033 .31575 .60449 .31433 .60238 .3117 Mtetra
.60238 .3117 .60449 .31433 .60867 .3129 .60655 .31027 Mtetra
.60655 .31027 .60867 .3129 .61284 .31148 .61073 .30884 Mtetra
.61073 .30884 .61284 .31148 .61703 .31005 .61492 .30741 Mtetra
.61492 .30741 .61703 .31005 .62122 .30862 .61911 .30598 Mtetra
.61911 .30598 .62122 .30862 .62541 .30719 .62332 .30454 Mtetra
.62332 .30454 .62541 .30719 .62962 .30576 .62752 .3031 Mtetra
.62752 .3031 .62962 .30576 .63382 .30432 .63174 .30166 Mtetra
.63174 .30166 .63382 .30432 .63804 .30288 .63596 .30022 Mtetra
.63596 .30022 .63804 .30288 .64226 .30144 .64018 .29878 Mtetra
.64018 .29878 .64226 .30144 .64649 .3 .64441 .29733 Mtetra
.64441 .29733 .64649 .3 .65072 .29856 .64865 .29588 Mtetra
.64865 .29588 .65072 .29856 .65497 .29711 .6529 .29443 Mtetra
.6529 .29443 .65497 .29711 .65921 .29566 .65715 .29298 Mtetra
.65715 .29298 .65921 .29566 .66347 .29421 .66141 .29152 Mtetra
.66141 .29152 .66347 .29421 .66773 .29276 .66567 .29007 Mtetra
.941 .578 .197 r
.66567 .29007 .66773 .29276 .67199 .2913 .6711 .31346 Mtetra
.507 .247 .455 r
.6711 .31346 .67199 .2913 .67747 .31469 .67541 .312 Mtetra
.662 .744 .911 r
.67541 .312 .67747 .31469 .68179 .31323 .67973 .31055 Mtetra
.67973 .31055 .68179 .31323 .68611 .31178 .68406 .30909 Mtetra
.68406 .30909 .68611 .31178 .69044 .31032 .68839 .30763 Mtetra
.68839 .30763 .69044 .31032 .69477 .30886 .69273 .30616 Mtetra
.69273 .30616 .69477 .30886 .69911 .3074 .69707 .3047 Mtetra
.69707 .3047 .69911 .3074 .70346 .30594 .70143 .30323 Mtetra
.70143 .30323 .70346 .30594 .70781 .30447 .70579 .30176 Mtetra
.70579 .30176 .70781 .30447 .71217 .303 .71015 .30029 Mtetra
.71015 .30029 .71217 .303 .71654 .30153 .71452 .29881 Mtetra
.71452 .29881 .71654 .30153 .72092 .30006 .7189 .29734 Mtetra
.7189 .29734 .72092 .30006 .7253 .29859 .72329 .29586 Mtetra
.72329 .29586 .7253 .29859 .72969 .29711 .72768 .29437 Mtetra
.72768 .29437 .72969 .29711 .73408 .29563 .73208 .29289 Mtetra
.73208 .29289 .73408 .29563 .73848 .29415 .73649 .2914 Mtetra
.73649 .2914 .73848 .29415 .74289 .29266 .7409 .28992 Mtetra
.7409 .28992 .74289 .29266 .7473 .29118 .74532 .28843 Mtetra
.97 .651 .309 r
.74532 .28843 .7473 .29118 .7597 .39912 .75766 .39643 Mtetra
.654 .754 .923 r
.75766 .39643 .7597 .39912 .76429 .39766 .76226 .39497 Mtetra
.76226 .39497 .76429 .39766 .76889 .3962 .76686 .3935 Mtetra
.76686 .3935 .76889 .3962 .7735 .39474 .77147 .39204 Mtetra
.77147 .39204 .7735 .39474 .77811 .39328 .77609 .39057 Mtetra
.77609 .39057 .77811 .39328 .78273 .39181 .78072 .3891 Mtetra
.78072 .3891 .78273 .39181 .78736 .39035 .78535 .38763 Mtetra
.78535 .38763 .78736 .39035 .79199 .38888 .78999 .38616 Mtetra
.78999 .38616 .79199 .38888 .79664 .3874 .79464 .38468 Mtetra
.79464 .38468 .79664 .3874 .80129 .38593 .79929 .3832 Mtetra
.79929 .3832 .80129 .38593 .80594 .38445 .80396 .38172 Mtetra
.80396 .38172 .80594 .38445 .81061 .38297 .80863 .38023 Mtetra
.80863 .38023 .81061 .38297 .81528 .38149 .81331 .37875 Mtetra
.81331 .37875 .81528 .38149 .81996 .38001 .81799 .37726 Mtetra
.81799 .37726 .81996 .38001 .82465 .37852 .82269 .37577 Mtetra
.82269 .37577 .82465 .37852 .82935 .37703 .82739 .37427 Mtetra
.82739 .37427 .82935 .37703 .83405 .37554 .83209 .37278 Mtetra
.83209 .37278 .83405 .37554 .83876 .37404 .83681 .37128 Mtetra
.83681 .37128 .83876 .37404 .84348 .37255 .84153 .36978 Mtetra
.84153 .36978 .84348 .37255 .8482 .37105 .84627 .36828 Mtetra
.84627 .36828 .8482 .37105 .85294 .36955 .85101 .36677 Mtetra
.648 .76 .931 r
.20862 .62898 .21125 .63115 .21509 .62998 .21246 .6278 Mtetra
.21246 .6278 .21509 .62998 .21893 .6288 .2163 .62663 Mtetra
.2163 .62663 .21893 .6288 .22278 .62762 .22015 .62545 Mtetra
.22015 .62545 .22278 .62762 .22663 .62645 .22401 .62426 Mtetra
.22401 .62426 .22663 .62645 .23049 .62526 .22787 .62308 Mtetra
.22787 .62308 .23049 .62526 .23435 .62408 .23174 .6219 Mtetra
.23174 .6219 .23435 .62408 .23822 .6229 .23561 .62071 Mtetra
.23561 .62071 .23822 .6229 .2421 .62171 .23949 .61952 Mtetra
.23949 .61952 .2421 .62171 .24598 .62053 .24337 .61833 Mtetra
.24337 .61833 .24598 .62053 .24986 .61934 .24726 .61714 Mtetra
.24726 .61714 .24986 .61934 .25376 .61815 .25116 .61594 Mtetra
.25116 .61594 .25376 .61815 .25766 .61695 .25506 .61475 Mtetra
.25506 .61475 .25766 .61695 .26156 .61576 .25897 .61355 Mtetra
.25897 .61355 .26156 .61576 .26547 .61456 .26288 .61235 Mtetra
.26288 .61235 .26547 .61456 .26939 .61336 .2668 .61115 Mtetra
.937 .705 .561 r
.2668 .61115 .26939 .61336 .27331 .61216 .27426 .56219 Mtetra
.555 .353 .561 r
.27426 .56219 .27331 .61216 .27724 .61096 .27814 .56097 Mtetra
.867 .615 .555 r
.27814 .56097 .27724 .61096 .2935 .43607 .29246 .41443 Mtetra
.572 .391 .598 r
.29246 .41443 .2935 .43607 .29725 .4348 .29619 .41316 Mtetra
.29619 .41316 .29725 .4348 .30101 .43353 .29993 .41188 Mtetra
.29993 .41188 .30101 .43353 .30477 .43226 .30367 .4106 Mtetra
.30367 .4106 .30477 .43226 .30853 .43099 .30742 .40931 Mtetra
.30742 .40931 .30853 .43099 .3123 .42971 .31117 .40803 Mtetra
.31117 .40803 .3123 .42971 .31608 .42844 .31493 .40674 Mtetra
0 0 .416 r
.31493 .40674 .31608 .42844 .31986 .42716 .31745 .42479 Mtetra
.662 .743 .91 r
.31745 .42479 .31986 .42716 .32364 .42588 .32124 .42351 Mtetra
.32124 .42351 .32364 .42588 .32744 .4246 .32504 .42222 Mtetra
.32504 .42222 .32744 .4246 .33123 .42331 .32884 .42094 Mtetra
.32884 .42094 .33123 .42331 .33504 .42203 .33265 .41965 Mtetra
.33265 .41965 .33504 .42203 .33884 .42074 .33646 .41836 Mtetra
.33646 .41836 .33884 .42074 .34266 .41945 .34027 .41706 Mtetra
.34027 .41706 .34266 .41945 .34648 .41816 .3441 .41577 Mtetra
.3441 .41577 .34648 .41816 .3503 .41686 .34793 .41447 Mtetra
.34793 .41447 .3503 .41686 .35413 .41557 .35176 .41317 Mtetra
.35176 .41317 .35413 .41557 .35797 .41427 .3556 .41187 Mtetra
.3556 .41187 .35797 .41427 .36181 .41297 .35944 .41057 Mtetra
.933 .726 .6 r
.35944 .41057 .36181 .41297 .36565 .41167 .36426 .38985 Mtetra
.572 .391 .598 r
.36426 .38985 .36565 .41167 .37044 .39096 .3681 .38854 Mtetra
.664 .741 .908 r
.3681 .38854 .37044 .39096 .37428 .38965 .37194 .38723 Mtetra
.37194 .38723 .37428 .38965 .37812 .38834 .37578 .38591 Mtetra
.37578 .38591 .37812 .38834 .38196 .38702 .37963 .38459 Mtetra
.37963 .38459 .38196 .38702 .38581 .38571 .38348 .38327 Mtetra
.38348 .38327 .38581 .38571 .38967 .38439 .38735 .38195 Mtetra
.38735 .38195 .38967 .38439 .39353 .38307 .39121 .38063 Mtetra
.39121 .38063 .39353 .38307 .3974 .38175 .39508 .3793 Mtetra
.39508 .3793 .3974 .38175 .40128 .38042 .39896 .37797 Mtetra
.39896 .37797 .40128 .38042 .40516 .3791 .40284 .37664 Mtetra
.40284 .37664 .40516 .3791 .40904 .37777 .40673 .37531 Mtetra
.40673 .37531 .40904 .37777 .41293 .37644 .41063 .37398 Mtetra
.41063 .37398 .41293 .37644 .41683 .37511 .41453 .37264 Mtetra
.41453 .37264 .41683 .37511 .42073 .37377 .41843 .37131 Mtetra
.41843 .37131 .42073 .37377 .42449 .37729 .42235 .36997 Mtetra
.618 .515 .715 r
.42235 .36997 .42449 .37729 .42841 .37595 .42626 .36863 Mtetra
.287 .305 .705 r
.42626 .36863 .42841 .37595 .43233 .37461 .43004 .37214 Mtetra
.663 .742 .908 r
.43004 .37214 .43233 .37461 .43626 .37328 .43398 .3708 Mtetra
.43398 .3708 .43626 .37328 .4402 .37193 .43792 .36945 Mtetra
.43792 .36945 .4402 .37193 .44414 .37059 .44186 .3681 Mtetra
.44186 .3681 .44414 .37059 .44809 .36924 .44581 .36675 Mtetra
.44581 .36675 .44809 .36924 .45204 .3679 .44977 .3654 Mtetra
.44977 .3654 .45204 .3679 .456 .36655 .45373 .36405 Mtetra
.962 .676 .444 r
.45373 .36405 .456 .36655 .45771 .4761 .45536 .47367 Mtetra
.655 .752 .922 r
.45536 .47367 .45771 .4761 .46182 .47478 .45947 .47235 Mtetra
.45947 .47235 .46182 .47478 .46593 .47347 .46359 .47103 Mtetra
.46359 .47103 .46593 .47347 .47005 .47214 .46772 .4697 Mtetra
.956 .718 .538 r
.46772 .4697 .47005 .47214 .47418 .47082 .47243 .43218 Mtetra
.559 .362 .57 r
.47243 .43218 .47418 .47082 .47831 .4695 .47652 .43084 Mtetra
.47652 .43084 .47831 .4695 .48245 .46817 .48062 .4295 Mtetra
.48062 .4295 .48245 .46817 .48659 .46684 .48472 .42816 Mtetra
.48472 .42816 .48659 .46684 .49112 .42929 .48883 .42681 Mtetra
.658 .749 .917 r
.48883 .42681 .49112 .42929 .49523 .42795 .49295 .42546 Mtetra
.49295 .42546 .49523 .42795 .49935 .4266 .49707 .42411 Mtetra
.49707 .42411 .49935 .4266 .50348 .42525 .5012 .42275 Mtetra
.5012 .42275 .50348 .42525 .50761 .4239 .50533 .4214 Mtetra
.50533 .4214 .50761 .4239 .51174 .42255 .50948 .42004 Mtetra
.50948 .42004 .51174 .42255 .51589 .42119 .51362 .41868 Mtetra
.51362 .41868 .51589 .42119 .51998 .45614 .51778 .41732 Mtetra
0 0 .428 r
.51778 .41732 .51998 .45614 .52419 .45479 .5219 .4523 Mtetra
.655 .752 .922 r
.5219 .4523 .52419 .45479 .52839 .45344 .52612 .45094 Mtetra
.52612 .45094 .52839 .45344 .53261 .45209 .53034 .44959 Mtetra
.53034 .44959 .53261 .45209 .53683 .45074 .53456 .44823 Mtetra
.53456 .44823 .53683 .45074 .54106 .44938 .53879 .44687 Mtetra
.53879 .44687 .54106 .44938 .54529 .44802 .54303 .44551 Mtetra
.54303 .44551 .54529 .44802 .54954 .44666 .54728 .44415 Mtetra
.54728 .44415 .54954 .44666 .55378 .4453 .55153 .44278 Mtetra
.55153 .44278 .55378 .4453 .55804 .44394 .55579 .44141 Mtetra
.55579 .44141 .55804 .44394 .5623 .44257 .56005 .44004 Mtetra
.56005 .44004 .5623 .44257 .56657 .4412 .56433 .43867 Mtetra
.56433 .43867 .56657 .4412 .57084 .43983 .5686 .4373 Mtetra
.5686 .4373 .57084 .43983 .57512 .43846 .57289 .43592 Mtetra
.57289 .43592 .57512 .43846 .57941 .43709 .57718 .43454 Mtetra
.57718 .43454 .57941 .43709 .5837 .43571 .58148 .43316 Mtetra
.58148 .43316 .5837 .43571 .588 .43433 .58578 .43178 Mtetra
.972 .698 .454 r
.58578 .43178 .588 .43433 .58989 .31597 .58775 .31334 Mtetra
.664 .741 .908 r
.58775 .31334 .58989 .31597 .59404 .31455 .59191 .31192 Mtetra
.59191 .31192 .59404 .31455 .59821 .31312 .59608 .31049 Mtetra
.59608 .31049 .59821 .31312 .60238 .3117 .60025 .30906 Mtetra
.60025 .30906 .60238 .3117 .60655 .31027 .60443 .30763 Mtetra
.60443 .30763 .60655 .31027 .61073 .30884 .60862 .3062 Mtetra
.60862 .3062 .61073 .30884 .61492 .30741 .61281 .30476 Mtetra
.61281 .30476 .61492 .30741 .61911 .30598 .61701 .30333 Mtetra
.61701 .30333 .61911 .30598 .62332 .30454 .62121 .30189 Mtetra
.62121 .30189 .62332 .30454 .62752 .3031 .62542 .30044 Mtetra
.62542 .30044 .62752 .3031 .63174 .30166 .62964 .299 Mtetra
.62964 .299 .63174 .30166 .63596 .30022 .63386 .29755 Mtetra
.63386 .29755 .63596 .30022 .64018 .29878 .63809 .29611 Mtetra
.63809 .29611 .64018 .29878 .64441 .29733 .64233 .29466 Mtetra
.64233 .29466 .64441 .29733 .64865 .29588 .64657 .2932 Mtetra
.64657 .2932 .64865 .29588 .6529 .29443 .65082 .29175 Mtetra
.65082 .29175 .6529 .29443 .65715 .29298 .65508 .29029 Mtetra
.65508 .29029 .65715 .29298 .66141 .29152 .65934 .28883 Mtetra
.923 .544 .14 r
.65934 .28883 .66141 .29152 .66567 .29007 .6645 .30722 Mtetra
.495 .224 .432 r
.6645 .30722 .66567 .29007 .6711 .31346 .6688 .30577 Mtetra
.617 .515 .715 r
.6688 .30577 .6711 .31346 .67541 .312 .67311 .30431 Mtetra
.67311 .30431 .67541 .312 .67973 .31055 .67743 .30284 Mtetra
.67743 .30284 .67973 .31055 .68406 .30909 .68175 .30138 Mtetra
.341 .342 .715 r
.68175 .30138 .68406 .30909 .68839 .30763 .68634 .30492 Mtetra
.662 .744 .911 r
.68634 .30492 .68839 .30763 .69273 .30616 .69068 .30346 Mtetra
.69068 .30346 .69273 .30616 .69707 .3047 .69503 .30199 Mtetra
.69503 .30199 .69707 .3047 .70143 .30323 .69939 .30051 Mtetra
.69939 .30051 .70143 .30323 .70579 .30176 .70375 .29904 Mtetra
.70375 .29904 .70579 .30176 .71015 .30029 .70812 .29756 Mtetra
.70812 .29756 .71015 .30029 .71452 .29881 .7125 .29608 Mtetra
.7125 .29608 .71452 .29881 .7189 .29734 .71688 .2946 Mtetra
.71688 .2946 .7189 .29734 .72329 .29586 .72127 .29312 Mtetra
.72127 .29312 .72329 .29586 .72768 .29437 .72567 .29163 Mtetra
.72567 .29163 .72768 .29437 .73208 .29289 .73007 .29015 Mtetra
.73007 .29015 .73208 .29289 .73649 .2914 .73448 .28866 Mtetra
.73448 .28866 .73649 .2914 .7409 .28992 .7389 .28716 Mtetra
.97 .652 .311 r
.7389 .28716 .7409 .28992 .74532 .28843 .75102 .39519 Mtetra
.535 .305 .514 r
.75102 .39519 .74532 .28843 .75766 .39643 .75562 .39373 Mtetra
.654 .754 .923 r
.75562 .39373 .75766 .39643 .76226 .39497 .76022 .39226 Mtetra
.76022 .39226 .76226 .39497 .76686 .3935 .76483 .3908 Mtetra
.76483 .3908 .76686 .3935 .77147 .39204 .76944 .38933 Mtetra
.76944 .38933 .77147 .39204 .77609 .39057 .77407 .38786 Mtetra
.77407 .38786 .77609 .39057 .78072 .3891 .7787 .38638 Mtetra
.7787 .38638 .78072 .3891 .78535 .38763 .78334 .38491 Mtetra
.78334 .38491 .78535 .38763 .78999 .38616 .78798 .38343 Mtetra
.78798 .38343 .78999 .38616 .79464 .38468 .79264 .38195 Mtetra
.79264 .38195 .79464 .38468 .79929 .3832 .7973 .38046 Mtetra
.7973 .38046 .79929 .3832 .80396 .38172 .80196 .37898 Mtetra
.80196 .37898 .80396 .38172 .80863 .38023 .80664 .37749 Mtetra
.80664 .37749 .80863 .38023 .81331 .37875 .81132 .376 Mtetra
.81132 .376 .81331 .37875 .81799 .37726 .81602 .3745 Mtetra
.81602 .3745 .81799 .37726 .82269 .37577 .82071 .37301 Mtetra
.82071 .37301 .82269 .37577 .82739 .37427 .82542 .37151 Mtetra
.82542 .37151 .82739 .37427 .83209 .37278 .83013 .37001 Mtetra
.83013 .37001 .83209 .37278 .83681 .37128 .83486 .36851 Mtetra
.83486 .36851 .83681 .37128 .84153 .36978 .83959 .367 Mtetra
.83959 .367 .84153 .36978 .84627 .36828 .84432 .36549 Mtetra
.84432 .36549 .84627 .36828 .85101 .36677 .84907 .36398 Mtetra
.648 .76 .931 r
.20598 .62681 .20862 .62898 .21246 .6278 .20982 .62563 Mtetra
.20982 .62563 .21246 .6278 .2163 .62663 .21367 .62445 Mtetra
.21367 .62445 .2163 .62663 .22015 .62545 .21752 .62326 Mtetra
.21752 .62326 .22015 .62545 .22401 .62426 .22138 .62208 Mtetra
.22138 .62208 .22401 .62426 .22787 .62308 .22525 .62089 Mtetra
.22525 .62089 .22787 .62308 .23174 .6219 .22912 .6197 Mtetra
.22912 .6197 .23174 .6219 .23561 .62071 .23299 .61851 Mtetra
.23299 .61851 .23561 .62071 .23949 .61952 .23688 .61732 Mtetra
.23688 .61732 .23949 .61952 .24337 .61833 .24076 .61613 Mtetra
.24076 .61613 .24337 .61833 .24726 .61714 .24466 .61493 Mtetra
.24466 .61493 .24726 .61714 .25116 .61594 .24856 .61373 Mtetra
.24856 .61373 .25116 .61594 .25506 .61475 .25246 .61253 Mtetra
.936 .704 .563 r
.25246 .61253 .25506 .61475 .25897 .61355 .26011 .5636 Mtetra
.555 .352 .561 r
.26011 .5636 .25897 .61355 .26288 .61235 .26397 .56238 Mtetra
.26397 .56238 .26288 .61235 .2668 .61115 .26784 .56116 Mtetra
.26784 .56116 .2668 .61115 .27426 .56219 .27172 .55993 Mtetra
.652 .755 .925 r
.27172 .55993 .27426 .56219 .27814 .56097 .2756 .55871 Mtetra
.2756 .55871 .27814 .56097 .29246 .41443 .27949 .55748 Mtetra
0 0 .174 r
.27949 .55748 .29246 .41443 .29619 .41316 .29378 .41079 Mtetra
.664 .741 .908 r
.29378 .41079 .29619 .41316 .29993 .41188 .29752 .40951 Mtetra
.29752 .40951 .29993 .41188 .30367 .4106 .30127 .40823 Mtetra
.30127 .40823 .30367 .4106 .30742 .40931 .30502 .40694 Mtetra
.30502 .40694 .30742 .40931 .31117 .40803 .30877 .40565 Mtetra
.30877 .40565 .31117 .40803 .31493 .40674 .31253 .40436 Mtetra
.31253 .40436 .31493 .40674 .31745 .42479 .3163 .40307 Mtetra
.572 .391 .598 r
.3163 .40307 .31745 .42479 .32124 .42351 .32007 .40178 Mtetra
.32007 .40178 .32124 .42351 .32504 .42222 .32384 .40048 Mtetra
.32384 .40048 .32504 .42222 .32884 .42094 .32763 .39918 Mtetra
.32763 .39918 .32884 .42094 .33265 .41965 .33141 .39789 Mtetra
.33141 .39789 .33265 .41965 .33646 .41836 .33521 .39659 Mtetra
.33521 .39659 .33646 .41836 .34027 .41706 .33901 .39528 Mtetra
.33901 .39528 .34027 .41706 .3441 .41577 .34281 .39398 Mtetra
.34281 .39398 .3441 .41577 .34793 .41447 .34662 .39267 Mtetra
.34662 .39267 .34793 .41447 .35176 .41317 .35043 .39136 Mtetra
.35043 .39136 .35176 .41317 .3556 .41187 .35425 .39005 Mtetra
.35425 .39005 .3556 .41187 .35944 .41057 .35808 .38874 Mtetra
.35808 .38874 .35944 .41057 .36426 .38985 .36191 .38743 Mtetra
.664 .741 .908 r
.36191 .38743 .36426 .38985 .3681 .38854 .36575 .38611 Mtetra
.36575 .38611 .3681 .38854 .37194 .38723 .36959 .38479 Mtetra
.36959 .38479 .37194 .38723 .37578 .38591 .37344 .38347 Mtetra
.37344 .38347 .37578 .38591 .37963 .38459 .37729 .38215 Mtetra
.37729 .38215 .37963 .38459 .38348 .38327 .38115 .38083 Mtetra
.38115 .38083 .38348 .38327 .38735 .38195 .38501 .3795 Mtetra
.38501 .3795 .38735 .38195 .39121 .38063 .38888 .37818 Mtetra
.38888 .37818 .39121 .38063 .39508 .3793 .39276 .37685 Mtetra
.39276 .37685 .39508 .3793 .39896 .37797 .39664 .37552 Mtetra
.39664 .37552 .39896 .37797 .40284 .37664 .40053 .37418 Mtetra
.40053 .37418 .40284 .37664 .40673 .37531 .40442 .37285 Mtetra
.40442 .37285 .40673 .37531 .41063 .37398 .40832 .37151 Mtetra
.40832 .37151 .41063 .37398 .41453 .37264 .41222 .37017 Mtetra
.41222 .37017 .41453 .37264 .41843 .37131 .41613 .36883 Mtetra
.41613 .36883 .41843 .37131 .42235 .36997 .42004 .36749 Mtetra
.42004 .36749 .42235 .36997 .42626 .36863 .42397 .36615 Mtetra
.42397 .36615 .42626 .36863 .43004 .37214 .42789 .3648 Mtetra
.287 .305 .705 r
.42789 .3648 .43004 .37214 .43398 .3708 .43168 .36831 Mtetra
.663 .742 .908 r
.43168 .36831 .43398 .3708 .43792 .36945 .43563 .36696 Mtetra
.43563 .36696 .43792 .36945 .44186 .3681 .43958 .36561 Mtetra
.43958 .36561 .44186 .3681 .44581 .36675 .44353 .36426 Mtetra
.44353 .36426 .44581 .36675 .44977 .3654 .44749 .3629 Mtetra
.44749 .3629 .44977 .3654 .45373 .36405 .45146 .36155 Mtetra
.45146 .36155 .45373 .36405 .45536 .47367 .45543 .36019 Mtetra
.155 .033 .45 r
.45543 .36019 .45536 .47367 .45947 .47235 .45787 .43373 Mtetra
.559 .362 .57 r
.45787 .43373 .45947 .47235 .46359 .47103 .46194 .43239 Mtetra
.46194 .43239 .46359 .47103 .46772 .4697 .46603 .43105 Mtetra
.46603 .43105 .46772 .4697 .47243 .43218 .47012 .42971 Mtetra
.658 .749 .917 r
.47012 .42971 .47243 .43218 .47652 .43084 .47421 .42836 Mtetra
.47421 .42836 .47652 .43084 .48062 .4295 .47831 .42702 Mtetra
.47831 .42702 .48062 .4295 .48472 .42816 .48242 .42567 Mtetra
.48242 .42567 .48472 .42816 .48883 .42681 .48654 .42432 Mtetra
.48654 .42432 .48883 .42681 .49295 .42546 .49066 .42296 Mtetra
.49066 .42296 .49295 .42546 .49707 .42411 .49478 .42161 Mtetra
.49478 .42161 .49707 .42411 .5012 .42275 .49892 .42025 Mtetra
.49892 .42025 .5012 .42275 .50533 .4214 .50305 .41889 Mtetra
.50305 .41889 .50533 .4214 .50948 .42004 .5072 .41753 Mtetra
.5072 .41753 .50948 .42004 .51362 .41868 .51135 .41617 Mtetra
.51135 .41617 .51362 .41868 .51778 .41732 .51551 .4148 Mtetra
.51551 .4148 .51778 .41732 .5219 .4523 .51967 .41343 Mtetra
0 0 .428 r
.51967 .41343 .5219 .4523 .52612 .45094 .52383 .44844 Mtetra
.655 .752 .922 r
.52383 .44844 .52612 .45094 .53034 .44959 .52806 .44708 Mtetra
.52806 .44708 .53034 .44959 .53456 .44823 .53229 .44572 Mtetra
.53229 .44572 .53456 .44823 .53879 .44687 .53652 .44436 Mtetra
.53652 .44436 .53879 .44687 .54303 .44551 .54077 .44299 Mtetra
.54077 .44299 .54303 .44551 .54728 .44415 .54502 .44163 Mtetra
.54502 .44163 .54728 .44415 .55153 .44278 .54927 .44026 Mtetra
.54927 .44026 .55153 .44278 .55579 .44141 .55353 .43888 Mtetra
.55353 .43888 .55579 .44141 .56005 .44004 .5578 .43751 Mtetra
.5578 .43751 .56005 .44004 .56433 .43867 .56208 .43613 Mtetra
.56208 .43613 .56433 .43867 .5686 .4373 .56636 .43476 Mtetra
.56636 .43476 .5686 .4373 .57289 .43592 .57065 .43338 Mtetra
.57065 .43338 .57289 .43592 .57718 .43454 .57495 .43199 Mtetra
.57495 .43199 .57718 .43454 .58148 .43316 .57925 .43061 Mtetra
.971 .698 .455 r
.57925 .43061 .58148 .43316 .58578 .43178 .58145 .31214 Mtetra
.547 .334 .542 r
.58145 .31214 .58578 .43178 .58775 .31334 .58561 .31071 Mtetra
.664 .741 .908 r
.58561 .31071 .58775 .31334 .59191 .31192 .58977 .30928 Mtetra
.58977 .30928 .59191 .31192 .59608 .31049 .59394 .30785 Mtetra
.59394 .30785 .59608 .31049 .60025 .30906 .59812 .30642 Mtetra
.59812 .30642 .60025 .30906 .60443 .30763 .6023 .30498 Mtetra
.6023 .30498 .60443 .30763 .60862 .3062 .60649 .30355 Mtetra
.60649 .30355 .60862 .3062 .61281 .30476 .61069 .30211 Mtetra
.61069 .30211 .61281 .30476 .61701 .30333 .61489 .30067 Mtetra
.61489 .30067 .61701 .30333 .62121 .30189 .6191 .29922 Mtetra
.6191 .29922 .62121 .30189 .62542 .30044 .62332 .29778 Mtetra
.62332 .29778 .62542 .30044 .62964 .299 .62754 .29633 Mtetra
.62754 .29633 .62964 .299 .63386 .29755 .63177 .29488 Mtetra
.63177 .29488 .63386 .29755 .63809 .29611 .636 .29343 Mtetra
.636 .29343 .63809 .29611 .64233 .29466 .64024 .29197 Mtetra
.64024 .29197 .64233 .29466 .64657 .2932 .64449 .29052 Mtetra
.64449 .29052 .64657 .2932 .65082 .29175 .64874 .28906 Mtetra
.64874 .28906 .65082 .29175 .65508 .29029 .65301 .2876 Mtetra
.924 .545 .144 r
.65301 .2876 .65508 .29029 .65934 .28883 .65812 .30599 Mtetra
.494 .222 .431 r
.65812 .30599 .65934 .28883 .6645 .30722 .66242 .30453 Mtetra
.662 .743 .91 r
.66242 .30453 .6645 .30722 .6688 .30577 .66673 .30307 Mtetra
.66673 .30307 .6688 .30577 .67311 .30431 .67104 .3016 Mtetra
.67104 .3016 .67311 .30431 .67743 .30284 .67536 .30014 Mtetra
.67536 .30014 .67743 .30284 .68175 .30138 .67969 .29867 Mtetra
.67969 .29867 .68175 .30138 .68634 .30492 .68402 .2972 Mtetra
.617 .515 .715 r
.68402 .2972 .68634 .30492 .69068 .30346 .68836 .29573 Mtetra
.68836 .29573 .69068 .30346 .69503 .30199 .69271 .29425 Mtetra
.69271 .29425 .69503 .30199 .69939 .30051 .69707 .29277 Mtetra
.344 .343 .715 r
.69707 .29277 .69939 .30051 .70375 .29904 .70171 .29631 Mtetra
.662 .744 .911 r
.70171 .29631 .70375 .29904 .70812 .29756 .70609 .29483 Mtetra
.70609 .29483 .70812 .29756 .7125 .29608 .71047 .29335 Mtetra
.71047 .29335 .7125 .29608 .71688 .2946 .71486 .29186 Mtetra
.71486 .29186 .71688 .2946 .72127 .29312 .71925 .29037 Mtetra
.71925 .29037 .72127 .29312 .72567 .29163 .72365 .28888 Mtetra
.72365 .28888 .72567 .29163 .73007 .29015 .72806 .28739 Mtetra
.72806 .28739 .73007 .29015 .73448 .28866 .73248 .2859 Mtetra
.73248 .2859 .73448 .28866 .7389 .28716 .7369 .2844 Mtetra
.97 .652 .311 r
.7369 .2844 .7389 .28716 .75102 .39519 .74897 .39249 Mtetra
.654 .754 .923 r
.74897 .39249 .75102 .39519 .75562 .39373 .75357 .39102 Mtetra
.75357 .39102 .75562 .39373 .76022 .39226 .75817 .38955 Mtetra
.75817 .38955 .76022 .39226 .76483 .3908 .76279 .38808 Mtetra
.76279 .38808 .76483 .3908 .76944 .38933 .76741 .38661 Mtetra
.76741 .38661 .76944 .38933 .77407 .38786 .77204 .38513 Mtetra
.77204 .38513 .77407 .38786 .7787 .38638 .77667 .38366 Mtetra
.77667 .38366 .7787 .38638 .78334 .38491 .78132 .38217 Mtetra
.78132 .38217 .78334 .38491 .78798 .38343 .78597 .38069 Mtetra
.78597 .38069 .78798 .38343 .79264 .38195 .79063 .37921 Mtetra
.79063 .37921 .79264 .38195 .7973 .38046 .79529 .37772 Mtetra
.79529 .37772 .7973 .38046 .80196 .37898 .79997 .37623 Mtetra
.79997 .37623 .80196 .37898 .80664 .37749 .80465 .37473 Mtetra
.80465 .37473 .80664 .37749 .81132 .376 .80934 .37324 Mtetra
.80934 .37324 .81132 .376 .81602 .3745 .81403 .37174 Mtetra
.81403 .37174 .81602 .3745 .82071 .37301 .81874 .37024 Mtetra
.81874 .37024 .82071 .37301 .82542 .37151 .82345 .36874 Mtetra
.82345 .36874 .82542 .37151 .83013 .37001 .82817 .36723 Mtetra
.82817 .36723 .83013 .37001 .83486 .36851 .8329 .36573 Mtetra
.8329 .36573 .83486 .36851 .83959 .367 .83763 .36422 Mtetra
.83763 .36422 .83959 .367 .84432 .36549 .84237 .3627 Mtetra
.84237 .3627 .84432 .36549 .84907 .36398 .84712 .36119 Mtetra
.648 .76 .931 r
.20333 .62463 .20598 .62681 .20982 .62563 .20718 .62345 Mtetra
.20718 .62345 .20982 .62563 .21367 .62445 .21103 .62226 Mtetra
.21103 .62226 .21367 .62445 .21752 .62326 .21489 .62107 Mtetra
.21489 .62107 .21752 .62326 .22138 .62208 .21875 .61989 Mtetra
.21875 .61989 .22138 .62208 .22525 .62089 .22262 .6187 Mtetra
.22262 .6187 .22525 .62089 .22912 .6197 .22649 .6175 Mtetra
.22649 .6175 .22912 .6197 .23299 .61851 .23037 .61631 Mtetra
.23037 .61631 .23299 .61851 .23688 .61732 .23426 .61511 Mtetra
.23426 .61511 .23688 .61732 .24076 .61613 .23815 .61392 Mtetra
.934 .704 .565 r
.23815 .61392 .24076 .61613 .24466 .61493 .24597 .56501 Mtetra
.554 .352 .56 r
.24597 .56501 .24466 .61493 .24856 .61373 .24982 .56379 Mtetra
.24982 .56379 .24856 .61373 .25246 .61253 .25368 .56257 Mtetra
.25368 .56257 .25246 .61253 .26011 .5636 .25754 .56135 Mtetra
.652 .755 .925 r
.25754 .56135 .26011 .5636 .26397 .56238 .26141 .56012 Mtetra
.26141 .56012 .26397 .56238 .26784 .56116 .26529 .5589 Mtetra
.26529 .5589 .26784 .56116 .27172 .55993 .26917 .55767 Mtetra
.26917 .55767 .27172 .55993 .2756 .55871 .27305 .55644 Mtetra
.27305 .55644 .2756 .55871 .27949 .55748 .27695 .55521 Mtetra
.27695 .55521 .27949 .55748 .29378 .41079 .28084 .55397 Mtetra
0 0 .174 r
.28084 .55397 .29378 .41079 .29752 .40951 .29511 .40714 Mtetra
.664 .741 .908 r
.29511 .40714 .29752 .40951 .30127 .40823 .29885 .40585 Mtetra
.29885 .40585 .30127 .40823 .30502 .40694 .30261 .40456 Mtetra
.30261 .40456 .30502 .40694 .30877 .40565 .30636 .40327 Mtetra
.30636 .40327 .30877 .40565 .31253 .40436 .31013 .40198 Mtetra
.31013 .40198 .31253 .40436 .3163 .40307 .3139 .40068 Mtetra
.3139 .40068 .3163 .40307 .32007 .40178 .31767 .39938 Mtetra
.31767 .39938 .32007 .40178 .32384 .40048 .32145 .39809 Mtetra
.32145 .39809 .32384 .40048 .32763 .39918 .32524 .39679 Mtetra
.32524 .39679 .32763 .39918 .33141 .39789 .32903 .39548 Mtetra
.32903 .39548 .33141 .39789 .33521 .39659 .33282 .39418 Mtetra
.33282 .39418 .33521 .39659 .33901 .39528 .33663 .39287 Mtetra
.33663 .39287 .33901 .39528 .34281 .39398 .34043 .39156 Mtetra
.34043 .39156 .34281 .39398 .34662 .39267 .34425 .39025 Mtetra
.34425 .39025 .34662 .39267 .35043 .39136 .34806 .38894 Mtetra
.34806 .38894 .35043 .39136 .35425 .39005 .35189 .38763 Mtetra
.35189 .38763 .35425 .39005 .35808 .38874 .35572 .38631 Mtetra
.35572 .38631 .35808 .38874 .36191 .38743 .35955 .385 Mtetra
.35955 .385 .36191 .38743 .36575 .38611 .36339 .38368 Mtetra
.36339 .38368 .36575 .38611 .36959 .38479 .36724 .38236 Mtetra
.36724 .38236 .36959 .38479 .37344 .38347 .37109 .38103 Mtetra
.37109 .38103 .37344 .38347 .37729 .38215 .37494 .37971 Mtetra
.37494 .37971 .37729 .38215 .38115 .38083 .37881 .37838 Mtetra
.37881 .37838 .38115 .38083 .38501 .3795 .38267 .37705 Mtetra
.38267 .37705 .38501 .3795 .38888 .37818 .38655 .37572 Mtetra
.38655 .37572 .38888 .37818 .39276 .37685 .39043 .37439 Mtetra
.39043 .37439 .39276 .37685 .39664 .37552 .39431 .37305 Mtetra
.39431 .37305 .39664 .37552 .40053 .37418 .3982 .37172 Mtetra
.3982 .37172 .40053 .37418 .40442 .37285 .4021 .37038 Mtetra
.4021 .37038 .40442 .37285 .40832 .37151 .406 .36904 Mtetra
.406 .36904 .40832 .37151 .41222 .37017 .40991 .3677 Mtetra
.40991 .3677 .41222 .37017 .41613 .36883 .41382 .36635 Mtetra
.41382 .36635 .41613 .36883 .42004 .36749 .41774 .36501 Mtetra
.41774 .36501 .42004 .36749 .42397 .36615 .42166 .36366 Mtetra
.42166 .36366 .42397 .36615 .42789 .3648 .42559 .36231 Mtetra
.42559 .36231 .42789 .3648 .43168 .36831 .42953 .36096 Mtetra
.618 .515 .715 r
.42953 .36096 .43168 .36831 .43563 .36696 .43347 .3596 Mtetra
.288 .306 .705 r
.43347 .3596 .43563 .36696 .43958 .36561 .43728 .36311 Mtetra
.663 .742 .908 r
.43728 .36311 .43958 .36561 .44353 .36426 .44124 .36176 Mtetra
.44124 .36176 .44353 .36426 .44749 .3629 .44521 .3604 Mtetra
.44521 .3604 .44749 .3629 .45146 .36155 .44918 .35904 Mtetra
.44918 .35904 .45146 .36155 .45543 .36019 .45315 .35767 Mtetra
.963 .669 .429 r
.45315 .35767 .45543 .36019 .45787 .43373 .45554 .43126 Mtetra
.658 .749 .917 r
.45554 .43126 .45787 .43373 .46194 .43239 .45962 .42991 Mtetra
.45962 .42991 .46194 .43239 .46603 .43105 .46371 .42857 Mtetra
.46371 .42857 .46603 .43105 .47012 .42971 .4678 .42722 Mtetra
.4678 .42722 .47012 .42971 .47421 .42836 .4719 .42587 Mtetra
.4719 .42587 .47421 .42836 .47831 .42702 .476 .42452 Mtetra
.476 .42452 .47831 .42702 .48242 .42567 .48012 .42317 Mtetra
.48012 .42317 .48242 .42567 .48654 .42432 .48423 .42182 Mtetra
.48423 .42182 .48654 .42432 .49066 .42296 .48836 .42046 Mtetra
.48836 .42046 .49066 .42296 .49478 .42161 .49249 .4191 Mtetra
.49249 .4191 .49478 .42161 .49892 .42025 .49663 .41774 Mtetra
.49663 .41774 .49892 .42025 .50305 .41889 .50077 .41638 Mtetra
.50077 .41638 .50305 .41889 .5072 .41753 .50492 .41501 Mtetra
.50492 .41501 .5072 .41753 .51135 .41617 .50907 .41365 Mtetra
.50907 .41365 .51135 .41617 .51551 .4148 .51323 .41228 Mtetra
.51323 .41228 .51551 .4148 .51967 .41343 .5174 .4109 Mtetra
.962 .638 .348 r
.5174 .4109 .51967 .41343 .52383 .44844 .52154 .44593 Mtetra
.655 .752 .922 r
.52154 .44593 .52383 .44844 .52806 .44708 .52577 .44457 Mtetra
.52577 .44457 .52806 .44708 .53229 .44572 .53 .4432 Mtetra
.53 .4432 .53229 .44572 .53652 .44436 .53424 .44184 Mtetra
.53424 .44184 .53652 .44436 .54077 .44299 .53849 .44047 Mtetra
.53849 .44047 .54077 .44299 .54502 .44163 .54275 .4391 Mtetra
.54275 .4391 .54502 .44163 .54927 .44026 .54701 .43772 Mtetra
.54701 .43772 .54927 .44026 .55353 .43888 .55127 .43635 Mtetra
.55127 .43635 .55353 .43888 .5578 .43751 .55555 .43497 Mtetra
.55555 .43497 .5578 .43751 .56208 .43613 .55983 .43359 Mtetra
.55983 .43359 .56208 .43613 .56636 .43476 .56411 .43221 Mtetra
.56411 .43221 .56636 .43476 .57065 .43338 .56841 .43082 Mtetra
.56841 .43082 .57065 .43338 .57495 .43199 .57271 .42944 Mtetra
.57271 .42944 .57495 .43199 .57925 .43061 .57702 .42805 Mtetra
.971 .698 .455 r
.57702 .42805 .57925 .43061 .58145 .31214 .57929 .3095 Mtetra
.664 .741 .908 r
.57929 .3095 .58145 .31214 .58561 .31071 .58346 .30807 Mtetra
.58346 .30807 .58561 .31071 .58977 .30928 .58763 .30664 Mtetra
.58763 .30664 .58977 .30928 .59394 .30785 .5918 .3052 Mtetra
.5918 .3052 .59394 .30785 .59812 .30642 .59598 .30377 Mtetra
.59598 .30377 .59812 .30642 .6023 .30498 .60017 .30233 Mtetra
.60017 .30233 .6023 .30498 .60649 .30355 .60437 .30089 Mtetra
.60437 .30089 .60649 .30355 .61069 .30211 .60857 .29944 Mtetra
.60857 .29944 .61069 .30211 .61489 .30067 .61277 .298 Mtetra
.61277 .298 .61489 .30067 .6191 .29922 .61699 .29655 Mtetra
.61699 .29655 .6191 .29922 .62332 .29778 .62121 .2951 Mtetra
.62121 .2951 .62332 .29778 .62754 .29633 .62543 .29365 Mtetra
.62543 .29365 .62754 .29633 .63177 .29488 .62967 .2922 Mtetra
.62967 .2922 .63177 .29488 .636 .29343 .6339 .29074 Mtetra
.6339 .29074 .636 .29343 .64024 .29197 .63815 .28928 Mtetra
.63815 .28928 .64024 .29197 .64449 .29052 .6424 .28782 Mtetra
.6424 .28782 .64449 .29052 .64874 .28906 .64666 .28636 Mtetra
.64666 .28636 .64874 .28906 .65301 .2876 .65092 .28489 Mtetra
.924 .545 .144 r
.65092 .28489 .65301 .2876 .65812 .30599 .65603 .30329 Mtetra
.662 .743 .91 r
.65603 .30329 .65812 .30599 .66242 .30453 .66034 .30183 Mtetra
.66034 .30183 .66242 .30453 .66673 .30307 .66465 .30036 Mtetra
.66465 .30036 .66673 .30307 .67104 .3016 .66897 .2989 Mtetra
.66897 .2989 .67104 .3016 .67536 .30014 .67329 .29742 Mtetra
.67329 .29742 .67536 .30014 .67969 .29867 .67762 .29595 Mtetra
.67762 .29595 .67969 .29867 .68402 .2972 .68196 .29448 Mtetra
.68196 .29448 .68402 .2972 .68836 .29573 .68631 .293 Mtetra
.68631 .293 .68836 .29573 .69271 .29425 .69066 .29152 Mtetra
.69066 .29152 .69271 .29425 .69707 .29277 .69502 .29004 Mtetra
.69502 .29004 .69707 .29277 .70171 .29631 .69938 .28855 Mtetra
.617 .514 .715 r
.69938 .28855 .70171 .29631 .70609 .29483 .70376 .28707 Mtetra
.70376 .28707 .70609 .29483 .71047 .29335 .70814 .28558 Mtetra
.70814 .28558 .71047 .29335 .71486 .29186 .71252 .28409 Mtetra
.346 .345 .716 r
.71252 .28409 .71486 .29186 .71925 .29037 .71722 .28762 Mtetra
.662 .744 .911 r
.71722 .28762 .71925 .29037 .72365 .28888 .72163 .28613 Mtetra
.72163 .28613 .72365 .28888 .72806 .28739 .72604 .28463 Mtetra
.72604 .28463 .72806 .28739 .73248 .2859 .73047 .28313 Mtetra
.73047 .28313 .73248 .2859 .7369 .2844 .73489 .28163 Mtetra
.97 .652 .311 r
.73489 .28163 .7369 .2844 .74897 .39249 .74691 .38978 Mtetra
.654 .754 .923 r
.74691 .38978 .74897 .39249 .75357 .39102 .75151 .38831 Mtetra
.75151 .38831 .75357 .39102 .75817 .38955 .75612 .38684 Mtetra
.75612 .38684 .75817 .38955 .76279 .38808 .76074 .38536 Mtetra
.76074 .38536 .76279 .38808 .76741 .38661 .76537 .38388 Mtetra
.76537 .38388 .76741 .38661 .77204 .38513 .77 .3824 Mtetra
.77 .3824 .77204 .38513 .77667 .38366 .77464 .38092 Mtetra
.77464 .38092 .77667 .38366 .78132 .38217 .77929 .37943 Mtetra
.77929 .37943 .78132 .38217 .78597 .38069 .78395 .37795 Mtetra
.78395 .37795 .78597 .38069 .79063 .37921 .78861 .37646 Mtetra
.78861 .37646 .79063 .37921 .79529 .37772 .79328 .37496 Mtetra
.79328 .37496 .79529 .37772 .79997 .37623 .79796 .37347 Mtetra
.79796 .37347 .79997 .37623 .80465 .37473 .80265 .37197 Mtetra
.80265 .37197 .80465 .37473 .80934 .37324 .80734 .37047 Mtetra
.80734 .37047 .80934 .37324 .81403 .37174 .81204 .36897 Mtetra
.81204 .36897 .81403 .37174 .81874 .37024 .81675 .36747 Mtetra
.81675 .36747 .81874 .37024 .82345 .36874 .82147 .36596 Mtetra
.82147 .36596 .82345 .36874 .82817 .36723 .8262 .36445 Mtetra
.8262 .36445 .82817 .36723 .8329 .36573 .83093 .36294 Mtetra
.83093 .36294 .8329 .36573 .83763 .36422 .83567 .36142 Mtetra
.83567 .36142 .83763 .36422 .84237 .3627 .84042 .35991 Mtetra
.84042 .35991 .84237 .3627 .84712 .36119 .84517 .35839 Mtetra
.553 .348 .557 r
.20564 .56968 .20333 .62463 .20718 .62345 .20944 .56848 Mtetra
.20944 .56848 .20718 .62345 .21103 .62226 .21323 .56727 Mtetra
.21323 .56727 .21103 .62226 .21489 .62107 .21704 .56606 Mtetra
.21704 .56606 .21489 .62107 .21875 .61989 .22085 .56485 Mtetra
.22085 .56485 .21875 .61989 .22262 .6187 .22466 .56363 Mtetra
0 0 .248 r
.22466 .56363 .22262 .6187 .22649 .6175 .22386 .6153 Mtetra
.933 .703 .567 r
.22386 .6153 .22649 .6175 .23037 .61631 .23186 .56642 Mtetra
.554 .351 .56 r
.23186 .56642 .23037 .61631 .23426 .61511 .2357 .5652 Mtetra
.2357 .5652 .23426 .61511 .23815 .61392 .23954 .56398 Mtetra
.23954 .56398 .23815 .61392 .24597 .56501 .24339 .56276 Mtetra
.652 .755 .925 r
.24339 .56276 .24597 .56501 .24982 .56379 .24725 .56154 Mtetra
.24725 .56154 .24982 .56379 .25368 .56257 .25111 .56031 Mtetra
.25111 .56031 .25368 .56257 .25754 .56135 .25497 .55909 Mtetra
.25497 .55909 .25754 .56135 .26141 .56012 .25885 .55786 Mtetra
.25885 .55786 .26141 .56012 .26529 .5589 .26273 .55663 Mtetra
.26273 .55663 .26529 .5589 .26917 .55767 .26661 .5554 Mtetra
.26661 .5554 .26917 .55767 .27305 .55644 .2705 .55416 Mtetra
.2705 .55416 .27305 .55644 .27695 .55521 .27439 .55293 Mtetra
.27439 .55293 .27695 .55521 .28084 .55397 .27829 .55169 Mtetra
.943 .693 .53 r
.27829 .55169 .28084 .55397 .29511 .40714 .29268 .40476 Mtetra
.664 .741 .908 r
.29268 .40476 .29511 .40714 .29885 .40585 .29643 .40347 Mtetra
.29643 .40347 .29885 .40585 .30261 .40456 .30019 .40218 Mtetra
.30019 .40218 .30261 .40456 .30636 .40327 .30395 .40088 Mtetra
.30395 .40088 .30636 .40327 .31013 .40198 .30772 .39958 Mtetra
.30772 .39958 .31013 .40198 .3139 .40068 .31149 .39829 Mtetra
.31149 .39829 .3139 .40068 .31767 .39938 .31527 .39699 Mtetra
.31527 .39699 .31767 .39938 .32145 .39809 .31905 .39568 Mtetra
.31905 .39568 .32145 .39809 .32524 .39679 .32284 .39438 Mtetra
.32284 .39438 .32524 .39679 .32903 .39548 .32664 .39307 Mtetra
.32664 .39307 .32903 .39548 .33282 .39418 .33044 .39177 Mtetra
.33044 .39177 .33282 .39418 .33663 .39287 .33424 .39046 Mtetra
.33424 .39046 .33663 .39287 .34043 .39156 .33805 .38915 Mtetra
.33805 .38915 .34043 .39156 .34425 .39025 .34187 .38783 Mtetra
.34187 .38783 .34425 .39025 .34806 .38894 .34569 .38652 Mtetra
.34569 .38652 .34806 .38894 .35189 .38763 .34951 .3852 Mtetra
.34951 .3852 .35189 .38763 .35572 .38631 .35335 .38388 Mtetra
.35335 .38388 .35572 .38631 .35955 .385 .35719 .38256 Mtetra
.35719 .38256 .35955 .385 .36339 .38368 .36103 .38124 Mtetra
.36103 .38124 .36339 .38368 .36724 .38236 .36488 .37991 Mtetra
.36488 .37991 .36724 .38236 .37109 .38103 .36873 .37859 Mtetra
.36873 .37859 .37109 .38103 .37494 .37971 .37259 .37726 Mtetra
.37259 .37726 .37494 .37971 .37881 .37838 .37646 .37593 Mtetra
.37646 .37593 .37881 .37838 .38267 .37705 .38033 .37459 Mtetra
.38033 .37459 .38267 .37705 .38655 .37572 .38421 .37326 Mtetra
.38421 .37326 .38655 .37572 .39043 .37439 .38809 .37192 Mtetra
.38809 .37192 .39043 .37439 .39431 .37305 .39198 .37059 Mtetra
.39198 .37059 .39431 .37305 .3982 .37172 .39587 .36925 Mtetra
.39587 .36925 .3982 .37172 .4021 .37038 .39977 .3679 Mtetra
.39977 .3679 .4021 .37038 .406 .36904 .40367 .36656 Mtetra
.40367 .36656 .406 .36904 .40991 .3677 .40759 .36521 Mtetra
.40759 .36521 .40991 .3677 .41382 .36635 .4115 .36387 Mtetra
.4115 .36387 .41382 .36635 .41774 .36501 .41542 .36252 Mtetra
.41542 .36252 .41774 .36501 .42166 .36366 .41935 .36116 Mtetra
.41935 .36116 .42166 .36366 .42559 .36231 .42329 .35981 Mtetra
.42329 .35981 .42559 .36231 .42953 .36096 .42723 .35845 Mtetra
0 .079 .593 r
.42723 .35845 .42953 .36096 .43347 .3596 .43103 .36196 Mtetra
.133 0 0 r
.43103 .36196 .43347 .3596 .43728 .36311 .43498 .36061 Mtetra
.663 .742 .908 r
.43498 .36061 .43728 .36311 .44124 .36176 .43895 .35925 Mtetra
.43895 .35925 .44124 .36176 .44521 .3604 .44291 .35788 Mtetra
.44291 .35788 .44521 .3604 .44918 .35904 .44689 .35652 Mtetra
.44689 .35652 .44918 .35904 .45315 .35767 .45087 .35515 Mtetra
.45087 .35515 .45315 .35767 .45554 .43126 .45485 .35378 Mtetra
0 0 .354 r
.45485 .35378 .45554 .43126 .45962 .42991 .45729 .42743 Mtetra
.658 .749 .917 r
.45729 .42743 .45962 .42991 .46371 .42857 .46138 .42608 Mtetra
.46138 .42608 .46371 .42857 .4678 .42722 .46547 .42473 Mtetra
.46547 .42473 .4678 .42722 .4719 .42587 .46958 .42338 Mtetra
.46958 .42338 .4719 .42587 .476 .42452 .47369 .42202 Mtetra
.47369 .42202 .476 .42452 .48012 .42317 .4778 .42067 Mtetra
.4778 .42067 .48012 .42317 .48423 .42182 .48193 .41931 Mtetra
.48193 .41931 .48423 .42182 .48836 .42046 .48605 .41795 Mtetra
.48605 .41795 .48836 .42046 .49249 .4191 .49019 .41659 Mtetra
.49019 .41659 .49249 .4191 .49663 .41774 .49433 .41522 Mtetra
.49433 .41522 .49663 .41774 .50077 .41638 .49848 .41386 Mtetra
.49848 .41386 .50077 .41638 .50492 .41501 .50263 .41249 Mtetra
.50263 .41249 .50492 .41501 .50907 .41365 .50679 .41112 Mtetra
.50679 .41112 .50907 .41365 .51323 .41228 .51095 .40974 Mtetra
.51095 .40974 .51323 .41228 .5174 .4109 .51513 .40837 Mtetra
.51513 .40837 .5174 .4109 .52154 .44593 .51931 .40699 Mtetra
0 0 .426 r
.51931 .40699 .52154 .44593 .52577 .44457 .52347 .44205 Mtetra
.655 .752 .922 r
.52347 .44205 .52577 .44457 .53 .4432 .52771 .44068 Mtetra
.52771 .44068 .53 .4432 .53424 .44184 .53196 .43931 Mtetra
.53196 .43931 .53424 .44184 .53849 .44047 .53621 .43793 Mtetra
.53621 .43793 .53849 .44047 .54275 .4391 .54047 .43656 Mtetra
.54047 .43656 .54275 .4391 .54701 .43772 .54473 .43518 Mtetra
.54473 .43518 .54701 .43772 .55127 .43635 .54901 .4338 Mtetra
.54901 .4338 .55127 .43635 .55555 .43497 .55328 .43242 Mtetra
.55328 .43242 .55555 .43497 .55983 .43359 .55757 .43104 Mtetra
.55757 .43104 .55983 .43359 .56411 .43221 .56186 .42965 Mtetra
.56186 .42965 .56411 .43221 .56841 .43082 .56616 .42826 Mtetra
.56616 .42826 .56841 .43082 .57271 .42944 .57046 .42687 Mtetra
.57046 .42687 .57271 .42944 .57702 .42805 .57477 .42548 Mtetra
.971 .698 .455 r
.57477 .42548 .57702 .42805 .57929 .3095 .57714 .30686 Mtetra
.664 .741 .908 r
.57714 .30686 .57929 .3095 .58346 .30807 .5813 .30543 Mtetra
.5813 .30543 .58346 .30807 .58763 .30664 .58548 .30399 Mtetra
.58548 .30399 .58763 .30664 .5918 .3052 .58966 .30255 Mtetra
.58966 .30255 .5918 .3052 .59598 .30377 .59384 .30111 Mtetra
.59384 .30111 .59598 .30377 .60017 .30233 .59803 .29967 Mtetra
.59803 .29967 .60017 .30233 .60437 .30089 .60223 .29822 Mtetra
.60223 .29822 .60437 .30089 .60857 .29944 .60644 .29677 Mtetra
.60644 .29677 .60857 .29944 .61277 .298 .61065 .29532 Mtetra
.61065 .29532 .61277 .298 .61699 .29655 .61487 .29387 Mtetra
.61487 .29387 .61699 .29655 .62121 .2951 .61909 .29242 Mtetra
.61909 .29242 .62121 .2951 .62543 .29365 .62332 .29096 Mtetra
.62332 .29096 .62543 .29365 .62967 .2922 .62756 .28951 Mtetra
.62756 .28951 .62967 .2922 .6339 .29074 .6318 .28804 Mtetra
.6318 .28804 .6339 .29074 .63815 .28928 .63605 .28658 Mtetra
.63605 .28658 .63815 .28928 .6424 .28782 .64031 .28512 Mtetra
.64031 .28512 .6424 .28782 .64666 .28636 .64457 .28365 Mtetra
.64457 .28365 .64666 .28636 .65092 .28489 .64884 .28218 Mtetra
.924 .545 .144 r
.64884 .28218 .65092 .28489 .65603 .30329 .65394 .30059 Mtetra
.662 .743 .91 r
.65394 .30059 .65603 .30329 .66034 .30183 .65825 .29912 Mtetra
.65825 .29912 .66034 .30183 .66465 .30036 .66256 .29765 Mtetra
.66256 .29765 .66465 .30036 .66897 .2989 .66689 .29618 Mtetra
.66689 .29618 .66897 .2989 .67329 .29742 .67122 .2947 Mtetra
.67122 .2947 .67329 .29742 .67762 .29595 .67555 .29323 Mtetra
.67555 .29323 .67762 .29595 .68196 .29448 .6799 .29175 Mtetra
.6799 .29175 .68196 .29448 .68631 .293 .68425 .29027 Mtetra
.68425 .29027 .68631 .293 .69066 .29152 .6886 .28878 Mtetra
.6886 .28878 .69066 .29152 .69502 .29004 .69297 .2873 Mtetra
.69297 .2873 .69502 .29004 .69938 .28855 .69734 .28581 Mtetra
.69734 .28581 .69938 .28855 .70376 .28707 .70171 .28432 Mtetra
.70171 .28432 .70376 .28707 .70814 .28558 .7061 .28282 Mtetra
.7061 .28282 .70814 .28558 .71252 .28409 .71049 .28133 Mtetra
.71049 .28133 .71252 .28409 .71722 .28762 .71488 .27983 Mtetra
.617 .514 .715 r
.71488 .27983 .71722 .28762 .72163 .28613 .71929 .27833 Mtetra
.71929 .27833 .72163 .28613 .72604 .28463 .7237 .27683 Mtetra
.7237 .27683 .72604 .28463 .73047 .28313 .72812 .27532 Mtetra
.97 .657 .283 r
.72812 .27532 .73047 .28313 .73489 .28163 .74023 .38854 Mtetra
.533 .303 .512 r
.74023 .38854 .73489 .28163 .74691 .38978 .74484 .38706 Mtetra
.654 .754 .923 r
.74484 .38706 .74691 .38978 .75151 .38831 .74945 .38559 Mtetra
.74945 .38559 .75151 .38831 .75612 .38684 .75406 .38411 Mtetra
.75406 .38411 .75612 .38684 .76074 .38536 .75869 .38263 Mtetra
.75869 .38263 .76074 .38536 .76537 .38388 .76332 .38115 Mtetra
.76332 .38115 .76537 .38388 .77 .3824 .76796 .37966 Mtetra
.76796 .37966 .77 .3824 .77464 .38092 .7726 .37818 Mtetra
.7726 .37818 .77464 .38092 .77929 .37943 .77726 .37669 Mtetra
.77726 .37669 .77929 .37943 .78395 .37795 .78192 .37519 Mtetra
.78192 .37519 .78395 .37795 .78861 .37646 .78659 .3737 Mtetra
.78659 .3737 .78861 .37646 .79328 .37496 .79127 .3722 Mtetra
.79127 .3722 .79328 .37496 .79796 .37347 .79595 .3707 Mtetra
.79595 .3707 .79796 .37347 .80265 .37197 .80064 .3692 Mtetra
.80064 .3692 .80265 .37197 .80734 .37047 .80534 .3677 Mtetra
.80534 .3677 .80734 .37047 .81204 .36897 .81005 .36619 Mtetra
.81005 .36619 .81204 .36897 .81675 .36747 .81477 .36468 Mtetra
.81477 .36468 .81675 .36747 .82147 .36596 .81949 .36317 Mtetra
.81949 .36317 .82147 .36596 .8262 .36445 .82422 .36166 Mtetra
.82422 .36166 .8262 .36445 .83093 .36294 .82896 .36014 Mtetra
.82896 .36014 .83093 .36294 .83567 .36142 .8337 .35862 Mtetra
.8337 .35862 .83567 .36142 .84042 .35991 .83846 .3571 Mtetra
.83846 .3571 .84042 .35991 .84517 .35839 .84322 .35558 Mtetra
.653 .755 .925 r
.20303 .56745 .20564 .56968 .20944 .56848 .20682 .56624 Mtetra
.20682 .56624 .20944 .56848 .21323 .56727 .21063 .56503 Mtetra
.21063 .56503 .21323 .56727 .21704 .56606 .21443 .56382 Mtetra
.21443 .56382 .21704 .56606 .22085 .56485 .21825 .5626 Mtetra
.21825 .5626 .22085 .56485 .22466 .56363 .22207 .56139 Mtetra
.22207 .56139 .22466 .56363 .22386 .6153 .22589 .56017 Mtetra
.51 .313 .549 r
.22589 .56017 .22386 .6153 .23186 .56642 .22927 .56417 Mtetra
.652 .755 .925 r
.22927 .56417 .23186 .56642 .2357 .5652 .23311 .56295 Mtetra
.23311 .56295 .2357 .5652 .23954 .56398 .23695 .56172 Mtetra
.23695 .56172 .23954 .56398 .24339 .56276 .24081 .5605 Mtetra
.24081 .5605 .24339 .56276 .24725 .56154 .24466 .55927 Mtetra
.24466 .55927 .24725 .56154 .25111 .56031 .24853 .55805 Mtetra
.24853 .55805 .25111 .56031 .25497 .55909 .2524 .55682 Mtetra
.2524 .55682 .25497 .55909 .25885 .55786 .25627 .55559 Mtetra
.25627 .55559 .25885 .55786 .26273 .55663 .26016 .55435 Mtetra
.26016 .55435 .26273 .55663 .26661 .5554 .26404 .55312 Mtetra
.26404 .55312 .26661 .5554 .2705 .55416 .26794 .55188 Mtetra
.26794 .55188 .2705 .55416 .27439 .55293 .27183 .55064 Mtetra
.27183 .55064 .27439 .55293 .27829 .55169 .27574 .5494 Mtetra
.27574 .5494 .27829 .55169 .29268 .40476 .27965 .54816 Mtetra
0 0 .171 r
.27965 .54816 .29268 .40476 .29643 .40347 .29401 .40108 Mtetra
.664 .741 .908 r
.29401 .40108 .29643 .40347 .30019 .40218 .29777 .39978 Mtetra
.29777 .39978 .30019 .40218 .30395 .40088 .30153 .39849 Mtetra
.30153 .39849 .30395 .40088 .30772 .39958 .3053 .39719 Mtetra
.3053 .39719 .30772 .39958 .31149 .39829 .30908 .39588 Mtetra
.30908 .39588 .31149 .39829 .31527 .39699 .31286 .39458 Mtetra
.31286 .39458 .31527 .39699 .31905 .39568 .31665 .39327 Mtetra
.31665 .39327 .31905 .39568 .32284 .39438 .32044 .39197 Mtetra
.32044 .39197 .32284 .39438 .32664 .39307 .32424 .39066 Mtetra
.32424 .39066 .32664 .39307 .33044 .39177 .32804 .38935 Mtetra
.32804 .38935 .33044 .39177 .33424 .39046 .33185 .38803 Mtetra
.33185 .38803 .33424 .39046 .33805 .38915 .33566 .38672 Mtetra
.33566 .38672 .33805 .38915 .34187 .38783 .33948 .3854 Mtetra
.33948 .3854 .34187 .38783 .34569 .38652 .34331 .38408 Mtetra
.34331 .38408 .34569 .38652 .34951 .3852 .34714 .38276 Mtetra
.34714 .38276 .34951 .3852 .35335 .38388 .35097 .38144 Mtetra
.35097 .38144 .35335 .38388 .35719 .38256 .35481 .38012 Mtetra
.35481 .38012 .35719 .38256 .36103 .38124 .35866 .37879 Mtetra
.35866 .37879 .36103 .38124 .36488 .37991 .36251 .37746 Mtetra
.36251 .37746 .36488 .37991 .36873 .37859 .36637 .37613 Mtetra
.36637 .37613 .36873 .37859 .37259 .37726 .37023 .3748 Mtetra
.37023 .3748 .37259 .37726 .37646 .37593 .3741 .37347 Mtetra
.3741 .37347 .37646 .37593 .38033 .37459 .37798 .37213 Mtetra
.37798 .37213 .38033 .37459 .38421 .37326 .38186 .37079 Mtetra
.38186 .37079 .38421 .37326 .38809 .37192 .38574 .36945 Mtetra
.38574 .36945 .38809 .37192 .39198 .37059 .38964 .36811 Mtetra
.38964 .36811 .39198 .37059 .39587 .36925 .39353 .36677 Mtetra
.39353 .36677 .39587 .36925 .39977 .3679 .39744 .36542 Mtetra
.39744 .36542 .39977 .3679 .40367 .36656 .40134 .36407 Mtetra
.40134 .36407 .40367 .36656 .40759 .36521 .40526 .36272 Mtetra
.40526 .36272 .40759 .36521 .4115 .36387 .40918 .36137 Mtetra
.40918 .36137 .4115 .36387 .41542 .36252 .4131 .36002 Mtetra
.4131 .36002 .41542 .36252 .41935 .36116 .41704 .35866 Mtetra
.41704 .35866 .41935 .36116 .42329 .35981 .42097 .35731 Mtetra
.42097 .35731 .42329 .35981 .42723 .35845 .42492 .35595 Mtetra
0 .079 .593 r
.42492 .35595 .42723 .35845 .43103 .36196 .42872 .35945 Mtetra
.663 .742 .908 r
.42872 .35945 .43103 .36196 .43498 .36061 .43268 .35809 Mtetra
.43268 .35809 .43498 .36061 .43895 .35925 .43664 .35673 Mtetra
.43664 .35673 .43895 .35925 .44291 .35788 .44062 .35536 Mtetra
.44062 .35536 .44291 .35788 .44689 .35652 .44459 .35399 Mtetra
.44459 .35399 .44689 .35652 .45087 .35515 .44858 .35262 Mtetra
.44858 .35262 .45087 .35515 .45485 .35378 .45257 .35125 Mtetra
.963 .669 .428 r
.45257 .35125 .45485 .35378 .45729 .42743 .45495 .42494 Mtetra
.658 .749 .917 r
.45495 .42494 .45729 .42743 .46138 .42608 .45904 .42359 Mtetra
.45904 .42359 .46138 .42608 .46547 .42473 .46314 .42223 Mtetra
.46314 .42223 .46547 .42473 .46958 .42338 .46725 .42088 Mtetra
.46725 .42088 .46958 .42338 .47369 .42202 .47136 .41952 Mtetra
.47136 .41952 .47369 .42202 .4778 .42067 .47548 .41816 Mtetra
.47548 .41816 .4778 .42067 .48193 .41931 .47961 .4168 Mtetra
.47961 .4168 .48193 .41931 .48605 .41795 .48374 .41543 Mtetra
.48374 .41543 .48605 .41795 .49019 .41659 .48788 .41407 Mtetra
.48788 .41407 .49019 .41659 .49433 .41522 .49203 .4127 Mtetra
.49203 .4127 .49433 .41522 .49848 .41386 .49618 .41133 Mtetra
.49618 .41133 .49848 .41386 .50263 .41249 .50033 .40995 Mtetra
.50033 .40995 .50263 .41249 .50679 .41112 .5045 .40858 Mtetra
.5045 .40858 .50679 .41112 .51095 .40974 .50867 .4072 Mtetra
.50867 .4072 .51095 .40974 .51513 .40837 .51284 .40582 Mtetra
.51284 .40582 .51513 .40837 .51931 .40699 .51703 .40444 Mtetra
.962 .638 .346 r
.51703 .40444 .51931 .40699 .52347 .44205 .52117 .43952 Mtetra
.655 .752 .922 r
.52117 .43952 .52347 .44205 .52771 .44068 .52542 .43814 Mtetra
.52542 .43814 .52771 .44068 .53196 .43931 .52967 .43677 Mtetra
.52967 .43677 .53196 .43931 .53621 .43793 .53392 .43539 Mtetra
.53392 .43539 .53621 .43793 .54047 .43656 .53819 .43401 Mtetra
.53819 .43401 .54047 .43656 .54473 .43518 .54246 .43263 Mtetra
.54246 .43263 .54473 .43518 .54901 .4338 .54673 .43125 Mtetra
.54673 .43125 .54901 .4338 .55328 .43242 .55101 .42986 Mtetra
.55101 .42986 .55328 .43242 .55757 .43104 .5553 .42848 Mtetra
.5553 .42848 .55757 .43104 .56186 .42965 .5596 .42709 Mtetra
.5596 .42709 .56186 .42965 .56616 .42826 .5639 .42569 Mtetra
.5639 .42569 .56616 .42826 .57046 .42687 .56821 .4243 Mtetra
.971 .698 .457 r
.56821 .4243 .57046 .42687 .57477 .42548 .57081 .30565 Mtetra
.546 .332 .541 r
.57081 .30565 .57477 .42548 .57714 .30686 .57497 .30421 Mtetra
.664 .741 .908 r
.57497 .30421 .57714 .30686 .5813 .30543 .57914 .30277 Mtetra
.57914 .30277 .5813 .30543 .58548 .30399 .58332 .30133 Mtetra
.58332 .30133 .58548 .30399 .58966 .30255 .5875 .29989 Mtetra
.5875 .29989 .58966 .30255 .59384 .30111 .59169 .29844 Mtetra
.59169 .29844 .59384 .30111 .59803 .29967 .59589 .297 Mtetra
.59589 .297 .59803 .29967 .60223 .29822 .60009 .29555 Mtetra
.60009 .29555 .60223 .29822 .60644 .29677 .6043 .2941 Mtetra
.6043 .2941 .60644 .29677 .61065 .29532 .60852 .29264 Mtetra
.60852 .29264 .61065 .29532 .61487 .29387 .61274 .29119 Mtetra
.61274 .29119 .61487 .29387 .61909 .29242 .61697 .28973 Mtetra
.61697 .28973 .61909 .29242 .62332 .29096 .6212 .28827 Mtetra
.6212 .28827 .62332 .29096 .62756 .28951 .62544 .28681 Mtetra
.62544 .28681 .62756 .28951 .6318 .28804 .62969 .28534 Mtetra
.62969 .28534 .6318 .28804 .63605 .28658 .63395 .28388 Mtetra
.63395 .28388 .63605 .28658 .64031 .28512 .63821 .28241 Mtetra
.63821 .28241 .64031 .28512 .64457 .28365 .64247 .28094 Mtetra
.64247 .28094 .64457 .28365 .64884 .28218 .64675 .27946 Mtetra
.924 .545 .144 r
.64675 .27946 .64884 .28218 .65394 .30059 .65184 .29788 Mtetra
.662 .743 .91 r
.65184 .29788 .65394 .30059 .65825 .29912 .65615 .29641 Mtetra
.65615 .29641 .65825 .29912 .66256 .29765 .66047 .29493 Mtetra
.66047 .29493 .66256 .29765 .66689 .29618 .6648 .29345 Mtetra
.6648 .29345 .66689 .29618 .67122 .2947 .66913 .29198 Mtetra
.66913 .29198 .67122 .2947 .67555 .29323 .67347 .29049 Mtetra
.67347 .29049 .67555 .29323 .6799 .29175 .67782 .28901 Mtetra
.67782 .28901 .6799 .29175 .68425 .29027 .68218 .28753 Mtetra
.68218 .28753 .68425 .29027 .6886 .28878 .68654 .28604 Mtetra
.68654 .28604 .6886 .28878 .69297 .2873 .69091 .28455 Mtetra
.69091 .28455 .69297 .2873 .69734 .28581 .69528 .28305 Mtetra
.69528 .28305 .69734 .28581 .70171 .28432 .69966 .28156 Mtetra
.69966 .28156 .70171 .28432 .7061 .28282 .70405 .28006 Mtetra
.70405 .28006 .7061 .28282 .71049 .28133 .70845 .27856 Mtetra
.70845 .27856 .71049 .28133 .71488 .27983 .71285 .27706 Mtetra
.71285 .27706 .71488 .27983 .71929 .27833 .71726 .27556 Mtetra
.71726 .27556 .71929 .27833 .7237 .27683 .72167 .27405 Mtetra
.72167 .27405 .7237 .27683 .72812 .27532 .7261 .27254 Mtetra
.971 .654 .316 r
.7261 .27254 .72812 .27532 .74023 .38854 .73815 .38581 Mtetra
.654 .754 .923 r
.73815 .38581 .74023 .38854 .74484 .38706 .74276 .38434 Mtetra
.74276 .38434 .74484 .38706 .74945 .38559 .74738 .38286 Mtetra
.74738 .38286 .74945 .38559 .75406 .38411 .752 .38138 Mtetra
.752 .38138 .75406 .38411 .75869 .38263 .75663 .37989 Mtetra
.75663 .37989 .75869 .38263 .76332 .38115 .76126 .3784 Mtetra
.76126 .3784 .76332 .38115 .76796 .37966 .76591 .37692 Mtetra
.76591 .37692 .76796 .37966 .7726 .37818 .77056 .37542 Mtetra
.77056 .37542 .7726 .37818 .77726 .37669 .77522 .37393 Mtetra
.77522 .37393 .77726 .37669 .78192 .37519 .77989 .37243 Mtetra
.77989 .37243 .78192 .37519 .78659 .3737 .78456 .37093 Mtetra
.78456 .37093 .78659 .3737 .79127 .3722 .78924 .36943 Mtetra
.78924 .36943 .79127 .3722 .79595 .3707 .79393 .36793 Mtetra
.79393 .36793 .79595 .3707 .80064 .3692 .79863 .36642 Mtetra
.79863 .36642 .80064 .3692 .80534 .3677 .80334 .36491 Mtetra
.80334 .36491 .80534 .3677 .81005 .36619 .80805 .3634 Mtetra
.80805 .3634 .81005 .36619 .81477 .36468 .81277 .36189 Mtetra
.81277 .36189 .81477 .36468 .81949 .36317 .8175 .36037 Mtetra
.8175 .36037 .81949 .36317 .82422 .36166 .82223 .35885 Mtetra
.82223 .35885 .82422 .36166 .82896 .36014 .82698 .35733 Mtetra
.82698 .35733 .82896 .36014 .8337 .35862 .83173 .35581 Mtetra
.83173 .35581 .8337 .35862 .83846 .3571 .83649 .35428 Mtetra
.83649 .35428 .83846 .3571 .84322 .35558 .84126 .35276 Mtetra
.653 .755 .925 r
.20041 .56522 .20303 .56745 .20682 .56624 .20421 .56401 Mtetra
.20421 .56401 .20682 .56624 .21063 .56503 .20801 .56279 Mtetra
.20801 .56279 .21063 .56503 .21443 .56382 .21182 .56157 Mtetra
.21182 .56157 .21443 .56382 .21825 .5626 .21564 .56035 Mtetra
.21564 .56035 .21825 .5626 .22207 .56139 .21946 .55913 Mtetra
.21946 .55913 .22207 .56139 .22589 .56017 .22329 .55791 Mtetra
.22329 .55791 .22589 .56017 .22927 .56417 .22712 .55669 Mtetra
.187 .237 .682 r
.22712 .55669 .22927 .56417 .23311 .56295 .23051 .56069 Mtetra
.652 .755 .925 r
.23051 .56069 .23311 .56295 .23695 .56172 .23436 .55946 Mtetra
.23436 .55946 .23695 .56172 .24081 .5605 .23821 .55824 Mtetra
.23821 .55824 .24081 .5605 .24466 .55927 .24207 .55701 Mtetra
.24207 .55701 .24466 .55927 .24853 .55805 .24594 .55577 Mtetra
.24594 .55577 .24853 .55805 .2524 .55682 .24982 .55454 Mtetra
.24982 .55454 .2524 .55682 .25627 .55559 .25369 .55331 Mtetra
.25369 .55331 .25627 .55559 .26016 .55435 .25758 .55207 Mtetra
.25758 .55207 .26016 .55435 .26404 .55312 .26147 .55083 Mtetra
.26147 .55083 .26404 .55312 .26794 .55188 .26537 .54959 Mtetra
.26537 .54959 .26794 .55188 .27183 .55064 .26927 .54835 Mtetra
.26927 .54835 .27183 .55064 .27574 .5494 .27318 .54711 Mtetra
.27318 .54711 .27574 .5494 .27965 .54816 .27709 .54586 Mtetra
.943 .693 .529 r
.27709 .54586 .27965 .54816 .29401 .40108 .29158 .39869 Mtetra
.664 .741 .908 r
.29158 .39869 .29401 .40108 .29777 .39978 .29534 .39739 Mtetra
.29534 .39739 .29777 .39978 .30153 .39849 .29911 .39608 Mtetra
.29911 .39608 .30153 .39849 .3053 .39719 .30288 .39478 Mtetra
.30288 .39478 .3053 .39719 .30908 .39588 .30666 .39348 Mtetra
.30666 .39348 .30908 .39588 .31286 .39458 .31045 .39217 Mtetra
.31045 .39217 .31286 .39458 .31665 .39327 .31424 .39086 Mtetra
.31424 .39086 .31665 .39327 .32044 .39197 .31803 .38955 Mtetra
.31803 .38955 .32044 .39197 .32424 .39066 .32183 .38824 Mtetra
.32183 .38824 .32424 .39066 .32804 .38935 .32564 .38692 Mtetra
.32564 .38692 .32804 .38935 .33185 .38803 .32945 .38561 Mtetra
.32945 .38561 .33185 .38803 .33566 .38672 .33327 .38429 Mtetra
.33327 .38429 .33566 .38672 .33948 .3854 .33709 .38297 Mtetra
.33709 .38297 .33948 .3854 .34331 .38408 .34092 .38164 Mtetra
.34092 .38164 .34331 .38408 .34714 .38276 .34475 .38032 Mtetra
.34475 .38032 .34714 .38276 .35097 .38144 .34859 .37899 Mtetra
.34859 .37899 .35097 .38144 .35481 .38012 .35243 .37767 Mtetra
.35243 .37767 .35481 .38012 .35866 .37879 .35629 .37634 Mtetra
.35629 .37634 .35866 .37879 .36251 .37746 .36014 .375 Mtetra
.36014 .375 .36251 .37746 .36637 .37613 .364 .37367 Mtetra
.364 .37367 .36637 .37613 .37023 .3748 .36787 .37233 Mtetra
.36787 .37233 .37023 .3748 .3741 .37347 .37174 .371 Mtetra
.37174 .371 .3741 .37347 .37798 .37213 .37562 .36966 Mtetra
.37562 .36966 .37798 .37213 .38186 .37079 .3795 .36832 Mtetra
.3795 .36832 .38186 .37079 .38574 .36945 .38339 .36697 Mtetra
.38339 .36697 .38574 .36945 .38964 .36811 .38729 .36563 Mtetra
.38729 .36563 .38964 .36811 .39353 .36677 .39119 .36428 Mtetra
.39119 .36428 .39353 .36677 .39744 .36542 .3951 .36293 Mtetra
.3951 .36293 .39744 .36542 .40134 .36407 .39901 .36158 Mtetra
.39901 .36158 .40134 .36407 .40526 .36272 .40293 .36023 Mtetra
.40293 .36023 .40526 .36272 .40918 .36137 .40685 .35887 Mtetra
.40685 .35887 .40918 .36137 .4131 .36002 .41078 .35751 Mtetra
.41078 .35751 .4131 .36002 .41704 .35866 .41471 .35615 Mtetra
.41471 .35615 .41704 .35866 .42097 .35731 .41866 .35479 Mtetra
0 .076 .59 r
.41866 .35479 .42097 .35731 .42492 .35595 .42244 .3583 Mtetra
.127 0 0 r
.42244 .3583 .42492 .35595 .42872 .35945 .4264 .35694 Mtetra
.663 .742 .908 r
.4264 .35694 .42872 .35945 .43268 .35809 .43037 .35557 Mtetra
.43037 .35557 .43268 .35809 .43664 .35673 .43434 .35421 Mtetra
.43434 .35421 .43664 .35673 .44062 .35536 .43831 .35284 Mtetra
.43831 .35284 .44062 .35536 .44459 .35399 .44229 .35146 Mtetra
.44229 .35146 .44459 .35399 .44858 .35262 .44628 .35009 Mtetra
.44628 .35009 .44858 .35262 .45257 .35125 .45028 .34871 Mtetra
.45028 .34871 .45257 .35125 .45495 .42494 .45427 .34734 Mtetra
0 0 .352 r
.45427 .34734 .45495 .42494 .45904 .42359 .4567 .42109 Mtetra
.658 .749 .917 r
.4567 .42109 .45904 .42359 .46314 .42223 .46081 .41973 Mtetra
.46081 .41973 .46314 .42223 .46725 .42088 .46492 .41837 Mtetra
.46492 .41837 .46725 .42088 .47136 .41952 .46903 .41701 Mtetra
.46903 .41701 .47136 .41952 .47548 .41816 .47316 .41564 Mtetra
.47316 .41564 .47548 .41816 .47961 .4168 .47729 .41428 Mtetra
.47729 .41428 .47961 .4168 .48374 .41543 .48142 .41291 Mtetra
.48142 .41291 .48374 .41543 .48788 .41407 .48557 .41154 Mtetra
.48557 .41154 .48788 .41407 .49203 .4127 .48972 .41017 Mtetra
.48972 .41017 .49203 .4127 .49618 .41133 .49387 .40879 Mtetra
.49387 .40879 .49618 .41133 .50033 .40995 .49803 .40741 Mtetra
.49803 .40741 .50033 .40995 .5045 .40858 .5022 .40604 Mtetra
.5022 .40604 .5045 .40858 .50867 .4072 .50637 .40466 Mtetra
.50637 .40466 .50867 .4072 .51284 .40582 .51056 .40327 Mtetra
.51056 .40327 .51284 .40582 .51703 .40444 .51474 .40189 Mtetra
.51474 .40189 .51703 .40444 .52117 .43952 .51894 .4005 Mtetra
0 0 .425 r
.51894 .4005 .52117 .43952 .52542 .43814 .52312 .4356 Mtetra
.655 .752 .922 r
.52312 .4356 .52542 .43814 .52967 .43677 .52737 .43423 Mtetra
.52737 .43423 .52967 .43677 .53392 .43539 .53163 .43284 Mtetra
.53163 .43284 .53392 .43539 .53819 .43401 .5359 .43146 Mtetra
.5359 .43146 .53819 .43401 .54246 .43263 .54017 .43008 Mtetra
.54017 .43008 .54246 .43263 .54673 .43125 .54445 .42869 Mtetra
.54445 .42869 .54673 .43125 .55101 .42986 .54874 .4273 Mtetra
.54874 .4273 .55101 .42986 .5553 .42848 .55303 .42591 Mtetra
.55303 .42591 .5553 .42848 .5596 .42709 .55733 .42451 Mtetra
.55733 .42451 .5596 .42709 .5639 .42569 .56164 .42312 Mtetra
.56164 .42312 .5639 .42569 .56821 .4243 .56595 .42172 Mtetra
.971 .698 .457 r
.56595 .42172 .56821 .4243 .57081 .30565 .56863 .30299 Mtetra
.664 .741 .908 r
.56863 .30299 .57081 .30565 .57497 .30421 .5728 .30155 Mtetra
.5728 .30155 .57497 .30421 .57914 .30277 .57697 .30011 Mtetra
.57697 .30011 .57914 .30277 .58332 .30133 .58116 .29867 Mtetra
.58116 .29867 .58332 .30133 .5875 .29989 .58534 .29722 Mtetra
.58534 .29722 .5875 .29989 .59169 .29844 .58954 .29577 Mtetra
.58954 .29577 .59169 .29844 .59589 .297 .59374 .29432 Mtetra
.59374 .29432 .59589 .297 .60009 .29555 .59795 .29287 Mtetra
.59795 .29287 .60009 .29555 .6043 .2941 .60216 .29141 Mtetra
.60216 .29141 .6043 .2941 .60852 .29264 .60638 .28995 Mtetra
.60638 .28995 .60852 .29264 .61274 .29119 .61061 .28849 Mtetra
.61061 .28849 .61274 .29119 .61697 .28973 .61484 .28703 Mtetra
.61484 .28703 .61697 .28973 .6212 .28827 .61908 .28557 Mtetra
.61908 .28557 .6212 .28827 .62544 .28681 .62332 .2841 Mtetra
.62332 .2841 .62544 .28681 .62969 .28534 .62758 .28263 Mtetra
.62758 .28263 .62969 .28534 .63395 .28388 .63183 .28116 Mtetra
.63183 .28116 .63395 .28388 .63821 .28241 .6361 .27969 Mtetra
.6361 .27969 .63821 .28241 .64247 .28094 .64037 .27821 Mtetra
.925 .547 .147 r
.64037 .27821 .64247 .28094 .64675 .27946 .64542 .29663 Mtetra
.491 .218 .427 r
.64542 .29663 .64675 .27946 .65184 .29788 .64973 .29516 Mtetra
.662 .743 .91 r
.64973 .29516 .65184 .29788 .65615 .29641 .65405 .29368 Mtetra
.65405 .29368 .65615 .29641 .66047 .29493 .65837 .2922 Mtetra
.65837 .2922 .66047 .29493 .6648 .29345 .66271 .29072 Mtetra
.66271 .29072 .6648 .29345 .66913 .29198 .66705 .28924 Mtetra
.66705 .28924 .66913 .29198 .67347 .29049 .67139 .28775 Mtetra
.67139 .28775 .67347 .29049 .67782 .28901 .67574 .28627 Mtetra
.67574 .28627 .67782 .28901 .68218 .28753 .6801 .28478 Mtetra
.6801 .28478 .68218 .28753 .68654 .28604 .68447 .28328 Mtetra
.68447 .28328 .68654 .28604 .69091 .28455 .68884 .28179 Mtetra
.68884 .28179 .69091 .28455 .69528 .28305 .69322 .28029 Mtetra
.69322 .28029 .69528 .28305 .69966 .28156 .69761 .27879 Mtetra
.69761 .27879 .69966 .28156 .70405 .28006 .702 .27729 Mtetra
.702 .27729 .70405 .28006 .70845 .27856 .7064 .27579 Mtetra
.7064 .27579 .70845 .27856 .71285 .27706 .71081 .27428 Mtetra
.71081 .27428 .71285 .27706 .71726 .27556 .71522 .27277 Mtetra
.71522 .27277 .71726 .27556 .72167 .27405 .71964 .27126 Mtetra
.71964 .27126 .72167 .27405 .7261 .27254 .72407 .26975 Mtetra
.72407 .26975 .7261 .27254 .73815 .38581 .7285 .26823 Mtetra
.036 0 .44 r
.7285 .26823 .73815 .38581 .74276 .38434 .74068 .3816 Mtetra
.654 .754 .923 r
.74068 .3816 .74276 .38434 .74738 .38286 .7453 .38012 Mtetra
.7453 .38012 .74738 .38286 .752 .38138 .74993 .37863 Mtetra
.74993 .37863 .752 .38138 .75663 .37989 .75456 .37714 Mtetra
.75456 .37714 .75663 .37989 .76126 .3784 .7592 .37565 Mtetra
.7592 .37565 .76126 .3784 .76591 .37692 .76385 .37416 Mtetra
.76385 .37416 .76591 .37692 .77056 .37542 .76851 .37266 Mtetra
.76851 .37266 .77056 .37542 .77522 .37393 .77318 .37117 Mtetra
.77318 .37117 .77522 .37393 .77989 .37243 .77785 .36966 Mtetra
.77785 .36966 .77989 .37243 .78456 .37093 .78253 .36816 Mtetra
.78253 .36816 .78456 .37093 .78924 .36943 .78722 .36665 Mtetra
.78722 .36665 .78924 .36943 .79393 .36793 .79191 .36515 Mtetra
.79191 .36515 .79393 .36793 .79863 .36642 .79661 .36364 Mtetra
.79661 .36364 .79863 .36642 .80334 .36491 .80133 .36212 Mtetra
.80133 .36212 .80334 .36491 .80805 .3634 .80604 .36061 Mtetra
.80604 .36061 .80805 .3634 .81277 .36189 .81077 .35909 Mtetra
.81077 .35909 .81277 .36189 .8175 .36037 .8155 .35757 Mtetra
.8155 .35757 .8175 .36037 .82223 .35885 .82024 .35604 Mtetra
.82024 .35604 .82223 .35885 .82698 .35733 .82499 .35452 Mtetra
.82499 .35452 .82698 .35733 .83173 .35581 .82975 .35299 Mtetra
.82975 .35299 .83173 .35581 .83649 .35428 .83452 .35146 Mtetra
.83452 .35146 .83649 .35428 .84126 .35276 .83929 .34993 Mtetra
.653 .755 .925 r
.19778 .56298 .20041 .56522 .20421 .56401 .20158 .56176 Mtetra
.20158 .56176 .20421 .56401 .20801 .56279 .20539 .56054 Mtetra
.20539 .56054 .20801 .56279 .21182 .56157 .2092 .55932 Mtetra
.2092 .55932 .21182 .56157 .21564 .56035 .21302 .5581 Mtetra
.21302 .5581 .21564 .56035 .21946 .55913 .21685 .55688 Mtetra
.21685 .55688 .21946 .55913 .22329 .55791 .22068 .55565 Mtetra
.22068 .55565 .22329 .55791 .22712 .55669 .22452 .55442 Mtetra
.666 .151 0 r
.22452 .55442 .22712 .55669 .23051 .56069 .2279 .55842 Mtetra
.652 .755 .925 r
.2279 .55842 .23051 .56069 .23436 .55946 .23175 .5572 Mtetra
.23175 .5572 .23436 .55946 .23821 .55824 .23561 .55596 Mtetra
.23561 .55596 .23821 .55824 .24207 .55701 .23948 .55473 Mtetra
.23948 .55473 .24207 .55701 .24594 .55577 .24335 .5535 Mtetra
.24335 .5535 .24594 .55577 .24982 .55454 .24723 .55226 Mtetra
.24723 .55226 .24982 .55454 .25369 .55331 .25111 .55102 Mtetra
.25111 .55102 .25369 .55331 .25758 .55207 .255 .54978 Mtetra
.255 .54978 .25758 .55207 .26147 .55083 .25889 .54854 Mtetra
.25889 .54854 .26147 .55083 .26537 .54959 .26279 .5473 Mtetra
.26279 .5473 .26537 .54959 .26927 .54835 .26669 .54605 Mtetra
.26669 .54605 .26927 .54835 .27318 .54711 .27061 .5448 Mtetra
.27061 .5448 .27318 .54711 .27709 .54586 .27452 .54355 Mtetra
.27452 .54355 .27709 .54586 .29158 .39869 .27845 .5423 Mtetra
0 0 .168 r
.27845 .5423 .29158 .39869 .29534 .39739 .29291 .39498 Mtetra
.664 .741 .908 r
.29291 .39498 .29534 .39739 .29911 .39608 .29668 .39368 Mtetra
.29668 .39368 .29911 .39608 .30288 .39478 .30045 .39237 Mtetra
.30045 .39237 .30288 .39478 .30666 .39348 .30424 .39106 Mtetra
.30424 .39106 .30666 .39348 .31045 .39217 .30802 .38975 Mtetra
.30802 .38975 .31045 .39217 .31424 .39086 .31182 .38844 Mtetra
.31182 .38844 .31424 .39086 .31803 .38955 .31562 .38712 Mtetra
.31562 .38712 .31803 .38955 .32183 .38824 .31942 .38581 Mtetra
.31942 .38581 .32183 .38824 .32564 .38692 .32323 .38449 Mtetra
.32323 .38449 .32564 .38692 .32945 .38561 .32704 .38317 Mtetra
.32704 .38317 .32945 .38561 .33327 .38429 .33087 .38185 Mtetra
.33087 .38185 .33327 .38429 .33709 .38297 .33469 .38052 Mtetra
.33469 .38052 .33709 .38297 .34092 .38164 .33852 .3792 Mtetra
.33852 .3792 .34092 .38164 .34475 .38032 .34236 .37787 Mtetra
.34236 .37787 .34475 .38032 .34859 .37899 .3462 .37654 Mtetra
.3462 .37654 .34859 .37899 .35243 .37767 .35005 .37521 Mtetra
.35005 .37521 .35243 .37767 .35629 .37634 .3539 .37388 Mtetra
.3539 .37388 .35629 .37634 .36014 .375 .35776 .37254 Mtetra
.35776 .37254 .36014 .375 .364 .37367 .36163 .3712 Mtetra
.36163 .3712 .364 .37367 .36787 .37233 .3655 .36986 Mtetra
.3655 .36986 .36787 .37233 .37174 .371 .36937 .36852 Mtetra
.36937 .36852 .37174 .371 .37562 .36966 .37326 .36718 Mtetra
.37326 .36718 .37562 .36966 .3795 .36832 .37714 .36583 Mtetra
.37714 .36583 .3795 .36832 .38339 .36697 .38104 .36449 Mtetra
.38104 .36449 .38339 .36697 .38729 .36563 .38494 .36314 Mtetra
.38494 .36314 .38729 .36563 .39119 .36428 .38884 .36179 Mtetra
.38884 .36179 .39119 .36428 .3951 .36293 .39275 .36043 Mtetra
.39275 .36043 .3951 .36293 .39901 .36158 .39667 .35908 Mtetra
.39667 .35908 .39901 .36158 .40293 .36023 .40059 .35772 Mtetra
.40059 .35772 .40293 .36023 .40685 .35887 .40451 .35636 Mtetra
.40451 .35636 .40685 .35887 .41078 .35751 .40845 .355 Mtetra
.40845 .355 .41078 .35751 .41471 .35615 .41239 .35364 Mtetra
0 .073 .587 r
.41239 .35364 .41471 .35615 .41866 .35479 .41616 .35715 Mtetra
.124 0 0 r
.41616 .35715 .41866 .35479 .42244 .3583 .42012 .35578 Mtetra
.663 .742 .908 r
.42012 .35578 .42244 .3583 .4264 .35694 .42408 .35442 Mtetra
.42408 .35442 .4264 .35694 .43037 .35557 .42805 .35305 Mtetra
.42805 .35305 .43037 .35557 .43434 .35421 .43202 .35168 Mtetra
.43202 .35168 .43434 .35421 .43831 .35284 .436 .3503 Mtetra
.436 .3503 .43831 .35284 .44229 .35146 .43999 .34893 Mtetra
.43999 .34893 .44229 .35146 .44628 .35009 .44398 .34755 Mtetra
.44398 .34755 .44628 .35009 .45028 .34871 .44798 .34617 Mtetra
.44798 .34617 .45028 .34871 .45427 .34734 .45198 .34479 Mtetra
.963 .669 .426 r
.45198 .34479 .45427 .34734 .4567 .42109 .45435 .41858 Mtetra
.658 .749 .917 r
.45435 .41858 .4567 .42109 .46081 .41973 .45846 .41722 Mtetra
.45846 .41722 .46081 .41973 .46492 .41837 .46258 .41585 Mtetra
.46258 .41585 .46492 .41837 .46903 .41701 .4667 .41449 Mtetra
.4667 .41449 .46903 .41701 .47316 .41564 .47083 .41312 Mtetra
.47083 .41312 .47316 .41564 .47729 .41428 .47496 .41175 Mtetra
.47496 .41175 .47729 .41428 .48142 .41291 .4791 .41038 Mtetra
.4791 .41038 .48142 .41291 .48557 .41154 .48325 .409 Mtetra
.48325 .409 .48557 .41154 .48972 .41017 .4874 .40763 Mtetra
.4874 .40763 .48972 .41017 .49387 .40879 .49156 .40625 Mtetra
.49156 .40625 .49387 .40879 .49803 .40741 .49572 .40487 Mtetra
.49572 .40487 .49803 .40741 .5022 .40604 .4999 .40349 Mtetra
.4999 .40349 .5022 .40604 .50637 .40466 .50407 .4021 Mtetra
.50407 .4021 .50637 .40466 .51056 .40327 .50826 .40071 Mtetra
.50826 .40071 .51056 .40327 .51474 .40189 .51245 .39933 Mtetra
.51245 .39933 .51474 .40189 .51894 .4005 .51665 .39793 Mtetra
.51665 .39793 .51894 .4005 .52312 .4356 .52085 .39654 Mtetra
0 0 .425 r
.52085 .39654 .52312 .4356 .52737 .43423 .52506 .43167 Mtetra
.655 .752 .922 r
.52506 .43167 .52737 .43423 .53163 .43284 .52933 .43029 Mtetra
.52933 .43029 .53163 .43284 .5359 .43146 .5336 .4289 Mtetra
.5336 .4289 .5359 .43146 .54017 .43008 .53788 .42751 Mtetra
.53788 .42751 .54017 .43008 .54445 .42869 .54216 .42612 Mtetra
.54216 .42612 .54445 .42869 .54874 .4273 .54645 .42473 Mtetra
.54645 .42473 .54874 .4273 .55303 .42591 .55075 .42333 Mtetra
.55075 .42333 .55303 .42591 .55733 .42451 .55506 .42193 Mtetra
.55506 .42193 .55733 .42451 .56164 .42312 .55937 .42053 Mtetra
.55937 .42053 .56164 .42312 .56595 .42172 .56369 .41913 Mtetra
.971 .698 .457 r
.56369 .41913 .56595 .42172 .56863 .30299 .56645 .30033 Mtetra
.664 .741 .908 r
.56645 .30033 .56863 .30299 .5728 .30155 .57062 .29889 Mtetra
.57062 .29889 .5728 .30155 .57697 .30011 .5748 .29744 Mtetra
.5748 .29744 .57697 .30011 .58116 .29867 .57899 .29599 Mtetra
.57899 .29599 .58116 .29867 .58534 .29722 .58318 .29454 Mtetra
.58318 .29454 .58534 .29722 .58954 .29577 .58738 .29309 Mtetra
.58738 .29309 .58954 .29577 .59374 .29432 .59158 .29164 Mtetra
.59158 .29164 .59374 .29432 .59795 .29287 .5958 .29018 Mtetra
.5958 .29018 .59795 .29287 .60216 .29141 .60001 .28872 Mtetra
.60001 .28872 .60216 .29141 .60638 .28995 .60424 .28726 Mtetra
.60424 .28726 .60638 .28995 .61061 .28849 .60847 .28579 Mtetra
.60847 .28579 .61061 .28849 .61484 .28703 .6127 .28433 Mtetra
.6127 .28433 .61484 .28703 .61908 .28557 .61695 .28286 Mtetra
.61695 .28286 .61908 .28557 .62332 .2841 .6212 .28139 Mtetra
.6212 .28139 .62332 .2841 .62758 .28263 .62545 .27992 Mtetra
.62545 .27992 .62758 .28263 .63183 .28116 .62972 .27844 Mtetra
.62972 .27844 .63183 .28116 .6361 .27969 .63399 .27696 Mtetra
.63399 .27696 .6361 .27969 .64037 .27821 .63826 .27548 Mtetra
.925 .547 .147 r
.63826 .27548 .64037 .27821 .64542 .29663 .6433 .29391 Mtetra
.662 .743 .91 r
.6433 .29391 .64542 .29663 .64973 .29516 .64762 .29243 Mtetra
.64762 .29243 .64973 .29516 .65405 .29368 .65194 .29095 Mtetra
.65194 .29095 .65405 .29368 .65837 .2922 .65627 .28947 Mtetra
.65627 .28947 .65837 .2922 .66271 .29072 .66061 .28798 Mtetra
.66061 .28798 .66271 .29072 .66705 .28924 .66495 .2865 Mtetra
.66495 .2865 .66705 .28924 .67139 .28775 .6693 .28501 Mtetra
.6693 .28501 .67139 .28775 .67574 .28627 .67366 .28351 Mtetra
.67366 .28351 .67574 .28627 .6801 .28478 .67802 .28202 Mtetra
.67802 .28202 .6801 .28478 .68447 .28328 .68239 .28052 Mtetra
.68239 .28052 .68447 .28328 .68884 .28179 .68677 .27902 Mtetra
.68677 .27902 .68884 .28179 .69322 .28029 .69115 .27752 Mtetra
.69115 .27752 .69322 .28029 .69761 .27879 .69555 .27602 Mtetra
.69555 .27602 .69761 .27879 .702 .27729 .69994 .27451 Mtetra
.69994 .27451 .702 .27729 .7064 .27579 .70435 .273 Mtetra
.70435 .273 .7064 .27579 .71081 .27428 .70876 .27149 Mtetra
.70876 .27149 .71081 .27428 .71522 .27277 .71318 .26998 Mtetra
.71318 .26998 .71522 .27277 .71964 .27126 .7176 .26847 Mtetra
.7176 .26847 .71964 .27126 .72407 .26975 .72203 .26695 Mtetra
.72203 .26695 .72407 .26975 .7285 .26823 .72647 .26543 Mtetra
.97 .653 .313 r
.72647 .26543 .7285 .26823 .74068 .3816 .73859 .37886 Mtetra
.654 .754 .923 r
.73859 .37886 .74068 .3816 .7453 .38012 .74322 .37737 Mtetra
.74322 .37737 .7453 .38012 .74993 .37863 .74785 .37588 Mtetra
.74785 .37588 .74993 .37863 .75456 .37714 .75249 .37439 Mtetra
.75249 .37439 .75456 .37714 .7592 .37565 .75714 .37289 Mtetra
.75714 .37289 .7592 .37565 .76385 .37416 .76179 .3714 Mtetra
.76179 .3714 .76385 .37416 .76851 .37266 .76646 .3699 Mtetra
.76646 .3699 .76851 .37266 .77318 .37117 .77113 .36839 Mtetra
.77113 .36839 .77318 .37117 .77785 .36966 .7758 .36689 Mtetra
.7758 .36689 .77785 .36966 .78253 .36816 .78049 .36538 Mtetra
.78049 .36538 .78253 .36816 .78722 .36665 .78518 .36387 Mtetra
.78518 .36387 .78722 .36665 .79191 .36515 .78988 .36236 Mtetra
.78988 .36236 .79191 .36515 .79661 .36364 .79459 .36084 Mtetra
.79459 .36084 .79661 .36364 .80133 .36212 .79931 .35932 Mtetra
.79931 .35932 .80133 .36212 .80604 .36061 .80403 .3578 Mtetra
.80403 .3578 .80604 .36061 .81077 .35909 .80876 .35628 Mtetra
.80876 .35628 .81077 .35909 .8155 .35757 .8135 .35475 Mtetra
.8135 .35475 .8155 .35757 .82024 .35604 .81825 .35323 Mtetra
.81825 .35323 .82024 .35604 .82499 .35452 .823 .3517 Mtetra
.823 .3517 .82499 .35452 .82975 .35299 .82777 .35016 Mtetra
.82777 .35016 .82975 .35299 .83452 .35146 .83254 .34863 Mtetra
.83254 .34863 .83452 .35146 .83929 .34993 .83732 .34709 Mtetra
.653 .755 .925 r
.19514 .56073 .19778 .56298 .20158 .56176 .19895 .55951 Mtetra
.19895 .55951 .20158 .56176 .20539 .56054 .20276 .55829 Mtetra
.20276 .55829 .20539 .56054 .2092 .55932 .20658 .55706 Mtetra
.20658 .55706 .2092 .55932 .21302 .5581 .2104 .55584 Mtetra
.2104 .55584 .21302 .5581 .21685 .55688 .21423 .55461 Mtetra
.21423 .55461 .21685 .55688 .22068 .55565 .21806 .55338 Mtetra
.21806 .55338 .22068 .55565 .22452 .55442 .2219 .55215 Mtetra
.2219 .55215 .22452 .55442 .2279 .55842 .22575 .55092 Mtetra
.186 .236 .682 r
.22575 .55092 .2279 .55842 .23175 .5572 .22914 .55492 Mtetra
.652 .755 .925 r
.22914 .55492 .23175 .5572 .23561 .55596 .233 .55369 Mtetra
.233 .55369 .23561 .55596 .23948 .55473 .23687 .55245 Mtetra
.23687 .55245 .23948 .55473 .24335 .5535 .24075 .55121 Mtetra
.24075 .55121 .24335 .5535 .24723 .55226 .24463 .54997 Mtetra
.24463 .54997 .24723 .55226 .25111 .55102 .24851 .54873 Mtetra
.24851 .54873 .25111 .55102 .255 .54978 .2524 .54749 Mtetra
.2524 .54749 .255 .54978 .25889 .54854 .2563 .54624 Mtetra
.2563 .54624 .25889 .54854 .26279 .5473 .26021 .545 Mtetra
.26021 .545 .26279 .5473 .26669 .54605 .26411 .54375 Mtetra
.26411 .54375 .26669 .54605 .27061 .5448 .26803 .5425 Mtetra
.26803 .5425 .27061 .5448 .27452 .54355 .27195 .54124 Mtetra
.27195 .54124 .27452 .54355 .27845 .5423 .27588 .53999 Mtetra
.27588 .53999 .27845 .5423 .29291 .39498 .27981 .53873 Mtetra
0 0 .168 r
.27981 .53873 .29291 .39498 .29668 .39368 .29424 .39126 Mtetra
.664 .741 .908 r
.29424 .39126 .29668 .39368 .30045 .39237 .29802 .38995 Mtetra
.29802 .38995 .30045 .39237 .30424 .39106 .30181 .38864 Mtetra
.30181 .38864 .30424 .39106 .30802 .38975 .3056 .38733 Mtetra
.3056 .38733 .30802 .38975 .31182 .38844 .30939 .38601 Mtetra
.30939 .38601 .31182 .38844 .31562 .38712 .3132 .38469 Mtetra
.3132 .38469 .31562 .38712 .31942 .38581 .317 .38337 Mtetra
.317 .38337 .31942 .38581 .32323 .38449 .32082 .38205 Mtetra
.32082 .38205 .32323 .38449 .32704 .38317 .32463 .38073 Mtetra
.32463 .38073 .32704 .38317 .33087 .38185 .32846 .3794 Mtetra
.32846 .3794 .33087 .38185 .33469 .38052 .33229 .37807 Mtetra
.33229 .37807 .33469 .38052 .33852 .3792 .33612 .37675 Mtetra
.33612 .37675 .33852 .3792 .34236 .37787 .33996 .37541 Mtetra
.33996 .37541 .34236 .37787 .3462 .37654 .34381 .37408 Mtetra
.34381 .37408 .3462 .37654 .35005 .37521 .34766 .37275 Mtetra
.34766 .37275 .35005 .37521 .3539 .37388 .35152 .37141 Mtetra
.35152 .37141 .3539 .37388 .35776 .37254 .35538 .37007 Mtetra
.35538 .37007 .35776 .37254 .36163 .3712 .35925 .36873 Mtetra
.35925 .36873 .36163 .3712 .3655 .36986 .36312 .36739 Mtetra
.36312 .36739 .3655 .36986 .36937 .36852 .367 .36604 Mtetra
.367 .36604 .36937 .36852 .37326 .36718 .37089 .3647 Mtetra
.37089 .3647 .37326 .36718 .37714 .36583 .37478 .36335 Mtetra
.37478 .36335 .37714 .36583 .38104 .36449 .37867 .362 Mtetra
.37867 .362 .38104 .36449 .38494 .36314 .38258 .36064 Mtetra
.38258 .36064 .38494 .36314 .38884 .36179 .38648 .35929 Mtetra
.38648 .35929 .38884 .36179 .39275 .36043 .3904 .35793 Mtetra
.3904 .35793 .39275 .36043 .39667 .35908 .39432 .35657 Mtetra
.39432 .35657 .39667 .35908 .40059 .35772 .39824 .35521 Mtetra
.39824 .35521 .40059 .35772 .40451 .35636 .40217 .35385 Mtetra
.40217 .35385 .40451 .35636 .40845 .355 .40611 .35249 Mtetra
0 .07 .583 r
.40611 .35249 .40845 .355 .41239 .35364 .40987 .35599 Mtetra
.121 0 0 r
.40987 .35599 .41239 .35364 .41616 .35715 .41383 .35463 Mtetra
.663 .742 .908 r
.41383 .35463 .41616 .35715 .42012 .35578 .41779 .35326 Mtetra
.41779 .35326 .42012 .35578 .42408 .35442 .42175 .35189 Mtetra
.42175 .35189 .42408 .35442 .42805 .35305 .42573 .35051 Mtetra
.42573 .35051 .42805 .35305 .43202 .35168 .4297 .34914 Mtetra
.4297 .34914 .43202 .35168 .436 .3503 .43369 .34776 Mtetra
.43369 .34776 .436 .3503 .43999 .34893 .43768 .34638 Mtetra
.43768 .34638 .43999 .34893 .44398 .34755 .44167 .345 Mtetra
.44167 .345 .44398 .34755 .44798 .34617 .44567 .34362 Mtetra
.44567 .34362 .44798 .34617 .45198 .34479 .44968 .34223 Mtetra
.44968 .34223 .45198 .34479 .45435 .41858 .45369 .34084 Mtetra
0 0 .35 r
.45369 .34084 .45435 .41858 .45846 .41722 .45611 .4147 Mtetra
.658 .749 .917 r
.45611 .4147 .45846 .41722 .46258 .41585 .46023 .41333 Mtetra
.46023 .41333 .46258 .41585 .4667 .41449 .46436 .41196 Mtetra
.46436 .41196 .4667 .41449 .47083 .41312 .46849 .41059 Mtetra
.46849 .41059 .47083 .41312 .47496 .41175 .47263 .40921 Mtetra
.47263 .40921 .47496 .41175 .4791 .41038 .47677 .40784 Mtetra
.47677 .40784 .4791 .41038 .48325 .409 .48092 .40646 Mtetra
.48092 .40646 .48325 .409 .4874 .40763 .48508 .40508 Mtetra
.48508 .40508 .4874 .40763 .49156 .40625 .48924 .4037 Mtetra
.48924 .4037 .49156 .40625 .49572 .40487 .49341 .40231 Mtetra
.49341 .40231 .49572 .40487 .4999 .40349 .49759 .40093 Mtetra
.49759 .40093 .4999 .40349 .50407 .4021 .50177 .39954 Mtetra
.50177 .39954 .50407 .4021 .50826 .40071 .50596 .39815 Mtetra
.50596 .39815 .50826 .40071 .51245 .39933 .51015 .39676 Mtetra
.51015 .39676 .51245 .39933 .51665 .39793 .51435 .39536 Mtetra
.51435 .39536 .51665 .39793 .52085 .39654 .51856 .39396 Mtetra
.962 .637 .342 r
.51856 .39396 .52085 .39654 .52506 .43167 .52275 .42912 Mtetra
.655 .752 .922 r
.52275 .42912 .52506 .43167 .52933 .43029 .52702 .42773 Mtetra
.52702 .42773 .52933 .43029 .5336 .4289 .5313 .42634 Mtetra
.5313 .42634 .5336 .4289 .53788 .42751 .53558 .42494 Mtetra
.53558 .42494 .53788 .42751 .54216 .42612 .53987 .42355 Mtetra
.53987 .42355 .54216 .42612 .54645 .42473 .54416 .42215 Mtetra
.54416 .42215 .54645 .42473 .55075 .42333 .54847 .42075 Mtetra
.54847 .42075 .55075 .42333 .55506 .42193 .55278 .41935 Mtetra
.55278 .41935 .55506 .42193 .55937 .42053 .55709 .41794 Mtetra
.971 .698 .458 r
.55709 .41794 .55937 .42053 .56369 .41913 .56009 .29911 Mtetra
.544 .33 .539 r
.56009 .29911 .56369 .41913 .56645 .30033 .56426 .29767 Mtetra
.664 .741 .908 r
.56426 .29767 .56645 .30033 .57062 .29889 .56844 .29622 Mtetra
.56844 .29622 .57062 .29889 .5748 .29744 .57262 .29477 Mtetra
.57262 .29477 .5748 .29744 .57899 .29599 .57681 .29331 Mtetra
.57681 .29331 .57899 .29599 .58318 .29454 .58101 .29186 Mtetra
.58101 .29186 .58318 .29454 .58738 .29309 .58521 .2904 Mtetra
.58521 .2904 .58738 .29309 .59158 .29164 .58942 .28894 Mtetra
.58942 .28894 .59158 .29164 .5958 .29018 .59364 .28748 Mtetra
.59364 .28748 .5958 .29018 .60001 .28872 .59786 .28602 Mtetra
.59786 .28602 .60001 .28872 .60424 .28726 .60209 .28455 Mtetra
.60209 .28455 .60424 .28726 .60847 .28579 .60632 .28309 Mtetra
.60632 .28309 .60847 .28579 .6127 .28433 .61056 .28162 Mtetra
.61056 .28162 .6127 .28433 .61695 .28286 .61481 .28014 Mtetra
.61481 .28014 .61695 .28286 .6212 .28139 .61907 .27867 Mtetra
.61907 .27867 .6212 .28139 .62545 .27992 .62333 .27719 Mtetra
.62333 .27719 .62545 .27992 .62972 .27844 .62759 .27571 Mtetra
.62759 .27571 .62972 .27844 .63399 .27696 .63187 .27423 Mtetra
.63187 .27423 .63399 .27696 .63826 .27548 .63615 .27275 Mtetra
.925 .547 .147 r
.63615 .27275 .63826 .27548 .6433 .29391 .64118 .29118 Mtetra
.662 .743 .91 r
.64118 .29118 .6433 .29391 .64762 .29243 .6455 .2897 Mtetra
.6455 .2897 .64762 .29243 .65194 .29095 .64983 .28821 Mtetra
.64983 .28821 .65194 .29095 .65627 .28947 .65416 .28672 Mtetra
.65416 .28672 .65627 .28947 .66061 .28798 .6585 .28523 Mtetra
.6585 .28523 .66061 .28798 .66495 .2865 .66285 .28374 Mtetra
.66285 .28374 .66495 .2865 .6693 .28501 .66721 .28225 Mtetra
.66721 .28225 .6693 .28501 .67366 .28351 .67157 .28075 Mtetra
.67157 .28075 .67366 .28351 .67802 .28202 .67594 .27925 Mtetra
.67594 .27925 .67802 .28202 .68239 .28052 .68031 .27775 Mtetra
.68031 .27775 .68239 .28052 .68677 .27902 .68469 .27625 Mtetra
.68469 .27625 .68677 .27902 .69115 .27752 .68908 .27474 Mtetra
.68908 .27474 .69115 .27752 .69555 .27602 .69348 .27324 Mtetra
.69348 .27324 .69555 .27602 .69994 .27451 .69788 .27173 Mtetra
.69788 .27173 .69994 .27451 .70435 .273 .70229 .27021 Mtetra
.70229 .27021 .70435 .273 .70876 .27149 .70671 .2687 Mtetra
.70671 .2687 .70876 .27149 .71318 .26998 .71113 .26718 Mtetra
.71113 .26718 .71318 .26998 .7176 .26847 .71556 .26566 Mtetra
.71556 .26566 .7176 .26847 .72203 .26695 .72 .26414 Mtetra
.72 .26414 .72203 .26695 .72647 .26543 .72444 .26262 Mtetra
.97 .653 .313 r
.72444 .26262 .72647 .26543 .73859 .37886 .7365 .37611 Mtetra
.654 .754 .923 r
.7365 .37611 .73859 .37886 .74322 .37737 .74113 .37462 Mtetra
.74113 .37462 .74322 .37737 .74785 .37588 .74577 .37312 Mtetra
.74577 .37312 .74785 .37588 .75249 .37439 .75041 .37163 Mtetra
.75041 .37163 .75249 .37439 .75714 .37289 .75507 .37013 Mtetra
.75507 .37013 .75714 .37289 .76179 .3714 .75973 .36862 Mtetra
.75973 .36862 .76179 .3714 .76646 .3699 .76439 .36712 Mtetra
.76439 .36712 .76646 .3699 .77113 .36839 .76907 .36561 Mtetra
.76907 .36561 .77113 .36839 .7758 .36689 .77375 .3641 Mtetra
.77375 .3641 .7758 .36689 .78049 .36538 .77844 .36259 Mtetra
.77844 .36259 .78049 .36538 .78518 .36387 .78314 .36107 Mtetra
.78314 .36107 .78518 .36387 .78988 .36236 .78785 .35956 Mtetra
.78785 .35956 .78988 .36236 .79459 .36084 .79256 .35804 Mtetra
.79256 .35804 .79459 .36084 .79931 .35932 .79728 .35651 Mtetra
.79728 .35651 .79931 .35932 .80403 .3578 .80201 .35499 Mtetra
.80201 .35499 .80403 .3578 .80876 .35628 .80675 .35346 Mtetra
.80675 .35346 .80876 .35628 .8135 .35475 .81149 .35193 Mtetra
.81149 .35193 .8135 .35475 .81825 .35323 .81625 .3504 Mtetra
.81625 .3504 .81825 .35323 .823 .3517 .82101 .34886 Mtetra
.82101 .34886 .823 .3517 .82777 .35016 .82578 .34733 Mtetra
.82578 .34733 .82777 .35016 .83254 .34863 .83055 .34579 Mtetra
.83055 .34579 .83254 .34863 .83732 .34709 .83534 .34424 Mtetra
.653 .755 .925 r
.1925 .55848 .19514 .56073 .19895 .55951 .19631 .55725 Mtetra
.19631 .55725 .19895 .55951 .20276 .55829 .20012 .55603 Mtetra
.20012 .55603 .20276 .55829 .20658 .55706 .20394 .5548 Mtetra
.20394 .5548 .20658 .55706 .2104 .55584 .20777 .55357 Mtetra
.20777 .55357 .2104 .55584 .21423 .55461 .2116 .55234 Mtetra
.2116 .55234 .21423 .55461 .21806 .55338 .21544 .55111 Mtetra
.21544 .55111 .21806 .55338 .2219 .55215 .21928 .54988 Mtetra
.21928 .54988 .2219 .55215 .22575 .55092 .22313 .54864 Mtetra
.664 .148 0 r
.22313 .54864 .22575 .55092 .22914 .55492 .22652 .55264 Mtetra
.652 .755 .925 r
.22652 .55264 .22914 .55492 .233 .55369 .23039 .5514 Mtetra
.23039 .5514 .233 .55369 .23687 .55245 .23426 .55016 Mtetra
.23426 .55016 .23687 .55245 .24075 .55121 .23814 .54892 Mtetra
.23814 .54892 .24075 .55121 .24463 .54997 .24202 .54768 Mtetra
.24202 .54768 .24463 .54997 .24851 .54873 .24591 .54644 Mtetra
.24591 .54644 .24851 .54873 .2524 .54749 .24981 .54519 Mtetra
.24981 .54519 .2524 .54749 .2563 .54624 .25371 .54394 Mtetra
.25371 .54394 .2563 .54624 .26021 .545 .25761 .54269 Mtetra
.25761 .54269 .26021 .545 .26411 .54375 .26153 .54144 Mtetra
.26153 .54144 .26411 .54375 .26803 .5425 .26545 .54018 Mtetra
.26545 .54018 .26803 .5425 .27195 .54124 .26937 .53893 Mtetra
.26937 .53893 .27195 .54124 .27588 .53999 .2733 .53767 Mtetra
.2733 .53767 .27588 .53999 .27981 .53873 .27724 .53641 Mtetra
.944 .693 .527 r
.27724 .53641 .27981 .53873 .29424 .39126 .2918 .38884 Mtetra
.664 .741 .908 r
.2918 .38884 .29424 .39126 .29802 .38995 .29558 .38753 Mtetra
.29558 .38753 .29802 .38995 .30181 .38864 .29937 .38621 Mtetra
.29937 .38621 .30181 .38864 .3056 .38733 .30316 .3849 Mtetra
.30316 .3849 .3056 .38733 .30939 .38601 .30696 .38358 Mtetra
.30696 .38358 .30939 .38601 .3132 .38469 .31077 .38225 Mtetra
.31077 .38225 .3132 .38469 .317 .38337 .31458 .38093 Mtetra
.31458 .38093 .317 .38337 .32082 .38205 .31839 .37961 Mtetra
.31839 .37961 .32082 .38205 .32463 .38073 .32222 .37828 Mtetra
.32222 .37828 .32463 .38073 .32846 .3794 .32604 .37695 Mtetra
.32604 .37695 .32846 .3794 .33229 .37807 .32988 .37562 Mtetra
.32988 .37562 .33229 .37807 .33612 .37675 .33371 .37429 Mtetra
.33371 .37429 .33612 .37675 .33996 .37541 .33756 .37295 Mtetra
.33756 .37295 .33996 .37541 .34381 .37408 .34141 .37161 Mtetra
.34141 .37161 .34381 .37408 .34766 .37275 .34526 .37028 Mtetra
.34526 .37028 .34766 .37275 .35152 .37141 .34912 .36894 Mtetra
.34912 .36894 .35152 .37141 .35538 .37007 .35299 .36759 Mtetra
.35299 .36759 .35538 .37007 .35925 .36873 .35686 .36625 Mtetra
.35686 .36625 .35925 .36873 .36312 .36739 .36074 .3649 Mtetra
.36074 .3649 .36312 .36739 .367 .36604 .36462 .36355 Mtetra
.36462 .36355 .367 .36604 .37089 .3647 .36851 .3622 Mtetra
.36851 .3622 .37089 .3647 .37478 .36335 .3724 .36085 Mtetra
.3724 .36085 .37478 .36335 .37867 .362 .3763 .3595 Mtetra
.3763 .3595 .37867 .362 .38258 .36064 .38021 .35814 Mtetra
.38021 .35814 .38258 .36064 .38648 .35929 .38412 .35678 Mtetra
.38412 .35678 .38648 .35929 .3904 .35793 .38804 .35542 Mtetra
.38804 .35542 .3904 .35793 .39432 .35657 .39196 .35406 Mtetra
.39196 .35406 .39432 .35657 .39824 .35521 .39589 .3527 Mtetra
.39589 .3527 .39824 .35521 .40217 .35385 .39982 .35133 Mtetra
.39982 .35133 .40217 .35385 .40611 .35249 .40376 .34996 Mtetra
0 .07 .583 r
.40376 .34996 .40611 .35249 .40987 .35599 .40753 .35347 Mtetra
.663 .742 .908 r
.40753 .35347 .40987 .35599 .41383 .35463 .41149 .3521 Mtetra
.41149 .3521 .41383 .35463 .41779 .35326 .41545 .35072 Mtetra
.41545 .35072 .41779 .35326 .42175 .35189 .41942 .34935 Mtetra
.41942 .34935 .42175 .35189 .42573 .35051 .4234 .34797 Mtetra
.4234 .34797 .42573 .35051 .4297 .34914 .42738 .34659 Mtetra
.42738 .34659 .4297 .34914 .43369 .34776 .43136 .34521 Mtetra
.43136 .34521 .43369 .34776 .43768 .34638 .43536 .34383 Mtetra
.43536 .34383 .43768 .34638 .44167 .345 .43935 .34245 Mtetra
.43935 .34245 .44167 .345 .44567 .34362 .44336 .34106 Mtetra
.44336 .34106 .44567 .34362 .44968 .34223 .44737 .33967 Mtetra
.44737 .33967 .44968 .34223 .45369 .34084 .45139 .33828 Mtetra
.45139 .33828 .45369 .34084 .45611 .4147 .45541 .33688 Mtetra
0 0 .35 r
.45541 .33688 .45611 .4147 .46023 .41333 .45788 .4108 Mtetra
.658 .749 .917 r
.45788 .4108 .46023 .41333 .46436 .41196 .46201 .40943 Mtetra
.46201 .40943 .46436 .41196 .46849 .41059 .46614 .40805 Mtetra
.46614 .40805 .46849 .41059 .47263 .40921 .47028 .40667 Mtetra
.47028 .40667 .47263 .40921 .47677 .40784 .47443 .40529 Mtetra
.47443 .40529 .47677 .40784 .48092 .40646 .47859 .40391 Mtetra
.47859 .40391 .48092 .40646 .48508 .40508 .48275 .40253 Mtetra
.48275 .40253 .48508 .40508 .48924 .4037 .48692 .40114 Mtetra
.48692 .40114 .48924 .4037 .49341 .40231 .49109 .39975 Mtetra
.49109 .39975 .49341 .40231 .49759 .40093 .49527 .39836 Mtetra
.49527 .39836 .49759 .40093 .50177 .39954 .49946 .39697 Mtetra
.49946 .39697 .50177 .39954 .50596 .39815 .50365 .39558 Mtetra
.50365 .39558 .50596 .39815 .51015 .39676 .50785 .39418 Mtetra
.50785 .39418 .51015 .39676 .51435 .39536 .51205 .39278 Mtetra
.51205 .39278 .51435 .39536 .51856 .39396 .51627 .39138 Mtetra
.51627 .39138 .51856 .39396 .52275 .42912 .52049 .38998 Mtetra
0 0 .423 r
.52049 .38998 .52275 .42912 .52702 .42773 .52471 .42516 Mtetra
.655 .752 .922 r
.52471 .42516 .52702 .42773 .5313 .42634 .52899 .42376 Mtetra
.52899 .42376 .5313 .42634 .53558 .42494 .53328 .42237 Mtetra
.53328 .42237 .53558 .42494 .53987 .42355 .53757 .42097 Mtetra
.53757 .42097 .53987 .42355 .54416 .42215 .54187 .41956 Mtetra
.54187 .41956 .54416 .42215 .54847 .42075 .54618 .41816 Mtetra
.54618 .41816 .54847 .42075 .55278 .41935 .55049 .41675 Mtetra
.55049 .41675 .55278 .41935 .55709 .41794 .55481 .41535 Mtetra
.971 .698 .458 r
.55481 .41535 .55709 .41794 .56009 .29911 .55789 .29644 Mtetra
.664 .741 .908 r
.55789 .29644 .56009 .29911 .56426 .29767 .56207 .29499 Mtetra
.56207 .29499 .56426 .29767 .56844 .29622 .56625 .29354 Mtetra
.56625 .29354 .56844 .29622 .57262 .29477 .57044 .29208 Mtetra
.57044 .29208 .57262 .29477 .57681 .29331 .57463 .29063 Mtetra
.57463 .29063 .57681 .29331 .58101 .29186 .57883 .28917 Mtetra
.57883 .28917 .58101 .29186 .58521 .2904 .58304 .28771 Mtetra
.58304 .28771 .58521 .2904 .58942 .28894 .58725 .28624 Mtetra
.58725 .28624 .58942 .28894 .59364 .28748 .59147 .28478 Mtetra
.59147 .28478 .59364 .28748 .59786 .28602 .5957 .28331 Mtetra
.5957 .28331 .59786 .28602 .60209 .28455 .59993 .28184 Mtetra
.59993 .28184 .60209 .28455 .60632 .28309 .60417 .28037 Mtetra
.60417 .28037 .60632 .28309 .61056 .28162 .60842 .2789 Mtetra
.60842 .2789 .61056 .28162 .61481 .28014 .61267 .27742 Mtetra
.61267 .27742 .61481 .28014 .61907 .27867 .61693 .27594 Mtetra
.61693 .27594 .61907 .27867 .62333 .27719 .62119 .27446 Mtetra
.62119 .27446 .62333 .27719 .62759 .27571 .62546 .27298 Mtetra
.62546 .27298 .62759 .27571 .63187 .27423 .62974 .27149 Mtetra
.62974 .27149 .63187 .27423 .63615 .27275 .63403 .27 Mtetra
.925 .547 .147 r
.63403 .27 .63615 .27275 .64118 .29118 .63905 .28844 Mtetra
.662 .743 .91 r
.63905 .28844 .64118 .29118 .6455 .2897 .64338 .28695 Mtetra
.64338 .28695 .6455 .2897 .64983 .28821 .64771 .28546 Mtetra
.64771 .28546 .64983 .28821 .65416 .28672 .65205 .28397 Mtetra
.65205 .28397 .65416 .28672 .6585 .28523 .65639 .28248 Mtetra
.65639 .28248 .6585 .28523 .66285 .28374 .66075 .28098 Mtetra
.66075 .28098 .66285 .28374 .66721 .28225 .66511 .27949 Mtetra
.66511 .27949 .66721 .28225 .67157 .28075 .66947 .27798 Mtetra
.66947 .27798 .67157 .28075 .67594 .27925 .67384 .27648 Mtetra
.67384 .27648 .67594 .27925 .68031 .27775 .67822 .27498 Mtetra
.67822 .27498 .68031 .27775 .68469 .27625 .68261 .27347 Mtetra
.68261 .27347 .68469 .27625 .68908 .27474 .687 .27196 Mtetra
.687 .27196 .68908 .27474 .69348 .27324 .69141 .27045 Mtetra
.69141 .27045 .69348 .27324 .69788 .27173 .69581 .26893 Mtetra
.69581 .26893 .69788 .27173 .70229 .27021 .70023 .26742 Mtetra
.70023 .26742 .70229 .27021 .70671 .2687 .70465 .2659 Mtetra
.70465 .2659 .70671 .2687 .71113 .26718 .70907 .26437 Mtetra
.70907 .26437 .71113 .26718 .71556 .26566 .71351 .26285 Mtetra
.71351 .26285 .71556 .26566 .72 .26414 .71795 .26132 Mtetra
.71795 .26132 .72 .26414 .72444 .26262 .7224 .2598 Mtetra
.7224 .2598 .72444 .26262 .7365 .37611 .72685 .25826 Mtetra
.032 0 .438 r
.72685 .25826 .7365 .37611 .74113 .37462 .73904 .37186 Mtetra
.654 .754 .923 r
.73904 .37186 .74113 .37462 .74577 .37312 .74368 .37036 Mtetra
.74368 .37036 .74577 .37312 .75041 .37163 .74833 .36885 Mtetra
.74833 .36885 .75041 .37163 .75507 .37013 .75299 .36735 Mtetra
.75299 .36735 .75507 .37013 .75973 .36862 .75765 .36584 Mtetra
.75765 .36584 .75973 .36862 .76439 .36712 .76233 .36433 Mtetra
.76233 .36433 .76439 .36712 .76907 .36561 .76701 .36282 Mtetra
.76701 .36282 .76907 .36561 .77375 .3641 .77169 .36131 Mtetra
.77169 .36131 .77375 .3641 .77844 .36259 .77639 .35979 Mtetra
.77639 .35979 .77844 .36259 .78314 .36107 .78109 .35827 Mtetra
.78109 .35827 .78314 .36107 .78785 .35956 .78581 .35675 Mtetra
.78581 .35675 .78785 .35956 .79256 .35804 .79053 .35522 Mtetra
.79053 .35522 .79256 .35804 .79728 .35651 .79525 .3537 Mtetra
.79525 .3537 .79728 .35651 .80201 .35499 .79999 .35217 Mtetra
.79999 .35217 .80201 .35499 .80675 .35346 .80473 .35063 Mtetra
.80473 .35063 .80675 .35346 .81149 .35193 .80948 .3491 Mtetra
.80948 .3491 .81149 .35193 .81625 .3504 .81424 .34756 Mtetra
.81424 .34756 .81625 .3504 .82101 .34886 .819 .34602 Mtetra
.819 .34602 .82101 .34886 .82578 .34733 .82378 .34448 Mtetra
.82378 .34448 .82578 .34733 .83055 .34579 .82856 .34294 Mtetra
.82856 .34294 .83055 .34579 .83534 .34424 .83335 .34139 Mtetra
.653 .755 .925 r
.18985 .55622 .1925 .55848 .19631 .55725 .19366 .55499 Mtetra
.19366 .55499 .19631 .55725 .20012 .55603 .19748 .55376 Mtetra
.19748 .55376 .20012 .55603 .20394 .5548 .2013 .55253 Mtetra
.2013 .55253 .20394 .5548 .20777 .55357 .20513 .5513 Mtetra
.20513 .5513 .20777 .55357 .2116 .55234 .20897 .55007 Mtetra
.20897 .55007 .2116 .55234 .21544 .55111 .21281 .54883 Mtetra
.21281 .54883 .21544 .55111 .21928 .54988 .21666 .54759 Mtetra
.21666 .54759 .21928 .54988 .22313 .54864 .22051 .54635 Mtetra
.664 .148 0 r
.22051 .54635 .22313 .54864 .22652 .55264 .2239 .55036 Mtetra
.652 .755 .925 r
.2239 .55036 .22652 .55264 .23039 .5514 .22777 .54911 Mtetra
.22777 .54911 .23039 .5514 .23426 .55016 .23164 .54787 Mtetra
.23164 .54787 .23426 .55016 .23814 .54892 .23552 .54663 Mtetra
.23552 .54663 .23814 .54892 .24202 .54768 .23941 .54538 Mtetra
.23941 .54538 .24202 .54768 .24591 .54644 .2433 .54413 Mtetra
.2433 .54413 .24591 .54644 .24981 .54519 .2472 .54288 Mtetra
.2472 .54288 .24981 .54519 .25371 .54394 .25111 .54163 Mtetra
.25111 .54163 .25371 .54394 .25761 .54269 .25502 .54038 Mtetra
.25502 .54038 .25761 .54269 .26153 .54144 .25893 .53912 Mtetra
.25893 .53912 .26153 .54144 .26545 .54018 .26285 .53786 Mtetra
.26285 .53786 .26545 .54018 .26937 .53893 .26678 .5366 Mtetra
.26678 .5366 .26937 .53893 .2733 .53767 .27072 .53534 Mtetra
.27072 .53534 .2733 .53767 .27724 .53641 .27465 .53408 Mtetra
.27465 .53408 .27724 .53641 .2918 .38884 .2786 .53281 Mtetra
0 0 .165 r
.2786 .53281 .2918 .38884 .29558 .38753 .29313 .3851 Mtetra
.664 .741 .908 r
.29313 .3851 .29558 .38753 .29937 .38621 .29692 .38378 Mtetra
.29692 .38378 .29937 .38621 .30316 .3849 .30072 .38246 Mtetra
.30072 .38246 .30316 .3849 .30696 .38358 .30452 .38114 Mtetra
.30452 .38114 .30696 .38358 .31077 .38225 .30833 .37981 Mtetra
.30833 .37981 .31077 .38225 .31458 .38093 .31215 .37848 Mtetra
.31215 .37848 .31458 .38093 .31839 .37961 .31597 .37715 Mtetra
.31597 .37715 .31839 .37961 .32222 .37828 .31979 .37582 Mtetra
.31979 .37582 .32222 .37828 .32604 .37695 .32362 .37449 Mtetra
.32362 .37449 .32604 .37695 .32988 .37562 .32746 .37316 Mtetra
.32746 .37316 .32988 .37562 .33371 .37429 .3313 .37182 Mtetra
.3313 .37182 .33371 .37429 .33756 .37295 .33515 .37048 Mtetra
.33515 .37048 .33756 .37295 .34141 .37161 .339 .36914 Mtetra
.339 .36914 .34141 .37161 .34526 .37028 .34286 .3678 Mtetra
.34286 .3678 .34526 .37028 .34912 .36894 .34672 .36646 Mtetra
.34672 .36646 .34912 .36894 .35299 .36759 .35059 .36511 Mtetra
.35059 .36511 .35299 .36759 .35686 .36625 .35447 .36376 Mtetra
.35447 .36376 .35686 .36625 .36074 .3649 .35835 .36241 Mtetra
.35835 .36241 .36074 .3649 .36462 .36355 .36223 .36106 Mtetra
.36223 .36106 .36462 .36355 .36851 .3622 .36613 .35971 Mtetra
.36613 .35971 .36851 .3622 .3724 .36085 .37002 .35835 Mtetra
.37002 .35835 .3724 .36085 .3763 .3595 .37393 .35699 Mtetra
.37393 .35699 .3763 .3595 .38021 .35814 .37784 .35563 Mtetra
.37784 .35563 .38021 .35814 .38412 .35678 .38175 .35427 Mtetra
.38175 .35427 .38412 .35678 .38804 .35542 .38567 .35291 Mtetra
.38567 .35291 .38804 .35542 .39196 .35406 .3896 .35154 Mtetra
.3896 .35154 .39196 .35406 .39589 .3527 .39353 .35017 Mtetra
.39353 .35017 .39589 .3527 .39982 .35133 .39747 .3488 Mtetra
0 .067 .58 r
.39747 .3488 .39982 .35133 .40376 .34996 .40122 .35231 Mtetra
.115 0 0 r
.40122 .35231 .40376 .34996 .40753 .35347 .40518 .35094 Mtetra
.663 .742 .908 r
.40518 .35094 .40753 .35347 .41149 .3521 .40914 .34956 Mtetra
.40914 .34956 .41149 .3521 .41545 .35072 .41311 .34818 Mtetra
.41311 .34818 .41545 .35072 .41942 .34935 .41708 .34681 Mtetra
.41708 .34681 .41942 .34935 .4234 .34797 .42106 .34543 Mtetra
.42106 .34543 .4234 .34797 .42738 .34659 .42504 .34404 Mtetra
.42504 .34404 .42738 .34659 .43136 .34521 .42903 .34266 Mtetra
.42903 .34266 .43136 .34521 .43536 .34383 .43303 .34127 Mtetra
.43303 .34127 .43536 .34383 .43935 .34245 .43703 .33988 Mtetra
.43703 .33988 .43935 .34245 .44336 .34106 .44104 .33849 Mtetra
.44104 .33849 .44336 .34106 .44737 .33967 .44506 .3371 Mtetra
.44506 .3371 .44737 .33967 .45139 .33828 .44908 .3357 Mtetra
.44908 .3357 .45139 .33828 .45541 .33688 .4531 .33431 Mtetra
.964 .669 .423 r
.4531 .33431 .45541 .33688 .45788 .4108 .45552 .40826 Mtetra
.658 .749 .917 r
.45552 .40826 .45788 .4108 .46201 .40943 .45965 .40688 Mtetra
.45965 .40688 .46201 .40943 .46614 .40805 .46379 .40551 Mtetra
.46379 .40551 .46614 .40805 .47028 .40667 .46794 .40412 Mtetra
.46794 .40412 .47028 .40667 .47443 .40529 .47209 .40274 Mtetra
.47209 .40274 .47443 .40529 .47859 .40391 .47625 .40135 Mtetra
.47625 .40135 .47859 .40391 .48275 .40253 .48041 .39997 Mtetra
.48041 .39997 .48275 .40253 .48692 .40114 .48458 .39858 Mtetra
.48458 .39858 .48692 .40114 .49109 .39975 .48876 .39718 Mtetra
.48876 .39718 .49109 .39975 .49527 .39836 .49295 .39579 Mtetra
.49295 .39579 .49527 .39836 .49946 .39697 .49714 .39439 Mtetra
.49714 .39439 .49946 .39697 .50365 .39558 .50133 .393 Mtetra
.50133 .393 .50365 .39558 .50785 .39418 .50554 .39159 Mtetra
.50554 .39159 .50785 .39418 .51205 .39278 .50975 .39019 Mtetra
.50975 .39019 .51205 .39278 .51627 .39138 .51396 .38879 Mtetra
.51396 .38879 .51627 .39138 .52049 .38998 .51819 .38738 Mtetra
.51819 .38738 .52049 .38998 .52471 .42516 .52242 .38597 Mtetra
0 0 .423 r
.52242 .38597 .52471 .42516 .52899 .42376 .52667 .42118 Mtetra
.655 .752 .922 r
.52667 .42118 .52899 .42376 .53328 .42237 .53096 .41978 Mtetra
.53096 .41978 .53328 .42237 .53757 .42097 .53526 .41838 Mtetra
.53526 .41838 .53757 .42097 .54187 .41956 .53957 .41697 Mtetra
.53957 .41697 .54187 .41956 .54618 .41816 .54388 .41556 Mtetra
.54388 .41556 .54618 .41816 .55049 .41675 .5482 .41415 Mtetra
.5482 .41415 .55049 .41675 .55481 .41535 .55252 .41274 Mtetra
.971 .698 .458 r
.55252 .41274 .55481 .41535 .55789 .29644 .55569 .29376 Mtetra
.664 .741 .908 r
.55569 .29376 .55789 .29644 .56207 .29499 .55987 .29231 Mtetra
.55987 .29231 .56207 .29499 .56625 .29354 .56405 .29085 Mtetra
.56405 .29085 .56625 .29354 .57044 .29208 .56825 .28939 Mtetra
.56825 .28939 .57044 .29208 .57463 .29063 .57245 .28793 Mtetra
.57245 .28793 .57463 .29063 .57883 .28917 .57665 .28647 Mtetra
.57665 .28647 .57883 .28917 .58304 .28771 .58086 .285 Mtetra
.58086 .285 .58304 .28771 .58725 .28624 .58508 .28354 Mtetra
.58508 .28354 .58725 .28624 .59147 .28478 .5893 .28207 Mtetra
.5893 .28207 .59147 .28478 .5957 .28331 .59353 .2806 Mtetra
.59353 .2806 .5957 .28331 .59993 .28184 .59777 .27912 Mtetra
.59777 .27912 .59993 .28184 .60417 .28037 .60201 .27765 Mtetra
.60201 .27765 .60417 .28037 .60842 .2789 .60626 .27617 Mtetra
.60626 .27617 .60842 .2789 .61267 .27742 .61052 .27469 Mtetra
.61052 .27469 .61267 .27742 .61693 .27594 .61478 .2732 Mtetra
.61478 .2732 .61693 .27594 .62119 .27446 .61905 .27172 Mtetra
.61905 .27172 .62119 .27446 .62546 .27298 .62333 .27023 Mtetra
.62333 .27023 .62546 .27298 .62974 .27149 .62761 .26874 Mtetra
.62761 .26874 .62974 .27149 .63403 .27 .6319 .26725 Mtetra
.925 .547 .147 r
.6319 .26725 .63403 .27 .63905 .28844 .63691 .28569 Mtetra
.662 .743 .91 r
.63691 .28569 .63905 .28844 .64338 .28695 .64125 .2842 Mtetra
.64125 .2842 .64338 .28695 .64771 .28546 .64558 .28271 Mtetra
.64558 .28271 .64771 .28546 .65205 .28397 .64993 .28121 Mtetra
.64993 .28121 .65205 .28397 .65639 .28248 .65428 .27972 Mtetra
.65428 .27972 .65639 .28248 .66075 .28098 .65863 .27822 Mtetra
.65863 .27822 .66075 .28098 .66511 .27949 .663 .27671 Mtetra
.663 .27671 .66511 .27949 .66947 .27798 .66737 .27521 Mtetra
.66737 .27521 .66947 .27798 .67384 .27648 .67175 .2737 Mtetra
.67175 .2737 .67384 .27648 .67822 .27498 .67613 .27219 Mtetra
.67613 .27219 .67822 .27498 .68261 .27347 .68052 .27068 Mtetra
.68052 .27068 .68261 .27347 .687 .27196 .68492 .26917 Mtetra
.68492 .26917 .687 .27196 .69141 .27045 .68933 .26765 Mtetra
.68933 .26765 .69141 .27045 .69581 .26893 .69374 .26613 Mtetra
.69374 .26613 .69581 .26893 .70023 .26742 .69816 .26461 Mtetra
.69816 .26461 .70023 .26742 .70465 .2659 .70258 .26309 Mtetra
.70258 .26309 .70465 .2659 .70907 .26437 .70701 .26156 Mtetra
.70701 .26156 .70907 .26437 .71351 .26285 .71145 .26003 Mtetra
.71145 .26003 .71351 .26285 .71795 .26132 .7159 .2585 Mtetra
.7159 .2585 .71795 .26132 .7224 .2598 .72035 .25697 Mtetra
.72035 .25697 .7224 .2598 .72685 .25826 .72481 .25543 Mtetra
.97 .652 .311 r
.72481 .25543 .72685 .25826 .73904 .37186 .73693 .36909 Mtetra
.654 .754 .923 r
.73693 .36909 .73904 .37186 .74368 .37036 .74158 .36758 Mtetra
.74158 .36758 .74368 .37036 .74833 .36885 .74624 .36607 Mtetra
.74624 .36607 .74833 .36885 .75299 .36735 .7509 .36457 Mtetra
.7509 .36457 .75299 .36735 .75765 .36584 .75557 .36305 Mtetra
.75557 .36305 .75765 .36584 .76233 .36433 .76025 .36154 Mtetra
.76025 .36154 .76233 .36433 .76701 .36282 .76494 .36002 Mtetra
.76494 .36002 .76701 .36282 .77169 .36131 .76963 .3585 Mtetra
.76963 .3585 .77169 .36131 .77639 .35979 .77433 .35698 Mtetra
.77433 .35698 .77639 .35979 .78109 .35827 .77904 .35546 Mtetra
.77904 .35546 .78109 .35827 .78581 .35675 .78376 .35393 Mtetra
.78376 .35393 .78581 .35675 .79053 .35522 .78848 .3524 Mtetra
.78848 .3524 .79053 .35522 .79525 .3537 .79322 .35087 Mtetra
.79322 .35087 .79525 .3537 .79999 .35217 .79796 .34934 Mtetra
.79796 .34934 .79999 .35217 .80473 .35063 .8027 .3478 Mtetra
.8027 .3478 .80473 .35063 .80948 .3491 .80746 .34626 Mtetra
.80746 .34626 .80948 .3491 .81424 .34756 .81222 .34472 Mtetra
.81222 .34472 .81424 .34756 .819 .34602 .817 .34317 Mtetra
.817 .34317 .819 .34602 .82378 .34448 .82178 .34163 Mtetra
.82178 .34163 .82378 .34448 .82856 .34294 .82656 .34008 Mtetra
.82656 .34008 .82856 .34294 .83335 .34139 .83136 .33853 Mtetra
.653 .755 .925 r
.18719 .55395 .18985 .55622 .19366 .55499 .19101 .55272 Mtetra
.19101 .55272 .19366 .55499 .19748 .55376 .19483 .55149 Mtetra
.19483 .55149 .19748 .55376 .2013 .55253 .19866 .55026 Mtetra
.19866 .55026 .2013 .55253 .20513 .5513 .20249 .54902 Mtetra
.20249 .54902 .20513 .5513 .20897 .55007 .20633 .54778 Mtetra
.20633 .54778 .20897 .55007 .21281 .54883 .21017 .54654 Mtetra
.21017 .54654 .21281 .54883 .21666 .54759 .21402 .5453 Mtetra
.21402 .5453 .21666 .54759 .22051 .54635 .21788 .54406 Mtetra
.21788 .54406 .22051 .54635 .2239 .55036 .22174 .54282 Mtetra
.183 .234 .681 r
.22174 .54282 .2239 .55036 .22777 .54911 .22514 .54682 Mtetra
.652 .755 .925 r
.22514 .54682 .22777 .54911 .23164 .54787 .22902 .54557 Mtetra
.22902 .54557 .23164 .54787 .23552 .54663 .2329 .54432 Mtetra
.2329 .54432 .23552 .54663 .23941 .54538 .23679 .54307 Mtetra
.23679 .54307 .23941 .54538 .2433 .54413 .24069 .54182 Mtetra
.24069 .54182 .2433 .54413 .2472 .54288 .24459 .54057 Mtetra
.24459 .54057 .2472 .54288 .25111 .54163 .2485 .53931 Mtetra
.2485 .53931 .25111 .54163 .25502 .54038 .25241 .53806 Mtetra
.25241 .53806 .25502 .54038 .25893 .53912 .25633 .5368 Mtetra
.25633 .5368 .25893 .53912 .26285 .53786 .26026 .53553 Mtetra
.26026 .53553 .26285 .53786 .26678 .5366 .26419 .53427 Mtetra
.26419 .53427 .26678 .5366 .27072 .53534 .26812 .53301 Mtetra
.26812 .53301 .27072 .53534 .27465 .53408 .27207 .53174 Mtetra
.27207 .53174 .27465 .53408 .2786 .53281 .27602 .53047 Mtetra
.27602 .53047 .2786 .53281 .29313 .3851 .27997 .5292 Mtetra
0 0 .165 r
.27997 .5292 .29313 .3851 .29692 .38378 .29447 .38134 Mtetra
.664 .741 .908 r
.29447 .38134 .29692 .38378 .30072 .38246 .29827 .38001 Mtetra
.29827 .38001 .30072 .38246 .30452 .38114 .30208 .37869 Mtetra
.30208 .37869 .30452 .38114 .30833 .37981 .30589 .37736 Mtetra
.30589 .37736 .30833 .37981 .31215 .37848 .30971 .37603 Mtetra
.30971 .37603 .31215 .37848 .31597 .37715 .31353 .3747 Mtetra
.31353 .3747 .31597 .37715 .31979 .37582 .31736 .37336 Mtetra
.31736 .37336 .31979 .37582 .32362 .37449 .32119 .37203 Mtetra
.32119 .37203 .32362 .37449 .32746 .37316 .32503 .37069 Mtetra
.32503 .37069 .32746 .37316 .3313 .37182 .32888 .36935 Mtetra
.32888 .36935 .3313 .37182 .33515 .37048 .33273 .36801 Mtetra
.33273 .36801 .33515 .37048 .339 .36914 .33659 .36666 Mtetra
.33659 .36666 .339 .36914 .34286 .3678 .34045 .36532 Mtetra
.34045 .36532 .34286 .3678 .34672 .36646 .34432 .36397 Mtetra
.34432 .36397 .34672 .36646 .35059 .36511 .34819 .36262 Mtetra
.34819 .36262 .35059 .36511 .35447 .36376 .35207 .36127 Mtetra
.35207 .36127 .35447 .36376 .35835 .36241 .35595 .35991 Mtetra
.35595 .35991 .35835 .36241 .36223 .36106 .35984 .35856 Mtetra
.35984 .35856 .36223 .36106 .36613 .35971 .36374 .3572 Mtetra
.36374 .3572 .36613 .35971 .37002 .35835 .36764 .35584 Mtetra
.36764 .35584 .37002 .35835 .37393 .35699 .37155 .35448 Mtetra
.37155 .35448 .37393 .35699 .37784 .35563 .37546 .35312 Mtetra
.37546 .35312 .37784 .35563 .38175 .35427 .37938 .35175 Mtetra
.37938 .35175 .38175 .35427 .38567 .35291 .3833 .35038 Mtetra
.3833 .35038 .38567 .35291 .3896 .35154 .38723 .34901 Mtetra
.38723 .34901 .3896 .35154 .39353 .35017 .39117 .34764 Mtetra
0 .064 .576 r
.39117 .34764 .39353 .35017 .39747 .3488 .39491 .35115 Mtetra
.112 0 0 r
.39491 .35115 .39747 .3488 .40122 .35231 .39886 .34977 Mtetra
.663 .742 .908 r
.39886 .34977 .40122 .35231 .40518 .35094 .40282 .3484 Mtetra
.40282 .3484 .40518 .35094 .40914 .34956 .40679 .34702 Mtetra
.40679 .34702 .40914 .34956 .41311 .34818 .41076 .34564 Mtetra
.41076 .34564 .41311 .34818 .41708 .34681 .41473 .34426 Mtetra
.41473 .34426 .41708 .34681 .42106 .34543 .41872 .34287 Mtetra
.41872 .34287 .42106 .34543 .42504 .34404 .4227 .34149 Mtetra
.4227 .34149 .42504 .34404 .42903 .34266 .4267 .3401 Mtetra
.4267 .3401 .42903 .34266 .43303 .34127 .4307 .33871 Mtetra
.4307 .33871 .43303 .34127 .43703 .33988 .43471 .33731 Mtetra
.43471 .33731 .43703 .33988 .44104 .33849 .43872 .33592 Mtetra
.43872 .33592 .44104 .33849 .44506 .3371 .44274 .33452 Mtetra
.44274 .33452 .44506 .3371 .44908 .3357 .44676 .33312 Mtetra
.44676 .33312 .44908 .3357 .4531 .33431 .45079 .33172 Mtetra
.45079 .33172 .4531 .33431 .45552 .40826 .45483 .33032 Mtetra
0 0 .348 r
.45483 .33032 .45552 .40826 .45965 .40688 .45729 .40434 Mtetra
.658 .749 .917 r
.45729 .40434 .45965 .40688 .46379 .40551 .46143 .40295 Mtetra
.46143 .40295 .46379 .40551 .46794 .40412 .46558 .40157 Mtetra
.46558 .40157 .46794 .40412 .47209 .40274 .46974 .40018 Mtetra
.46974 .40018 .47209 .40274 .47625 .40135 .4739 .39879 Mtetra
.4739 .39879 .47625 .40135 .48041 .39997 .47807 .3974 Mtetra
.47807 .3974 .48041 .39997 .48458 .39858 .48225 .396 Mtetra
.48225 .396 .48458 .39858 .48876 .39718 .48643 .39461 Mtetra
.48643 .39461 .48876 .39718 .49295 .39579 .49062 .39321 Mtetra
.49062 .39321 .49295 .39579 .49714 .39439 .49481 .39181 Mtetra
.49481 .39181 .49714 .39439 .50133 .393 .49901 .39041 Mtetra
.49901 .39041 .50133 .393 .50554 .39159 .50322 .389 Mtetra
.50322 .389 .50554 .39159 .50975 .39019 .50743 .3876 Mtetra
.50743 .3876 .50975 .39019 .51396 .38879 .51166 .38619 Mtetra
.966 .705 .487 r
.51166 .38619 .51396 .38879 .51819 .38738 .51608 .31396 Mtetra
.547 .336 .546 r
.51608 .31396 .51819 .38738 .52242 .38597 .52022 .31253 Mtetra
.52022 .31253 .52242 .38597 .52667 .42118 .52437 .31109 Mtetra
.543 .329 .539 r
.52437 .31109 .52667 .42118 .53096 .41978 .52852 .30965 Mtetra
.52852 .30965 .53096 .41978 .53526 .41838 .53268 .30821 Mtetra
.53268 .30821 .53526 .41838 .53957 .41697 .53685 .30676 Mtetra
.53685 .30676 .53957 .41697 .54388 .41556 .54102 .30532 Mtetra
.54102 .30532 .54388 .41556 .5482 .41415 .5452 .30387 Mtetra
.5452 .30387 .5482 .41415 .55252 .41274 .54938 .30242 Mtetra
.576 .354 .542 r
.54938 .30242 .55252 .41274 .55569 .29376 .55348 .29108 Mtetra
.664 .741 .908 r
.55348 .29108 .55569 .29376 .55987 .29231 .55766 .28962 Mtetra
.55766 .28962 .55987 .29231 .56405 .29085 .56185 .28816 Mtetra
.56185 .28816 .56405 .29085 .56825 .28939 .56605 .28669 Mtetra
.56605 .28669 .56825 .28939 .57245 .28793 .57025 .28523 Mtetra
.57025 .28523 .57245 .28793 .57665 .28647 .57446 .28376 Mtetra
.57446 .28376 .57665 .28647 .58086 .285 .57868 .28229 Mtetra
.57868 .28229 .58086 .285 .58508 .28354 .5829 .28082 Mtetra
.5829 .28082 .58508 .28354 .5893 .28207 .58713 .27935 Mtetra
.58713 .27935 .5893 .28207 .59353 .2806 .59136 .27787 Mtetra
.59136 .27787 .59353 .2806 .59777 .27912 .5956 .2764 Mtetra
.5956 .2764 .59777 .27912 .60201 .27765 .59985 .27492 Mtetra
.59985 .27492 .60201 .27765 .60626 .27617 .60411 .27343 Mtetra
.60411 .27343 .60626 .27617 .61052 .27469 .60837 .27195 Mtetra
.60837 .27195 .61052 .27469 .61478 .2732 .61263 .27046 Mtetra
.61263 .27046 .61478 .2732 .61905 .27172 .61691 .26897 Mtetra
.61691 .26897 .61905 .27172 .62333 .27023 .62119 .26748 Mtetra
.886 .482 .048 r
.62119 .26748 .62333 .27023 .62761 .26874 .62596 .28091 Mtetra
.465 .169 .378 r
.62596 .28091 .62761 .26874 .6319 .26725 .63028 .27942 Mtetra
.63028 .27942 .6319 .26725 .63691 .28569 .6346 .27793 Mtetra
.328 .333 .713 r
.6346 .27793 .63691 .28569 .64125 .2842 .63911 .28144 Mtetra
.662 .743 .91 r
.63911 .28144 .64125 .2842 .64558 .28271 .64345 .27995 Mtetra
.64345 .27995 .64558 .28271 .64993 .28121 .6478 .27845 Mtetra
.6478 .27845 .64993 .28121 .65428 .27972 .65215 .27694 Mtetra
.65215 .27694 .65428 .27972 .65863 .27822 .65652 .27544 Mtetra
.65652 .27544 .65863 .27822 .663 .27671 .66089 .27393 Mtetra
.66089 .27393 .663 .27671 .66737 .27521 .66526 .27242 Mtetra
.66526 .27242 .66737 .27521 .67175 .2737 .66964 .27091 Mtetra
.66964 .27091 .67175 .2737 .67613 .27219 .67403 .2694 Mtetra
.67403 .2694 .67613 .27219 .68052 .27068 .67843 .26788 Mtetra
.67843 .26788 .68052 .27068 .68492 .26917 .68283 .26636 Mtetra
.68283 .26636 .68492 .26917 .68933 .26765 .68724 .26484 Mtetra
.68724 .26484 .68933 .26765 .69374 .26613 .69166 .26332 Mtetra
.69166 .26332 .69374 .26613 .69816 .26461 .69608 .26179 Mtetra
.69608 .26179 .69816 .26461 .70258 .26309 .70051 .26027 Mtetra
.70051 .26027 .70258 .26309 .70701 .26156 .70495 .25874 Mtetra
.70495 .25874 .70701 .26156 .71145 .26003 .70939 .2572 Mtetra
.70939 .2572 .71145 .26003 .7159 .2585 .71384 .25567 Mtetra
.71384 .25567 .7159 .2585 .72035 .25697 .7183 .25413 Mtetra
.7183 .25413 .72035 .25697 .72481 .25543 .72277 .25259 Mtetra
.97 .652 .311 r
.72277 .25259 .72481 .25543 .73693 .36909 .73483 .36631 Mtetra
.654 .754 .923 r
.73483 .36631 .73693 .36909 .74158 .36758 .73948 .3648 Mtetra
.73948 .3648 .74158 .36758 .74624 .36607 .74414 .36329 Mtetra
.74414 .36329 .74624 .36607 .7509 .36457 .74881 .36177 Mtetra
.74881 .36177 .7509 .36457 .75557 .36305 .75349 .36026 Mtetra
.75349 .36026 .75557 .36305 .76025 .36154 .75817 .35874 Mtetra
.75817 .35874 .76025 .36154 .76494 .36002 .76286 .35722 Mtetra
.76286 .35722 .76494 .36002 .76963 .3585 .76756 .35569 Mtetra
.76756 .35569 .76963 .3585 .77433 .35698 .77227 .35417 Mtetra
.77227 .35417 .77433 .35698 .77904 .35546 .77698 .35264 Mtetra
.77698 .35264 .77904 .35546 .78376 .35393 .78171 .35111 Mtetra
.78171 .35111 .78376 .35393 .78848 .3524 .78644 .34957 Mtetra
.78644 .34957 .78848 .3524 .79322 .35087 .79117 .34804 Mtetra
.79117 .34804 .79322 .35087 .79796 .34934 .79592 .3465 Mtetra
.79592 .3465 .79796 .34934 .8027 .3478 .80067 .34496 Mtetra
.80067 .34496 .8027 .3478 .80746 .34626 .80543 .34341 Mtetra
.80543 .34341 .80746 .34626 .81222 .34472 .8102 .34187 Mtetra
.8102 .34187 .81222 .34472 .817 .34317 .81498 .34032 Mtetra
.81498 .34032 .817 .34317 .82178 .34163 .81977 .33876 Mtetra
.81977 .33876 .82178 .34163 .82656 .34008 .82456 .33721 Mtetra
.82456 .33721 .82656 .34008 .83136 .33853 .82936 .33565 Mtetra
.653 .755 .925 r
.18453 .55168 .18719 .55395 .19101 .55272 .18835 .55045 Mtetra
.18835 .55045 .19101 .55272 .19483 .55149 .19217 .54921 Mtetra
.19217 .54921 .19483 .55149 .19866 .55026 .196 .54797 Mtetra
.196 .54797 .19866 .55026 .20249 .54902 .19984 .54674 Mtetra
.19984 .54674 .20249 .54902 .20633 .54778 .20368 .54549 Mtetra
.20368 .54549 .20633 .54778 .21017 .54654 .20753 .54425 Mtetra
.20753 .54425 .21017 .54654 .21402 .5453 .21138 .54301 Mtetra
.21138 .54301 .21402 .5453 .21788 .54406 .21524 .54176 Mtetra
.21524 .54176 .21788 .54406 .22174 .54282 .2191 .54051 Mtetra
.661 .145 0 r
.2191 .54051 .22174 .54282 .22514 .54682 .2225 .54452 Mtetra
.652 .755 .925 r
.2225 .54452 .22514 .54682 .22902 .54557 .22638 .54327 Mtetra
.22638 .54327 .22902 .54557 .2329 .54432 .23027 .54201 Mtetra
.23027 .54201 .2329 .54432 .23679 .54307 .23417 .54076 Mtetra
.23417 .54076 .23679 .54307 .24069 .54182 .23807 .53951 Mtetra
.23807 .53951 .24069 .54182 .24459 .54057 .24197 .53825 Mtetra
.24197 .53825 .24459 .54057 .2485 .53931 .24588 .53699 Mtetra
.24588 .53699 .2485 .53931 .25241 .53806 .2498 .53573 Mtetra
.2498 .53573 .25241 .53806 .25633 .5368 .25372 .53447 Mtetra
.25372 .53447 .25633 .5368 .26026 .53553 .25765 .5332 Mtetra
.25765 .5332 .26026 .53553 .26419 .53427 .26158 .53193 Mtetra
.26158 .53193 .26419 .53427 .26812 .53301 .26553 .53067 Mtetra
.26553 .53067 .26812 .53301 .27207 .53174 .26947 .5294 Mtetra
.26947 .5294 .27207 .53174 .27602 .53047 .27342 .52812 Mtetra
.27342 .52812 .27602 .53047 .27997 .5292 .27738 .52685 Mtetra
.945 .693 .525 r
.27738 .52685 .27997 .5292 .29447 .38134 .29202 .37889 Mtetra
.664 .741 .908 r
.29202 .37889 .29447 .38134 .29827 .38001 .29582 .37756 Mtetra
.29582 .37756 .29827 .38001 .30208 .37869 .29963 .37623 Mtetra
.29963 .37623 .30208 .37869 .30589 .37736 .30345 .3749 Mtetra
.30345 .3749 .30589 .37736 .30971 .37603 .30727 .37357 Mtetra
.30727 .37357 .30971 .37603 .31353 .3747 .31109 .37223 Mtetra
.31109 .37223 .31353 .3747 .31736 .37336 .31492 .37089 Mtetra
.31492 .37089 .31736 .37336 .32119 .37203 .31876 .36955 Mtetra
.31876 .36955 .32119 .37203 .32503 .37069 .3226 .36821 Mtetra
.3226 .36821 .32503 .37069 .32888 .36935 .32645 .36687 Mtetra
.32645 .36687 .32888 .36935 .33273 .36801 .33031 .36552 Mtetra
.33031 .36552 .33273 .36801 .33659 .36666 .33417 .36418 Mtetra
.33417 .36418 .33659 .36666 .34045 .36532 .33803 .36283 Mtetra
.33803 .36283 .34045 .36532 .34432 .36397 .3419 .36148 Mtetra
.3419 .36148 .34432 .36397 .34819 .36262 .34578 .36012 Mtetra
.34578 .36012 .34819 .36262 .35207 .36127 .34966 .35877 Mtetra
.34966 .35877 .35207 .36127 .35595 .35991 .35355 .35741 Mtetra
.35355 .35741 .35595 .35991 .35984 .35856 .35744 .35605 Mtetra
.35744 .35605 .35984 .35856 .36374 .3572 .36134 .35469 Mtetra
.36134 .35469 .36374 .3572 .36764 .35584 .36525 .35333 Mtetra
.36525 .35333 .36764 .35584 .37155 .35448 .36916 .35196 Mtetra
.36916 .35196 .37155 .35448 .37546 .35312 .37307 .35059 Mtetra
.37307 .35059 .37546 .35312 .37938 .35175 .37699 .34922 Mtetra
.37699 .34922 .37938 .35175 .3833 .35038 .38092 .34785 Mtetra
.38092 .34785 .3833 .35038 .38723 .34901 .38486 .34648 Mtetra
.38486 .34648 .38723 .34901 .39117 .34764 .3888 .3451 Mtetra
0 .064 .576 r
.3888 .3451 .39117 .34764 .39491 .35115 .39254 .34861 Mtetra
.663 .742 .908 r
.39254 .34861 .39491 .35115 .39886 .34977 .39649 .34723 Mtetra
.39649 .34723 .39886 .34977 .40282 .3484 .40046 .34585 Mtetra
.40046 .34585 .40282 .3484 .40679 .34702 .40443 .34447 Mtetra
.40443 .34447 .40679 .34702 .41076 .34564 .4084 .34308 Mtetra
.4084 .34308 .41076 .34564 .41473 .34426 .41238 .3417 Mtetra
.41238 .3417 .41473 .34426 .41872 .34287 .41637 .34031 Mtetra
.41637 .34031 .41872 .34287 .4227 .34149 .42036 .33892 Mtetra
.42036 .33892 .4227 .34149 .4267 .3401 .42436 .33753 Mtetra
.42436 .33753 .4267 .3401 .4307 .33871 .42836 .33613 Mtetra
.42836 .33613 .4307 .33871 .43471 .33731 .43237 .33474 Mtetra
.43237 .33474 .43471 .33731 .43872 .33592 .43639 .33334 Mtetra
.43639 .33334 .43872 .33592 .44274 .33452 .44041 .33194 Mtetra
.44041 .33194 .44274 .33452 .44676 .33312 .44444 .33054 Mtetra
.44444 .33054 .44676 .33312 .45079 .33172 .44847 .32913 Mtetra
.44847 .32913 .45079 .33172 .45483 .33032 .45251 .32772 Mtetra
.964 .669 .421 r
.45251 .32772 .45483 .33032 .45729 .40434 .45492 .40178 Mtetra
.658 .749 .917 r
.45492 .40178 .45729 .40434 .46143 .40295 .45907 .40039 Mtetra
.45907 .40039 .46143 .40295 .46558 .40157 .46322 .399 Mtetra
.46322 .399 .46558 .40157 .46974 .40018 .46738 .39761 Mtetra
.46738 .39761 .46974 .40018 .4739 .39879 .47155 .39622 Mtetra
.47155 .39622 .4739 .39879 .47807 .3974 .47572 .39482 Mtetra
.47572 .39482 .47807 .3974 .48225 .396 .4799 .39343 Mtetra
.4799 .39343 .48225 .396 .48643 .39461 .48409 .39203 Mtetra
.48409 .39203 .48643 .39461 .49062 .39321 .48828 .39062 Mtetra
.48828 .39062 .49062 .39321 .49481 .39181 .49248 .38922 Mtetra
.49248 .38922 .49481 .39181 .49901 .39041 .49668 .38781 Mtetra
.49668 .38781 .49901 .39041 .50322 .389 .5009 .3864 Mtetra
.5009 .3864 .50322 .389 .50743 .3876 .50511 .38499 Mtetra
.966 .705 .488 r
.50511 .38499 .50743 .3876 .51166 .38619 .50968 .31275 Mtetra
.546 .336 .546 r
.50968 .31275 .51166 .38619 .51608 .31396 .51382 .31131 Mtetra
.663 .742 .909 r
.51382 .31131 .51608 .31396 .52022 .31253 .51797 .30987 Mtetra
.51797 .30987 .52022 .31253 .52437 .31109 .52212 .30843 Mtetra
.52212 .30843 .52437 .31109 .52852 .30965 .52627 .30698 Mtetra
.52627 .30698 .52852 .30965 .53268 .30821 .53044 .30554 Mtetra
.53044 .30554 .53268 .30821 .53685 .30676 .53461 .30409 Mtetra
.53461 .30409 .53685 .30676 .54102 .30532 .53878 .30264 Mtetra
.53878 .30264 .54102 .30532 .5452 .30387 .54296 .30119 Mtetra
.54296 .30119 .5452 .30387 .54938 .30242 .54715 .29973 Mtetra
.932 .765 .652 r
.54715 .29973 .54938 .30242 .55348 .29108 .55126 .28838 Mtetra
.664 .741 .908 r
.55126 .28838 .55348 .29108 .55766 .28962 .55545 .28692 Mtetra
.55545 .28692 .55766 .28962 .56185 .28816 .55965 .28546 Mtetra
.55965 .28546 .56185 .28816 .56605 .28669 .56385 .28399 Mtetra
.56385 .28399 .56605 .28669 .57025 .28523 .56805 .28252 Mtetra
.56805 .28252 .57025 .28523 .57446 .28376 .57227 .28105 Mtetra
.57227 .28105 .57446 .28376 .57868 .28229 .57649 .27958 Mtetra
.57649 .27958 .57868 .28229 .5829 .28082 .58071 .2781 Mtetra
.58071 .2781 .5829 .28082 .58713 .27935 .58495 .27662 Mtetra
.58495 .27662 .58713 .27935 .59136 .27787 .58918 .27514 Mtetra
.58918 .27514 .59136 .27787 .5956 .2764 .59343 .27366 Mtetra
.59343 .27366 .5956 .2764 .59985 .27492 .59768 .27218 Mtetra
.59768 .27218 .59985 .27492 .60411 .27343 .60194 .27069 Mtetra
.60194 .27069 .60411 .27343 .60837 .27195 .60621 .2692 Mtetra
.60621 .2692 .60837 .27195 .61263 .27046 .61048 .26771 Mtetra
.61048 .26771 .61263 .27046 .61691 .26897 .61476 .26622 Mtetra
.888 .484 .052 r
.61476 .26622 .61691 .26897 .62119 .26748 .6195 .27965 Mtetra
.464 .168 .377 r
.6195 .27965 .62119 .26748 .62596 .28091 .62381 .27816 Mtetra
.663 .743 .91 r
.62381 .27816 .62596 .28091 .63028 .27942 .62813 .27666 Mtetra
.62813 .27666 .63028 .27942 .6346 .27793 .63245 .27516 Mtetra
.63245 .27516 .6346 .27793 .63911 .28144 .63679 .27366 Mtetra
.616 .513 .715 r
.63679 .27366 .63911 .28144 .64345 .27995 .64112 .27216 Mtetra
.329 .334 .713 r
.64112 .27216 .64345 .27995 .6478 .27845 .64567 .27567 Mtetra
.662 .743 .91 r
.64567 .27567 .6478 .27845 .65215 .27694 .65003 .27417 Mtetra
.65003 .27417 .65215 .27694 .65652 .27544 .65439 .27266 Mtetra
.65439 .27266 .65652 .27544 .66089 .27393 .65877 .27115 Mtetra
.65877 .27115 .66089 .27393 .66526 .27242 .66315 .26963 Mtetra
.66315 .26963 .66526 .27242 .66964 .27091 .66753 .26812 Mtetra
.66753 .26812 .66964 .27091 .67403 .2694 .67193 .2666 Mtetra
.67193 .2666 .67403 .2694 .67843 .26788 .67633 .26508 Mtetra
.67633 .26508 .67843 .26788 .68283 .26636 .68073 .26355 Mtetra
.68073 .26355 .68283 .26636 .68724 .26484 .68515 .26203 Mtetra
.68515 .26203 .68724 .26484 .69166 .26332 .68957 .2605 Mtetra
.68957 .2605 .69166 .26332 .69608 .26179 .694 .25897 Mtetra
.694 .25897 .69608 .26179 .70051 .26027 .69843 .25744 Mtetra
.69843 .25744 .70051 .26027 .70495 .25874 .70288 .2559 Mtetra
.70288 .2559 .70495 .25874 .70939 .2572 .70732 .25437 Mtetra
.70732 .25437 .70939 .2572 .71384 .25567 .71178 .25283 Mtetra
.71178 .25283 .71384 .25567 .7183 .25413 .71624 .25129 Mtetra
.71624 .25129 .7183 .25413 .72277 .25259 .72071 .24974 Mtetra
.972 .657 .319 r
.72071 .24974 .72277 .25259 .73483 .36631 .7345 .39095 Mtetra
.502 .24 .449 r
.7345 .39095 .73483 .36631 .73948 .3648 .7392 .38944 Mtetra
.7392 .38944 .73948 .3648 .74414 .36329 .74391 .38794 Mtetra
.74391 .38794 .74414 .36329 .74881 .36177 .74863 .38643 Mtetra
.74863 .38643 .74881 .36177 .75349 .36026 .75335 .38492 Mtetra
.75335 .38492 .75349 .36026 .75817 .35874 .75808 .3834 Mtetra
0 0 .299 r
.75808 .3834 .75817 .35874 .76286 .35722 .76078 .3544 Mtetra
.654 .754 .923 r
.76078 .3544 .76286 .35722 .76756 .35569 .76549 .35287 Mtetra
.76549 .35287 .76756 .35569 .77227 .35417 .7702 .35134 Mtetra
.7702 .35134 .77227 .35417 .77698 .35264 .77492 .34981 Mtetra
.77492 .34981 .77698 .35264 .78171 .35111 .77965 .34827 Mtetra
.77965 .34827 .78171 .35111 .78644 .34957 .78438 .34673 Mtetra
.78438 .34673 .78644 .34957 .79117 .34804 .78913 .34519 Mtetra
.78913 .34519 .79117 .34804 .79592 .3465 .79388 .34365 Mtetra
.79388 .34365 .79592 .3465 .80067 .34496 .79864 .3421 Mtetra
.79864 .3421 .80067 .34496 .80543 .34341 .8034 .34056 Mtetra
.8034 .34056 .80543 .34341 .8102 .34187 .80818 .339 Mtetra
.80818 .339 .8102 .34187 .81498 .34032 .81296 .33745 Mtetra
.81296 .33745 .81498 .34032 .81977 .33876 .81775 .33589 Mtetra
.81775 .33589 .81977 .33876 .82456 .33721 .82255 .33433 Mtetra
.82255 .33433 .82456 .33721 .82936 .33565 .82736 .33277 Mtetra
.653 .755 .925 r
.18185 .5494 .18453 .55168 .18835 .55045 .18568 .54816 Mtetra
.18568 .54816 .18835 .55045 .19217 .54921 .18951 .54693 Mtetra
.18951 .54693 .19217 .54921 .196 .54797 .19334 .54569 Mtetra
.19334 .54569 .196 .54797 .19984 .54674 .19718 .54444 Mtetra
.19718 .54444 .19984 .54674 .20368 .54549 .20102 .5432 Mtetra
.20102 .5432 .20368 .54549 .20753 .54425 .20487 .54195 Mtetra
.20487 .54195 .20753 .54425 .21138 .54301 .20873 .54071 Mtetra
.20873 .54071 .21138 .54301 .21524 .54176 .21259 .53946 Mtetra
.21259 .53946 .21524 .54176 .2191 .54051 .21646 .53821 Mtetra
.21646 .53821 .2191 .54051 .2225 .54452 .22034 .53695 Mtetra
.181 .233 .68 r
.22034 .53695 .2225 .54452 .22638 .54327 .22374 .54095 Mtetra
.652 .755 .925 r
.22374 .54095 .22638 .54327 .23027 .54201 .22764 .5397 Mtetra
.22764 .5397 .23027 .54201 .23417 .54076 .23153 .53844 Mtetra
.23153 .53844 .23417 .54076 .23807 .53951 .23544 .53718 Mtetra
.23544 .53718 .23807 .53951 .24197 .53825 .23934 .53592 Mtetra
.23934 .53592 .24197 .53825 .24588 .53699 .24326 .53466 Mtetra
.24326 .53466 .24588 .53699 .2498 .53573 .24718 .5334 Mtetra
.24718 .5334 .2498 .53573 .25372 .53447 .25111 .53213 Mtetra
.25111 .53213 .25372 .53447 .25765 .5332 .25504 .53086 Mtetra
.25504 .53086 .25765 .5332 .26158 .53193 .25898 .52959 Mtetra
.25898 .52959 .26158 .53193 .26553 .53067 .26292 .52832 Mtetra
.26292 .52832 .26553 .53067 .26947 .5294 .26687 .52704 Mtetra
.26687 .52704 .26947 .5294 .27342 .52812 .27083 .52577 Mtetra
.27083 .52577 .27342 .52812 .27738 .52685 .27479 .52449 Mtetra
.27479 .52449 .27738 .52685 .29202 .37889 .27876 .52321 Mtetra
0 0 .162 r
.27876 .52321 .29202 .37889 .29582 .37756 .29336 .37511 Mtetra
.664 .741 .908 r
.29336 .37511 .29582 .37756 .29963 .37623 .29717 .37377 Mtetra
.29717 .37377 .29963 .37623 .30345 .3749 .30099 .37244 Mtetra
.30099 .37244 .30345 .3749 .30727 .37357 .30482 .3711 Mtetra
.30482 .3711 .30727 .37357 .31109 .37223 .30865 .36976 Mtetra
.30865 .36976 .31109 .37223 .31492 .37089 .31248 .36842 Mtetra
.31248 .36842 .31492 .37089 .31876 .36955 .31632 .36708 Mtetra
.31632 .36708 .31876 .36955 .3226 .36821 .32017 .36573 Mtetra
.32017 .36573 .3226 .36821 .32645 .36687 .32402 .36438 Mtetra
.32402 .36438 .32645 .36687 .33031 .36552 .32788 .36303 Mtetra
.32788 .36303 .33031 .36552 .33417 .36418 .33174 .36168 Mtetra
.33174 .36168 .33417 .36418 .33803 .36283 .33561 .36033 Mtetra
.33561 .36033 .33803 .36283 .3419 .36148 .33948 .35898 Mtetra
.33948 .35898 .3419 .36148 .34578 .36012 .34336 .35762 Mtetra
.34336 .35762 .34578 .36012 .34966 .35877 .34725 .35626 Mtetra
.34725 .35626 .34966 .35877 .35355 .35741 .35114 .3549 Mtetra
.35114 .3549 .35355 .35741 .35744 .35605 .35504 .35354 Mtetra
.35504 .35354 .35744 .35605 .36134 .35469 .35894 .35217 Mtetra
.35894 .35217 .36134 .35469 .36525 .35333 .36285 .3508 Mtetra
.36285 .3508 .36525 .35333 .36916 .35196 .36676 .34943 Mtetra
.36676 .34943 .36916 .35196 .37307 .35059 .37068 .34806 Mtetra
.37068 .34806 .37307 .35059 .37699 .34922 .37461 .34669 Mtetra
.37461 .34669 .37699 .34922 .38092 .34785 .37854 .34532 Mtetra
.37854 .34532 .38092 .34785 .38486 .34648 .38248 .34394 Mtetra
.38248 .34394 .38486 .34648 .3888 .3451 .38642 .34256 Mtetra
0 .064 .576 r
.38642 .34256 .3888 .3451 .39254 .34861 .39016 .34606 Mtetra
.663 .742 .908 r
.39016 .34606 .39254 .34861 .39649 .34723 .39412 .34468 Mtetra
.39412 .34468 .39649 .34723 .40046 .34585 .39809 .3433 Mtetra
.39809 .3433 .40046 .34585 .40443 .34447 .40206 .34191 Mtetra
.40206 .34191 .40443 .34447 .4084 .34308 .40604 .34052 Mtetra
.40604 .34052 .4084 .34308 .41238 .3417 .41002 .33913 Mtetra
.41002 .33913 .41238 .3417 .41637 .34031 .41401 .33774 Mtetra
.41401 .33774 .41637 .34031 .42036 .33892 .41801 .33635 Mtetra
.41801 .33635 .42036 .33892 .42436 .33753 .42201 .33495 Mtetra
.42201 .33495 .42436 .33753 .42836 .33613 .42602 .33355 Mtetra
.42602 .33355 .42836 .33613 .43237 .33474 .43003 .33215 Mtetra
.43003 .33215 .43237 .33474 .43639 .33334 .43405 .33075 Mtetra
.43405 .33075 .43639 .33334 .44041 .33194 .43808 .32935 Mtetra
.43808 .32935 .44041 .33194 .44444 .33054 .44211 .32794 Mtetra
.44211 .32794 .44444 .33054 .44847 .32913 .44614 .32653 Mtetra
.44614 .32653 .44847 .32913 .45251 .32772 .45019 .32512 Mtetra
.45019 .32512 .45251 .32772 .45492 .40178 .45424 .32371 Mtetra
0 0 .346 r
.45424 .32371 .45492 .40178 .45907 .40039 .45669 .39783 Mtetra
.658 .749 .917 r
.45669 .39783 .45907 .40039 .46322 .399 .46085 .39643 Mtetra
.46085 .39643 .46322 .399 .46738 .39761 .46502 .39504 Mtetra
.46502 .39504 .46738 .39761 .47155 .39622 .46919 .39364 Mtetra
.46919 .39364 .47155 .39622 .47572 .39482 .47337 .39224 Mtetra
.47337 .39224 .47572 .39482 .4799 .39343 .47755 .39084 Mtetra
.47755 .39084 .4799 .39343 .48409 .39203 .48174 .38944 Mtetra
.48174 .38944 .48409 .39203 .48828 .39062 .48594 .38803 Mtetra
.48594 .38803 .48828 .39062 .49248 .38922 .49014 .38662 Mtetra
.49014 .38662 .49248 .38922 .49668 .38781 .49435 .38521 Mtetra
.49435 .38521 .49668 .38781 .5009 .3864 .49857 .3838 Mtetra
.966 .705 .489 r
.49857 .3838 .5009 .3864 .50511 .38499 .50328 .31153 Mtetra
.546 .335 .545 r
.50328 .31153 .50511 .38499 .50968 .31275 .50741 .31009 Mtetra
.663 .742 .909 r
.50741 .31009 .50968 .31275 .51382 .31131 .51155 .30865 Mtetra
.51155 .30865 .51382 .31131 .51797 .30987 .5157 .30721 Mtetra
.5157 .30721 .51797 .30987 .52212 .30843 .51986 .30576 Mtetra
.51986 .30576 .52212 .30843 .52627 .30698 .52402 .30431 Mtetra
.52402 .30431 .52627 .30698 .53044 .30554 .52819 .30286 Mtetra
.52819 .30286 .53044 .30554 .53461 .30409 .53236 .30141 Mtetra
.53236 .30141 .53461 .30409 .53878 .30264 .53654 .29996 Mtetra
.53654 .29996 .53878 .30264 .54296 .30119 .54073 .2985 Mtetra
.54073 .2985 .54296 .30119 .54715 .29973 .54492 .29704 Mtetra
.932 .765 .652 r
.54492 .29704 .54715 .29973 .55126 .28838 .54904 .28568 Mtetra
.664 .741 .908 r
.54904 .28568 .55126 .28838 .55545 .28692 .55323 .28421 Mtetra
.55323 .28421 .55545 .28692 .55965 .28546 .55743 .28275 Mtetra
.55743 .28275 .55965 .28546 .56385 .28399 .56164 .28128 Mtetra
.56164 .28128 .56385 .28399 .56805 .28252 .56585 .2798 Mtetra
.56585 .2798 .56805 .28252 .57227 .28105 .57007 .27833 Mtetra
.57007 .27833 .57227 .28105 .57649 .27958 .57429 .27685 Mtetra
.57429 .27685 .57649 .27958 .58071 .2781 .57852 .27537 Mtetra
.57852 .27537 .58071 .2781 .58495 .27662 .58276 .27389 Mtetra
.58276 .27389 .58495 .27662 .58918 .27514 .587 .2724 Mtetra
.587 .2724 .58918 .27514 .59343 .27366 .59125 .27092 Mtetra
.59125 .27092 .59343 .27366 .59768 .27218 .59551 .26943 Mtetra
.59551 .26943 .59768 .27218 .60194 .27069 .59977 .26794 Mtetra
.59977 .26794 .60194 .27069 .60621 .2692 .60404 .26645 Mtetra
.60404 .26645 .60621 .2692 .61048 .26771 .60832 .26495 Mtetra
.889 .486 .056 r
.60832 .26495 .61048 .26771 .61476 .26622 .61302 .27839 Mtetra
.463 .166 .376 r
.61302 .27839 .61476 .26622 .6195 .27965 .61733 .27689 Mtetra
.663 .743 .91 r
.61733 .27689 .6195 .27965 .62381 .27816 .62165 .27539 Mtetra
.62165 .27539 .62381 .27816 .62813 .27666 .62597 .27389 Mtetra
.62597 .27389 .62813 .27666 .63245 .27516 .6303 .27239 Mtetra
.6303 .27239 .63245 .27516 .63679 .27366 .63464 .27089 Mtetra
.63464 .27089 .63679 .27366 .64112 .27216 .63898 .26938 Mtetra
.63898 .26938 .64112 .27216 .64567 .27567 .64333 .26787 Mtetra
.329 .334 .713 r
.64333 .26787 .64567 .27567 .65003 .27417 .64789 .27138 Mtetra
.662 .743 .91 r
.64789 .27138 .65003 .27417 .65439 .27266 .65226 .26987 Mtetra
.65226 .26987 .65439 .27266 .65877 .27115 .65664 .26835 Mtetra
.65664 .26835 .65877 .27115 .66315 .26963 .66103 .26683 Mtetra
.66103 .26683 .66315 .26963 .66753 .26812 .66542 .26531 Mtetra
.66542 .26531 .66753 .26812 .67193 .2666 .66982 .26379 Mtetra
.66982 .26379 .67193 .2666 .67633 .26508 .67422 .26226 Mtetra
.67422 .26226 .67633 .26508 .68073 .26355 .67863 .26074 Mtetra
.67863 .26074 .68073 .26355 .68515 .26203 .68305 .25921 Mtetra
.68305 .25921 .68515 .26203 .68957 .2605 .68748 .25768 Mtetra
.68748 .25768 .68957 .2605 .694 .25897 .69191 .25614 Mtetra
.69191 .25614 .694 .25897 .69843 .25744 .69635 .2546 Mtetra
.69635 .2546 .69843 .25744 .70288 .2559 .7008 .25306 Mtetra
.7008 .25306 .70288 .2559 .70732 .25437 .70525 .25152 Mtetra
.70525 .25152 .70732 .25437 .71178 .25283 .70971 .24998 Mtetra
.70971 .24998 .71178 .25283 .71624 .25129 .71418 .24843 Mtetra
.972 .657 .321 r
.71418 .24843 .71624 .25129 .72071 .24974 .72767 .38968 Mtetra
.53 .299 .51 r
.72767 .38968 .72071 .24974 .7345 .39095 .73237 .38817 Mtetra
.651 .757 .927 r
.73237 .38817 .7345 .39095 .7392 .38944 .73707 .38666 Mtetra
.73707 .38666 .7392 .38944 .74391 .38794 .74179 .38515 Mtetra
.74179 .38515 .74391 .38794 .74863 .38643 .74651 .38364 Mtetra
.74651 .38364 .74863 .38643 .75335 .38492 .75124 .38212 Mtetra
.75124 .38212 .75335 .38492 .75808 .3834 .75597 .3806 Mtetra
.75597 .3806 .75808 .3834 .76078 .3544 .76072 .37908 Mtetra
.501 .238 .448 r
.76072 .37908 .76078 .3544 .76549 .35287 .76547 .37756 Mtetra
.76547 .37756 .76549 .35287 .7702 .35134 .77023 .37603 Mtetra
.77023 .37603 .7702 .35134 .77492 .34981 .775 .3745 Mtetra
.775 .3745 .77492 .34981 .77965 .34827 .77978 .37297 Mtetra
.77978 .37297 .77965 .34827 .78438 .34673 .78456 .37144 Mtetra
.78456 .37144 .78438 .34673 .78913 .34519 .78935 .3699 Mtetra
.78935 .3699 .78913 .34519 .79388 .34365 .79415 .36836 Mtetra
0 0 .312 r
.79415 .36836 .79388 .34365 .79864 .3421 .79659 .33924 Mtetra
.654 .754 .923 r
.79659 .33924 .79864 .3421 .8034 .34056 .80136 .33769 Mtetra
.80136 .33769 .8034 .34056 .80818 .339 .80614 .33613 Mtetra
.80614 .33613 .80818 .339 .81296 .33745 .81093 .33457 Mtetra
.81093 .33457 .81296 .33745 .81775 .33589 .81573 .33301 Mtetra
.81573 .33301 .81775 .33589 .82255 .33433 .82053 .33145 Mtetra
.82053 .33145 .82255 .33433 .82736 .33277 .82535 .32988 Mtetra
.653 .755 .925 r
.17918 .54712 .18185 .5494 .18568 .54816 .183 .54588 Mtetra
.183 .54588 .18568 .54816 .18951 .54693 .18683 .54463 Mtetra
.18683 .54463 .18951 .54693 .19334 .54569 .19067 .54339 Mtetra
.19067 .54339 .19334 .54569 .19718 .54444 .19451 .54215 Mtetra
.19451 .54215 .19718 .54444 .20102 .5432 .19836 .5409 Mtetra
.19836 .5409 .20102 .5432 .20487 .54195 .20221 .53965 Mtetra
.20221 .53965 .20487 .54195 .20873 .54071 .20607 .5384 Mtetra
.20607 .5384 .20873 .54071 .21259 .53946 .20994 .53714 Mtetra
.20994 .53714 .21259 .53946 .21646 .53821 .21381 .53589 Mtetra
.21381 .53589 .21646 .53821 .22034 .53695 .21769 .53463 Mtetra
.658 .142 0 r
.21769 .53463 .22034 .53695 .22374 .54095 .2211 .53864 Mtetra
.652 .755 .925 r
.2211 .53864 .22374 .54095 .22764 .5397 .22499 .53738 Mtetra
.22499 .53738 .22764 .5397 .23153 .53844 .22889 .53612 Mtetra
.22889 .53612 .23153 .53844 .23544 .53718 .2328 .53485 Mtetra
.2328 .53485 .23544 .53718 .23934 .53592 .23671 .53359 Mtetra
.23671 .53359 .23934 .53592 .24326 .53466 .24063 .53232 Mtetra
.24063 .53232 .24326 .53466 .24718 .5334 .24455 .53106 Mtetra
.24455 .53106 .24718 .5334 .25111 .53213 .24848 .52979 Mtetra
.24848 .52979 .25111 .53213 .25504 .53086 .25242 .52851 Mtetra
.25242 .52851 .25504 .53086 .25898 .52959 .25636 .52724 Mtetra
.25636 .52724 .25898 .52959 .26292 .52832 .26031 .52597 Mtetra
.26031 .52597 .26292 .52832 .26687 .52704 .26426 .52469 Mtetra
.26426 .52469 .26687 .52704 .27083 .52577 .26822 .52341 Mtetra
.26822 .52341 .27083 .52577 .27479 .52449 .27219 .52213 Mtetra
.27219 .52213 .27479 .52449 .27876 .52321 .27616 .52084 Mtetra
.945 .693 .524 r
.27616 .52084 .27876 .52321 .29336 .37511 .29089 .37264 Mtetra
.664 .741 .908 r
.29089 .37264 .29336 .37511 .29717 .37377 .29471 .37131 Mtetra
.29471 .37131 .29717 .37377 .30099 .37244 .29853 .36997 Mtetra
.29853 .36997 .30099 .37244 .30482 .3711 .30236 .36863 Mtetra
.30236 .36863 .30482 .3711 .30865 .36976 .30619 .36728 Mtetra
.30619 .36728 .30865 .36976 .31248 .36842 .31003 .36594 Mtetra
.31003 .36594 .31248 .36842 .31632 .36708 .31387 .36459 Mtetra
.31387 .36459 .31632 .36708 .32017 .36573 .31772 .36324 Mtetra
.31772 .36324 .32017 .36573 .32402 .36438 .32158 .36189 Mtetra
.32158 .36189 .32402 .36438 .32788 .36303 .32544 .36054 Mtetra
.32544 .36054 .32788 .36303 .33174 .36168 .32931 .35918 Mtetra
.32931 .35918 .33174 .36168 .33561 .36033 .33318 .35783 Mtetra
.33318 .35783 .33561 .36033 .33948 .35898 .33706 .35647 Mtetra
.33706 .35647 .33948 .35898 .34336 .35762 .34094 .35511 Mtetra
.34094 .35511 .34336 .35762 .34725 .35626 .34483 .35375 Mtetra
.34483 .35375 .34725 .35626 .35114 .3549 .34872 .35238 Mtetra
.34872 .35238 .35114 .3549 .35504 .35354 .35262 .35101 Mtetra
.35262 .35101 .35504 .35354 .35894 .35217 .35653 .34965 Mtetra
.35653 .34965 .35894 .35217 .36285 .3508 .36044 .34827 Mtetra
.36044 .34827 .36285 .3508 .36676 .34943 .36436 .3469 Mtetra
.36436 .3469 .36676 .34943 .37068 .34806 .36828 .34553 Mtetra
.36828 .34553 .37068 .34806 .37461 .34669 .37221 .34415 Mtetra
.37221 .34415 .37461 .34669 .37854 .34532 .37615 .34277 Mtetra
.37615 .34277 .37854 .34532 .38248 .34394 .38009 .34139 Mtetra
.38009 .34139 .38248 .34394 .38642 .34256 .38403 .34001 Mtetra
0 .064 .576 r
.38403 .34001 .38642 .34256 .39016 .34606 .38778 .34351 Mtetra
.663 .742 .908 r
.38778 .34351 .39016 .34606 .39412 .34468 .39174 .34213 Mtetra
.39174 .34213 .39412 .34468 .39809 .3433 .39571 .34074 Mtetra
.39571 .34074 .39809 .3433 .40206 .34191 .39969 .33935 Mtetra
.39969 .33935 .40206 .34191 .40604 .34052 .40367 .33796 Mtetra
.40367 .33796 .40604 .34052 .41002 .33913 .40765 .33656 Mtetra
.40765 .33656 .41002 .33913 .41401 .33774 .41165 .33517 Mtetra
.41165 .33517 .41401 .33774 .41801 .33635 .41565 .33377 Mtetra
.41565 .33377 .41801 .33635 .42201 .33495 .41965 .33237 Mtetra
.41965 .33237 .42201 .33495 .42602 .33355 .42367 .33097 Mtetra
.42367 .33097 .42602 .33355 .43003 .33215 .42768 .32956 Mtetra
.42768 .32956 .43003 .33215 .43405 .33075 .43171 .32816 Mtetra
.43171 .32816 .43405 .33075 .43808 .32935 .43574 .32675 Mtetra
.43574 .32675 .43808 .32935 .44211 .32794 .43977 .32534 Mtetra
.43977 .32534 .44211 .32794 .44614 .32653 .44381 .32393 Mtetra
.44381 .32393 .44614 .32653 .45019 .32512 .44786 .32251 Mtetra
.44786 .32251 .45019 .32512 .45424 .32371 .45191 .3211 Mtetra
.964 .668 .42 r
.45191 .3211 .45424 .32371 .45669 .39783 .45432 .39525 Mtetra
.658 .749 .917 r
.45432 .39525 .45669 .39783 .46085 .39643 .45848 .39386 Mtetra
.45848 .39386 .46085 .39643 .46502 .39504 .46265 .39246 Mtetra
.46265 .39246 .46502 .39504 .46919 .39364 .46682 .39106 Mtetra
.46682 .39106 .46919 .39364 .47337 .39224 .471 .38965 Mtetra
.471 .38965 .47337 .39224 .47755 .39084 .47519 .38825 Mtetra
.47519 .38825 .47755 .39084 .48174 .38944 .47939 .38684 Mtetra
.47939 .38684 .48174 .38944 .48594 .38803 .48359 .38543 Mtetra
.48359 .38543 .48594 .38803 .49014 .38662 .48779 .38402 Mtetra
.48779 .38402 .49014 .38662 .49435 .38521 .49201 .3826 Mtetra
.965 .705 .49 r
.49201 .3826 .49435 .38521 .49857 .3838 .49686 .31031 Mtetra
.545 .334 .545 r
.49686 .31031 .49857 .3838 .50328 .31153 .501 .30887 Mtetra
.663 .742 .909 r
.501 .30887 .50328 .31153 .50741 .31009 .50514 .30743 Mtetra
.50514 .30743 .50741 .31009 .51155 .30865 .50928 .30598 Mtetra
.50928 .30598 .51155 .30865 .5157 .30721 .51343 .30454 Mtetra
.51343 .30454 .5157 .30721 .51986 .30576 .51759 .30309 Mtetra
.51759 .30309 .51986 .30576 .52402 .30431 .52176 .30163 Mtetra
.52176 .30163 .52402 .30431 .52819 .30286 .52593 .30018 Mtetra
.52593 .30018 .52819 .30286 .53236 .30141 .53011 .29872 Mtetra
.53011 .29872 .53236 .30141 .53654 .29996 .53429 .29727 Mtetra
.53429 .29727 .53654 .29996 .54073 .2985 .53848 .2958 Mtetra
.53848 .2958 .54073 .2985 .54492 .29704 .54268 .29434 Mtetra
.932 .765 .652 r
.54268 .29434 .54492 .29704 .54904 .28568 .54681 .28297 Mtetra
.664 .741 .908 r
.54681 .28297 .54904 .28568 .55323 .28421 .55101 .2815 Mtetra
.55101 .2815 .55323 .28421 .55743 .28275 .55521 .28003 Mtetra
.55521 .28003 .55743 .28275 .56164 .28128 .55942 .27855 Mtetra
.55942 .27855 .56164 .28128 .56585 .2798 .56364 .27708 Mtetra
.56364 .27708 .56585 .2798 .57007 .27833 .56786 .2756 Mtetra
.56786 .2756 .57007 .27833 .57429 .27685 .57209 .27412 Mtetra
.57209 .27412 .57429 .27685 .57852 .27537 .57632 .27263 Mtetra
.57632 .27263 .57852 .27537 .58276 .27389 .58056 .27115 Mtetra
.58056 .27115 .58276 .27389 .587 .2724 .58481 .26966 Mtetra
.58481 .26966 .587 .2724 .59125 .27092 .58906 .26817 Mtetra
.58906 .26817 .59125 .27092 .59551 .26943 .59333 .26668 Mtetra
.59333 .26668 .59551 .26943 .59977 .26794 .59759 .26518 Mtetra
.59759 .26518 .59977 .26794 .60404 .26645 .60187 .26368 Mtetra
.891 .488 .06 r
.60187 .26368 .60404 .26645 .60832 .26495 .60654 .27712 Mtetra
.462 .165 .374 r
.60654 .27712 .60832 .26495 .61302 .27839 .61085 .27562 Mtetra
.663 .743 .91 r
.61085 .27562 .61302 .27839 .61733 .27689 .61516 .27412 Mtetra
.61516 .27412 .61733 .27689 .62165 .27539 .61948 .27262 Mtetra
.61948 .27262 .62165 .27539 .62597 .27389 .62381 .27112 Mtetra
.62381 .27112 .62597 .27389 .6303 .27239 .62815 .26961 Mtetra
.62815 .26961 .6303 .27239 .63464 .27089 .63249 .2681 Mtetra
.63249 .2681 .63464 .27089 .63898 .26938 .63684 .26659 Mtetra
.63684 .26659 .63898 .26938 .64333 .26787 .64119 .26507 Mtetra
.64119 .26507 .64333 .26787 .64789 .27138 .64555 .26356 Mtetra
.329 .334 .713 r
.64555 .26356 .64789 .27138 .65226 .26987 .65013 .26707 Mtetra
.662 .743 .91 r
.65013 .26707 .65226 .26987 .65664 .26835 .65451 .26555 Mtetra
.65451 .26555 .65664 .26835 .66103 .26683 .6589 .26402 Mtetra
.6589 .26402 .66103 .26683 .66542 .26531 .66329 .2625 Mtetra
.66329 .2625 .66542 .26531 .66982 .26379 .6677 .26097 Mtetra
.6677 .26097 .66982 .26379 .67422 .26226 .67211 .25944 Mtetra
.67211 .25944 .67422 .26226 .67863 .26074 .67652 .25791 Mtetra
.67652 .25791 .67863 .26074 .68305 .25921 .68095 .25638 Mtetra
.68095 .25638 .68305 .25921 .68748 .25768 .68538 .25484 Mtetra
.68538 .25484 .68748 .25768 .69191 .25614 .68982 .2533 Mtetra
.68982 .2533 .69191 .25614 .69635 .2546 .69426 .25176 Mtetra
.69426 .25176 .69635 .2546 .7008 .25306 .69871 .25022 Mtetra
.69871 .25022 .7008 .25306 .70525 .25152 .70317 .24867 Mtetra
.70317 .24867 .70525 .25152 .70971 .24998 .70764 .24712 Mtetra
.972 .658 .324 r
.70764 .24712 .70971 .24998 .71418 .24843 .72083 .3884 Mtetra
.529 .298 .509 r
.72083 .3884 .71418 .24843 .72767 .38968 .72552 .38689 Mtetra
.651 .757 .927 r
.72552 .38689 .72767 .38968 .73237 .38817 .73023 .38538 Mtetra
.73023 .38538 .73237 .38817 .73707 .38666 .73494 .38387 Mtetra
.73494 .38387 .73707 .38666 .74179 .38515 .73966 .38235 Mtetra
.73966 .38235 .74179 .38515 .74651 .38364 .74438 .38084 Mtetra
.74438 .38084 .74651 .38364 .75124 .38212 .74912 .37932 Mtetra
.74912 .37932 .75124 .38212 .75597 .3806 .75386 .37779 Mtetra
.75386 .37779 .75597 .3806 .76072 .37908 .75861 .37627 Mtetra
.75861 .37627 .76072 .37908 .76547 .37756 .76337 .37474 Mtetra
.76337 .37474 .76547 .37756 .77023 .37603 .76813 .37321 Mtetra
.76813 .37321 .77023 .37603 .775 .3745 .77291 .37167 Mtetra
.77291 .37167 .775 .3745 .77978 .37297 .77769 .37014 Mtetra
.77769 .37014 .77978 .37297 .78456 .37144 .78248 .3686 Mtetra
.78248 .3686 .78456 .37144 .78935 .3699 .78728 .36706 Mtetra
.78728 .36706 .78935 .3699 .79415 .36836 .79208 .36552 Mtetra
.79208 .36552 .79415 .36836 .79659 .33924 .7969 .36397 Mtetra
.5 .237 .447 r
.7969 .36397 .79659 .33924 .80136 .33769 .80172 .36242 Mtetra
.80172 .36242 .80136 .33769 .80614 .33613 .80655 .36087 Mtetra
.80655 .36087 .80614 .33613 .81093 .33457 .81139 .35932 Mtetra
.81139 .35932 .81093 .33457 .81573 .33301 .81623 .35776 Mtetra
.81623 .35776 .81573 .33301 .82053 .33145 .82109 .3562 Mtetra
.82109 .3562 .82053 .33145 .82535 .32988 .82595 .35464 Mtetra
.653 .755 .925 r
.17649 .54483 .17918 .54712 .183 .54588 .18032 .54358 Mtetra
.18032 .54358 .183 .54588 .18683 .54463 .18415 .54234 Mtetra
.18415 .54234 .18683 .54463 .19067 .54339 .18799 .54109 Mtetra
.18799 .54109 .19067 .54339 .19451 .54215 .19184 .53984 Mtetra
.19184 .53984 .19451 .54215 .19836 .5409 .19569 .53859 Mtetra
.19569 .53859 .19836 .5409 .20221 .53965 .19955 .53734 Mtetra
.19955 .53734 .20221 .53965 .20607 .5384 .20341 .53608 Mtetra
.20341 .53608 .20607 .5384 .20994 .53714 .20728 .53483 Mtetra
.20728 .53483 .20994 .53714 .21381 .53589 .21115 .53357 Mtetra
.21115 .53357 .21381 .53589 .21769 .53463 .21504 .53231 Mtetra
.21504 .53231 .21769 .53463 .2211 .53864 .21892 .53105 Mtetra
.18 .231 .68 r
.21892 .53105 .2211 .53864 .22499 .53738 .22234 .53505 Mtetra
.652 .755 .925 r
.22234 .53505 .22499 .53738 .22889 .53612 .22624 .53378 Mtetra
.22624 .53378 .22889 .53612 .2328 .53485 .23015 .53252 Mtetra
.23015 .53252 .2328 .53485 .23671 .53359 .23407 .53125 Mtetra
.23407 .53125 .23671 .53359 .24063 .53232 .23799 .52998 Mtetra
.23799 .52998 .24063 .53232 .24455 .53106 .24192 .52871 Mtetra
.24192 .52871 .24455 .53106 .24848 .52979 .24585 .52744 Mtetra
.24585 .52744 .24848 .52979 .25242 .52851 .24979 .52616 Mtetra
.24979 .52616 .25242 .52851 .25636 .52724 .25374 .52488 Mtetra
.25374 .52488 .25636 .52724 .26031 .52597 .25769 .5236 Mtetra
.25769 .5236 .26031 .52597 .26426 .52469 .26164 .52232 Mtetra
.26164 .52232 .26426 .52469 .26822 .52341 .26561 .52104 Mtetra
.26561 .52104 .26822 .52341 .27219 .52213 .26958 .51976 Mtetra
.26958 .51976 .27219 .52213 .27616 .52084 .27355 .51847 Mtetra
.27355 .51847 .27616 .52084 .29089 .37264 .27753 .51718 Mtetra
0 0 .159 r
.27753 .51718 .29089 .37264 .29471 .37131 .29224 .36883 Mtetra
.664 .741 .908 r
.29224 .36883 .29471 .37131 .29853 .36997 .29606 .36749 Mtetra
.29606 .36749 .29853 .36997 .30236 .36863 .2999 .36615 Mtetra
.2999 .36615 .30236 .36863 .30619 .36728 .30373 .3648 Mtetra
.30373 .3648 .30619 .36728 .31003 .36594 .30757 .36345 Mtetra
.30757 .36345 .31003 .36594 .31387 .36459 .31142 .3621 Mtetra
.31142 .3621 .31387 .36459 .31772 .36324 .31527 .36075 Mtetra
.31527 .36075 .31772 .36324 .32158 .36189 .31913 .35939 Mtetra
.31913 .35939 .32158 .36189 .32544 .36054 .323 .35804 Mtetra
.323 .35804 .32544 .36054 .32931 .35918 .32687 .35668 Mtetra
.32687 .35668 .32931 .35918 .33318 .35783 .33074 .35532 Mtetra
.33074 .35532 .33318 .35783 .33706 .35647 .33462 .35396 Mtetra
.33462 .35396 .33706 .35647 .34094 .35511 .33851 .35259 Mtetra
.33851 .35259 .34094 .35511 .34483 .35375 .3424 .35122 Mtetra
.3424 .35122 .34483 .35375 .34872 .35238 .3463 .34986 Mtetra
.3463 .34986 .34872 .35238 .35262 .35101 .3502 .34849 Mtetra
.3502 .34849 .35262 .35101 .35653 .34965 .35411 .34711 Mtetra
.35411 .34711 .35653 .34965 .36044 .34827 .35803 .34574 Mtetra
.35803 .34574 .36044 .34827 .36436 .3469 .36195 .34436 Mtetra
.36195 .34436 .36436 .3469 .36828 .34553 .36588 .34298 Mtetra
.36588 .34298 .36828 .34553 .37221 .34415 .36981 .3416 Mtetra
.36981 .3416 .37221 .34415 .37615 .34277 .37375 .34022 Mtetra
.37375 .34022 .37615 .34277 .38009 .34139 .37769 .33884 Mtetra
.37769 .33884 .38009 .34139 .38403 .34001 .38164 .33745 Mtetra
.38164 .33745 .38403 .34001 .38778 .34351 .3856 .33606 Mtetra
.27 .293 .702 r
.3856 .33606 .38778 .34351 .39174 .34213 .38935 .33956 Mtetra
.663 .742 .908 r
.38935 .33956 .39174 .34213 .39571 .34074 .39333 .33817 Mtetra
.39333 .33817 .39571 .34074 .39969 .33935 .39731 .33678 Mtetra
.39731 .33678 .39969 .33935 .40367 .33796 .40129 .33538 Mtetra
.40129 .33538 .40367 .33796 .40765 .33656 .40528 .33398 Mtetra
.40528 .33398 .40765 .33656 .41165 .33517 .40928 .33259 Mtetra
.40928 .33259 .41165 .33517 .41565 .33377 .41328 .33118 Mtetra
.41328 .33118 .41565 .33377 .41965 .33237 .41729 .32978 Mtetra
.41729 .32978 .41965 .33237 .42367 .33097 .42131 .32837 Mtetra
.42131 .32837 .42367 .33097 .42768 .32956 .42533 .32697 Mtetra
.42533 .32697 .42768 .32956 .43171 .32816 .42936 .32556 Mtetra
.42936 .32556 .43171 .32816 .43574 .32675 .43339 .32414 Mtetra
.43339 .32414 .43574 .32675 .43977 .32534 .43743 .32273 Mtetra
.43743 .32273 .43977 .32534 .44381 .32393 .44147 .32131 Mtetra
.44147 .32131 .44381 .32393 .44786 .32251 .44553 .31989 Mtetra
.44553 .31989 .44786 .32251 .45191 .3211 .44958 .31847 Mtetra
.44958 .31847 .45191 .3211 .45432 .39525 .45365 .31705 Mtetra
0 0 .344 r
.45365 .31705 .45432 .39525 .45848 .39386 .4561 .39127 Mtetra
.658 .749 .917 r
.4561 .39127 .45848 .39386 .46265 .39246 .46027 .38987 Mtetra
.46027 .38987 .46265 .39246 .46682 .39106 .46445 .38846 Mtetra
.46445 .38846 .46682 .39106 .471 .38965 .46863 .38705 Mtetra
.46863 .38705 .471 .38965 .47519 .38825 .47283 .38564 Mtetra
.47283 .38564 .47519 .38825 .47939 .38684 .47703 .38423 Mtetra
.47703 .38423 .47939 .38684 .48359 .38543 .48123 .38282 Mtetra
.48123 .38282 .48359 .38543 .48779 .38402 .48544 .3814 Mtetra
.965 .705 .492 r
.48544 .3814 .48779 .38402 .49201 .3826 .49044 .30909 Mtetra
.545 .334 .544 r
.49044 .30909 .49201 .3826 .49686 .31031 .49457 .30765 Mtetra
.663 .742 .909 r
.49457 .30765 .49686 .31031 .501 .30887 .49871 .30621 Mtetra
.49871 .30621 .501 .30887 .50514 .30743 .50285 .30476 Mtetra
.50285 .30476 .50514 .30743 .50928 .30598 .507 .30331 Mtetra
.507 .30331 .50928 .30598 .51343 .30454 .51116 .30186 Mtetra
.51116 .30186 .51343 .30454 .51759 .30309 .51532 .3004 Mtetra
.51532 .3004 .51759 .30309 .52176 .30163 .51949 .29895 Mtetra
.51949 .29895 .52176 .30163 .52593 .30018 .52367 .29749 Mtetra
.52367 .29749 .52593 .30018 .53011 .29872 .52785 .29603 Mtetra
.52785 .29603 .53011 .29872 .53429 .29727 .53204 .29457 Mtetra
.53204 .29457 .53429 .29727 .53848 .2958 .53623 .2931 Mtetra
.53623 .2931 .53848 .2958 .54268 .29434 .54043 .29163 Mtetra
.932 .765 .652 r
.54043 .29163 .54268 .29434 .54681 .28297 .54458 .28026 Mtetra
.664 .741 .908 r
.54458 .28026 .54681 .28297 .55101 .2815 .54878 .27878 Mtetra
.54878 .27878 .55101 .2815 .55521 .28003 .55299 .27731 Mtetra
.55299 .27731 .55521 .28003 .55942 .27855 .5572 .27583 Mtetra
.5572 .27583 .55942 .27855 .56364 .27708 .56142 .27435 Mtetra
.56142 .27435 .56364 .27708 .56786 .2756 .56564 .27286 Mtetra
.56564 .27286 .56786 .2756 .57209 .27412 .56988 .27138 Mtetra
.56988 .27138 .57209 .27412 .57632 .27263 .57412 .26989 Mtetra
.57412 .26989 .57632 .27263 .58056 .27115 .57836 .2684 Mtetra
.57836 .2684 .58056 .27115 .58481 .26966 .58261 .26691 Mtetra
.58261 .26691 .58481 .26966 .58906 .26817 .58687 .26541 Mtetra
.58687 .26541 .58906 .26817 .59333 .26668 .59114 .26391 Mtetra
.59114 .26391 .59333 .26668 .59759 .26518 .59541 .26241 Mtetra
.59541 .26241 .59759 .26518 .60187 .26368 .59969 .26091 Mtetra
.891 .488 .06 r
.59969 .26091 .60187 .26368 .60654 .27712 .60436 .27436 Mtetra
.663 .743 .91 r
.60436 .27436 .60654 .27712 .61085 .27562 .60867 .27285 Mtetra
.60867 .27285 .61085 .27562 .61516 .27412 .61299 .27135 Mtetra
.61299 .27135 .61516 .27412 .61948 .27262 .61731 .26984 Mtetra
.61731 .26984 .61948 .27262 .62381 .27112 .62165 .26833 Mtetra
.62165 .26833 .62381 .27112 .62815 .26961 .62599 .26682 Mtetra
.62599 .26682 .62815 .26961 .63249 .2681 .63033 .26531 Mtetra
.63033 .26531 .63249 .2681 .63684 .26659 .63468 .26379 Mtetra
.63468 .26379 .63684 .26659 .64119 .26507 .63904 .26227 Mtetra
.63904 .26227 .64119 .26507 .64555 .26356 .64341 .26075 Mtetra
.64341 .26075 .64555 .26356 .65013 .26707 .64778 .25923 Mtetra
.615 .513 .715 r
.64778 .25923 .65013 .26707 .65451 .26555 .65216 .2577 Mtetra
.33 .334 .713 r
.65216 .2577 .65451 .26555 .6589 .26402 .65677 .26121 Mtetra
.662 .743 .91 r
.65677 .26121 .6589 .26402 .66329 .2625 .66117 .25968 Mtetra
.66117 .25968 .66329 .2625 .6677 .26097 .66557 .25815 Mtetra
.66557 .25815 .6677 .26097 .67211 .25944 .66999 .25661 Mtetra
.66999 .25661 .67211 .25944 .67652 .25791 .67441 .25508 Mtetra
.67441 .25508 .67652 .25791 .68095 .25638 .67884 .25354 Mtetra
.67884 .25354 .68095 .25638 .68538 .25484 .68327 .252 Mtetra
.68327 .252 .68538 .25484 .68982 .2533 .68772 .25045 Mtetra
.68772 .25045 .68982 .2533 .69426 .25176 .69217 .24891 Mtetra
.69217 .24891 .69426 .25176 .69871 .25022 .69662 .24736 Mtetra
.69662 .24736 .69871 .25022 .70317 .24867 .70109 .24581 Mtetra
.70109 .24581 .70317 .24867 .70764 .24712 .70556 .24426 Mtetra
.972 .658 .324 r
.70556 .24426 .70764 .24712 .72083 .3884 .71867 .38562 Mtetra
.651 .757 .927 r
.71867 .38562 .72083 .3884 .72552 .38689 .72337 .3841 Mtetra
.72337 .3841 .72552 .38689 .73023 .38538 .72808 .38259 Mtetra
.72808 .38259 .73023 .38538 .73494 .38387 .73279 .38107 Mtetra
.73279 .38107 .73494 .38387 .73966 .38235 .73752 .37955 Mtetra
.73752 .37955 .73966 .38235 .74438 .38084 .74225 .37803 Mtetra
.74225 .37803 .74438 .38084 .74912 .37932 .74699 .3765 Mtetra
.74699 .3765 .74912 .37932 .75386 .37779 .75174 .37497 Mtetra
.75174 .37497 .75386 .37779 .75861 .37627 .75649 .37344 Mtetra
.75649 .37344 .75861 .37627 .76337 .37474 .76126 .37191 Mtetra
.76126 .37191 .76337 .37474 .76813 .37321 .76603 .37037 Mtetra
.76603 .37037 .76813 .37321 .77291 .37167 .77081 .36884 Mtetra
.77081 .36884 .77291 .37167 .77769 .37014 .7756 .3673 Mtetra
.7756 .3673 .77769 .37014 .78248 .3686 .78039 .36575 Mtetra
.78039 .36575 .78248 .3686 .78728 .36706 .7852 .36421 Mtetra
.7852 .36421 .78728 .36706 .79208 .36552 .79001 .36266 Mtetra
.79001 .36266 .79208 .36552 .7969 .36397 .79483 .36111 Mtetra
.79483 .36111 .7969 .36397 .80172 .36242 .79965 .35955 Mtetra
.79965 .35955 .80172 .36242 .80655 .36087 .80449 .358 Mtetra
.80449 .358 .80655 .36087 .81139 .35932 .80933 .35644 Mtetra
.80933 .35644 .81139 .35932 .81623 .35776 .81419 .35488 Mtetra
.81419 .35488 .81623 .35776 .82109 .3562 .81905 .35332 Mtetra
.81905 .35332 .82109 .3562 .82595 .35464 .82391 .35175 Mtetra
.653 .755 .925 r
.17379 .54253 .17649 .54483 .18032 .54358 .17763 .54128 Mtetra
.17763 .54128 .18032 .54358 .18415 .54234 .18146 .54003 Mtetra
.18146 .54003 .18415 .54234 .18799 .54109 .18531 .53878 Mtetra
.18531 .53878 .18799 .54109 .19184 .53984 .18916 .53753 Mtetra
.18916 .53753 .19184 .53984 .19569 .53859 .19301 .53628 Mtetra
.19301 .53628 .19569 .53859 .19955 .53734 .19687 .53502 Mtetra
.19687 .53502 .19955 .53734 .20341 .53608 .20074 .53376 Mtetra
.20074 .53376 .20341 .53608 .20728 .53483 .20461 .5325 Mtetra
.20461 .5325 .20728 .53483 .21115 .53357 .20849 .53124 Mtetra
.20849 .53124 .21115 .53357 .21504 .53231 .21237 .52998 Mtetra
.21237 .52998 .21504 .53231 .21892 .53105 .21626 .52871 Mtetra
.655 .139 0 r
.21626 .52871 .21892 .53105 .22234 .53505 .21968 .53271 Mtetra
.652 .755 .925 r
.21968 .53271 .22234 .53505 .22624 .53378 .22359 .53145 Mtetra
.22359 .53145 .22624 .53378 .23015 .53252 .2275 .53018 Mtetra
.2275 .53018 .23015 .53252 .23407 .53125 .23142 .52891 Mtetra
.23142 .52891 .23407 .53125 .23799 .52998 .23534 .52763 Mtetra
.23534 .52763 .23799 .52998 .24192 .52871 .23928 .52636 Mtetra
.23928 .52636 .24192 .52871 .24585 .52744 .24321 .52508 Mtetra
.24321 .52508 .24585 .52744 .24979 .52616 .24716 .5238 Mtetra
.24716 .5238 .24979 .52616 .25374 .52488 .2511 .52252 Mtetra
.2511 .52252 .25374 .52488 .25769 .5236 .25506 .52124 Mtetra
.25506 .52124 .25769 .5236 .26164 .52232 .25902 .51995 Mtetra
.25902 .51995 .26164 .52232 .26561 .52104 .26299 .51867 Mtetra
.26299 .51867 .26561 .52104 .26958 .51976 .26696 .51738 Mtetra
.26696 .51738 .26958 .51976 .27355 .51847 .27094 .51609 Mtetra
.27094 .51609 .27355 .51847 .27753 .51718 .27492 .51479 Mtetra
.27492 .51479 .27753 .51718 .29224 .36883 .27891 .5135 Mtetra
0 0 .159 r
.27891 .5135 .29224 .36883 .29606 .36749 .29359 .36501 Mtetra
.664 .741 .908 r
.29359 .36501 .29606 .36749 .2999 .36615 .29743 .36366 Mtetra
.29743 .36366 .2999 .36615 .30373 .3648 .30126 .36231 Mtetra
.30126 .36231 .30373 .3648 .30757 .36345 .30511 .36096 Mtetra
.30511 .36096 .30757 .36345 .31142 .3621 .30896 .3596 Mtetra
.30896 .3596 .31142 .3621 .31527 .36075 .31282 .35825 Mtetra
.31282 .35825 .31527 .36075 .31913 .35939 .31668 .35689 Mtetra
.31668 .35689 .31913 .35939 .323 .35804 .32055 .35553 Mtetra
.32055 .35553 .323 .35804 .32687 .35668 .32442 .35416 Mtetra
.32442 .35416 .32687 .35668 .33074 .35532 .3283 .3528 Mtetra
.3283 .3528 .33074 .35532 .33462 .35396 .33218 .35143 Mtetra
.33218 .35143 .33462 .35396 .33851 .35259 .33607 .35007 Mtetra
.33607 .35007 .33851 .35259 .3424 .35122 .33997 .3487 Mtetra
.33997 .3487 .3424 .35122 .3463 .34986 .34387 .34732 Mtetra
.34387 .34732 .3463 .34986 .3502 .34849 .34778 .34595 Mtetra
.34778 .34595 .3502 .34849 .35411 .34711 .35169 .34457 Mtetra
.35169 .34457 .35411 .34711 .35803 .34574 .35561 .3432 Mtetra
.35561 .3432 .35803 .34574 .36195 .34436 .35954 .34182 Mtetra
.35954 .34182 .36195 .34436 .36588 .34298 .36347 .34043 Mtetra
.36347 .34043 .36588 .34298 .36981 .3416 .3674 .33905 Mtetra
.3674 .33905 .36981 .3416 .37375 .34022 .37135 .33766 Mtetra
.37135 .33766 .37375 .34022 .37769 .33884 .37529 .33627 Mtetra
.37529 .33627 .37769 .33884 .38164 .33745 .37925 .33488 Mtetra
.37925 .33488 .38164 .33745 .3856 .33606 .38321 .33349 Mtetra
0 .067 .58 r
.38321 .33349 .3856 .33606 .38935 .33956 .38696 .33699 Mtetra
.663 .742 .908 r
.38696 .33699 .38935 .33956 .39333 .33817 .39094 .3356 Mtetra
.39094 .3356 .39333 .33817 .39731 .33678 .39492 .3342 Mtetra
.39492 .3342 .39731 .33678 .40129 .33538 .39891 .3328 Mtetra
.39891 .3328 .40129 .33538 .40528 .33398 .4029 .3314 Mtetra
.4029 .3314 .40528 .33398 .40928 .33259 .4069 .33 Mtetra
.4069 .33 .40928 .33259 .41328 .33118 .41091 .32859 Mtetra
.41091 .32859 .41328 .33118 .41729 .32978 .41492 .32718 Mtetra
.41492 .32718 .41729 .32978 .42131 .32837 .41894 .32577 Mtetra
.41894 .32577 .42131 .32837 .42533 .32697 .42297 .32436 Mtetra
.42297 .32436 .42533 .32697 .42936 .32556 .427 .32295 Mtetra
.427 .32295 .42936 .32556 .43339 .32414 .43104 .32153 Mtetra
.43104 .32153 .43339 .32414 .43743 .32273 .43508 .32011 Mtetra
.43508 .32011 .43743 .32273 .44147 .32131 .43913 .31869 Mtetra
.43913 .31869 .44147 .32131 .44553 .31989 .44318 .31727 Mtetra
.44318 .31727 .44553 .31989 .44958 .31847 .44725 .31585 Mtetra
.44725 .31585 .44958 .31847 .45365 .31705 .45131 .31442 Mtetra
.965 .668 .418 r
.45131 .31442 .45365 .31705 .4561 .39127 .45371 .38868 Mtetra
.658 .749 .917 r
.45371 .38868 .4561 .39127 .46027 .38987 .45789 .38727 Mtetra
.45789 .38727 .46027 .38987 .46445 .38846 .46207 .38586 Mtetra
.46207 .38586 .46445 .38846 .46863 .38705 .46626 .38445 Mtetra
.46626 .38445 .46863 .38705 .47283 .38564 .47046 .38304 Mtetra
.47046 .38304 .47283 .38564 .47703 .38423 .47466 .38162 Mtetra
.47466 .38162 .47703 .38423 .48123 .38282 .47887 .3802 Mtetra
.964 .705 .493 r
.47887 .3802 .48123 .38282 .48544 .3814 .48401 .30787 Mtetra
.544 .333 .544 r
.48401 .30787 .48544 .3814 .49044 .30909 .48814 .30643 Mtetra
.663 .742 .909 r
.48814 .30643 .49044 .30909 .49457 .30765 .49227 .30498 Mtetra
.49227 .30498 .49457 .30765 .49871 .30621 .49642 .30353 Mtetra
.49642 .30353 .49871 .30621 .50285 .30476 .50056 .30208 Mtetra
.50056 .30208 .50285 .30476 .507 .30331 .50472 .30063 Mtetra
.50472 .30063 .507 .30331 .51116 .30186 .50888 .29917 Mtetra
.50888 .29917 .51116 .30186 .51532 .3004 .51305 .29771 Mtetra
.51305 .29771 .51532 .3004 .51949 .29895 .51722 .29625 Mtetra
.51722 .29625 .51949 .29895 .52367 .29749 .5214 .29479 Mtetra
.5214 .29479 .52367 .29749 .52785 .29603 .52559 .29333 Mtetra
.52559 .29333 .52785 .29603 .53204 .29457 .52978 .29186 Mtetra
.52978 .29186 .53204 .29457 .53623 .2931 .53398 .29039 Mtetra
.53398 .29039 .53623 .2931 .54043 .29163 .53818 .28892 Mtetra
.932 .765 .652 r
.53818 .28892 .54043 .29163 .54458 .28026 .54234 .27753 Mtetra
.664 .741 .908 r
.54234 .27753 .54458 .28026 .54878 .27878 .54654 .27605 Mtetra
.54654 .27605 .54878 .27878 .55299 .27731 .55075 .27457 Mtetra
.55075 .27457 .55299 .27731 .5572 .27583 .55497 .27309 Mtetra
.55497 .27309 .5572 .27583 .56142 .27435 .55919 .2716 Mtetra
.55919 .2716 .56142 .27435 .56564 .27286 .56343 .27012 Mtetra
.56343 .27012 .56564 .27286 .56988 .27138 .56766 .26863 Mtetra
.56766 .26863 .56988 .27138 .57412 .26989 .57191 .26713 Mtetra
.57191 .26713 .57412 .26989 .57836 .2684 .57616 .26564 Mtetra
.57616 .26564 .57836 .2684 .58261 .26691 .58041 .26414 Mtetra
.58041 .26414 .58261 .26691 .58687 .26541 .58467 .26264 Mtetra
.58467 .26264 .58687 .26541 .59114 .26391 .58894 .26114 Mtetra
.58894 .26114 .59114 .26391 .59541 .26241 .59322 .25964 Mtetra
.59322 .25964 .59541 .26241 .59969 .26091 .5975 .25813 Mtetra
.891 .488 .06 r
.5975 .25813 .59969 .26091 .60436 .27436 .60217 .27158 Mtetra
.663 .743 .91 r
.60217 .27158 .60436 .27436 .60867 .27285 .60648 .27007 Mtetra
.60648 .27007 .60867 .27285 .61299 .27135 .61081 .26857 Mtetra
.61081 .26857 .61299 .27135 .61731 .26984 .61514 .26705 Mtetra
.61514 .26705 .61731 .26984 .62165 .26833 .61947 .26554 Mtetra
.61947 .26554 .62165 .26833 .62599 .26682 .62382 .26402 Mtetra
.62382 .26402 .62599 .26682 .63033 .26531 .62817 .26251 Mtetra
.62817 .26251 .63033 .26531 .63468 .26379 .63253 .26099 Mtetra
.63253 .26099 .63468 .26379 .63904 .26227 .63689 .25946 Mtetra
.63689 .25946 .63904 .26227 .64341 .26075 .64126 .25794 Mtetra
.64126 .25794 .64341 .26075 .64778 .25923 .64564 .25641 Mtetra
.64564 .25641 .64778 .25923 .65216 .2577 .65002 .25488 Mtetra
.65002 .25488 .65216 .2577 .65677 .26121 .65441 .25335 Mtetra
.33 .334 .713 r
.65441 .25335 .65677 .26121 .66117 .25968 .65903 .25685 Mtetra
.662 .743 .91 r
.65903 .25685 .66117 .25968 .66557 .25815 .66344 .25531 Mtetra
.66344 .25531 .66557 .25815 .66999 .25661 .66786 .25378 Mtetra
.66786 .25378 .66999 .25661 .67441 .25508 .67229 .25223 Mtetra
.67229 .25223 .67441 .25508 .67884 .25354 .67672 .25069 Mtetra
.67672 .25069 .67884 .25354 .68327 .252 .68116 .24915 Mtetra
.68116 .24915 .68327 .252 .68772 .25045 .68561 .2476 Mtetra
.68561 .2476 .68772 .25045 .69217 .24891 .69007 .24605 Mtetra
.69007 .24605 .69217 .24891 .69662 .24736 .69453 .2445 Mtetra
.69453 .2445 .69662 .24736 .70109 .24581 .69899 .24294 Mtetra
.972 .658 .326 r
.69899 .24294 .70109 .24581 .70556 .24426 .7118 .38434 Mtetra
.528 .297 .508 r
.7118 .38434 .70556 .24426 .71867 .38562 .7165 .38282 Mtetra
.651 .757 .927 r
.7165 .38282 .71867 .38562 .72337 .3841 .72121 .3813 Mtetra
.72121 .3813 .72337 .3841 .72808 .38259 .72592 .37978 Mtetra
.72592 .37978 .72808 .38259 .73279 .38107 .73064 .37826 Mtetra
.73064 .37826 .73279 .38107 .73752 .37955 .73537 .37674 Mtetra
.73537 .37674 .73752 .37955 .74225 .37803 .74011 .37521 Mtetra
.74011 .37521 .74225 .37803 .74699 .3765 .74486 .37368 Mtetra
.74486 .37368 .74699 .3765 .75174 .37497 .74961 .37215 Mtetra
.74961 .37215 .75174 .37497 .75649 .37344 .75437 .37061 Mtetra
.75437 .37061 .75649 .37344 .76126 .37191 .75914 .36907 Mtetra
.75914 .36907 .76126 .37191 .76603 .37037 .76392 .36753 Mtetra
.76392 .36753 .76603 .37037 .77081 .36884 .7687 .36599 Mtetra
.7687 .36599 .77081 .36884 .7756 .3673 .7735 .36445 Mtetra
.7735 .36445 .7756 .3673 .78039 .36575 .7783 .3629 Mtetra
.7783 .3629 .78039 .36575 .7852 .36421 .78311 .36135 Mtetra
.78311 .36135 .7852 .36421 .79001 .36266 .78792 .35979 Mtetra
.78792 .35979 .79001 .36266 .79483 .36111 .79275 .35824 Mtetra
.79275 .35824 .79483 .36111 .79965 .35955 .79758 .35668 Mtetra
.79758 .35668 .79965 .35955 .80449 .358 .80242 .35512 Mtetra
.80242 .35512 .80449 .358 .80933 .35644 .80727 .35356 Mtetra
.80727 .35356 .80933 .35644 .81419 .35488 .81213 .35199 Mtetra
.81213 .35199 .81419 .35488 .81905 .35332 .817 .35042 Mtetra
.817 .35042 .81905 .35332 .82391 .35175 .82187 .34885 Mtetra
.653 .755 .925 r
.17109 .54023 .17379 .54253 .17763 .54128 .17493 .53898 Mtetra
.17493 .53898 .17763 .54128 .18146 .54003 .17877 .53772 Mtetra
.17877 .53772 .18146 .54003 .18531 .53878 .18262 .53647 Mtetra
.18262 .53647 .18531 .53878 .18916 .53753 .18647 .53521 Mtetra
.18647 .53521 .18916 .53753 .19301 .53628 .19033 .53396 Mtetra
.19033 .53396 .19301 .53628 .19687 .53502 .19419 .5327 Mtetra
.19419 .5327 .19687 .53502 .20074 .53376 .19806 .53143 Mtetra
.19806 .53143 .20074 .53376 .20461 .5325 .20194 .53017 Mtetra
.20194 .53017 .20461 .5325 .20849 .53124 .20582 .52891 Mtetra
.20582 .52891 .20849 .53124 .21237 .52998 .20971 .52764 Mtetra
.20971 .52764 .21237 .52998 .21626 .52871 .2136 .52637 Mtetra
.655 .139 0 r
.2136 .52637 .21626 .52871 .21968 .53271 .21701 .53037 Mtetra
.652 .755 .925 r
.21701 .53037 .21968 .53271 .22359 .53145 .22092 .5291 Mtetra
.22092 .5291 .22359 .53145 .2275 .53018 .22484 .52783 Mtetra
.22484 .52783 .2275 .53018 .23142 .52891 .22876 .52655 Mtetra
.22876 .52655 .23142 .52891 .23534 .52763 .23269 .52528 Mtetra
.23269 .52528 .23534 .52763 .23928 .52636 .23663 .524 Mtetra
.23663 .524 .23928 .52636 .24321 .52508 .24057 .52272 Mtetra
.24057 .52272 .24321 .52508 .24716 .5238 .24451 .52144 Mtetra
.24451 .52144 .24716 .5238 .2511 .52252 .24847 .52015 Mtetra
.24847 .52015 .2511 .52252 .25506 .52124 .25242 .51886 Mtetra
.25242 .51886 .25506 .52124 .25902 .51995 .25639 .51758 Mtetra
.25639 .51758 .25902 .51995 .26299 .51867 .26036 .51629 Mtetra
.26036 .51629 .26299 .51867 .26696 .51738 .26433 .51499 Mtetra
.26433 .51499 .26696 .51738 .27094 .51609 .26832 .5137 Mtetra
.26832 .5137 .27094 .51609 .27492 .51479 .27231 .5124 Mtetra
.27231 .5124 .27492 .51479 .27891 .5135 .2763 .51111 Mtetra
.946 .693 .523 r
.2763 .51111 .27891 .5135 .29359 .36501 .29111 .36252 Mtetra
.664 .741 .908 r
.29111 .36252 .29359 .36501 .29743 .36366 .29495 .36116 Mtetra
.29495 .36116 .29743 .36366 .30126 .36231 .29879 .35981 Mtetra
.29879 .35981 .30126 .36231 .30511 .36096 .30264 .35845 Mtetra
.30264 .35845 .30511 .36096 .30896 .3596 .30649 .3571 Mtetra
.30649 .3571 .30896 .3596 .31282 .35825 .31035 .35574 Mtetra
.31035 .35574 .31282 .35825 .31668 .35689 .31422 .35437 Mtetra
.31422 .35437 .31668 .35689 .32055 .35553 .31809 .35301 Mtetra
.31809 .35301 .32055 .35553 .32442 .35416 .32197 .35165 Mtetra
.32197 .35165 .32442 .35416 .3283 .3528 .32585 .35028 Mtetra
.32585 .35028 .3283 .3528 .33218 .35143 .32974 .34891 Mtetra
.32974 .34891 .33218 .35143 .33607 .35007 .33363 .34754 Mtetra
.33363 .34754 .33607 .35007 .33997 .3487 .33753 .34616 Mtetra
.33753 .34616 .33997 .3487 .34387 .34732 .34144 .34479 Mtetra
.34144 .34479 .34387 .34732 .34778 .34595 .34535 .34341 Mtetra
.34535 .34341 .34778 .34595 .35169 .34457 .34926 .34203 Mtetra
.34926 .34203 .35169 .34457 .35561 .3432 .35319 .34065 Mtetra
.35319 .34065 .35561 .3432 .35954 .34182 .35711 .33926 Mtetra
.35711 .33926 .35954 .34182 .36347 .34043 .36105 .33788 Mtetra
.36105 .33788 .36347 .34043 .3674 .33905 .36499 .33649 Mtetra
.36499 .33649 .3674 .33905 .37135 .33766 .36893 .3351 Mtetra
.36893 .3351 .37135 .33766 .37529 .33627 .37289 .33371 Mtetra
.37289 .33371 .37529 .33627 .37925 .33488 .37684 .33231 Mtetra
.37684 .33231 .37925 .33488 .38321 .33349 .38081 .33092 Mtetra
0 .067 .58 r
.38081 .33092 .38321 .33349 .38696 .33699 .38456 .33441 Mtetra
.663 .742 .908 r
.38456 .33441 .38696 .33699 .39094 .3356 .38854 .33302 Mtetra
.38854 .33302 .39094 .3356 .39492 .3342 .39253 .33161 Mtetra
.39253 .33161 .39492 .3342 .39891 .3328 .39652 .33021 Mtetra
.39652 .33021 .39891 .3328 .4029 .3314 .40052 .32881 Mtetra
.40052 .32881 .4029 .3314 .4069 .33 .40452 .3274 Mtetra
.40452 .3274 .4069 .33 .41091 .32859 .40853 .32599 Mtetra
.40853 .32599 .41091 .32859 .41492 .32718 .41255 .32458 Mtetra
.41255 .32458 .41492 .32718 .41894 .32577 .41657 .32316 Mtetra
.41657 .32316 .41894 .32577 .42297 .32436 .4206 .32175 Mtetra
.4206 .32175 .42297 .32436 .427 .32295 .42464 .32033 Mtetra
.42464 .32033 .427 .32295 .43104 .32153 .42868 .31891 Mtetra
.42868 .31891 .43104 .32153 .43508 .32011 .43272 .31749 Mtetra
.43272 .31749 .43508 .32011 .43913 .31869 .43678 .31607 Mtetra
.43678 .31607 .43913 .31869 .44318 .31727 .44084 .31464 Mtetra
.44084 .31464 .44318 .31727 .44725 .31585 .4449 .31321 Mtetra
.4449 .31321 .44725 .31585 .45131 .31442 .44897 .31178 Mtetra
.44897 .31178 .45131 .31442 .45371 .38868 .45305 .31035 Mtetra
0 0 .342 r
.45305 .31035 .45371 .38868 .45789 .38727 .4555 .38467 Mtetra
.658 .749 .917 r
.4555 .38467 .45789 .38727 .46207 .38586 .45968 .38325 Mtetra
.45968 .38325 .46207 .38586 .46626 .38445 .46388 .38184 Mtetra
.46388 .38184 .46626 .38445 .47046 .38304 .46808 .38042 Mtetra
.964 .705 .495 r
.46808 .38042 .47046 .38304 .47466 .38162 .47345 .3081 Mtetra
.544 .332 .543 r
.47345 .3081 .47466 .38162 .47887 .3802 .47757 .30665 Mtetra
.47757 .30665 .47887 .3802 .48401 .30787 .4817 .3052 Mtetra
.663 .742 .909 r
.4817 .3052 .48401 .30787 .48814 .30643 .48583 .30376 Mtetra
.48583 .30376 .48814 .30643 .49227 .30498 .48997 .3023 Mtetra
.48997 .3023 .49227 .30498 .49642 .30353 .49412 .30085 Mtetra
.49412 .30085 .49642 .30353 .50056 .30208 .49827 .2994 Mtetra
.49827 .2994 .50056 .30208 .50472 .30063 .50243 .29794 Mtetra
.50243 .29794 .50472 .30063 .50888 .29917 .50659 .29648 Mtetra
.50659 .29648 .50888 .29917 .51305 .29771 .51076 .29502 Mtetra
.51076 .29502 .51305 .29771 .51722 .29625 .51494 .29355 Mtetra
.51494 .29355 .51722 .29625 .5214 .29479 .51912 .29209 Mtetra
.51912 .29209 .5214 .29479 .52559 .29333 .52331 .29062 Mtetra
.52331 .29062 .52559 .29333 .52978 .29186 .52751 .28915 Mtetra
.52751 .28915 .52978 .29186 .53398 .29039 .53171 .28767 Mtetra
.53171 .28767 .53398 .29039 .53818 .28892 .53592 .2862 Mtetra
.932 .765 .652 r
.53592 .2862 .53818 .28892 .54234 .27753 .54009 .2748 Mtetra
.664 .741 .908 r
.54009 .2748 .54234 .27753 .54654 .27605 .5443 .27332 Mtetra
.5443 .27332 .54654 .27605 .55075 .27457 .54851 .27183 Mtetra
.54851 .27183 .55075 .27457 .55497 .27309 .55274 .27035 Mtetra
.55274 .27035 .55497 .27309 .55919 .2716 .55696 .26886 Mtetra
.55696 .26886 .55919 .2716 .56343 .27012 .5612 .26736 Mtetra
.5612 .26736 .56343 .27012 .56766 .26863 .56544 .26587 Mtetra
.56544 .26587 .56766 .26863 .57191 .26713 .56969 .26437 Mtetra
.56969 .26437 .57191 .26713 .57616 .26564 .57394 .26288 Mtetra
.57394 .26288 .57616 .26564 .58041 .26414 .5782 .26137 Mtetra
.5782 .26137 .58041 .26414 .58467 .26264 .58247 .25987 Mtetra
.58247 .25987 .58467 .26264 .58894 .26114 .58674 .25837 Mtetra
.58674 .25837 .58894 .26114 .59322 .25964 .59102 .25686 Mtetra
.59102 .25686 .59322 .25964 .5975 .25813 .59531 .25535 Mtetra
.891 .488 .06 r
.59531 .25535 .5975 .25813 .60217 .27158 .59997 .2688 Mtetra
.663 .743 .91 r
.59997 .2688 .60217 .27158 .60648 .27007 .60429 .26729 Mtetra
.60429 .26729 .60648 .27007 .61081 .26857 .60862 .26577 Mtetra
.60862 .26577 .61081 .26857 .61514 .26705 .61295 .26426 Mtetra
.61295 .26426 .61514 .26705 .61947 .26554 .61729 .26274 Mtetra
.61729 .26274 .61947 .26554 .62382 .26402 .62164 .26122 Mtetra
.62164 .26122 .62382 .26402 .62817 .26251 .626 .2597 Mtetra
.626 .2597 .62817 .26251 .63253 .26099 .63036 .25817 Mtetra
.63036 .25817 .63253 .26099 .63689 .25946 .63473 .25665 Mtetra
.63473 .25665 .63689 .25946 .64126 .25794 .6391 .25512 Mtetra
.6391 .25512 .64126 .25794 .64564 .25641 .64349 .25358 Mtetra
.64349 .25358 .64564 .25641 .65002 .25488 .64788 .25205 Mtetra
.64788 .25205 .65002 .25488 .65441 .25335 .65227 .25051 Mtetra
.65227 .25051 .65441 .25335 .65903 .25685 .65667 .24897 Mtetra
.615 .513 .715 r
.65667 .24897 .65903 .25685 .66344 .25531 .66108 .24743 Mtetra
.331 .335 .713 r
.66108 .24743 .66344 .25531 .66786 .25378 .66573 .25093 Mtetra
.662 .743 .91 r
.66573 .25093 .66786 .25378 .67229 .25223 .67016 .24938 Mtetra
.67016 .24938 .67229 .25223 .67672 .25069 .6746 .24784 Mtetra
.6746 .24784 .67672 .25069 .68116 .24915 .67905 .24629 Mtetra
.67905 .24629 .68116 .24915 .68561 .2476 .6835 .24473 Mtetra
.6835 .24473 .68561 .2476 .69007 .24605 .68796 .24318 Mtetra
.68796 .24318 .69007 .24605 .69453 .2445 .69242 .24162 Mtetra
.972 .659 .329 r
.69242 .24162 .69453 .2445 .69899 .24294 .70493 .38305 Mtetra
.527 .296 .507 r
.70493 .38305 .69899 .24294 .7118 .38434 .70962 .38154 Mtetra
.651 .757 .927 r
.70962 .38154 .7118 .38434 .7165 .38282 .71433 .38002 Mtetra
.71433 .38002 .7165 .38282 .72121 .3813 .71904 .3785 Mtetra
.71904 .3785 .72121 .3813 .72592 .37978 .72376 .37697 Mtetra
.72376 .37697 .72592 .37978 .73064 .37826 .72849 .37544 Mtetra
.72849 .37544 .73064 .37826 .73537 .37674 .73322 .37391 Mtetra
.73322 .37391 .73537 .37674 .74011 .37521 .73797 .37238 Mtetra
.73797 .37238 .74011 .37521 .74486 .37368 .74272 .37085 Mtetra
.74272 .37085 .74486 .37368 .74961 .37215 .74748 .36931 Mtetra
.74748 .36931 .74961 .37215 .75437 .37061 .75224 .36777 Mtetra
.75224 .36777 .75437 .37061 .75914 .36907 .75702 .36623 Mtetra
.75702 .36623 .75914 .36907 .76392 .36753 .7618 .36468 Mtetra
.7618 .36468 .76392 .36753 .7687 .36599 .76659 .36314 Mtetra
.76659 .36314 .7687 .36599 .7735 .36445 .77139 .36159 Mtetra
.77139 .36159 .7735 .36445 .7783 .3629 .7762 .36003 Mtetra
.7762 .36003 .7783 .3629 .78311 .36135 .78101 .35848 Mtetra
.78101 .35848 .78311 .36135 .78792 .35979 .78583 .35692 Mtetra
.78583 .35692 .78792 .35979 .79275 .35824 .79067 .35536 Mtetra
.79067 .35536 .79275 .35824 .79758 .35668 .79551 .3538 Mtetra
.79551 .3538 .79758 .35668 .80242 .35512 .80035 .35223 Mtetra
.80035 .35223 .80242 .35512 .80727 .35356 .80521 .35066 Mtetra
.80521 .35066 .80727 .35356 .81213 .35199 .81007 .34909 Mtetra
.81007 .34909 .81213 .35199 .817 .35042 .81494 .34752 Mtetra
.81494 .34752 .817 .35042 .82187 .34885 .81982 .34594 Mtetra
.653 .755 .925 r
.16838 .53792 .17109 .54023 .17493 .53898 .17222 .53666 Mtetra
.17222 .53666 .17493 .53898 .17877 .53772 .17607 .53541 Mtetra
.17607 .53541 .17877 .53772 .18262 .53647 .17992 .53415 Mtetra
.17992 .53415 .18262 .53647 .18647 .53521 .18377 .53289 Mtetra
.18377 .53289 .18647 .53521 .19033 .53396 .18764 .53163 Mtetra
.18764 .53163 .19033 .53396 .19419 .5327 .1915 .53037 Mtetra
.1915 .53037 .19419 .5327 .19806 .53143 .19538 .5291 Mtetra
.19538 .5291 .19806 .53143 .20194 .53017 .19926 .52783 Mtetra
.19926 .52783 .20194 .53017 .20582 .52891 .20314 .52657 Mtetra
.20314 .52657 .20582 .52891 .20971 .52764 .20703 .52529 Mtetra
.20703 .52529 .20971 .52764 .2136 .52637 .21093 .52402 Mtetra
.21093 .52402 .2136 .52637 .21701 .53037 .21483 .52275 Mtetra
.177 .229 .679 r
.21483 .52275 .21701 .53037 .22092 .5291 .21825 .52675 Mtetra
.652 .755 .925 r
.21825 .52675 .22092 .5291 .22484 .52783 .22217 .52547 Mtetra
.22217 .52547 .22484 .52783 .22876 .52655 .2261 .5242 Mtetra
.2261 .5242 .22876 .52655 .23269 .52528 .23003 .52292 Mtetra
.23003 .52292 .23269 .52528 .23663 .524 .23397 .52163 Mtetra
.23397 .52163 .23663 .524 .24057 .52272 .23791 .52035 Mtetra
.23791 .52035 .24057 .52272 .24451 .52144 .24186 .51906 Mtetra
.24186 .51906 .24451 .52144 .24847 .52015 .24582 .51777 Mtetra
.24582 .51777 .24847 .52015 .25242 .51886 .24978 .51648 Mtetra
.24978 .51648 .25242 .51886 .25639 .51758 .25375 .51519 Mtetra
.25375 .51519 .25639 .51758 .26036 .51629 .25772 .5139 Mtetra
.25772 .5139 .26036 .51629 .26433 .51499 .2617 .5126 Mtetra
.2617 .5126 .26433 .51499 .26832 .5137 .26569 .51131 Mtetra
.26569 .51131 .26832 .5137 .27231 .5124 .26968 .51001 Mtetra
.26968 .51001 .27231 .5124 .2763 .51111 .27368 .5087 Mtetra
.27368 .5087 .2763 .51111 .29111 .36252 .27768 .5074 Mtetra
0 0 .157 r
.27768 .5074 .29111 .36252 .29495 .36116 .29246 .35866 Mtetra
.664 .741 .908 r
.29246 .35866 .29495 .36116 .29879 .35981 .29631 .35731 Mtetra
.29631 .35731 .29879 .35981 .30264 .35845 .30016 .35595 Mtetra
.30016 .35595 .30264 .35845 .30649 .3571 .30402 .35458 Mtetra
.30402 .35458 .30649 .3571 .31035 .35574 .30788 .35322 Mtetra
.30788 .35322 .31035 .35574 .31422 .35437 .31175 .35186 Mtetra
.31175 .35186 .31422 .35437 .31809 .35301 .31563 .35049 Mtetra
.31563 .35049 .31809 .35301 .32197 .35165 .31951 .34912 Mtetra
.31951 .34912 .32197 .35165 .32585 .35028 .32339 .34775 Mtetra
.32339 .34775 .32585 .35028 .32974 .34891 .32728 .34637 Mtetra
.32728 .34637 .32974 .34891 .33363 .34754 .33118 .345 Mtetra
.33118 .345 .33363 .34754 .33753 .34616 .33508 .34362 Mtetra
.33508 .34362 .33753 .34616 .34144 .34479 .33899 .34224 Mtetra
.33899 .34224 .34144 .34479 .34535 .34341 .34291 .34086 Mtetra
.34291 .34086 .34535 .34341 .34926 .34203 .34683 .33948 Mtetra
.34683 .33948 .34926 .34203 .35319 .34065 .35075 .33809 Mtetra
.35075 .33809 .35319 .34065 .35711 .33926 .35469 .3367 Mtetra
.35469 .3367 .35711 .33926 .36105 .33788 .35862 .33531 Mtetra
.35862 .33531 .36105 .33788 .36499 .33649 .36257 .33392 Mtetra
.36257 .33392 .36499 .33649 .36893 .3351 .36652 .33253 Mtetra
.36652 .33253 .36893 .3351 .37289 .33371 .37047 .33113 Mtetra
.37047 .33113 .37289 .33371 .37684 .33231 .37443 .32973 Mtetra
.37443 .32973 .37684 .33231 .38081 .33092 .3784 .32833 Mtetra
.3784 .32833 .38081 .33092 .38456 .33441 .38237 .32693 Mtetra
.267 .292 .701 r
.38237 .32693 .38456 .33441 .38854 .33302 .38614 .33043 Mtetra
.663 .742 .908 r
.38614 .33043 .38854 .33302 .39253 .33161 .39013 .32902 Mtetra
.39013 .32902 .39253 .33161 .39652 .33021 .39412 .32762 Mtetra
.39412 .32762 .39652 .33021 .40052 .32881 .39813 .32621 Mtetra
.39813 .32621 .40052 .32881 .40452 .3274 .40213 .3248 Mtetra
.40213 .3248 .40452 .3274 .40853 .32599 .40615 .32338 Mtetra
.40615 .32338 .40853 .32599 .41255 .32458 .41017 .32197 Mtetra
.41017 .32197 .41255 .32458 .41657 .32316 .4142 .32055 Mtetra
.4142 .32055 .41657 .32316 .4206 .32175 .41823 .31913 Mtetra
.41823 .31913 .4206 .32175 .42464 .32033 .42227 .31771 Mtetra
.42227 .31771 .42464 .32033 .42868 .31891 .42631 .31628 Mtetra
.42631 .31628 .42868 .31891 .43272 .31749 .43036 .31486 Mtetra
.43036 .31486 .43272 .31749 .43678 .31607 .43442 .31343 Mtetra
.43442 .31343 .43678 .31607 .44084 .31464 .43848 .312 Mtetra
.43848 .312 .44084 .31464 .4449 .31321 .44255 .31057 Mtetra
.44255 .31057 .4449 .31321 .44897 .31178 .44663 .30913 Mtetra
.44663 .30913 .44897 .31178 .45305 .31035 .45071 .3077 Mtetra
.965 .668 .417 r
.45071 .3077 .45305 .31035 .4555 .38467 .4531 .38206 Mtetra
.658 .749 .917 r
.4531 .38206 .4555 .38467 .45968 .38325 .45729 .38064 Mtetra
.45729 .38064 .45968 .38325 .46388 .38184 .46149 .37922 Mtetra
.963 .705 .496 r
.46149 .37922 .46388 .38184 .46808 .38042 .467 .30687 Mtetra
.543 .332 .543 r
.467 .30687 .46808 .38042 .47345 .3081 .47112 .30543 Mtetra
.663 .742 .909 r
.47112 .30543 .47345 .3081 .47757 .30665 .47525 .30398 Mtetra
.47525 .30398 .47757 .30665 .4817 .3052 .47938 .30253 Mtetra
.47938 .30253 .4817 .3052 .48583 .30376 .48352 .30108 Mtetra
.48352 .30108 .48583 .30376 .48997 .3023 .48766 .29962 Mtetra
.48766 .29962 .48997 .3023 .49412 .30085 .49181 .29816 Mtetra
.49181 .29816 .49412 .30085 .49827 .2994 .49597 .2967 Mtetra
.49597 .2967 .49827 .2994 .50243 .29794 .50013 .29524 Mtetra
.50013 .29524 .50243 .29794 .50659 .29648 .5043 .29378 Mtetra
.5043 .29378 .50659 .29648 .51076 .29502 .50847 .29231 Mtetra
.50847 .29231 .51076 .29502 .51494 .29355 .51265 .29084 Mtetra
.51265 .29084 .51494 .29355 .51912 .29209 .51684 .28937 Mtetra
.51684 .28937 .51912 .29209 .52331 .29062 .52104 .2879 Mtetra
.52104 .2879 .52331 .29062 .52751 .28915 .52524 .28643 Mtetra
.52524 .28643 .52751 .28915 .53171 .28767 .52944 .28495 Mtetra
.52944 .28495 .53171 .28767 .53592 .2862 .53366 .28347 Mtetra
.932 .765 .652 r
.53366 .28347 .53592 .2862 .54009 .2748 .53784 .27206 Mtetra
.664 .741 .908 r
.53784 .27206 .54009 .2748 .5443 .27332 .54205 .27057 Mtetra
.54205 .27057 .5443 .27332 .54851 .27183 .54627 .26909 Mtetra
.54627 .26909 .54851 .27183 .55274 .27035 .5505 .26759 Mtetra
.5505 .26759 .55274 .27035 .55696 .26886 .55473 .2661 Mtetra
.55473 .2661 .55696 .26886 .5612 .26736 .55897 .2646 Mtetra
.55897 .2646 .5612 .26736 .56544 .26587 .56321 .26311 Mtetra
.56321 .26311 .56544 .26587 .56969 .26437 .56746 .26161 Mtetra
.56746 .26161 .56969 .26437 .57394 .26288 .57172 .2601 Mtetra
.57172 .2601 .57394 .26288 .5782 .26137 .57599 .2586 Mtetra
.57599 .2586 .5782 .26137 .58247 .25987 .58026 .25709 Mtetra
.58026 .25709 .58247 .25987 .58674 .25837 .58454 .25558 Mtetra
.58454 .25558 .58674 .25837 .59102 .25686 .58882 .25407 Mtetra
.58882 .25407 .59102 .25686 .59531 .25535 .59311 .25255 Mtetra
.891 .488 .06 r
.59311 .25255 .59531 .25535 .59997 .2688 .59777 .26601 Mtetra
.663 .743 .91 r
.59777 .26601 .59997 .2688 .60429 .26729 .60209 .26449 Mtetra
.60209 .26449 .60429 .26729 .60862 .26577 .60642 .26297 Mtetra
.60642 .26297 .60862 .26577 .61295 .26426 .61076 .26145 Mtetra
.61076 .26145 .61295 .26426 .61729 .26274 .61511 .25993 Mtetra
.61511 .25993 .61729 .26274 .62164 .26122 .61946 .25841 Mtetra
.61946 .25841 .62164 .26122 .626 .2597 .62382 .25688 Mtetra
.62382 .25688 .626 .2597 .63036 .25817 .62819 .25535 Mtetra
.62819 .25535 .63036 .25817 .63473 .25665 .63256 .25382 Mtetra
.63256 .25382 .63473 .25665 .6391 .25512 .63694 .25229 Mtetra
.63694 .25229 .6391 .25512 .64349 .25358 .64133 .25075 Mtetra
.64133 .25075 .64349 .25358 .64788 .25205 .64572 .24921 Mtetra
.64572 .24921 .64788 .25205 .65227 .25051 .65012 .24767 Mtetra
.65012 .24767 .65227 .25051 .65667 .24897 .65453 .24613 Mtetra
.65453 .24613 .65667 .24897 .66108 .24743 .65895 .24458 Mtetra
.65895 .24458 .66108 .24743 .66573 .25093 .66337 .24303 Mtetra
.331 .335 .713 r
.66337 .24303 .66573 .25093 .67016 .24938 .66803 .24653 Mtetra
.662 .743 .91 r
.66803 .24653 .67016 .24938 .6746 .24784 .67247 .24497 Mtetra
.67247 .24497 .6746 .24784 .67905 .24629 .67692 .24342 Mtetra
.67692 .24342 .67905 .24629 .6835 .24473 .68138 .24186 Mtetra
.68138 .24186 .6835 .24473 .68796 .24318 .68584 .2403 Mtetra
.972 .66 .331 r
.68584 .2403 .68796 .24318 .69242 .24162 .69804 .38177 Mtetra
.527 .295 .507 r
.69804 .38177 .69242 .24162 .70493 .38305 .70274 .38025 Mtetra
.651 .757 .927 r
.70274 .38025 .70493 .38305 .70962 .38154 .70744 .37873 Mtetra
.70744 .37873 .70962 .38154 .71433 .38002 .71215 .37721 Mtetra
.71215 .37721 .71433 .38002 .71904 .3785 .71687 .37568 Mtetra
.71687 .37568 .71904 .3785 .72376 .37697 .72159 .37415 Mtetra
.72159 .37415 .72376 .37697 .72849 .37544 .72632 .37262 Mtetra
.72632 .37262 .72849 .37544 .73322 .37391 .73107 .37108 Mtetra
.73107 .37108 .73322 .37391 .73797 .37238 .73581 .36955 Mtetra
.73581 .36955 .73797 .37238 .74272 .37085 .74057 .36801 Mtetra
.74057 .36801 .74272 .37085 .74748 .36931 .74534 .36647 Mtetra
.74534 .36647 .74748 .36931 .75224 .36777 .75011 .36492 Mtetra
.75011 .36492 .75224 .36777 .75702 .36623 .75489 .36337 Mtetra
.75489 .36337 .75702 .36623 .7618 .36468 .75968 .36182 Mtetra
.75968 .36182 .7618 .36468 .76659 .36314 .76447 .36027 Mtetra
.76447 .36027 .76659 .36314 .77139 .36159 .76928 .35872 Mtetra
.76928 .35872 .77139 .36159 .7762 .36003 .77409 .35716 Mtetra
.77409 .35716 .7762 .36003 .78101 .35848 .77891 .3556 Mtetra
.77891 .3556 .78101 .35848 .78583 .35692 .78374 .35404 Mtetra
.78374 .35404 .78583 .35692 .79067 .35536 .78858 .35247 Mtetra
.78858 .35247 .79067 .35536 .79551 .3538 .79342 .3509 Mtetra
.79342 .3509 .79551 .3538 .80035 .35223 .79827 .34933 Mtetra
.79827 .34933 .80035 .35223 .80521 .35066 .80314 .34776 Mtetra
.80314 .34776 .80521 .35066 .81007 .34909 .808 .34618 Mtetra
.808 .34618 .81007 .34909 .81494 .34752 .81288 .34461 Mtetra
.81288 .34461 .81494 .34752 .81982 .34594 .81777 .34302 Mtetra
.653 .755 .925 r
.16567 .5356 .16838 .53792 .17222 .53666 .16951 .53434 Mtetra
.16951 .53434 .17222 .53666 .17607 .53541 .17336 .53308 Mtetra
.17336 .53308 .17607 .53541 .17992 .53415 .17721 .53182 Mtetra
.17721 .53182 .17992 .53415 .18377 .53289 .18107 .53056 Mtetra
.18107 .53056 .18377 .53289 .18764 .53163 .18494 .5293 Mtetra
.18494 .5293 .18764 .53163 .1915 .53037 .18881 .52803 Mtetra
.18881 .52803 .1915 .53037 .19538 .5291 .19268 .52676 Mtetra
.19268 .52676 .19538 .5291 .19926 .52783 .19657 .52549 Mtetra
.19657 .52549 .19926 .52783 .20314 .52657 .20045 .52422 Mtetra
.20045 .52422 .20314 .52657 .20703 .52529 .20435 .52294 Mtetra
.20435 .52294 .20703 .52529 .21093 .52402 .20825 .52167 Mtetra
.20825 .52167 .21093 .52402 .21483 .52275 .21215 .52039 Mtetra
.652 .137 0 r
.21215 .52039 .21483 .52275 .21825 .52675 .21558 .52439 Mtetra
.652 .755 .925 r
.21558 .52439 .21825 .52675 .22217 .52547 .2195 .52311 Mtetra
.2195 .52311 .22217 .52547 .2261 .5242 .22343 .52183 Mtetra
.22343 .52183 .2261 .5242 .23003 .52292 .22737 .52055 Mtetra
.22737 .52055 .23003 .52292 .23397 .52163 .23131 .51926 Mtetra
.23131 .51926 .23397 .52163 .23791 .52035 .23525 .51797 Mtetra
.23525 .51797 .23791 .52035 .24186 .51906 .23921 .51668 Mtetra
.23921 .51668 .24186 .51906 .24582 .51777 .24317 .51539 Mtetra
.24317 .51539 .24582 .51777 .24978 .51648 .24713 .5141 Mtetra
.24713 .5141 .24978 .51648 .25375 .51519 .2511 .5128 Mtetra
.2511 .5128 .25375 .51519 .25772 .5139 .25508 .5115 Mtetra
.25508 .5115 .25772 .5139 .2617 .5126 .25906 .51021 Mtetra
.25906 .51021 .2617 .5126 .26569 .51131 .26305 .5089 Mtetra
.26305 .5089 .26569 .51131 .26968 .51001 .26705 .5076 Mtetra
.26705 .5076 .26968 .51001 .27368 .5087 .27105 .50629 Mtetra
.27105 .50629 .27368 .5087 .27768 .5074 .27506 .50499 Mtetra
.27506 .50499 .27768 .5074 .29246 .35866 .27907 .50368 Mtetra
0 0 .157 r
.27907 .50368 .29246 .35866 .29631 .35731 .29382 .35479 Mtetra
.664 .741 .908 r
.29382 .35479 .29631 .35731 .30016 .35595 .29768 .35343 Mtetra
.29768 .35343 .30016 .35595 .30402 .35458 .30154 .35207 Mtetra
.30154 .35207 .30402 .35458 .30788 .35322 .30541 .3507 Mtetra
.30541 .3507 .30788 .35322 .31175 .35186 .30928 .34933 Mtetra
.30928 .34933 .31175 .35186 .31563 .35049 .31316 .34796 Mtetra
.31316 .34796 .31563 .35049 .31951 .34912 .31704 .34658 Mtetra
.31704 .34658 .31951 .34912 .32339 .34775 .32093 .34521 Mtetra
.32093 .34521 .32339 .34775 .32728 .34637 .32483 .34383 Mtetra
.32483 .34383 .32728 .34637 .33118 .345 .32873 .34245 Mtetra
.32873 .34245 .33118 .345 .33508 .34362 .33263 .34107 Mtetra
.33263 .34107 .33508 .34362 .33899 .34224 .33654 .33969 Mtetra
.33654 .33969 .33899 .34224 .34291 .34086 .34046 .3383 Mtetra
.34046 .3383 .34291 .34086 .34683 .33948 .34439 .33692 Mtetra
.34439 .33692 .34683 .33948 .35075 .33809 .34832 .33553 Mtetra
.34832 .33553 .35075 .33809 .35469 .3367 .35225 .33414 Mtetra
.35225 .33414 .35469 .3367 .35862 .33531 .35619 .33274 Mtetra
.35619 .33274 .35862 .33531 .36257 .33392 .36014 .33135 Mtetra
.36014 .33135 .36257 .33392 .36652 .33253 .36409 .32995 Mtetra
.36409 .32995 .36652 .33253 .37047 .33113 .36805 .32855 Mtetra
.36805 .32855 .37047 .33113 .37443 .32973 .37202 .32715 Mtetra
.37202 .32715 .37443 .32973 .3784 .32833 .37599 .32574 Mtetra
.37599 .32574 .3784 .32833 .38237 .32693 .37996 .32434 Mtetra
0 .07 .583 r
.37996 .32434 .38237 .32693 .38614 .33043 .38373 .32783 Mtetra
.663 .742 .908 r
.38373 .32783 .38614 .33043 .39013 .32902 .38772 .32642 Mtetra
.38772 .32642 .39013 .32902 .39412 .32762 .39172 .32501 Mtetra
.39172 .32501 .39412 .32762 .39813 .32621 .39573 .3236 Mtetra
.39573 .3236 .39813 .32621 .40213 .3248 .39974 .32219 Mtetra
.39974 .32219 .40213 .3248 .40615 .32338 .40376 .32077 Mtetra
.40376 .32077 .40615 .32338 .41017 .32197 .40778 .31935 Mtetra
.40778 .31935 .41017 .32197 .4142 .32055 .41181 .31793 Mtetra
.41181 .31793 .4142 .32055 .41823 .31913 .41585 .3165 Mtetra
.41585 .3165 .41823 .31913 .42227 .31771 .41989 .31508 Mtetra
.41989 .31508 .42227 .31771 .42631 .31628 .42394 .31365 Mtetra
.42394 .31365 .42631 .31628 .43036 .31486 .42799 .31222 Mtetra
.42799 .31222 .43036 .31486 .43442 .31343 .43206 .31079 Mtetra
.43206 .31079 .43442 .31343 .43848 .312 .43612 .30935 Mtetra
.43612 .30935 .43848 .312 .44255 .31057 .44019 .30792 Mtetra
.44019 .30792 .44255 .31057 .44663 .30913 .44427 .30648 Mtetra
.44427 .30648 .44663 .30913 .45071 .3077 .44836 .30504 Mtetra
.44836 .30504 .45071 .3077 .4531 .38206 .45245 .3036 Mtetra
0 0 .34 r
.45245 .3036 .4531 .38206 .45729 .38064 .45489 .37802 Mtetra
.963 .705 .497 r
.45489 .37802 .45729 .38064 .46149 .37922 .46055 .30565 Mtetra
.543 .331 .542 r
.46055 .30565 .46149 .37922 .467 .30687 .46467 .3042 Mtetra
.663 .742 .909 r
.46467 .3042 .467 .30687 .47112 .30543 .46879 .30275 Mtetra
.46879 .30275 .47112 .30543 .47525 .30398 .47292 .3013 Mtetra
.47292 .3013 .47525 .30398 .47938 .30253 .47705 .29984 Mtetra
.47705 .29984 .47938 .30253 .48352 .30108 .48119 .29839 Mtetra
.48119 .29839 .48352 .30108 .48766 .29962 .48534 .29693 Mtetra
.48534 .29693 .48766 .29962 .49181 .29816 .4895 .29547 Mtetra
.4895 .29547 .49181 .29816 .49597 .2967 .49366 .294 Mtetra
.49366 .294 .49597 .2967 .50013 .29524 .49782 .29254 Mtetra
.49782 .29254 .50013 .29524 .5043 .29378 .502 .29107 Mtetra
.502 .29107 .5043 .29378 .50847 .29231 .50618 .2896 Mtetra
.50618 .2896 .50847 .29231 .51265 .29084 .51036 .28813 Mtetra
.51036 .28813 .51265 .29084 .51684 .28937 .51455 .28665 Mtetra
.51455 .28665 .51684 .28937 .52104 .2879 .51875 .28518 Mtetra
.51875 .28518 .52104 .2879 .52524 .28643 .52296 .2837 Mtetra
.52296 .2837 .52524 .28643 .52944 .28495 .52717 .28221 Mtetra
.52717 .28221 .52944 .28495 .53366 .28347 .53139 .28073 Mtetra
.932 .765 .652 r
.53139 .28073 .53366 .28347 .53784 .27206 .53558 .26932 Mtetra
.664 .741 .908 r
.53558 .26932 .53784 .27206 .54205 .27057 .53979 .26782 Mtetra
.53979 .26782 .54205 .27057 .54627 .26909 .54402 .26633 Mtetra
.54402 .26633 .54627 .26909 .5505 .26759 .54825 .26483 Mtetra
.54825 .26483 .5505 .26759 .55473 .2661 .55248 .26334 Mtetra
.55248 .26334 .55473 .2661 .55897 .2646 .55673 .26184 Mtetra
.55673 .26184 .55897 .2646 .56321 .26311 .56098 .26033 Mtetra
.56098 .26033 .56321 .26311 .56746 .26161 .56523 .25883 Mtetra
.56523 .25883 .56746 .26161 .57172 .2601 .5695 .25732 Mtetra
.5695 .25732 .57172 .2601 .57599 .2586 .57377 .25581 Mtetra
.57377 .25581 .57599 .2586 .58026 .25709 .57804 .2543 Mtetra
.57804 .2543 .58026 .25709 .58454 .25558 .58233 .25279 Mtetra
.58233 .25279 .58454 .25558 .58882 .25407 .58661 .25127 Mtetra
.58661 .25127 .58882 .25407 .59311 .25255 .59091 .24975 Mtetra
.891 .488 .06 r
.59091 .24975 .59311 .25255 .59777 .26601 .59556 .26321 Mtetra
.663 .743 .91 r
.59556 .26321 .59777 .26601 .60209 .26449 .59989 .26169 Mtetra
.59989 .26169 .60209 .26449 .60642 .26297 .60422 .26017 Mtetra
.60422 .26017 .60642 .26297 .61076 .26145 .60857 .25864 Mtetra
.60857 .25864 .61076 .26145 .61511 .25993 .61292 .25712 Mtetra
.61292 .25712 .61511 .25993 .61946 .25841 .61728 .25559 Mtetra
.61728 .25559 .61946 .25841 .62382 .25688 .62164 .25406 Mtetra
.62164 .25406 .62382 .25688 .62819 .25535 .62601 .25252 Mtetra
.62601 .25252 .62819 .25535 .63256 .25382 .63039 .25099 Mtetra
.63039 .25099 .63256 .25382 .63694 .25229 .63477 .24945 Mtetra
.63477 .24945 .63694 .25229 .64133 .25075 .63916 .24791 Mtetra
.63916 .24791 .64133 .25075 .64572 .24921 .64356 .24636 Mtetra
.64356 .24636 .64572 .24921 .65012 .24767 .64797 .24482 Mtetra
.64797 .24482 .65012 .24767 .65453 .24613 .65238 .24327 Mtetra
.65238 .24327 .65453 .24613 .65895 .24458 .6568 .24172 Mtetra
.6568 .24172 .65895 .24458 .66337 .24303 .66123 .24017 Mtetra
.66123 .24017 .66337 .24303 .66803 .24653 .66566 .23861 Mtetra
.614 .513 .715 r
.66566 .23861 .66803 .24653 .67247 .24497 .6701 .23705 Mtetra
.332 .336 .713 r
.6701 .23705 .67247 .24497 .67692 .24342 .67479 .24054 Mtetra
.662 .743 .91 r
.67479 .24054 .67692 .24342 .68138 .24186 .67926 .23898 Mtetra
.67926 .23898 .68138 .24186 .68584 .2403 .68372 .23742 Mtetra
.972 .66 .331 r
.68372 .23742 .68584 .2403 .69804 .38177 .69584 .37896 Mtetra
.651 .757 .927 r
.69584 .37896 .69804 .38177 .70274 .38025 .70054 .37744 Mtetra
.70054 .37744 .70274 .38025 .70744 .37873 .70525 .37591 Mtetra
.70525 .37591 .70744 .37873 .71215 .37721 .70996 .37439 Mtetra
.70996 .37439 .71215 .37721 .71687 .37568 .71469 .37285 Mtetra
.71469 .37285 .71687 .37568 .72159 .37415 .71942 .37132 Mtetra
.71942 .37132 .72159 .37415 .72632 .37262 .72416 .36978 Mtetra
.72416 .36978 .72632 .37262 .73107 .37108 .7289 .36824 Mtetra
.7289 .36824 .73107 .37108 .73581 .36955 .73366 .3667 Mtetra
.73366 .3667 .73581 .36955 .74057 .36801 .73842 .36516 Mtetra
.73842 .36516 .74057 .36801 .74534 .36647 .74319 .36361 Mtetra
.74319 .36361 .74534 .36647 .75011 .36492 .74797 .36206 Mtetra
.74797 .36206 .75011 .36492 .75489 .36337 .75275 .36051 Mtetra
.75275 .36051 .75489 .36337 .75968 .36182 .75755 .35896 Mtetra
.75755 .35896 .75968 .36182 .76447 .36027 .76235 .3574 Mtetra
.76235 .3574 .76447 .36027 .76928 .35872 .76716 .35584 Mtetra
.76716 .35584 .76928 .35872 .77409 .35716 .77198 .35428 Mtetra
.77198 .35428 .77409 .35716 .77891 .3556 .7768 .35271 Mtetra
.7768 .35271 .77891 .3556 .78374 .35404 .78164 .35115 Mtetra
.78164 .35115 .78374 .35404 .78858 .35247 .78648 .34958 Mtetra
.78648 .34958 .78858 .35247 .79342 .3509 .79133 .348 Mtetra
.79133 .348 .79342 .3509 .79827 .34933 .79619 .34643 Mtetra
.79619 .34643 .79827 .34933 .80314 .34776 .80106 .34485 Mtetra
.80106 .34485 .80314 .34776 .808 .34618 .80593 .34327 Mtetra
.80593 .34327 .808 .34618 .81288 .34461 .81081 .34168 Mtetra
.81081 .34168 .81288 .34461 .81777 .34302 .81571 .3401 Mtetra
.653 .755 .925 r
.16294 .53328 .16567 .5356 .16951 .53434 .16679 .53202 Mtetra
.16679 .53202 .16951 .53434 .17336 .53308 .17064 .53075 Mtetra
.17064 .53075 .17336 .53308 .17721 .53182 .1745 .52949 Mtetra
.1745 .52949 .17721 .53182 .18107 .53056 .17836 .52822 Mtetra
.17836 .52822 .18107 .53056 .18494 .5293 .18223 .52696 Mtetra
.18223 .52696 .18494 .5293 .18881 .52803 .1861 .52569 Mtetra
.1861 .52569 .18881 .52803 .19268 .52676 .18998 .52441 Mtetra
.18998 .52441 .19268 .52676 .19657 .52549 .19387 .52314 Mtetra
.19387 .52314 .19657 .52549 .20045 .52422 .19776 .52186 Mtetra
.19776 .52186 .20045 .52422 .20435 .52294 .20166 .52059 Mtetra
.20166 .52059 .20435 .52294 .20825 .52167 .20556 .51931 Mtetra
.20556 .51931 .20825 .52167 .21215 .52039 .20947 .51802 Mtetra
.20947 .51802 .21215 .52039 .21558 .52439 .21338 .51674 Mtetra
.175 .228 .679 r
.21338 .51674 .21558 .52439 .2195 .52311 .21682 .52074 Mtetra
.652 .755 .925 r
.21682 .52074 .2195 .52311 .22343 .52183 .22075 .51946 Mtetra
.22075 .51946 .22343 .52183 .22737 .52055 .22469 .51817 Mtetra
.22469 .51817 .22737 .52055 .23131 .51926 .22864 .51688 Mtetra
.22864 .51688 .23131 .51926 .23525 .51797 .23259 .51559 Mtetra
.23259 .51559 .23525 .51797 .23921 .51668 .23654 .5143 Mtetra
.23654 .5143 .23921 .51668 .24317 .51539 .24051 .513 Mtetra
.24051 .513 .24317 .51539 .24713 .5141 .24447 .5117 Mtetra
.24447 .5117 .24713 .5141 .2511 .5128 .24845 .51041 Mtetra
.24845 .51041 .2511 .5128 .25508 .5115 .25243 .5091 Mtetra
.25243 .5091 .25508 .5115 .25906 .51021 .25642 .5078 Mtetra
.25642 .5078 .25906 .51021 .26305 .5089 .26041 .5065 Mtetra
.26041 .5065 .26305 .5089 .26705 .5076 .26441 .50519 Mtetra
.26441 .50519 .26705 .5076 .27105 .50629 .26842 .50388 Mtetra
.26842 .50388 .27105 .50629 .27506 .50499 .27243 .50257 Mtetra
.27243 .50257 .27506 .50499 .27907 .50368 .27644 .50126 Mtetra
.947 .694 .521 r
.27644 .50126 .27907 .50368 .29382 .35479 .29133 .35228 Mtetra
.664 .741 .908 r
.29133 .35228 .29382 .35479 .29768 .35343 .29519 .35091 Mtetra
.29519 .35091 .29768 .35343 .30154 .35207 .29905 .34954 Mtetra
.29905 .34954 .30154 .35207 .30541 .3507 .30292 .34817 Mtetra
.30292 .34817 .30541 .3507 .30928 .34933 .3068 .3468 Mtetra
.3068 .3468 .30928 .34933 .31316 .34796 .31068 .34542 Mtetra
.31068 .34542 .31316 .34796 .31704 .34658 .31457 .34404 Mtetra
.31457 .34404 .31704 .34658 .32093 .34521 .31846 .34267 Mtetra
.31846 .34267 .32093 .34521 .32483 .34383 .32236 .34128 Mtetra
.32236 .34128 .32483 .34383 .32873 .34245 .32626 .3399 Mtetra
.32626 .3399 .32873 .34245 .33263 .34107 .33017 .33852 Mtetra
.33017 .33852 .33263 .34107 .33654 .33969 .33409 .33713 Mtetra
.33409 .33713 .33654 .33969 .34046 .3383 .33801 .33574 Mtetra
.33801 .33574 .34046 .3383 .34439 .33692 .34194 .33435 Mtetra
.34194 .33435 .34439 .33692 .34832 .33553 .34587 .33296 Mtetra
.34587 .33296 .34832 .33553 .35225 .33414 .34981 .33156 Mtetra
.34981 .33156 .35225 .33414 .35619 .33274 .35376 .33016 Mtetra
.35376 .33016 .35619 .33274 .36014 .33135 .35771 .32876 Mtetra
.35771 .32876 .36014 .33135 .36409 .32995 .36166 .32736 Mtetra
.36166 .32736 .36409 .32995 .36805 .32855 .36562 .32596 Mtetra
.36562 .32596 .36805 .32855 .37202 .32715 .36959 .32455 Mtetra
.36959 .32455 .37202 .32715 .37599 .32574 .37357 .32315 Mtetra
.37357 .32315 .37599 .32574 .37996 .32434 .37755 .32174 Mtetra
0 .07 .583 r
.37755 .32174 .37996 .32434 .38373 .32783 .38131 .32523 Mtetra
.663 .742 .908 r
.38131 .32523 .38373 .32783 .38772 .32642 .38531 .32382 Mtetra
.38531 .32382 .38772 .32642 .39172 .32501 .38931 .3224 Mtetra
.38931 .3224 .39172 .32501 .39573 .3236 .39332 .32099 Mtetra
.39332 .32099 .39573 .3236 .39974 .32219 .39734 .31957 Mtetra
.39734 .31957 .39974 .32219 .40376 .32077 .40136 .31815 Mtetra
.40136 .31815 .40376 .32077 .40778 .31935 .40539 .31672 Mtetra
.40539 .31672 .40778 .31935 .41181 .31793 .40942 .3153 Mtetra
.40942 .3153 .41181 .31793 .41585 .3165 .41346 .31387 Mtetra
.41346 .31387 .41585 .3165 .41989 .31508 .41751 .31244 Mtetra
.41751 .31244 .41989 .31508 .42394 .31365 .42156 .31101 Mtetra
.42156 .31101 .42394 .31365 .42799 .31222 .42562 .30957 Mtetra
.42562 .30957 .42799 .31222 .43206 .31079 .42968 .30814 Mtetra
.42968 .30814 .43206 .31079 .43612 .30935 .43375 .3067 Mtetra
.43375 .3067 .43612 .30935 .44019 .30792 .43783 .30526 Mtetra
.43783 .30526 .44019 .30792 .44427 .30648 .44191 .30382 Mtetra
.44191 .30382 .44427 .30648 .44836 .30504 .446 .30237 Mtetra
.446 .30237 .44836 .30504 .45245 .3036 .4501 .30093 Mtetra
0 .121 .638 r
.4501 .30093 .45245 .3036 .45489 .37802 .45409 .30442 Mtetra
.542 .33 .542 r
.45409 .30442 .45489 .37802 .46055 .30565 .4582 .30297 Mtetra
.663 .742 .909 r
.4582 .30297 .46055 .30565 .46467 .3042 .46232 .30152 Mtetra
.46232 .30152 .46467 .3042 .46879 .30275 .46645 .30007 Mtetra
.46645 .30007 .46879 .30275 .47292 .3013 .47058 .29861 Mtetra
.47058 .29861 .47292 .3013 .47705 .29984 .47472 .29715 Mtetra
.47472 .29715 .47705 .29984 .48119 .29839 .47887 .29569 Mtetra
.47887 .29569 .48119 .29839 .48534 .29693 .48302 .29423 Mtetra
.48302 .29423 .48534 .29693 .4895 .29547 .48718 .29276 Mtetra
.48718 .29276 .4895 .29547 .49366 .294 .49134 .2913 Mtetra
.49134 .2913 .49366 .294 .49782 .29254 .49551 .28983 Mtetra
.49551 .28983 .49782 .29254 .502 .29107 .49969 .28835 Mtetra
.49969 .28835 .502 .29107 .50618 .2896 .50387 .28688 Mtetra
.50387 .28688 .50618 .2896 .51036 .28813 .50806 .2854 Mtetra
.50806 .2854 .51036 .28813 .51455 .28665 .51226 .28392 Mtetra
.51226 .28392 .51455 .28665 .51875 .28518 .51646 .28244 Mtetra
.51646 .28244 .51875 .28518 .52296 .2837 .52067 .28096 Mtetra
.52067 .28096 .52296 .2837 .52717 .28221 .52489 .27947 Mtetra
.52489 .27947 .52717 .28221 .53139 .28073 .52911 .27799 Mtetra
.932 .765 .652 r
.52911 .27799 .53139 .28073 .53558 .26932 .53331 .26656 Mtetra
.664 .741 .908 r
.53331 .26656 .53558 .26932 .53979 .26782 .53753 .26506 Mtetra
.53753 .26506 .53979 .26782 .54402 .26633 .54176 .26357 Mtetra
.54176 .26357 .54402 .26633 .54825 .26483 .54599 .26207 Mtetra
.54599 .26207 .54825 .26483 .55248 .26334 .55024 .26057 Mtetra
.55024 .26057 .55248 .26334 .55673 .26184 .55448 .25906 Mtetra
.55448 .25906 .55673 .26184 .56098 .26033 .55874 .25755 Mtetra
.55874 .25755 .56098 .26033 .56523 .25883 .563 .25604 Mtetra
.563 .25604 .56523 .25883 .5695 .25732 .56727 .25453 Mtetra
.56727 .25453 .5695 .25732 .57377 .25581 .57154 .25302 Mtetra
.57154 .25302 .57377 .25581 .57804 .2543 .57582 .2515 Mtetra
.57582 .2515 .57804 .2543 .58233 .25279 .58011 .24998 Mtetra
.58011 .24998 .58233 .25279 .58661 .25127 .5844 .24846 Mtetra
.5844 .24846 .58661 .25127 .59091 .24975 .5887 .24694 Mtetra
.891 .488 .06 r
.5887 .24694 .59091 .24975 .59556 .26321 .59334 .2604 Mtetra
.663 .743 .91 r
.59334 .2604 .59556 .26321 .59989 .26169 .59767 .25888 Mtetra
.59767 .25888 .59989 .26169 .60422 .26017 .60202 .25735 Mtetra
.60202 .25735 .60422 .26017 .60857 .25864 .60636 .25582 Mtetra
.60636 .25582 .60857 .25864 .61292 .25712 .61072 .25429 Mtetra
.61072 .25429 .61292 .25712 .61728 .25559 .61508 .25276 Mtetra
.61508 .25276 .61728 .25559 .62164 .25406 .61945 .25122 Mtetra
.61945 .25122 .62164 .25406 .62601 .25252 .62383 .24968 Mtetra
.62383 .24968 .62601 .25252 .63039 .25099 .62821 .24814 Mtetra
.62821 .24814 .63039 .25099 .63477 .24945 .6326 .2466 Mtetra
.6326 .2466 .63477 .24945 .63916 .24791 .63699 .24506 Mtetra
.63699 .24506 .63916 .24791 .64356 .24636 .6414 .24351 Mtetra
.6414 .24351 .64356 .24636 .64797 .24482 .64581 .24196 Mtetra
.64581 .24196 .64797 .24482 .65238 .24327 .65023 .2404 Mtetra
.65023 .2404 .65238 .24327 .6568 .24172 .65465 .23885 Mtetra
.65465 .23885 .6568 .24172 .66123 .24017 .65908 .23729 Mtetra
.65908 .23729 .66123 .24017 .66566 .23861 .66352 .23573 Mtetra
.66352 .23573 .66566 .23861 .6701 .23705 .66796 .23417 Mtetra
.66796 .23417 .6701 .23705 .67479 .24054 .67241 .2326 Mtetra
.332 .336 .713 r
.67241 .2326 .67479 .24054 .67926 .23898 .67713 .23609 Mtetra
.973 .66 .334 r
.67713 .23609 .67926 .23898 .68372 .23742 .68894 .37767 Mtetra
.525 .293 .505 r
.68894 .37767 .68372 .23742 .69584 .37896 .69363 .37615 Mtetra
.651 .757 .927 r
.69363 .37615 .69584 .37896 .70054 .37744 .69834 .37462 Mtetra
.69834 .37462 .70054 .37744 .70525 .37591 .70305 .37309 Mtetra
.70305 .37309 .70525 .37591 .70996 .37439 .70777 .37156 Mtetra
.70777 .37156 .70996 .37439 .71469 .37285 .7125 .37002 Mtetra
.7125 .37002 .71469 .37285 .71942 .37132 .71724 .36848 Mtetra
.71724 .36848 .71942 .37132 .72416 .36978 .72198 .36694 Mtetra
.72198 .36694 .72416 .36978 .7289 .36824 .72673 .3654 Mtetra
.72673 .3654 .7289 .36824 .73366 .3667 .73149 .36385 Mtetra
.73149 .36385 .73366 .3667 .73842 .36516 .73626 .3623 Mtetra
.73626 .3623 .73842 .36516 .74319 .36361 .74103 .36075 Mtetra
.74103 .36075 .74319 .36361 .74797 .36206 .74582 .3592 Mtetra
.74582 .3592 .74797 .36206 .75275 .36051 .75061 .35764 Mtetra
.75061 .35764 .75275 .36051 .75755 .35896 .75541 .35608 Mtetra
.75541 .35608 .75755 .35896 .76235 .3574 .76022 .35452 Mtetra
.76022 .35452 .76235 .3574 .76716 .35584 .76503 .35295 Mtetra
.76503 .35295 .76716 .35584 .77198 .35428 .76986 .35139 Mtetra
.76986 .35139 .77198 .35428 .7768 .35271 .77469 .34982 Mtetra
.77469 .34982 .7768 .35271 .78164 .35115 .77953 .34824 Mtetra
.77953 .34824 .78164 .35115 .78648 .34958 .78438 .34667 Mtetra
.78438 .34667 .78648 .34958 .79133 .348 .78923 .34509 Mtetra
.78923 .34509 .79133 .348 .79619 .34643 .7941 .34351 Mtetra
.7941 .34351 .79619 .34643 .80106 .34485 .79897 .34193 Mtetra
.79897 .34193 .80106 .34485 .80593 .34327 .80385 .34034 Mtetra
.80385 .34034 .80593 .34327 .81081 .34168 .80874 .33875 Mtetra
.80874 .33875 .81081 .34168 .81571 .3401 .81364 .33716 Mtetra
.653 .755 .925 r
.16021 .53095 .16294 .53328 .16679 .53202 .16406 .52968 Mtetra
.16406 .52968 .16679 .53202 .17064 .53075 .16792 .52842 Mtetra
.16792 .52842 .17064 .53075 .1745 .52949 .17178 .52715 Mtetra
.17178 .52715 .1745 .52949 .17836 .52822 .17564 .52588 Mtetra
.17564 .52588 .17836 .52822 .18223 .52696 .17951 .52461 Mtetra
.17951 .52461 .18223 .52696 .1861 .52569 .18339 .52334 Mtetra
.18339 .52334 .1861 .52569 .18998 .52441 .18727 .52206 Mtetra
.18727 .52206 .18998 .52441 .19387 .52314 .19116 .52078 Mtetra
.19116 .52078 .19387 .52314 .19776 .52186 .19506 .5195 Mtetra
.19506 .5195 .19776 .52186 .20166 .52059 .19896 .51822 Mtetra
.19896 .51822 .20166 .52059 .20556 .51931 .20287 .51694 Mtetra
.20287 .51694 .20556 .51931 .20947 .51802 .20678 .51565 Mtetra
.20678 .51565 .20947 .51802 .21338 .51674 .2107 .51437 Mtetra
.649 .134 0 r
.2107 .51437 .21338 .51674 .21682 .52074 .21413 .51837 Mtetra
.652 .755 .925 r
.21413 .51837 .21682 .52074 .22075 .51946 .21807 .51708 Mtetra
.21807 .51708 .22075 .51946 .22469 .51817 .22201 .51579 Mtetra
.22201 .51579 .22469 .51817 .22864 .51688 .22596 .5145 Mtetra
.22596 .5145 .22864 .51688 .23259 .51559 .22991 .5132 Mtetra
.22991 .5132 .23259 .51559 .23654 .5143 .23387 .5119 Mtetra
.23387 .5119 .23654 .5143 .24051 .513 .23784 .51061 Mtetra
.23784 .51061 .24051 .513 .24447 .5117 .24181 .5093 Mtetra
.24181 .5093 .24447 .5117 .24845 .51041 .24579 .508 Mtetra
.24579 .508 .24845 .51041 .25243 .5091 .24977 .5067 Mtetra
.24977 .5067 .25243 .5091 .25642 .5078 .25376 .50539 Mtetra
.25376 .50539 .25642 .5078 .26041 .5065 .25776 .50408 Mtetra
.25776 .50408 .26041 .5065 .26441 .50519 .26176 .50277 Mtetra
.26176 .50277 .26441 .50519 .26842 .50388 .26577 .50146 Mtetra
.26577 .50146 .26842 .50388 .27243 .50257 .26979 .50014 Mtetra
.26979 .50014 .27243 .50257 .27644 .50126 .27381 .49883 Mtetra
.27381 .49883 .27644 .50126 .29133 .35228 .27784 .49751 Mtetra
0 0 .154 r
.27784 .49751 .29133 .35228 .29519 .35091 .29269 .34838 Mtetra
.664 .741 .908 r
.29269 .34838 .29519 .35091 .29905 .34954 .29656 .34701 Mtetra
.29656 .34701 .29905 .34954 .30292 .34817 .30043 .34563 Mtetra
.30043 .34563 .30292 .34817 .3068 .3468 .30431 .34426 Mtetra
.30431 .34426 .3068 .3468 .31068 .34542 .3082 .34288 Mtetra
.3082 .34288 .31068 .34542 .31457 .34404 .31209 .3415 Mtetra
.31209 .3415 .31457 .34404 .31846 .34267 .31598 .34011 Mtetra
.31598 .34011 .31846 .34267 .32236 .34128 .31989 .33873 Mtetra
.31989 .33873 .32236 .34128 .32626 .3399 .32379 .33734 Mtetra
.32379 .33734 .32626 .3399 .33017 .33852 .32771 .33595 Mtetra
.32771 .33595 .33017 .33852 .33409 .33713 .33163 .33456 Mtetra
.33163 .33456 .33409 .33713 .33801 .33574 .33555 .33317 Mtetra
.33555 .33317 .33801 .33574 .34194 .33435 .33948 .33178 Mtetra
.33948 .33178 .34194 .33435 .34587 .33296 .34342 .33038 Mtetra
.34342 .33038 .34587 .33296 .34981 .33156 .34736 .32898 Mtetra
.34736 .32898 .34981 .33156 .35376 .33016 .35131 .32758 Mtetra
.35131 .32758 .35376 .33016 .35771 .32876 .35527 .32617 Mtetra
.35527 .32617 .35771 .32876 .36166 .32736 .35923 .32477 Mtetra
.35923 .32477 .36166 .32736 .36562 .32596 .36319 .32336 Mtetra
.36319 .32336 .36562 .32596 .36959 .32455 .36716 .32195 Mtetra
.36716 .32195 .36959 .32455 .37357 .32315 .37114 .32054 Mtetra
.37114 .32054 .37357 .32315 .37755 .32174 .37513 .31913 Mtetra
.37513 .31913 .37755 .32174 .38131 .32523 .37911 .31771 Mtetra
.615 .513 .715 r
.37911 .31771 .38131 .32523 .38531 .32382 .38311 .31629 Mtetra
.38311 .31629 .38531 .32382 .38931 .3224 .38711 .31487 Mtetra
.38711 .31487 .38931 .3224 .39332 .32099 .39112 .31345 Mtetra
.39112 .31345 .39332 .32099 .39734 .31957 .39513 .31203 Mtetra
.39513 .31203 .39734 .31957 .40136 .31815 .39915 .3106 Mtetra
.39915 .3106 .40136 .31815 .40539 .31672 .40318 .30917 Mtetra
.40318 .30917 .40539 .31672 .40942 .3153 .40721 .30774 Mtetra
.40721 .30774 .40942 .3153 .41346 .31387 .41125 .30631 Mtetra
.41125 .30631 .41346 .31387 .41751 .31244 .41529 .30487 Mtetra
.41529 .30487 .41751 .31244 .42156 .31101 .41934 .30344 Mtetra
.41934 .30344 .42156 .31101 .42562 .30957 .4234 .302 Mtetra
.4234 .302 .42562 .30957 .42968 .30814 .42746 .30055 Mtetra
.42746 .30055 .42968 .30814 .43375 .3067 .43153 .29911 Mtetra
.43153 .29911 .43375 .3067 .43783 .30526 .4356 .29767 Mtetra
.4356 .29767 .43783 .30526 .44191 .30382 .43968 .29622 Mtetra
.43968 .29622 .44191 .30382 .446 .30237 .44377 .29477 Mtetra
.44377 .29477 .446 .30237 .4501 .30093 .44786 .29331 Mtetra
0 0 .492 r
.44786 .29331 .4501 .30093 .45409 .30442 .45173 .30175 Mtetra
.663 .742 .909 r
.45173 .30175 .45409 .30442 .4582 .30297 .45585 .30029 Mtetra
.45585 .30029 .4582 .30297 .46232 .30152 .45997 .29884 Mtetra
.45997 .29884 .46232 .30152 .46645 .30007 .4641 .29738 Mtetra
.4641 .29738 .46645 .30007 .47058 .29861 .46824 .29592 Mtetra
.46824 .29592 .47058 .29861 .47472 .29715 .47238 .29445 Mtetra
.47238 .29445 .47472 .29715 .47887 .29569 .47653 .29299 Mtetra
.47653 .29299 .47887 .29569 .48302 .29423 .48069 .29152 Mtetra
.48069 .29152 .48302 .29423 .48718 .29276 .48485 .29005 Mtetra
.48485 .29005 .48718 .29276 .49134 .2913 .48902 .28858 Mtetra
.48902 .28858 .49134 .2913 .49551 .28983 .49319 .28711 Mtetra
.49319 .28711 .49551 .28983 .49969 .28835 .49738 .28563 Mtetra
.49738 .28563 .49969 .28835 .50387 .28688 .50156 .28415 Mtetra
.50156 .28415 .50387 .28688 .50806 .2854 .50576 .28267 Mtetra
.50576 .28267 .50806 .2854 .51226 .28392 .50996 .28119 Mtetra
.50996 .28119 .51226 .28392 .51646 .28244 .51417 .2797 Mtetra
.51417 .2797 .51646 .28244 .52067 .28096 .51838 .27821 Mtetra
.51838 .27821 .52067 .28096 .52489 .27947 .5226 .27673 Mtetra
.5226 .27673 .52489 .27947 .52911 .27799 .52682 .27523 Mtetra
.932 .765 .652 r
.52682 .27523 .52911 .27799 .53331 .26656 .53104 .2638 Mtetra
.664 .741 .908 r
.53104 .2638 .53331 .26656 .53753 .26506 .53526 .2623 Mtetra
.53526 .2623 .53753 .26506 .54176 .26357 .5395 .2608 Mtetra
.5395 .2608 .54176 .26357 .54599 .26207 .54373 .25929 Mtetra
.54373 .25929 .54599 .26207 .55024 .26057 .54798 .25779 Mtetra
.54798 .25779 .55024 .26057 .55448 .25906 .55223 .25628 Mtetra
.55223 .25628 .55448 .25906 .55874 .25755 .55649 .25477 Mtetra
.55649 .25477 .55874 .25755 .563 .25604 .56076 .25325 Mtetra
.56076 .25325 .563 .25604 .56727 .25453 .56503 .25174 Mtetra
.56503 .25174 .56727 .25453 .57154 .25302 .5693 .25022 Mtetra
.5693 .25022 .57154 .25302 .57582 .2515 .57359 .2487 Mtetra
.57359 .2487 .57582 .2515 .58011 .24998 .57788 .24717 Mtetra
.57788 .24717 .58011 .24998 .5844 .24846 .58218 .24565 Mtetra
.58218 .24565 .5844 .24846 .5887 .24694 .58648 .24412 Mtetra
.891 .488 .06 r
.58648 .24412 .5887 .24694 .59334 .2604 .59112 .25759 Mtetra
.663 .743 .91 r
.59112 .25759 .59334 .2604 .59767 .25888 .59546 .25606 Mtetra
.59546 .25606 .59767 .25888 .60202 .25735 .5998 .25453 Mtetra
.5998 .25453 .60202 .25735 .60636 .25582 .60416 .25299 Mtetra
.60416 .25299 .60636 .25582 .61072 .25429 .60852 .25146 Mtetra
.60852 .25146 .61072 .25429 .61508 .25276 .61288 .24992 Mtetra
.61288 .24992 .61508 .25276 .61945 .25122 .61726 .24838 Mtetra
.61726 .24838 .61945 .25122 .62383 .24968 .62164 .24684 Mtetra
.62164 .24684 .62383 .24968 .62821 .24814 .62602 .24529 Mtetra
.62602 .24529 .62821 .24814 .6326 .2466 .63042 .24375 Mtetra
.63042 .24375 .6326 .2466 .63699 .24506 .63482 .2422 Mtetra
.63482 .2422 .63699 .24506 .6414 .24351 .63923 .24064 Mtetra
.63923 .24064 .6414 .24351 .64581 .24196 .64364 .23909 Mtetra
.64364 .23909 .64581 .24196 .65023 .2404 .64806 .23753 Mtetra
.64806 .23753 .65023 .2404 .65465 .23885 .65249 .23597 Mtetra
.65249 .23597 .65465 .23885 .65908 .23729 .65693 .23441 Mtetra
.65693 .23441 .65908 .23729 .66352 .23573 .66137 .23285 Mtetra
.66137 .23285 .66352 .23573 .66796 .23417 .66582 .23128 Mtetra
.66582 .23128 .66796 .23417 .67241 .2326 .67028 .22971 Mtetra
.67028 .22971 .67241 .2326 .67713 .23609 .67474 .22814 Mtetra
.974 .665 .313 r
.67474 .22814 .67713 .23609 .68894 .37767 .68672 .37486 Mtetra
.651 .757 .927 r
.68672 .37486 .68894 .37767 .69363 .37615 .69142 .37333 Mtetra
.69142 .37333 .69363 .37615 .69834 .37462 .69613 .37179 Mtetra
.69613 .37179 .69834 .37462 .70305 .37309 .70085 .37026 Mtetra
.70085 .37026 .70305 .37309 .70777 .37156 .70557 .36872 Mtetra
.70557 .36872 .70777 .37156 .7125 .37002 .71031 .36718 Mtetra
.71031 .36718 .7125 .37002 .71724 .36848 .71505 .36563 Mtetra
.71505 .36563 .71724 .36848 .72198 .36694 .7198 .36409 Mtetra
.7198 .36409 .72198 .36694 .72673 .3654 .72455 .36254 Mtetra
.72455 .36254 .72673 .3654 .73149 .36385 .72932 .36099 Mtetra
.72932 .36099 .73149 .36385 .73626 .3623 .73409 .35944 Mtetra
.73409 .35944 .73626 .3623 .74103 .36075 .73887 .35788 Mtetra
.73887 .35788 .74103 .36075 .74582 .3592 .74366 .35632 Mtetra
.74366 .35632 .74582 .3592 .75061 .35764 .74846 .35476 Mtetra
.74846 .35476 .75061 .35764 .75541 .35608 .75326 .35319 Mtetra
.75326 .35319 .75541 .35608 .76022 .35452 .75808 .35163 Mtetra
.75808 .35163 .76022 .35452 .76503 .35295 .7629 .35006 Mtetra
.7629 .35006 .76503 .35295 .76986 .35139 .76773 .34849 Mtetra
.76773 .34849 .76986 .35139 .77469 .34982 .77257 .34691 Mtetra
.77257 .34691 .77469 .34982 .77953 .34824 .77741 .34533 Mtetra
.77741 .34533 .77953 .34824 .78438 .34667 .78227 .34375 Mtetra
.78227 .34375 .78438 .34667 .78923 .34509 .78713 .34217 Mtetra
.78713 .34217 .78923 .34509 .7941 .34351 .792 .34059 Mtetra
.792 .34059 .7941 .34351 .79897 .34193 .79688 .339 Mtetra
.79688 .339 .79897 .34193 .80385 .34034 .80177 .33741 Mtetra
.80177 .33741 .80385 .34034 .80874 .33875 .80666 .33581 Mtetra
.80666 .33581 .80874 .33875 .81364 .33716 .81156 .33422 Mtetra
.653 .755 .925 r
.15747 .52861 .16021 .53095 .16406 .52968 .16133 .52735 Mtetra
.16133 .52735 .16406 .52968 .16792 .52842 .16518 .52608 Mtetra
.16518 .52608 .16792 .52842 .17178 .52715 .16905 .52481 Mtetra
.16905 .52481 .17178 .52715 .17564 .52588 .17292 .52353 Mtetra
.17292 .52353 .17564 .52588 .17951 .52461 .17679 .52226 Mtetra
.17679 .52226 .17951 .52461 .18339 .52334 .18067 .52098 Mtetra
.18067 .52098 .18339 .52334 .18727 .52206 .18456 .5197 Mtetra
.18456 .5197 .18727 .52206 .19116 .52078 .18845 .51842 Mtetra
.18845 .51842 .19116 .52078 .19506 .5195 .19235 .51714 Mtetra
.19235 .51714 .19506 .5195 .19896 .51822 .19625 .51585 Mtetra
.19625 .51585 .19896 .51822 .20287 .51694 .20016 .51456 Mtetra
.20016 .51456 .20287 .51694 .20678 .51565 .20408 .51328 Mtetra
.20408 .51328 .20678 .51565 .2107 .51437 .208 .51198 Mtetra
.208 .51198 .2107 .51437 .21413 .51837 .21193 .51069 Mtetra
.173 .227 .678 r
.21193 .51069 .21413 .51837 .21807 .51708 .21537 .5147 Mtetra
.652 .755 .925 r
.21537 .5147 .21807 .51708 .22201 .51579 .21932 .5134 Mtetra
.21932 .5134 .22201 .51579 .22596 .5145 .22327 .5121 Mtetra
.22327 .5121 .22596 .5145 .22991 .5132 .22723 .51081 Mtetra
.22723 .51081 .22991 .5132 .23387 .5119 .23119 .5095 Mtetra
.23119 .5095 .23387 .5119 .23784 .51061 .23516 .5082 Mtetra
.23516 .5082 .23784 .51061 .24181 .5093 .23914 .5069 Mtetra
.23914 .5069 .24181 .5093 .24579 .508 .24312 .50559 Mtetra
.24312 .50559 .24579 .508 .24977 .5067 .24711 .50428 Mtetra
.24711 .50428 .24977 .5067 .25376 .50539 .2511 .50297 Mtetra
.2511 .50297 .25376 .50539 .25776 .50408 .2551 .50166 Mtetra
.2551 .50166 .25776 .50408 .26176 .50277 .25911 .50034 Mtetra
.25911 .50034 .26176 .50277 .26577 .50146 .26312 .49903 Mtetra
.26312 .49903 .26577 .50146 .26979 .50014 .26714 .49771 Mtetra
.26714 .49771 .26979 .50014 .27381 .49883 .27117 .49639 Mtetra
.27117 .49639 .27381 .49883 .27784 .49751 .2752 .49507 Mtetra
.947 .694 .52 r
.2752 .49507 .27784 .49751 .29269 .34838 .29019 .34584 Mtetra
.664 .741 .908 r
.29019 .34584 .29269 .34838 .29656 .34701 .29406 .34447 Mtetra
.29406 .34447 .29656 .34701 .30043 .34563 .29794 .34309 Mtetra
.29794 .34309 .30043 .34563 .30431 .34426 .30182 .34171 Mtetra
.30182 .34171 .30431 .34426 .3082 .34288 .30571 .34033 Mtetra
.30571 .34033 .3082 .34288 .31209 .3415 .3096 .33894 Mtetra
.3096 .33894 .31209 .3415 .31598 .34011 .3135 .33756 Mtetra
.3135 .33756 .31598 .34011 .31989 .33873 .31741 .33617 Mtetra
.31741 .33617 .31989 .33873 .32379 .33734 .32132 .33478 Mtetra
.32132 .33478 .32379 .33734 .32771 .33595 .32524 .33338 Mtetra
.32524 .33338 .32771 .33595 .33163 .33456 .32916 .33199 Mtetra
.32916 .33199 .33163 .33456 .33555 .33317 .33309 .33059 Mtetra
.33309 .33059 .33555 .33317 .33948 .33178 .33702 .32919 Mtetra
.33702 .32919 .33948 .33178 .34342 .33038 .34096 .32779 Mtetra
.34096 .32779 .34342 .33038 .34736 .32898 .34491 .32639 Mtetra
.34491 .32639 .34736 .32898 .35131 .32758 .34886 .32499 Mtetra
.34886 .32499 .35131 .32758 .35527 .32617 .35282 .32358 Mtetra
.35282 .32358 .35527 .32617 .35923 .32477 .35678 .32217 Mtetra
.35678 .32217 .35923 .32477 .36319 .32336 .36075 .32076 Mtetra
.36075 .32076 .36319 .32336 .36716 .32195 .36473 .31934 Mtetra
.36473 .31934 .36716 .32195 .37114 .32054 .36871 .31793 Mtetra
.36871 .31793 .37114 .32054 .37513 .31913 .3727 .31651 Mtetra
.3727 .31651 .37513 .31913 .37911 .31771 .37669 .31509 Mtetra
.37669 .31509 .37911 .31771 .38311 .31629 .38069 .31367 Mtetra
.38069 .31367 .38311 .31629 .38711 .31487 .38469 .31225 Mtetra
.38469 .31225 .38711 .31487 .39112 .31345 .38871 .31082 Mtetra
.38871 .31082 .39112 .31345 .39513 .31203 .39272 .30939 Mtetra
.39272 .30939 .39513 .31203 .39915 .3106 .39675 .30796 Mtetra
.39675 .30796 .39915 .3106 .40318 .30917 .40078 .30653 Mtetra
.40078 .30653 .40318 .30917 .40721 .30774 .40481 .30509 Mtetra
.40481 .30509 .40721 .30774 .41125 .30631 .40885 .30366 Mtetra
.40885 .30366 .41125 .30631 .41529 .30487 .4129 .30222 Mtetra
.4129 .30222 .41529 .30487 .41934 .30344 .41695 .30078 Mtetra
.41695 .30078 .41934 .30344 .4234 .302 .42101 .29933 Mtetra
.42101 .29933 .4234 .302 .42746 .30055 .42508 .29789 Mtetra
.42508 .29789 .42746 .30055 .43153 .29911 .42915 .29644 Mtetra
.42915 .29644 .43153 .29911 .4356 .29767 .43323 .29499 Mtetra
.43323 .29499 .4356 .29767 .43968 .29622 .43731 .29354 Mtetra
.43731 .29354 .43968 .29622 .44377 .29477 .44141 .29208 Mtetra
.44141 .29208 .44377 .29477 .44786 .29331 .4455 .29063 Mtetra
.4455 .29063 .44786 .29331 .45173 .30175 .4496 .28917 Mtetra
.113 .108 .572 r
.4496 .28917 .45173 .30175 .45585 .30029 .45349 .2976 Mtetra
.663 .742 .909 r
.45349 .2976 .45585 .30029 .45997 .29884 .45762 .29614 Mtetra
.45762 .29614 .45997 .29884 .4641 .29738 .46175 .29468 Mtetra
.46175 .29468 .4641 .29738 .46824 .29592 .46589 .29321 Mtetra
.46589 .29321 .46824 .29592 .47238 .29445 .47004 .29175 Mtetra
.47004 .29175 .47238 .29445 .47653 .29299 .47419 .29028 Mtetra
.47419 .29028 .47653 .29299 .48069 .29152 .47835 .28881 Mtetra
.47835 .28881 .48069 .29152 .48485 .29005 .48252 .28733 Mtetra
.48252 .28733 .48485 .29005 .48902 .28858 .48669 .28586 Mtetra
.48669 .28586 .48902 .28858 .49319 .28711 .49087 .28438 Mtetra
.49087 .28438 .49319 .28711 .49738 .28563 .49506 .2829 Mtetra
.49506 .2829 .49738 .28563 .50156 .28415 .49925 .28142 Mtetra
.49925 .28142 .50156 .28415 .50576 .28267 .50345 .27993 Mtetra
.50345 .27993 .50576 .28267 .50996 .28119 .50765 .27844 Mtetra
.50765 .27844 .50996 .28119 .51417 .2797 .51186 .27695 Mtetra
.51186 .27695 .51417 .2797 .51838 .27821 .51608 .27546 Mtetra
.51608 .27546 .51838 .27821 .5226 .27673 .5203 .27397 Mtetra
.5203 .27397 .5226 .27673 .52682 .27523 .52453 .27247 Mtetra
.932 .765 .652 r
.52453 .27247 .52682 .27523 .53104 .2638 .52876 .26103 Mtetra
.664 .741 .908 r
.52876 .26103 .53104 .2638 .53526 .2623 .53299 .25952 Mtetra
.53299 .25952 .53526 .2623 .5395 .2608 .53723 .25802 Mtetra
.53723 .25802 .5395 .2608 .54373 .25929 .54147 .25651 Mtetra
.54147 .25651 .54373 .25929 .54798 .25779 .54572 .255 Mtetra
.54572 .255 .54798 .25779 .55223 .25628 .54997 .25348 Mtetra
.54997 .25348 .55223 .25628 .55649 .25477 .55424 .25197 Mtetra
.55424 .25197 .55649 .25477 .56076 .25325 .55851 .25045 Mtetra
.55851 .25045 .56076 .25325 .56503 .25174 .56278 .24893 Mtetra
.56278 .24893 .56503 .25174 .5693 .25022 .56706 .24741 Mtetra
.56706 .24741 .5693 .25022 .57359 .2487 .57135 .24588 Mtetra
.57135 .24588 .57359 .2487 .57788 .24717 .57565 .24436 Mtetra
.57565 .24436 .57788 .24717 .58218 .24565 .57995 .24283 Mtetra
.57995 .24283 .58218 .24565 .58648 .24412 .58426 .2413 Mtetra
.891 .488 .06 r
.58426 .2413 .58648 .24412 .59112 .25759 .58889 .25476 Mtetra
.663 .743 .91 r
.58889 .25476 .59112 .25759 .59546 .25606 .59323 .25323 Mtetra
.59323 .25323 .59546 .25606 .5998 .25453 .59758 .2517 Mtetra
.59758 .2517 .5998 .25453 .60416 .25299 .60194 .25016 Mtetra
.60194 .25016 .60416 .25299 .60852 .25146 .60631 .24862 Mtetra
.60631 .24862 .60852 .25146 .61288 .24992 .61068 .24708 Mtetra
.61068 .24708 .61288 .24992 .61726 .24838 .61505 .24553 Mtetra
.61505 .24553 .61726 .24838 .62164 .24684 .61944 .24398 Mtetra
.61944 .24398 .62164 .24684 .62602 .24529 .62383 .24243 Mtetra
.62383 .24243 .62602 .24529 .63042 .24375 .62823 .24088 Mtetra
.62823 .24088 .63042 .24375 .63482 .2422 .63264 .23933 Mtetra
.63264 .23933 .63482 .2422 .63923 .24064 .63705 .23777 Mtetra
.63705 .23777 .63923 .24064 .64364 .23909 .64147 .23621 Mtetra
.64147 .23621 .64364 .23909 .64806 .23753 .64589 .23465 Mtetra
.64589 .23465 .64806 .23753 .65249 .23597 .65033 .23309 Mtetra
.65033 .23309 .65249 .23597 .65693 .23441 .65477 .23152 Mtetra
.65477 .23152 .65693 .23441 .66137 .23285 .65922 .22995 Mtetra
.65922 .22995 .66137 .23285 .66582 .23128 .66367 .22838 Mtetra
.66367 .22838 .66582 .23128 .67028 .22971 .66813 .22681 Mtetra
.973 .661 .337 r
.66813 .22681 .67028 .22971 .67474 .22814 .67979 .37356 Mtetra
.524 .292 .504 r
.67979 .37356 .67474 .22814 .68672 .37486 .68449 .37203 Mtetra
.651 .757 .927 r
.68449 .37203 .68672 .37486 .69142 .37333 .6892 .37049 Mtetra
.6892 .37049 .69142 .37333 .69613 .37179 .69391 .36896 Mtetra
.69391 .36896 .69613 .37179 .70085 .37026 .69863 .36742 Mtetra
.69863 .36742 .70085 .37026 .70557 .36872 .70337 .36587 Mtetra
.70337 .36587 .70557 .36872 .71031 .36718 .7081 .36433 Mtetra
.7081 .36433 .71031 .36718 .71505 .36563 .71285 .36278 Mtetra
.71285 .36278 .71505 .36563 .7198 .36409 .71761 .36123 Mtetra
.71761 .36123 .7198 .36409 .72455 .36254 .72237 .35967 Mtetra
.72237 .35967 .72455 .36254 .72932 .36099 .72714 .35812 Mtetra
.72714 .35812 .72932 .36099 .73409 .35944 .73192 .35656 Mtetra
.73192 .35656 .73409 .35944 .73887 .35788 .73671 .355 Mtetra
.73671 .355 .73887 .35788 .74366 .35632 .7415 .35344 Mtetra
.7415 .35344 .74366 .35632 .74846 .35476 .7463 .35187 Mtetra
.7463 .35187 .74846 .35476 .75326 .35319 .75111 .3503 Mtetra
.75111 .3503 .75326 .35319 .75808 .35163 .75593 .34873 Mtetra
.75593 .34873 .75808 .35163 .7629 .35006 .76076 .34715 Mtetra
.76076 .34715 .7629 .35006 .76773 .34849 .7656 .34558 Mtetra
.7656 .34558 .76773 .34849 .77257 .34691 .77044 .344 Mtetra
.77044 .344 .77257 .34691 .77741 .34533 .77529 .34242 Mtetra
.77529 .34242 .77741 .34533 .78227 .34375 .78015 .34083 Mtetra
.78015 .34083 .78227 .34375 .78713 .34217 .78502 .33924 Mtetra
.78502 .33924 .78713 .34217 .792 .34059 .78989 .33765 Mtetra
.78989 .33765 .792 .34059 .79688 .339 .79478 .33606 Mtetra
.79478 .33606 .79688 .339 .80177 .33741 .79967 .33446 Mtetra
.79967 .33446 .80177 .33741 .80666 .33581 .80457 .33287 Mtetra
.80457 .33287 .80666 .33581 .81156 .33422 .80948 .33126 Mtetra
.653 .755 .925 r
.15473 .52627 .15747 .52861 .16133 .52735 .15858 .525 Mtetra
.15858 .525 .16133 .52735 .16518 .52608 .16244 .52373 Mtetra
.16244 .52373 .16518 .52608 .16905 .52481 .16631 .52245 Mtetra
.16631 .52245 .16905 .52481 .17292 .52353 .17018 .52118 Mtetra
.17018 .52118 .17292 .52353 .17679 .52226 .17406 .5199 Mtetra
.17406 .5199 .17679 .52226 .18067 .52098 .17795 .51862 Mtetra
.17795 .51862 .18067 .52098 .18456 .5197 .18184 .51733 Mtetra
.18184 .51733 .18456 .5197 .18845 .51842 .18573 .51605 Mtetra
.18573 .51605 .18845 .51842 .19235 .51714 .18963 .51476 Mtetra
.18963 .51476 .19235 .51714 .19625 .51585 .19354 .51347 Mtetra
.19354 .51347 .19625 .51585 .20016 .51456 .19745 .51218 Mtetra
.19745 .51218 .20016 .51456 .20408 .51328 .20137 .51089 Mtetra
.20137 .51089 .20408 .51328 .208 .51198 .2053 .5096 Mtetra
.2053 .5096 .208 .51198 .21193 .51069 .20923 .5083 Mtetra
.646 .131 0 r
.20923 .5083 .21193 .51069 .21537 .5147 .21267 .5123 Mtetra
.652 .755 .925 r
.21267 .5123 .21537 .5147 .21932 .5134 .21662 .51101 Mtetra
.21662 .51101 .21932 .5134 .22327 .5121 .22058 .50971 Mtetra
.22058 .50971 .22327 .5121 .22723 .51081 .22454 .5084 Mtetra
.22454 .5084 .22723 .51081 .23119 .5095 .2285 .5071 Mtetra
.2285 .5071 .23119 .5095 .23516 .5082 .23248 .50579 Mtetra
.23248 .50579 .23516 .5082 .23914 .5069 .23646 .50448 Mtetra
.23646 .50448 .23914 .5069 .24312 .50559 .24044 .50317 Mtetra
.24044 .50317 .24312 .50559 .24711 .50428 .24444 .50186 Mtetra
.24444 .50186 .24711 .50428 .2511 .50297 .24843 .50055 Mtetra
.24843 .50055 .2511 .50297 .2551 .50166 .25244 .49923 Mtetra
.25244 .49923 .2551 .50166 .25911 .50034 .25645 .49791 Mtetra
.25645 .49791 .25911 .50034 .26312 .49903 .26046 .49659 Mtetra
.26046 .49659 .26312 .49903 .26714 .49771 .26449 .49527 Mtetra
.26449 .49527 .26714 .49771 .27117 .49639 .26851 .49395 Mtetra
.26851 .49395 .27117 .49639 .2752 .49507 .27255 .49262 Mtetra
.946 .698 .529 r
.27255 .49262 .2752 .49507 .29019 .34584 .28359 .39785 Mtetra
0 0 .094 r
.28359 .39785 .29019 .34584 .29406 .34447 .29155 .34192 Mtetra
.664 .741 .908 r
.29155 .34192 .29406 .34447 .29794 .34309 .29543 .34054 Mtetra
.29543 .34054 .29794 .34309 .30182 .34171 .29932 .33916 Mtetra
.29932 .33916 .30182 .34171 .30571 .34033 .30321 .33777 Mtetra
.30321 .33777 .30571 .34033 .3096 .33894 .30711 .33638 Mtetra
.30711 .33638 .3096 .33894 .3135 .33756 .31101 .33499 Mtetra
.31101 .33499 .3135 .33756 .31741 .33617 .31492 .3336 Mtetra
.31492 .3336 .31741 .33617 .32132 .33478 .31884 .3322 Mtetra
.31884 .3322 .32132 .33478 .32524 .33338 .32276 .33081 Mtetra
.32276 .33081 .32524 .33338 .32916 .33199 .32668 .32941 Mtetra
.32668 .32941 .32916 .33199 .33309 .33059 .33061 .32801 Mtetra
.33061 .32801 .33309 .33059 .33702 .32919 .33455 .32661 Mtetra
.33455 .32661 .33702 .32919 .34096 .32779 .3385 .3252 Mtetra
.3385 .3252 .34096 .32779 .34491 .32639 .34245 .3238 Mtetra
.34245 .3238 .34491 .32639 .34886 .32499 .3464 .32239 Mtetra
.3464 .32239 .34886 .32499 .35282 .32358 .35036 .32098 Mtetra
.35036 .32098 .35282 .32358 .35678 .32217 .35433 .31956 Mtetra
.35433 .31956 .35678 .32217 .36075 .32076 .3583 .31815 Mtetra
.3583 .31815 .36075 .32076 .36473 .31934 .36228 .31673 Mtetra
.36228 .31673 .36473 .31934 .36871 .31793 .36627 .31531 Mtetra
.36627 .31531 .36871 .31793 .3727 .31651 .37026 .31389 Mtetra
.37026 .31389 .3727 .31651 .37669 .31509 .37426 .31247 Mtetra
.37426 .31247 .37669 .31509 .38069 .31367 .37826 .31104 Mtetra
.37826 .31104 .38069 .31367 .38469 .31225 .38227 .30961 Mtetra
.38227 .30961 .38469 .31225 .38871 .31082 .38628 .30818 Mtetra
.38628 .30818 .38871 .31082 .39272 .30939 .39031 .30675 Mtetra
.39031 .30675 .39272 .30939 .39675 .30796 .39433 .30531 Mtetra
.39433 .30531 .39675 .30796 .40078 .30653 .39837 .30388 Mtetra
.39837 .30388 .40078 .30653 .40481 .30509 .40241 .30244 Mtetra
.40241 .30244 .40481 .30509 .40885 .30366 .40645 .301 Mtetra
.40645 .301 .40885 .30366 .4129 .30222 .4105 .29956 Mtetra
.4105 .29956 .4129 .30222 .41695 .30078 .41456 .29811 Mtetra
.41456 .29811 .41695 .30078 .42101 .29933 .41862 .29666 Mtetra
.41862 .29666 .42101 .29933 .42508 .29789 .42269 .29521 Mtetra
.42269 .29521 .42508 .29789 .42915 .29644 .42677 .29376 Mtetra
.42677 .29376 .42915 .29644 .43323 .29499 .43085 .29231 Mtetra
.43085 .29231 .43323 .29499 .43731 .29354 .43494 .29085 Mtetra
.43494 .29085 .43731 .29354 .44141 .29208 .43903 .28939 Mtetra
.43903 .28939 .44141 .29208 .4455 .29063 .44313 .28793 Mtetra
.44313 .28793 .4455 .29063 .4496 .28917 .44724 .28647 Mtetra
.843 .405 0 r
.44724 .28647 .4496 .28917 .45349 .2976 .45112 .2949 Mtetra
.663 .742 .909 r
.45112 .2949 .45349 .2976 .45762 .29614 .45525 .29344 Mtetra
.45525 .29344 .45762 .29614 .46175 .29468 .45939 .29197 Mtetra
.45939 .29197 .46175 .29468 .46589 .29321 .46354 .2905 Mtetra
.46354 .2905 .46589 .29321 .47004 .29175 .46769 .28903 Mtetra
.46769 .28903 .47004 .29175 .47419 .29028 .47185 .28756 Mtetra
.47185 .28756 .47419 .29028 .47835 .28881 .47601 .28608 Mtetra
.47601 .28608 .47835 .28881 .48252 .28733 .48018 .28461 Mtetra
.48018 .28461 .48252 .28733 .48669 .28586 .48436 .28313 Mtetra
.48436 .28313 .48669 .28586 .49087 .28438 .48854 .28164 Mtetra
.48854 .28164 .49087 .28438 .49506 .2829 .49273 .28016 Mtetra
.49273 .28016 .49506 .2829 .49925 .28142 .49692 .27867 Mtetra
.49692 .27867 .49925 .28142 .50345 .27993 .50113 .27718 Mtetra
.50113 .27718 .50345 .27993 .50765 .27844 .50534 .27569 Mtetra
.50534 .27569 .50765 .27844 .51186 .27695 .50955 .2742 Mtetra
.50955 .2742 .51186 .27695 .51608 .27546 .51377 .2727 Mtetra
.51377 .2727 .51608 .27546 .5203 .27397 .518 .2712 Mtetra
.518 .2712 .5203 .27397 .52453 .27247 .52224 .2697 Mtetra
.932 .765 .652 r
.52224 .2697 .52453 .27247 .52876 .26103 .52647 .25825 Mtetra
.664 .741 .908 r
.52647 .25825 .52876 .26103 .53299 .25952 .53071 .25674 Mtetra
.53071 .25674 .53299 .25952 .53723 .25802 .53495 .25523 Mtetra
.53495 .25523 .53723 .25802 .54147 .25651 .5392 .25372 Mtetra
.5392 .25372 .54147 .25651 .54572 .255 .54345 .2522 Mtetra
.54345 .2522 .54572 .255 .54997 .25348 .54771 .25069 Mtetra
.54771 .25069 .54997 .25348 .55424 .25197 .55198 .24917 Mtetra
.55198 .24917 .55424 .25197 .55851 .25045 .55625 .24764 Mtetra
.55625 .24764 .55851 .25045 .56278 .24893 .56053 .24612 Mtetra
.56053 .24612 .56278 .24893 .56706 .24741 .56482 .24459 Mtetra
.56482 .24459 .56706 .24741 .57135 .24588 .56911 .24306 Mtetra
.56911 .24306 .57135 .24588 .57565 .24436 .57341 .24153 Mtetra
.57341 .24153 .57565 .24436 .57995 .24283 .57772 .24 Mtetra
.57772 .24 .57995 .24283 .58426 .2413 .58203 .23846 Mtetra
.891 .488 .06 r
.58203 .23846 .58426 .2413 .58889 .25476 .58665 .25193 Mtetra
.663 .743 .91 r
.58665 .25193 .58889 .25476 .59323 .25323 .591 .25039 Mtetra
.591 .25039 .59323 .25323 .59758 .2517 .59536 .24885 Mtetra
.59536 .24885 .59758 .2517 .60194 .25016 .59972 .24731 Mtetra
.59972 .24731 .60194 .25016 .60631 .24862 .60409 .24577 Mtetra
.60409 .24577 .60631 .24862 .61068 .24708 .60846 .24422 Mtetra
.60846 .24422 .61068 .24708 .61505 .24553 .61285 .24267 Mtetra
.61285 .24267 .61505 .24553 .61944 .24398 .61724 .24112 Mtetra
.61724 .24112 .61944 .24398 .62383 .24243 .62163 .23957 Mtetra
.62163 .23957 .62383 .24243 .62823 .24088 .62604 .23801 Mtetra
.62604 .23801 .62823 .24088 .63264 .23933 .63045 .23645 Mtetra
.63045 .23645 .63264 .23933 .63705 .23777 .63486 .23489 Mtetra
.63486 .23489 .63705 .23777 .64147 .23621 .63929 .23333 Mtetra
.63929 .23333 .64147 .23621 .64589 .23465 .64372 .23176 Mtetra
.64372 .23176 .64589 .23465 .65033 .23309 .64816 .23019 Mtetra
.64816 .23019 .65033 .23309 .65477 .23152 .6526 .22862 Mtetra
.6526 .22862 .65477 .23152 .65922 .22995 .65705 .22705 Mtetra
.65705 .22705 .65922 .22995 .66367 .22838 .66151 .22547 Mtetra
.66151 .22547 .66367 .22838 .66813 .22681 .66598 .22389 Mtetra
.973 .661 .337 r
.66598 .22389 .66813 .22681 .67979 .37356 .67755 .37073 Mtetra
.651 .757 .927 r
.67755 .37073 .67979 .37356 .68449 .37203 .68225 .36919 Mtetra
.68225 .36919 .68449 .37203 .6892 .37049 .68697 .36765 Mtetra
.68697 .36765 .6892 .37049 .69391 .36896 .69169 .36611 Mtetra
.69169 .36611 .69391 .36896 .69863 .36742 .69642 .36456 Mtetra
.69642 .36456 .69863 .36742 .70337 .36587 .70115 .36302 Mtetra
.70115 .36302 .70337 .36587 .7081 .36433 .7059 .36147 Mtetra
.7059 .36147 .7081 .36433 .71285 .36278 .71065 .35991 Mtetra
.71065 .35991 .71285 .36278 .71761 .36123 .71541 .35836 Mtetra
.71541 .35836 .71761 .36123 .72237 .35967 .72018 .3568 Mtetra
.72018 .3568 .72237 .35967 .72714 .35812 .72495 .35524 Mtetra
.72495 .35524 .72714 .35812 .73192 .35656 .72974 .35368 Mtetra
.72974 .35368 .73192 .35656 .73671 .355 .73453 .35211 Mtetra
.73453 .35211 .73671 .355 .7415 .35344 .73933 .35054 Mtetra
.73933 .35054 .7415 .35344 .7463 .35187 .74414 .34897 Mtetra
.74414 .34897 .7463 .35187 .75111 .3503 .74896 .3474 Mtetra
.74896 .3474 .75111 .3503 .75593 .34873 .75378 .34582 Mtetra
.75378 .34582 .75593 .34873 .76076 .34715 .75861 .34424 Mtetra
.75861 .34424 .76076 .34715 .7656 .34558 .76346 .34266 Mtetra
.76346 .34266 .7656 .34558 .77044 .344 .7683 .34107 Mtetra
.7683 .34107 .77044 .344 .77529 .34242 .77316 .33949 Mtetra
.77316 .33949 .77529 .34242 .78015 .34083 .77803 .3379 Mtetra
.77803 .3379 .78015 .34083 .78502 .33924 .7829 .3363 Mtetra
.7829 .3363 .78502 .33924 .78989 .33765 .78778 .33471 Mtetra
.78778 .33471 .78989 .33765 .79478 .33606 .79267 .33311 Mtetra
.79267 .33311 .79478 .33606 .79967 .33446 .79757 .33151 Mtetra
.79757 .33151 .79967 .33446 .80457 .33287 .80248 .32991 Mtetra
.80248 .32991 .80457 .33287 .80948 .33126 .8074 .3283 Mtetra
.653 .755 .925 r
.15197 .52392 .15473 .52627 .15858 .525 .15583 .52265 Mtetra
.15583 .52265 .15858 .525 .16244 .52373 .1597 .52137 Mtetra
.1597 .52137 .16244 .52373 .16631 .52245 .16357 .52009 Mtetra
.16357 .52009 .16631 .52245 .17018 .52118 .16744 .51881 Mtetra
.16744 .51881 .17018 .52118 .17406 .5199 .17132 .51753 Mtetra
.17132 .51753 .17406 .5199 .17795 .51862 .17521 .51625 Mtetra
.17521 .51625 .17795 .51862 .18184 .51733 .1791 .51496 Mtetra
.1791 .51496 .18184 .51733 .18573 .51605 .183 .51367 Mtetra
.183 .51367 .18573 .51605 .18963 .51476 .18691 .51238 Mtetra
.18691 .51238 .18963 .51476 .19354 .51347 .19082 .51109 Mtetra
.19082 .51109 .19354 .51347 .19745 .51218 .19474 .5098 Mtetra
.19474 .5098 .19745 .51218 .20137 .51089 .19866 .5085 Mtetra
.19866 .5085 .20137 .51089 .2053 .5096 .20259 .5072 Mtetra
.20259 .5072 .2053 .5096 .20923 .5083 .20652 .5059 Mtetra
.646 .131 0 r
.20652 .5059 .20923 .5083 .21267 .5123 .20996 .50991 Mtetra
.652 .755 .925 r
.20996 .50991 .21267 .5123 .21662 .51101 .21392 .5086 Mtetra
.21392 .5086 .21662 .51101 .22058 .50971 .21787 .5073 Mtetra
.21787 .5073 .22058 .50971 .22454 .5084 .22184 .50599 Mtetra
.22184 .50599 .22454 .5084 .2285 .5071 .22581 .50469 Mtetra
.22581 .50469 .2285 .5071 .23248 .50579 .22979 .50338 Mtetra
.22979 .50338 .23248 .50579 .23646 .50448 .23377 .50206 Mtetra
.23377 .50206 .23646 .50448 .24044 .50317 .23776 .50075 Mtetra
.23776 .50075 .24044 .50317 .24444 .50186 .24175 .49943 Mtetra
.24175 .49943 .24444 .50186 .24843 .50055 .24576 .49812 Mtetra
.24576 .49812 .24843 .50055 .25244 .49923 .24976 .4968 Mtetra
.24976 .4968 .25244 .49923 .25645 .49791 .25378 .49547 Mtetra
.25378 .49547 .25645 .49791 .26046 .49659 .2578 .49415 Mtetra
.2578 .49415 .26046 .49659 .26449 .49527 .26182 .49282 Mtetra
.26182 .49282 .26449 .49527 .26851 .49395 .26586 .4915 Mtetra
.946 .697 .53 r
.26586 .4915 .26851 .49395 .27255 .49262 .27709 .3967 Mtetra
.538 .322 .534 r
.27709 .3967 .27255 .49262 .28359 .39785 .28102 .39534 Mtetra
.66 .746 .914 r
.28102 .39534 .28359 .39785 .29155 .34192 .28497 .39397 Mtetra
.513 .268 .481 r
.28497 .39397 .29155 .34192 .29543 .34054 .28891 .3926 Mtetra
.28891 .3926 .29543 .34054 .29932 .33916 .29287 .39123 Mtetra
.29287 .39123 .29932 .33916 .30321 .33777 .29683 .38986 Mtetra
.29683 .38986 .30321 .33777 .30711 .33638 .30079 .38848 Mtetra
.30079 .38848 .30711 .33638 .31101 .33499 .30476 .3871 Mtetra
0 0 .109 r
.30476 .3871 .31101 .33499 .31492 .3336 .31243 .33102 Mtetra
.664 .741 .908 r
.31243 .33102 .31492 .3336 .31884 .3322 .31635 .32963 Mtetra
.31635 .32963 .31884 .3322 .32276 .33081 .32027 .32823 Mtetra
.32027 .32823 .32276 .33081 .32668 .32941 .3242 .32682 Mtetra
.3242 .32682 .32668 .32941 .33061 .32801 .32814 .32542 Mtetra
.32814 .32542 .33061 .32801 .33455 .32661 .33208 .32401 Mtetra
.33208 .32401 .33455 .32661 .3385 .3252 .33602 .3226 Mtetra
.33602 .3226 .3385 .3252 .34245 .3238 .33998 .32119 Mtetra
.33998 .32119 .34245 .3238 .3464 .32239 .34394 .31978 Mtetra
.34394 .31978 .3464 .32239 .35036 .32098 .3479 .31836 Mtetra
.3479 .31836 .35036 .32098 .35433 .31956 .35187 .31695 Mtetra
.35187 .31695 .35433 .31956 .3583 .31815 .35585 .31553 Mtetra
.35585 .31553 .3583 .31815 .36228 .31673 .35983 .31411 Mtetra
.35983 .31411 .36228 .31673 .36627 .31531 .36382 .31268 Mtetra
.36382 .31268 .36627 .31531 .37026 .31389 .36782 .31126 Mtetra
.36782 .31126 .37026 .31389 .37426 .31247 .37182 .30983 Mtetra
.37182 .30983 .37426 .31247 .37826 .31104 .37582 .3084 Mtetra
.37582 .3084 .37826 .31104 .38227 .30961 .37984 .30697 Mtetra
.37984 .30697 .38227 .30961 .38628 .30818 .38386 .30554 Mtetra
.38386 .30554 .38628 .30818 .39031 .30675 .38788 .3041 Mtetra
.38788 .3041 .39031 .30675 .39433 .30531 .39191 .30266 Mtetra
.39191 .30266 .39433 .30531 .39837 .30388 .39595 .30122 Mtetra
.39595 .30122 .39837 .30388 .40241 .30244 .39999 .29978 Mtetra
.39999 .29978 .40241 .30244 .40645 .301 .40404 .29833 Mtetra
.40404 .29833 .40645 .301 .4105 .29956 .4081 .29689 Mtetra
.4081 .29689 .4105 .29956 .41456 .29811 .41216 .29544 Mtetra
.41216 .29544 .41456 .29811 .41862 .29666 .41623 .29399 Mtetra
.41623 .29399 .41862 .29666 .42269 .29521 .4203 .29253 Mtetra
.4203 .29253 .42269 .29521 .42677 .29376 .42438 .29108 Mtetra
.42438 .29108 .42677 .29376 .43085 .29231 .42847 .28962 Mtetra
.42847 .28962 .43085 .29231 .43494 .29085 .43256 .28816 Mtetra
.43256 .28816 .43494 .29085 .43903 .28939 .43666 .28669 Mtetra
.43666 .28669 .43903 .28939 .44313 .28793 .44076 .28523 Mtetra
.44076 .28523 .44313 .28793 .44724 .28647 .44487 .28376 Mtetra
.843 .405 0 r
.44487 .28376 .44724 .28647 .45112 .2949 .44875 .2922 Mtetra
.663 .742 .909 r
.44875 .2922 .45112 .2949 .45525 .29344 .45288 .29073 Mtetra
.45288 .29073 .45525 .29344 .45939 .29197 .45703 .28926 Mtetra
.45703 .28926 .45939 .29197 .46354 .2905 .46117 .28779 Mtetra
.46117 .28779 .46354 .2905 .46769 .28903 .46533 .28631 Mtetra
.46533 .28631 .46769 .28903 .47185 .28756 .46949 .28483 Mtetra
.46949 .28483 .47185 .28756 .47601 .28608 .47366 .28335 Mtetra
.47366 .28335 .47601 .28608 .48018 .28461 .47783 .28187 Mtetra
.47783 .28187 .48018 .28461 .48436 .28313 .48201 .28039 Mtetra
.48201 .28039 .48436 .28313 .48854 .28164 .4862 .2789 Mtetra
.4862 .2789 .48854 .28164 .49273 .28016 .4904 .27741 Mtetra
.4904 .27741 .49273 .28016 .49692 .27867 .4946 .27592 Mtetra
.4946 .27592 .49692 .27867 .50113 .27718 .4988 .27443 Mtetra
.4988 .27443 .50113 .27718 .50534 .27569 .50302 .27293 Mtetra
.50302 .27293 .50534 .27569 .50955 .2742 .50724 .27143 Mtetra
.50724 .27143 .50955 .2742 .51377 .2727 .51146 .26993 Mtetra
.51146 .26993 .51377 .2727 .518 .2712 .51569 .26843 Mtetra
.51569 .26843 .518 .2712 .52224 .2697 .51993 .26693 Mtetra
.932 .765 .652 r
.51993 .26693 .52224 .2697 .52647 .25825 .52418 .25546 Mtetra
.664 .741 .908 r
.52418 .25546 .52647 .25825 .53071 .25674 .52842 .25395 Mtetra
.52842 .25395 .53071 .25674 .53495 .25523 .53266 .25244 Mtetra
.53266 .25244 .53495 .25523 .5392 .25372 .53692 .25092 Mtetra
.53692 .25092 .5392 .25372 .54345 .2522 .54117 .2494 Mtetra
.54117 .2494 .54345 .2522 .54771 .25069 .54544 .24788 Mtetra
.54544 .24788 .54771 .25069 .55198 .24917 .54971 .24635 Mtetra
.54971 .24635 .55198 .24917 .55625 .24764 .55399 .24483 Mtetra
.55399 .24483 .55625 .24764 .56053 .24612 .55827 .2433 Mtetra
.55827 .2433 .56053 .24612 .56482 .24459 .56256 .24177 Mtetra
.56256 .24177 .56482 .24459 .56911 .24306 .56686 .24023 Mtetra
.56686 .24023 .56911 .24306 .57341 .24153 .57117 .2387 Mtetra
.57117 .2387 .57341 .24153 .57772 .24 .57548 .23716 Mtetra
.57548 .23716 .57772 .24 .58203 .23846 .5798 .23562 Mtetra
.891 .488 .06 r
.5798 .23562 .58203 .23846 .58665 .25193 .58441 .24909 Mtetra
.663 .743 .91 r
.58441 .24909 .58665 .25193 .591 .25039 .58876 .24755 Mtetra
.58876 .24755 .591 .25039 .59536 .24885 .59312 .24601 Mtetra
.59312 .24601 .59536 .24885 .59972 .24731 .59749 .24446 Mtetra
.59749 .24446 .59972 .24731 .60409 .24577 .60186 .24291 Mtetra
.60186 .24291 .60409 .24577 .60846 .24422 .60625 .24136 Mtetra
.60625 .24136 .60846 .24422 .61285 .24267 .61063 .23981 Mtetra
.61063 .23981 .61285 .24267 .61724 .24112 .61503 .23825 Mtetra
.61503 .23825 .61724 .24112 .62163 .23957 .61943 .23669 Mtetra
.61943 .23669 .62163 .23957 .62604 .23801 .62384 .23513 Mtetra
.62384 .23513 .62604 .23801 .63045 .23645 .62825 .23357 Mtetra
.62825 .23357 .63045 .23645 .63486 .23489 .63267 .232 Mtetra
.63267 .232 .63486 .23489 .63929 .23333 .6371 .23043 Mtetra
.6371 .23043 .63929 .23333 .64372 .23176 .64154 .22886 Mtetra
.64154 .22886 .64372 .23176 .64816 .23019 .64598 .22729 Mtetra
.64598 .22729 .64816 .23019 .6526 .22862 .65043 .22571 Mtetra
.65043 .22571 .6526 .22862 .65705 .22705 .65489 .22414 Mtetra
.65489 .22414 .65705 .22705 .66151 .22547 .65935 .22255 Mtetra
.65935 .22255 .66151 .22547 .66598 .22389 .66382 .22097 Mtetra
.972 .66 .335 r
.66382 .22097 .66598 .22389 .67755 .37073 .67478 .3568 Mtetra
.175 .157 .597 r
.67478 .3568 .67755 .37073 .68225 .36919 .68001 .36635 Mtetra
.651 .757 .927 r
.68001 .36635 .68225 .36919 .68697 .36765 .68473 .3648 Mtetra
.68473 .3648 .68697 .36765 .69169 .36611 .68946 .36326 Mtetra
.68946 .36326 .69169 .36611 .69642 .36456 .69419 .36171 Mtetra
.69419 .36171 .69642 .36456 .70115 .36302 .69893 .36015 Mtetra
.69893 .36015 .70115 .36302 .7059 .36147 .70368 .3586 Mtetra
.70368 .3586 .7059 .36147 .71065 .35991 .70844 .35704 Mtetra
.70844 .35704 .71065 .35991 .71541 .35836 .71321 .35548 Mtetra
.71321 .35548 .71541 .35836 .72018 .3568 .71798 .35392 Mtetra
.71798 .35392 .72018 .3568 .72495 .35524 .72276 .35235 Mtetra
.72276 .35235 .72495 .35524 .72974 .35368 .72755 .35078 Mtetra
.72755 .35078 .72974 .35368 .73453 .35211 .73235 .34921 Mtetra
.73235 .34921 .73453 .35211 .73933 .35054 .73716 .34764 Mtetra
.73716 .34764 .73933 .35054 .74414 .34897 .74197 .34606 Mtetra
.74197 .34606 .74414 .34897 .74896 .3474 .74679 .34448 Mtetra
.74679 .34448 .74896 .3474 .75378 .34582 .75162 .3429 Mtetra
.75162 .3429 .75378 .34582 .75861 .34424 .75646 .34132 Mtetra
.75646 .34132 .75861 .34424 .76346 .34266 .76131 .33973 Mtetra
.76131 .33973 .76346 .34266 .7683 .34107 .76616 .33814 Mtetra
.76616 .33814 .7683 .34107 .77316 .33949 .77103 .33655 Mtetra
.77103 .33655 .77316 .33949 .77803 .3379 .7759 .33496 Mtetra
.7759 .33496 .77803 .3379 .7829 .3363 .78078 .33336 Mtetra
.78078 .33336 .7829 .3363 .78778 .33471 .78567 .33176 Mtetra
.78567 .33176 .78778 .33471 .79267 .33311 .79056 .33015 Mtetra
.79056 .33015 .79267 .33311 .79757 .33151 .79547 .32855 Mtetra
.79547 .32855 .79757 .33151 .80248 .32991 .80038 .32694 Mtetra
.80038 .32694 .80248 .32991 .8074 .3283 .8053 .32533 Mtetra
.653 .755 .925 r
.14921 .52157 .15197 .52392 .15583 .52265 .15307 .52029 Mtetra
.15307 .52029 .15583 .52265 .1597 .52137 .15694 .51901 Mtetra
.15694 .51901 .1597 .52137 .16357 .52009 .16081 .51773 Mtetra
.16081 .51773 .16357 .52009 .16744 .51881 .16469 .51644 Mtetra
.16469 .51644 .16744 .51881 .17132 .51753 .16858 .51516 Mtetra
.16858 .51516 .17132 .51753 .17521 .51625 .17247 .51387 Mtetra
.17247 .51387 .17521 .51625 .1791 .51496 .17637 .51258 Mtetra
.17637 .51258 .1791 .51496 .183 .51367 .18027 .51129 Mtetra
.18027 .51129 .183 .51367 .18691 .51238 .18418 .51 Mtetra
.18418 .51 .18691 .51238 .19082 .51109 .18809 .5087 Mtetra
.18809 .5087 .19082 .51109 .19474 .5098 .19201 .5074 Mtetra
.19201 .5074 .19474 .5098 .19866 .5085 .19594 .5061 Mtetra
.19594 .5061 .19866 .5085 .20259 .5072 .19987 .5048 Mtetra
.19987 .5048 .20259 .5072 .20652 .5059 .20381 .5035 Mtetra
.20381 .5035 .20652 .5059 .20996 .50991 .20775 .50219 Mtetra
.17 .225 .677 r
.20775 .50219 .20996 .50991 .21392 .5086 .2112 .50619 Mtetra
.652 .755 .925 r
.2112 .50619 .21392 .5086 .21787 .5073 .21517 .50489 Mtetra
.21517 .50489 .21787 .5073 .22184 .50599 .21913 .50358 Mtetra
.21913 .50358 .22184 .50599 .22581 .50469 .22311 .50227 Mtetra
.22311 .50227 .22581 .50469 .22979 .50338 .22709 .50095 Mtetra
.22709 .50095 .22979 .50338 .23377 .50206 .23108 .49964 Mtetra
.23108 .49964 .23377 .50206 .23776 .50075 .23507 .49832 Mtetra
.23507 .49832 .23776 .50075 .24175 .49943 .23907 .497 Mtetra
.23907 .497 .24175 .49943 .24576 .49812 .24307 .49568 Mtetra
.24307 .49568 .24576 .49812 .24976 .4968 .24708 .49435 Mtetra
.24708 .49435 .24976 .4968 .25378 .49547 .2511 .49303 Mtetra
.2511 .49303 .25378 .49547 .2578 .49415 .25512 .4917 Mtetra
.25512 .4917 .2578 .49415 .26182 .49282 .25915 .49037 Mtetra
.25915 .49037 .26182 .49282 .26586 .4915 .26319 .48904 Mtetra
.946 .697 .53 r
.26319 .48904 .26586 .4915 .27709 .3967 .27451 .39418 Mtetra
.66 .746 .914 r
.27451 .39418 .27709 .3967 .28102 .39534 .27845 .39281 Mtetra
.27845 .39281 .28102 .39534 .28497 .39397 .2824 .39144 Mtetra
.2824 .39144 .28497 .39397 .28891 .3926 .28635 .39007 Mtetra
.28635 .39007 .28891 .3926 .29287 .39123 .29031 .38869 Mtetra
.29031 .38869 .29287 .39123 .29683 .38986 .29427 .38732 Mtetra
.29427 .38732 .29683 .38986 .30079 .38848 .29824 .38594 Mtetra
.29824 .38594 .30079 .38848 .30476 .3871 .30221 .38456 Mtetra
.30221 .38456 .30476 .3871 .31243 .33102 .30619 .38317 Mtetra
.512 .267 .481 r
.30619 .38317 .31243 .33102 .31635 .32963 .31018 .38179 Mtetra
.31018 .38179 .31635 .32963 .32027 .32823 .31417 .3804 Mtetra
.31417 .3804 .32027 .32823 .3242 .32682 .31817 .37901 Mtetra
.31817 .37901 .3242 .32682 .32814 .32542 .32218 .37762 Mtetra
.32218 .37762 .32814 .32542 .33208 .32401 .32619 .37623 Mtetra
0 0 .124 r
.32619 .37623 .33208 .32401 .33602 .3226 .33355 .32 Mtetra
.664 .741 .908 r
.33355 .32 .33602 .3226 .33998 .32119 .3375 .31858 Mtetra
.3375 .31858 .33998 .32119 .34394 .31978 .34147 .31717 Mtetra
.34147 .31717 .34394 .31978 .3479 .31836 .34543 .31575 Mtetra
.34543 .31575 .3479 .31836 .35187 .31695 .34941 .31433 Mtetra
.34941 .31433 .35187 .31695 .35585 .31553 .35339 .3129 Mtetra
.35339 .3129 .35585 .31553 .35983 .31411 .35738 .31148 Mtetra
.35738 .31148 .35983 .31411 .36382 .31268 .36137 .31005 Mtetra
.36137 .31005 .36382 .31268 .36782 .31126 .36537 .30862 Mtetra
.36537 .30862 .36782 .31126 .37182 .30983 .36937 .30719 Mtetra
.36937 .30719 .37182 .30983 .37582 .3084 .37338 .30576 Mtetra
.37338 .30576 .37582 .3084 .37984 .30697 .3774 .30432 Mtetra
.3774 .30432 .37984 .30697 .38386 .30554 .38142 .30288 Mtetra
.38142 .30288 .38386 .30554 .38788 .3041 .38545 .30144 Mtetra
.38545 .30144 .38788 .3041 .39191 .30266 .38949 .3 Mtetra
.38949 .3 .39191 .30266 .39595 .30122 .39353 .29856 Mtetra
.39353 .29856 .39595 .30122 .39999 .29978 .39757 .29711 Mtetra
.39757 .29711 .39999 .29978 .40404 .29833 .40163 .29566 Mtetra
.40163 .29566 .40404 .29833 .4081 .29689 .40568 .29421 Mtetra
.40568 .29421 .4081 .29689 .41216 .29544 .40975 .29276 Mtetra
.40975 .29276 .41216 .29544 .41623 .29399 .41382 .2913 Mtetra
.41382 .2913 .41623 .29399 .4203 .29253 .4179 .28984 Mtetra
.4179 .28984 .4203 .29253 .42438 .29108 .42198 .28838 Mtetra
.42198 .28838 .42438 .29108 .42847 .28962 .42607 .28692 Mtetra
.42607 .28692 .42847 .28962 .43256 .28816 .43017 .28546 Mtetra
.43017 .28546 .43256 .28816 .43666 .28669 .43427 .28399 Mtetra
.43427 .28399 .43666 .28669 .44076 .28523 .43838 .28252 Mtetra
.43838 .28252 .44076 .28523 .44487 .28376 .44249 .28105 Mtetra
.843 .405 0 r
.44249 .28105 .44487 .28376 .44875 .2922 .44637 .28949 Mtetra
.663 .742 .909 r
.44637 .28949 .44875 .2922 .45288 .29073 .45051 .28801 Mtetra
.45051 .28801 .45288 .29073 .45703 .28926 .45465 .28654 Mtetra
.45465 .28654 .45703 .28926 .46117 .28779 .45881 .28506 Mtetra
.45881 .28506 .46117 .28779 .46533 .28631 .46297 .28358 Mtetra
.46297 .28358 .46533 .28631 .46949 .28483 .46713 .2821 Mtetra
.46713 .2821 .46949 .28483 .47366 .28335 .4713 .28062 Mtetra
.4713 .28062 .47366 .28335 .47783 .28187 .47548 .27913 Mtetra
.47548 .27913 .47783 .28187 .48201 .28039 .47967 .27764 Mtetra
.47967 .27764 .48201 .28039 .4862 .2789 .48386 .27615 Mtetra
.48386 .27615 .4862 .2789 .4904 .27741 .48806 .27466 Mtetra
.48806 .27466 .4904 .27741 .4946 .27592 .49226 .27316 Mtetra
.49226 .27316 .4946 .27592 .4988 .27443 .49647 .27167 Mtetra
.49647 .27167 .4988 .27443 .50302 .27293 .50069 .27017 Mtetra
.50069 .27017 .50302 .27293 .50724 .27143 .50491 .26866 Mtetra
.50491 .26866 .50724 .27143 .51146 .26993 .50914 .26716 Mtetra
.50914 .26716 .51146 .26993 .51569 .26843 .51338 .26565 Mtetra
.51338 .26565 .51569 .26843 .51993 .26693 .51762 .26414 Mtetra
.932 .765 .652 r
.51762 .26414 .51993 .26693 .52418 .25546 .52188 .25267 Mtetra
.664 .741 .908 r
.52188 .25267 .52418 .25546 .52842 .25395 .52613 .25115 Mtetra
.52613 .25115 .52842 .25395 .53266 .25244 .53037 .24963 Mtetra
.53037 .24963 .53266 .25244 .53692 .25092 .53463 .24811 Mtetra
.53463 .24811 .53692 .25092 .54117 .2494 .53889 .24659 Mtetra
.53889 .24659 .54117 .2494 .54544 .24788 .54316 .24506 Mtetra
.54316 .24506 .54544 .24788 .54971 .24635 .54744 .24353 Mtetra
.54744 .24353 .54971 .24635 .55399 .24483 .55172 .242 Mtetra
.55172 .242 .55399 .24483 .55827 .2433 .55601 .24047 Mtetra
.55601 .24047 .55827 .2433 .56256 .24177 .5603 .23893 Mtetra
.5603 .23893 .56256 .24177 .56686 .24023 .56461 .2374 Mtetra
.56461 .2374 .56686 .24023 .57117 .2387 .56892 .23586 Mtetra
.56892 .23586 .57117 .2387 .57548 .23716 .57323 .23431 Mtetra
.57323 .23431 .57548 .23716 .5798 .23562 .57755 .23277 Mtetra
.891 .488 .06 r
.57755 .23277 .5798 .23562 .58441 .24909 .58216 .24624 Mtetra
.663 .743 .91 r
.58216 .24624 .58441 .24909 .58876 .24755 .58652 .2447 Mtetra
.58652 .2447 .58876 .24755 .59312 .24601 .59089 .24315 Mtetra
.59089 .24315 .59312 .24601 .59749 .24446 .59526 .2416 Mtetra
.59526 .2416 .59749 .24446 .60186 .24291 .59964 .24005 Mtetra
.59964 .24005 .60186 .24291 .60625 .24136 .60402 .23849 Mtetra
.60402 .23849 .60625 .24136 .61063 .23981 .60841 .23693 Mtetra
.60841 .23693 .61063 .23981 .61503 .23825 .61281 .23537 Mtetra
.61281 .23537 .61503 .23825 .61943 .23669 .61722 .23381 Mtetra
.61722 .23381 .61943 .23669 .62384 .23513 .62163 .23224 Mtetra
.62163 .23224 .62384 .23513 .62825 .23357 .62605 .23068 Mtetra
.62605 .23068 .62825 .23357 .63267 .232 .63048 .2291 Mtetra
.63048 .2291 .63267 .232 .6371 .23043 .63491 .22753 Mtetra
.63491 .22753 .6371 .23043 .64154 .22886 .63935 .22596 Mtetra
.63935 .22596 .64154 .22886 .64598 .22729 .6438 .22438 Mtetra
.6438 .22438 .64598 .22729 .65043 .22571 .64825 .2228 Mtetra
.64825 .2228 .65043 .22571 .65489 .22414 .65271 .22122 Mtetra
.65271 .22122 .65489 .22414 .65935 .22255 .65718 .21963 Mtetra
.973 .661 .337 r
.65718 .21963 .65935 .22255 .66382 .22097 .66784 .35549 Mtetra
.522 .288 .501 r
.66784 .35549 .66382 .22097 .67478 .3568 .67253 .35395 Mtetra
.652 .755 .925 r
.67253 .35395 .67478 .3568 .68001 .36635 .67723 .3524 Mtetra
.582 .432 .643 r
.67723 .3524 .68001 .36635 .68473 .3648 .68194 .35084 Mtetra
.177 .158 .598 r
.68194 .35084 .68473 .3648 .68946 .36326 .68722 .36039 Mtetra
.651 .757 .927 r
.68722 .36039 .68946 .36326 .69419 .36171 .69196 .35884 Mtetra
.69196 .35884 .69419 .36171 .69893 .36015 .69671 .35728 Mtetra
.69671 .35728 .69893 .36015 .70368 .3586 .70146 .35572 Mtetra
.70146 .35572 .70368 .3586 .70844 .35704 .70623 .35416 Mtetra
.70623 .35416 .70844 .35704 .71321 .35548 .711 .35259 Mtetra
.711 .35259 .71321 .35548 .71798 .35392 .71578 .35102 Mtetra
.71578 .35102 .71798 .35392 .72276 .35235 .72056 .34945 Mtetra
.72056 .34945 .72276 .35235 .72755 .35078 .72536 .34788 Mtetra
.72536 .34788 .72755 .35078 .73235 .34921 .73016 .34631 Mtetra
.73016 .34631 .73235 .34921 .73716 .34764 .73497 .34473 Mtetra
.73497 .34473 .73716 .34764 .74197 .34606 .73979 .34315 Mtetra
.73979 .34315 .74197 .34606 .74679 .34448 .74462 .34156 Mtetra
.74462 .34156 .74679 .34448 .75162 .3429 .74946 .33998 Mtetra
.74946 .33998 .75162 .3429 .75646 .34132 .7543 .33839 Mtetra
.7543 .33839 .75646 .34132 .76131 .33973 .75916 .3368 Mtetra
.75916 .3368 .76131 .33973 .76616 .33814 .76402 .3352 Mtetra
.76402 .3352 .76616 .33814 .77103 .33655 .76888 .3336 Mtetra
.76888 .3336 .77103 .33655 .7759 .33496 .77376 .332 Mtetra
.77376 .332 .7759 .33496 .78078 .33336 .77865 .3304 Mtetra
.77865 .3304 .78078 .33336 .78567 .33176 .78354 .3288 Mtetra
.78354 .3288 .78567 .33176 .79056 .33015 .78844 .32719 Mtetra
.78844 .32719 .79056 .33015 .79547 .32855 .79335 .32558 Mtetra
.79335 .32558 .79547 .32855 .80038 .32694 .79827 .32396 Mtetra
.79827 .32396 .80038 .32694 .8053 .32533 .8032 .32235 Mtetra
.653 .755 .925 r
.14644 .51921 .14921 .52157 .15307 .52029 .15031 .51793 Mtetra
.15031 .51793 .15307 .52029 .15694 .51901 .15418 .51664 Mtetra
.15418 .51664 .15694 .51901 .16081 .51773 .15805 .51536 Mtetra
.15805 .51536 .16081 .51773 .16469 .51644 .16194 .51407 Mtetra
.16194 .51407 .16469 .51644 .16858 .51516 .16583 .51278 Mtetra
.16583 .51278 .16858 .51516 .17247 .51387 .16972 .51149 Mtetra
.16972 .51149 .17247 .51387 .17637 .51258 .17362 .51019 Mtetra
.17362 .51019 .17637 .51258 .18027 .51129 .17753 .5089 Mtetra
.17753 .5089 .18027 .51129 .18418 .51 .18144 .5076 Mtetra
.18144 .5076 .18418 .51 .18809 .5087 .18536 .5063 Mtetra
.18536 .5063 .18809 .5087 .19201 .5074 .18928 .505 Mtetra
.18928 .505 .19201 .5074 .19594 .5061 .19321 .5037 Mtetra
.19321 .5037 .19594 .5061 .19987 .5048 .19714 .50239 Mtetra
.19714 .50239 .19987 .5048 .20381 .5035 .20109 .50108 Mtetra
.20109 .50108 .20381 .5035 .20775 .50219 .20503 .49978 Mtetra
.643 .128 0 r
.20503 .49978 .20775 .50219 .2112 .50619 .20848 .50378 Mtetra
.652 .755 .925 r
.20848 .50378 .2112 .50619 .21517 .50489 .21245 .50247 Mtetra
.21245 .50247 .21517 .50489 .21913 .50358 .21642 .50115 Mtetra
.21642 .50115 .21913 .50358 .22311 .50227 .2204 .49984 Mtetra
.2204 .49984 .22311 .50227 .22709 .50095 .22438 .49852 Mtetra
.22438 .49852 .22709 .50095 .23108 .49964 .22837 .4972 Mtetra
.22837 .4972 .23108 .49964 .23507 .49832 .23237 .49588 Mtetra
.23237 .49588 .23507 .49832 .23907 .497 .23637 .49456 Mtetra
.23637 .49456 .23907 .497 .24307 .49568 .24038 .49323 Mtetra
.24038 .49323 .24307 .49568 .24708 .49435 .2444 .4919 Mtetra
.2444 .4919 .24708 .49435 .2511 .49303 .24842 .49057 Mtetra
.24842 .49057 .2511 .49303 .25512 .4917 .25244 .48924 Mtetra
.25244 .48924 .25512 .4917 .25915 .49037 .25648 .48791 Mtetra
.946 .697 .531 r
.25648 .48791 .25915 .49037 .26319 .48904 .26799 .39302 Mtetra
.536 .32 .533 r
.26799 .39302 .26319 .48904 .27451 .39418 .27193 .39165 Mtetra
.66 .746 .914 r
.27193 .39165 .27451 .39418 .27845 .39281 .27587 .39028 Mtetra
.27587 .39028 .27845 .39281 .2824 .39144 .27982 .3889 Mtetra
.27982 .3889 .2824 .39144 .28635 .39007 .28377 .38753 Mtetra
.28377 .38753 .28635 .39007 .29031 .38869 .28774 .38615 Mtetra
.28774 .38615 .29031 .38869 .29427 .38732 .2917 .38477 Mtetra
.2917 .38477 .29427 .38732 .29824 .38594 .29567 .38339 Mtetra
.29567 .38339 .29824 .38594 .30221 .38456 .29965 .382 Mtetra
.29965 .382 .30221 .38456 .30619 .38317 .30364 .38061 Mtetra
.30364 .38061 .30619 .38317 .31018 .38179 .30763 .37923 Mtetra
.30763 .37923 .31018 .38179 .31417 .3804 .31163 .37783 Mtetra
.31163 .37783 .31417 .3804 .31817 .37901 .31563 .37644 Mtetra
.31563 .37644 .31817 .37901 .32218 .37762 .31964 .37505 Mtetra
.31964 .37505 .32218 .37762 .32619 .37623 .32365 .37365 Mtetra
.32365 .37365 .32619 .37623 .33355 .32 .32767 .37225 Mtetra
.511 .266 .48 r
.32767 .37225 .33355 .32 .3375 .31858 .3317 .37085 Mtetra
.3317 .37085 .3375 .31858 .34147 .31717 .33573 .36944 Mtetra
.33573 .36944 .34147 .31717 .34543 .31575 .33977 .36804 Mtetra
.33977 .36804 .34543 .31575 .34941 .31433 .34382 .36663 Mtetra
0 0 .136 r
.34382 .36663 .34941 .31433 .35339 .3129 .35092 .31027 Mtetra
.664 .741 .908 r
.35092 .31027 .35339 .3129 .35738 .31148 .35491 .30884 Mtetra
.35491 .30884 .35738 .31148 .36137 .31005 .35891 .30741 Mtetra
.35891 .30741 .36137 .31005 .36537 .30862 .36291 .30598 Mtetra
.36291 .30598 .36537 .30862 .36937 .30719 .36692 .30454 Mtetra
.36692 .30454 .36937 .30719 .37338 .30576 .37093 .3031 Mtetra
.37093 .3031 .37338 .30576 .3774 .30432 .37495 .30166 Mtetra
.37495 .30166 .3774 .30432 .38142 .30288 .37898 .30022 Mtetra
.37898 .30022 .38142 .30288 .38545 .30144 .38301 .29878 Mtetra
.38301 .29878 .38545 .30144 .38949 .3 .38705 .29733 Mtetra
.38705 .29733 .38949 .3 .39353 .29856 .3911 .29588 Mtetra
.3911 .29588 .39353 .29856 .39757 .29711 .39515 .29443 Mtetra
.39515 .29443 .39757 .29711 .40163 .29566 .3992 .29298 Mtetra
.3992 .29298 .40163 .29566 .40568 .29421 .40327 .29152 Mtetra
.40327 .29152 .40568 .29421 .40975 .29276 .40734 .29007 Mtetra
.40734 .29007 .40975 .29276 .41382 .2913 .41141 .28861 Mtetra
.41141 .28861 .41382 .2913 .4179 .28984 .41549 .28715 Mtetra
.41549 .28715 .4179 .28984 .42198 .28838 .41958 .28568 Mtetra
.41958 .28568 .42198 .28838 .42607 .28692 .42367 .28421 Mtetra
.42367 .28421 .42607 .28692 .43017 .28546 .42777 .28275 Mtetra
.42777 .28275 .43017 .28546 .43427 .28399 .43188 .28128 Mtetra
.43188 .28128 .43427 .28399 .43838 .28252 .43599 .2798 Mtetra
.43599 .2798 .43838 .28252 .44249 .28105 .44011 .27833 Mtetra
.44011 .27833 .44249 .28105 .44637 .28949 .44424 .27685 Mtetra
.108 .103 .57 r
.44424 .27685 .44637 .28949 .45051 .28801 .44812 .28529 Mtetra
.663 .742 .909 r
.44812 .28529 .45051 .28801 .45465 .28654 .45227 .28381 Mtetra
.45227 .28381 .45465 .28654 .45881 .28506 .45643 .28233 Mtetra
.45643 .28233 .45881 .28506 .46297 .28358 .46059 .28085 Mtetra
.46059 .28085 .46297 .28358 .46713 .2821 .46476 .27936 Mtetra
.46476 .27936 .46713 .2821 .4713 .28062 .46894 .27787 Mtetra
.46894 .27787 .4713 .28062 .47548 .27913 .47312 .27638 Mtetra
.47312 .27638 .47548 .27913 .47967 .27764 .47731 .27489 Mtetra
.47731 .27489 .47967 .27764 .48386 .27615 .48151 .27339 Mtetra
.48151 .27339 .48386 .27615 .48806 .27466 .48571 .2719 Mtetra
.48571 .2719 .48806 .27466 .49226 .27316 .48992 .2704 Mtetra
.48992 .2704 .49226 .27316 .49647 .27167 .49413 .26889 Mtetra
.49413 .26889 .49647 .27167 .50069 .27017 .49835 .26739 Mtetra
.49835 .26739 .50069 .27017 .50491 .26866 .50258 .26588 Mtetra
.50258 .26588 .50491 .26866 .50914 .26716 .50682 .26437 Mtetra
.50682 .26437 .50914 .26716 .51338 .26565 .51106 .26286 Mtetra
.51106 .26286 .51338 .26565 .51762 .26414 .51531 .26135 Mtetra
.932 .765 .652 r
.51531 .26135 .51762 .26414 .52188 .25267 .51958 .24987 Mtetra
.664 .741 .908 r
.51958 .24987 .52188 .25267 .52613 .25115 .52382 .24835 Mtetra
.52382 .24835 .52613 .25115 .53037 .24963 .52808 .24682 Mtetra
.52808 .24682 .53037 .24963 .53463 .24811 .53234 .2453 Mtetra
.53234 .2453 .53463 .24811 .53889 .24659 .5366 .24377 Mtetra
.5366 .24377 .53889 .24659 .54316 .24506 .54088 .24224 Mtetra
.54088 .24224 .54316 .24506 .54744 .24353 .54516 .24071 Mtetra
.54516 .24071 .54744 .24353 .55172 .242 .54945 .23917 Mtetra
.54945 .23917 .55172 .242 .55601 .24047 .55374 .23763 Mtetra
.55374 .23763 .55601 .24047 .5603 .23893 .55804 .23609 Mtetra
.55804 .23609 .5603 .23893 .56461 .2374 .56235 .23455 Mtetra
.56235 .23455 .56461 .2374 .56892 .23586 .56666 .23301 Mtetra
.955 .609 .263 r
.56666 .23301 .56892 .23586 .57323 .23431 .57143 .26165 Mtetra
.495 .233 .447 r
.57143 .26165 .57323 .23431 .57755 .23277 .5758 .26011 Mtetra
.5758 .26011 .57755 .23277 .58216 .24624 .58018 .25857 Mtetra
0 0 .062 r
.58018 .25857 .58216 .24624 .58652 .2447 .58427 .24184 Mtetra
.663 .743 .91 r
.58427 .24184 .58652 .2447 .59089 .24315 .58864 .24029 Mtetra
.58864 .24029 .59089 .24315 .59526 .2416 .59302 .23873 Mtetra
.59302 .23873 .59526 .2416 .59964 .24005 .5974 .23717 Mtetra
.5974 .23717 .59964 .24005 .60402 .23849 .60179 .23561 Mtetra
.60179 .23561 .60402 .23849 .60841 .23693 .60619 .23405 Mtetra
.60619 .23405 .60841 .23693 .61281 .23537 .61059 .23248 Mtetra
.61059 .23248 .61281 .23537 .61722 .23381 .615 .23092 Mtetra
.615 .23092 .61722 .23381 .62163 .23224 .61942 .22935 Mtetra
.61942 .22935 .62163 .23224 .62605 .23068 .62384 .22777 Mtetra
.62384 .22777 .62605 .23068 .63048 .2291 .62827 .2262 Mtetra
.62827 .2262 .63048 .2291 .63491 .22753 .63271 .22462 Mtetra
.63271 .22462 .63491 .22753 .63935 .22596 .63716 .22304 Mtetra
.63716 .22304 .63935 .22596 .6438 .22438 .64161 .22146 Mtetra
.64161 .22146 .6438 .22438 .64825 .2228 .64607 .21987 Mtetra
.64607 .21987 .64825 .2228 .65271 .22122 .65053 .21829 Mtetra
.973 .661 .339 r
.65053 .21829 .65271 .22122 .65718 .21963 .66089 .35418 Mtetra
.521 .287 .501 r
.66089 .35418 .65718 .21963 .66784 .35549 .66558 .35263 Mtetra
.652 .755 .925 r
.66558 .35263 .66784 .35549 .67253 .35395 .67028 .35108 Mtetra
.67028 .35108 .67253 .35395 .67723 .3524 .67498 .34953 Mtetra
.67498 .34953 .67723 .3524 .68194 .35084 .6797 .34797 Mtetra
.6797 .34797 .68194 .35084 .68722 .36039 .68442 .34641 Mtetra
.582 .431 .642 r
.68442 .34641 .68722 .36039 .69196 .35884 .68914 .34484 Mtetra
.178 .16 .598 r
.68914 .34484 .69196 .35884 .69671 .35728 .69447 .3544 Mtetra
.651 .757 .927 r
.69447 .3544 .69671 .35728 .70146 .35572 .69923 .35283 Mtetra
.69923 .35283 .70146 .35572 .70623 .35416 .704 .35127 Mtetra
.704 .35127 .70623 .35416 .711 .35259 .70878 .3497 Mtetra
.70878 .3497 .711 .35259 .71578 .35102 .71357 .34812 Mtetra
.71357 .34812 .71578 .35102 .72056 .34945 .71836 .34655 Mtetra
.71836 .34655 .72056 .34945 .72536 .34788 .72316 .34497 Mtetra
.72316 .34497 .72536 .34788 .73016 .34631 .72797 .34339 Mtetra
.72797 .34339 .73016 .34631 .73497 .34473 .73279 .34181 Mtetra
.73279 .34181 .73497 .34473 .73979 .34315 .73761 .34022 Mtetra
.73761 .34022 .73979 .34315 .74462 .34156 .74244 .33863 Mtetra
.74244 .33863 .74462 .34156 .74946 .33998 .74729 .33704 Mtetra
.74729 .33704 .74946 .33998 .7543 .33839 .75214 .33545 Mtetra
.75214 .33545 .7543 .33839 .75916 .3368 .75699 .33385 Mtetra
.75699 .33385 .75916 .3368 .76402 .3352 .76186 .33225 Mtetra
.76186 .33225 .76402 .3352 .76888 .3336 .76674 .33065 Mtetra
.76674 .33065 .76888 .3336 .77376 .332 .77162 .32904 Mtetra
.77162 .32904 .77376 .332 .77865 .3304 .77651 .32744 Mtetra
.77651 .32744 .77865 .3304 .78354 .3288 .78141 .32583 Mtetra
.78141 .32583 .78354 .3288 .78844 .32719 .78632 .32421 Mtetra
.78632 .32421 .78844 .32719 .79335 .32558 .79123 .3226 Mtetra
.79123 .3226 .79335 .32558 .79827 .32396 .79616 .32098 Mtetra
.79616 .32098 .79827 .32396 .8032 .32235 .80109 .31936 Mtetra
.653 .755 .925 r
.14367 .51684 .14644 .51921 .15031 .51793 .14753 .51555 Mtetra
.14753 .51555 .15031 .51793 .15418 .51664 .15141 .51427 Mtetra
.15141 .51427 .15418 .51664 .15805 .51536 .15529 .51298 Mtetra
.15529 .51298 .15805 .51536 .16194 .51407 .15917 .51169 Mtetra
.15917 .51169 .16194 .51407 .16583 .51278 .16306 .51039 Mtetra
.16306 .51039 .16583 .51278 .16972 .51149 .16696 .5091 Mtetra
.16696 .5091 .16972 .51149 .17362 .51019 .17087 .5078 Mtetra
.17087 .5078 .17362 .51019 .17753 .5089 .17478 .5065 Mtetra
.17478 .5065 .17753 .5089 .18144 .5076 .17869 .5052 Mtetra
.17869 .5052 .18144 .5076 .18536 .5063 .18261 .5039 Mtetra
.18261 .5039 .18536 .5063 .18928 .505 .18654 .50259 Mtetra
.18654 .50259 .18928 .505 .19321 .5037 .19047 .50129 Mtetra
.19047 .50129 .19321 .5037 .19714 .50239 .19441 .49998 Mtetra
.19441 .49998 .19714 .50239 .20109 .50108 .19836 .49867 Mtetra
.19836 .49867 .20109 .50108 .20503 .49978 .20231 .49735 Mtetra
.20231 .49735 .20503 .49978 .20848 .50378 .20627 .49604 Mtetra
.169 .224 .677 r
.20627 .49604 .20848 .50378 .21245 .50247 .20972 .50004 Mtetra
.652 .755 .925 r
.20972 .50004 .21245 .50247 .21642 .50115 .2137 .49872 Mtetra
.2137 .49872 .21642 .50115 .2204 .49984 .21768 .4974 Mtetra
.21768 .4974 .2204 .49984 .22438 .49852 .22167 .49608 Mtetra
.22167 .49608 .22438 .49852 .22837 .4972 .22566 .49476 Mtetra
.22566 .49476 .22837 .4972 .23237 .49588 .22966 .49344 Mtetra
.22966 .49344 .23237 .49588 .23637 .49456 .23367 .49211 Mtetra
.23367 .49211 .23637 .49456 .24038 .49323 .23768 .49078 Mtetra
.23768 .49078 .24038 .49323 .2444 .4919 .2417 .48945 Mtetra
.2417 .48945 .2444 .4919 .24842 .49057 .24572 .48811 Mtetra
.24572 .48811 .24842 .49057 .25244 .48924 .24976 .48678 Mtetra
.945 .697 .532 r
.24976 .48678 .25244 .48924 .25648 .48791 .26146 .39186 Mtetra
.536 .319 .533 r
.26146 .39186 .25648 .48791 .26799 .39302 .2654 .39049 Mtetra
.66 .746 .914 r
.2654 .39049 .26799 .39302 .27193 .39165 .26934 .38912 Mtetra
.26934 .38912 .27193 .39165 .27587 .39028 .27328 .38774 Mtetra
.27328 .38774 .27587 .39028 .27982 .3889 .27724 .38636 Mtetra
.27724 .38636 .27982 .3889 .28377 .38753 .28119 .38498 Mtetra
.28119 .38498 .28377 .38753 .28774 .38615 .28516 .3836 Mtetra
.28516 .3836 .28774 .38615 .2917 .38477 .28913 .38221 Mtetra
.28913 .38221 .2917 .38477 .29567 .38339 .2931 .38083 Mtetra
.2931 .38083 .29567 .38339 .29965 .382 .29709 .37944 Mtetra
.29709 .37944 .29965 .382 .30364 .38061 .30108 .37805 Mtetra
.30108 .37805 .30364 .38061 .30763 .37923 .30507 .37666 Mtetra
.30507 .37666 .30763 .37923 .31163 .37783 .30907 .37526 Mtetra
.30907 .37526 .31163 .37783 .31563 .37644 .31308 .37386 Mtetra
.31308 .37386 .31563 .37644 .31964 .37505 .31709 .37246 Mtetra
.31709 .37246 .31964 .37505 .32365 .37365 .32111 .37106 Mtetra
.32111 .37106 .32365 .37365 .32767 .37225 .32513 .36966 Mtetra
.32513 .36966 .32767 .37225 .3317 .37085 .32916 .36825 Mtetra
.32916 .36825 .3317 .37085 .33573 .36944 .3332 .36685 Mtetra
.3332 .36685 .33573 .36944 .33977 .36804 .33724 .36544 Mtetra
.33724 .36544 .33977 .36804 .34382 .36663 .34129 .36403 Mtetra
.34129 .36403 .34382 .36663 .35092 .31027 .34535 .36261 Mtetra
.511 .265 .479 r
.34535 .36261 .35092 .31027 .35491 .30884 .34941 .36119 Mtetra
0 0 .138 r
.34941 .36119 .35491 .30884 .35891 .30741 .35644 .30476 Mtetra
.664 .741 .908 r
.35644 .30476 .35891 .30741 .36291 .30598 .36045 .30333 Mtetra
.36045 .30333 .36291 .30598 .36692 .30454 .36446 .30189 Mtetra
.36446 .30189 .36692 .30454 .37093 .3031 .36848 .30044 Mtetra
.36848 .30044 .37093 .3031 .37495 .30166 .3725 .299 Mtetra
.3725 .299 .37495 .30166 .37898 .30022 .37653 .29755 Mtetra
.37653 .29755 .37898 .30022 .38301 .29878 .38057 .29611 Mtetra
.38057 .29611 .38301 .29878 .38705 .29733 .38461 .29466 Mtetra
.38461 .29466 .38705 .29733 .3911 .29588 .38866 .2932 Mtetra
.38866 .2932 .3911 .29588 .39515 .29443 .39271 .29175 Mtetra
.39271 .29175 .39515 .29443 .3992 .29298 .39677 .29029 Mtetra
.39677 .29029 .3992 .29298 .40327 .29152 .40084 .28883 Mtetra
.40084 .28883 .40327 .29152 .40734 .29007 .40491 .28737 Mtetra
.40491 .28737 .40734 .29007 .41141 .28861 .40899 .28591 Mtetra
.40899 .28591 .41141 .28861 .41549 .28715 .41308 .28444 Mtetra
.41308 .28444 .41549 .28715 .41958 .28568 .41717 .28297 Mtetra
.41717 .28297 .41958 .28568 .42367 .28421 .42127 .2815 Mtetra
.42127 .2815 .42367 .28421 .42777 .28275 .42537 .28003 Mtetra
.42537 .28003 .42777 .28275 .43188 .28128 .42948 .27855 Mtetra
.42948 .27855 .43188 .28128 .43599 .2798 .4336 .27708 Mtetra
.4336 .27708 .43599 .2798 .44011 .27833 .43772 .2756 Mtetra
.43772 .2756 .44011 .27833 .44424 .27685 .44185 .27412 Mtetra
.842 .402 0 r
.44185 .27412 .44424 .27685 .44812 .28529 .44573 .28256 Mtetra
.663 .742 .909 r
.44573 .28256 .44812 .28529 .45227 .28381 .44989 .28107 Mtetra
.44989 .28107 .45227 .28381 .45643 .28233 .45405 .27959 Mtetra
.45405 .27959 .45643 .28233 .46059 .28085 .45822 .2781 Mtetra
.45822 .2781 .46059 .28085 .46476 .27936 .46239 .27661 Mtetra
.46239 .27661 .46476 .27936 .46894 .27787 .46657 .27512 Mtetra
.927 .76 .656 r
.46657 .27512 .46894 .27787 .47312 .27638 .47093 .26368 Mtetra
.586 .436 .645 r
.47093 .26368 .47312 .27638 .47731 .27489 .47511 .26218 Mtetra
.47511 .26218 .47731 .27489 .48151 .27339 .4793 .26068 Mtetra
.4793 .26068 .48151 .27339 .48571 .2719 .48349 .25918 Mtetra
.48349 .25918 .48571 .2719 .48992 .2704 .48769 .25767 Mtetra
.48769 .25767 .48992 .2704 .49413 .26889 .49189 .25616 Mtetra
.49189 .25616 .49413 .26889 .49835 .26739 .49611 .25465 Mtetra
.49611 .25465 .49835 .26739 .50258 .26588 .50033 .25314 Mtetra
.50033 .25314 .50258 .26588 .50682 .26437 .50455 .25162 Mtetra
.50455 .25162 .50682 .26437 .51106 .26286 .50878 .2501 Mtetra
.50878 .2501 .51106 .26286 .51531 .26135 .51302 .24858 Mtetra
.51302 .24858 .51531 .26135 .51958 .24987 .51727 .24706 Mtetra
.664 .741 .908 r
.51727 .24706 .51958 .24987 .52382 .24835 .52152 .24553 Mtetra
.52152 .24553 .52382 .24835 .52808 .24682 .52577 .244 Mtetra
.52577 .244 .52808 .24682 .53234 .2453 .53004 .24247 Mtetra
.53004 .24247 .53234 .2453 .5366 .24377 .53431 .24094 Mtetra
.53431 .24094 .5366 .24377 .54088 .24224 .53859 .23941 Mtetra
.53859 .23941 .54088 .24224 .54516 .24071 .54287 .23787 Mtetra
.54287 .23787 .54516 .24071 .54945 .23917 .54716 .23633 Mtetra
.54716 .23633 .54945 .23917 .55374 .23763 .55146 .23479 Mtetra
.956 .612 .271 r
.55146 .23479 .55374 .23763 .55804 .23609 .55607 .26343 Mtetra
.494 .232 .446 r
.55607 .26343 .55804 .23609 .56235 .23455 .56042 .26189 Mtetra
.56042 .26189 .56235 .23455 .56666 .23301 .56479 .26035 Mtetra
.56479 .26035 .56666 .23301 .57143 .26165 .56915 .25881 Mtetra
.662 .744 .911 r
.56915 .25881 .57143 .26165 .5758 .26011 .57353 .25726 Mtetra
.57353 .25726 .5758 .26011 .58018 .25857 .57791 .25571 Mtetra
.57791 .25571 .58018 .25857 .58427 .24184 .5823 .25416 Mtetra
.449 .146 .359 r
.5823 .25416 .58427 .24184 .58864 .24029 .58669 .25261 Mtetra
0 0 .065 r
.58669 .25261 .58864 .24029 .59302 .23873 .59077 .23585 Mtetra
.663 .743 .91 r
.59077 .23585 .59302 .23873 .5974 .23717 .59516 .23429 Mtetra
.59516 .23429 .5974 .23717 .60179 .23561 .59955 .23273 Mtetra
.59955 .23273 .60179 .23561 .60619 .23405 .60395 .23116 Mtetra
.60395 .23116 .60619 .23405 .61059 .23248 .60836 .22959 Mtetra
.60836 .22959 .61059 .23248 .615 .23092 .61277 .22802 Mtetra
.61277 .22802 .615 .23092 .61942 .22935 .6172 .22644 Mtetra
.6172 .22644 .61942 .22935 .62384 .22777 .62163 .22486 Mtetra
.62163 .22486 .62384 .22777 .62827 .2262 .62606 .22328 Mtetra
.62606 .22328 .62827 .2262 .63271 .22462 .63051 .2217 Mtetra
.63051 .2217 .63271 .22462 .63716 .22304 .63496 .22012 Mtetra
.63496 .22012 .63716 .22304 .64161 .22146 .63941 .21853 Mtetra
.63941 .21853 .64161 .22146 .64607 .21987 .64388 .21694 Mtetra
.973 .662 .342 r
.64388 .21694 .64607 .21987 .65053 .21829 .65394 .35287 Mtetra
.521 .286 .5 r
.65394 .35287 .65053 .21829 .66089 .35418 .65862 .35132 Mtetra
.652 .755 .925 r
.65862 .35132 .66089 .35418 .66558 .35263 .66332 .34977 Mtetra
.66332 .34977 .66558 .35263 .67028 .35108 .66802 .34821 Mtetra
.66802 .34821 .67028 .35108 .67498 .34953 .67273 .34665 Mtetra
.67273 .34665 .67498 .34953 .6797 .34797 .67745 .34508 Mtetra
.67745 .34508 .6797 .34797 .68442 .34641 .68217 .34352 Mtetra
.68217 .34352 .68442 .34641 .68914 .34484 .68691 .34195 Mtetra
.68691 .34195 .68914 .34484 .69447 .3544 .69165 .34038 Mtetra
.582 .431 .642 r
.69165 .34038 .69447 .3544 .69923 .35283 .6964 .33881 Mtetra
.18 .161 .599 r
.6964 .33881 .69923 .35283 .704 .35127 .70177 .34837 Mtetra
.651 .757 .927 r
.70177 .34837 .704 .35127 .70878 .3497 .70656 .34679 Mtetra
.70656 .34679 .70878 .3497 .71357 .34812 .71135 .34521 Mtetra
.71135 .34521 .71357 .34812 .71836 .34655 .71615 .34363 Mtetra
.71615 .34363 .71836 .34655 .72316 .34497 .72095 .34205 Mtetra
.72095 .34205 .72316 .34497 .72797 .34339 .72577 .34046 Mtetra
.72577 .34046 .72797 .34339 .73279 .34181 .73059 .33888 Mtetra
.73059 .33888 .73279 .34181 .73761 .34022 .73542 .33729 Mtetra
.73542 .33729 .73761 .34022 .74244 .33863 .74026 .33569 Mtetra
.74026 .33569 .74244 .33863 .74729 .33704 .74511 .3341 Mtetra
.74511 .3341 .74729 .33704 .75214 .33545 .74996 .3325 Mtetra
.74996 .3325 .75214 .33545 .75699 .33385 .75483 .33089 Mtetra
.75483 .33089 .75699 .33385 .76186 .33225 .7597 .32929 Mtetra
.7597 .32929 .76186 .33225 .76674 .33065 .76458 .32768 Mtetra
.76458 .32768 .76674 .33065 .77162 .32904 .76947 .32607 Mtetra
.76947 .32607 .77162 .32904 .77651 .32744 .77437 .32446 Mtetra
.77437 .32446 .77651 .32744 .78141 .32583 .77927 .32284 Mtetra
.77927 .32284 .78141 .32583 .78632 .32421 .78419 .32123 Mtetra
.78419 .32123 .78632 .32421 .79123 .3226 .78911 .31961 Mtetra
.78911 .31961 .79123 .3226 .79616 .32098 .79404 .31798 Mtetra
.79404 .31798 .79616 .32098 .80109 .31936 .79898 .31636 Mtetra
.653 .755 .925 r
.14088 .51447 .14367 .51684 .14753 .51555 .14475 .51318 Mtetra
.14475 .51318 .14753 .51555 .15141 .51427 .14863 .51189 Mtetra
.14863 .51189 .15141 .51427 .15529 .51298 .15251 .51059 Mtetra
.15251 .51059 .15529 .51298 .15917 .51169 .1564 .5093 Mtetra
.1564 .5093 .15917 .51169 .16306 .51039 .1603 .508 Mtetra
.1603 .508 .16306 .51039 .16696 .5091 .1642 .5067 Mtetra
.1642 .5067 .16696 .5091 .17087 .5078 .1681 .5054 Mtetra
.1681 .5054 .17087 .5078 .17478 .5065 .17202 .5041 Mtetra
.17202 .5041 .17478 .5065 .17869 .5052 .17594 .50279 Mtetra
.17594 .50279 .17869 .5052 .18261 .5039 .17986 .50149 Mtetra
.17986 .50149 .18261 .5039 .18654 .50259 .18379 .50018 Mtetra
.18379 .50018 .18654 .50259 .19047 .50129 .18773 .49887 Mtetra
.18773 .49887 .19047 .50129 .19441 .49998 .19167 .49756 Mtetra
.19167 .49756 .19441 .49998 .19836 .49867 .19562 .49624 Mtetra
.19562 .49624 .19836 .49867 .20231 .49735 .19957 .49492 Mtetra
.19957 .49492 .20231 .49735 .20627 .49604 .20353 .49361 Mtetra
.64 .125 0 r
.20353 .49361 .20627 .49604 .20972 .50004 .20699 .49761 Mtetra
.652 .755 .925 r
.20699 .49761 .20972 .50004 .2137 .49872 .21097 .49629 Mtetra
.21097 .49629 .2137 .49872 .21768 .4974 .21496 .49496 Mtetra
.21496 .49496 .21768 .4974 .22167 .49608 .21895 .49364 Mtetra
.21895 .49364 .22167 .49608 .22566 .49476 .22294 .49231 Mtetra
.22294 .49231 .22566 .49476 .22966 .49344 .22695 .49098 Mtetra
.22695 .49098 .22966 .49344 .23367 .49211 .23096 .48965 Mtetra
.23096 .48965 .23367 .49211 .23768 .49078 .23497 .48832 Mtetra
.23497 .48832 .23768 .49078 .2417 .48945 .239 .48698 Mtetra
.239 .48698 .2417 .48945 .24572 .48811 .24302 .48565 Mtetra
.24302 .48565 .24572 .48811 .24976 .48678 .24706 .48431 Mtetra
.945 .697 .532 r
.24706 .48431 .24976 .48678 .26146 .39186 .25886 .38933 Mtetra
.66 .746 .914 r
.25886 .38933 .26146 .39186 .2654 .39049 .26279 .38795 Mtetra
.26279 .38795 .2654 .39049 .26934 .38912 .26674 .38657 Mtetra
.26674 .38657 .26934 .38912 .27328 .38774 .27069 .38519 Mtetra
.27069 .38519 .27328 .38774 .27724 .38636 .27464 .38381 Mtetra
.27464 .38381 .27724 .38636 .28119 .38498 .27861 .38243 Mtetra
.27861 .38243 .28119 .38498 .28516 .3836 .28257 .38104 Mtetra
.28257 .38104 .28516 .3836 .28913 .38221 .28655 .37965 Mtetra
.28655 .37965 .28913 .38221 .2931 .38083 .29053 .37826 Mtetra
.29053 .37826 .2931 .38083 .29709 .37944 .29451 .37687 Mtetra
.29451 .37687 .29709 .37944 .30108 .37805 .29851 .37548 Mtetra
.29851 .37548 .30108 .37805 .30507 .37666 .3025 .37408 Mtetra
.3025 .37408 .30507 .37666 .30907 .37526 .30651 .37268 Mtetra
.30651 .37268 .30907 .37526 .31308 .37386 .31052 .37128 Mtetra
.31052 .37128 .31308 .37386 .31709 .37246 .31453 .36988 Mtetra
.31453 .36988 .31709 .37246 .32111 .37106 .31856 .36847 Mtetra
.31856 .36847 .32111 .37106 .32513 .36966 .32259 .36706 Mtetra
.32259 .36706 .32513 .36966 .32916 .36825 .32662 .36565 Mtetra
.32662 .36565 .32916 .36825 .3332 .36685 .33066 .36424 Mtetra
.33066 .36424 .3332 .36685 .33724 .36544 .33471 .36283 Mtetra
.33471 .36283 .33724 .36544 .34129 .36403 .33876 .36141 Mtetra
.33876 .36141 .34129 .36403 .34535 .36261 .34282 .35999 Mtetra
.34282 .35999 .34535 .36261 .34941 .36119 .34689 .35857 Mtetra
.952 .706 .528 r
.34689 .35857 .34941 .36119 .35644 .30476 .35397 .30211 Mtetra
.664 .741 .908 r
.35397 .30211 .35644 .30476 .36045 .30333 .35798 .30067 Mtetra
.35798 .30067 .36045 .30333 .36446 .30189 .36199 .29922 Mtetra
.36199 .29922 .36446 .30189 .36848 .30044 .36602 .29778 Mtetra
.36602 .29778 .36848 .30044 .3725 .299 .37004 .29633 Mtetra
.37004 .29633 .3725 .299 .37653 .29755 .37408 .29488 Mtetra
.37408 .29488 .37653 .29755 .38057 .29611 .37812 .29343 Mtetra
.37812 .29343 .38057 .29611 .38461 .29466 .38216 .29197 Mtetra
.38216 .29197 .38461 .29466 .38866 .2932 .38622 .29052 Mtetra
.38622 .29052 .38866 .2932 .39271 .29175 .39027 .28906 Mtetra
.39027 .28906 .39271 .29175 .39677 .29029 .39434 .2876 Mtetra
.39434 .2876 .39677 .29029 .40084 .28883 .39841 .28613 Mtetra
.39841 .28613 .40084 .28883 .40491 .28737 .40249 .28467 Mtetra
.40249 .28467 .40491 .28737 .40899 .28591 .40657 .2832 Mtetra
.40657 .2832 .40899 .28591 .41308 .28444 .41066 .28173 Mtetra
.41066 .28173 .41308 .28444 .41717 .28297 .41475 .28026 Mtetra
.41475 .28026 .41717 .28297 .42127 .2815 .41885 .27878 Mtetra
.41885 .27878 .42127 .2815 .42537 .28003 .42296 .27731 Mtetra
.42296 .27731 .42537 .28003 .42948 .27855 .42708 .27583 Mtetra
.42708 .27583 .42948 .27855 .4336 .27708 .4312 .27435 Mtetra
.4312 .27435 .4336 .27708 .43772 .2756 .43532 .27286 Mtetra
.43532 .27286 .43772 .2756 .44185 .27412 .43946 .27138 Mtetra
.43946 .27138 .44185 .27412 .44573 .28256 .4436 .26989 Mtetra
.586 .436 .644 r
.4436 .26989 .44573 .28256 .44989 .28107 .44774 .2684 Mtetra
.44774 .2684 .44989 .28107 .45405 .27959 .45189 .26691 Mtetra
.45189 .26691 .45405 .27959 .45822 .2781 .45605 .26541 Mtetra
.45605 .26541 .45822 .2781 .46239 .27661 .46022 .26391 Mtetra
.46022 .26391 .46239 .27661 .46657 .27512 .46439 .26241 Mtetra
.46439 .26241 .46657 .27512 .47093 .26368 .46857 .26091 Mtetra
.664 .741 .908 r
.46857 .26091 .47093 .26368 .47511 .26218 .47275 .25941 Mtetra
.47275 .25941 .47511 .26218 .4793 .26068 .47694 .2579 Mtetra
.47694 .2579 .4793 .26068 .48349 .25918 .48114 .25639 Mtetra
.48114 .25639 .48349 .25918 .48769 .25767 .48534 .25488 Mtetra
.48534 .25488 .48769 .25767 .49189 .25616 .48955 .25337 Mtetra
.48955 .25337 .49189 .25616 .49611 .25465 .49377 .25185 Mtetra
.49377 .25185 .49611 .25465 .50033 .25314 .49799 .25033 Mtetra
.49799 .25033 .50033 .25314 .50455 .25162 .50222 .24881 Mtetra
.50222 .24881 .50455 .25162 .50878 .2501 .50646 .24729 Mtetra
.50646 .24729 .50878 .2501 .51302 .24858 .5107 .24577 Mtetra
.5107 .24577 .51302 .24858 .51727 .24706 .51495 .24424 Mtetra
.51495 .24424 .51727 .24706 .52152 .24553 .5192 .24271 Mtetra
.5192 .24271 .52152 .24553 .52577 .244 .52346 .24118 Mtetra
.52346 .24118 .52577 .244 .53004 .24247 .52773 .23964 Mtetra
.52773 .23964 .53004 .24247 .53431 .24094 .53201 .23811 Mtetra
.53201 .23811 .53431 .24094 .53859 .23941 .53629 .23657 Mtetra
.53629 .23657 .53859 .23941 .54287 .23787 .54058 .23502 Mtetra
.957 .613 .276 r
.54058 .23502 .54287 .23787 .54716 .23633 .54507 .26367 Mtetra
.493 .231 .445 r
.54507 .26367 .54716 .23633 .55146 .23479 .54942 .26213 Mtetra
.54942 .26213 .55146 .23479 .55607 .26343 .55377 .26059 Mtetra
.662 .744 .911 r
.55377 .26059 .55607 .26343 .56042 .26189 .55813 .25904 Mtetra
.55813 .25904 .56042 .26189 .56479 .26035 .56249 .2575 Mtetra
.56249 .2575 .56479 .26035 .56915 .25881 .56687 .25595 Mtetra
.56687 .25595 .56915 .25881 .57353 .25726 .57125 .2544 Mtetra
.57125 .2544 .57353 .25726 .57791 .25571 .57563 .25285 Mtetra
.57563 .25285 .57791 .25571 .5823 .25416 .58002 .25129 Mtetra
.58002 .25129 .5823 .25416 .58669 .25261 .58442 .24974 Mtetra
.58442 .24974 .58669 .25261 .59077 .23585 .58883 .24818 Mtetra
0 0 .065 r
.58883 .24818 .59077 .23585 .59516 .23429 .59291 .2314 Mtetra
.663 .743 .91 r
.59291 .2314 .59516 .23429 .59955 .23273 .59731 .22983 Mtetra
.59731 .22983 .59955 .23273 .60395 .23116 .60171 .22826 Mtetra
.60171 .22826 .60395 .23116 .60836 .22959 .60612 .22668 Mtetra
.60612 .22668 .60836 .22959 .61277 .22802 .61054 .22511 Mtetra
.61054 .22511 .61277 .22802 .6172 .22644 .61497 .22353 Mtetra
.61497 .22353 .6172 .22644 .62163 .22486 .6194 .22195 Mtetra
.6194 .22195 .62163 .22486 .62606 .22328 .62385 .22036 Mtetra
.62385 .22036 .62606 .22328 .63051 .2217 .62829 .21878 Mtetra
.62829 .21878 .63051 .2217 .63496 .22012 .63275 .21719 Mtetra
.63275 .21719 .63496 .22012 .63941 .21853 .63721 .21559 Mtetra
.973 .662 .344 r
.63721 .21559 .63941 .21853 .64388 .21694 .64697 .35156 Mtetra
.52 .286 .499 r
.64697 .35156 .64388 .21694 .65394 .35287 .65165 .35001 Mtetra
.652 .755 .925 r
.65165 .35001 .65394 .35287 .65862 .35132 .65635 .34845 Mtetra
.65635 .34845 .65862 .35132 .66332 .34977 .66104 .34689 Mtetra
.66104 .34689 .66332 .34977 .66802 .34821 .66575 .34533 Mtetra
.66575 .34533 .66802 .34821 .67273 .34665 .67047 .34376 Mtetra
.67047 .34376 .67273 .34665 .67745 .34508 .67519 .34219 Mtetra
.67519 .34219 .67745 .34508 .68217 .34352 .67992 .34062 Mtetra
.67992 .34062 .68217 .34352 .68691 .34195 .68466 .33905 Mtetra
.68466 .33905 .68691 .34195 .69165 .34038 .68941 .33747 Mtetra
.68941 .33747 .69165 .34038 .6964 .33881 .69416 .3359 Mtetra
.69416 .3359 .6964 .33881 .70177 .34837 .69892 .33431 Mtetra
.18 .161 .599 r
.69892 .33431 .70177 .34837 .70656 .34679 .70433 .34388 Mtetra
.651 .757 .927 r
.70433 .34388 .70656 .34679 .71135 .34521 .70912 .34229 Mtetra
.70912 .34229 .71135 .34521 .71615 .34363 .71393 .34071 Mtetra
.71393 .34071 .71615 .34363 .72095 .34205 .71874 .33912 Mtetra
.71874 .33912 .72095 .34205 .72577 .34046 .72356 .33753 Mtetra
.72356 .33753 .72577 .34046 .73059 .33888 .72839 .33594 Mtetra
.72839 .33594 .73059 .33888 .73542 .33729 .73322 .33434 Mtetra
.73322 .33434 .73542 .33729 .74026 .33569 .73807 .33274 Mtetra
.73807 .33274 .74026 .33569 .74511 .3341 .74292 .33114 Mtetra
.74292 .33114 .74511 .3341 .74996 .3325 .74778 .32954 Mtetra
.74778 .32954 .74996 .3325 .75483 .33089 .75265 .32793 Mtetra
.75265 .32793 .75483 .33089 .7597 .32929 .75753 .32632 Mtetra
.75753 .32632 .7597 .32929 .76458 .32768 .76242 .32471 Mtetra
.76242 .32471 .76458 .32768 .76947 .32607 .76731 .32309 Mtetra
.76731 .32309 .76947 .32607 .77437 .32446 .77222 .32148 Mtetra
.77222 .32148 .77437 .32446 .77927 .32284 .77713 .31986 Mtetra
.77713 .31986 .77927 .32284 .78419 .32123 .78205 .31823 Mtetra
.78205 .31823 .78419 .32123 .78911 .31961 .78698 .31661 Mtetra
.78698 .31661 .78911 .31961 .79404 .31798 .79191 .31498 Mtetra
.79191 .31498 .79404 .31798 .79898 .31636 .79686 .31335 Mtetra
.653 .755 .925 r
.13809 .51208 .14088 .51447 .14475 .51318 .14196 .51079 Mtetra
.14196 .51079 .14475 .51318 .14863 .51189 .14584 .5095 Mtetra
.14584 .5095 .14863 .51189 .15251 .51059 .14973 .5082 Mtetra
.14973 .5082 .15251 .51059 .1564 .5093 .15362 .5069 Mtetra
.15362 .5069 .1564 .5093 .1603 .508 .15752 .5056 Mtetra
.15752 .5056 .1603 .508 .1642 .5067 .16142 .5043 Mtetra
.16142 .5043 .1642 .5067 .1681 .5054 .16533 .50299 Mtetra
.16533 .50299 .1681 .5054 .17202 .5041 .16925 .50169 Mtetra
.16925 .50169 .17202 .5041 .17594 .50279 .17317 .50038 Mtetra
.17317 .50038 .17594 .50279 .17986 .50149 .1771 .49907 Mtetra
.1771 .49907 .17986 .50149 .18379 .50018 .18104 .49776 Mtetra
.18104 .49776 .18379 .50018 .18773 .49887 .18498 .49644 Mtetra
.18498 .49644 .18773 .49887 .19167 .49756 .18892 .49513 Mtetra
.18892 .49513 .19167 .49756 .19562 .49624 .19287 .49381 Mtetra
.19287 .49381 .19562 .49624 .19957 .49492 .19683 .49249 Mtetra
.19683 .49249 .19957 .49492 .20353 .49361 .2008 .49117 Mtetra
.64 .125 0 r
.2008 .49117 .20353 .49361 .20699 .49761 .20425 .49517 Mtetra
.652 .755 .925 r
.20425 .49517 .20699 .49761 .21097 .49629 .20823 .49384 Mtetra
.20823 .49384 .21097 .49629 .21496 .49496 .21222 .49252 Mtetra
.21222 .49252 .21496 .49496 .21895 .49364 .21622 .49119 Mtetra
.21622 .49119 .21895 .49364 .22294 .49231 .22022 .48986 Mtetra
.22022 .48986 .22294 .49231 .22695 .49098 .22423 .48852 Mtetra
.22423 .48852 .22695 .49098 .23096 .48965 .22824 .48719 Mtetra
.22824 .48719 .23096 .48965 .23497 .48832 .23226 .48585 Mtetra
.23226 .48585 .23497 .48832 .239 .48698 .23628 .48451 Mtetra
.23628 .48451 .239 .48698 .24302 .48565 .24032 .48317 Mtetra
.945 .697 .532 r
.24032 .48317 .24302 .48565 .24706 .48431 .25231 .38816 Mtetra
.535 .318 .532 r
.25231 .38816 .24706 .48431 .25886 .38933 .25624 .38679 Mtetra
.66 .746 .914 r
.25624 .38679 .25886 .38933 .26279 .38795 .26018 .38541 Mtetra
.26018 .38541 .26279 .38795 .26674 .38657 .26413 .38402 Mtetra
.26413 .38402 .26674 .38657 .27069 .38519 .26809 .38264 Mtetra
.26809 .38264 .27069 .38519 .27464 .38381 .27205 .38125 Mtetra
.27205 .38125 .27464 .38381 .27861 .38243 .27601 .37987 Mtetra
.27601 .37987 .27861 .38243 .28257 .38104 .27998 .37848 Mtetra
.27998 .37848 .28257 .38104 .28655 .37965 .28396 .37708 Mtetra
.28396 .37708 .28655 .37965 .29053 .37826 .28794 .37569 Mtetra
.28794 .37569 .29053 .37826 .29451 .37687 .29193 .37429 Mtetra
.29193 .37429 .29451 .37687 .29851 .37548 .29593 .3729 Mtetra
.29593 .3729 .29851 .37548 .3025 .37408 .29993 .3715 Mtetra
.29993 .3715 .3025 .37408 .30651 .37268 .30394 .37009 Mtetra
.30394 .37009 .30651 .37268 .31052 .37128 .30795 .36869 Mtetra
.30795 .36869 .31052 .37128 .31453 .36988 .31197 .36728 Mtetra
.31197 .36728 .31453 .36988 .31856 .36847 .316 .36587 Mtetra
.316 .36587 .31856 .36847 .32259 .36706 .32003 .36446 Mtetra
.32003 .36446 .32259 .36706 .32662 .36565 .32407 .36305 Mtetra
.32407 .36305 .32662 .36565 .33066 .36424 .32811 .36163 Mtetra
.32811 .36163 .33066 .36424 .33471 .36283 .33216 .36021 Mtetra
.33216 .36021 .33471 .36283 .33876 .36141 .33622 .35879 Mtetra
.33622 .35879 .33876 .36141 .34282 .35999 .34028 .35737 Mtetra
.34028 .35737 .34282 .35999 .34689 .35857 .34435 .35595 Mtetra
.34435 .35595 .34689 .35857 .35397 .30211 .34843 .35452 Mtetra
0 0 .136 r
.34843 .35452 .35397 .30211 .35798 .30067 .3555 .298 Mtetra
.664 .741 .908 r
.3555 .298 .35798 .30067 .36199 .29922 .35952 .29655 Mtetra
.35952 .29655 .36199 .29922 .36602 .29778 .36355 .2951 Mtetra
.36355 .2951 .36602 .29778 .37004 .29633 .36758 .29365 Mtetra
.36758 .29365 .37004 .29633 .37408 .29488 .37162 .2922 Mtetra
.37162 .2922 .37408 .29488 .37812 .29343 .37566 .29074 Mtetra
.37566 .29074 .37812 .29343 .38216 .29197 .37971 .28928 Mtetra
.37971 .28928 .38216 .29197 .38622 .29052 .38376 .28782 Mtetra
.38376 .28782 .38622 .29052 .39027 .28906 .38783 .28636 Mtetra
.38783 .28636 .39027 .28906 .39434 .2876 .3919 .28489 Mtetra
.3919 .28489 .39434 .2876 .39841 .28613 .39597 .28342 Mtetra
.39597 .28342 .39841 .28613 .40249 .28467 .40005 .28195 Mtetra
.40005 .28195 .40249 .28467 .40657 .2832 .40414 .28048 Mtetra
.40414 .28048 .40657 .2832 .41066 .28173 .40823 .27901 Mtetra
.40823 .27901 .41066 .28173 .41475 .28026 .41233 .27753 Mtetra
.41233 .27753 .41475 .28026 .41885 .27878 .41644 .27605 Mtetra
.41644 .27605 .41885 .27878 .42296 .27731 .42055 .27457 Mtetra
.42055 .27457 .42296 .27731 .42708 .27583 .42467 .27309 Mtetra
.42467 .27309 .42708 .27583 .4312 .27435 .42879 .2716 Mtetra
.42879 .2716 .4312 .27435 .43532 .27286 .43292 .27012 Mtetra
.956 .615 .307 r
.43292 .27012 .43532 .27286 .43946 .27138 .43635 .29358 Mtetra
0 0 .088 r
.43635 .29358 .43946 .27138 .4436 .26989 .4412 .26713 Mtetra
.664 .741 .908 r
.4412 .26713 .4436 .26989 .44774 .2684 .44535 .26564 Mtetra
.44535 .26564 .44774 .2684 .45189 .26691 .44951 .26414 Mtetra
.44951 .26414 .45189 .26691 .45605 .26541 .45367 .26264 Mtetra
.45367 .26264 .45605 .26541 .46022 .26391 .45784 .26114 Mtetra
.45784 .26114 .46022 .26391 .46439 .26241 .46201 .25964 Mtetra
.46201 .25964 .46439 .26241 .46857 .26091 .46619 .25813 Mtetra
.46619 .25813 .46857 .26091 .47275 .25941 .47038 .25663 Mtetra
.47038 .25663 .47275 .25941 .47694 .2579 .47458 .25511 Mtetra
.47458 .25511 .47694 .2579 .48114 .25639 .47878 .2536 Mtetra
.47878 .2536 .48114 .25639 .48534 .25488 .48299 .25209 Mtetra
.48299 .25209 .48534 .25488 .48955 .25337 .4872 .25057 Mtetra
.4872 .25057 .48955 .25337 .49377 .25185 .49142 .24905 Mtetra
.49142 .24905 .49377 .25185 .49799 .25033 .49565 .24753 Mtetra
.49565 .24753 .49799 .25033 .50222 .24881 .49988 .246 Mtetra
.49988 .246 .50222 .24881 .50646 .24729 .50412 .24447 Mtetra
.50412 .24447 .50646 .24729 .5107 .24577 .50837 .24294 Mtetra
.50837 .24294 .5107 .24577 .51495 .24424 .51262 .24141 Mtetra
.51262 .24141 .51495 .24424 .5192 .24271 .51688 .23988 Mtetra
.51688 .23988 .5192 .24271 .52346 .24118 .52115 .23834 Mtetra
.52115 .23834 .52346 .24118 .52773 .23964 .52542 .2368 Mtetra
.958 .616 .284 r
.52542 .2368 .52773 .23964 .53201 .23811 .52975 .26544 Mtetra
.492 .23 .444 r
.52975 .26544 .53201 .23811 .53629 .23657 .53408 .2639 Mtetra
.53408 .2639 .53629 .23657 .54058 .23502 .53841 .26237 Mtetra
.53841 .26237 .54058 .23502 .54507 .26367 .54276 .26083 Mtetra
.662 .744 .911 r
.54276 .26083 .54507 .26367 .54942 .26213 .54711 .25928 Mtetra
.54711 .25928 .54942 .26213 .55377 .26059 .55146 .25774 Mtetra
.55146 .25774 .55377 .26059 .55813 .25904 .55582 .25619 Mtetra
.55582 .25619 .55813 .25904 .56249 .2575 .56019 .25464 Mtetra
.56019 .25464 .56249 .2575 .56687 .25595 .56457 .25309 Mtetra
.56457 .25309 .56687 .25595 .57125 .2544 .56896 .25153 Mtetra
.56896 .25153 .57125 .2544 .57563 .25285 .57335 .24998 Mtetra
.57335 .24998 .57563 .25285 .58002 .25129 .57774 .24842 Mtetra
.57774 .24842 .58002 .25129 .58442 .24974 .58215 .24685 Mtetra
.58215 .24685 .58442 .24974 .58883 .24818 .58656 .24529 Mtetra
.58656 .24529 .58883 .24818 .59291 .2314 .59098 .24372 Mtetra
.447 .143 .356 r
.59098 .24372 .59291 .2314 .59731 .22983 .5954 .24215 Mtetra
0 0 .068 r
.5954 .24215 .59731 .22983 .60171 .22826 .59946 .22535 Mtetra
.663 .743 .91 r
.59946 .22535 .60171 .22826 .60612 .22668 .60388 .22377 Mtetra
.60388 .22377 .60612 .22668 .61054 .22511 .60831 .22219 Mtetra
.60831 .22219 .61054 .22511 .61497 .22353 .61274 .22061 Mtetra
.61274 .22061 .61497 .22353 .6194 .22195 .61718 .21902 Mtetra
.61718 .21902 .6194 .22195 .62385 .22036 .62162 .21743 Mtetra
.62162 .21743 .62385 .22036 .62829 .21878 .62608 .21584 Mtetra
.62608 .21584 .62829 .21878 .63275 .21719 .63053 .21425 Mtetra
.63053 .21425 .63275 .21719 .63721 .21559 .635 .21265 Mtetra
.973 .662 .344 r
.635 .21265 .63721 .21559 .64697 .35156 .64467 .34869 Mtetra
.652 .755 .925 r
.64467 .34869 .64697 .35156 .65165 .35001 .64936 .34713 Mtetra
.64936 .34713 .65165 .35001 .65635 .34845 .65406 .34557 Mtetra
.65406 .34557 .65635 .34845 .66104 .34689 .65877 .344 Mtetra
.65877 .344 .66104 .34689 .66575 .34533 .66348 .34243 Mtetra
.66348 .34243 .66575 .34533 .67047 .34376 .6682 .34086 Mtetra
.6682 .34086 .67047 .34376 .67519 .34219 .67293 .33929 Mtetra
.67293 .33929 .67519 .34219 .67992 .34062 .67766 .33772 Mtetra
.67766 .33772 .67992 .34062 .68466 .33905 .68241 .33614 Mtetra
.68241 .33614 .68466 .33905 .68941 .33747 .68716 .33456 Mtetra
.68716 .33456 .68941 .33747 .69416 .3359 .69192 .33297 Mtetra
.69192 .33297 .69416 .3359 .69892 .33431 .69669 .33139 Mtetra
.69669 .33139 .69892 .33431 .70433 .34388 .70146 .3298 Mtetra
.581 .43 .642 r
.70146 .3298 .70433 .34388 .70912 .34229 .70625 .32821 Mtetra
.181 .162 .599 r
.70625 .32821 .70912 .34229 .71393 .34071 .7117 .33778 Mtetra
.651 .757 .927 r
.7117 .33778 .71393 .34071 .71874 .33912 .71652 .33618 Mtetra
.71652 .33618 .71874 .33912 .72356 .33753 .72134 .33459 Mtetra
.72134 .33459 .72356 .33753 .72839 .33594 .72618 .33299 Mtetra
.72618 .33299 .72839 .33594 .73322 .33434 .73102 .33139 Mtetra
.73102 .33139 .73322 .33434 .73807 .33274 .73587 .32978 Mtetra
.73587 .32978 .73807 .33274 .74292 .33114 .74073 .32818 Mtetra
.74073 .32818 .74292 .33114 .74778 .32954 .7456 .32657 Mtetra
.7456 .32657 .74778 .32954 .75265 .32793 .75047 .32496 Mtetra
.75047 .32496 .75265 .32793 .75753 .32632 .75536 .32334 Mtetra
.75536 .32334 .75753 .32632 .76242 .32471 .76025 .32172 Mtetra
.76025 .32172 .76242 .32471 .76731 .32309 .76515 .3201 Mtetra
.76515 .3201 .76731 .32309 .77222 .32148 .77006 .31848 Mtetra
.77006 .31848 .77222 .32148 .77713 .31986 .77498 .31686 Mtetra
.77498 .31686 .77713 .31986 .78205 .31823 .7799 .31523 Mtetra
.7799 .31523 .78205 .31823 .78698 .31661 .78484 .3136 Mtetra
.78484 .3136 .78698 .31661 .79191 .31498 .78978 .31196 Mtetra
.78978 .31196 .79191 .31498 .79686 .31335 .79473 .31033 Mtetra
.653 .755 .925 r
.13529 .5097 .13809 .51208 .14196 .51079 .13917 .5084 Mtetra
.13917 .5084 .14196 .51079 .14584 .5095 .14305 .5071 Mtetra
.14305 .5071 .14584 .5095 .14973 .5082 .14694 .5058 Mtetra
.14694 .5058 .14973 .5082 .15362 .5069 .15083 .5045 Mtetra
.15083 .5045 .15362 .5069 .15752 .5056 .15474 .5032 Mtetra
.15474 .5032 .15752 .5056 .16142 .5043 .15864 .50189 Mtetra
.15864 .50189 .16142 .5043 .16533 .50299 .16256 .50058 Mtetra
.16256 .50058 .16533 .50299 .16925 .50169 .16648 .49927 Mtetra
.16648 .49927 .16925 .50169 .17317 .50038 .1704 .49796 Mtetra
.1704 .49796 .17317 .50038 .1771 .49907 .17433 .49665 Mtetra
.17433 .49665 .1771 .49907 .18104 .49776 .17827 .49533 Mtetra
.17827 .49533 .18104 .49776 .18498 .49644 .18222 .49401 Mtetra
.18222 .49401 .18498 .49644 .18892 .49513 .18617 .49269 Mtetra
.18617 .49269 .18892 .49513 .19287 .49381 .19012 .49137 Mtetra
.19012 .49137 .19287 .49381 .19683 .49249 .19408 .49004 Mtetra
.19408 .49004 .19683 .49249 .2008 .49117 .19805 .48872 Mtetra
.947 .665 .471 r
.19805 .48872 .2008 .49117 .20425 .49517 .19675 .54148 Mtetra
.506 .257 .471 r
.19675 .54148 .20425 .49517 .20823 .49384 .20079 .54017 Mtetra
.20079 .54017 .20823 .49384 .21222 .49252 .20484 .53886 Mtetra
.20484 .53886 .21222 .49252 .21622 .49119 .20889 .53755 Mtetra
.20889 .53755 .21622 .49119 .22022 .48986 .21295 .53623 Mtetra
.21295 .53623 .22022 .48986 .22423 .48852 .21702 .53491 Mtetra
.21702 .53491 .22423 .48852 .22824 .48719 .22109 .53359 Mtetra
.22109 .53359 .22824 .48719 .23226 .48585 .22517 .53227 Mtetra
.22517 .53227 .23226 .48585 .23628 .48451 .22925 .53095 Mtetra
.22925 .53095 .23628 .48451 .24032 .48317 .23335 .52962 Mtetra
.997 .779 .434 r
.23335 .52962 .24032 .48317 .25231 .38816 .24968 .38562 Mtetra
.66 .746 .914 r
.24968 .38562 .25231 .38816 .25624 .38679 .25362 .38424 Mtetra
.25362 .38424 .25624 .38679 .26018 .38541 .25757 .38285 Mtetra
.25757 .38285 .26018 .38541 .26413 .38402 .26152 .38147 Mtetra
.26152 .38147 .26413 .38402 .26809 .38264 .26548 .38008 Mtetra
.26548 .38008 .26809 .38264 .27205 .38125 .26944 .37869 Mtetra
.26944 .37869 .27205 .38125 .27601 .37987 .27341 .3773 Mtetra
.27341 .3773 .27601 .37987 .27998 .37848 .27738 .37591 Mtetra
.27738 .37591 .27998 .37848 .28396 .37708 .28136 .37451 Mtetra
.28136 .37451 .28396 .37708 .28794 .37569 .28535 .37311 Mtetra
.28535 .37311 .28794 .37569 .29193 .37429 .28934 .37171 Mtetra
.28934 .37171 .29193 .37429 .29593 .3729 .29334 .37031 Mtetra
.29334 .37031 .29593 .3729 .29993 .3715 .29735 .3689 Mtetra
.29735 .3689 .29993 .3715 .30394 .37009 .30136 .3675 Mtetra
.30136 .3675 .30394 .37009 .30795 .36869 .30538 .36609 Mtetra
.30538 .36609 .30795 .36869 .31197 .36728 .3094 .36468 Mtetra
.3094 .36468 .31197 .36728 .316 .36587 .31343 .36326 Mtetra
.31343 .36326 .316 .36587 .32003 .36446 .31747 .36185 Mtetra
.31747 .36185 .32003 .36446 .32407 .36305 .32151 .36043 Mtetra
.32151 .36043 .32407 .36305 .32811 .36163 .32556 .35901 Mtetra
.32556 .35901 .32811 .36163 .33216 .36021 .32961 .35759 Mtetra
.32961 .35759 .33216 .36021 .33622 .35879 .33367 .35617 Mtetra
.33367 .35617 .33622 .35879 .34028 .35737 .33774 .35474 Mtetra
.33774 .35474 .34028 .35737 .34435 .35595 .34181 .35331 Mtetra
.34181 .35331 .34435 .35595 .34843 .35452 .34589 .35188 Mtetra
.953 .707 .527 r
.34589 .35188 .34843 .35452 .3555 .298 .35302 .29532 Mtetra
.664 .741 .908 r
.35302 .29532 .3555 .298 .35952 .29655 .35704 .29387 Mtetra
.35704 .29387 .35952 .29655 .36355 .2951 .36107 .29242 Mtetra
.36107 .29242 .36355 .2951 .36758 .29365 .36511 .29096 Mtetra
.36511 .29096 .36758 .29365 .37162 .2922 .36915 .28951 Mtetra
.36915 .28951 .37162 .2922 .37566 .29074 .37319 .28804 Mtetra
.37319 .28804 .37566 .29074 .37971 .28928 .37725 .28658 Mtetra
.37725 .28658 .37971 .28928 .38376 .28782 .38131 .28512 Mtetra
.38131 .28512 .38376 .28782 .38783 .28636 .38537 .28365 Mtetra
.38537 .28365 .38783 .28636 .3919 .28489 .38945 .28218 Mtetra
.38945 .28218 .3919 .28489 .39597 .28342 .39352 .28071 Mtetra
.39352 .28071 .39597 .28342 .40005 .28195 .39761 .27924 Mtetra
.39761 .27924 .40005 .28195 .40414 .28048 .4017 .27776 Mtetra
.4017 .27776 .40414 .28048 .40823 .27901 .4058 .27628 Mtetra
.4058 .27628 .40823 .27901 .41233 .27753 .4099 .2748 Mtetra
.4099 .2748 .41233 .27753 .41644 .27605 .41401 .27332 Mtetra
.41401 .27332 .41644 .27605 .42055 .27457 .41812 .27183 Mtetra
.41812 .27183 .42055 .27457 .42467 .27309 .42225 .27035 Mtetra
.42225 .27035 .42467 .27309 .42879 .2716 .42638 .26886 Mtetra
.956 .615 .309 r
.42638 .26886 .42879 .2716 .43292 .27012 .42975 .29232 Mtetra
.483 .212 .427 r
.42975 .29232 .43292 .27012 .43635 .29358 .43392 .29083 Mtetra
.662 .744 .911 r
.43392 .29083 .43635 .29358 .4412 .26713 .4381 .28934 Mtetra
0 0 .088 r
.4381 .28934 .4412 .26713 .44535 .26564 .44295 .26288 Mtetra
.664 .741 .908 r
.44295 .26288 .44535 .26564 .44951 .26414 .44711 .26137 Mtetra
.44711 .26137 .44951 .26414 .45367 .26264 .45128 .25987 Mtetra
.45128 .25987 .45367 .26264 .45784 .26114 .45545 .25837 Mtetra
.45545 .25837 .45784 .26114 .46201 .25964 .45963 .25686 Mtetra
.45963 .25686 .46201 .25964 .46619 .25813 .46382 .25535 Mtetra
.46382 .25535 .46619 .25813 .47038 .25663 .46801 .25383 Mtetra
.46801 .25383 .47038 .25663 .47458 .25511 .47221 .25232 Mtetra
.47221 .25232 .47458 .25511 .47878 .2536 .47641 .2508 Mtetra
.47641 .2508 .47878 .2536 .48299 .25209 .48062 .24928 Mtetra
.48062 .24928 .48299 .25209 .4872 .25057 .48484 .24776 Mtetra
.48484 .24776 .4872 .25057 .49142 .24905 .48907 .24624 Mtetra
.48907 .24624 .49142 .24905 .49565 .24753 .4933 .24471 Mtetra
.4933 .24471 .49565 .24753 .49988 .246 .49754 .24318 Mtetra
.49754 .24318 .49988 .246 .50412 .24447 .50178 .24165 Mtetra
.50178 .24165 .50412 .24447 .50837 .24294 .50603 .24012 Mtetra
.50603 .24012 .50837 .24294 .51262 .24141 .51029 .23858 Mtetra
.51029 .23858 .51262 .24141 .51688 .23988 .51455 .23704 Mtetra
.51455 .23704 .51688 .23988 .52115 .23834 .51883 .2355 Mtetra
.958 .617 .287 r
.51883 .2355 .52115 .23834 .52542 .2368 .52308 .26414 Mtetra
.492 .228 .443 r
.52308 .26414 .52542 .2368 .52975 .26544 .52741 .2626 Mtetra
.662 .744 .911 r
.52741 .2626 .52975 .26544 .53408 .2639 .53174 .26106 Mtetra
.53174 .26106 .53408 .2639 .53841 .26237 .53608 .25952 Mtetra
.53608 .25952 .53841 .26237 .54276 .26083 .54043 .25798 Mtetra
.54043 .25798 .54276 .26083 .54711 .25928 .54479 .25643 Mtetra
.54479 .25643 .54711 .25928 .55146 .25774 .54915 .25488 Mtetra
.54915 .25488 .55146 .25774 .55582 .25619 .55351 .25333 Mtetra
.55351 .25333 .55582 .25619 .56019 .25464 .55789 .25177 Mtetra
.55789 .25177 .56019 .25464 .56457 .25309 .56227 .25022 Mtetra
.56227 .25022 .56457 .25309 .56896 .25153 .56666 .24866 Mtetra
.56666 .24866 .56896 .25153 .57335 .24998 .57105 .24709 Mtetra
.57105 .24709 .57335 .24998 .57774 .24842 .57546 .24553 Mtetra
.57546 .24553 .57774 .24842 .58215 .24685 .57987 .24396 Mtetra
.57987 .24396 .58215 .24685 .58656 .24529 .58428 .24239 Mtetra
.58428 .24239 .58656 .24529 .59098 .24372 .58871 .24082 Mtetra
.58871 .24082 .59098 .24372 .5954 .24215 .59314 .23925 Mtetra
.59314 .23925 .5954 .24215 .59946 .22535 .59757 .23767 Mtetra
0 0 .068 r
.59757 .23767 .59946 .22535 .60388 .22377 .60163 .22085 Mtetra
.663 .743 .91 r
.60163 .22085 .60388 .22377 .60831 .22219 .60606 .21926 Mtetra
.60606 .21926 .60831 .22219 .61274 .22061 .6105 .21768 Mtetra
.6105 .21768 .61274 .22061 .61718 .21902 .61494 .21608 Mtetra
.61494 .21608 .61718 .21902 .62162 .21743 .61939 .21449 Mtetra
.61939 .21449 .62162 .21743 .62608 .21584 .62385 .21289 Mtetra
.62385 .21289 .62608 .21584 .63053 .21425 .62831 .2113 Mtetra
.973 .663 .346 r
.62831 .2113 .63053 .21425 .635 .21265 .63769 .34737 Mtetra
.519 .284 .498 r
.63769 .34737 .635 .21265 .64467 .34869 .64237 .34581 Mtetra
.652 .755 .925 r
.64237 .34581 .64467 .34869 .64936 .34713 .64707 .34424 Mtetra
.64707 .34424 .64936 .34713 .65406 .34557 .65177 .34268 Mtetra
.65177 .34268 .65406 .34557 .65877 .344 .65648 .34111 Mtetra
.65648 .34111 .65877 .344 .66348 .34243 .6612 .33953 Mtetra
.6612 .33953 .66348 .34243 .6682 .34086 .66592 .33796 Mtetra
.66592 .33796 .6682 .34086 .67293 .33929 .67066 .33638 Mtetra
.67066 .33638 .67293 .33929 .67766 .33772 .6754 .3348 Mtetra
.6754 .3348 .67766 .33772 .68241 .33614 .68015 .33322 Mtetra
.68015 .33322 .68241 .33614 .68716 .33456 .6849 .33163 Mtetra
.6849 .33163 .68716 .33456 .69192 .33297 .68967 .33004 Mtetra
.68967 .33004 .69192 .33297 .69669 .33139 .69444 .32845 Mtetra
.69444 .32845 .69669 .33139 .70146 .3298 .69923 .32686 Mtetra
.69923 .32686 .70146 .3298 .70625 .32821 .70402 .32526 Mtetra
.70402 .32526 .70625 .32821 .7117 .33778 .70881 .32367 Mtetra
.581 .43 .642 r
.70881 .32367 .7117 .33778 .71652 .33618 .71362 .32206 Mtetra
.183 .163 .6 r
.71362 .32206 .71652 .33618 .72134 .33459 .71912 .33163 Mtetra
.651 .757 .927 r
.71912 .33163 .72134 .33459 .72618 .33299 .72396 .33003 Mtetra
.72396 .33003 .72618 .33299 .73102 .33139 .72881 .32843 Mtetra
.72881 .32843 .73102 .33139 .73587 .32978 .73367 .32682 Mtetra
.73367 .32682 .73587 .32978 .74073 .32818 .73853 .3252 Mtetra
.73853 .3252 .74073 .32818 .7456 .32657 .7434 .32359 Mtetra
.7434 .32359 .7456 .32657 .75047 .32496 .74829 .32197 Mtetra
.74829 .32197 .75047 .32496 .75536 .32334 .75318 .32035 Mtetra
.75318 .32035 .75536 .32334 .76025 .32172 .75807 .31873 Mtetra
.75807 .31873 .76025 .32172 .76515 .3201 .76298 .31711 Mtetra
.76298 .31711 .76515 .3201 .77006 .31848 .7679 .31548 Mtetra
.7679 .31548 .77006 .31848 .77498 .31686 .77282 .31385 Mtetra
.77282 .31385 .77498 .31686 .7799 .31523 .77775 .31221 Mtetra
.77775 .31221 .7799 .31523 .78484 .3136 .78269 .31058 Mtetra
.78269 .31058 .78484 .3136 .78978 .31196 .78764 .30894 Mtetra
.78764 .30894 .78978 .31196 .79473 .31033 .7926 .3073 Mtetra
.653 .755 .925 r
.13248 .5073 .13529 .5097 .13917 .5084 .13636 .506 Mtetra
.13636 .506 .13917 .5084 .14305 .5071 .14025 .5047 Mtetra
.14025 .5047 .14305 .5071 .14694 .5058 .14414 .5034 Mtetra
.14414 .5034 .14694 .5058 .15083 .5045 .14804 .50209 Mtetra
.14804 .50209 .15083 .5045 .15474 .5032 .15194 .50078 Mtetra
.15194 .50078 .15474 .5032 .15864 .50189 .15586 .49947 Mtetra
.15586 .49947 .15864 .50189 .16256 .50058 .15977 .49816 Mtetra
.15977 .49816 .16256 .50058 .16648 .49927 .1637 .49685 Mtetra
.1637 .49685 .16648 .49927 .1704 .49796 .16762 .49553 Mtetra
.16762 .49553 .1704 .49796 .17433 .49665 .17156 .49421 Mtetra
.17156 .49421 .17433 .49665 .17827 .49533 .1755 .49289 Mtetra
.1755 .49289 .17827 .49533 .18222 .49401 .17945 .49157 Mtetra
.17945 .49157 .18222 .49401 .18617 .49269 .1834 .49025 Mtetra
.1834 .49025 .18617 .49269 .19012 .49137 .18736 .48892 Mtetra
.946 .665 .474 r
.18736 .48892 .19012 .49137 .19408 .49004 .18587 .54168 Mtetra
.508 .26 .474 r
.18587 .54168 .19408 .49004 .19805 .48872 .18991 .54037 Mtetra
.18991 .54037 .19805 .48872 .19675 .54148 .19395 .53906 Mtetra
.648 .76 .931 r
.19395 .53906 .19675 .54148 .20079 .54017 .19799 .53775 Mtetra
.19799 .53775 .20079 .54017 .20484 .53886 .20204 .53643 Mtetra
.20204 .53643 .20484 .53886 .20889 .53755 .2061 .53512 Mtetra
.2061 .53512 .20889 .53755 .21295 .53623 .21016 .5338 Mtetra
.21016 .5338 .21295 .53623 .21702 .53491 .21423 .53248 Mtetra
.21423 .53248 .21702 .53491 .22109 .53359 .21831 .53115 Mtetra
.21831 .53115 .22109 .53359 .22517 .53227 .22239 .52983 Mtetra
.22239 .52983 .22517 .53227 .22925 .53095 .22648 .5285 Mtetra
.22648 .5285 .22925 .53095 .23335 .52962 .23058 .52717 Mtetra
.946 .694 .524 r
.23058 .52717 .23335 .52962 .24968 .38562 .24705 .38307 Mtetra
.66 .746 .914 r
.24705 .38307 .24968 .38562 .25362 .38424 .251 .38168 Mtetra
.251 .38168 .25362 .38424 .25757 .38285 .25494 .38029 Mtetra
.25494 .38029 .25757 .38285 .26152 .38147 .2589 .3789 Mtetra
.2589 .3789 .26152 .38147 .26548 .38008 .26286 .37751 Mtetra
.26286 .37751 .26548 .38008 .26944 .37869 .26683 .37612 Mtetra
.26683 .37612 .26944 .37869 .27341 .3773 .2708 .37472 Mtetra
.2708 .37472 .27341 .3773 .27738 .37591 .27478 .37333 Mtetra
.27478 .37333 .27738 .37591 .28136 .37451 .27876 .37193 Mtetra
.27876 .37193 .28136 .37451 .28535 .37311 .28275 .37052 Mtetra
.28275 .37052 .28535 .37311 .28934 .37171 .28675 .36912 Mtetra
.28675 .36912 .28934 .37171 .29334 .37031 .29075 .36771 Mtetra
.29075 .36771 .29334 .37031 .29735 .3689 .29476 .36631 Mtetra
.29476 .36631 .29735 .3689 .30136 .3675 .29878 .36489 Mtetra
.29878 .36489 .30136 .3675 .30538 .36609 .3028 .36348 Mtetra
.3028 .36348 .30538 .36609 .3094 .36468 .30683 .36207 Mtetra
.30683 .36207 .3094 .36468 .31343 .36326 .31086 .36065 Mtetra
.31086 .36065 .31343 .36326 .31747 .36185 .3149 .35923 Mtetra
.3149 .35923 .31747 .36185 .32151 .36043 .31894 .35781 Mtetra
.31894 .35781 .32151 .36043 .32556 .35901 .323 .35639 Mtetra
.323 .35639 .32556 .35901 .32961 .35759 .32705 .35496 Mtetra
.32705 .35496 .32961 .35759 .33367 .35617 .33112 .35353 Mtetra
.33112 .35353 .33367 .35617 .33774 .35474 .33519 .3521 Mtetra
.33519 .3521 .33774 .35474 .34181 .35331 .33927 .35067 Mtetra
.33927 .35067 .34181 .35331 .34589 .35188 .34335 .34923 Mtetra
.953 .707 .527 r
.34335 .34923 .34589 .35188 .35302 .29532 .35053 .29264 Mtetra
.664 .741 .908 r
.35053 .29264 .35302 .29532 .35704 .29387 .35455 .29119 Mtetra
.35455 .29119 .35704 .29387 .36107 .29242 .35859 .28973 Mtetra
.35859 .28973 .36107 .29242 .36511 .29096 .36263 .28827 Mtetra
.36263 .28827 .36511 .29096 .36915 .28951 .36667 .28681 Mtetra
.36667 .28681 .36915 .28951 .37319 .28804 .37072 .28534 Mtetra
.37072 .28534 .37319 .28804 .37725 .28658 .37478 .28388 Mtetra
.37478 .28388 .37725 .28658 .38131 .28512 .37884 .28241 Mtetra
.37884 .28241 .38131 .28512 .38537 .28365 .38291 .28094 Mtetra
.38291 .28094 .38537 .28365 .38945 .28218 .38699 .27946 Mtetra
.38699 .27946 .38945 .28218 .39352 .28071 .39107 .27799 Mtetra
.39107 .27799 .39352 .28071 .39761 .27924 .39516 .27651 Mtetra
.39516 .27651 .39761 .27924 .4017 .27776 .39925 .27503 Mtetra
.39925 .27503 .4017 .27776 .4058 .27628 .40336 .27355 Mtetra
.40336 .27355 .4058 .27628 .4099 .2748 .40746 .27206 Mtetra
.40746 .27206 .4099 .2748 .41401 .27332 .41158 .27057 Mtetra
.41158 .27057 .41401 .27332 .41812 .27183 .4157 .26909 Mtetra
.4157 .26909 .41812 .27183 .42225 .27035 .41982 .26759 Mtetra
.956 .616 .311 r
.41982 .26759 .42225 .27035 .42638 .26886 .42314 .29106 Mtetra
.482 .211 .426 r
.42314 .29106 .42638 .26886 .42975 .29232 .42731 .28957 Mtetra
.662 .744 .911 r
.42731 .28957 .42975 .29232 .43392 .29083 .43149 .28808 Mtetra
.43149 .28808 .43392 .29083 .4381 .28934 .43567 .28659 Mtetra
.43567 .28659 .4381 .28934 .44295 .26288 .43986 .28509 Mtetra
0 0 .088 r
.43986 .28509 .44295 .26288 .44711 .26137 .44471 .2586 Mtetra
.664 .741 .908 r
.44471 .2586 .44711 .26137 .45128 .25987 .44888 .25709 Mtetra
.44888 .25709 .45128 .25987 .45545 .25837 .45306 .25558 Mtetra
.45306 .25558 .45545 .25837 .45963 .25686 .45724 .25407 Mtetra
.45724 .25407 .45963 .25686 .46382 .25535 .46143 .25255 Mtetra
.46143 .25255 .46382 .25535 .46801 .25383 .46563 .25104 Mtetra
.46563 .25104 .46801 .25383 .47221 .25232 .46983 .24952 Mtetra
.46983 .24952 .47221 .25232 .47641 .2508 .47404 .24799 Mtetra
.47404 .24799 .47641 .2508 .48062 .24928 .47826 .24647 Mtetra
.47826 .24647 .48062 .24928 .48484 .24776 .48248 .24494 Mtetra
.48248 .24494 .48484 .24776 .48907 .24624 .48671 .24342 Mtetra
.48671 .24342 .48907 .24624 .4933 .24471 .49094 .24188 Mtetra
.49094 .24188 .4933 .24471 .49754 .24318 .49519 .24035 Mtetra
.49519 .24035 .49754 .24318 .50178 .24165 .49943 .23882 Mtetra
.49943 .23882 .50178 .24165 .50603 .24012 .50369 .23728 Mtetra
.50369 .23728 .50603 .24012 .51029 .23858 .50795 .23574 Mtetra
.50795 .23574 .51029 .23858 .51455 .23704 .51222 .23419 Mtetra
.51222 .23419 .51455 .23704 .51883 .2355 .5165 .23265 Mtetra
.958 .617 .287 r
.5165 .23265 .51883 .2355 .52308 .26414 .52074 .2613 Mtetra
.662 .744 .911 r
.52074 .2613 .52308 .26414 .52741 .2626 .52507 .25976 Mtetra
.52507 .25976 .52741 .2626 .53174 .26106 .52941 .25821 Mtetra
.52941 .25821 .53174 .26106 .53608 .25952 .53375 .25667 Mtetra
.53375 .25667 .53608 .25952 .54043 .25798 .5381 .25512 Mtetra
.5381 .25512 .54043 .25798 .54479 .25643 .54246 .25357 Mtetra
.54246 .25357 .54479 .25643 .54915 .25488 .54683 .25201 Mtetra
.54683 .25201 .54915 .25488 .55351 .25333 .5512 .25046 Mtetra
.5512 .25046 .55351 .25333 .55789 .25177 .55558 .2489 Mtetra
.55558 .2489 .55789 .25177 .56227 .25022 .55996 .24734 Mtetra
.55996 .24734 .56227 .25022 .56666 .24866 .56436 .24577 Mtetra
.56436 .24577 .56666 .24866 .57105 .24709 .56876 .2442 Mtetra
.56876 .2442 .57105 .24709 .57546 .24553 .57316 .24264 Mtetra
.57316 .24264 .57546 .24553 .57987 .24396 .57758 .24106 Mtetra
.57758 .24106 .57987 .24396 .58428 .24239 .582 .23949 Mtetra
.582 .23949 .58428 .24239 .58871 .24082 .58643 .23791 Mtetra
.58643 .23791 .58871 .24082 .59314 .23925 .59086 .23634 Mtetra
.59086 .23634 .59314 .23925 .59757 .23767 .5953 .23475 Mtetra
.5953 .23475 .59757 .23767 .60163 .22085 .59975 .23317 Mtetra
.445 .14 .353 r
.59975 .23317 .60163 .22085 .60606 .21926 .60421 .23158 Mtetra
0 0 .071 r
.60421 .23158 .60606 .21926 .6105 .21768 .60825 .21474 Mtetra
.663 .743 .91 r
.60825 .21474 .6105 .21768 .61494 .21608 .6127 .21314 Mtetra
.6127 .21314 .61494 .21608 .61939 .21449 .61716 .21154 Mtetra
.61716 .21154 .61939 .21449 .62385 .21289 .62162 .20994 Mtetra
.973 .663 .349 r
.62162 .20994 .62385 .21289 .62831 .2113 .63069 .34605 Mtetra
.518 .283 .497 r
.63069 .34605 .62831 .2113 .63769 .34737 .63537 .34448 Mtetra
.652 .755 .925 r
.63537 .34448 .63769 .34737 .64237 .34581 .64006 .34292 Mtetra
.64006 .34292 .64237 .34581 .64707 .34424 .64476 .34135 Mtetra
.64476 .34135 .64707 .34424 .65177 .34268 .64947 .33978 Mtetra
.64947 .33978 .65177 .34268 .65648 .34111 .65418 .3382 Mtetra
.65418 .3382 .65648 .34111 .6612 .33953 .65891 .33662 Mtetra
.65891 .33662 .6612 .33953 .66592 .33796 .66364 .33504 Mtetra
.66364 .33504 .66592 .33796 .67066 .33638 .66838 .33346 Mtetra
.66838 .33346 .67066 .33638 .6754 .3348 .67313 .33188 Mtetra
.67313 .33188 .6754 .3348 .68015 .33322 .67788 .33029 Mtetra
.67788 .33029 .68015 .33322 .6849 .33163 .68264 .3287 Mtetra
.68264 .3287 .6849 .33163 .68967 .33004 .68741 .32711 Mtetra
.68741 .32711 .68967 .33004 .69444 .32845 .69219 .32551 Mtetra
.69219 .32551 .69444 .32845 .69923 .32686 .69698 .32391 Mtetra
.69698 .32391 .69923 .32686 .70402 .32526 .70178 .32231 Mtetra
.70178 .32231 .70402 .32526 .70881 .32367 .70658 .32071 Mtetra
.70658 .32071 .70881 .32367 .71362 .32206 .71139 .3191 Mtetra
.71139 .3191 .71362 .32206 .71912 .33163 .71621 .31749 Mtetra
.58 .43 .642 r
.71621 .31749 .71912 .33163 .72396 .33003 .72104 .31588 Mtetra
.184 .165 .601 r
.72104 .31588 .72396 .33003 .72881 .32843 .72659 .32545 Mtetra
.651 .757 .927 r
.72659 .32545 .72881 .32843 .73367 .32682 .73145 .32384 Mtetra
.73145 .32384 .73367 .32682 .73853 .3252 .73633 .32222 Mtetra
.73633 .32222 .73853 .3252 .7434 .32359 .7412 .3206 Mtetra
.7412 .3206 .7434 .32359 .74829 .32197 .74609 .31898 Mtetra
.74609 .31898 .74829 .32197 .75318 .32035 .75099 .31736 Mtetra
.75099 .31736 .75318 .32035 .75807 .31873 .75589 .31573 Mtetra
.75589 .31573 .75807 .31873 .76298 .31711 .7608 .3141 Mtetra
.7608 .3141 .76298 .31711 .7679 .31548 .76572 .31247 Mtetra
.76572 .31247 .7679 .31548 .77282 .31385 .77065 .31083 Mtetra
.77065 .31083 .77282 .31385 .77775 .31221 .77559 .30919 Mtetra
.77559 .30919 .77775 .31221 .78269 .31058 .78054 .30755 Mtetra
.78054 .30755 .78269 .31058 .78764 .30894 .78549 .3059 Mtetra
.78549 .3059 .78764 .30894 .7926 .3073 .79046 .30426 Mtetra
.653 .755 .925 r
.12966 .5049 .13248 .5073 .13636 .506 .13355 .5036 Mtetra
.13355 .5036 .13636 .506 .14025 .5047 .13744 .50229 Mtetra
.13744 .50229 .14025 .5047 .14414 .5034 .14133 .50098 Mtetra
.14133 .50098 .14414 .5034 .14804 .50209 .14524 .49967 Mtetra
.14524 .49967 .14804 .50209 .15194 .50078 .14915 .49836 Mtetra
.14915 .49836 .15194 .50078 .15586 .49947 .15306 .49705 Mtetra
.15306 .49705 .15586 .49947 .15977 .49816 .15698 .49573 Mtetra
.15698 .49573 .15977 .49816 .1637 .49685 .16091 .49442 Mtetra
.16091 .49442 .1637 .49685 .16762 .49553 .16484 .4931 Mtetra
.16484 .4931 .16762 .49553 .17156 .49421 .16878 .49178 Mtetra
.16878 .49178 .17156 .49421 .1755 .49289 .17272 .49045 Mtetra
.17272 .49045 .1755 .49289 .17945 .49157 .17667 .48913 Mtetra
.945 .665 .476 r
.17667 .48913 .17945 .49157 .1834 .49025 .175 .54189 Mtetra
.507 .259 .473 r
.175 .54189 .1834 .49025 .18736 .48892 .17903 .54058 Mtetra
.17903 .54058 .18736 .48892 .18587 .54168 .18306 .53927 Mtetra
.648 .76 .931 r
.18306 .53927 .18587 .54168 .18991 .54037 .18709 .53795 Mtetra
.18709 .53795 .18991 .54037 .19395 .53906 .19113 .53664 Mtetra
.19113 .53664 .19395 .53906 .19799 .53775 .19518 .53532 Mtetra
.19518 .53532 .19799 .53775 .20204 .53643 .19924 .534 Mtetra
.19924 .534 .20204 .53643 .2061 .53512 .2033 .53268 Mtetra
.2033 .53268 .2061 .53512 .21016 .5338 .20737 .53135 Mtetra
.20737 .53135 .21016 .5338 .21423 .53248 .21144 .53003 Mtetra
.21144 .53003 .21423 .53248 .21831 .53115 .21552 .5287 Mtetra
.21552 .5287 .21831 .53115 .22239 .52983 .21961 .52737 Mtetra
.21961 .52737 .22239 .52983 .22648 .5285 .2237 .52604 Mtetra
.2237 .52604 .22648 .5285 .23058 .52717 .2278 .52471 Mtetra
.2278 .52471 .23058 .52717 .24705 .38307 .2319 .52337 Mtetra
0 0 .111 r
.2319 .52337 .24705 .38307 .251 .38168 .24836 .37912 Mtetra
.66 .746 .914 r
.24836 .37912 .251 .38168 .25494 .38029 .25231 .37773 Mtetra
.25231 .37773 .25494 .38029 .2589 .3789 .25627 .37633 Mtetra
.25627 .37633 .2589 .3789 .26286 .37751 .26024 .37494 Mtetra
.26024 .37494 .26286 .37751 .26683 .37612 .26421 .37354 Mtetra
.26421 .37354 .26683 .37612 .2708 .37472 .26818 .37214 Mtetra
.26818 .37214 .2708 .37472 .27478 .37333 .27216 .37074 Mtetra
.27216 .37074 .27478 .37333 .27876 .37193 .27615 .36934 Mtetra
.27615 .36934 .27876 .37193 .28275 .37052 .28015 .36793 Mtetra
.28015 .36793 .28275 .37052 .28675 .36912 .28415 .36652 Mtetra
.28415 .36652 .28675 .36912 .29075 .36771 .28815 .36511 Mtetra
.28815 .36511 .29075 .36771 .29476 .36631 .29217 .3637 Mtetra
.29217 .3637 .29476 .36631 .29878 .36489 .29619 .36228 Mtetra
.29619 .36228 .29878 .36489 .3028 .36348 .30021 .36087 Mtetra
.30021 .36087 .3028 .36348 .30683 .36207 .30424 .35945 Mtetra
.30424 .35945 .30683 .36207 .31086 .36065 .30828 .35803 Mtetra
.30828 .35803 .31086 .36065 .3149 .35923 .31232 .3566 Mtetra
.31232 .3566 .3149 .35923 .31894 .35781 .31637 .35518 Mtetra
.31637 .35518 .31894 .35781 .323 .35639 .32043 .35375 Mtetra
.32043 .35375 .323 .35639 .32705 .35496 .32449 .35232 Mtetra
.32449 .35232 .32705 .35496 .33112 .35353 .32856 .35089 Mtetra
.32856 .35089 .33112 .35353 .33519 .3521 .33263 .34946 Mtetra
.33263 .34946 .33519 .3521 .33927 .35067 .33671 .34802 Mtetra
.33671 .34802 .33927 .35067 .34335 .34923 .3408 .34658 Mtetra
.953 .707 .527 r
.3408 .34658 .34335 .34923 .35053 .29264 .34803 .28995 Mtetra
.664 .741 .908 r
.34803 .28995 .35053 .29264 .35455 .29119 .35206 .28849 Mtetra
.35206 .28849 .35455 .29119 .35859 .28973 .3561 .28703 Mtetra
.3561 .28703 .35859 .28973 .36263 .28827 .36014 .28557 Mtetra
.36014 .28557 .36263 .28827 .36667 .28681 .36419 .2841 Mtetra
.36419 .2841 .36667 .28681 .37072 .28534 .36824 .28263 Mtetra
.36824 .28263 .37072 .28534 .37478 .28388 .3723 .28116 Mtetra
.3723 .28116 .37478 .28388 .37884 .28241 .37637 .27969 Mtetra
.37637 .27969 .37884 .28241 .38291 .28094 .38045 .27821 Mtetra
.38045 .27821 .38291 .28094 .38699 .27946 .38453 .27674 Mtetra
.38453 .27674 .38699 .27946 .39107 .27799 .38861 .27526 Mtetra
.38861 .27526 .39107 .27799 .39516 .27651 .3927 .27377 Mtetra
.3927 .27377 .39516 .27651 .39925 .27503 .3968 .27229 Mtetra
.3968 .27229 .39925 .27503 .40336 .27355 .40091 .2708 Mtetra
.40091 .2708 .40336 .27355 .40746 .27206 .40502 .26932 Mtetra
.40502 .26932 .40746 .27206 .41158 .27057 .40914 .26782 Mtetra
.40914 .26782 .41158 .27057 .4157 .26909 .41326 .26633 Mtetra
.956 .617 .314 r
.41326 .26633 .4157 .26909 .41982 .26759 .41652 .2898 Mtetra
.482 .21 .425 r
.41652 .2898 .41982 .26759 .42314 .29106 .42069 .28831 Mtetra
.662 .744 .911 r
.42069 .28831 .42314 .29106 .42731 .28957 .42486 .28682 Mtetra
.42486 .28682 .42731 .28957 .43149 .28808 .42905 .28532 Mtetra
.42905 .28532 .43149 .28808 .43567 .28659 .43324 .28382 Mtetra
.43324 .28382 .43567 .28659 .43986 .28509 .43743 .28232 Mtetra
.43743 .28232 .43986 .28509 .44471 .2586 .44163 .28082 Mtetra
0 0 .088 r
.44163 .28082 .44471 .2586 .44888 .25709 .44648 .2543 Mtetra
.664 .741 .908 r
.44648 .2543 .44888 .25709 .45306 .25558 .45066 .25279 Mtetra
.45066 .25279 .45306 .25558 .45724 .25407 .45485 .25127 Mtetra
.45485 .25127 .45724 .25407 .46143 .25255 .45904 .24975 Mtetra
.45904 .24975 .46143 .25255 .46563 .25104 .46324 .24823 Mtetra
.46324 .24823 .46563 .25104 .46983 .24952 .46745 .24671 Mtetra
.46745 .24671 .46983 .24952 .47404 .24799 .47166 .24518 Mtetra
.47166 .24518 .47404 .24799 .47826 .24647 .47588 .24365 Mtetra
.47588 .24365 .47826 .24647 .48248 .24494 .48011 .24212 Mtetra
.48011 .24212 .48248 .24494 .48671 .24342 .48434 .24059 Mtetra
.48434 .24059 .48671 .24342 .49094 .24188 .48858 .23905 Mtetra
.48858 .23905 .49094 .24188 .49519 .24035 .49283 .23751 Mtetra
.49283 .23751 .49519 .24035 .49943 .23882 .49708 .23597 Mtetra
.49708 .23597 .49943 .23882 .50369 .23728 .50134 .23443 Mtetra
.50134 .23443 .50369 .23728 .50795 .23574 .50561 .23289 Mtetra
.50561 .23289 .50795 .23574 .51222 .23419 .50988 .23134 Mtetra
.50988 .23134 .51222 .23419 .5165 .23265 .51416 .22979 Mtetra
.958 .617 .287 r
.51416 .22979 .5165 .23265 .52074 .2613 .51838 .25845 Mtetra
.662 .744 .911 r
.51838 .25845 .52074 .2613 .52507 .25976 .52272 .2569 Mtetra
.52272 .2569 .52507 .25976 .52941 .25821 .52706 .25536 Mtetra
.52706 .25536 .52941 .25821 .53375 .25667 .53141 .2538 Mtetra
.53141 .2538 .53375 .25667 .5381 .25512 .53576 .25225 Mtetra
.53576 .25225 .5381 .25512 .54246 .25357 .54013 .2507 Mtetra
.54013 .2507 .54246 .25357 .54683 .25201 .5445 .24914 Mtetra
.5445 .24914 .54683 .25201 .5512 .25046 .54887 .24758 Mtetra
.54887 .24758 .5512 .25046 .55558 .2489 .55326 .24601 Mtetra
.55326 .24601 .55558 .2489 .55996 .24734 .55765 .24445 Mtetra
.55765 .24445 .55996 .24734 .56436 .24577 .56205 .24288 Mtetra
.56205 .24288 .56436 .24577 .56876 .2442 .56645 .24131 Mtetra
.56645 .24131 .56876 .2442 .57316 .24264 .57086 .23973 Mtetra
.57086 .23973 .57316 .24264 .57758 .24106 .57528 .23816 Mtetra
.57528 .23816 .57758 .24106 .582 .23949 .57971 .23658 Mtetra
.57971 .23658 .582 .23949 .58643 .23791 .58414 .235 Mtetra
.58414 .235 .58643 .23791 .59086 .23634 .58858 .23341 Mtetra
.58858 .23341 .59086 .23634 .5953 .23475 .59303 .23183 Mtetra
.59303 .23183 .5953 .23475 .59975 .23317 .59748 .23024 Mtetra
.59748 .23024 .59975 .23317 .60421 .23158 .60194 .22865 Mtetra
.60194 .22865 .60421 .23158 .60825 .21474 .60641 .22705 Mtetra
.444 .138 .352 r
.60641 .22705 .60825 .21474 .6127 .21314 .61088 .22546 Mtetra
0 0 .074 r
.61088 .22546 .6127 .21314 .61716 .21154 .61491 .20858 Mtetra
.973 .664 .351 r
.61491 .20858 .61716 .21154 .62162 .20994 .62368 .34472 Mtetra
.518 .282 .497 r
.62368 .34472 .62162 .20994 .63069 .34605 .62836 .34316 Mtetra
.652 .755 .925 r
.62836 .34316 .63069 .34605 .63537 .34448 .63305 .34159 Mtetra
.63305 .34159 .63537 .34448 .64006 .34292 .63774 .34002 Mtetra
.63774 .34002 .64006 .34292 .64476 .34135 .64245 .33844 Mtetra
.64245 .33844 .64476 .34135 .64947 .33978 .64716 .33687 Mtetra
.64716 .33687 .64947 .33978 .65418 .3382 .65188 .33529 Mtetra
.65188 .33529 .65418 .3382 .65891 .33662 .65661 .33371 Mtetra
.65661 .33371 .65891 .33662 .66364 .33504 .66135 .33212 Mtetra
.66135 .33212 .66364 .33504 .66838 .33346 .66609 .33053 Mtetra
.66609 .33053 .66838 .33346 .67313 .33188 .67085 .32894 Mtetra
.67085 .32894 .67313 .33188 .67788 .33029 .67561 .32735 Mtetra
.67561 .32735 .67788 .33029 .68264 .3287 .68037 .32576 Mtetra
.68037 .32576 .68264 .3287 .68741 .32711 .68515 .32416 Mtetra
.68515 .32416 .68741 .32711 .69219 .32551 .68994 .32256 Mtetra
.68994 .32256 .69219 .32551 .69698 .32391 .69473 .32095 Mtetra
.69473 .32095 .69698 .32391 .70178 .32231 .69953 .31935 Mtetra
.69953 .31935 .70178 .32231 .70658 .32071 .70434 .31774 Mtetra
.70434 .31774 .70658 .32071 .71139 .3191 .70916 .31613 Mtetra
.70916 .31613 .71139 .3191 .71621 .31749 .71398 .31451 Mtetra
.71398 .31451 .71621 .31749 .72104 .31588 .71882 .3129 Mtetra
.71882 .3129 .72104 .31588 .72659 .32545 .72366 .31128 Mtetra
.58 .429 .641 r
.72366 .31128 .72659 .32545 .73145 .32384 .72851 .30965 Mtetra
.186 .166 .601 r
.72851 .30965 .73145 .32384 .73633 .32222 .73411 .31923 Mtetra
.651 .757 .927 r
.73411 .31923 .73633 .32222 .7412 .3206 .739 .31761 Mtetra
.739 .31761 .7412 .3206 .74609 .31898 .74389 .31598 Mtetra
.74389 .31598 .74609 .31898 .75099 .31736 .74879 .31435 Mtetra
.74879 .31435 .75099 .31736 .75589 .31573 .7537 .31272 Mtetra
.7537 .31272 .75589 .31573 .7608 .3141 .75862 .31108 Mtetra
.75862 .31108 .7608 .3141 .76572 .31247 .76355 .30944 Mtetra
.76355 .30944 .76572 .31247 .77065 .31083 .76848 .3078 Mtetra
.76848 .3078 .77065 .31083 .77559 .30919 .77343 .30616 Mtetra
.77343 .30616 .77559 .30919 .78054 .30755 .77838 .30451 Mtetra
.77838 .30451 .78054 .30755 .78549 .3059 .78334 .30286 Mtetra
.78334 .30286 .78549 .3059 .79046 .30426 .78831 .30121 Mtetra
.653 .755 .925 r
.12684 .50249 .12966 .5049 .13355 .5036 .13073 .50119 Mtetra
.13073 .50119 .13355 .5036 .13744 .50229 .13462 .49988 Mtetra
.13462 .49988 .13744 .50229 .14133 .50098 .13852 .49857 Mtetra
.13852 .49857 .14133 .50098 .14524 .49967 .14243 .49725 Mtetra
.14243 .49725 .14524 .49967 .14915 .49836 .14634 .49594 Mtetra
.14634 .49594 .14915 .49836 .15306 .49705 .15026 .49462 Mtetra
.15026 .49462 .15306 .49705 .15698 .49573 .15418 .4933 Mtetra
.15418 .4933 .15698 .49573 .16091 .49442 .15811 .49198 Mtetra
.15811 .49198 .16091 .49442 .16484 .4931 .16204 .49066 Mtetra
.16204 .49066 .16484 .4931 .16878 .49178 .16599 .48933 Mtetra
.944 .665 .478 r
.16599 .48933 .16878 .49178 .17272 .49045 .16414 .54209 Mtetra
.506 .258 .473 r
.16414 .54209 .17272 .49045 .17667 .48913 .16815 .54078 Mtetra
.16815 .54078 .17667 .48913 .175 .54189 .17217 .53947 Mtetra
.648 .76 .931 r
.17217 .53947 .175 .54189 .17903 .54058 .1762 .53815 Mtetra
.1762 .53815 .17903 .54058 .18306 .53927 .18023 .53684 Mtetra
.18023 .53684 .18306 .53927 .18709 .53795 .18427 .53552 Mtetra
.18427 .53552 .18709 .53795 .19113 .53664 .18831 .5342 Mtetra
.18831 .5342 .19113 .53664 .19518 .53532 .19237 .53288 Mtetra
.19237 .53288 .19518 .53532 .19924 .534 .19643 .53156 Mtetra
.19643 .53156 .19924 .534 .2033 .53268 .20049 .53023 Mtetra
.20049 .53023 .2033 .53268 .20737 .53135 .20456 .52891 Mtetra
.20456 .52891 .20737 .53135 .21144 .53003 .20864 .52758 Mtetra
.20864 .52758 .21144 .53003 .21552 .5287 .21272 .52624 Mtetra
.21272 .52624 .21552 .5287 .21961 .52737 .21681 .52491 Mtetra
.21681 .52491 .21961 .52737 .2237 .52604 .22091 .52358 Mtetra
.22091 .52358 .2237 .52604 .2278 .52471 .22501 .52224 Mtetra
.22501 .52224 .2278 .52471 .2319 .52337 .22912 .5209 Mtetra
.946 .694 .524 r
.22912 .5209 .2319 .52337 .24836 .37912 .24572 .37655 Mtetra
.66 .746 .914 r
.24572 .37655 .24836 .37912 .25231 .37773 .24967 .37515 Mtetra
.24967 .37515 .25231 .37773 .25627 .37633 .25364 .37376 Mtetra
.25364 .37376 .25627 .37633 .26024 .37494 .2576 .37236 Mtetra
.2576 .37236 .26024 .37494 .26421 .37354 .26158 .37096 Mtetra
.26158 .37096 .26421 .37354 .26818 .37214 .26556 .36955 Mtetra
.26556 .36955 .26818 .37214 .27216 .37074 .26954 .36815 Mtetra
.26954 .36815 .27216 .37074 .27615 .36934 .27354 .36674 Mtetra
.27354 .36674 .27615 .36934 .28015 .36793 .27753 .36533 Mtetra
.27753 .36533 .28015 .36793 .28415 .36652 .28154 .36392 Mtetra
.28154 .36392 .28415 .36652 .28815 .36511 .28555 .3625 Mtetra
.28555 .3625 .28815 .36511 .29217 .3637 .28956 .36109 Mtetra
.28956 .36109 .29217 .3637 .29619 .36228 .29359 .35967 Mtetra
.29359 .35967 .29619 .36228 .30021 .36087 .29761 .35825 Mtetra
.29761 .35825 .30021 .36087 .30424 .35945 .30165 .35682 Mtetra
.30165 .35682 .30424 .35945 .30828 .35803 .30569 .3554 Mtetra
.30569 .3554 .30828 .35803 .31232 .3566 .30974 .35397 Mtetra
.30974 .35397 .31232 .3566 .31637 .35518 .31379 .35254 Mtetra
.31379 .35254 .31637 .35518 .32043 .35375 .31785 .35111 Mtetra
.31785 .35111 .32043 .35375 .32449 .35232 .32192 .34968 Mtetra
.32192 .34968 .32449 .35232 .32856 .35089 .32599 .34824 Mtetra
.32599 .34824 .32856 .35089 .33263 .34946 .33007 .3468 Mtetra
.33007 .3468 .33263 .34946 .33671 .34802 .33415 .34536 Mtetra
.33415 .34536 .33671 .34802 .3408 .34658 .33824 .34392 Mtetra
.953 .707 .527 r
.33824 .34392 .3408 .34658 .34803 .28995 .34552 .28726 Mtetra
.664 .741 .908 r
.34552 .28726 .34803 .28995 .35206 .28849 .34956 .28579 Mtetra
.34956 .28579 .35206 .28849 .3561 .28703 .3536 .28433 Mtetra
.3536 .28433 .3561 .28703 .36014 .28557 .35765 .28286 Mtetra
.35765 .28286 .36014 .28557 .36419 .2841 .3617 .28139 Mtetra
.3617 .28139 .36419 .2841 .36824 .28263 .36576 .27992 Mtetra
.36576 .27992 .36824 .28263 .3723 .28116 .36982 .27844 Mtetra
.95 .599 .292 r
.36982 .27844 .3723 .28116 .37637 .27969 .37292 .29686 Mtetra
.467 .183 .397 r
.37292 .29686 .37637 .27969 .38045 .27821 .37703 .29539 Mtetra
.37703 .29539 .38045 .27821 .38453 .27674 .38114 .29391 Mtetra
.38114 .29391 .38453 .27674 .38861 .27526 .38525 .29243 Mtetra
.38525 .29243 .38861 .27526 .3927 .27377 .38937 .29095 Mtetra
.38937 .29095 .3927 .27377 .3968 .27229 .3935 .28947 Mtetra
.3935 .28947 .3968 .27229 .40091 .2708 .39764 .28798 Mtetra
.39764 .28798 .40091 .2708 .40502 .26932 .40178 .2865 Mtetra
.40178 .2865 .40502 .26932 .40914 .26782 .40593 .28501 Mtetra
.40593 .28501 .40914 .26782 .41326 .26633 .41008 .28351 Mtetra
.581 .284 .429 r
.41008 .28351 .41326 .26633 .41652 .2898 .41406 .28705 Mtetra
.662 .744 .911 r
.41406 .28705 .41652 .2898 .42069 .28831 .41823 .28555 Mtetra
.41823 .28555 .42069 .28831 .42486 .28682 .42241 .28406 Mtetra
.42241 .28406 .42486 .28682 .42905 .28532 .4266 .28256 Mtetra
.4266 .28256 .42905 .28532 .43324 .28382 .43079 .28105 Mtetra
.43079 .28105 .43324 .28382 .43743 .28232 .43499 .27955 Mtetra
.43499 .27955 .43743 .28232 .44163 .28082 .4392 .27804 Mtetra
.955 .729 .556 r
.4392 .27804 .44163 .28082 .44648 .2543 .44407 .2515 Mtetra
.664 .741 .908 r
.44407 .2515 .44648 .2543 .45066 .25279 .44825 .24998 Mtetra
.44825 .24998 .45066 .25279 .45485 .25127 .45244 .24846 Mtetra
.45244 .24846 .45485 .25127 .45904 .24975 .45664 .24694 Mtetra
.45664 .24694 .45904 .24975 .46324 .24823 .46085 .24541 Mtetra
.46085 .24541 .46324 .24823 .46745 .24671 .46506 .24389 Mtetra
.46506 .24389 .46745 .24671 .47166 .24518 .46928 .24236 Mtetra
.46928 .24236 .47166 .24518 .47588 .24365 .4735 .24082 Mtetra
.4735 .24082 .47588 .24365 .48011 .24212 .47773 .23929 Mtetra
.47773 .23929 .48011 .24212 .48434 .24059 .48197 .23775 Mtetra
.48197 .23775 .48434 .24059 .48858 .23905 .48621 .23621 Mtetra
.48621 .23621 .48858 .23905 .49283 .23751 .49046 .23467 Mtetra
.49046 .23467 .49283 .23751 .49708 .23597 .49472 .23312 Mtetra
.49472 .23312 .49708 .23597 .50134 .23443 .49898 .23158 Mtetra
.49898 .23158 .50134 .23443 .50561 .23289 .50325 .23003 Mtetra
.50325 .23003 .50561 .23289 .50988 .23134 .50753 .22848 Mtetra
.50753 .22848 .50988 .23134 .51416 .22979 .51182 .22692 Mtetra
.958 .617 .287 r
.51182 .22692 .51416 .22979 .51838 .25845 .51602 .25559 Mtetra
.662 .744 .911 r
.51602 .25559 .51838 .25845 .52272 .2569 .52036 .25404 Mtetra
.52036 .25404 .52272 .2569 .52706 .25536 .52471 .25249 Mtetra
.52471 .25249 .52706 .25536 .53141 .2538 .52906 .25093 Mtetra
.52906 .25093 .53141 .2538 .53576 .25225 .53342 .24938 Mtetra
.53342 .24938 .53576 .25225 .54013 .2507 .53779 .24782 Mtetra
.53779 .24782 .54013 .2507 .5445 .24914 .54216 .24625 Mtetra
.54216 .24625 .5445 .24914 .54887 .24758 .54654 .24469 Mtetra
.54654 .24469 .54887 .24758 .55326 .24601 .55093 .24312 Mtetra
.55093 .24312 .55326 .24601 .55765 .24445 .55533 .24155 Mtetra
.55533 .24155 .55765 .24445 .56205 .24288 .55973 .23998 Mtetra
.55973 .23998 .56205 .24288 .56645 .24131 .56414 .2384 Mtetra
.56414 .2384 .56645 .24131 .57086 .23973 .56855 .23682 Mtetra
.56855 .23682 .57086 .23973 .57528 .23816 .57298 .23524 Mtetra
.57298 .23524 .57528 .23816 .57971 .23658 .57741 .23366 Mtetra
.57741 .23366 .57971 .23658 .58414 .235 .58185 .23207 Mtetra
.58185 .23207 .58414 .235 .58858 .23341 .58629 .23048 Mtetra
.58629 .23048 .58858 .23341 .59303 .23183 .59074 .22889 Mtetra
.59074 .22889 .59303 .23183 .59748 .23024 .5952 .2273 Mtetra
.5952 .2273 .59748 .23024 .60194 .22865 .59967 .2257 Mtetra
.59967 .2257 .60194 .22865 .60641 .22705 .60414 .22411 Mtetra
.60414 .22411 .60641 .22705 .61088 .22546 .60862 .2225 Mtetra
.972 .662 .349 r
.60862 .2225 .61088 .22546 .61491 .20858 .61666 .3434 Mtetra
.517 .281 .496 r
.61666 .3434 .61491 .20858 .62368 .34472 .62134 .34183 Mtetra
.652 .755 .925 r
.62134 .34183 .62368 .34472 .62836 .34316 .62602 .34026 Mtetra
.62602 .34026 .62836 .34316 .63305 .34159 .63072 .33869 Mtetra
.63072 .33869 .63305 .34159 .63774 .34002 .63542 .33711 Mtetra
.63542 .33711 .63774 .34002 .64245 .33844 .64013 .33553 Mtetra
.64013 .33553 .64245 .33844 .64716 .33687 .64485 .33395 Mtetra
.64485 .33395 .64716 .33687 .65188 .33529 .64958 .33236 Mtetra
.64958 .33236 .65188 .33529 .65661 .33371 .65431 .33078 Mtetra
.65431 .33078 .65661 .33371 .66135 .33212 .65905 .32919 Mtetra
.65905 .32919 .66135 .33212 .66609 .33053 .6638 .3276 Mtetra
.6638 .3276 .66609 .33053 .67085 .32894 .66856 .326 Mtetra
.66856 .326 .67085 .32894 .67561 .32735 .67333 .3244 Mtetra
.67333 .3244 .67561 .32735 .68037 .32576 .6781 .3228 Mtetra
.6781 .3228 .68037 .32576 .68515 .32416 .68288 .3212 Mtetra
.68288 .3212 .68515 .32416 .68994 .32256 .68767 .31959 Mtetra
.68767 .31959 .68994 .32256 .69473 .32095 .69247 .31799 Mtetra
.69247 .31799 .69473 .32095 .69953 .31935 .69728 .31637 Mtetra
.69728 .31637 .69953 .31935 .70434 .31774 .70209 .31476 Mtetra
.70209 .31476 .70434 .31774 .70916 .31613 .70691 .31314 Mtetra
.70691 .31314 .70916 .31613 .71398 .31451 .71175 .31152 Mtetra
.71175 .31152 .71398 .31451 .71882 .3129 .71659 .3099 Mtetra
.71659 .3099 .71882 .3129 .72366 .31128 .72143 .30828 Mtetra
.72143 .30828 .72366 .31128 .72851 .30965 .72629 .30665 Mtetra
.72629 .30665 .72851 .30965 .73411 .31923 .73115 .30502 Mtetra
.58 .429 .641 r
.73115 .30502 .73411 .31923 .739 .31761 .73603 .30339 Mtetra
.187 .167 .602 r
.73603 .30339 .739 .31761 .74389 .31598 .74168 .31297 Mtetra
.651 .757 .927 r
.74168 .31297 .74389 .31598 .74879 .31435 .74659 .31133 Mtetra
.74659 .31133 .74879 .31435 .7537 .31272 .7515 .3097 Mtetra
.7515 .3097 .7537 .31272 .75862 .31108 .75643 .30805 Mtetra
.75643 .30805 .75862 .31108 .76355 .30944 .76136 .30641 Mtetra
.76136 .30641 .76355 .30944 .76848 .3078 .7663 .30476 Mtetra
.7663 .30476 .76848 .3078 .77343 .30616 .77125 .30312 Mtetra
.77125 .30312 .77343 .30616 .77838 .30451 .77621 .30146 Mtetra
.77621 .30146 .77838 .30451 .78334 .30286 .78118 .29981 Mtetra
.78118 .29981 .78334 .30286 .78831 .30121 .78615 .29815 Mtetra
.653 .755 .925 r
.12401 .50008 .12684 .50249 .13073 .50119 .1279 .49877 Mtetra
.1279 .49877 .13073 .50119 .13462 .49988 .13179 .49745 Mtetra
.13179 .49745 .13462 .49988 .13852 .49857 .1357 .49614 Mtetra
.1357 .49614 .13852 .49857 .14243 .49725 .13961 .49482 Mtetra
.13961 .49482 .14243 .49725 .14634 .49594 .14352 .4935 Mtetra
.14352 .4935 .14634 .49594 .15026 .49462 .14744 .49218 Mtetra
.14744 .49218 .15026 .49462 .15418 .4933 .15137 .49086 Mtetra
.15137 .49086 .15418 .4933 .15811 .49198 .1553 .48953 Mtetra
.944 .665 .48 r
.1553 .48953 .15811 .49198 .16204 .49066 .15327 .54229 Mtetra
.506 .257 .472 r
.15327 .54229 .16204 .49066 .16599 .48933 .15728 .54098 Mtetra
.15728 .54098 .16599 .48933 .16414 .54209 .16129 .53967 Mtetra
.648 .76 .931 r
.16129 .53967 .16414 .54209 .16815 .54078 .1653 .53836 Mtetra
.1653 .53836 .16815 .54078 .17217 .53947 .16933 .53704 Mtetra
.16933 .53704 .17217 .53947 .1762 .53815 .17336 .53573 Mtetra
.17336 .53573 .1762 .53815 .18023 .53684 .1774 .53441 Mtetra
.1774 .53441 .18023 .53684 .18427 .53552 .18144 .53309 Mtetra
.18144 .53309 .18427 .53552 .18831 .5342 .18549 .53176 Mtetra
.18549 .53176 .18831 .5342 .19237 .53288 .18954 .53044 Mtetra
.18954 .53044 .19237 .53288 .19643 .53156 .19361 .52911 Mtetra
.19361 .52911 .19643 .53156 .20049 .53023 .19767 .52778 Mtetra
.19767 .52778 .20049 .53023 .20456 .52891 .20175 .52645 Mtetra
.20175 .52645 .20456 .52891 .20864 .52758 .20583 .52512 Mtetra
.20583 .52512 .20864 .52758 .21272 .52624 .20992 .52378 Mtetra
.20992 .52378 .21272 .52624 .21681 .52491 .21401 .52244 Mtetra
.21401 .52244 .21681 .52491 .22091 .52358 .21811 .5211 Mtetra
.21811 .5211 .22091 .52358 .22501 .52224 .22222 .51976 Mtetra
.22222 .51976 .22501 .52224 .22912 .5209 .22633 .51842 Mtetra
.22633 .51842 .22912 .5209 .24572 .37655 .23045 .51707 Mtetra
0 0 .108 r
.23045 .51707 .24572 .37655 .24967 .37515 .24703 .37257 Mtetra
.66 .746 .914 r
.24703 .37257 .24967 .37515 .25364 .37376 .25099 .37117 Mtetra
.25099 .37117 .25364 .37376 .2576 .37236 .25496 .36977 Mtetra
.25496 .36977 .2576 .37236 .26158 .37096 .25894 .36836 Mtetra
.25894 .36836 .26158 .37096 .26556 .36955 .26293 .36696 Mtetra
.26293 .36696 .26556 .36955 .26954 .36815 .26692 .36555 Mtetra
.26692 .36555 .26954 .36815 .27354 .36674 .27091 .36413 Mtetra
.27091 .36413 .27354 .36674 .27753 .36533 .27491 .36272 Mtetra
.27491 .36272 .27753 .36533 .28154 .36392 .27892 .3613 Mtetra
.27892 .3613 .28154 .36392 .28555 .3625 .28293 .35989 Mtetra
.28293 .35989 .28555 .3625 .28956 .36109 .28695 .35847 Mtetra
.28695 .35847 .28956 .36109 .29359 .35967 .29098 .35704 Mtetra
.29098 .35704 .29359 .35967 .29761 .35825 .29501 .35562 Mtetra
.29501 .35562 .29761 .35825 .30165 .35682 .29905 .35419 Mtetra
.29905 .35419 .30165 .35682 .30569 .3554 .3031 .35276 Mtetra
.3031 .35276 .30569 .3554 .30974 .35397 .30715 .35133 Mtetra
.30715 .35133 .30974 .35397 .31379 .35254 .3112 .3499 Mtetra
.3112 .3499 .31379 .35254 .31785 .35111 .31527 .34846 Mtetra
.31527 .34846 .31785 .35111 .32192 .34968 .31934 .34702 Mtetra
.31934 .34702 .32192 .34968 .32599 .34824 .32341 .34558 Mtetra
.32341 .34558 .32599 .34824 .33007 .3468 .32749 .34414 Mtetra
.32749 .34414 .33007 .3468 .33415 .34536 .33158 .3427 Mtetra
.33158 .3427 .33415 .34536 .33824 .34392 .33568 .34125 Mtetra
.949 .715 .55 r
.33568 .34125 .33824 .34392 .34552 .28726 .34185 .30442 Mtetra
.466 .181 .396 r
.34185 .30442 .34552 .28726 .34956 .28579 .34591 .30296 Mtetra
.34591 .30296 .34956 .28579 .3536 .28433 .34998 .30149 Mtetra
.34998 .30149 .3536 .28433 .35765 .28286 .35406 .30003 Mtetra
.35406 .30003 .35765 .28286 .3617 .28139 .35814 .29856 Mtetra
.35814 .29856 .3617 .28139 .36576 .27992 .36223 .29709 Mtetra
.36223 .29709 .36576 .27992 .36982 .27844 .36632 .29561 Mtetra
.36632 .29561 .36982 .27844 .37292 .29686 .37042 .29414 Mtetra
.662 .743 .91 r
.37042 .29414 .37292 .29686 .37703 .29539 .37453 .29266 Mtetra
.37453 .29266 .37703 .29539 .38114 .29391 .37864 .29118 Mtetra
.37864 .29118 .38114 .29391 .38525 .29243 .38276 .2897 Mtetra
.38276 .2897 .38525 .29243 .38937 .29095 .38689 .28821 Mtetra
.38689 .28821 .38937 .29095 .3935 .28947 .39102 .28672 Mtetra
.39102 .28672 .3935 .28947 .39764 .28798 .39516 .28523 Mtetra
.39516 .28523 .39764 .28798 .40178 .2865 .3993 .28374 Mtetra
.3993 .28374 .40178 .2865 .40593 .28501 .40345 .28225 Mtetra
.40345 .28225 .40593 .28501 .41008 .28351 .40761 .28075 Mtetra
0 .106 .622 r
.40761 .28075 .41008 .28351 .41406 .28705 .41159 .28429 Mtetra
.662 .744 .911 r
.41159 .28429 .41406 .28705 .41823 .28555 .41577 .28279 Mtetra
.41577 .28279 .41823 .28555 .42241 .28406 .41995 .28128 Mtetra
.41995 .28128 .42241 .28406 .4266 .28256 .42414 .27978 Mtetra
.42414 .27978 .4266 .28256 .43079 .28105 .42834 .27827 Mtetra
.42834 .27827 .43079 .28105 .43499 .27955 .43254 .27677 Mtetra
.43254 .27677 .43499 .27955 .4392 .27804 .43675 .27525 Mtetra
.43675 .27525 .4392 .27804 .44407 .2515 .44097 .27374 Mtetra
0 0 .085 r
.44097 .27374 .44407 .2515 .44825 .24998 .44584 .24717 Mtetra
.664 .741 .908 r
.44584 .24717 .44825 .24998 .45244 .24846 .45003 .24565 Mtetra
.45003 .24565 .45244 .24846 .45664 .24694 .45424 .24412 Mtetra
.45424 .24412 .45664 .24694 .46085 .24541 .45845 .24259 Mtetra
.45845 .24259 .46085 .24541 .46506 .24389 .46266 .24106 Mtetra
.46266 .24106 .46506 .24389 .46928 .24236 .46688 .23952 Mtetra
.46688 .23952 .46928 .24236 .4735 .24082 .47111 .23799 Mtetra
.47111 .23799 .4735 .24082 .47773 .23929 .47535 .23645 Mtetra
.47535 .23645 .47773 .23929 .48197 .23775 .47959 .23491 Mtetra
.47959 .23491 .48197 .23775 .48621 .23621 .48384 .23336 Mtetra
.48384 .23336 .48621 .23621 .49046 .23467 .48809 .23182 Mtetra
.48809 .23182 .49046 .23467 .49472 .23312 .49235 .23027 Mtetra
.49235 .23027 .49472 .23312 .49898 .23158 .49662 .22871 Mtetra
.49662 .22871 .49898 .23158 .50325 .23003 .5009 .22716 Mtetra
.5009 .22716 .50325 .23003 .50753 .22848 .50518 .2256 Mtetra
.50518 .2256 .50753 .22848 .51182 .22692 .50947 .22405 Mtetra
.958 .617 .287 r
.50947 .22405 .51182 .22692 .51602 .25559 .51365 .25273 Mtetra
.662 .744 .911 r
.51365 .25273 .51602 .25559 .52036 .25404 .51799 .25117 Mtetra
.51799 .25117 .52036 .25404 .52471 .25249 .52235 .24962 Mtetra
.52235 .24962 .52471 .25249 .52906 .25093 .5267 .24806 Mtetra
.5267 .24806 .52906 .25093 .53342 .24938 .53107 .24649 Mtetra
.53107 .24649 .53342 .24938 .53779 .24782 .53544 .24493 Mtetra
.53544 .24493 .53779 .24782 .54216 .24625 .53982 .24336 Mtetra
.53982 .24336 .54216 .24625 .54654 .24469 .54421 .24179 Mtetra
.54421 .24179 .54654 .24469 .55093 .24312 .5486 .24022 Mtetra
.5486 .24022 .55093 .24312 .55533 .24155 .553 .23864 Mtetra
.553 .23864 .55533 .24155 .55973 .23998 .5574 .23706 Mtetra
.5574 .23706 .55973 .23998 .56414 .2384 .56182 .23548 Mtetra
.56182 .23548 .56414 .2384 .56855 .23682 .56624 .2339 Mtetra
.56624 .2339 .56855 .23682 .57298 .23524 .57067 .23232 Mtetra
.57067 .23232 .57298 .23524 .57741 .23366 .5751 .23073 Mtetra
.5751 .23073 .57741 .23366 .58185 .23207 .57955 .22914 Mtetra
.57955 .22914 .58185 .23207 .58629 .23048 .58399 .22755 Mtetra
.58399 .22755 .58629 .23048 .59074 .22889 .58845 .22595 Mtetra
.58845 .22595 .59074 .22889 .5952 .2273 .59291 .22435 Mtetra
.59291 .22435 .5952 .2273 .59967 .2257 .59739 .22275 Mtetra
.59739 .22275 .59967 .2257 .60414 .22411 .60186 .22115 Mtetra
.60186 .22115 .60414 .22411 .60862 .2225 .60635 .21954 Mtetra
.972 .662 .349 r
.60635 .21954 .60862 .2225 .61666 .3434 .61431 .3405 Mtetra
.652 .755 .925 r
.61431 .3405 .61666 .3434 .62134 .34183 .61899 .33893 Mtetra
.61899 .33893 .62134 .34183 .62602 .34026 .62368 .33735 Mtetra
.62368 .33735 .62602 .34026 .63072 .33869 .62838 .33577 Mtetra
.62838 .33577 .63072 .33869 .63542 .33711 .63309 .33419 Mtetra
.63309 .33419 .63542 .33711 .64013 .33553 .6378 .33261 Mtetra
.6378 .33261 .64013 .33553 .64485 .33395 .64253 .33102 Mtetra
.64253 .33102 .64485 .33395 .64958 .33236 .64726 .32943 Mtetra
.64726 .32943 .64958 .33236 .65431 .33078 .652 .32784 Mtetra
.652 .32784 .65431 .33078 .65905 .32919 .65675 .32625 Mtetra
.65675 .32625 .65905 .32919 .6638 .3276 .6615 .32465 Mtetra
.6615 .32465 .6638 .3276 .66856 .326 .66627 .32305 Mtetra
.66627 .32305 .66856 .326 .67333 .3244 .67104 .32145 Mtetra
.67104 .32145 .67333 .3244 .6781 .3228 .67582 .31984 Mtetra
.67582 .31984 .6781 .3228 .68288 .3212 .6806 .31823 Mtetra
.6806 .31823 .68288 .3212 .68767 .31959 .6854 .31662 Mtetra
.6854 .31662 .68767 .31959 .69247 .31799 .6902 .31501 Mtetra
.6902 .31501 .69247 .31799 .69728 .31637 .69502 .31339 Mtetra
.69502 .31339 .69728 .31637 .70209 .31476 .69984 .31177 Mtetra
.69984 .31177 .70209 .31476 .70691 .31314 .70467 .31015 Mtetra
.70467 .31015 .70691 .31314 .71175 .31152 .7095 .30853 Mtetra
.7095 .30853 .71175 .31152 .71659 .3099 .71435 .3069 Mtetra
.71435 .3069 .71659 .3099 .72143 .30828 .7192 .30527 Mtetra
.7192 .30527 .72143 .30828 .72629 .30665 .72406 .30364 Mtetra
.72406 .30364 .72629 .30665 .73115 .30502 .72893 .302 Mtetra
.72893 .302 .73115 .30502 .73603 .30339 .73381 .30036 Mtetra
.73381 .30036 .73603 .30339 .74168 .31297 .7387 .29872 Mtetra
.579 .429 .641 r
.7387 .29872 .74168 .31297 .74659 .31133 .74359 .29708 Mtetra
.189 .168 .602 r
.74359 .29708 .74659 .31133 .7515 .3097 .7493 .30666 Mtetra
.651 .757 .927 r
.7493 .30666 .7515 .3097 .75643 .30805 .75423 .30502 Mtetra
.75423 .30502 .75643 .30805 .76136 .30641 .75917 .30337 Mtetra
.75917 .30337 .76136 .30641 .7663 .30476 .76412 .30172 Mtetra
.76412 .30172 .7663 .30476 .77125 .30312 .76907 .30006 Mtetra
.76907 .30006 .77125 .30312 .77621 .30146 .77404 .29841 Mtetra
.77404 .29841 .77621 .30146 .78118 .29981 .77901 .29675 Mtetra
.77901 .29675 .78118 .29981 .78615 .29815 .78399 .29508 Mtetra
.653 .755 .925 r
.12117 .49766 .12401 .50008 .1279 .49877 .12506 .49634 Mtetra
.12506 .49634 .1279 .49877 .13179 .49745 .12896 .49503 Mtetra
.12896 .49503 .13179 .49745 .1357 .49614 .13287 .49371 Mtetra
.13287 .49371 .1357 .49614 .13961 .49482 .13678 .49239 Mtetra
.13678 .49239 .13961 .49482 .14352 .4935 .1407 .49106 Mtetra
.1407 .49106 .14352 .4935 .14744 .49218 .14462 .48974 Mtetra
.943 .665 .482 r
.14462 .48974 .14744 .49218 .15137 .49086 .14241 .54249 Mtetra
.505 .256 .471 r
.14241 .54249 .15137 .49086 .1553 .48953 .1464 .54118 Mtetra
.1464 .54118 .1553 .48953 .15327 .54229 .15041 .53987 Mtetra
.648 .76 .931 r
.15041 .53987 .15327 .54229 .15728 .54098 .15441 .53856 Mtetra
.15441 .53856 .15728 .54098 .16129 .53967 .15843 .53724 Mtetra
.15843 .53724 .16129 .53967 .1653 .53836 .16245 .53593 Mtetra
.16245 .53593 .1653 .53836 .16933 .53704 .16648 .53461 Mtetra
.16648 .53461 .16933 .53704 .17336 .53573 .17051 .53329 Mtetra
.17051 .53329 .17336 .53573 .1774 .53441 .17455 .53197 Mtetra
.17455 .53197 .1774 .53441 .18144 .53309 .1786 .53064 Mtetra
.1786 .53064 .18144 .53309 .18549 .53176 .18265 .52931 Mtetra
.18265 .52931 .18549 .53176 .18954 .53044 .18671 .52799 Mtetra
.18671 .52799 .18954 .53044 .19361 .52911 .19078 .52665 Mtetra
.19078 .52665 .19361 .52911 .19767 .52778 .19485 .52532 Mtetra
.19485 .52532 .19767 .52778 .20175 .52645 .19893 .52399 Mtetra
.19893 .52399 .20175 .52645 .20583 .52512 .20301 .52265 Mtetra
.20301 .52265 .20583 .52512 .20992 .52378 .2071 .52131 Mtetra
.2071 .52131 .20992 .52378 .21401 .52244 .2112 .51997 Mtetra
.2112 .51997 .21401 .52244 .21811 .5211 .21531 .51862 Mtetra
.21531 .51862 .21811 .5211 .22222 .51976 .21942 .51728 Mtetra
.21942 .51728 .22222 .51976 .22633 .51842 .22353 .51593 Mtetra
.22353 .51593 .22633 .51842 .23045 .51707 .22766 .51458 Mtetra
.947 .694 .523 r
.22766 .51458 .23045 .51707 .24703 .37257 .24437 .36998 Mtetra
.66 .746 .914 r
.24437 .36998 .24703 .37257 .25099 .37117 .24834 .36858 Mtetra
.24834 .36858 .25099 .37117 .25496 .36977 .25232 .36717 Mtetra
.25232 .36717 .25496 .36977 .25894 .36836 .2563 .36576 Mtetra
.2563 .36576 .25894 .36836 .26293 .36696 .26029 .36435 Mtetra
.26029 .36435 .26293 .36696 .26692 .36555 .26428 .36294 Mtetra
.26428 .36294 .26692 .36555 .27091 .36413 .26828 .36152 Mtetra
.26828 .36152 .27091 .36413 .27491 .36272 .27228 .3601 Mtetra
.27228 .3601 .27491 .36272 .27892 .3613 .2763 .35868 Mtetra
.2763 .35868 .27892 .3613 .28293 .35989 .28031 .35726 Mtetra
.28031 .35726 .28293 .35989 .28695 .35847 .28434 .35584 Mtetra
.28434 .35584 .28695 .35847 .29098 .35704 .28837 .35441 Mtetra
.28837 .35441 .29098 .35704 .29501 .35562 .2924 .35298 Mtetra
.2924 .35298 .29501 .35562 .29905 .35419 .29644 .35155 Mtetra
.29644 .35155 .29905 .35419 .3031 .35276 .30049 .35012 Mtetra
.30049 .35012 .3031 .35276 .30715 .35133 .30455 .34868 Mtetra
.30455 .34868 .30715 .35133 .3112 .3499 .30861 .34724 Mtetra
.30861 .34724 .3112 .3499 .31527 .34846 .31268 .3458 Mtetra
.31268 .3458 .31527 .34846 .31934 .34702 .31675 .34436 Mtetra
.31675 .34436 .31934 .34702 .32341 .34558 .32083 .34292 Mtetra
.32083 .34292 .32341 .34558 .32749 .34414 .32491 .34147 Mtetra
.32491 .34147 .32749 .34414 .33158 .3427 .32901 .34002 Mtetra
.32901 .34002 .33158 .3427 .33568 .34125 .33311 .33857 Mtetra
.949 .715 .55 r
.33311 .33857 .33568 .34125 .34185 .30442 .33931 .30172 Mtetra
.662 .743 .91 r
.33931 .30172 .34185 .30442 .34591 .30296 .34338 .30025 Mtetra
.34338 .30025 .34591 .30296 .34998 .30149 .34745 .29878 Mtetra
.34745 .29878 .34998 .30149 .35406 .30003 .35153 .29731 Mtetra
.35153 .29731 .35406 .30003 .35814 .29856 .35562 .29584 Mtetra
.35562 .29584 .35814 .29856 .36223 .29709 .35971 .29436 Mtetra
.35971 .29436 .36223 .29709 .36632 .29561 .36381 .29289 Mtetra
.36381 .29289 .36632 .29561 .37042 .29414 .36791 .29141 Mtetra
.36791 .29141 .37042 .29414 .37453 .29266 .37202 .28992 Mtetra
.37202 .28992 .37453 .29266 .37864 .29118 .37614 .28844 Mtetra
.37614 .28844 .37864 .29118 .38276 .2897 .38026 .28695 Mtetra
.38026 .28695 .38276 .2897 .38689 .28821 .38439 .28546 Mtetra
.38439 .28546 .38689 .28821 .39102 .28672 .38853 .28397 Mtetra
.38853 .28397 .39102 .28672 .39516 .28523 .39267 .28248 Mtetra
.39267 .28248 .39516 .28523 .3993 .28374 .39682 .28098 Mtetra
.39682 .28098 .3993 .28374 .40345 .28225 .40098 .27949 Mtetra
.40098 .27949 .40345 .28225 .40761 .28075 .40514 .27798 Mtetra
0 .106 .622 r
.40514 .27798 .40761 .28075 .41159 .28429 .40912 .28152 Mtetra
.662 .744 .911 r
.40912 .28152 .41159 .28429 .41577 .28279 .4133 .28001 Mtetra
.4133 .28001 .41577 .28279 .41995 .28128 .41749 .27851 Mtetra
.41749 .27851 .41995 .28128 .42414 .27978 .42168 .277 Mtetra
.42168 .277 .42414 .27978 .42834 .27827 .42588 .27549 Mtetra
.42588 .27549 .42834 .27827 .43254 .27677 .43009 .27397 Mtetra
.43009 .27397 .43254 .27677 .43675 .27525 .4343 .27246 Mtetra
.4343 .27246 .43675 .27525 .44097 .27374 .43853 .27094 Mtetra
.43853 .27094 .44097 .27374 .44584 .24717 .44275 .26942 Mtetra
0 0 .085 r
.44275 .26942 .44584 .24717 .45003 .24565 .44762 .24283 Mtetra
.664 .741 .908 r
.44762 .24283 .45003 .24565 .45424 .24412 .45182 .2413 Mtetra
.45182 .2413 .45424 .24412 .45845 .24259 .45604 .23976 Mtetra
.45604 .23976 .45845 .24259 .46266 .24106 .46026 .23822 Mtetra
.46026 .23822 .46266 .24106 .46688 .23952 .46448 .23668 Mtetra
.46448 .23668 .46688 .23952 .47111 .23799 .46872 .23514 Mtetra
.46872 .23514 .47111 .23799 .47535 .23645 .47296 .2336 Mtetra
.47296 .2336 .47535 .23645 .47959 .23491 .4772 .23205 Mtetra
.4772 .23205 .47959 .23491 .48384 .23336 .48145 .2305 Mtetra
.48145 .2305 .48384 .23336 .48809 .23182 .48571 .22895 Mtetra
.48571 .22895 .48809 .23182 .49235 .23027 .48998 .2274 Mtetra
.48998 .2274 .49235 .23027 .49662 .22871 .49425 .22584 Mtetra
.49425 .22584 .49662 .22871 .5009 .22716 .49853 .22429 Mtetra
.49853 .22429 .5009 .22716 .50518 .2256 .50282 .22272 Mtetra
.50282 .22272 .50518 .2256 .50947 .22405 .50711 .22116 Mtetra
.958 .617 .287 r
.50711 .22116 .50947 .22405 .51365 .25273 .51127 .24986 Mtetra
.662 .744 .911 r
.51127 .24986 .51365 .25273 .51799 .25117 .51562 .2483 Mtetra
.51562 .2483 .51799 .25117 .52235 .24962 .51998 .24673 Mtetra
.51998 .24673 .52235 .24962 .5267 .24806 .52434 .24517 Mtetra
.52434 .24517 .5267 .24806 .53107 .24649 .52871 .2436 Mtetra
.52871 .2436 .53107 .24649 .53544 .24493 .53309 .24203 Mtetra
.53309 .24203 .53544 .24493 .53982 .24336 .53747 .24046 Mtetra
.53747 .24046 .53982 .24336 .54421 .24179 .54186 .23888 Mtetra
.54186 .23888 .54421 .24179 .5486 .24022 .54626 .23731 Mtetra
.54626 .23731 .5486 .24022 .553 .23864 .55066 .23573 Mtetra
.55066 .23573 .553 .23864 .5574 .23706 .55507 .23415 Mtetra
.55507 .23415 .5574 .23706 .56182 .23548 .55949 .23256 Mtetra
.55949 .23256 .56182 .23548 .56624 .2339 .56392 .23097 Mtetra
.56392 .23097 .56624 .2339 .57067 .23232 .56835 .22938 Mtetra
.56835 .22938 .57067 .23232 .5751 .23073 .57279 .22779 Mtetra
.57279 .22779 .5751 .23073 .57955 .22914 .57724 .2262 Mtetra
.57724 .2262 .57955 .22914 .58399 .22755 .58169 .2246 Mtetra
.58169 .2246 .58399 .22755 .58845 .22595 .58615 .223 Mtetra
.58615 .223 .58845 .22595 .59291 .22435 .59062 .22139 Mtetra
.59062 .22139 .59291 .22435 .59739 .22275 .5951 .21979 Mtetra
.5951 .21979 .59739 .22275 .60186 .22115 .59958 .21818 Mtetra
.59958 .21818 .60186 .22115 .60635 .21954 .60407 .21657 Mtetra
.972 .662 .349 r
.60407 .21657 .60635 .21954 .61431 .3405 .61195 .33759 Mtetra
.652 .755 .925 r
.61195 .33759 .61431 .3405 .61899 .33893 .61664 .33602 Mtetra
.61664 .33602 .61899 .33893 .62368 .33735 .62133 .33444 Mtetra
.62133 .33444 .62368 .33735 .62838 .33577 .62604 .33285 Mtetra
.62604 .33285 .62838 .33577 .63309 .33419 .63075 .33127 Mtetra
.63075 .33127 .63309 .33419 .6378 .33261 .63547 .32968 Mtetra
.63547 .32968 .6378 .33261 .64253 .33102 .6402 .32809 Mtetra
.6402 .32809 .64253 .33102 .64726 .32943 .64494 .32649 Mtetra
.64494 .32649 .64726 .32943 .652 .32784 .64968 .3249 Mtetra
.64968 .3249 .652 .32784 .65675 .32625 .65444 .3233 Mtetra
.65444 .3233 .65675 .32625 .6615 .32465 .6592 .32169 Mtetra
.6592 .32169 .6615 .32465 .66627 .32305 .66397 .32009 Mtetra
.66397 .32009 .66627 .32305 .67104 .32145 .66874 .31848 Mtetra
.66874 .31848 .67104 .32145 .67582 .31984 .67353 .31687 Mtetra
.67353 .31687 .67582 .31984 .6806 .31823 .67832 .31526 Mtetra
.67832 .31526 .6806 .31823 .6854 .31662 .68312 .31364 Mtetra
.68312 .31364 .6854 .31662 .6902 .31501 .68793 .31202 Mtetra
.68793 .31202 .6902 .31501 .69502 .31339 .69275 .3104 Mtetra
.69275 .3104 .69502 .31339 .69984 .31177 .69758 .30878 Mtetra
.69758 .30878 .69984 .31177 .70467 .31015 .70241 .30715 Mtetra
.70241 .30715 .70467 .31015 .7095 .30853 .70725 .30552 Mtetra
.70725 .30552 .7095 .30853 .71435 .3069 .7121 .30389 Mtetra
.7121 .30389 .71435 .3069 .7192 .30527 .71696 .30225 Mtetra
.71696 .30225 .7192 .30527 .72406 .30364 .72183 .30062 Mtetra
.72183 .30062 .72406 .30364 .72893 .302 .72671 .29898 Mtetra
.72671 .29898 .72893 .302 .73381 .30036 .73159 .29733 Mtetra
.73159 .29733 .73381 .30036 .7387 .29872 .73648 .29569 Mtetra
.73648 .29569 .7387 .29872 .74359 .29708 .74138 .29404 Mtetra
.74138 .29404 .74359 .29708 .7493 .30666 .74629 .29238 Mtetra
.189 .168 .602 r
.74629 .29238 .7493 .30666 .75423 .30502 .75203 .30197 Mtetra
.651 .757 .927 r
.75203 .30197 .75423 .30502 .75917 .30337 .75697 .30032 Mtetra
.75697 .30032 .75917 .30337 .76412 .30172 .76192 .29866 Mtetra
.76192 .29866 .76412 .30172 .76907 .30006 .76689 .297 Mtetra
.76689 .297 .76907 .30006 .77404 .29841 .77186 .29534 Mtetra
.77186 .29534 .77404 .29841 .77901 .29675 .77684 .29367 Mtetra
.77684 .29367 .77901 .29675 .78399 .29508 .78182 .292 Mtetra
.653 .755 .925 r
.11832 .49523 .12117 .49766 .12506 .49634 .12222 .49391 Mtetra
.12222 .49391 .12506 .49634 .12896 .49503 .12612 .49259 Mtetra
.12612 .49259 .12896 .49503 .13287 .49371 .13003 .49127 Mtetra
.13003 .49127 .13287 .49371 .13678 .49239 .13395 .48994 Mtetra
.942 .665 .484 r
.13395 .48994 .13678 .49239 .1407 .49106 .13155 .54269 Mtetra
.504 .255 .47 r
.13155 .54269 .1407 .49106 .14462 .48974 .13553 .54138 Mtetra
.13553 .54138 .14462 .48974 .14241 .54249 .13953 .54007 Mtetra
.648 .76 .931 r
.13953 .54007 .14241 .54249 .1464 .54118 .14353 .53876 Mtetra
.14353 .53876 .1464 .54118 .15041 .53987 .14753 .53745 Mtetra
.14753 .53745 .15041 .53987 .15441 .53856 .15155 .53613 Mtetra
.15155 .53613 .15441 .53856 .15843 .53724 .15556 .53481 Mtetra
.15556 .53481 .15843 .53724 .16245 .53593 .15959 .53349 Mtetra
.15959 .53349 .16245 .53593 .16648 .53461 .16362 .53217 Mtetra
.16362 .53217 .16648 .53461 .17051 .53329 .16766 .53085 Mtetra
.16766 .53085 .17051 .53329 .17455 .53197 .1717 .52952 Mtetra
.1717 .52952 .17455 .53197 .1786 .53064 .17575 .52819 Mtetra
.17575 .52819 .1786 .53064 .18265 .52931 .17981 .52686 Mtetra
.17981 .52686 .18265 .52931 .18671 .52799 .18387 .52553 Mtetra
.18387 .52553 .18671 .52799 .19078 .52665 .18794 .52419 Mtetra
.18794 .52419 .19078 .52665 .19485 .52532 .19202 .52286 Mtetra
.19202 .52286 .19485 .52532 .19893 .52399 .1961 .52152 Mtetra
.1961 .52152 .19893 .52399 .20301 .52265 .20019 .52017 Mtetra
.20019 .52017 .20301 .52265 .2071 .52131 .20428 .51883 Mtetra
.20428 .51883 .2071 .52131 .2112 .51997 .20838 .51749 Mtetra
.20838 .51749 .2112 .51997 .21531 .51862 .21249 .51614 Mtetra
.21249 .51614 .21531 .51862 .21942 .51728 .21661 .51479 Mtetra
.21661 .51479 .21942 .51728 .22353 .51593 .22073 .51344 Mtetra
.22073 .51344 .22353 .51593 .22766 .51458 .22486 .51208 Mtetra
.22486 .51208 .22766 .51458 .24437 .36998 .22899 .51073 Mtetra
0 0 .105 r
.22899 .51073 .24437 .36998 .24834 .36858 .24569 .36598 Mtetra
.66 .746 .914 r
.24569 .36598 .24834 .36858 .25232 .36717 .24966 .36457 Mtetra
.24966 .36457 .25232 .36717 .2563 .36576 .25365 .36316 Mtetra
.25365 .36316 .2563 .36576 .26029 .36435 .25764 .36174 Mtetra
.25764 .36174 .26029 .36435 .26428 .36294 .26164 .36032 Mtetra
.26164 .36032 .26428 .36294 .26828 .36152 .26564 .3589 Mtetra
.26564 .3589 .26828 .36152 .27228 .3601 .26965 .35748 Mtetra
.26965 .35748 .27228 .3601 .2763 .35868 .27366 .35606 Mtetra
.27366 .35606 .2763 .35868 .28031 .35726 .27768 .35463 Mtetra
.27768 .35463 .28031 .35726 .28434 .35584 .28171 .3532 Mtetra
.28171 .3532 .28434 .35584 .28837 .35441 .28575 .35177 Mtetra
.28575 .35177 .28837 .35441 .2924 .35298 .28979 .35034 Mtetra
.28979 .35034 .2924 .35298 .29644 .35155 .29383 .3489 Mtetra
.29383 .3489 .29644 .35155 .30049 .35012 .29788 .34747 Mtetra
.29788 .34747 .30049 .35012 .30455 .34868 .30194 .34603 Mtetra
.30194 .34603 .30455 .34868 .30861 .34724 .30601 .34458 Mtetra
.30601 .34458 .30861 .34724 .31268 .3458 .31008 .34314 Mtetra
.31008 .34314 .31268 .3458 .31675 .34436 .31415 .34169 Mtetra
.31415 .34169 .31675 .34436 .32083 .34292 .31824 .34025 Mtetra
.31824 .34025 .32083 .34292 .32491 .34147 .32233 .3388 Mtetra
.32233 .3388 .32491 .34147 .32901 .34002 .32642 .33734 Mtetra
.949 .715 .551 r
.32642 .33734 .32901 .34002 .33311 .33857 .33271 .30048 Mtetra
.544 .342 .556 r
.33271 .30048 .33311 .33857 .33931 .30172 .33677 .29901 Mtetra
.662 .743 .91 r
.33677 .29901 .33931 .30172 .34338 .30025 .34084 .29754 Mtetra
.34084 .29754 .34338 .30025 .34745 .29878 .34492 .29607 Mtetra
.34492 .29607 .34745 .29878 .35153 .29731 .349 .29459 Mtetra
.349 .29459 .35153 .29731 .35562 .29584 .35309 .29311 Mtetra
.35309 .29311 .35562 .29584 .35971 .29436 .35719 .29163 Mtetra
.35719 .29163 .35971 .29436 .36381 .29289 .36129 .29015 Mtetra
.36129 .29015 .36381 .29289 .36791 .29141 .3654 .28867 Mtetra
.3654 .28867 .36791 .29141 .37202 .28992 .36951 .28718 Mtetra
.36951 .28718 .37202 .28992 .37614 .28844 .37363 .28569 Mtetra
.37363 .28569 .37614 .28844 .38026 .28695 .37776 .2842 Mtetra
.37776 .2842 .38026 .28695 .38439 .28546 .38189 .28271 Mtetra
.38189 .28271 .38439 .28546 .38853 .28397 .38603 .28121 Mtetra
.38603 .28121 .38853 .28397 .39267 .28248 .39018 .27972 Mtetra
.39018 .27972 .39267 .28248 .39682 .28098 .39433 .27822 Mtetra
.39433 .27822 .39682 .28098 .40098 .27949 .39849 .27671 Mtetra
.39849 .27671 .40098 .27949 .40514 .27798 .40266 .27521 Mtetra
0 .106 .622 r
.40266 .27521 .40514 .27798 .40912 .28152 .40664 .27874 Mtetra
.662 .744 .911 r
.40664 .27874 .40912 .28152 .4133 .28001 .41082 .27723 Mtetra
.41082 .27723 .4133 .28001 .41749 .27851 .41502 .27572 Mtetra
.41502 .27572 .41749 .27851 .42168 .277 .41921 .27421 Mtetra
.41921 .27421 .42168 .277 .42588 .27549 .42342 .27269 Mtetra
.42342 .27269 .42588 .27549 .43009 .27397 .42763 .27117 Mtetra
.42763 .27117 .43009 .27397 .4343 .27246 .43185 .26965 Mtetra
.43185 .26965 .4343 .27246 .43853 .27094 .43607 .26813 Mtetra
.43607 .26813 .43853 .27094 .44275 .26942 .4403 .26661 Mtetra
.4403 .26661 .44275 .26942 .44762 .24283 .44454 .26508 Mtetra
0 0 .085 r
.44454 .26508 .44762 .24283 .45182 .2413 .44941 .23846 Mtetra
.664 .741 .908 r
.44941 .23846 .45182 .2413 .45604 .23976 .45362 .23692 Mtetra
.45362 .23692 .45604 .23976 .46026 .23822 .45785 .23538 Mtetra
.45785 .23538 .46026 .23822 .46448 .23668 .46208 .23384 Mtetra
.46208 .23384 .46448 .23668 .46872 .23514 .46631 .23229 Mtetra
.46631 .23229 .46872 .23514 .47296 .2336 .47056 .23074 Mtetra
.47056 .23074 .47296 .2336 .4772 .23205 .47481 .22919 Mtetra
.47481 .22919 .4772 .23205 .48145 .2305 .47906 .22764 Mtetra
.47906 .22764 .48145 .2305 .48571 .22895 .48333 .22608 Mtetra
.48333 .22608 .48571 .22895 .48998 .2274 .4876 .22453 Mtetra
.4876 .22453 .48998 .2274 .49425 .22584 .49187 .22296 Mtetra
.49187 .22296 .49425 .22584 .49853 .22429 .49616 .2214 Mtetra
.49616 .2214 .49853 .22429 .50282 .22272 .50045 .21984 Mtetra
.50045 .21984 .50282 .22272 .50711 .22116 .50475 .21827 Mtetra
.958 .617 .287 r
.50475 .21827 .50711 .22116 .51127 .24986 .50889 .24697 Mtetra
.662 .744 .911 r
.50889 .24697 .51127 .24986 .51562 .2483 .51324 .24541 Mtetra
.51324 .24541 .51562 .2483 .51998 .24673 .5176 .24384 Mtetra
.5176 .24384 .51998 .24673 .52434 .24517 .52197 .24227 Mtetra
.52197 .24227 .52434 .24517 .52871 .2436 .52635 .2407 Mtetra
.52635 .2407 .52871 .2436 .53309 .24203 .53073 .23913 Mtetra
.53073 .23913 .53309 .24203 .53747 .24046 .53511 .23755 Mtetra
.53511 .23755 .53747 .24046 .54186 .23888 .53951 .23597 Mtetra
.53951 .23597 .54186 .23888 .54626 .23731 .54391 .23439 Mtetra
.54391 .23439 .54626 .23731 .55066 .23573 .54832 .2328 Mtetra
.54832 .2328 .55066 .23573 .55507 .23415 .55274 .23122 Mtetra
.55274 .23122 .55507 .23415 .55949 .23256 .55716 .22963 Mtetra
.55716 .22963 .55949 .23256 .56392 .23097 .56159 .22804 Mtetra
.56159 .22804 .56392 .23097 .56835 .22938 .56603 .22644 Mtetra
.56603 .22644 .56835 .22938 .57279 .22779 .57047 .22484 Mtetra
.57047 .22484 .57279 .22779 .57724 .2262 .57492 .22324 Mtetra
.57492 .22324 .57724 .2262 .58169 .2246 .57938 .22164 Mtetra
.57938 .22164 .58169 .2246 .58615 .223 .58385 .22004 Mtetra
.58385 .22004 .58615 .223 .59062 .22139 .58832 .21843 Mtetra
.58832 .21843 .59062 .22139 .5951 .21979 .5928 .21682 Mtetra
.5928 .21682 .5951 .21979 .59958 .21818 .59729 .21521 Mtetra
.59729 .21521 .59958 .21818 .60407 .21657 .60178 .21359 Mtetra
.972 .662 .349 r
.60178 .21359 .60407 .21657 .61195 .33759 .60958 .33468 Mtetra
.652 .755 .925 r
.60958 .33468 .61195 .33759 .61664 .33602 .61427 .3331 Mtetra
.61427 .3331 .61664 .33602 .62133 .33444 .61898 .33151 Mtetra
.61898 .33151 .62133 .33444 .62604 .33285 .62369 .32992 Mtetra
.62369 .32992 .62604 .33285 .63075 .33127 .6284 .32833 Mtetra
.6284 .32833 .63075 .33127 .63547 .32968 .63313 .32674 Mtetra
.63313 .32674 .63547 .32968 .6402 .32809 .63787 .32514 Mtetra
.63787 .32514 .6402 .32809 .64494 .32649 .64261 .32354 Mtetra
.64261 .32354 .64494 .32649 .64968 .3249 .64736 .32194 Mtetra
.64736 .32194 .64968 .3249 .65444 .3233 .65212 .32034 Mtetra
.65212 .32034 .65444 .3233 .6592 .32169 .65688 .31873 Mtetra
.65688 .31873 .6592 .32169 .66397 .32009 .66166 .31712 Mtetra
.66166 .31712 .66397 .32009 .66874 .31848 .66644 .31551 Mtetra
.66644 .31551 .66874 .31848 .67353 .31687 .67123 .31389 Mtetra
.67123 .31389 .67353 .31687 .67832 .31526 .67603 .31227 Mtetra
.67603 .31227 .67832 .31526 .68312 .31364 .68084 .31065 Mtetra
.68084 .31065 .68312 .31364 .68793 .31202 .68565 .30903 Mtetra
.68565 .30903 .68793 .31202 .69275 .3104 .69048 .3074 Mtetra
.69048 .3074 .69275 .3104 .69758 .30878 .69531 .30577 Mtetra
.69531 .30577 .69758 .30878 .70241 .30715 .70015 .30414 Mtetra
.70015 .30414 .70241 .30715 .70725 .30552 .70499 .30251 Mtetra
.70499 .30251 .70725 .30552 .7121 .30389 .70985 .30087 Mtetra
.70985 .30087 .7121 .30389 .71696 .30225 .71472 .29923 Mtetra
.71472 .29923 .71696 .30225 .72183 .30062 .71959 .29758 Mtetra
.71959 .29758 .72183 .30062 .72671 .29898 .72447 .29594 Mtetra
.72447 .29594 .72671 .29898 .73159 .29733 .72936 .29429 Mtetra
.72936 .29429 .73159 .29733 .73648 .29569 .73426 .29264 Mtetra
.73426 .29264 .73648 .29569 .74138 .29404 .73917 .29098 Mtetra
.73917 .29098 .74138 .29404 .74629 .29238 .74408 .28933 Mtetra
.74408 .28933 .74629 .29238 .75203 .30197 .749 .28767 Mtetra
.579 .428 .641 r
.749 .28767 .75203 .30197 .75697 .30032 .75394 .286 Mtetra
.19 .169 .603 r
.75394 .286 .75697 .30032 .76192 .29866 .75972 .29559 Mtetra
.651 .757 .927 r
.75972 .29559 .76192 .29866 .76689 .297 .76469 .29393 Mtetra
.76469 .29393 .76689 .297 .77186 .29534 .76967 .29226 Mtetra
.76967 .29226 .77186 .29534 .77684 .29367 .77465 .29059 Mtetra
.77465 .29059 .77684 .29367 .78182 .292 .77965 .28892 Mtetra
.653 .755 .925 r
.11546 .49279 .11832 .49523 .12222 .49391 .11936 .49147 Mtetra
.11936 .49147 .12222 .49391 .12612 .49259 .12327 .49015 Mtetra
.941 .665 .486 r
.12327 .49015 .12612 .49259 .13003 .49127 .12069 .54289 Mtetra
.503 .254 .469 r
.12069 .54289 .13003 .49127 .13395 .48994 .12467 .54158 Mtetra
.12467 .54158 .13395 .48994 .13155 .54269 .12865 .54027 Mtetra
.648 .76 .931 r
.12865 .54027 .13155 .54269 .13553 .54138 .13264 .53896 Mtetra
.13264 .53896 .13553 .54138 .13953 .54007 .13664 .53765 Mtetra
.13664 .53765 .13953 .54007 .14353 .53876 .14064 .53633 Mtetra
.14064 .53633 .14353 .53876 .14753 .53745 .14465 .53502 Mtetra
.14465 .53502 .14753 .53745 .15155 .53613 .14867 .5337 Mtetra
.14867 .5337 .15155 .53613 .15556 .53481 .15269 .53237 Mtetra
.15269 .53237 .15556 .53481 .15959 .53349 .15672 .53105 Mtetra
.15672 .53105 .15959 .53349 .16362 .53217 .16075 .52972 Mtetra
.16075 .52972 .16362 .53217 .16766 .53085 .16479 .52839 Mtetra
.16479 .52839 .16766 .53085 .1717 .52952 .16884 .52706 Mtetra
.16884 .52706 .1717 .52952 .17575 .52819 .1729 .52573 Mtetra
.1729 .52573 .17575 .52819 .17981 .52686 .17696 .5244 Mtetra
.17696 .5244 .17981 .52686 .18387 .52553 .18102 .52306 Mtetra
.18102 .52306 .18387 .52553 .18794 .52419 .1851 .52172 Mtetra
.1851 .52172 .18794 .52419 .19202 .52286 .18918 .52038 Mtetra
.18918 .52038 .19202 .52286 .1961 .52152 .19326 .51904 Mtetra
.19326 .51904 .1961 .52152 .20019 .52017 .19735 .51769 Mtetra
.19735 .51769 .20019 .52017 .20428 .51883 .20145 .51635 Mtetra
.20145 .51635 .20428 .51883 .20838 .51749 .20556 .515 Mtetra
.20556 .515 .20838 .51749 .21249 .51614 .20967 .51365 Mtetra
.20967 .51365 .21249 .51614 .21661 .51479 .21379 .51229 Mtetra
.21379 .51229 .21661 .51479 .22073 .51344 .21791 .51094 Mtetra
.21791 .51094 .22073 .51344 .22486 .51208 .22204 .50958 Mtetra
.22204 .50958 .22486 .51208 .22899 .51073 .22618 .50822 Mtetra
.22618 .50822 .22899 .51073 .24569 .36598 .23033 .50686 Mtetra
0 0 .105 r
.23033 .50686 .24569 .36598 .24966 .36457 .247 .36196 Mtetra
.66 .746 .914 r
.247 .36196 .24966 .36457 .25365 .36316 .25099 .36054 Mtetra
.25099 .36054 .25365 .36316 .25764 .36174 .25499 .35912 Mtetra
.25499 .35912 .25764 .36174 .26164 .36032 .25899 .3577 Mtetra
.25899 .3577 .26164 .36032 .26564 .3589 .26299 .35628 Mtetra
.26299 .35628 .26564 .3589 .26965 .35748 .26701 .35485 Mtetra
.26701 .35485 .26965 .35748 .27366 .35606 .27102 .35342 Mtetra
.27102 .35342 .27366 .35606 .27768 .35463 .27505 .35199 Mtetra
.27505 .35199 .27768 .35463 .28171 .3532 .27908 .35056 Mtetra
.27908 .35056 .28171 .3532 .28575 .35177 .28312 .34912 Mtetra
.28312 .34912 .28575 .35177 .28979 .35034 .28716 .34769 Mtetra
.28716 .34769 .28979 .35034 .29383 .3489 .29121 .34625 Mtetra
.29121 .34625 .29383 .3489 .29788 .34747 .29527 .34481 Mtetra
.29527 .34481 .29788 .34747 .30194 .34603 .29933 .34336 Mtetra
.29933 .34336 .30194 .34603 .30601 .34458 .3034 .34192 Mtetra
.3034 .34192 .30601 .34458 .31008 .34314 .30747 .34047 Mtetra
.30747 .34047 .31008 .34314 .31415 .34169 .31155 .33902 Mtetra
.31155 .33902 .31415 .34169 .31824 .34025 .31564 .33757 Mtetra
.31564 .33757 .31824 .34025 .32233 .3388 .31973 .33611 Mtetra
.31973 .33611 .32233 .3388 .32642 .33734 .32383 .33465 Mtetra
.949 .715 .551 r
.32383 .33465 .32642 .33734 .33271 .30048 .33015 .29776 Mtetra
.662 .743 .91 r
.33015 .29776 .33271 .30048 .33677 .29901 .33422 .29629 Mtetra
.33422 .29629 .33677 .29901 .34084 .29754 .33829 .29482 Mtetra
.33829 .29482 .34084 .29754 .34492 .29607 .34237 .29334 Mtetra
.34237 .29334 .34492 .29607 .349 .29459 .34646 .29186 Mtetra
.34646 .29186 .349 .29459 .35309 .29311 .35055 .29038 Mtetra
.35055 .29038 .35309 .29311 .35719 .29163 .35465 .2889 Mtetra
.35465 .2889 .35719 .29163 .36129 .29015 .35876 .28741 Mtetra
.35876 .28741 .36129 .29015 .3654 .28867 .36287 .28592 Mtetra
.36287 .28592 .3654 .28867 .36951 .28718 .36699 .28443 Mtetra
.36699 .28443 .36951 .28718 .37363 .28569 .37112 .28294 Mtetra
.37112 .28294 .37363 .28569 .37776 .2842 .37525 .28144 Mtetra
.37525 .28144 .37776 .2842 .38189 .28271 .37938 .27995 Mtetra
.37938 .27995 .38189 .28271 .38603 .28121 .38353 .27845 Mtetra
.38353 .27845 .38603 .28121 .39018 .27972 .38768 .27694 Mtetra
.38768 .27694 .39018 .27972 .39433 .27822 .39184 .27544 Mtetra
.39184 .27544 .39433 .27822 .39849 .27671 .396 .27393 Mtetra
.396 .27393 .39849 .27671 .40266 .27521 .40017 .27242 Mtetra
0 .106 .622 r
.40017 .27242 .40266 .27521 .40664 .27874 .40415 .27595 Mtetra
.662 .744 .911 r
.40415 .27595 .40664 .27874 .41082 .27723 .40834 .27444 Mtetra
.40834 .27444 .41082 .27723 .41502 .27572 .41254 .27292 Mtetra
.41254 .27292 .41502 .27572 .41921 .27421 .41674 .27141 Mtetra
.41674 .27141 .41921 .27421 .42342 .27269 .42095 .26989 Mtetra
.42095 .26989 .42342 .27269 .42763 .27117 .42516 .26837 Mtetra
.42516 .26837 .42763 .27117 .43185 .26965 .42938 .26684 Mtetra
.42938 .26684 .43185 .26965 .43607 .26813 .43361 .26532 Mtetra
.43361 .26532 .43607 .26813 .4403 .26661 .43785 .26379 Mtetra
.43785 .26379 .4403 .26661 .44454 .26508 .44209 .26226 Mtetra
.44209 .26226 .44454 .26508 .44941 .23846 .44634 .26072 Mtetra
0 0 .085 r
.44634 .26072 .44941 .23846 .45362 .23692 .4512 .23407 Mtetra
.664 .741 .908 r
.4512 .23407 .45362 .23692 .45785 .23538 .45543 .23253 Mtetra
.45543 .23253 .45785 .23538 .46208 .23384 .45966 .23098 Mtetra
.45966 .23098 .46208 .23384 .46631 .23229 .4639 .22943 Mtetra
.4639 .22943 .46631 .23229 .47056 .23074 .46815 .22788 Mtetra
.46815 .22788 .47056 .23074 .47481 .22919 .47241 .22632 Mtetra
.47241 .22632 .47481 .22919 .47906 .22764 .47667 .22476 Mtetra
.47667 .22476 .47906 .22764 .48333 .22608 .48094 .2232 Mtetra
.48094 .2232 .48333 .22608 .4876 .22453 .48521 .22164 Mtetra
.48521 .22164 .4876 .22453 .49187 .22296 .48949 .22008 Mtetra
.48949 .22008 .49187 .22296 .49616 .2214 .49378 .21851 Mtetra
.49378 .21851 .49616 .2214 .50045 .21984 .49807 .21694 Mtetra
.49807 .21694 .50045 .21984 .50475 .21827 .50237 .21537 Mtetra
.958 .617 .287 r
.50237 .21537 .50475 .21827 .50889 .24697 .5065 .24408 Mtetra
.662 .744 .911 r
.5065 .24408 .50889 .24697 .51324 .24541 .51086 .24252 Mtetra
.51086 .24252 .51324 .24541 .5176 .24384 .51522 .24094 Mtetra
.51522 .24094 .5176 .24384 .52197 .24227 .5196 .23937 Mtetra
.5196 .23937 .52197 .24227 .52635 .2407 .52397 .23779 Mtetra
.52397 .23779 .52635 .2407 .53073 .23913 .52836 .23621 Mtetra
.52836 .23621 .53073 .23913 .53511 .23755 .53275 .23463 Mtetra
.53275 .23463 .53511 .23755 .53951 .23597 .53715 .23305 Mtetra
.53715 .23305 .53951 .23597 .54391 .23439 .54156 .23146 Mtetra
.54156 .23146 .54391 .23439 .54832 .2328 .54597 .22987 Mtetra
.54597 .22987 .54832 .2328 .55274 .23122 .55039 .22828 Mtetra
.55039 .22828 .55274 .23122 .55716 .22963 .55482 .22669 Mtetra
.55482 .22669 .55716 .22963 .56159 .22804 .55926 .22509 Mtetra
.55926 .22509 .56159 .22804 .56603 .22644 .5637 .22349 Mtetra
.5637 .22349 .56603 .22644 .57047 .22484 .56815 .22189 Mtetra
.56815 .22189 .57047 .22484 .57492 .22324 .5726 .22028 Mtetra
.5726 .22028 .57492 .22324 .57938 .22164 .57707 .21868 Mtetra
.57707 .21868 .57938 .22164 .58385 .22004 .58154 .21707 Mtetra
.58154 .21707 .58385 .22004 .58832 .21843 .58602 .21545 Mtetra
.58602 .21545 .58832 .21843 .5928 .21682 .5905 .21384 Mtetra
.5905 .21384 .5928 .21682 .59729 .21521 .59499 .21222 Mtetra
.59499 .21222 .59729 .21521 .60178 .21359 .59949 .2106 Mtetra
.972 .662 .349 r
.59949 .2106 .60178 .21359 .60958 .33468 .6072 .33175 Mtetra
.652 .755 .925 r
.6072 .33175 .60958 .33468 .61427 .3331 .6119 .33017 Mtetra
.6119 .33017 .61427 .3331 .61898 .33151 .61661 .32858 Mtetra
.61661 .32858 .61898 .33151 .62369 .32992 .62133 .32698 Mtetra
.62133 .32698 .62369 .32992 .6284 .32833 .62605 .32539 Mtetra
.62605 .32539 .6284 .32833 .63313 .32674 .63078 .32379 Mtetra
.63078 .32379 .63313 .32674 .63787 .32514 .63552 .32219 Mtetra
.63552 .32219 .63787 .32514 .64261 .32354 .64027 .32058 Mtetra
.64027 .32058 .64261 .32354 .64736 .32194 .64503 .31898 Mtetra
.64503 .31898 .64736 .32194 .65212 .32034 .64979 .31737 Mtetra
.64979 .31737 .65212 .32034 .65688 .31873 .65456 .31575 Mtetra
.65456 .31575 .65688 .31873 .66166 .31712 .65934 .31414 Mtetra
.65934 .31414 .66166 .31712 .66644 .31551 .66413 .31252 Mtetra
.66413 .31252 .66644 .31551 .67123 .31389 .66893 .3109 Mtetra
.66893 .3109 .67123 .31389 .67603 .31227 .67373 .30928 Mtetra
.67373 .30928 .67603 .31227 .68084 .31065 .67854 .30765 Mtetra
.67854 .30765 .68084 .31065 .68565 .30903 .68336 .30602 Mtetra
.68336 .30602 .68565 .30903 .69048 .3074 .68819 .30439 Mtetra
.68819 .30439 .69048 .3074 .69531 .30577 .69303 .30276 Mtetra
.69303 .30276 .69531 .30577 .70015 .30414 .69788 .30112 Mtetra
.69788 .30112 .70015 .30414 .70499 .30251 .70273 .29948 Mtetra
.70273 .29948 .70499 .30251 .70985 .30087 .70759 .29784 Mtetra
.70759 .29784 .70985 .30087 .71472 .29923 .71246 .29619 Mtetra
.71246 .29619 .71472 .29923 .71959 .29758 .71734 .29454 Mtetra
.71734 .29454 .71959 .29758 .72447 .29594 .72223 .29289 Mtetra
.72223 .29289 .72447 .29594 .72936 .29429 .72713 .29124 Mtetra
.72713 .29124 .72936 .29429 .73426 .29264 .73203 .28958 Mtetra
.73203 .28958 .73426 .29264 .73917 .29098 .73694 .28792 Mtetra
.73694 .28792 .73917 .29098 .74408 .28933 .74186 .28626 Mtetra
.74186 .28626 .74408 .28933 .749 .28767 .74679 .28459 Mtetra
.74679 .28459 .749 .28767 .75394 .286 .75173 .28293 Mtetra
.75173 .28293 .75394 .286 .75972 .29559 .75668 .28125 Mtetra
.578 .428 .64 r
.75668 .28125 .75972 .29559 .76469 .29393 .76163 .27958 Mtetra
.192 .171 .603 r
.76163 .27958 .76469 .29393 .76967 .29226 .76747 .28917 Mtetra
.651 .757 .927 r
.76747 .28917 .76967 .29226 .77465 .29059 .77247 .2875 Mtetra
.77247 .2875 .77465 .29059 .77965 .28892 .77747 .28582 Mtetra
.941 .665 .488 r
.1126 .49035 .11546 .49279 .11936 .49147 .10983 .54309 Mtetra
.503 .253 .468 r
.10983 .54309 .11936 .49147 .12327 .49015 .1138 .54179 Mtetra
.1138 .54179 .12327 .49015 .12069 .54289 .11778 .54048 Mtetra
.648 .76 .931 r
.11778 .54048 .12069 .54289 .12467 .54158 .12176 .53916 Mtetra
.12176 .53916 .12467 .54158 .12865 .54027 .12575 .53785 Mtetra
.12575 .53785 .12865 .54027 .13264 .53896 .12974 .53654 Mtetra
.12974 .53654 .13264 .53896 .13664 .53765 .13374 .53522 Mtetra
.13374 .53522 .13664 .53765 .14064 .53633 .13775 .5339 Mtetra
.13775 .5339 .14064 .53633 .14465 .53502 .14176 .53258 Mtetra
.14176 .53258 .14465 .53502 .14867 .5337 .14578 .53125 Mtetra
.14578 .53125 .14867 .5337 .15269 .53237 .14981 .52993 Mtetra
.14981 .52993 .15269 .53237 .15672 .53105 .15384 .5286 Mtetra
.15384 .5286 .15672 .53105 .16075 .52972 .15788 .52727 Mtetra
.15788 .52727 .16075 .52972 .16479 .52839 .16192 .52594 Mtetra
.16192 .52594 .16479 .52839 .16884 .52706 .16597 .5246 Mtetra
.16597 .5246 .16884 .52706 .1729 .52573 .17003 .52327 Mtetra
.17003 .52327 .1729 .52573 .17696 .5244 .1741 .52193 Mtetra
.1741 .52193 .17696 .5244 .18102 .52306 .17817 .52059 Mtetra
.17817 .52059 .18102 .52306 .1851 .52172 .18224 .51925 Mtetra
.18224 .51925 .1851 .52172 .18918 .52038 .18633 .5179 Mtetra
.18633 .5179 .18918 .52038 .19326 .51904 .19042 .51655 Mtetra
.19042 .51655 .19326 .51904 .19735 .51769 .19451 .5152 Mtetra
.19451 .5152 .19735 .51769 .20145 .51635 .19861 .51385 Mtetra
.19861 .51385 .20145 .51635 .20556 .515 .20272 .5125 Mtetra
.20272 .5125 .20556 .515 .20967 .51365 .20684 .51114 Mtetra
.20684 .51114 .20967 .51365 .21379 .51229 .21096 .50979 Mtetra
.21096 .50979 .21379 .51229 .21791 .51094 .21509 .50843 Mtetra
.21509 .50843 .21791 .51094 .22204 .50958 .21923 .50707 Mtetra
.21923 .50707 .22204 .50958 .22618 .50822 .22337 .5057 Mtetra
.22337 .5057 .22618 .50822 .23033 .50686 .22752 .50433 Mtetra
.947 .694 .521 r
.22752 .50433 .23033 .50686 .247 .36196 .24434 .35934 Mtetra
.66 .746 .914 r
.24434 .35934 .247 .36196 .25099 .36054 .24833 .35792 Mtetra
.24833 .35792 .25099 .36054 .25499 .35912 .25232 .35649 Mtetra
.25232 .35649 .25499 .35912 .25899 .3577 .25633 .35507 Mtetra
.25633 .35507 .25899 .3577 .26299 .35628 .26034 .35364 Mtetra
.26034 .35364 .26299 .35628 .26701 .35485 .26435 .35221 Mtetra
.26435 .35221 .26701 .35485 .27102 .35342 .26838 .35078 Mtetra
.26838 .35078 .27102 .35342 .27505 .35199 .27241 .34934 Mtetra
.27241 .34934 .27505 .35199 .27908 .35056 .27644 .34791 Mtetra
.27644 .34791 .27908 .35056 .28312 .34912 .28048 .34647 Mtetra
.28048 .34647 .28312 .34912 .28716 .34769 .28453 .34503 Mtetra
.28453 .34503 .28716 .34769 .29121 .34625 .28858 .34359 Mtetra
.28858 .34359 .29121 .34625 .29527 .34481 .29264 .34214 Mtetra
.29264 .34214 .29527 .34481 .29933 .34336 .29671 .34069 Mtetra
.29671 .34069 .29933 .34336 .3034 .34192 .30078 .33924 Mtetra
.30078 .33924 .3034 .34192 .30747 .34047 .30486 .33779 Mtetra
.30486 .33779 .30747 .34047 .31155 .33902 .30894 .33634 Mtetra
.958 .664 .435 r
.30894 .33634 .31155 .33902 .31564 .33757 .30919 .39219 Mtetra
.503 .255 .471 r
.30919 .39219 .31564 .33757 .31973 .33611 .31336 .39075 Mtetra
.31336 .39075 .31973 .33611 .32383 .33465 .31753 .38931 Mtetra
.31753 .38931 .32383 .33465 .33015 .29776 .32172 .38786 Mtetra
0 0 .145 r
.32172 .38786 .33015 .29776 .33422 .29629 .33166 .29357 Mtetra
.662 .743 .91 r
.33166 .29357 .33422 .29629 .33829 .29482 .33574 .29209 Mtetra
.33574 .29209 .33829 .29482 .34237 .29334 .33982 .29061 Mtetra
.33982 .29061 .34237 .29334 .34646 .29186 .34391 .28913 Mtetra
.34391 .28913 .34646 .29186 .35055 .29038 .34801 .28764 Mtetra
.34801 .28764 .35055 .29038 .35465 .2889 .35212 .28615 Mtetra
.35212 .28615 .35465 .2889 .35876 .28741 .35623 .28466 Mtetra
.35623 .28466 .35876 .28741 .36287 .28592 .36034 .28317 Mtetra
.36034 .28317 .36287 .28592 .36699 .28443 .36446 .28167 Mtetra
.36446 .28167 .36699 .28443 .37112 .28294 .36859 .28018 Mtetra
.36859 .28018 .37112 .28294 .37525 .28144 .37273 .27868 Mtetra
.37273 .27868 .37525 .28144 .37938 .27995 .37687 .27718 Mtetra
.37687 .27718 .37938 .27995 .38353 .27845 .38102 .27567 Mtetra
.38102 .27567 .38353 .27845 .38768 .27694 .38517 .27417 Mtetra
.38517 .27417 .38768 .27694 .39184 .27544 .38933 .27266 Mtetra
.38933 .27266 .39184 .27544 .396 .27393 .3935 .27115 Mtetra
.3935 .27115 .396 .27393 .40017 .27242 .39767 .26963 Mtetra
0 .106 .622 r
.39767 .26963 .40017 .27242 .40415 .27595 .40165 .27316 Mtetra
.662 .744 .911 r
.40165 .27316 .40415 .27595 .40834 .27444 .40585 .27164 Mtetra
.40585 .27164 .40834 .27444 .41254 .27292 .41005 .27012 Mtetra
.41005 .27012 .41254 .27292 .41674 .27141 .41425 .2686 Mtetra
.41425 .2686 .41674 .27141 .42095 .26989 .41847 .26708 Mtetra
.41847 .26708 .42095 .26989 .42516 .26837 .42269 .26555 Mtetra
.42269 .26555 .42516 .26837 .42938 .26684 .42691 .26402 Mtetra
.42691 .26402 .42938 .26684 .43361 .26532 .43115 .26249 Mtetra
.43115 .26249 .43361 .26532 .43785 .26379 .43539 .26096 Mtetra
.43539 .26096 .43785 .26379 .44209 .26226 .43963 .25942 Mtetra
.43963 .25942 .44209 .26226 .44634 .26072 .44389 .25788 Mtetra
.44389 .25788 .44634 .26072 .4512 .23407 .44815 .25634 Mtetra
0 0 .085 r
.44815 .25634 .4512 .23407 .45543 .23253 .453 .22967 Mtetra
.664 .741 .908 r
.453 .22967 .45543 .23253 .45966 .23098 .45724 .22812 Mtetra
.45724 .22812 .45966 .23098 .4639 .22943 .46149 .22656 Mtetra
.46149 .22656 .4639 .22943 .46815 .22788 .46574 .225 Mtetra
.46574 .225 .46815 .22788 .47241 .22632 .47 .22344 Mtetra
.47 .22344 .47241 .22632 .47667 .22476 .47426 .22188 Mtetra
.47426 .22188 .47667 .22476 .48094 .2232 .47854 .22032 Mtetra
.47854 .22032 .48094 .2232 .48521 .22164 .48282 .21875 Mtetra
.48282 .21875 .48521 .22164 .48949 .22008 .4871 .21718 Mtetra
.4871 .21718 .48949 .22008 .49378 .21851 .49139 .21561 Mtetra
.49139 .21561 .49378 .21851 .49807 .21694 .49569 .21403 Mtetra
.49569 .21403 .49807 .21694 .50237 .21537 .5 .21246 Mtetra
.958 .617 .287 r
.5 .21246 .50237 .21537 .5065 .24408 .5041 .24119 Mtetra
.662 .744 .911 r
.5041 .24119 .5065 .24408 .51086 .24252 .50847 .23961 Mtetra
.50847 .23961 .51086 .24252 .51522 .24094 .51284 .23804 Mtetra
.51284 .23804 .51522 .24094 .5196 .23937 .51721 .23646 Mtetra
.51721 .23646 .5196 .23937 .52397 .23779 .52159 .23488 Mtetra
.52159 .23488 .52397 .23779 .52836 .23621 .52599 .23329 Mtetra
.52599 .23329 .52836 .23621 .53275 .23463 .53038 .23171 Mtetra
.53038 .23171 .53275 .23463 .53715 .23305 .53479 .23012 Mtetra
.53479 .23012 .53715 .23305 .54156 .23146 .5392 .22853 Mtetra
.5392 .22853 .54156 .23146 .54597 .22987 .54362 .22693 Mtetra
.54362 .22693 .54597 .22987 .55039 .22828 .54804 .22534 Mtetra
.54804 .22534 .55039 .22828 .55482 .22669 .55247 .22374 Mtetra
.55247 .22374 .55482 .22669 .55926 .22509 .55691 .22213 Mtetra
.55691 .22213 .55926 .22509 .5637 .22349 .56136 .22053 Mtetra
.56136 .22053 .5637 .22349 .56815 .22189 .56581 .21892 Mtetra
.56581 .21892 .56815 .22189 .5726 .22028 .57028 .21731 Mtetra
.57028 .21731 .5726 .22028 .57707 .21868 .57474 .2157 Mtetra
.57474 .2157 .57707 .21868 .58154 .21707 .57922 .21409 Mtetra
.57922 .21409 .58154 .21707 .58602 .21545 .5837 .21247 Mtetra
.5837 .21247 .58602 .21545 .5905 .21384 .58819 .21085 Mtetra
.58819 .21085 .5905 .21384 .59499 .21222 .59269 .20923 Mtetra
.59269 .20923 .59499 .21222 .59949 .2106 .59719 .2076 Mtetra
.972 .662 .349 r
.59719 .2076 .59949 .2106 .6072 .33175 .60482 .32882 Mtetra
.652 .755 .925 r
.60482 .32882 .6072 .33175 .6119 .33017 .60953 .32723 Mtetra
.60953 .32723 .6119 .33017 .61661 .32858 .61424 .32563 Mtetra
.61424 .32563 .61661 .32858 .62133 .32698 .61896 .32403 Mtetra
.61896 .32403 .62133 .32698 .62605 .32539 .62369 .32243 Mtetra
.62369 .32243 .62605 .32539 .63078 .32379 .62843 .32083 Mtetra
.62843 .32083 .63078 .32379 .63552 .32219 .63317 .31922 Mtetra
.63317 .31922 .63552 .32219 .64027 .32058 .63793 .31761 Mtetra
.63793 .31761 .64027 .32058 .64503 .31898 .64269 .316 Mtetra
.64269 .316 .64503 .31898 .64979 .31737 .64746 .31439 Mtetra
.64746 .31439 .64979 .31737 .65456 .31575 .65223 .31277 Mtetra
.65223 .31277 .65456 .31575 .65934 .31414 .65702 .31115 Mtetra
.65702 .31115 .65934 .31414 .66413 .31252 .66181 .30953 Mtetra
.66181 .30953 .66413 .31252 .66893 .3109 .66662 .3079 Mtetra
.66662 .3079 .66893 .3109 .67373 .30928 .67143 .30627 Mtetra
.67143 .30627 .67373 .30928 .67854 .30765 .67624 .30464 Mtetra
.67624 .30464 .67854 .30765 .68336 .30602 .68107 .30301 Mtetra
.68107 .30301 .68336 .30602 .68819 .30439 .6859 .30137 Mtetra
.6859 .30137 .68819 .30439 .69303 .30276 .69075 .29973 Mtetra
.69075 .29973 .69303 .30276 .69788 .30112 .6956 .29809 Mtetra
.6956 .29809 .69788 .30112 .70273 .29948 .70046 .29645 Mtetra
.70046 .29645 .70273 .29948 .70759 .29784 .70533 .2948 Mtetra
.70533 .2948 .70759 .29784 .71246 .29619 .7102 .29315 Mtetra
.7102 .29315 .71246 .29619 .71734 .29454 .71509 .29149 Mtetra
.71509 .29149 .71734 .29454 .72223 .29289 .71998 .28984 Mtetra
.71998 .28984 .72223 .29289 .72713 .29124 .72488 .28818 Mtetra
.72488 .28818 .72713 .29124 .73203 .28958 .72979 .28652 Mtetra
.72979 .28652 .73203 .28958 .73694 .28792 .73471 .28485 Mtetra
.73471 .28485 .73694 .28792 .74186 .28626 .73964 .28318 Mtetra
.73964 .28318 .74186 .28626 .74679 .28459 .74457 .28151 Mtetra
.74457 .28151 .74679 .28459 .75173 .28293 .74952 .27984 Mtetra
.74952 .27984 .75173 .28293 .75668 .28125 .75447 .27816 Mtetra
.75447 .27816 .75668 .28125 .76163 .27958 .75943 .27648 Mtetra
.75943 .27648 .76163 .27958 .76747 .28917 .7644 .2748 Mtetra
.578 .427 .64 r
.7644 .2748 .76747 .28917 .77247 .2875 .76938 .27311 Mtetra
0 0 .227 r
.76938 .27311 .77247 .2875 .77747 .28582 .77712 .30553 Mtetra
.502 .252 .468 r
.10294 .54199 .1126 .49035 .10983 .54309 .10691 .54068 Mtetra
.648 .76 .931 r
.10691 .54068 .10983 .54309 .1138 .54179 .11088 .53937 Mtetra
.11088 .53937 .1138 .54179 .11778 .54048 .11486 .53805 Mtetra
.11486 .53805 .11778 .54048 .12176 .53916 .11885 .53674 Mtetra
.11885 .53674 .12176 .53916 .12575 .53785 .12284 .53542 Mtetra
.12284 .53542 .12575 .53785 .12974 .53654 .12683 .5341 Mtetra
.12683 .5341 .12974 .53654 .13374 .53522 .13084 .53278 Mtetra
.13084 .53278 .13374 .53522 .13775 .5339 .13485 .53146 Mtetra
.13485 .53146 .13775 .5339 .14176 .53258 .13887 .53013 Mtetra
.13887 .53013 .14176 .53258 .14578 .53125 .14289 .5288 Mtetra
.14289 .5288 .14578 .53125 .14981 .52993 .14692 .52747 Mtetra
.14692 .52747 .14981 .52993 .15384 .5286 .15095 .52614 Mtetra
.15095 .52614 .15384 .5286 .15788 .52727 .15499 .52481 Mtetra
.15499 .52481 .15788 .52727 .16192 .52594 .15904 .52347 Mtetra
.15904 .52347 .16192 .52594 .16597 .5246 .1631 .52213 Mtetra
.1631 .52213 .16597 .5246 .17003 .52327 .16716 .52079 Mtetra
.16716 .52079 .17003 .52327 .1741 .52193 .17123 .51945 Mtetra
.17123 .51945 .1741 .52193 .17817 .52059 .1753 .51811 Mtetra
.1753 .51811 .17817 .52059 .18224 .51925 .17938 .51676 Mtetra
.17938 .51676 .18224 .51925 .18633 .5179 .18347 .51541 Mtetra
.18347 .51541 .18633 .5179 .19042 .51655 .18756 .51406 Mtetra
.18756 .51406 .19042 .51655 .19451 .5152 .19166 .51271 Mtetra
.19166 .51271 .19451 .5152 .19861 .51385 .19577 .51135 Mtetra
.19577 .51135 .19861 .51385 .20272 .5125 .19988 .51 Mtetra
.19988 .51 .20272 .5125 .20684 .51114 .204 .50864 Mtetra
.204 .50864 .20684 .51114 .21096 .50979 .20813 .50727 Mtetra
.20813 .50727 .21096 .50979 .21509 .50843 .21226 .50591 Mtetra
.21226 .50591 .21509 .50843 .21923 .50707 .2164 .50455 Mtetra
.2164 .50455 .21923 .50707 .22337 .5057 .22054 .50318 Mtetra
.22054 .50318 .22337 .5057 .22752 .50433 .2247 .50181 Mtetra
.2247 .50181 .22752 .50433 .24434 .35934 .22886 .50043 Mtetra
0 0 .102 r
.22886 .50043 .24434 .35934 .24833 .35792 .24565 .35529 Mtetra
.66 .746 .914 r
.24565 .35529 .24833 .35792 .25232 .35649 .24966 .35386 Mtetra
.24966 .35386 .25232 .35649 .25633 .35507 .25366 .35243 Mtetra
.25366 .35243 .25633 .35507 .26034 .35364 .25768 .351 Mtetra
.25768 .351 .26034 .35364 .26435 .35221 .2617 .34957 Mtetra
.2617 .34957 .26435 .35221 .26838 .35078 .26572 .34813 Mtetra
.26572 .34813 .26838 .35078 .27241 .34934 .26975 .34669 Mtetra
.26975 .34669 .27241 .34934 .27644 .34791 .27379 .34525 Mtetra
.27379 .34525 .27644 .34791 .28048 .34647 .27784 .34381 Mtetra
.27784 .34381 .28048 .34647 .28453 .34503 .28189 .34236 Mtetra
.28189 .34236 .28453 .34503 .28858 .34359 .28595 .34091 Mtetra
.28595 .34091 .28858 .34359 .29264 .34214 .29001 .33947 Mtetra
.29001 .33947 .29264 .34214 .29671 .34069 .29408 .33801 Mtetra
.29408 .33801 .29671 .34069 .30078 .33924 .29816 .33656 Mtetra
.957 .665 .438 r
.29816 .33656 .30078 .33924 .30486 .33779 .2982 .39241 Mtetra
.503 .254 .47 r
.2982 .39241 .30486 .33779 .30894 .33634 .30236 .39097 Mtetra
.30236 .39097 .30894 .33634 .30919 .39219 .30652 .38953 Mtetra
.655 .752 .921 r
.30652 .38953 .30919 .39219 .31336 .39075 .3107 .38808 Mtetra
.3107 .38808 .31336 .39075 .31753 .38931 .31487 .38664 Mtetra
.31487 .38664 .31753 .38931 .32172 .38786 .31906 .38519 Mtetra
.955 .7 .51 r
.31906 .38519 .32172 .38786 .33166 .29357 .3291 .29084 Mtetra
.662 .743 .91 r
.3291 .29084 .33166 .29357 .33574 .29209 .33318 .28935 Mtetra
.33318 .28935 .33574 .29209 .33982 .29061 .33727 .28787 Mtetra
.33727 .28787 .33982 .29061 .34391 .28913 .34136 .28638 Mtetra
.34136 .28638 .34391 .28913 .34801 .28764 .34546 .28489 Mtetra
.34546 .28489 .34801 .28764 .35212 .28615 .34957 .2834 Mtetra
.34957 .2834 .35212 .28615 .35623 .28466 .35368 .2819 Mtetra
.35368 .2819 .35623 .28466 .36034 .28317 .3578 .28041 Mtetra
.3578 .28041 .36034 .28317 .36446 .28167 .36193 .27891 Mtetra
.36193 .27891 .36446 .28167 .36859 .28018 .36606 .27741 Mtetra
.36606 .27741 .36859 .28018 .37273 .27868 .3702 .2759 Mtetra
.3702 .2759 .37273 .27868 .37687 .27718 .37435 .2744 Mtetra
.37435 .2744 .37687 .27718 .38102 .27567 .3785 .27289 Mtetra
.3785 .27289 .38102 .27567 .38517 .27417 .38266 .27138 Mtetra
.38266 .27138 .38517 .27417 .38933 .27266 .38682 .26987 Mtetra
.38682 .26987 .38933 .27266 .3935 .27115 .39099 .26835 Mtetra
0 .103 .619 r
.39099 .26835 .3935 .27115 .39767 .26963 .39496 .27187 Mtetra
.032 0 0 r
.39496 .27187 .39767 .26963 .40165 .27316 .39915 .27036 Mtetra
.662 .744 .911 r
.39915 .27036 .40165 .27316 .40585 .27164 .40335 .26884 Mtetra
.40335 .26884 .40585 .27164 .41005 .27012 .40755 .26731 Mtetra
.40755 .26731 .41005 .27012 .41425 .2686 .41176 .26579 Mtetra
.41176 .26579 .41425 .2686 .41847 .26708 .41598 .26426 Mtetra
.41598 .26426 .41847 .26708 .42269 .26555 .42021 .26273 Mtetra
.42021 .26273 .42269 .26555 .42691 .26402 .42444 .26119 Mtetra
.42444 .26119 .42691 .26402 .43115 .26249 .42867 .25966 Mtetra
.42867 .25966 .43115 .26249 .43539 .26096 .43292 .25812 Mtetra
.43292 .25812 .43539 .26096 .43963 .25942 .43717 .25658 Mtetra
.43717 .25658 .43963 .25942 .44389 .25788 .44143 .25504 Mtetra
.44143 .25504 .44389 .25788 .44815 .25634 .44569 .25349 Mtetra
.958 .73 .552 r
.44569 .25349 .44815 .25634 .453 .22967 .45057 .2268 Mtetra
.664 .741 .908 r
.45057 .2268 .453 .22967 .45724 .22812 .45482 .22524 Mtetra
.45482 .22524 .45724 .22812 .46149 .22656 .45907 .22369 Mtetra
.45907 .22369 .46149 .22656 .46574 .225 .46332 .22212 Mtetra
.46332 .22212 .46574 .225 .47 .22344 .46758 .22056 Mtetra
.46758 .22056 .47 .22344 .47426 .22188 .47185 .21899 Mtetra
.47185 .21899 .47426 .22188 .47854 .22032 .47613 .21742 Mtetra
.47613 .21742 .47854 .22032 .48282 .21875 .48041 .21585 Mtetra
.48041 .21585 .48282 .21875 .4871 .21718 .4847 .21428 Mtetra
.4847 .21428 .4871 .21718 .49139 .21561 .489 .2127 Mtetra
.489 .2127 .49139 .21561 .49569 .21403 .4933 .21112 Mtetra
.4933 .21112 .49569 .21403 .5 .21246 .49761 .20954 Mtetra
.958 .617 .287 r
.49761 .20954 .5 .21246 .5041 .24119 .5017 .23828 Mtetra
.662 .744 .911 r
.5017 .23828 .5041 .24119 .50847 .23961 .50607 .2367 Mtetra
.50607 .2367 .50847 .23961 .51284 .23804 .51044 .23512 Mtetra
.51044 .23512 .51284 .23804 .51721 .23646 .51482 .23354 Mtetra
.51482 .23354 .51721 .23646 .52159 .23488 .51921 .23195 Mtetra
.51921 .23195 .52159 .23488 .52599 .23329 .5236 .23036 Mtetra
.5236 .23036 .52599 .23329 .53038 .23171 .52801 .22877 Mtetra
.52801 .22877 .53038 .23171 .53479 .23012 .53241 .22718 Mtetra
.53241 .22718 .53479 .23012 .5392 .22853 .53683 .22558 Mtetra
.53683 .22558 .5392 .22853 .54362 .22693 .54125 .22398 Mtetra
.54125 .22398 .54362 .22693 .54804 .22534 .54568 .22238 Mtetra
.54568 .22238 .54804 .22534 .55247 .22374 .55012 .22078 Mtetra
.55012 .22078 .55247 .22374 .55691 .22213 .55457 .21917 Mtetra
.55457 .21917 .55691 .22213 .56136 .22053 .55902 .21756 Mtetra
.55902 .21756 .56136 .22053 .56581 .21892 .56348 .21595 Mtetra
.56348 .21595 .56581 .21892 .57028 .21731 .56794 .21434 Mtetra
.56794 .21434 .57028 .21731 .57474 .2157 .57241 .21272 Mtetra
.57241 .21272 .57474 .2157 .57922 .21409 .57689 .2111 Mtetra
.57689 .2111 .57922 .21409 .5837 .21247 .58138 .20948 Mtetra
.58138 .20948 .5837 .21247 .58819 .21085 .58588 .20785 Mtetra
.58588 .20785 .58819 .21085 .59269 .20923 .59038 .20623 Mtetra
.59038 .20623 .59269 .20923 .59719 .2076 .59489 .2046 Mtetra
.972 .662 .349 r
.59489 .2046 .59719 .2076 .60482 .32882 .60243 .32588 Mtetra
.652 .755 .925 r
.60243 .32588 .60482 .32882 .60953 .32723 .60714 .32428 Mtetra
.60714 .32428 .60953 .32723 .61424 .32563 .61186 .32268 Mtetra
.61186 .32268 .61424 .32563 .61896 .32403 .61659 .32108 Mtetra
.61659 .32108 .61896 .32403 .62369 .32243 .62132 .31947 Mtetra
.62132 .31947 .62369 .32243 .62843 .32083 .62607 .31786 Mtetra
.62607 .31786 .62843 .32083 .63317 .31922 .63082 .31625 Mtetra
.63082 .31625 .63317 .31922 .63793 .31761 .63557 .31464 Mtetra
.63557 .31464 .63793 .31761 .64269 .316 .64034 .31302 Mtetra
.64034 .31302 .64269 .316 .64746 .31439 .64512 .3114 Mtetra
.64512 .3114 .64746 .31439 .65223 .31277 .6499 .30978 Mtetra
.6499 .30978 .65223 .31277 .65702 .31115 .65469 .30815 Mtetra
.65469 .30815 .65702 .31115 .66181 .30953 .65949 .30652 Mtetra
.65949 .30652 .66181 .30953 .66662 .3079 .6643 .30489 Mtetra
.6643 .30489 .66662 .3079 .67143 .30627 .66911 .30326 Mtetra
.66911 .30326 .67143 .30627 .67624 .30464 .67394 .30162 Mtetra
.67394 .30162 .67624 .30464 .68107 .30301 .67877 .29999 Mtetra
.67877 .29999 .68107 .30301 .6859 .30137 .68361 .29834 Mtetra
.68361 .29834 .6859 .30137 .69075 .29973 .68846 .2967 Mtetra
.68846 .2967 .69075 .29973 .6956 .29809 .69331 .29505 Mtetra
.69331 .29505 .6956 .29809 .70046 .29645 .69818 .2934 Mtetra
.69818 .2934 .70046 .29645 .70533 .2948 .70305 .29175 Mtetra
.70305 .29175 .70533 .2948 .7102 .29315 .70794 .29009 Mtetra
.70794 .29009 .7102 .29315 .71509 .29149 .71283 .28843 Mtetra
.71283 .28843 .71509 .29149 .71998 .28984 .71773 .28677 Mtetra
.71773 .28677 .71998 .28984 .72488 .28818 .72263 .28511 Mtetra
.72263 .28511 .72488 .28818 .72979 .28652 .72755 .28344 Mtetra
.72755 .28344 .72979 .28652 .73471 .28485 .73247 .28177 Mtetra
.73247 .28177 .73471 .28485 .73964 .28318 .73741 .2801 Mtetra
.73741 .2801 .73964 .28318 .74457 .28151 .74235 .27842 Mtetra
.74235 .27842 .74457 .28151 .74952 .27984 .7473 .27674 Mtetra
.7473 .27674 .74952 .27984 .75447 .27816 .75226 .27506 Mtetra
.75226 .27506 .75447 .27816 .75943 .27648 .75722 .27337 Mtetra
.922 .557 .128 r
.75722 .27337 .75943 .27648 .7644 .2748 .76481 .30579 Mtetra
.488 .223 .439 r
.76481 .30579 .7644 .2748 .76938 .27311 .76986 .30411 Mtetra
.76986 .30411 .76938 .27311 .77712 .30553 .77491 .30243 Mtetra
.648 .76 .931 r
.1 .53957 .10294 .54199 .10691 .54068 .10397 .53826 Mtetra
.10397 .53826 .10691 .54068 .11088 .53937 .10795 .53694 Mtetra
.10795 .53694 .11088 .53937 .11486 .53805 .11193 .53562 Mtetra
.11193 .53562 .11486 .53805 .11885 .53674 .11592 .5343 Mtetra
.11592 .5343 .11885 .53674 .12284 .53542 .11992 .53298 Mtetra
.11992 .53298 .12284 .53542 .12683 .5341 .12392 .53166 Mtetra
.12392 .53166 .12683 .5341 .13084 .53278 .12793 .53034 Mtetra
.12793 .53034 .13084 .53278 .13485 .53146 .13194 .52901 Mtetra
.13194 .52901 .13485 .53146 .13887 .53013 .13596 .52768 Mtetra
.13596 .52768 .13887 .53013 .14289 .5288 .13999 .52635 Mtetra
.13999 .52635 .14289 .5288 .14692 .52747 .14402 .52501 Mtetra
.14402 .52501 .14692 .52747 .15095 .52614 .14806 .52368 Mtetra
.14806 .52368 .15095 .52614 .15499 .52481 .1521 .52234 Mtetra
.1521 .52234 .15499 .52481 .15904 .52347 .15616 .521 Mtetra
.15616 .521 .15904 .52347 .1631 .52213 .16021 .51966 Mtetra
.16021 .51966 .1631 .52213 .16716 .52079 .16428 .51831 Mtetra
.16428 .51831 .16716 .52079 .17123 .51945 .16835 .51697 Mtetra
.16835 .51697 .17123 .51945 .1753 .51811 .17243 .51562 Mtetra
.17243 .51562 .1753 .51811 .17938 .51676 .17651 .51427 Mtetra
.17651 .51427 .17938 .51676 .18347 .51541 .1806 .51292 Mtetra
.1806 .51292 .18347 .51541 .18756 .51406 .1847 .51156 Mtetra
.1847 .51156 .18756 .51406 .19166 .51271 .1888 .5102 Mtetra
.1888 .5102 .19166 .51271 .19577 .51135 .19291 .50885 Mtetra
.19291 .50885 .19577 .51135 .19988 .51 .19703 .50748 Mtetra
.19703 .50748 .19988 .51 .204 .50864 .20115 .50612 Mtetra
.20115 .50612 .204 .50864 .20813 .50727 .20528 .50476 Mtetra
.20528 .50476 .20813 .50727 .21226 .50591 .20942 .50339 Mtetra
.20942 .50339 .21226 .50591 .2164 .50455 .21356 .50202 Mtetra
.21356 .50202 .2164 .50455 .22054 .50318 .21771 .50065 Mtetra
.21771 .50065 .22054 .50318 .2247 .50181 .22187 .49927 Mtetra
.22187 .49927 .2247 .50181 .22886 .50043 .22603 .49789 Mtetra
.948 .694 .52 r
.22603 .49789 .22886 .50043 .24565 .35529 .24297 .35265 Mtetra
.66 .746 .914 r
.24297 .35265 .24565 .35529 .24966 .35386 .24698 .35122 Mtetra
.24698 .35122 .24966 .35386 .25366 .35243 .25099 .34979 Mtetra
.25099 .34979 .25366 .35243 .25768 .351 .25501 .34835 Mtetra
.25501 .34835 .25768 .351 .2617 .34957 .25903 .34691 Mtetra
.25903 .34691 .2617 .34957 .26572 .34813 .26306 .34547 Mtetra
.26306 .34547 .26572 .34813 .26975 .34669 .2671 .34403 Mtetra
.2671 .34403 .26975 .34669 .27379 .34525 .27114 .34258 Mtetra
.27114 .34258 .27379 .34525 .27784 .34381 .27519 .34114 Mtetra
.27519 .34114 .27784 .34381 .28189 .34236 .27924 .33969 Mtetra
.27924 .33969 .28189 .34236 .28595 .34091 .2833 .33824 Mtetra
.956 .665 .442 r
.2833 .33824 .28595 .34091 .29001 .33947 .28306 .39407 Mtetra
.502 .253 .469 r
.28306 .39407 .29001 .33947 .29408 .33801 .28721 .39263 Mtetra
.28721 .39263 .29408 .33801 .29816 .33656 .29136 .39119 Mtetra
.29136 .39119 .29816 .33656 .2982 .39241 .29551 .38975 Mtetra
.655 .752 .921 r
.29551 .38975 .2982 .39241 .30236 .39097 .29968 .38831 Mtetra
.29968 .38831 .30236 .39097 .30652 .38953 .30385 .38686 Mtetra
.30385 .38686 .30652 .38953 .3107 .38808 .30803 .38541 Mtetra
.30803 .38541 .3107 .38808 .31487 .38664 .31221 .38396 Mtetra
.31221 .38396 .31487 .38664 .31906 .38519 .3164 .38251 Mtetra
.3164 .38251 .31906 .38519 .3291 .29084 .3206 .38105 Mtetra
0 0 .142 r
.3206 .38105 .3291 .29084 .33318 .28935 .33061 .28661 Mtetra
.662 .743 .91 r
.33061 .28661 .33318 .28935 .33727 .28787 .3347 .28512 Mtetra
.3347 .28512 .33727 .28787 .34136 .28638 .3388 .28363 Mtetra
.3388 .28363 .34136 .28638 .34546 .28489 .3429 .28213 Mtetra
.3429 .28213 .34546 .28489 .34957 .2834 .34702 .28064 Mtetra
.34702 .28064 .34957 .2834 .35368 .2819 .35113 .27914 Mtetra
.35113 .27914 .35368 .2819 .3578 .28041 .35526 .27764 Mtetra
.35526 .27764 .3578 .28041 .36193 .27891 .35939 .27613 Mtetra
.35939 .27613 .36193 .27891 .36606 .27741 .36352 .27463 Mtetra
.36352 .27463 .36606 .27741 .3702 .2759 .36767 .27312 Mtetra
.36767 .27312 .3702 .2759 .37435 .2744 .37182 .27161 Mtetra
.37182 .27161 .37435 .2744 .3785 .27289 .37597 .2701 Mtetra
.37597 .2701 .3785 .27289 .38266 .27138 .38014 .26858 Mtetra
.38014 .26858 .38266 .27138 .38682 .26987 .3843 .26707 Mtetra
.3843 .26707 .38682 .26987 .39099 .26835 .38848 .26555 Mtetra
0 .103 .619 r
.38848 .26555 .39099 .26835 .39496 .27187 .39245 .26907 Mtetra
.662 .744 .911 r
.39245 .26907 .39496 .27187 .39915 .27036 .39664 .26755 Mtetra
.39664 .26755 .39915 .27036 .40335 .26884 .40084 .26602 Mtetra
.40084 .26602 .40335 .26884 .40755 .26731 .40505 .26449 Mtetra
.40505 .26449 .40755 .26731 .41176 .26579 .40927 .26296 Mtetra
.40927 .26296 .41176 .26579 .41598 .26426 .41349 .26143 Mtetra
.41349 .26143 .41598 .26426 .42021 .26273 .41772 .25989 Mtetra
.41772 .25989 .42021 .26273 .42444 .26119 .42195 .25836 Mtetra
.42195 .25836 .42444 .26119 .42867 .25966 .42619 .25682 Mtetra
.42619 .25682 .42867 .25966 .43292 .25812 .43044 .25528 Mtetra
.43044 .25528 .43292 .25812 .43717 .25658 .4347 .25373 Mtetra
.4347 .25373 .43717 .25658 .44143 .25504 .43896 .25218 Mtetra
.43896 .25218 .44143 .25504 .44569 .25349 .44323 .25063 Mtetra
.44323 .25063 .44569 .25349 .45057 .2268 .4475 .24908 Mtetra
0 0 .082 r
.4475 .24908 .45057 .2268 .45482 .22524 .45238 .22236 Mtetra
.664 .741 .908 r
.45238 .22236 .45482 .22524 .45907 .22369 .45664 .2208 Mtetra
.45664 .2208 .45907 .22369 .46332 .22212 .4609 .21923 Mtetra
.4609 .21923 .46332 .22212 .46758 .22056 .46516 .21766 Mtetra
.46516 .21766 .46758 .22056 .47185 .21899 .46944 .21609 Mtetra
.46944 .21609 .47185 .21899 .47613 .21742 .47372 .21452 Mtetra
.47372 .21452 .47613 .21742 .48041 .21585 .478 .21294 Mtetra
.478 .21294 .48041 .21585 .4847 .21428 .4823 .21136 Mtetra
.4823 .21136 .4847 .21428 .489 .2127 .4866 .20978 Mtetra
.4866 .20978 .489 .2127 .4933 .21112 .49091 .2082 Mtetra
.49091 .2082 .4933 .21112 .49761 .20954 .49522 .20661 Mtetra
.958 .617 .287 r
.49522 .20661 .49761 .20954 .5017 .23828 .49929 .23536 Mtetra
.662 .744 .911 r
.49929 .23536 .5017 .23828 .50607 .2367 .50366 .23378 Mtetra
.50366 .23378 .50607 .2367 .51044 .23512 .50804 .23219 Mtetra
.50804 .23219 .51044 .23512 .51482 .23354 .51242 .23061 Mtetra
.51242 .23061 .51482 .23354 .51921 .23195 .51682 .22902 Mtetra
.51682 .22902 .51921 .23195 .5236 .23036 .52122 .22742 Mtetra
.52122 .22742 .5236 .23036 .52801 .22877 .52562 .22583 Mtetra
.52562 .22583 .52801 .22877 .53241 .22718 .53004 .22423 Mtetra
.53004 .22423 .53241 .22718 .53683 .22558 .53446 .22263 Mtetra
.53446 .22263 .53683 .22558 .54125 .22398 .53888 .22102 Mtetra
.53888 .22102 .54125 .22398 .54568 .22238 .54332 .21942 Mtetra
.54332 .21942 .54568 .22238 .55012 .22078 .54776 .21781 Mtetra
.54776 .21781 .55012 .22078 .55457 .21917 .55221 .2162 Mtetra
.55221 .2162 .55457 .21917 .55902 .21756 .55667 .21459 Mtetra
.55667 .21459 .55902 .21756 .56348 .21595 .56113 .21297 Mtetra
.56113 .21297 .56348 .21595 .56794 .21434 .5656 .21135 Mtetra
.5656 .21135 .56794 .21434 .57241 .21272 .57008 .20973 Mtetra
.57008 .20973 .57241 .21272 .57689 .2111 .57456 .2081 Mtetra
.57456 .2081 .57689 .2111 .58138 .20948 .57905 .20648 Mtetra
.57905 .20648 .58138 .20948 .58588 .20785 .58355 .20485 Mtetra
.58355 .20485 .58588 .20785 .59038 .20623 .58806 .20322 Mtetra
.58806 .20322 .59038 .20623 .59489 .2046 .59258 .20158 Mtetra
.972 .662 .349 r
.59258 .20158 .59489 .2046 .60243 .32588 .60004 .32293 Mtetra
.652 .755 .925 r
.60004 .32293 .60243 .32588 .60714 .32428 .60475 .32132 Mtetra
.60475 .32132 .60714 .32428 .61186 .32268 .60948 .31972 Mtetra
.60948 .31972 .61186 .32268 .61659 .32108 .61421 .31811 Mtetra
.61421 .31811 .61659 .32108 .62132 .31947 .61895 .3165 Mtetra
.61895 .3165 .62132 .31947 .62607 .31786 .6237 .31489 Mtetra
.6237 .31489 .62607 .31786 .63082 .31625 .62845 .31327 Mtetra
.62845 .31327 .63082 .31625 .63557 .31464 .63322 .31165 Mtetra
.63322 .31165 .63557 .31464 .64034 .31302 .63799 .31003 Mtetra
.63799 .31003 .64034 .31302 .64512 .3114 .64277 .3084 Mtetra
.64277 .3084 .64512 .3114 .6499 .30978 .64756 .30678 Mtetra
.64756 .30678 .6499 .30978 .65469 .30815 .65235 .30515 Mtetra
.65235 .30515 .65469 .30815 .65949 .30652 .65716 .30351 Mtetra
.65716 .30351 .65949 .30652 .6643 .30489 .66197 .30188 Mtetra
.66197 .30188 .6643 .30489 .66911 .30326 .66679 .30024 Mtetra
.66679 .30024 .66911 .30326 .67394 .30162 .67162 .2986 Mtetra
.67162 .2986 .67394 .30162 .67877 .29999 .67646 .29695 Mtetra
.67646 .29695 .67877 .29999 .68361 .29834 .68131 .2953 Mtetra
.68131 .2953 .68361 .29834 .68846 .2967 .68616 .29366 Mtetra
.68616 .29366 .68846 .2967 .69331 .29505 .69102 .292 Mtetra
.69102 .292 .69331 .29505 .69818 .2934 .69589 .29035 Mtetra
.69589 .29035 .69818 .2934 .70305 .29175 .70077 .28869 Mtetra
.70077 .28869 .70305 .29175 .70794 .29009 .70566 .28703 Mtetra
.70566 .28703 .70794 .29009 .71283 .28843 .71056 .28536 Mtetra
.71056 .28536 .71283 .28843 .71773 .28677 .71546 .2837 Mtetra
.71546 .2837 .71773 .28677 .72263 .28511 .72038 .28203 Mtetra
.72038 .28203 .72263 .28511 .72755 .28344 .7253 .28035 Mtetra
.7253 .28035 .72755 .28344 .73247 .28177 .73023 .27868 Mtetra
.73023 .27868 .73247 .28177 .73741 .2801 .73517 .277 Mtetra
.73517 .277 .73741 .2801 .74235 .27842 .74011 .27532 Mtetra
.926 .562 .14 r
.74011 .27532 .74235 .27842 .7473 .27674 .74749 .30772 Mtetra
.487 .222 .438 r
.74749 .30772 .7473 .27674 .75226 .27506 .75252 .30605 Mtetra
.75252 .30605 .75226 .27506 .75722 .27337 .75755 .30437 Mtetra
.75755 .30437 .75722 .27337 .76481 .30579 .76258 .30269 Mtetra
.649 .759 .929 r
.76258 .30269 .76481 .30579 .76986 .30411 .76763 .301 Mtetra
.76763 .301 .76986 .30411 .77491 .30243 .77269 .29931 Mtetra
.648 .76 .931 r
.09706 .53714 .1 .53957 .10397 .53826 .10103 .53583 Mtetra
.10103 .53583 .10397 .53826 .10795 .53694 .10501 .53451 Mtetra
.10501 .53451 .10795 .53694 .11193 .53562 .109 .53319 Mtetra
.109 .53319 .11193 .53562 .11592 .5343 .11299 .53186 Mtetra
.11299 .53186 .11592 .5343 .11992 .53298 .11699 .53054 Mtetra
.11699 .53054 .11992 .53298 .12392 .53166 .12099 .52921 Mtetra
.12099 .52921 .12392 .53166 .12793 .53034 .125 .52788 Mtetra
.125 .52788 .12793 .53034 .13194 .52901 .12902 .52655 Mtetra
.12902 .52655 .13194 .52901 .13596 .52768 .13304 .52522 Mtetra
.13304 .52522 .13596 .52768 .13999 .52635 .13707 .52388 Mtetra
.13707 .52388 .13999 .52635 .14402 .52501 .14111 .52255 Mtetra
.14111 .52255 .14402 .52501 .14806 .52368 .14515 .52121 Mtetra
.14515 .52121 .14806 .52368 .1521 .52234 .1492 .51987 Mtetra
.1492 .51987 .1521 .52234 .15616 .521 .15326 .51852 Mtetra
.15326 .51852 .15616 .521 .16021 .51966 .15732 .51718 Mtetra
.15732 .51718 .16021 .51966 .16428 .51831 .16139 .51583 Mtetra
.16139 .51583 .16428 .51831 .16835 .51697 .16546 .51448 Mtetra
.16546 .51448 .16835 .51697 .17243 .51562 .16955 .51312 Mtetra
.16955 .51312 .17243 .51562 .17651 .51427 .17363 .51177 Mtetra
.17363 .51177 .17651 .51427 .1806 .51292 .17773 .51041 Mtetra
.17773 .51041 .1806 .51292 .1847 .51156 .18183 .50905 Mtetra
.18183 .50905 .1847 .51156 .1888 .5102 .18594 .50769 Mtetra
.18594 .50769 .1888 .5102 .19291 .50885 .19005 .50633 Mtetra
.19005 .50633 .19291 .50885 .19703 .50748 .19417 .50497 Mtetra
.19417 .50497 .19703 .50748 .20115 .50612 .1983 .5036 Mtetra
.1983 .5036 .20115 .50612 .20528 .50476 .20243 .50223 Mtetra
.20243 .50223 .20528 .50476 .20942 .50339 .20657 .50086 Mtetra
.20657 .50086 .20942 .50339 .21356 .50202 .21072 .49948 Mtetra
.21072 .49948 .21356 .50202 .21771 .50065 .21487 .49811 Mtetra
.21487 .49811 .21771 .50065 .22187 .49927 .21903 .49673 Mtetra
.21903 .49673 .22187 .49927 .22603 .49789 .2232 .49535 Mtetra
.2232 .49535 .22603 .49789 .24297 .35265 .22737 .49396 Mtetra
0 0 .099 r
.22737 .49396 .24297 .35265 .24698 .35122 .24429 .34857 Mtetra
.66 .746 .914 r
.24429 .34857 .24698 .35122 .25099 .34979 .24831 .34713 Mtetra
.24831 .34713 .25099 .34979 .25501 .34835 .25233 .34569 Mtetra
.25233 .34569 .25501 .34835 .25903 .34691 .25636 .34425 Mtetra
.25636 .34425 .25903 .34691 .26306 .34547 .26039 .34281 Mtetra
.26039 .34281 .26306 .34547 .2671 .34403 .26443 .34136 Mtetra
.26443 .34136 .2671 .34403 .27114 .34258 .26848 .33991 Mtetra
.955 .665 .446 r
.26848 .33991 .27114 .34258 .27519 .34114 .26796 .39572 Mtetra
.501 .252 .468 r
.26796 .39572 .27519 .34114 .27924 .33969 .27209 .39429 Mtetra
.27209 .39429 .27924 .33969 .2833 .33824 .27622 .39285 Mtetra
.27622 .39285 .2833 .33824 .28306 .39407 .28036 .39141 Mtetra
.655 .752 .921 r
.28036 .39141 .28306 .39407 .28721 .39263 .28451 .38997 Mtetra
.28451 .38997 .28721 .39263 .29136 .39119 .28866 .38853 Mtetra
.28866 .38853 .29136 .39119 .29551 .38975 .29282 .38708 Mtetra
.29282 .38708 .29551 .38975 .29968 .38831 .29699 .38563 Mtetra
.29699 .38563 .29968 .38831 .30385 .38686 .30117 .38418 Mtetra
.30117 .38418 .30385 .38686 .30803 .38541 .30535 .38273 Mtetra
.30535 .38273 .30803 .38541 .31221 .38396 .30953 .38127 Mtetra
.30953 .38127 .31221 .38396 .3164 .38251 .31373 .37982 Mtetra
.31373 .37982 .3164 .38251 .3206 .38105 .31793 .37836 Mtetra
.31793 .37836 .3206 .38105 .33061 .28661 .32214 .3769 Mtetra
0 0 .142 r
.32214 .3769 .33061 .28661 .3347 .28512 .33213 .28236 Mtetra
.662 .743 .91 r
.33213 .28236 .3347 .28512 .3388 .28363 .33623 .28087 Mtetra
.33623 .28087 .3388 .28363 .3429 .28213 .34034 .27937 Mtetra
.34034 .27937 .3429 .28213 .34702 .28064 .34446 .27787 Mtetra
.34446 .27787 .34702 .28064 .35113 .27914 .34858 .27637 Mtetra
.34858 .27637 .35113 .27914 .35526 .27764 .3527 .27486 Mtetra
.3527 .27486 .35526 .27764 .35939 .27613 .35684 .27335 Mtetra
.35684 .27335 .35939 .27613 .36352 .27463 .36098 .27184 Mtetra
.36098 .27184 .36352 .27463 .36767 .27312 .36513 .27033 Mtetra
.36513 .27033 .36767 .27312 .37182 .27161 .36928 .26882 Mtetra
.36928 .26882 .37182 .27161 .37597 .2701 .37344 .2673 Mtetra
.37344 .2673 .37597 .2701 .38014 .26858 .37761 .26578 Mtetra
.37761 .26578 .38014 .26858 .3843 .26707 .38178 .26426 Mtetra
.38178 .26426 .3843 .26707 .38848 .26555 .38596 .26273 Mtetra
0 .103 .619 r
.38596 .26273 .38848 .26555 .39245 .26907 .38992 .26626 Mtetra
.662 .744 .911 r
.38992 .26626 .39245 .26907 .39664 .26755 .39412 .26473 Mtetra
.39412 .26473 .39664 .26755 .40084 .26602 .39833 .2632 Mtetra
.39833 .2632 .40084 .26602 .40505 .26449 .40254 .26167 Mtetra
.40254 .26167 .40505 .26449 .40927 .26296 .40676 .26013 Mtetra
.40676 .26013 .40927 .26296 .41349 .26143 .41099 .25859 Mtetra
.41099 .25859 .41349 .26143 .41772 .25989 .41522 .25705 Mtetra
.41522 .25705 .41772 .25989 .42195 .25836 .41946 .25551 Mtetra
.41946 .25551 .42195 .25836 .42619 .25682 .4237 .25397 Mtetra
.4237 .25397 .42619 .25682 .43044 .25528 .42796 .25242 Mtetra
.42796 .25242 .43044 .25528 .4347 .25373 .43222 .25087 Mtetra
.43222 .25087 .4347 .25373 .43896 .25218 .43648 .24932 Mtetra
.43648 .24932 .43896 .25218 .44323 .25063 .44075 .24777 Mtetra
.44075 .24777 .44323 .25063 .4475 .24908 .44503 .24621 Mtetra
.44503 .24621 .4475 .24908 .45238 .22236 .44932 .24465 Mtetra
0 0 .082 r
.44932 .24465 .45238 .22236 .45664 .2208 .4542 .21791 Mtetra
.664 .741 .908 r
.4542 .21791 .45664 .2208 .4609 .21923 .45846 .21634 Mtetra
.45846 .21634 .4609 .21923 .46516 .21766 .46273 .21476 Mtetra
.46273 .21476 .46516 .21766 .46944 .21609 .46701 .21319 Mtetra
.46701 .21319 .46944 .21609 .47372 .21452 .4713 .21161 Mtetra
.4713 .21161 .47372 .21452 .478 .21294 .47559 .21003 Mtetra
.47559 .21003 .478 .21294 .4823 .21136 .47989 .20844 Mtetra
.47989 .20844 .4823 .21136 .4866 .20978 .48419 .20686 Mtetra
.48419 .20686 .4866 .20978 .49091 .2082 .4885 .20527 Mtetra
.4885 .20527 .49091 .2082 .49522 .20661 .49282 .20368 Mtetra
.958 .617 .287 r
.49282 .20368 .49522 .20661 .49929 .23536 .49687 .23244 Mtetra
.662 .744 .911 r
.49687 .23244 .49929 .23536 .50366 .23378 .50125 .23085 Mtetra
.50125 .23085 .50366 .23378 .50804 .23219 .50563 .22926 Mtetra
.50563 .22926 .50804 .23219 .51242 .23061 .51002 .22767 Mtetra
.51002 .22767 .51242 .23061 .51682 .22902 .51442 .22607 Mtetra
.51442 .22607 .51682 .22902 .52122 .22742 .51882 .22447 Mtetra
.51882 .22447 .52122 .22742 .52562 .22583 .52323 .22287 Mtetra
.52323 .22287 .52562 .22583 .53004 .22423 .52765 .22127 Mtetra
.52765 .22127 .53004 .22423 .53446 .22263 .53207 .21967 Mtetra
.53207 .21967 .53446 .22263 .53888 .22102 .53651 .21806 Mtetra
.53651 .21806 .53888 .22102 .54332 .21942 .54095 .21645 Mtetra
.54095 .21645 .54332 .21942 .54776 .21781 .54539 .21483 Mtetra
.54539 .21483 .54776 .21781 .55221 .2162 .54985 .21322 Mtetra
.54985 .21322 .55221 .2162 .55667 .21459 .55431 .2116 Mtetra
.55431 .2116 .55667 .21459 .56113 .21297 .55878 .20998 Mtetra
.55878 .20998 .56113 .21297 .5656 .21135 .56325 .20835 Mtetra
.56325 .20835 .5656 .21135 .57008 .20973 .56773 .20673 Mtetra
.56773 .20673 .57008 .20973 .57456 .2081 .57222 .2051 Mtetra
.57222 .2051 .57456 .2081 .57905 .20648 .57672 .20347 Mtetra
.57672 .20347 .57905 .20648 .58355 .20485 .58123 .20183 Mtetra
.58123 .20183 .58355 .20485 .58806 .20322 .58574 .2002 Mtetra
.58574 .2002 .58806 .20322 .59258 .20158 .59026 .19856 Mtetra
.972 .662 .349 r
.59026 .19856 .59258 .20158 .60004 .32293 .59763 .31997 Mtetra
.652 .755 .925 r
.59763 .31997 .60004 .32293 .60475 .32132 .60235 .31836 Mtetra
.60235 .31836 .60475 .32132 .60948 .31972 .60708 .31675 Mtetra
.60708 .31675 .60948 .31972 .61421 .31811 .61182 .31513 Mtetra
.61182 .31513 .61421 .31811 .61895 .3165 .61656 .31352 Mtetra
.61656 .31352 .61895 .3165 .6237 .31489 .62132 .3119 Mtetra
.62132 .3119 .6237 .31489 .62845 .31327 .62608 .31028 Mtetra
.62608 .31028 .62845 .31327 .63322 .31165 .63085 .30865 Mtetra
.63085 .30865 .63322 .31165 .63799 .31003 .63563 .30703 Mtetra
.63563 .30703 .63799 .31003 .64277 .3084 .64041 .3054 Mtetra
.64041 .3054 .64277 .3084 .64756 .30678 .64521 .30376 Mtetra
.64521 .30376 .64756 .30678 .65235 .30515 .65001 .30213 Mtetra
.65001 .30213 .65235 .30515 .65716 .30351 .65482 .30049 Mtetra
.65482 .30049 .65716 .30351 .66197 .30188 .65964 .29885 Mtetra
.65964 .29885 .66197 .30188 .66679 .30024 .66446 .29721 Mtetra
.66446 .29721 .66679 .30024 .67162 .2986 .6693 .29556 Mtetra
.6693 .29556 .67162 .2986 .67646 .29695 .67414 .29391 Mtetra
.67414 .29391 .67646 .29695 .68131 .2953 .67899 .29226 Mtetra
.67899 .29226 .68131 .2953 .68616 .29366 .68385 .2906 Mtetra
.68385 .2906 .68616 .29366 .69102 .292 .68872 .28894 Mtetra
.68872 .28894 .69102 .292 .69589 .29035 .6936 .28728 Mtetra
.6936 .28728 .69589 .29035 .70077 .28869 .69849 .28562 Mtetra
.69849 .28562 .70077 .28869 .70566 .28703 .70338 .28395 Mtetra
.70338 .28395 .70566 .28703 .71056 .28536 .70828 .28228 Mtetra
.70828 .28228 .71056 .28536 .71546 .2837 .71319 .28061 Mtetra
.71319 .28061 .71546 .2837 .72038 .28203 .71811 .27894 Mtetra
.71811 .27894 .72038 .28203 .7253 .28035 .72304 .27726 Mtetra
.72304 .27726 .7253 .28035 .73023 .27868 .72798 .27558 Mtetra
.929 .565 .147 r
.72798 .27558 .73023 .27868 .73517 .277 .73521 .30798 Mtetra
.486 .221 .437 r
.73521 .30798 .73517 .277 .74011 .27532 .74022 .30631 Mtetra
.74022 .30631 .74011 .27532 .74749 .30772 .74524 .30463 Mtetra
.649 .759 .929 r
.74524 .30463 .74749 .30772 .75252 .30605 .75027 .30295 Mtetra
.75027 .30295 .75252 .30605 .75755 .30437 .7553 .30126 Mtetra
.7553 .30126 .75755 .30437 .76258 .30269 .76035 .29957 Mtetra
.76035 .29957 .76258 .30269 .76763 .301 .7654 .29788 Mtetra
.7654 .29788 .76763 .301 .77269 .29931 .77047 .29619 Mtetra
.648 .76 .931 r
.0941 .53471 .09706 .53714 .10103 .53583 .09808 .53339 Mtetra
.09808 .53339 .10103 .53583 .10501 .53451 .10206 .53207 Mtetra
.10206 .53207 .10501 .53451 .109 .53319 .10605 .53074 Mtetra
.10605 .53074 .109 .53319 .11299 .53186 .11005 .52942 Mtetra
.11005 .52942 .11299 .53186 .11699 .53054 .11405 .52809 Mtetra
.11405 .52809 .11699 .53054 .12099 .52921 .11806 .52676 Mtetra
.11806 .52676 .12099 .52921 .125 .52788 .12207 .52542 Mtetra
.12207 .52542 .125 .52788 .12902 .52655 .12609 .52409 Mtetra
.12609 .52409 .12902 .52655 .13304 .52522 .13012 .52275 Mtetra
.13012 .52275 .13304 .52522 .13707 .52388 .13416 .52141 Mtetra
.13416 .52141 .13707 .52388 .14111 .52255 .1382 .52007 Mtetra
.1382 .52007 .14111 .52255 .14515 .52121 .14224 .51873 Mtetra
.14224 .51873 .14515 .52121 .1492 .51987 .14629 .51738 Mtetra
.14629 .51738 .1492 .51987 .15326 .51852 .15035 .51603 Mtetra
.15035 .51603 .15326 .51852 .15732 .51718 .15442 .51469 Mtetra
.15442 .51469 .15732 .51718 .16139 .51583 .15849 .51333 Mtetra
.15849 .51333 .16139 .51583 .16546 .51448 .16257 .51198 Mtetra
.16257 .51198 .16546 .51448 .16955 .51312 .16665 .51062 Mtetra
.16665 .51062 .16955 .51312 .17363 .51177 .17075 .50926 Mtetra
.17075 .50926 .17363 .51177 .17773 .51041 .17484 .5079 Mtetra
.17484 .5079 .17773 .51041 .18183 .50905 .17895 .50654 Mtetra
.17895 .50654 .18183 .50905 .18594 .50769 .18306 .50518 Mtetra
.18306 .50518 .18594 .50769 .19005 .50633 .18718 .50381 Mtetra
.18718 .50381 .19005 .50633 .19417 .50497 .1913 .50244 Mtetra
.1913 .50244 .19417 .50497 .1983 .5036 .19543 .50107 Mtetra
.19543 .50107 .1983 .5036 .20243 .50223 .19957 .49969 Mtetra
.19957 .49969 .20243 .50223 .20657 .50086 .20371 .49832 Mtetra
.20371 .49832 .20657 .50086 .21072 .49948 .20787 .49694 Mtetra
.20787 .49694 .21072 .49948 .21487 .49811 .21202 .49556 Mtetra
.21202 .49556 .21487 .49811 .21903 .49673 .21619 .49418 Mtetra
.21619 .49418 .21903 .49673 .2232 .49535 .22036 .49279 Mtetra
.22036 .49279 .2232 .49535 .22737 .49396 .22454 .49141 Mtetra
.948 .694 .519 r
.22454 .49141 .22737 .49396 .24429 .34857 .2416 .34592 Mtetra
.66 .746 .914 r
.2416 .34592 .24429 .34857 .24831 .34713 .24562 .34447 Mtetra
.24562 .34447 .24831 .34713 .25233 .34569 .24965 .34303 Mtetra
.24965 .34303 .25233 .34569 .25636 .34425 .25368 .34158 Mtetra
.25368 .34158 .25636 .34425 .26039 .34281 .25771 .34013 Mtetra
.955 .665 .449 r
.25771 .34013 .26039 .34281 .26443 .34136 .25699 .39594 Mtetra
.5 .251 .468 r
.25699 .39594 .26443 .34136 .26848 .33991 .26111 .39451 Mtetra
.26111 .39451 .26848 .33991 .26796 .39572 .26524 .39307 Mtetra
.655 .752 .921 r
.26524 .39307 .26796 .39572 .27209 .39429 .26937 .39163 Mtetra
.26937 .39163 .27209 .39429 .27622 .39285 .27351 .39019 Mtetra
.27351 .39019 .27622 .39285 .28036 .39141 .27765 .38875 Mtetra
.27765 .38875 .28036 .39141 .28451 .38997 .2818 .3873 Mtetra
.2818 .3873 .28451 .38997 .28866 .38853 .28596 .38586 Mtetra
.28596 .38586 .28866 .38853 .29282 .38708 .29013 .38441 Mtetra
.29013 .38441 .29282 .38708 .29699 .38563 .2943 .38295 Mtetra
.2943 .38295 .29699 .38563 .30117 .38418 .29848 .3815 Mtetra
.29848 .3815 .30117 .38418 .30535 .38273 .30266 .38004 Mtetra
.30266 .38004 .30535 .38273 .30953 .38127 .30685 .37858 Mtetra
.30685 .37858 .30953 .38127 .31373 .37982 .31105 .37712 Mtetra
.31105 .37712 .31373 .37982 .31793 .37836 .31526 .37566 Mtetra
.31526 .37566 .31793 .37836 .32214 .3769 .31947 .37419 Mtetra
.956 .7 .508 r
.31947 .37419 .32214 .3769 .33213 .28236 .32955 .2796 Mtetra
.662 .743 .91 r
.32955 .2796 .33213 .28236 .33623 .28087 .33366 .2781 Mtetra
.33366 .2781 .33623 .28087 .34034 .27937 .33777 .2766 Mtetra
.33777 .2766 .34034 .27937 .34446 .27787 .34189 .27509 Mtetra
.34189 .27509 .34446 .27787 .34858 .27637 .34601 .27359 Mtetra
.34601 .27359 .34858 .27637 .3527 .27486 .35014 .27208 Mtetra
.35014 .27208 .3527 .27486 .35684 .27335 .35428 .27056 Mtetra
.35428 .27056 .35684 .27335 .36098 .27184 .35843 .26905 Mtetra
.35843 .26905 .36098 .27184 .36513 .27033 .36258 .26753 Mtetra
.36258 .26753 .36513 .27033 .36928 .26882 .36674 .26601 Mtetra
.36674 .26601 .36928 .26882 .37344 .2673 .3709 .26449 Mtetra
.3709 .26449 .37344 .2673 .37761 .26578 .37507 .26297 Mtetra
.37507 .26297 .37761 .26578 .38178 .26426 .37925 .26144 Mtetra
.37925 .26144 .38178 .26426 .38596 .26273 .38343 .25991 Mtetra
0 .103 .619 r
.38343 .25991 .38596 .26273 .38992 .26626 .3874 .26343 Mtetra
.662 .744 .911 r
.3874 .26343 .38992 .26626 .39412 .26473 .3916 .2619 Mtetra
.3916 .2619 .39412 .26473 .39833 .2632 .39581 .26037 Mtetra
.39581 .26037 .39833 .2632 .40254 .26167 .40003 .25883 Mtetra
.40003 .25883 .40254 .26167 .40676 .26013 .40425 .25729 Mtetra
.40425 .25729 .40676 .26013 .41099 .25859 .40848 .25575 Mtetra
.40848 .25575 .41099 .25859 .41522 .25705 .41272 .25421 Mtetra
.41272 .25421 .41522 .25705 .41946 .25551 .41696 .25266 Mtetra
.41696 .25266 .41946 .25551 .4237 .25397 .42121 .25111 Mtetra
.42121 .25111 .4237 .25397 .42796 .25242 .42547 .24956 Mtetra
.42547 .24956 .42796 .25242 .43222 .25087 .42973 .24801 Mtetra
.42973 .24801 .43222 .25087 .43648 .24932 .434 .24645 Mtetra
.434 .24645 .43648 .24932 .44075 .24777 .43828 .24489 Mtetra
.43828 .24489 .44075 .24777 .44503 .24621 .44256 .24333 Mtetra
.44256 .24333 .44503 .24621 .44932 .24465 .44685 .24177 Mtetra
.44685 .24177 .44932 .24465 .4542 .21791 .45115 .2402 Mtetra
0 0 .082 r
.45115 .2402 .4542 .21791 .45846 .21634 .45602 .21343 Mtetra
.664 .741 .908 r
.45602 .21343 .45846 .21634 .46273 .21476 .4603 .21185 Mtetra
.4603 .21185 .46273 .21476 .46701 .21319 .46458 .21027 Mtetra
.46458 .21027 .46701 .21319 .4713 .21161 .46887 .20869 Mtetra
.46887 .20869 .4713 .21161 .47559 .21003 .47317 .2071 Mtetra
.47317 .2071 .47559 .21003 .47989 .20844 .47747 .20551 Mtetra
.47747 .20551 .47989 .20844 .48419 .20686 .48178 .20392 Mtetra
.48178 .20392 .48419 .20686 .4885 .20527 .48609 .20233 Mtetra
.48609 .20233 .4885 .20527 .49282 .20368 .49042 .20073 Mtetra
.958 .617 .287 r
.49042 .20073 .49282 .20368 .49687 .23244 .49445 .22951 Mtetra
.662 .744 .911 r
.49445 .22951 .49687 .23244 .50125 .23085 .49883 .22791 Mtetra
.49883 .22791 .50125 .23085 .50563 .22926 .50321 .22632 Mtetra
.50321 .22632 .50563 .22926 .51002 .22767 .50761 .22472 Mtetra
.50761 .22472 .51002 .22767 .51442 .22607 .51201 .22312 Mtetra
.51201 .22312 .51442 .22607 .51882 .22447 .51642 .22152 Mtetra
.51642 .22152 .51882 .22447 .52323 .22287 .52083 .21991 Mtetra
.52083 .21991 .52323 .22287 .52765 .22127 .52526 .21831 Mtetra
.52526 .21831 .52765 .22127 .53207 .21967 .52969 .21669 Mtetra
.52969 .21669 .53207 .21967 .53651 .21806 .53412 .21508 Mtetra
.53412 .21508 .53651 .21806 .54095 .21645 .53857 .21347 Mtetra
.53857 .21347 .54095 .21645 .54539 .21483 .54302 .21185 Mtetra
.54302 .21185 .54539 .21483 .54985 .21322 .54748 .21023 Mtetra
.54748 .21023 .54985 .21322 .55431 .2116 .55194 .2086 Mtetra
.55194 .2086 .55431 .2116 .55878 .20998 .55642 .20698 Mtetra
.55642 .20698 .55878 .20998 .56325 .20835 .5609 .20535 Mtetra
.5609 .20535 .56325 .20835 .56773 .20673 .56538 .20372 Mtetra
.56538 .20372 .56773 .20673 .57222 .2051 .56988 .20208 Mtetra
.56988 .20208 .57222 .2051 .57672 .20347 .57438 .20045 Mtetra
.57438 .20045 .57672 .20347 .58123 .20183 .57889 .19881 Mtetra
.57889 .19881 .58123 .20183 .58574 .2002 .58341 .19717 Mtetra
.58341 .19717 .58574 .2002 .59026 .19856 .58793 .19552 Mtetra
.972 .662 .349 r
.58793 .19552 .59026 .19856 .59763 .31997 .59522 .31699 Mtetra
.652 .755 .925 r
.59522 .31699 .59763 .31997 .60235 .31836 .59995 .31538 Mtetra
.59995 .31538 .60235 .31836 .60708 .31675 .60468 .31377 Mtetra
.60468 .31377 .60708 .31675 .61182 .31513 .60942 .31215 Mtetra
.60942 .31215 .61182 .31513 .61656 .31352 .61417 .31053 Mtetra
.61417 .31053 .61656 .31352 .62132 .3119 .61893 .3089 Mtetra
.61893 .3089 .62132 .3119 .62608 .31028 .6237 .30728 Mtetra
.6237 .30728 .62608 .31028 .63085 .30865 .62847 .30565 Mtetra
.62847 .30565 .63085 .30865 .63563 .30703 .63326 .30401 Mtetra
.63326 .30401 .63563 .30703 .64041 .3054 .63805 .30238 Mtetra
.63805 .30238 .64041 .3054 .64521 .30376 .64285 .30074 Mtetra
.64285 .30074 .64521 .30376 .65001 .30213 .64766 .2991 Mtetra
.64766 .2991 .65001 .30213 .65482 .30049 .65247 .29746 Mtetra
.65247 .29746 .65482 .30049 .65964 .29885 .6573 .29581 Mtetra
.6573 .29581 .65964 .29885 .66446 .29721 .66213 .29416 Mtetra
.66213 .29416 .66446 .29721 .6693 .29556 .66697 .29251 Mtetra
.66697 .29251 .6693 .29556 .67414 .29391 .67182 .29086 Mtetra
.67182 .29086 .67414 .29391 .67899 .29226 .67668 .2892 Mtetra
.67668 .2892 .67899 .29226 .68385 .2906 .68154 .28754 Mtetra
.68154 .28754 .68385 .2906 .68872 .28894 .68642 .28588 Mtetra
.68642 .28588 .68872 .28894 .6936 .28728 .6913 .28421 Mtetra
.6913 .28421 .6936 .28728 .69849 .28562 .69619 .28254 Mtetra
.69619 .28254 .69849 .28562 .70338 .28395 .70109 .28087 Mtetra
.70109 .28087 .70338 .28395 .70828 .28228 .706 .27919 Mtetra
.706 .27919 .70828 .28228 .71319 .28061 .71091 .27752 Mtetra
.71091 .27752 .71319 .28061 .71811 .27894 .71584 .27584 Mtetra
.931 .569 .154 r
.71584 .27584 .71811 .27894 .72304 .27726 .72293 .30824 Mtetra
.486 .22 .436 r
.72293 .30824 .72304 .27726 .72798 .27558 .72793 .30656 Mtetra
.72793 .30656 .72798 .27558 .73521 .30798 .73294 .30489 Mtetra
.649 .759 .929 r
.73294 .30489 .73521 .30798 .74022 .30631 .73795 .3032 Mtetra
.73795 .3032 .74022 .30631 .74524 .30463 .74298 .30152 Mtetra
.74298 .30152 .74524 .30463 .75027 .30295 .74801 .29983 Mtetra
.74801 .29983 .75027 .30295 .7553 .30126 .75305 .29814 Mtetra
.75305 .29814 .7553 .30126 .76035 .29957 .7581 .29645 Mtetra
.7581 .29645 .76035 .29957 .7654 .29788 .76316 .29476 Mtetra
.76316 .29476 .7654 .29788 .77047 .29619 .76823 .29306 Mtetra
.648 .76 .931 r
.09114 .53227 .0941 .53471 .09808 .53339 .09512 .53095 Mtetra
.09512 .53095 .09808 .53339 .10206 .53207 .09911 .52962 Mtetra
.09911 .52962 .10206 .53207 .10605 .53074 .1031 .52829 Mtetra
.1031 .52829 .10605 .53074 .11005 .52942 .1071 .52696 Mtetra
.1071 .52696 .11005 .52942 .11405 .52809 .11111 .52563 Mtetra
.11111 .52563 .11405 .52809 .11806 .52676 .11512 .52429 Mtetra
.11512 .52429 .11806 .52676 .12207 .52542 .11913 .52296 Mtetra
.11913 .52296 .12207 .52542 .12609 .52409 .12316 .52162 Mtetra
.12316 .52162 .12609 .52409 .13012 .52275 .12719 .52028 Mtetra
.12719 .52028 .13012 .52275 .13416 .52141 .13123 .51894 Mtetra
.13123 .51894 .13416 .52141 .1382 .52007 .13527 .51759 Mtetra
.13527 .51759 .1382 .52007 .14224 .51873 .13932 .51624 Mtetra
.13932 .51624 .14224 .51873 .14629 .51738 .14338 .51489 Mtetra
.14338 .51489 .14629 .51738 .15035 .51603 .14744 .51354 Mtetra
.14744 .51354 .15035 .51603 .15442 .51469 .15151 .51219 Mtetra
.15151 .51219 .15442 .51469 .15849 .51333 .15558 .51083 Mtetra
.15558 .51083 .15849 .51333 .16257 .51198 .15967 .50947 Mtetra
.15967 .50947 .16257 .51198 .16665 .51062 .16376 .50811 Mtetra
.16376 .50811 .16665 .51062 .17075 .50926 .16785 .50675 Mtetra
.16785 .50675 .17075 .50926 .17484 .5079 .17195 .50539 Mtetra
.17195 .50539 .17484 .5079 .17895 .50654 .17606 .50402 Mtetra
.17606 .50402 .17895 .50654 .18306 .50518 .18018 .50265 Mtetra
.18018 .50265 .18306 .50518 .18718 .50381 .1843 .50128 Mtetra
.1843 .50128 .18718 .50381 .1913 .50244 .18843 .49991 Mtetra
.18843 .49991 .1913 .50244 .19543 .50107 .19256 .49853 Mtetra
.19256 .49853 .19543 .50107 .19957 .49969 .1967 .49715 Mtetra
.1967 .49715 .19957 .49969 .20371 .49832 .20085 .49577 Mtetra
.20085 .49577 .20371 .49832 .20787 .49694 .205 .49439 Mtetra
.205 .49439 .20787 .49694 .21202 .49556 .20917 .49301 Mtetra
.20917 .49301 .21202 .49556 .21619 .49418 .21333 .49162 Mtetra
.21333 .49162 .21619 .49418 .22036 .49279 .21751 .49023 Mtetra
.21751 .49023 .22036 .49279 .22454 .49141 .22169 .48884 Mtetra
.22169 .48884 .22454 .49141 .2416 .34592 .22588 .48745 Mtetra
0 0 .095 r
.22588 .48745 .2416 .34592 .24562 .34447 .24293 .34181 Mtetra
.954 .666 .453 r
.24293 .34181 .24562 .34447 .24965 .34303 .24192 .3976 Mtetra
.5 .25 .467 r
.24192 .3976 .24965 .34303 .25368 .34158 .24603 .39616 Mtetra
.24603 .39616 .25368 .34158 .25771 .34013 .25014 .39473 Mtetra
.25014 .39473 .25771 .34013 .25699 .39594 .25425 .39329 Mtetra
.655 .752 .921 r
.25425 .39329 .25699 .39594 .26111 .39451 .25838 .39186 Mtetra
.25838 .39186 .26111 .39451 .26524 .39307 .26251 .39042 Mtetra
.26251 .39042 .26524 .39307 .26937 .39163 .26664 .38897 Mtetra
.26664 .38897 .26937 .39163 .27351 .39019 .27079 .38753 Mtetra
.27079 .38753 .27351 .39019 .27765 .38875 .27493 .38608 Mtetra
.27493 .38608 .27765 .38875 .2818 .3873 .27909 .38463 Mtetra
.27909 .38463 .2818 .3873 .28596 .38586 .28325 .38318 Mtetra
.28325 .38318 .28596 .38586 .29013 .38441 .28742 .38172 Mtetra
.28742 .38172 .29013 .38441 .2943 .38295 .2916 .38027 Mtetra
.2916 .38027 .2943 .38295 .29848 .3815 .29578 .37881 Mtetra
.29578 .37881 .29848 .3815 .30266 .38004 .29997 .37735 Mtetra
.29997 .37735 .30266 .38004 .30685 .37858 .30416 .37588 Mtetra
.30416 .37588 .30685 .37858 .31105 .37712 .30837 .37442 Mtetra
.30837 .37442 .31105 .37712 .31526 .37566 .31257 .37295 Mtetra
.31257 .37295 .31526 .37566 .31947 .37419 .31679 .37148 Mtetra
.31679 .37148 .31947 .37419 .32955 .2796 .32101 .37 Mtetra
0 0 .139 r
.32101 .37 .32955 .2796 .33366 .2781 .33107 .27532 Mtetra
.662 .743 .91 r
.33107 .27532 .33366 .2781 .33777 .2766 .33519 .27382 Mtetra
.33519 .27382 .33777 .2766 .34189 .27509 .33931 .27231 Mtetra
.33931 .27231 .34189 .27509 .34601 .27359 .34344 .2708 Mtetra
.34344 .2708 .34601 .27359 .35014 .27208 .34758 .26928 Mtetra
.34758 .26928 .35014 .27208 .35428 .27056 .35172 .26777 Mtetra
.35172 .26777 .35428 .27056 .35843 .26905 .35587 .26625 Mtetra
.35587 .26625 .35843 .26905 .36258 .26753 .36002 .26473 Mtetra
.36002 .26473 .36258 .26753 .36674 .26601 .36418 .2632 Mtetra
.36418 .2632 .36674 .26601 .3709 .26449 .36835 .26168 Mtetra
.36835 .26168 .3709 .26449 .37507 .26297 .37253 .26015 Mtetra
.37253 .26015 .37507 .26297 .37925 .26144 .37671 .25862 Mtetra
.37671 .25862 .37925 .26144 .38343 .25991 .3809 .25709 Mtetra
0 .103 .619 r
.3809 .25709 .38343 .25991 .3874 .26343 .38486 .2606 Mtetra
.662 .744 .911 r
.38486 .2606 .3874 .26343 .3916 .2619 .38907 .25907 Mtetra
.38907 .25907 .3916 .2619 .39581 .26037 .39328 .25753 Mtetra
.39328 .25753 .39581 .26037 .40003 .25883 .3975 .25599 Mtetra
.3975 .25599 .40003 .25883 .40425 .25729 .40173 .25444 Mtetra
.40173 .25444 .40425 .25729 .40848 .25575 .40596 .2529 Mtetra
.40596 .2529 .40848 .25575 .41272 .25421 .4102 .25135 Mtetra
.4102 .25135 .41272 .25421 .41696 .25266 .41445 .2498 Mtetra
.41445 .2498 .41696 .25266 .42121 .25111 .41871 .24824 Mtetra
.41871 .24824 .42121 .25111 .42547 .24956 .42297 .24669 Mtetra
.42297 .24669 .42547 .24956 .42973 .24801 .42723 .24513 Mtetra
.42723 .24513 .42973 .24801 .434 .24645 .43151 .24357 Mtetra
.43151 .24357 .434 .24645 .43828 .24489 .43579 .24201 Mtetra
.43579 .24201 .43828 .24489 .44256 .24333 .44008 .24044 Mtetra
.44008 .24044 .44256 .24333 .44685 .24177 .44437 .23887 Mtetra
.44437 .23887 .44685 .24177 .45115 .2402 .44867 .2373 Mtetra
.44867 .2373 .45115 .2402 .45602 .21343 .45298 .23573 Mtetra
0 0 .082 r
.45298 .23573 .45602 .21343 .4603 .21185 .45786 .20893 Mtetra
.664 .741 .908 r
.45786 .20893 .4603 .21185 .46458 .21027 .46214 .20735 Mtetra
.46214 .20735 .46458 .21027 .46887 .20869 .46644 .20576 Mtetra
.46644 .20576 .46887 .20869 .47317 .2071 .47074 .20417 Mtetra
.47074 .20417 .47317 .2071 .47747 .20551 .47504 .20258 Mtetra
.47504 .20258 .47747 .20551 .48178 .20392 .47936 .20098 Mtetra
.47936 .20098 .48178 .20392 .48609 .20233 .48368 .19938 Mtetra
.48368 .19938 .48609 .20233 .49042 .20073 .48801 .19778 Mtetra
.958 .617 .287 r
.48801 .19778 .49042 .20073 .49445 .22951 .49201 .22656 Mtetra
.662 .744 .911 r
.49201 .22656 .49445 .22951 .49883 .22791 .4964 .22497 Mtetra
.4964 .22497 .49883 .22791 .50321 .22632 .50079 .22337 Mtetra
.50079 .22337 .50321 .22632 .50761 .22472 .50519 .22176 Mtetra
.50519 .22176 .50761 .22472 .51201 .22312 .50959 .22016 Mtetra
.50959 .22016 .51201 .22312 .51642 .22152 .51401 .21855 Mtetra
.51401 .21855 .51642 .22152 .52083 .21991 .51843 .21694 Mtetra
.51843 .21694 .52083 .21991 .52526 .21831 .52286 .21533 Mtetra
.52286 .21533 .52526 .21831 .52969 .21669 .52729 .21372 Mtetra
.52729 .21372 .52969 .21669 .53412 .21508 .53173 .2121 Mtetra
.53173 .2121 .53412 .21508 .53857 .21347 .53618 .21048 Mtetra
.53618 .21048 .53857 .21347 .54302 .21185 .54064 .20885 Mtetra
.54064 .20885 .54302 .21185 .54748 .21023 .5451 .20723 Mtetra
.5451 .20723 .54748 .21023 .55194 .2086 .54957 .2056 Mtetra
.54957 .2056 .55194 .2086 .55642 .20698 .55405 .20397 Mtetra
.55405 .20397 .55642 .20698 .5609 .20535 .55853 .20234 Mtetra
.55853 .20234 .5609 .20535 .56538 .20372 .56303 .2007 Mtetra
.56303 .2007 .56538 .20372 .56988 .20208 .56752 .19906 Mtetra
.56752 .19906 .56988 .20208 .57438 .20045 .57203 .19742 Mtetra
.57203 .19742 .57438 .20045 .57889 .19881 .57655 .19578 Mtetra
.57655 .19578 .57889 .19881 .58341 .19717 .58107 .19413 Mtetra
.973 .666 .359 r
.58107 .19413 .58341 .19717 .58793 .19552 .58876 .34943 Mtetra
.511 .273 .49 r
.58876 .34943 .58793 .19552 .59522 .31699 .59353 .34783 Mtetra
.485 .218 .435 r
.59353 .34783 .59522 .31699 .59995 .31538 .59832 .34622 Mtetra
0 0 .215 r
.59832 .34622 .59995 .31538 .60468 .31377 .60227 .31078 Mtetra
.652 .755 .925 r
.60227 .31078 .60468 .31377 .60942 .31215 .60702 .30915 Mtetra
.60702 .30915 .60942 .31215 .61417 .31053 .61178 .30753 Mtetra
.61178 .30753 .61417 .31053 .61893 .3089 .61654 .3059 Mtetra
.61654 .3059 .61893 .3089 .6237 .30728 .62131 .30427 Mtetra
.62131 .30427 .6237 .30728 .62847 .30565 .62609 .30263 Mtetra
.62609 .30263 .62847 .30565 .63326 .30401 .63088 .30099 Mtetra
.63088 .30099 .63326 .30401 .63805 .30238 .63568 .29935 Mtetra
.63568 .29935 .63805 .30238 .64285 .30074 .64048 .29771 Mtetra
.64048 .29771 .64285 .30074 .64766 .2991 .6453 .29607 Mtetra
.6453 .29607 .64766 .2991 .65247 .29746 .65012 .29442 Mtetra
.65012 .29442 .65247 .29746 .6573 .29581 .65495 .29277 Mtetra
.65495 .29277 .6573 .29581 .66213 .29416 .65979 .29111 Mtetra
.65979 .29111 .66213 .29416 .66697 .29251 .66463 .28945 Mtetra
.66463 .28945 .66697 .29251 .67182 .29086 .66949 .28779 Mtetra
.66949 .28779 .67182 .29086 .67668 .2892 .67435 .28613 Mtetra
.67435 .28613 .67668 .2892 .68154 .28754 .67922 .28447 Mtetra
.67922 .28447 .68154 .28754 .68642 .28588 .6841 .2828 Mtetra
.6841 .2828 .68642 .28588 .6913 .28421 .68899 .28113 Mtetra
.68899 .28113 .6913 .28421 .69619 .28254 .69389 .27945 Mtetra
.69389 .27945 .69619 .28254 .70109 .28087 .69879 .27777 Mtetra
.69879 .27777 .70109 .28087 .706 .27919 .70371 .27609 Mtetra
.933 .572 .161 r
.70371 .27609 .706 .27919 .71091 .27752 .71065 .3085 Mtetra
.485 .218 .435 r
.71065 .3085 .71091 .27752 .71584 .27584 .71564 .30682 Mtetra
.71564 .30682 .71584 .27584 .72293 .30824 .72064 .30514 Mtetra
.649 .759 .929 r
.72064 .30514 .72293 .30824 .72793 .30656 .72564 .30346 Mtetra
.72564 .30346 .72793 .30656 .73294 .30489 .73065 .30178 Mtetra
.73065 .30178 .73294 .30489 .73795 .3032 .73568 .30009 Mtetra
.73568 .30009 .73795 .3032 .74298 .30152 .74071 .2984 Mtetra
.74071 .2984 .74298 .30152 .74801 .29983 .74575 .29671 Mtetra
.74575 .29671 .74801 .29983 .75305 .29814 .7508 .29502 Mtetra
.7508 .29502 .75305 .29814 .7581 .29645 .75585 .29332 Mtetra
.75585 .29332 .7581 .29645 .76316 .29476 .76092 .29162 Mtetra
.76092 .29162 .76316 .29476 .76823 .29306 .766 .28991 Mtetra
.648 .76 .931 r
.08817 .52983 .09114 .53227 .09512 .53095 .09215 .5285 Mtetra
.09215 .5285 .09512 .53095 .09911 .52962 .09614 .52717 Mtetra
.09614 .52717 .09911 .52962 .1031 .52829 .10014 .52583 Mtetra
.10014 .52583 .1031 .52829 .1071 .52696 .10414 .5245 Mtetra
.10414 .5245 .1071 .52696 .11111 .52563 .10815 .52316 Mtetra
.10815 .52316 .11111 .52563 .11512 .52429 .11217 .52183 Mtetra
.11217 .52183 .11512 .52429 .11913 .52296 .11619 .52048 Mtetra
.11619 .52048 .11913 .52296 .12316 .52162 .12022 .51914 Mtetra
.12022 .51914 .12316 .52162 .12719 .52028 .12425 .5178 Mtetra
.12425 .5178 .12719 .52028 .13123 .51894 .12829 .51645 Mtetra
.12829 .51645 .13123 .51894 .13527 .51759 .13234 .5151 Mtetra
.13234 .5151 .13527 .51759 .13932 .51624 .13639 .51375 Mtetra
.13639 .51375 .13932 .51624 .14338 .51489 .14045 .5124 Mtetra
.14045 .5124 .14338 .51489 .14744 .51354 .14452 .51104 Mtetra
.14452 .51104 .14744 .51354 .15151 .51219 .14859 .50968 Mtetra
.14859 .50968 .15151 .51219 .15558 .51083 .15267 .50832 Mtetra
.15267 .50832 .15558 .51083 .15967 .50947 .15676 .50696 Mtetra
.15676 .50696 .15967 .50947 .16376 .50811 .16085 .5056 Mtetra
.16085 .5056 .16376 .50811 .16785 .50675 .16495 .50423 Mtetra
.16495 .50423 .16785 .50675 .17195 .50539 .16905 .50286 Mtetra
.16905 .50286 .17195 .50539 .17606 .50402 .17316 .50149 Mtetra
.17316 .50149 .17606 .50402 .18018 .50265 .17728 .50012 Mtetra
.17728 .50012 .18018 .50265 .1843 .50128 .18141 .49874 Mtetra
.18141 .49874 .1843 .50128 .18843 .49991 .18554 .49736 Mtetra
.18554 .49736 .18843 .49991 .19256 .49853 .18968 .49598 Mtetra
.18968 .49598 .19256 .49853 .1967 .49715 .19382 .4946 Mtetra
.19382 .4946 .1967 .49715 .20085 .49577 .19798 .49322 Mtetra
.19798 .49322 .20085 .49577 .205 .49439 .20213 .49183 Mtetra
.20213 .49183 .205 .49439 .20917 .49301 .2063 .49044 Mtetra
.2063 .49044 .20917 .49301 .21333 .49162 .21047 .48905 Mtetra
.21047 .48905 .21333 .49162 .21751 .49023 .21465 .48766 Mtetra
.21465 .48766 .21751 .49023 .22169 .48884 .21884 .48626 Mtetra
.21884 .48626 .22169 .48884 .22588 .48745 .22303 .48487 Mtetra
.948 .699 .529 r
.22303 .48487 .22588 .48745 .24293 .34181 .23507 .39639 Mtetra
.499 .248 .466 r
.23507 .39639 .24293 .34181 .24192 .3976 .23917 .39495 Mtetra
.655 .752 .921 r
.23917 .39495 .24192 .3976 .24603 .39616 .24328 .39352 Mtetra
.24328 .39352 .24603 .39616 .25014 .39473 .24739 .39208 Mtetra
.24739 .39208 .25014 .39473 .25425 .39329 .25151 .39064 Mtetra
.25151 .39064 .25425 .39329 .25838 .39186 .25564 .38919 Mtetra
.25564 .38919 .25838 .39186 .26251 .39042 .25977 .38775 Mtetra
.25977 .38775 .26251 .39042 .26664 .38897 .26391 .3863 Mtetra
.26391 .3863 .26664 .38897 .27079 .38753 .26806 .38485 Mtetra
.26806 .38485 .27079 .38753 .27493 .38608 .27221 .3834 Mtetra
.27221 .3834 .27493 .38608 .27909 .38463 .27637 .38195 Mtetra
.27637 .38195 .27909 .38463 .28325 .38318 .28054 .38049 Mtetra
.28054 .38049 .28325 .38318 .28742 .38172 .28471 .37903 Mtetra
.28471 .37903 .28742 .38172 .2916 .38027 .28889 .37757 Mtetra
.28889 .37757 .2916 .38027 .29578 .37881 .29307 .37611 Mtetra
.29307 .37611 .29578 .37881 .29997 .37735 .29727 .37464 Mtetra
.29727 .37464 .29997 .37735 .30416 .37588 .30147 .37317 Mtetra
.30147 .37317 .30416 .37588 .30837 .37442 .30567 .3717 Mtetra
.30567 .3717 .30837 .37442 .31257 .37295 .30989 .37023 Mtetra
.30989 .37023 .31257 .37295 .31679 .37148 .3141 .36875 Mtetra
.3141 .36875 .31679 .37148 .32101 .37 .31833 .36728 Mtetra
.31833 .36728 .32101 .37 .33107 .27532 .32256 .3658 Mtetra
0 0 .139 r
.32256 .3658 .33107 .27532 .33519 .27382 .3326 .27103 Mtetra
.662 .743 .91 r
.3326 .27103 .33519 .27382 .33931 .27231 .33673 .26952 Mtetra
.33673 .26952 .33931 .27231 .34344 .2708 .34086 .268 Mtetra
.34086 .268 .34344 .2708 .34758 .26928 .345 .26648 Mtetra
.345 .26648 .34758 .26928 .35172 .26777 .34915 .26496 Mtetra
.34915 .26496 .35172 .26777 .35587 .26625 .3533 .26344 Mtetra
.3533 .26344 .35587 .26625 .36002 .26473 .35746 .26191 Mtetra
.35746 .26191 .36002 .26473 .36418 .2632 .36163 .26038 Mtetra
.36163 .26038 .36418 .2632 .36835 .26168 .3658 .25885 Mtetra
.3658 .25885 .36835 .26168 .37253 .26015 .36998 .25732 Mtetra
.36998 .25732 .37253 .26015 .37671 .25862 .37416 .25579 Mtetra
.37416 .25579 .37671 .25862 .3809 .25709 .37835 .25425 Mtetra
0 .103 .619 r
.37835 .25425 .3809 .25709 .38486 .2606 .38232 .25777 Mtetra
.662 .744 .911 r
.38232 .25777 .38486 .2606 .38907 .25907 .38653 .25622 Mtetra
.38653 .25622 .38907 .25907 .39328 .25753 .39075 .25468 Mtetra
.39075 .25468 .39328 .25753 .3975 .25599 .39497 .25314 Mtetra
.39497 .25314 .3975 .25599 .40173 .25444 .3992 .25159 Mtetra
.3992 .25159 .40173 .25444 .40596 .2529 .40344 .25004 Mtetra
.40344 .25004 .40596 .2529 .4102 .25135 .40769 .24848 Mtetra
.40769 .24848 .4102 .25135 .41445 .2498 .41194 .24693 Mtetra
.41194 .24693 .41445 .2498 .41871 .24824 .4162 .24537 Mtetra
.4162 .24537 .41871 .24824 .42297 .24669 .42046 .24381 Mtetra
.42046 .24381 .42297 .24669 .42723 .24513 .42473 .24225 Mtetra
.42473 .24225 .42723 .24513 .43151 .24357 .42901 .24068 Mtetra
.42901 .24068 .43151 .24357 .43579 .24201 .4333 .23911 Mtetra
.4333 .23911 .43579 .24201 .44008 .24044 .43759 .23754 Mtetra
.43759 .23754 .44008 .24044 .44437 .23887 .44189 .23597 Mtetra
.44189 .23597 .44437 .23887 .44867 .2373 .44619 .2344 Mtetra
.44619 .2344 .44867 .2373 .45298 .23573 .45051 .23282 Mtetra
.45051 .23282 .45298 .23573 .45786 .20893 .45483 .23124 Mtetra
0 0 .082 r
.45483 .23124 .45786 .20893 .46214 .20735 .4597 .20441 Mtetra
.664 .741 .908 r
.4597 .20441 .46214 .20735 .46644 .20576 .46399 .20282 Mtetra
.46399 .20282 .46644 .20576 .47074 .20417 .4683 .20123 Mtetra
.4683 .20123 .47074 .20417 .47504 .20258 .47261 .19963 Mtetra
.47261 .19963 .47504 .20258 .47936 .20098 .47693 .19803 Mtetra
.47693 .19803 .47936 .20098 .48368 .19938 .48125 .19643 Mtetra
.48125 .19643 .48368 .19938 .48801 .19778 .48559 .19482 Mtetra
.958 .617 .287 r
.48559 .19482 .48801 .19778 .49201 .22656 .48957 .22361 Mtetra
.662 .744 .911 r
.48957 .22361 .49201 .22656 .4964 .22497 .49396 .22201 Mtetra
.49396 .22201 .4964 .22497 .50079 .22337 .49836 .22041 Mtetra
.49836 .22041 .50079 .22337 .50519 .22176 .50276 .2188 Mtetra
.50276 .2188 .50519 .22176 .50959 .22016 .50717 .21719 Mtetra
.50717 .21719 .50959 .22016 .51401 .21855 .51159 .21558 Mtetra
.51159 .21558 .51401 .21855 .51843 .21694 .51602 .21396 Mtetra
.51602 .21396 .51843 .21694 .52286 .21533 .52045 .21235 Mtetra
.52045 .21235 .52286 .21533 .52729 .21372 .52489 .21073 Mtetra
.52489 .21073 .52729 .21372 .53173 .2121 .52933 .2091 Mtetra
.52933 .2091 .53173 .2121 .53618 .21048 .53379 .20748 Mtetra
.53379 .20748 .53618 .21048 .54064 .20885 .53825 .20585 Mtetra
.53825 .20585 .54064 .20885 .5451 .20723 .54272 .20422 Mtetra
.54272 .20422 .5451 .20723 .54957 .2056 .54719 .20259 Mtetra
.54719 .20259 .54957 .2056 .55405 .20397 .55167 .20095 Mtetra
.55167 .20095 .55405 .20397 .55853 .20234 .55616 .19931 Mtetra
.55616 .19931 .55853 .20234 .56303 .2007 .56066 .19767 Mtetra
.56066 .19767 .56303 .2007 .56752 .19906 .56516 .19603 Mtetra
.56516 .19603 .56752 .19906 .57203 .19742 .56968 .19438 Mtetra
.56968 .19438 .57203 .19742 .57655 .19578 .5742 .19273 Mtetra
.973 .667 .361 r
.5742 .19273 .57655 .19578 .58107 .19413 .58153 .34807 Mtetra
.51 .272 .489 r
.58153 .34807 .58107 .19413 .58876 .34943 .5863 .34647 Mtetra
.649 .759 .929 r
.5863 .34647 .58876 .34943 .59353 .34783 .59108 .34486 Mtetra
.59108 .34486 .59353 .34783 .59832 .34622 .59587 .34325 Mtetra
.59587 .34325 .59832 .34622 .60227 .31078 .60067 .34163 Mtetra
.484 .217 .434 r
.60067 .34163 .60227 .31078 .60702 .30915 .60547 .34002 Mtetra
0 0 .217 r
.60547 .34002 .60702 .30915 .61178 .30753 .60937 .30452 Mtetra
.652 .755 .925 r
.60937 .30452 .61178 .30753 .61654 .3059 .61414 .30288 Mtetra
.61414 .30288 .61654 .3059 .62131 .30427 .61892 .30125 Mtetra
.61892 .30125 .62131 .30427 .62609 .30263 .6237 .29961 Mtetra
.6237 .29961 .62609 .30263 .63088 .30099 .6285 .29796 Mtetra
.6285 .29796 .63088 .30099 .63568 .29935 .6333 .29632 Mtetra
.6333 .29632 .63568 .29935 .64048 .29771 .63811 .29467 Mtetra
.63811 .29467 .64048 .29771 .6453 .29607 .64293 .29302 Mtetra
.64293 .29302 .6453 .29607 .65012 .29442 .64776 .29137 Mtetra
.64776 .29137 .65012 .29442 .65495 .29277 .65259 .28971 Mtetra
.65259 .28971 .65495 .29277 .65979 .29111 .65744 .28805 Mtetra
.65744 .28805 .65979 .29111 .66463 .28945 .66229 .28639 Mtetra
.66229 .28639 .66463 .28945 .66949 .28779 .66715 .28472 Mtetra
.66715 .28472 .66949 .28779 .67435 .28613 .67202 .28305 Mtetra
.67202 .28305 .67435 .28613 .67922 .28447 .6769 .28138 Mtetra
.6769 .28138 .67922 .28447 .6841 .2828 .68178 .27971 Mtetra
.68178 .27971 .6841 .2828 .68899 .28113 .68668 .27803 Mtetra
.68668 .27803 .68899 .28113 .69389 .27945 .69158 .27635 Mtetra
.935 .575 .169 r
.69158 .27635 .69389 .27945 .69879 .27777 .69838 .30875 Mtetra
.484 .217 .434 r
.69838 .30875 .69879 .27777 .70371 .27609 .70335 .30708 Mtetra
.70335 .30708 .70371 .27609 .71065 .3085 .70834 .3054 Mtetra
.649 .759 .929 r
.70834 .3054 .71065 .3085 .71564 .30682 .71333 .30372 Mtetra
.71333 .30372 .71564 .30682 .72064 .30514 .71833 .30204 Mtetra
.71833 .30204 .72064 .30514 .72564 .30346 .72334 .30035 Mtetra
.72334 .30035 .72564 .30346 .73065 .30178 .72836 .29866 Mtetra
.72836 .29866 .73065 .30178 .73568 .30009 .73339 .29697 Mtetra
.73339 .29697 .73568 .30009 .74071 .2984 .73843 .29528 Mtetra
.73843 .29528 .74071 .2984 .74575 .29671 .74348 .29358 Mtetra
.74348 .29358 .74575 .29671 .7508 .29502 .74853 .29188 Mtetra
.74853 .29188 .7508 .29502 .75585 .29332 .75359 .29017 Mtetra
.75359 .29017 .75585 .29332 .76092 .29162 .75867 .28847 Mtetra
.75867 .28847 .76092 .29162 .766 .28991 .76375 .28676 Mtetra
.648 .76 .931 r
.08519 .52737 .08817 .52983 .09215 .5285 .08918 .52604 Mtetra
.08918 .52604 .09215 .5285 .09614 .52717 .09317 .52471 Mtetra
.09317 .52471 .09614 .52717 .10014 .52583 .09717 .52337 Mtetra
.09717 .52337 .10014 .52583 .10414 .5245 .10118 .52203 Mtetra
.10118 .52203 .10414 .5245 .10815 .52316 .10519 .52069 Mtetra
.10519 .52069 .10815 .52316 .11217 .52183 .10921 .51935 Mtetra
.10921 .51935 .11217 .52183 .11619 .52048 .11323 .518 Mtetra
.11323 .518 .11619 .52048 .12022 .51914 .11726 .51666 Mtetra
.11726 .51666 .12022 .51914 .12425 .5178 .1213 .51531 Mtetra
.1213 .51531 .12425 .5178 .12829 .51645 .12535 .51396 Mtetra
.12535 .51396 .12829 .51645 .13234 .5151 .1294 .5126 Mtetra
.1294 .5126 .13234 .5151 .13639 .51375 .13345 .51125 Mtetra
.13345 .51125 .13639 .51375 .14045 .5124 .13752 .50989 Mtetra
.13752 .50989 .14045 .5124 .14452 .51104 .14159 .50853 Mtetra
.14159 .50853 .14452 .51104 .14859 .50968 .14566 .50717 Mtetra
.14566 .50717 .14859 .50968 .15267 .50832 .14975 .50581 Mtetra
.14975 .50581 .15267 .50832 .15676 .50696 .15384 .50444 Mtetra
.15384 .50444 .15676 .50696 .16085 .5056 .15793 .50307 Mtetra
.15793 .50307 .16085 .5056 .16495 .50423 .16204 .5017 Mtetra
.16204 .5017 .16495 .50423 .16905 .50286 .16614 .50033 Mtetra
.16614 .50033 .16905 .50286 .17316 .50149 .17026 .49895 Mtetra
.17026 .49895 .17316 .50149 .17728 .50012 .17438 .49758 Mtetra
.17438 .49758 .17728 .50012 .18141 .49874 .17851 .4962 Mtetra
.17851 .4962 .18141 .49874 .18554 .49736 .18265 .49482 Mtetra
.18265 .49482 .18554 .49736 .18968 .49598 .18679 .49343 Mtetra
.18679 .49343 .18968 .49598 .19382 .4946 .19094 .49205 Mtetra
.19094 .49205 .19382 .4946 .19798 .49322 .19509 .49066 Mtetra
.19509 .49066 .19798 .49322 .20213 .49183 .19926 .48927 Mtetra
.19926 .48927 .20213 .49183 .2063 .49044 .20343 .48787 Mtetra
.20343 .48787 .2063 .49044 .21047 .48905 .2076 .48648 Mtetra
.2076 .48648 .21047 .48905 .21465 .48766 .21178 .48508 Mtetra
.21178 .48508 .21465 .48766 .21884 .48626 .21597 .48368 Mtetra
.21597 .48368 .21884 .48626 .22303 .48487 .22017 .48228 Mtetra
.948 .699 .529 r
.22017 .48228 .22303 .48487 .23507 .39639 .2323 .39374 Mtetra
.655 .752 .921 r
.2323 .39374 .23507 .39639 .23917 .39495 .2364 .3923 Mtetra
.2364 .3923 .23917 .39495 .24328 .39352 .24051 .39086 Mtetra
.24051 .39086 .24328 .39352 .24739 .39208 .24463 .38942 Mtetra
.24463 .38942 .24739 .39208 .25151 .39064 .24876 .38797 Mtetra
.24876 .38797 .25151 .39064 .25564 .38919 .25289 .38653 Mtetra
.25289 .38653 .25564 .38919 .25977 .38775 .25702 .38508 Mtetra
.25702 .38508 .25977 .38775 .26391 .3863 .26117 .38362 Mtetra
.26117 .38362 .26391 .3863 .26806 .38485 .26532 .38217 Mtetra
.26532 .38217 .26806 .38485 .27221 .3834 .26948 .38071 Mtetra
.26948 .38071 .27221 .3834 .27637 .38195 .27364 .37926 Mtetra
.27364 .37926 .27637 .38195 .28054 .38049 .27781 .3778 Mtetra
.27781 .3778 .28054 .38049 .28471 .37903 .28199 .37633 Mtetra
.28199 .37633 .28471 .37903 .28889 .37757 .28617 .37487 Mtetra
.28617 .37487 .28889 .37757 .29307 .37611 .29036 .3734 Mtetra
.29036 .3734 .29307 .37611 .29727 .37464 .29456 .37193 Mtetra
.29456 .37193 .29727 .37464 .30147 .37317 .29876 .37046 Mtetra
.29876 .37046 .30147 .37317 .30567 .3717 .30297 .36898 Mtetra
.30297 .36898 .30567 .3717 .30989 .37023 .30719 .3675 Mtetra
.30719 .3675 .30989 .37023 .3141 .36875 .31141 .36603 Mtetra
.31141 .36603 .3141 .36875 .31833 .36728 .31564 .36454 Mtetra
.31564 .36454 .31833 .36728 .32256 .3658 .31988 .36306 Mtetra
.957 .7 .506 r
.31988 .36306 .32256 .3658 .3326 .27103 .33001 .26823 Mtetra
.662 .743 .91 r
.33001 .26823 .3326 .27103 .33673 .26952 .33414 .26671 Mtetra
.33414 .26671 .33673 .26952 .34086 .268 .33828 .26519 Mtetra
.33828 .26519 .34086 .268 .345 .26648 .34242 .26367 Mtetra
.34242 .26367 .345 .26648 .34915 .26496 .34657 .26215 Mtetra
.34657 .26215 .34915 .26496 .3533 .26344 .35073 .26062 Mtetra
.35073 .26062 .3533 .26344 .35746 .26191 .35489 .25909 Mtetra
.35489 .25909 .35746 .26191 .36163 .26038 .35906 .25756 Mtetra
.35906 .25756 .36163 .26038 .3658 .25885 .36324 .25602 Mtetra
.36324 .25602 .3658 .25885 .36998 .25732 .36742 .25449 Mtetra
.36742 .25449 .36998 .25732 .37416 .25579 .37161 .25295 Mtetra
.37161 .25295 .37416 .25579 .37835 .25425 .3758 .2514 Mtetra
0 .103 .619 r
.3758 .2514 .37835 .25425 .38232 .25777 .37977 .25492 Mtetra
.662 .744 .911 r
.37977 .25492 .38232 .25777 .38653 .25622 .38398 .25337 Mtetra
.38398 .25337 .38653 .25622 .39075 .25468 .3882 .25183 Mtetra
.3882 .25183 .39075 .25468 .39497 .25314 .39243 .25028 Mtetra
.39243 .25028 .39497 .25314 .3992 .25159 .39667 .24872 Mtetra
.39667 .24872 .3992 .25159 .40344 .25004 .40091 .24717 Mtetra
.40091 .24717 .40344 .25004 .40769 .24848 .40516 .24561 Mtetra
.40516 .24561 .40769 .24848 .41194 .24693 .40942 .24405 Mtetra
.40942 .24405 .41194 .24693 .4162 .24537 .41368 .24249 Mtetra
.41368 .24249 .4162 .24537 .42046 .24381 .41795 .24092 Mtetra
.41795 .24092 .42046 .24381 .42473 .24225 .42222 .23936 Mtetra
.42222 .23936 .42473 .24225 .42901 .24068 .42651 .23779 Mtetra
.42651 .23779 .42901 .24068 .4333 .23911 .4308 .23621 Mtetra
.4308 .23621 .4333 .23911 .43759 .23754 .43509 .23464 Mtetra
.43509 .23464 .43759 .23754 .44189 .23597 .4394 .23306 Mtetra
.4394 .23306 .44189 .23597 .44619 .2344 .44371 .23148 Mtetra
.44371 .23148 .44619 .2344 .45051 .23282 .44802 .2299 Mtetra
.44802 .2299 .45051 .23282 .45483 .23124 .45235 .22831 Mtetra
.96 .731 .548 r
.45235 .22831 .45483 .23124 .4597 .20441 .45724 .20147 Mtetra
.664 .741 .908 r
.45724 .20147 .4597 .20441 .46399 .20282 .46155 .19987 Mtetra
.46155 .19987 .46399 .20282 .4683 .20123 .46586 .19828 Mtetra
.46586 .19828 .4683 .20123 .47261 .19963 .47017 .19667 Mtetra
.47017 .19667 .47261 .19963 .47693 .19803 .47449 .19507 Mtetra
.971 .676 .408 r
.47449 .19507 .47693 .19803 .48125 .19643 .47606 .37422 Mtetra
.511 .273 .491 r
.47606 .37422 .48125 .19643 .48559 .19482 .48066 .37266 Mtetra
.48066 .37266 .48559 .19482 .48957 .22361 .48526 .37111 Mtetra
.509 .271 .488 r
.48526 .37111 .48957 .22361 .49396 .22201 .48987 .36955 Mtetra
0 0 .258 r
.48987 .36955 .49396 .22201 .49836 .22041 .49592 .21744 Mtetra
.662 .744 .911 r
.49592 .21744 .49836 .22041 .50276 .2188 .50033 .21583 Mtetra
.50033 .21583 .50276 .2188 .50717 .21719 .50474 .21421 Mtetra
.50474 .21421 .50717 .21719 .51159 .21558 .50917 .2126 Mtetra
.50917 .2126 .51159 .21558 .51602 .21396 .5136 .21098 Mtetra
.5136 .21098 .51602 .21396 .52045 .21235 .51803 .20935 Mtetra
.51803 .20935 .52045 .21235 .52489 .21073 .52248 .20773 Mtetra
.52248 .20773 .52489 .21073 .52933 .2091 .52693 .2061 Mtetra
.52693 .2061 .52933 .2091 .53379 .20748 .53139 .20447 Mtetra
.53139 .20447 .53379 .20748 .53825 .20585 .53585 .20284 Mtetra
.53585 .20284 .53825 .20585 .54272 .20422 .54032 .2012 Mtetra
.54032 .2012 .54272 .20422 .54719 .20259 .5448 .19957 Mtetra
.5448 .19957 .54719 .20259 .55167 .20095 .54929 .19792 Mtetra
.54929 .19792 .55167 .20095 .55616 .19931 .55379 .19628 Mtetra
.55379 .19628 .55616 .19931 .56066 .19767 .55829 .19464 Mtetra
.55829 .19464 .56066 .19767 .56516 .19603 .5628 .19299 Mtetra
.973 .668 .366 r
.5628 .19299 .56516 .19603 .56968 .19438 .56952 .34832 Mtetra
.51 .271 .489 r
.56952 .34832 .56968 .19438 .5742 .19273 .57429 .34671 Mtetra
.57429 .34671 .5742 .19273 .58153 .34807 .57906 .34511 Mtetra
.649 .759 .929 r
.57906 .34511 .58153 .34807 .5863 .34647 .58383 .34349 Mtetra
.58383 .34349 .5863 .34647 .59108 .34486 .58862 .34188 Mtetra
.58862 .34188 .59108 .34486 .59587 .34325 .59341 .34026 Mtetra
.59341 .34026 .59587 .34325 .60067 .34163 .59822 .33864 Mtetra
.59822 .33864 .60067 .34163 .60547 .34002 .60303 .33702 Mtetra
.60303 .33702 .60547 .34002 .60937 .30452 .60785 .3354 Mtetra
.483 .216 .433 r
.60785 .3354 .60937 .30452 .61414 .30288 .61268 .33377 Mtetra
0 0 .22 r
.61268 .33377 .61414 .30288 .61892 .30125 .61652 .29822 Mtetra
.652 .755 .925 r
.61652 .29822 .61892 .30125 .6237 .29961 .62131 .29657 Mtetra
.62131 .29657 .6237 .29961 .6285 .29796 .62611 .29492 Mtetra
.62611 .29492 .6285 .29796 .6333 .29632 .63092 .29327 Mtetra
.63092 .29327 .6333 .29632 .63811 .29467 .63573 .29162 Mtetra
.63573 .29162 .63811 .29467 .64293 .29302 .64056 .28996 Mtetra
.64056 .28996 .64293 .29302 .64776 .29137 .64539 .28831 Mtetra
.64539 .28831 .64776 .29137 .65259 .28971 .65023 .28664 Mtetra
.65023 .28664 .65259 .28971 .65744 .28805 .65508 .28498 Mtetra
.65508 .28498 .65744 .28805 .66229 .28639 .65994 .28331 Mtetra
.65994 .28331 .66229 .28639 .66715 .28472 .6648 .28164 Mtetra
.6648 .28164 .66715 .28472 .67202 .28305 .66968 .27997 Mtetra
.66968 .27997 .67202 .28305 .6769 .28138 .67456 .27829 Mtetra
.938 .579 .179 r
.67456 .27829 .6769 .28138 .68178 .27971 .68115 .31068 Mtetra
.483 .216 .433 r
.68115 .31068 .68178 .27971 .68668 .27803 .68611 .30901 Mtetra
.68611 .30901 .68668 .27803 .69158 .27635 .69107 .30734 Mtetra
.69107 .30734 .69158 .27635 .69838 .30875 .69605 .30566 Mtetra
.649 .759 .929 r
.69605 .30566 .69838 .30875 .70335 .30708 .70103 .30398 Mtetra
.70103 .30398 .70335 .30708 .70834 .3054 .70602 .3023 Mtetra
.70602 .3023 .70834 .3054 .71333 .30372 .71102 .30061 Mtetra
.71102 .30061 .71333 .30372 .71833 .30204 .71602 .29892 Mtetra
.71602 .29892 .71833 .30204 .72334 .30035 .72104 .29723 Mtetra
.72104 .29723 .72334 .30035 .72836 .29866 .72607 .29554 Mtetra
.72607 .29554 .72836 .29866 .73339 .29697 .7311 .29384 Mtetra
.7311 .29384 .73339 .29697 .73843 .29528 .73614 .29214 Mtetra
.73614 .29214 .73843 .29528 .74348 .29358 .7412 .29044 Mtetra
.7412 .29044 .74348 .29358 .74853 .29188 .74626 .28873 Mtetra
.74626 .28873 .74853 .29188 .75359 .29017 .75133 .28702 Mtetra
.75133 .28702 .75359 .29017 .75867 .28847 .75641 .28531 Mtetra
.75641 .28531 .75867 .28847 .76375 .28676 .7615 .28359 Mtetra
.648 .76 .931 r
.0822 .52491 .08519 .52737 .08918 .52604 .08619 .52358 Mtetra
.08619 .52358 .08918 .52604 .09317 .52471 .09019 .52224 Mtetra
.09019 .52224 .09317 .52471 .09717 .52337 .09419 .5209 Mtetra
.09419 .5209 .09717 .52337 .10118 .52203 .0982 .51956 Mtetra
.0982 .51956 .10118 .52203 .10519 .52069 .10222 .51821 Mtetra
.10222 .51821 .10519 .52069 .10921 .51935 .10624 .51686 Mtetra
.10624 .51686 .10921 .51935 .11323 .518 .11027 .51552 Mtetra
.11027 .51552 .11323 .518 .11726 .51666 .1143 .51417 Mtetra
.1143 .51417 .11726 .51666 .1213 .51531 .11834 .51281 Mtetra
.11834 .51281 .1213 .51531 .12535 .51396 .12239 .51146 Mtetra
.12239 .51146 .12535 .51396 .1294 .5126 .12645 .5101 Mtetra
.12645 .5101 .1294 .5126 .13345 .51125 .13051 .50874 Mtetra
.13051 .50874 .13345 .51125 .13752 .50989 .13457 .50738 Mtetra
.13457 .50738 .13752 .50989 .14159 .50853 .13865 .50602 Mtetra
.13865 .50602 .14159 .50853 .14566 .50717 .14273 .50465 Mtetra
.14273 .50465 .14566 .50717 .14975 .50581 .14681 .50328 Mtetra
.14681 .50328 .14975 .50581 .15384 .50444 .15091 .50191 Mtetra
.15091 .50191 .15384 .50444 .15793 .50307 .15501 .50054 Mtetra
.15501 .50054 .15793 .50307 .16204 .5017 .15911 .49917 Mtetra
.15911 .49917 .16204 .5017 .16614 .50033 .16323 .49779 Mtetra
.16323 .49779 .16614 .50033 .17026 .49895 .16735 .49641 Mtetra
.16735 .49641 .17026 .49895 .17438 .49758 .17147 .49503 Mtetra
.17147 .49503 .17438 .49758 .17851 .4962 .17561 .49364 Mtetra
.17561 .49364 .17851 .4962 .18265 .49482 .17975 .49226 Mtetra
.17975 .49226 .18265 .49482 .18679 .49343 .18389 .49087 Mtetra
.18389 .49087 .18679 .49343 .19094 .49205 .18804 .48948 Mtetra
.18804 .48948 .19094 .49205 .19509 .49066 .1922 .48809 Mtetra
.1922 .48809 .19509 .49066 .19926 .48927 .19637 .48669 Mtetra
.19637 .48669 .19926 .48927 .20343 .48787 .20054 .4853 Mtetra
.20054 .4853 .20343 .48787 .2076 .48648 .20472 .4839 Mtetra
.20472 .4839 .2076 .48648 .21178 .48508 .20891 .4825 Mtetra
.20891 .4825 .21178 .48508 .21597 .48368 .2131 .48109 Mtetra
.2131 .48109 .21597 .48368 .22017 .48228 .2173 .47969 Mtetra
.948 .699 .529 r
.2173 .47969 .22017 .48228 .2323 .39374 .22952 .39108 Mtetra
.655 .752 .921 r
.22952 .39108 .2323 .39374 .2364 .3923 .23363 .38964 Mtetra
.23363 .38964 .2364 .3923 .24051 .39086 .23775 .38819 Mtetra
.23775 .38819 .24051 .39086 .24463 .38942 .24187 .38675 Mtetra
.24187 .38675 .24463 .38942 .24876 .38797 .246 .3853 Mtetra
.246 .3853 .24876 .38797 .25289 .38653 .25013 .38385 Mtetra
.25013 .38385 .25289 .38653 .25702 .38508 .25427 .38239 Mtetra
.25427 .38239 .25702 .38508 .26117 .38362 .25842 .38094 Mtetra
.25842 .38094 .26117 .38362 .26532 .38217 .26257 .37948 Mtetra
.26257 .37948 .26532 .38217 .26948 .38071 .26673 .37802 Mtetra
.26673 .37802 .26948 .38071 .27364 .37926 .2709 .37656 Mtetra
.2709 .37656 .27364 .37926 .27781 .3778 .27508 .37509 Mtetra
.27508 .37509 .27781 .3778 .28199 .37633 .27926 .37363 Mtetra
.27926 .37363 .28199 .37633 .28617 .37487 .28344 .37216 Mtetra
.28344 .37216 .28617 .37487 .29036 .3734 .28764 .37068 Mtetra
.28764 .37068 .29036 .3734 .29456 .37193 .29184 .36921 Mtetra
.29184 .36921 .29456 .37193 .29876 .37046 .29605 .36773 Mtetra
.29605 .36773 .29876 .37046 .30297 .36898 .30026 .36625 Mtetra
.30026 .36625 .30297 .36898 .30719 .3675 .30448 .36477 Mtetra
.30448 .36477 .30719 .3675 .31141 .36603 .30871 .36329 Mtetra
.30871 .36329 .31141 .36603 .31564 .36454 .31294 .3618 Mtetra
.31294 .3618 .31564 .36454 .31988 .36306 .31719 .36031 Mtetra
.31719 .36031 .31988 .36306 .33001 .26823 .32143 .35882 Mtetra
0 0 .136 r
.32143 .35882 .33001 .26823 .33414 .26671 .33154 .26391 Mtetra
.662 .743 .91 r
.33154 .26391 .33414 .26671 .33828 .26519 .33568 .26238 Mtetra
.33568 .26238 .33828 .26519 .34242 .26367 .33983 .26085 Mtetra
.33983 .26085 .34242 .26367 .34657 .26215 .34398 .25933 Mtetra
.34398 .25933 .34657 .26215 .35073 .26062 .34814 .25779 Mtetra
.34814 .25779 .35073 .26062 .35489 .25909 .35231 .25626 Mtetra
.35231 .25626 .35489 .25909 .35906 .25756 .35649 .25472 Mtetra
.35649 .25472 .35906 .25756 .36324 .25602 .36067 .25318 Mtetra
.36067 .25318 .36324 .25602 .36742 .25449 .36485 .25164 Mtetra
.36485 .25164 .36742 .25449 .37161 .25295 .36905 .2501 Mtetra
.36905 .2501 .37161 .25295 .3758 .2514 .37325 .24855 Mtetra
0 .103 .619 r
.37325 .24855 .3758 .2514 .37977 .25492 .37721 .25206 Mtetra
.662 .744 .911 r
.37721 .25206 .37977 .25492 .38398 .25337 .38143 .25051 Mtetra
.38143 .25051 .38398 .25337 .3882 .25183 .38565 .24896 Mtetra
.38565 .24896 .3882 .25183 .39243 .25028 .38989 .24741 Mtetra
.38989 .24741 .39243 .25028 .39667 .24872 .39413 .24585 Mtetra
.39413 .24585 .39667 .24872 .40091 .24717 .39837 .24429 Mtetra
.39837 .24429 .40091 .24717 .40516 .24561 .40263 .24273 Mtetra
.40263 .24273 .40516 .24561 .40942 .24405 .40689 .24116 Mtetra
.40689 .24116 .40942 .24405 .41368 .24249 .41115 .2396 Mtetra
.41115 .2396 .41368 .24249 .41795 .24092 .41543 .23803 Mtetra
.41543 .23803 .41795 .24092 .42222 .23936 .41971 .23646 Mtetra
.41971 .23646 .42222 .23936 .42651 .23779 .424 .23488 Mtetra
.424 .23488 .42651 .23779 .4308 .23621 .42829 .2333 Mtetra
.42829 .2333 .4308 .23621 .43509 .23464 .43259 .23172 Mtetra
.43259 .23172 .43509 .23464 .4394 .23306 .4369 .23014 Mtetra
.4369 .23014 .4394 .23306 .44371 .23148 .44121 .22856 Mtetra
.44121 .22856 .44371 .23148 .44802 .2299 .44553 .22697 Mtetra
.44553 .22697 .44802 .2299 .45235 .22831 .44986 .22538 Mtetra
.44986 .22538 .45235 .22831 .45724 .20147 .4542 .22379 Mtetra
0 0 .079 r
.4542 .22379 .45724 .20147 .46155 .19987 .45909 .19692 Mtetra
.97 .677 .413 r
.45909 .19692 .46155 .19987 .46586 .19828 .45972 .37601 Mtetra
.51 .272 .49 r
.45972 .37601 .46586 .19828 .47017 .19667 .4643 .37445 Mtetra
.4643 .37445 .47017 .19667 .47449 .19507 .46888 .3729 Mtetra
.46888 .3729 .47449 .19507 .47606 .37422 .47347 .37134 Mtetra
.65 .758 .928 r
.47347 .37134 .47606 .37422 .48066 .37266 .47807 .36979 Mtetra
.47807 .36979 .48066 .37266 .48526 .37111 .48268 .36823 Mtetra
.48268 .36823 .48526 .37111 .48987 .36955 .4873 .36666 Mtetra
.4873 .36666 .48987 .36955 .49592 .21744 .49192 .36509 Mtetra
.509 .27 .487 r
.49192 .36509 .49592 .21744 .50033 .21583 .49655 .36353 Mtetra
.49655 .36353 .50033 .21583 .50474 .21421 .50119 .36195 Mtetra
0 0 .263 r
.50119 .36195 .50474 .21421 .50917 .2126 .50674 .2096 Mtetra
.662 .744 .911 r
.50674 .2096 .50917 .2126 .5136 .21098 .51117 .20798 Mtetra
.51117 .20798 .5136 .21098 .51803 .20935 .51561 .20635 Mtetra
.51561 .20635 .51803 .20935 .52248 .20773 .52006 .20472 Mtetra
.52006 .20472 .52248 .20773 .52693 .2061 .52452 .20309 Mtetra
.52452 .20309 .52693 .2061 .53139 .20447 .52898 .20146 Mtetra
.52898 .20146 .53139 .20447 .53585 .20284 .53345 .19982 Mtetra
.53345 .19982 .53585 .20284 .54032 .2012 .53793 .19818 Mtetra
.53793 .19818 .54032 .2012 .5448 .19957 .54241 .19653 Mtetra
.54241 .19653 .5448 .19957 .54929 .19792 .5469 .19489 Mtetra
.5469 .19489 .54929 .19792 .55379 .19628 .5514 .19324 Mtetra
.5514 .19324 .55379 .19628 .55829 .19464 .55591 .19159 Mtetra
.973 .668 .368 r
.55591 .19159 .55829 .19464 .5628 .19299 .56228 .34696 Mtetra
.509 .27 .488 r
.56228 .34696 .5628 .19299 .56952 .34832 .56703 .34535 Mtetra
.649 .759 .929 r
.56703 .34535 .56952 .34832 .57429 .34671 .5718 .34374 Mtetra
.5718 .34374 .57429 .34671 .57906 .34511 .57658 .34213 Mtetra
.57658 .34213 .57906 .34511 .58383 .34349 .58136 .34051 Mtetra
.58136 .34051 .58383 .34349 .58862 .34188 .58615 .33889 Mtetra
.58615 .33889 .58862 .34188 .59341 .34026 .59095 .33727 Mtetra
.59095 .33727 .59341 .34026 .59822 .33864 .59576 .33565 Mtetra
.59576 .33565 .59822 .33864 .60303 .33702 .60058 .33402 Mtetra
.60058 .33402 .60303 .33702 .60785 .3354 .6054 .33239 Mtetra
.6054 .33239 .60785 .3354 .61268 .33377 .61024 .33076 Mtetra
.61024 .33076 .61268 .33377 .61652 .29822 .61508 .32912 Mtetra
.482 .215 .432 r
.61508 .32912 .61652 .29822 .62131 .29657 .61993 .32748 Mtetra
0 0 .222 r
.61993 .32748 .62131 .29657 .62611 .29492 .62371 .29188 Mtetra
.652 .755 .925 r
.62371 .29188 .62611 .29492 .63092 .29327 .62852 .29022 Mtetra
.62852 .29022 .63092 .29327 .63573 .29162 .63334 .28856 Mtetra
.63334 .28856 .63573 .29162 .64056 .28996 .63817 .2869 Mtetra
.63817 .2869 .64056 .28996 .64539 .28831 .64301 .28523 Mtetra
.64301 .28523 .64539 .28831 .65023 .28664 .64786 .28357 Mtetra
.64786 .28357 .65023 .28664 .65508 .28498 .65271 .2819 Mtetra
.65271 .2819 .65508 .28498 .65994 .28331 .65758 .28022 Mtetra
.65758 .28022 .65994 .28331 .6648 .28164 .66245 .27855 Mtetra
.94 .582 .186 r
.66245 .27855 .6648 .28164 .66968 .27997 .6689 .31094 Mtetra
.482 .215 .432 r
.6689 .31094 .66968 .27997 .67456 .27829 .67384 .30927 Mtetra
.67384 .30927 .67456 .27829 .68115 .31068 .67879 .3076 Mtetra
.649 .759 .929 r
.67879 .3076 .68115 .31068 .68611 .30901 .68375 .30592 Mtetra
.68375 .30592 .68611 .30901 .69107 .30734 .68873 .30424 Mtetra
.68873 .30424 .69107 .30734 .69605 .30566 .6937 .30256 Mtetra
.6937 .30256 .69605 .30566 .70103 .30398 .69869 .30087 Mtetra
.69869 .30087 .70103 .30398 .70602 .3023 .70369 .29918 Mtetra
.70369 .29918 .70602 .3023 .71102 .30061 .70869 .29749 Mtetra
.70869 .29749 .71102 .30061 .71602 .29892 .71371 .2958 Mtetra
.71371 .2958 .71602 .29892 .72104 .29723 .71873 .2941 Mtetra
.71873 .2941 .72104 .29723 .72607 .29554 .72376 .2924 Mtetra
.72376 .2924 .72607 .29554 .7311 .29384 .7288 .2907 Mtetra
.7288 .2907 .7311 .29384 .73614 .29214 .73385 .28899 Mtetra
.73385 .28899 .73614 .29214 .7412 .29044 .73891 .28728 Mtetra
.73891 .28728 .7412 .29044 .74626 .28873 .74398 .28557 Mtetra
.74398 .28557 .74626 .28873 .75133 .28702 .74906 .28386 Mtetra
.74906 .28386 .75133 .28702 .75641 .28531 .75414 .28214 Mtetra
.75414 .28214 .75641 .28531 .7615 .28359 .75924 .28042 Mtetra
.648 .76 .931 r
.0792 .52244 .0822 .52491 .08619 .52358 .0832 .5211 Mtetra
.0832 .5211 .08619 .52358 .09019 .52224 .0872 .51976 Mtetra
.0872 .51976 .09019 .52224 .09419 .5209 .0912 .51842 Mtetra
.0912 .51842 .09419 .5209 .0982 .51956 .09522 .51707 Mtetra
.09522 .51707 .0982 .51956 .10222 .51821 .09924 .51572 Mtetra
.09924 .51572 .10222 .51821 .10624 .51686 .10326 .51437 Mtetra
.10326 .51437 .10624 .51686 .11027 .51552 .10729 .51302 Mtetra
.10729 .51302 .11027 .51552 .1143 .51417 .11133 .51167 Mtetra
.11133 .51167 .1143 .51417 .11834 .51281 .11538 .51031 Mtetra
.11538 .51031 .11834 .51281 .12239 .51146 .11943 .50895 Mtetra
.11943 .50895 .12239 .51146 .12645 .5101 .12349 .50759 Mtetra
.12349 .50759 .12645 .5101 .13051 .50874 .12755 .50623 Mtetra
.12755 .50623 .13051 .50874 .13457 .50738 .13162 .50486 Mtetra
.13162 .50486 .13457 .50738 .13865 .50602 .1357 .50349 Mtetra
.1357 .50349 .13865 .50602 .14273 .50465 .13978 .50212 Mtetra
.13978 .50212 .14273 .50465 .14681 .50328 .14387 .50075 Mtetra
.14387 .50075 .14681 .50328 .15091 .50191 .14797 .49938 Mtetra
.14797 .49938 .15091 .50191 .15501 .50054 .15207 .498 Mtetra
.15207 .498 .15501 .50054 .15911 .49917 .15618 .49662 Mtetra
.15618 .49662 .15911 .49917 .16323 .49779 .1603 .49524 Mtetra
.1603 .49524 .16323 .49779 .16735 .49641 .16442 .49386 Mtetra
.16442 .49386 .16735 .49641 .17147 .49503 .16855 .49247 Mtetra
.16855 .49247 .17147 .49503 .17561 .49364 .17269 .49108 Mtetra
.17269 .49108 .17561 .49364 .17975 .49226 .17683 .4897 Mtetra
.17683 .4897 .17975 .49226 .18389 .49087 .18098 .4883 Mtetra
.18098 .4883 .18389 .49087 .18804 .48948 .18514 .48691 Mtetra
.18514 .48691 .18804 .48948 .1922 .48809 .1893 .48551 Mtetra
.1893 .48551 .1922 .48809 .19637 .48669 .19347 .48411 Mtetra
.19347 .48411 .19637 .48669 .20054 .4853 .19765 .48271 Mtetra
.19765 .48271 .20054 .4853 .20472 .4839 .20183 .48131 Mtetra
.20183 .48131 .20472 .4839 .20891 .4825 .20603 .4799 Mtetra
.20603 .4799 .20891 .4825 .2131 .48109 .21022 .4785 Mtetra
.935 .727 .598 r
.21022 .4785 .2131 .48109 .2173 .47969 .21652 .45484 Mtetra
.87 .618 .554 r
.21652 .45484 .2173 .47969 .22952 .39108 .22674 .38842 Mtetra
.655 .752 .921 r
.22674 .38842 .22952 .39108 .23363 .38964 .23085 .38697 Mtetra
.23085 .38697 .23363 .38964 .23775 .38819 .23497 .38552 Mtetra
.23497 .38552 .23775 .38819 .24187 .38675 .2391 .38407 Mtetra
.2391 .38407 .24187 .38675 .246 .3853 .24323 .38262 Mtetra
.24323 .38262 .246 .3853 .25013 .38385 .24737 .38116 Mtetra
.24737 .38116 .25013 .38385 .25427 .38239 .25151 .37971 Mtetra
.25151 .37971 .25427 .38239 .25842 .38094 .25566 .37825 Mtetra
.25566 .37825 .25842 .38094 .26257 .37948 .25982 .37678 Mtetra
.25982 .37678 .26257 .37948 .26673 .37802 .26399 .37532 Mtetra
.26399 .37532 .26673 .37802 .2709 .37656 .26816 .37385 Mtetra
.26816 .37385 .2709 .37656 .27508 .37509 .27233 .37238 Mtetra
.27233 .37238 .27508 .37509 .27926 .37363 .27652 .37091 Mtetra
.27652 .37091 .27926 .37363 .28344 .37216 .28071 .36944 Mtetra
.28071 .36944 .28344 .37216 .28764 .37068 .28491 .36796 Mtetra
.28491 .36796 .28764 .37068 .29184 .36921 .28911 .36648 Mtetra
.28911 .36648 .29184 .36921 .29605 .36773 .29333 .365 Mtetra
.29333 .365 .29605 .36773 .30026 .36625 .29754 .36352 Mtetra
.29754 .36352 .30026 .36625 .30448 .36477 .30177 .36203 Mtetra
.30177 .36203 .30448 .36477 .30871 .36329 .306 .36054 Mtetra
.306 .36054 .30871 .36329 .31294 .3618 .31024 .35905 Mtetra
.31024 .35905 .31294 .3618 .31719 .36031 .31449 .35756 Mtetra
.31449 .35756 .31719 .36031 .32143 .35882 .31874 .35606 Mtetra
.31874 .35606 .32143 .35882 .33154 .26391 .323 .35457 Mtetra
0 0 .136 r
.323 .35457 .33154 .26391 .33568 .26238 .33308 .25956 Mtetra
.662 .743 .91 r
.33308 .25956 .33568 .26238 .33983 .26085 .33723 .25803 Mtetra
.33723 .25803 .33983 .26085 .34398 .25933 .34139 .2565 Mtetra
.34139 .2565 .34398 .25933 .34814 .25779 .34556 .25496 Mtetra
.34556 .25496 .34814 .25779 .35231 .25626 .34973 .25342 Mtetra
.34973 .25342 .35231 .25626 .35649 .25472 .3539 .25188 Mtetra
.3539 .25188 .35649 .25472 .36067 .25318 .35809 .25034 Mtetra
.35809 .25034 .36067 .25318 .36485 .25164 .36228 .24879 Mtetra
.36228 .24879 .36485 .25164 .36905 .2501 .36648 .24724 Mtetra
.36648 .24724 .36905 .2501 .37325 .24855 .37068 .24569 Mtetra
0 .103 .619 r
.37068 .24569 .37325 .24855 .37721 .25206 .37464 .2492 Mtetra
.662 .744 .911 r
.37464 .2492 .37721 .25206 .38143 .25051 .37887 .24765 Mtetra
.37887 .24765 .38143 .25051 .38565 .24896 .3831 .24609 Mtetra
.3831 .24609 .38565 .24896 .38989 .24741 .38734 .24453 Mtetra
.38734 .24453 .38989 .24741 .39413 .24585 .39158 .24297 Mtetra
.39158 .24297 .39413 .24585 .39837 .24429 .39583 .2414 Mtetra
.39583 .2414 .39837 .24429 .40263 .24273 .40009 .23984 Mtetra
.40009 .23984 .40263 .24273 .40689 .24116 .40435 .23827 Mtetra
.40435 .23827 .40689 .24116 .41115 .2396 .40862 .2367 Mtetra
.40862 .2367 .41115 .2396 .41543 .23803 .4129 .23512 Mtetra
.4129 .23512 .41543 .23803 .41971 .23646 .41719 .23355 Mtetra
.41719 .23355 .41971 .23646 .424 .23488 .42148 .23197 Mtetra
.42148 .23197 .424 .23488 .42829 .2333 .42577 .23039 Mtetra
.42577 .23039 .42829 .2333 .43259 .23172 .43008 .2288 Mtetra
.43008 .2288 .43259 .23172 .4369 .23014 .43439 .22721 Mtetra
.43439 .22721 .4369 .23014 .44121 .22856 .43871 .22563 Mtetra
.43871 .22563 .44121 .22856 .44553 .22697 .44304 .22403 Mtetra
.44304 .22403 .44553 .22697 .44986 .22538 .44737 .22244 Mtetra
.44737 .22244 .44986 .22538 .4542 .22379 .45171 .22084 Mtetra
.97 .675 .411 r
.45171 .22084 .4542 .22379 .45909 .19692 .45254 .37469 Mtetra
.509 .271 .489 r
.45254 .37469 .45909 .19692 .45972 .37601 .45711 .37314 Mtetra
.65 .758 .928 r
.45711 .37314 .45972 .37601 .4643 .37445 .46169 .37158 Mtetra
.46169 .37158 .4643 .37445 .46888 .3729 .46628 .37003 Mtetra
.46628 .37003 .46888 .3729 .47347 .37134 .47088 .36847 Mtetra
.47088 .36847 .47347 .37134 .47807 .36979 .47548 .3669 Mtetra
.47548 .3669 .47807 .36979 .48268 .36823 .48009 .36534 Mtetra
.48009 .36534 .48268 .36823 .4873 .36666 .48471 .36377 Mtetra
.48471 .36377 .4873 .36666 .49192 .36509 .48934 .3622 Mtetra
.48934 .3622 .49192 .36509 .49655 .36353 .49398 .36062 Mtetra
.49398 .36062 .49655 .36353 .50119 .36195 .49862 .35904 Mtetra
.49862 .35904 .50119 .36195 .50674 .2096 .50327 .35747 Mtetra
.508 .269 .487 r
.50327 .35747 .50674 .2096 .51117 .20798 .50793 .35588 Mtetra
.50793 .35588 .51117 .20798 .51561 .20635 .5126 .3543 Mtetra
0 0 .267 r
.5126 .3543 .51561 .20635 .52006 .20472 .51763 .20171 Mtetra
.662 .744 .911 r
.51763 .20171 .52006 .20472 .52452 .20309 .5221 .20007 Mtetra
.5221 .20007 .52452 .20309 .52898 .20146 .52656 .19843 Mtetra
.52656 .19843 .52898 .20146 .53345 .19982 .53104 .19679 Mtetra
.53104 .19679 .53345 .19982 .53793 .19818 .53552 .19514 Mtetra
.53552 .19514 .53793 .19818 .54241 .19653 .54001 .19349 Mtetra
.54001 .19349 .54241 .19653 .5469 .19489 .54451 .19184 Mtetra
.973 .669 .372 r
.54451 .19184 .5469 .19489 .5514 .19324 .55027 .34721 Mtetra
.508 .269 .487 r
.55027 .34721 .5514 .19324 .55591 .19159 .55502 .3456 Mtetra
.55502 .3456 .55591 .19159 .56228 .34696 .55977 .34399 Mtetra
.649 .759 .929 r
.55977 .34399 .56228 .34696 .56703 .34535 .56454 .34238 Mtetra
.56454 .34238 .56703 .34535 .5718 .34374 .56931 .34076 Mtetra
.56931 .34076 .5718 .34374 .57658 .34213 .57409 .33914 Mtetra
.57409 .33914 .57658 .34213 .58136 .34051 .57888 .33752 Mtetra
.57888 .33752 .58136 .34051 .58615 .33889 .58368 .3359 Mtetra
.58368 .3359 .58615 .33889 .59095 .33727 .58848 .33427 Mtetra
.58848 .33427 .59095 .33727 .59576 .33565 .5933 .33264 Mtetra
.5933 .33264 .59576 .33565 .60058 .33402 .59812 .33101 Mtetra
.59812 .33101 .60058 .33402 .6054 .33239 .60295 .32937 Mtetra
.60295 .32937 .6054 .33239 .61024 .33076 .60779 .32774 Mtetra
.60779 .32774 .61024 .33076 .61508 .32912 .61264 .32609 Mtetra
.61264 .32609 .61508 .32912 .61993 .32748 .61749 .32445 Mtetra
.61749 .32445 .61993 .32748 .62371 .29188 .62236 .3228 Mtetra
.481 .213 .431 r
.62236 .3228 .62371 .29188 .62852 .29022 .62723 .32115 Mtetra
0 0 .224 r
.62723 .32115 .62852 .29022 .63334 .28856 .63095 .28549 Mtetra
.652 .755 .925 r
.63095 .28549 .63334 .28856 .63817 .2869 .63578 .28382 Mtetra
.63578 .28382 .63817 .2869 .64301 .28523 .64063 .28215 Mtetra
.64063 .28215 .64301 .28523 .64786 .28357 .64548 .28048 Mtetra
.64548 .28048 .64786 .28357 .65271 .2819 .65034 .27881 Mtetra
.942 .584 .192 r
.65034 .27881 .65271 .2819 .65758 .28022 .65664 .3112 Mtetra
.481 .213 .431 r
.65664 .3112 .65758 .28022 .66245 .27855 .66158 .30953 Mtetra
.66158 .30953 .66245 .27855 .6689 .31094 .66652 .30785 Mtetra
.649 .759 .929 r
.66652 .30785 .6689 .31094 .67384 .30927 .67147 .30618 Mtetra
.67147 .30618 .67384 .30927 .67879 .3076 .67643 .3045 Mtetra
.67643 .3045 .67879 .3076 .68375 .30592 .68139 .30282 Mtetra
.68139 .30282 .68375 .30592 .68873 .30424 .68637 .30113 Mtetra
.68637 .30113 .68873 .30424 .6937 .30256 .69136 .29944 Mtetra
.69136 .29944 .6937 .30256 .69869 .30087 .69635 .29775 Mtetra
.69635 .29775 .69869 .30087 .70369 .29918 .70135 .29606 Mtetra
.70135 .29606 .70369 .29918 .70869 .29749 .70636 .29436 Mtetra
.70636 .29436 .70869 .29749 .71371 .2958 .71138 .29266 Mtetra
.71138 .29266 .71371 .2958 .71873 .2941 .71641 .29096 Mtetra
.71641 .29096 .71873 .2941 .72376 .2924 .72145 .28926 Mtetra
.72145 .28926 .72376 .2924 .7288 .2907 .7265 .28755 Mtetra
.7265 .28755 .7288 .2907 .73385 .28899 .73155 .28584 Mtetra
.73155 .28584 .73385 .28899 .73891 .28728 .73662 .28412 Mtetra
.73662 .28412 .73891 .28728 .74398 .28557 .74169 .2824 Mtetra
.74169 .2824 .74398 .28557 .74906 .28386 .74677 .28068 Mtetra
.74677 .28068 .74906 .28386 .75414 .28214 .75187 .27896 Mtetra
.75187 .27896 .75414 .28214 .75924 .28042 .75697 .27723 Mtetra
.648 .76 .931 r
.0762 .51997 .0792 .52244 .0832 .5211 .08019 .51862 Mtetra
.08019 .51862 .0832 .5211 .0872 .51976 .0842 .51728 Mtetra
.0842 .51728 .0872 .51976 .0912 .51842 .08821 .51593 Mtetra
.08821 .51593 .0912 .51842 .09522 .51707 .09222 .51458 Mtetra
.09222 .51458 .09522 .51707 .09924 .51572 .09625 .51323 Mtetra
.09625 .51323 .09924 .51572 .10326 .51437 .10028 .51187 Mtetra
.10028 .51187 .10326 .51437 .10729 .51302 .10431 .51052 Mtetra
.10431 .51052 .10729 .51302 .11133 .51167 .10835 .50916 Mtetra
.10835 .50916 .11133 .51167 .11538 .51031 .1124 .5078 Mtetra
.1124 .5078 .11538 .51031 .11943 .50895 .11646 .50644 Mtetra
.11646 .50644 .11943 .50895 .12349 .50759 .12052 .50507 Mtetra
.12052 .50507 .12349 .50759 .12755 .50623 .12459 .5037 Mtetra
.12459 .5037 .12755 .50623 .13162 .50486 .12866 .50233 Mtetra
.12866 .50233 .13162 .50486 .1357 .50349 .13274 .50096 Mtetra
.13274 .50096 .1357 .50349 .13978 .50212 .13683 .49959 Mtetra
.13683 .49959 .13978 .50212 .14387 .50075 .14092 .49821 Mtetra
.14092 .49821 .14387 .50075 .14797 .49938 .14503 .49683 Mtetra
.14503 .49683 .14797 .49938 .15207 .498 .14913 .49545 Mtetra
.14913 .49545 .15207 .498 .15618 .49662 .15325 .49407 Mtetra
.15325 .49407 .15618 .49662 .1603 .49524 .15737 .49269 Mtetra
.15737 .49269 .1603 .49524 .16442 .49386 .16149 .4913 Mtetra
.16149 .4913 .16442 .49386 .16855 .49247 .16563 .48991 Mtetra
.16563 .48991 .16855 .49247 .17269 .49108 .16977 .48852 Mtetra
.16977 .48852 .17269 .49108 .17683 .4897 .17392 .48712 Mtetra
.17392 .48712 .17683 .4897 .18098 .4883 .17807 .48573 Mtetra
.17807 .48573 .18098 .4883 .18514 .48691 .18223 .48433 Mtetra
.18223 .48433 .18514 .48691 .1893 .48551 .1864 .48293 Mtetra
.1864 .48293 .1893 .48551 .19347 .48411 .19057 .48153 Mtetra
.19057 .48153 .19347 .48411 .19765 .48271 .19475 .48012 Mtetra
.19475 .48012 .19765 .48271 .20183 .48131 .19894 .47871 Mtetra
.19894 .47871 .20183 .48131 .20603 .4799 .20313 .4773 Mtetra
.935 .727 .598 r
.20313 .4773 .20603 .4799 .21022 .4785 .20948 .45364 Mtetra
.55 .362 .58 r
.20948 .45364 .21022 .4785 .21652 .45484 .21366 .45221 Mtetra
.65 .758 .928 r
.21366 .45221 .21652 .45484 .22674 .38842 .21785 .45079 Mtetra
0 0 .038 r
.21785 .45079 .22674 .38842 .23085 .38697 .22806 .38429 Mtetra
.655 .752 .921 r
.22806 .38429 .23085 .38697 .23497 .38552 .23219 .38284 Mtetra
.23219 .38284 .23497 .38552 .2391 .38407 .23631 .38139 Mtetra
.23631 .38139 .2391 .38407 .24323 .38262 .24045 .37993 Mtetra
.24045 .37993 .24323 .38262 .24737 .38116 .24459 .37847 Mtetra
.24459 .37847 .24737 .38116 .25151 .37971 .24874 .37701 Mtetra
.24874 .37701 .25151 .37971 .25566 .37825 .2529 .37554 Mtetra
.2529 .37554 .25566 .37825 .25982 .37678 .25706 .37408 Mtetra
.25706 .37408 .25982 .37678 .26399 .37532 .26123 .37261 Mtetra
.26123 .37261 .26399 .37532 .26816 .37385 .2654 .37114 Mtetra
.2654 .37114 .26816 .37385 .27233 .37238 .26959 .36966 Mtetra
.26959 .36966 .27233 .37238 .27652 .37091 .27377 .36819 Mtetra
.27377 .36819 .27652 .37091 .28071 .36944 .27797 .36671 Mtetra
.27797 .36671 .28071 .36944 .28491 .36796 .28217 .36523 Mtetra
.28217 .36523 .28491 .36796 .28911 .36648 .28638 .36374 Mtetra
.28638 .36374 .28911 .36648 .29333 .365 .2906 .36226 Mtetra
.2906 .36226 .29333 .365 .29754 .36352 .29482 .36077 Mtetra
.29482 .36077 .29754 .36352 .30177 .36203 .29905 .35928 Mtetra
.29905 .35928 .30177 .36203 .306 .36054 .30328 .35779 Mtetra
.30328 .35779 .306 .36054 .31024 .35905 .30753 .35629 Mtetra
.30753 .35629 .31024 .35905 .31449 .35756 .31178 .3548 Mtetra
.31178 .3548 .31449 .35756 .31874 .35606 .31603 .3533 Mtetra
.31603 .3533 .31874 .35606 .323 .35457 .3203 .35179 Mtetra
.958 .7 .504 r
.3203 .35179 .323 .35457 .33308 .25956 .33047 .25673 Mtetra
.662 .743 .91 r
.33047 .25673 .33308 .25956 .33723 .25803 .33463 .2552 Mtetra
.33463 .2552 .33723 .25803 .34139 .2565 .33879 .25366 Mtetra
.33879 .25366 .34139 .2565 .34556 .25496 .34296 .25212 Mtetra
.34296 .25212 .34556 .25496 .34973 .25342 .34713 .25057 Mtetra
.34713 .25057 .34973 .25342 .3539 .25188 .35132 .24903 Mtetra
.35132 .24903 .3539 .25188 .35809 .25034 .3555 .24748 Mtetra
.3555 .24748 .35809 .25034 .36228 .24879 .3597 .24593 Mtetra
.3597 .24593 .36228 .24879 .36648 .24724 .3639 .24438 Mtetra
0 .1 .616 r
.3639 .24438 .36648 .24724 .37068 .24569 .36785 .24789 Mtetra
0 0 0 r
.36785 .24789 .37068 .24569 .37464 .2492 .37207 .24633 Mtetra
.662 .744 .911 r
.37207 .24633 .37464 .2492 .37887 .24765 .3763 .24477 Mtetra
.3763 .24477 .37887 .24765 .3831 .24609 .38053 .24321 Mtetra
.38053 .24321 .3831 .24609 .38734 .24453 .38477 .24165 Mtetra
.38477 .24165 .38734 .24453 .39158 .24297 .38902 .24008 Mtetra
.38902 .24008 .39158 .24297 .39583 .2414 .39328 .23851 Mtetra
.39328 .23851 .39583 .2414 .40009 .23984 .39754 .23694 Mtetra
.39754 .23694 .40009 .23984 .40435 .23827 .40181 .23537 Mtetra
.40181 .23537 .40435 .23827 .40862 .2367 .40608 .23379 Mtetra
.40608 .23379 .40862 .2367 .4129 .23512 .41037 .23221 Mtetra
.41037 .23221 .4129 .23512 .41719 .23355 .41465 .23063 Mtetra
.41465 .23063 .41719 .23355 .42148 .23197 .41895 .22905 Mtetra
.41895 .22905 .42148 .23197 .42577 .23039 .42325 .22746 Mtetra
.42325 .22746 .42577 .23039 .43008 .2288 .42756 .22587 Mtetra
.42756 .22587 .43008 .2288 .43439 .22721 .43188 .22428 Mtetra
.43188 .22428 .43439 .22721 .43871 .22563 .4362 .22269 Mtetra
.4362 .22269 .43871 .22563 .44304 .22403 .44053 .22109 Mtetra
.44053 .22109 .44304 .22403 .44737 .22244 .44487 .21949 Mtetra
.969 .675 .413 r
.44487 .21949 .44737 .22244 .45171 .22084 .44534 .37338 Mtetra
.507 .268 .486 r
.44534 .37338 .45171 .22084 .45254 .37469 .44991 .37182 Mtetra
.65 .758 .928 r
.44991 .37182 .45254 .37469 .45711 .37314 .45449 .37027 Mtetra
.45449 .37027 .45711 .37314 .46169 .37158 .45908 .36871 Mtetra
.45908 .36871 .46169 .37158 .46628 .37003 .46367 .36714 Mtetra
.46367 .36714 .46628 .37003 .47088 .36847 .46827 .36558 Mtetra
.46827 .36558 .47088 .36847 .47548 .3669 .47288 .36401 Mtetra
.47288 .36401 .47548 .3669 .48009 .36534 .4775 .36244 Mtetra
.4775 .36244 .48009 .36534 .48471 .36377 .48212 .36086 Mtetra
.48212 .36086 .48471 .36377 .48934 .3622 .48676 .35929 Mtetra
.48676 .35929 .48934 .3622 .49398 .36062 .4914 .35771 Mtetra
.4914 .35771 .49398 .36062 .49862 .35904 .49605 .35613 Mtetra
.49605 .35613 .49862 .35904 .50327 .35747 .5007 .35454 Mtetra
.5007 .35454 .50327 .35747 .50793 .35588 .50537 .35296 Mtetra
.50537 .35296 .50793 .35588 .5126 .3543 .51004 .35137 Mtetra
.51004 .35137 .5126 .3543 .51763 .20171 .51472 .34977 Mtetra
.507 .268 .486 r
.51472 .34977 .51763 .20171 .5221 .20007 .51941 .34818 Mtetra
.51941 .34818 .5221 .20007 .52656 .19843 .5241 .34658 Mtetra
0 0 .272 r
.5241 .34658 .52656 .19843 .53104 .19679 .52862 .19375 Mtetra
.662 .744 .911 r
.52862 .19375 .53104 .19679 .53552 .19514 .53311 .1921 Mtetra
.53311 .1921 .53552 .19514 .54001 .19349 .5376 .19044 Mtetra
.973 .669 .374 r
.5376 .19044 .54001 .19349 .54451 .19184 .543 .34585 Mtetra
.507 .268 .486 r
.543 .34585 .54451 .19184 .55027 .34721 .54775 .34424 Mtetra
.649 .759 .929 r
.54775 .34424 .55027 .34721 .55502 .3456 .5525 .34263 Mtetra
.5525 .34263 .55502 .3456 .55977 .34399 .55726 .34101 Mtetra
.55726 .34101 .55977 .34399 .56454 .34238 .56203 .33939 Mtetra
.56203 .33939 .56454 .34238 .56931 .34076 .56681 .33777 Mtetra
.56681 .33777 .56931 .34076 .57409 .33914 .5716 .33615 Mtetra
.5716 .33615 .57409 .33914 .57888 .33752 .57639 .33452 Mtetra
.57639 .33452 .57888 .33752 .58368 .3359 .58119 .33289 Mtetra
.58119 .33289 .58368 .3359 .58848 .33427 .586 .33126 Mtetra
.586 .33126 .58848 .33427 .5933 .33264 .59082 .32963 Mtetra
.59082 .32963 .5933 .33264 .59812 .33101 .59565 .32799 Mtetra
.59565 .32799 .59812 .33101 .60295 .32937 .60049 .32635 Mtetra
.60049 .32635 .60295 .32937 .60779 .32774 .60533 .3247 Mtetra
.60533 .3247 .60779 .32774 .61264 .32609 .61019 .32306 Mtetra
.61019 .32306 .61264 .32609 .61749 .32445 .61505 .32141 Mtetra
.61505 .32141 .61749 .32445 .62236 .3228 .61992 .31976 Mtetra
.61992 .31976 .62236 .3228 .62723 .32115 .6248 .3181 Mtetra
.6248 .3181 .62723 .32115 .63095 .28549 .62968 .31644 Mtetra
.48 .212 .43 r
.62968 .31644 .63095 .28549 .63578 .28382 .63458 .31478 Mtetra
0 0 .227 r
.63458 .31478 .63578 .28382 .64063 .28215 .63824 .27906 Mtetra
.943 .587 .199 r
.63824 .27906 .64063 .28215 .64548 .28048 .64439 .31145 Mtetra
.48 .212 .43 r
.64439 .31145 .64548 .28048 .65034 .27881 .64932 .30978 Mtetra
.64932 .30978 .65034 .27881 .65664 .3112 .65425 .30811 Mtetra
.649 .759 .929 r
.65425 .30811 .65664 .3112 .66158 .30953 .65918 .30644 Mtetra
.65918 .30644 .66158 .30953 .66652 .30785 .66413 .30476 Mtetra
.66413 .30476 .66652 .30785 .67147 .30618 .66909 .30308 Mtetra
.66909 .30308 .67147 .30618 .67643 .3045 .67405 .30139 Mtetra
.67405 .30139 .67643 .3045 .68139 .30282 .67903 .2997 Mtetra
.67903 .2997 .68139 .30282 .68637 .30113 .68401 .29801 Mtetra
.68401 .29801 .68637 .30113 .69136 .29944 .689 .29632 Mtetra
.689 .29632 .69136 .29944 .69635 .29775 .694 .29462 Mtetra
.694 .29462 .69635 .29775 .70135 .29606 .69901 .29293 Mtetra
.69901 .29293 .70135 .29606 .70636 .29436 .70402 .29122 Mtetra
.70402 .29122 .70636 .29436 .71138 .29266 .70905 .28952 Mtetra
.70905 .28952 .71138 .29266 .71641 .29096 .71409 .28781 Mtetra
.71409 .28781 .71641 .29096 .72145 .28926 .71913 .2861 Mtetra
.71913 .2861 .72145 .28926 .7265 .28755 .72418 .28439 Mtetra
.72418 .28439 .7265 .28755 .73155 .28584 .72925 .28267 Mtetra
.72925 .28267 .73155 .28584 .73662 .28412 .73432 .28095 Mtetra
.73432 .28095 .73662 .28412 .74169 .2824 .7394 .27922 Mtetra
.7394 .27922 .74169 .2824 .74677 .28068 .74449 .2775 Mtetra
.74449 .2775 .74677 .28068 .75187 .27896 .74958 .27577 Mtetra
.74958 .27577 .75187 .27896 .75697 .27723 .75469 .27404 Mtetra
.53 .316 .534 r
.08055 .46302 .0762 .51997 .08019 .51862 .08449 .46165 Mtetra
0 0 .108 r
.08449 .46165 .08019 .51862 .0842 .51728 .08119 .51479 Mtetra
.648 .76 .931 r
.08119 .51479 .0842 .51728 .08821 .51593 .0852 .51344 Mtetra
.0852 .51344 .08821 .51593 .09222 .51458 .08922 .51208 Mtetra
.08922 .51208 .09222 .51458 .09625 .51323 .09325 .51073 Mtetra
.09325 .51073 .09625 .51323 .10028 .51187 .09728 .50937 Mtetra
.09728 .50937 .10028 .51187 .10431 .51052 .10132 .50801 Mtetra
.10132 .50801 .10431 .51052 .10835 .50916 .10537 .50665 Mtetra
.10537 .50665 .10835 .50916 .1124 .5078 .10942 .50528 Mtetra
.10942 .50528 .1124 .5078 .11646 .50644 .11348 .50391 Mtetra
.11348 .50391 .11646 .50644 .12052 .50507 .11754 .50254 Mtetra
.11754 .50254 .12052 .50507 .12459 .5037 .12161 .50117 Mtetra
.12161 .50117 .12459 .5037 .12866 .50233 .12569 .4998 Mtetra
.12569 .4998 .12866 .50233 .13274 .50096 .12978 .49842 Mtetra
.12978 .49842 .13274 .50096 .13683 .49959 .13387 .49705 Mtetra
.13387 .49705 .13683 .49959 .14092 .49821 .13797 .49567 Mtetra
.13797 .49567 .14092 .49821 .14503 .49683 .14207 .49428 Mtetra
.14207 .49428 .14503 .49683 .14913 .49545 .14618 .4929 Mtetra
.14618 .4929 .14913 .49545 .15325 .49407 .1503 .49151 Mtetra
.1503 .49151 .15325 .49407 .15737 .49269 .15442 .49012 Mtetra
.15442 .49012 .15737 .49269 .16149 .4913 .15855 .48873 Mtetra
.15855 .48873 .16149 .4913 .16563 .48991 .16269 .48734 Mtetra
.16269 .48734 .16563 .48991 .16977 .48852 .16684 .48594 Mtetra
.16684 .48594 .16977 .48852 .17392 .48712 .17099 .48454 Mtetra
.17099 .48454 .17392 .48712 .17807 .48573 .17514 .48314 Mtetra
.17514 .48314 .17807 .48573 .18223 .48433 .17931 .48174 Mtetra
.17931 .48174 .18223 .48433 .1864 .48293 .18348 .48034 Mtetra
.18348 .48034 .1864 .48293 .19057 .48153 .18766 .47893 Mtetra
.18766 .47893 .19057 .48153 .19475 .48012 .19184 .47752 Mtetra
.19184 .47752 .19475 .48012 .19894 .47871 .19603 .47611 Mtetra
.934 .727 .599 r
.19603 .47611 .19894 .47871 .20313 .4773 .20242 .45243 Mtetra
.549 .361 .579 r
.20242 .45243 .20313 .4773 .20948 .45364 .2066 .45101 Mtetra
.65 .758 .928 r
.2066 .45101 .20948 .45364 .21366 .45221 .21079 .44958 Mtetra
.21079 .44958 .21366 .45221 .21785 .45079 .21498 .44815 Mtetra
.21498 .44815 .21785 .45079 .22806 .38429 .21918 .44672 Mtetra
.497 .247 .466 r
.21918 .44672 .22806 .38429 .23219 .38284 .22338 .44529 Mtetra
0 0 .041 r
.22338 .44529 .23219 .38284 .23631 .38139 .23353 .37869 Mtetra
.655 .752 .921 r
.23353 .37869 .23631 .38139 .24045 .37993 .23767 .37723 Mtetra
.23767 .37723 .24045 .37993 .24459 .37847 .24181 .37577 Mtetra
.24181 .37577 .24459 .37847 .24874 .37701 .24596 .3743 Mtetra
.24596 .3743 .24874 .37701 .2529 .37554 .25012 .37283 Mtetra
.25012 .37283 .2529 .37554 .25706 .37408 .25429 .37136 Mtetra
.25429 .37136 .25706 .37408 .26123 .37261 .25846 .36989 Mtetra
.25846 .36989 .26123 .37261 .2654 .37114 .26264 .36841 Mtetra
.26264 .36841 .2654 .37114 .26959 .36966 .26683 .36694 Mtetra
.26683 .36694 .26959 .36966 .27377 .36819 .27102 .36546 Mtetra
.27102 .36546 .27377 .36819 .27797 .36671 .27522 .36397 Mtetra
.27522 .36397 .27797 .36671 .28217 .36523 .27943 .36249 Mtetra
.27943 .36249 .28217 .36523 .28638 .36374 .28364 .361 Mtetra
.28364 .361 .28638 .36374 .2906 .36226 .28786 .35951 Mtetra
.28786 .35951 .2906 .36226 .29482 .36077 .29209 .35802 Mtetra
.29209 .35802 .29482 .36077 .29905 .35928 .29632 .35652 Mtetra
.29632 .35652 .29905 .35928 .30328 .35779 .30056 .35503 Mtetra
.30056 .35503 .30328 .35779 .30753 .35629 .30481 .35353 Mtetra
.30481 .35353 .30753 .35629 .31178 .3548 .30906 .35203 Mtetra
.30906 .35203 .31178 .3548 .31603 .3533 .31332 .35052 Mtetra
.31332 .35052 .31603 .3533 .3203 .35179 .31759 .34901 Mtetra
.31759 .34901 .3203 .35179 .33047 .25673 .32186 .3475 Mtetra
0 0 .133 r
.32186 .3475 .33047 .25673 .33463 .2552 .33202 .25235 Mtetra
.662 .743 .91 r
.33202 .25235 .33463 .2552 .33879 .25366 .33618 .25081 Mtetra
.33618 .25081 .33879 .25366 .34296 .25212 .34035 .24927 Mtetra
.34035 .24927 .34296 .25212 .34713 .25057 .34453 .24772 Mtetra
.34453 .24772 .34713 .25057 .35132 .24903 .34872 .24617 Mtetra
.34872 .24617 .35132 .24903 .3555 .24748 .35291 .24461 Mtetra
.35291 .24461 .3555 .24748 .3597 .24593 .35711 .24306 Mtetra
.35711 .24306 .3597 .24593 .3639 .24438 .36132 .2415 Mtetra
0 .1 .616 r
.36132 .2415 .3639 .24438 .36785 .24789 .36526 .24501 Mtetra
.662 .744 .911 r
.36526 .24501 .36785 .24789 .37207 .24633 .36949 .24345 Mtetra
.36949 .24345 .37207 .24633 .3763 .24477 .37372 .24189 Mtetra
.37372 .24189 .3763 .24477 .38053 .24321 .37796 .24032 Mtetra
.37796 .24032 .38053 .24321 .38477 .24165 .38221 .23875 Mtetra
.38221 .23875 .38477 .24165 .38902 .24008 .38646 .23718 Mtetra
.38646 .23718 .38902 .24008 .39328 .23851 .39072 .23561 Mtetra
.39072 .23561 .39328 .23851 .39754 .23694 .39498 .23403 Mtetra
.39498 .23403 .39754 .23694 .40181 .23537 .39926 .23245 Mtetra
.39926 .23245 .40181 .23537 .40608 .23379 .40354 .23087 Mtetra
.40354 .23087 .40608 .23379 .41037 .23221 .40782 .22929 Mtetra
.40782 .22929 .41037 .23221 .41465 .23063 .41212 .2277 Mtetra
.41212 .2277 .41465 .23063 .41895 .22905 .41642 .22612 Mtetra
.41642 .22612 .41895 .22905 .42325 .22746 .42072 .22452 Mtetra
.42072 .22452 .42325 .22746 .42756 .22587 .42504 .22293 Mtetra
.42504 .22293 .42756 .22587 .43188 .22428 .42936 .22133 Mtetra
.42936 .22133 .43188 .22428 .4362 .22269 .43368 .21974 Mtetra
.43368 .21974 .4362 .22269 .44053 .22109 .43802 .21813 Mtetra
.969 .676 .415 r
.43802 .21813 .44053 .22109 .44487 .21949 .43814 .37206 Mtetra
.507 .267 .485 r
.43814 .37206 .44487 .21949 .44534 .37338 .44271 .37051 Mtetra
.65 .758 .928 r
.44271 .37051 .44534 .37338 .44991 .37182 .44728 .36895 Mtetra
.44728 .36895 .44991 .37182 .45449 .37027 .45186 .36738 Mtetra
.45186 .36738 .45449 .37027 .45908 .36871 .45645 .36582 Mtetra
.45645 .36582 .45908 .36871 .46367 .36714 .46105 .36425 Mtetra
.46105 .36425 .46367 .36714 .46827 .36558 .46566 .36268 Mtetra
.46566 .36268 .46827 .36558 .47288 .36401 .47027 .36111 Mtetra
.47027 .36111 .47288 .36401 .4775 .36244 .4749 .35953 Mtetra
.4749 .35953 .4775 .36244 .48212 .36086 .47953 .35795 Mtetra
.47953 .35795 .48212 .36086 .48676 .35929 .48416 .35637 Mtetra
.48416 .35637 .48676 .35929 .4914 .35771 .48881 .35479 Mtetra
.48881 .35479 .4914 .35771 .49605 .35613 .49346 .3532 Mtetra
.49346 .3532 .49605 .35613 .5007 .35454 .49812 .35161 Mtetra
.49812 .35161 .5007 .35454 .50537 .35296 .50279 .35002 Mtetra
.50279 .35002 .50537 .35296 .51004 .35137 .50747 .34842 Mtetra
.50747 .34842 .51004 .35137 .51472 .34977 .51216 .34683 Mtetra
.51216 .34683 .51472 .34977 .51941 .34818 .51685 .34523 Mtetra
.51685 .34523 .51941 .34818 .5241 .34658 .52155 .34362 Mtetra
.52155 .34362 .5241 .34658 .52862 .19375 .52626 .34202 Mtetra
.507 .266 .485 r
.52626 .34202 .52862 .19375 .53311 .1921 .53098 .34041 Mtetra
.522 .279 .487 r
.53098 .34041 .53311 .1921 .5376 .19044 .53572 .34449 Mtetra
.507 .267 .486 r
.53572 .34449 .5376 .19044 .543 .34585 .54047 .34287 Mtetra
.649 .759 .929 r
.54047 .34287 .543 .34585 .54775 .34424 .54522 .34126 Mtetra
.54522 .34126 .54775 .34424 .5525 .34263 .54998 .33964 Mtetra
.54998 .33964 .5525 .34263 .55726 .34101 .55474 .33802 Mtetra
.55474 .33802 .55726 .34101 .56203 .33939 .55952 .3364 Mtetra
.55952 .3364 .56203 .33939 .56681 .33777 .5643 .33477 Mtetra
.5643 .33477 .56681 .33777 .5716 .33615 .56909 .33314 Mtetra
.56909 .33314 .5716 .33615 .57639 .33452 .57389 .33151 Mtetra
.57389 .33151 .57639 .33452 .58119 .33289 .5787 .32988 Mtetra
.5787 .32988 .58119 .33289 .586 .33126 .58352 .32824 Mtetra
.58352 .32824 .586 .33126 .59082 .32963 .58834 .3266 Mtetra
.58834 .3266 .59082 .32963 .59565 .32799 .59318 .32496 Mtetra
.59318 .32496 .59565 .32799 .60049 .32635 .59802 .32331 Mtetra
.59802 .32331 .60049 .32635 .60533 .3247 .60287 .32166 Mtetra
.60287 .32166 .60533 .3247 .61019 .32306 .60773 .32001 Mtetra
.60773 .32001 .61019 .32306 .61505 .32141 .61259 .31836 Mtetra
.61259 .31836 .61505 .32141 .61992 .31976 .61747 .3167 Mtetra
.61747 .3167 .61992 .31976 .6248 .3181 .62235 .31504 Mtetra
.62235 .31504 .6248 .3181 .62968 .31644 .62725 .31337 Mtetra
.62725 .31337 .62968 .31644 .63458 .31478 .63215 .31171 Mtetra
.63215 .31171 .63458 .31478 .63824 .27906 .63706 .31004 Mtetra
.479 .211 .429 r
.63706 .31004 .63824 .27906 .64439 .31145 .64198 .30837 Mtetra
.649 .759 .929 r
.64198 .30837 .64439 .31145 .64932 .30978 .6469 .30669 Mtetra
.6469 .30669 .64932 .30978 .65425 .30811 .65184 .30502 Mtetra
.65184 .30502 .65425 .30811 .65918 .30644 .65678 .30333 Mtetra
.65678 .30333 .65918 .30644 .66413 .30476 .66174 .30165 Mtetra
.66174 .30165 .66413 .30476 .66909 .30308 .6667 .29996 Mtetra
.6667 .29996 .66909 .30308 .67405 .30139 .67167 .29827 Mtetra
.67167 .29827 .67405 .30139 .67903 .2997 .67665 .29658 Mtetra
.67665 .29658 .67903 .2997 .68401 .29801 .68164 .29489 Mtetra
.68164 .29489 .68401 .29801 .689 .29632 .68663 .29319 Mtetra
.68663 .29319 .689 .29632 .694 .29462 .69164 .29149 Mtetra
.69164 .29149 .694 .29462 .69901 .29293 .69666 .28978 Mtetra
.69666 .28978 .69901 .29293 .70402 .29122 .70168 .28807 Mtetra
.70168 .28807 .70402 .29122 .70905 .28952 .70671 .28636 Mtetra
.70671 .28636 .70905 .28952 .71409 .28781 .71175 .28465 Mtetra
.71175 .28465 .71409 .28781 .71913 .2861 .7168 .28293 Mtetra
.7168 .28293 .71913 .2861 .72418 .28439 .72186 .28121 Mtetra
.72186 .28121 .72418 .28439 .72925 .28267 .72693 .27949 Mtetra
.72693 .27949 .72925 .28267 .73432 .28095 .73201 .27776 Mtetra
.73201 .27776 .73432 .28095 .7394 .27922 .73709 .27603 Mtetra
.73709 .27603 .7394 .27922 .74449 .2775 .74219 .2743 Mtetra
.74219 .2743 .74449 .2775 .74958 .27577 .74729 .27257 Mtetra
.74729 .27257 .74958 .27577 .75469 .27404 .75241 .27083 Mtetra
.653 .755 .925 r
.07758 .4605 .08055 .46302 .08449 .46165 .08153 .45912 Mtetra
.08153 .45912 .08449 .46165 .08119 .51479 .08548 .45775 Mtetra
.529 .315 .534 r
.08548 .45775 .08119 .51479 .0852 .51344 .08943 .45637 Mtetra
.08943 .45637 .0852 .51344 .08922 .51208 .0934 .45499 Mtetra
0 0 .114 r
.0934 .45499 .08922 .51208 .09325 .51073 .09024 .50822 Mtetra
.648 .76 .931 r
.09024 .50822 .09325 .51073 .09728 .50937 .09428 .50686 Mtetra
.09428 .50686 .09728 .50937 .10132 .50801 .09832 .50549 Mtetra
.09832 .50549 .10132 .50801 .10537 .50665 .10237 .50412 Mtetra
.10237 .50412 .10537 .50665 .10942 .50528 .10643 .50276 Mtetra
.10643 .50276 .10942 .50528 .11348 .50391 .11049 .50138 Mtetra
.11049 .50138 .11348 .50391 .11754 .50254 .11456 .50001 Mtetra
.11456 .50001 .11754 .50254 .12161 .50117 .11863 .49864 Mtetra
.11863 .49864 .12161 .50117 .12569 .4998 .12271 .49726 Mtetra
.12271 .49726 .12569 .4998 .12978 .49842 .1268 .49588 Mtetra
.1268 .49588 .12978 .49842 .13387 .49705 .1309 .4945 Mtetra
.1309 .4945 .13387 .49705 .13797 .49567 .135 .49311 Mtetra
.135 .49311 .13797 .49567 .14207 .49428 .13911 .49173 Mtetra
.13911 .49173 .14207 .49428 .14618 .4929 .14322 .49034 Mtetra
.14322 .49034 .14618 .4929 .1503 .49151 .14734 .48895 Mtetra
.14734 .48895 .1503 .49151 .15442 .49012 .15147 .48755 Mtetra
.15147 .48755 .15442 .49012 .15855 .48873 .15561 .48616 Mtetra
.15561 .48616 .15855 .48873 .16269 .48734 .15975 .48476 Mtetra
.15975 .48476 .16269 .48734 .16684 .48594 .1639 .48336 Mtetra
.1639 .48336 .16684 .48594 .17099 .48454 .16805 .48196 Mtetra
.16805 .48196 .17099 .48454 .17514 .48314 .17221 .48055 Mtetra
.17221 .48055 .17514 .48314 .17931 .48174 .17638 .47915 Mtetra
.17638 .47915 .17931 .48174 .18348 .48034 .18055 .47774 Mtetra
.18055 .47774 .18348 .48034 .18766 .47893 .18474 .47633 Mtetra
.18474 .47633 .18766 .47893 .19184 .47752 .18893 .47491 Mtetra
.934 .726 .599 r
.18893 .47491 .19184 .47752 .19603 .47611 .19536 .45123 Mtetra
.549 .361 .579 r
.19536 .45123 .19603 .47611 .20242 .45243 .19954 .4498 Mtetra
.65 .758 .928 r
.19954 .4498 .20242 .45243 .2066 .45101 .20372 .44837 Mtetra
.20372 .44837 .2066 .45101 .21079 .44958 .20791 .44694 Mtetra
.20791 .44694 .21079 .44958 .21498 .44815 .2121 .44551 Mtetra
.2121 .44551 .21498 .44815 .21918 .44672 .21631 .44407 Mtetra
.21631 .44407 .21918 .44672 .22338 .44529 .22052 .44263 Mtetra
.22052 .44263 .22338 .44529 .23353 .37869 .22473 .44119 Mtetra
0 0 .041 r
.22473 .44119 .23353 .37869 .23767 .37723 .23487 .37453 Mtetra
.655 .752 .921 r
.23487 .37453 .23767 .37723 .24181 .37577 .23902 .37306 Mtetra
.23902 .37306 .24181 .37577 .24596 .3743 .24318 .37159 Mtetra
.24318 .37159 .24596 .3743 .25012 .37283 .24734 .37012 Mtetra
.24734 .37012 .25012 .37283 .25429 .37136 .25151 .36864 Mtetra
.25151 .36864 .25429 .37136 .25846 .36989 .25569 .36716 Mtetra
.25569 .36716 .25846 .36989 .26264 .36841 .25987 .36568 Mtetra
.25987 .36568 .26264 .36841 .26683 .36694 .26406 .3642 Mtetra
.26406 .3642 .26683 .36694 .27102 .36546 .26826 .36272 Mtetra
.26826 .36272 .27102 .36546 .27522 .36397 .27246 .36123 Mtetra
.27246 .36123 .27522 .36397 .27943 .36249 .27667 .35974 Mtetra
.27667 .35974 .27943 .36249 .28364 .361 .28089 .35825 Mtetra
.28089 .35825 .28364 .361 .28786 .35951 .28511 .35675 Mtetra
.28511 .35675 .28786 .35951 .29209 .35802 .28934 .35526 Mtetra
.28934 .35526 .29209 .35802 .29632 .35652 .29358 .35376 Mtetra
.29358 .35376 .29632 .35652 .30056 .35503 .29782 .35226 Mtetra
.29782 .35226 .30056 .35503 .30481 .35353 .30208 .35075 Mtetra
.30208 .35075 .30481 .35353 .30906 .35203 .30633 .34925 Mtetra
.30633 .34925 .30906 .35203 .31332 .35052 .3106 .34774 Mtetra
.3106 .34774 .31332 .35052 .31759 .34901 .31487 .34623 Mtetra
.31487 .34623 .31759 .34901 .32186 .3475 .31915 .34471 Mtetra
.31915 .34471 .32186 .3475 .33202 .25235 .32343 .3432 Mtetra
0 0 .133 r
.32343 .3432 .33202 .25235 .33618 .25081 .33357 .24796 Mtetra
.662 .743 .91 r
.33357 .24796 .33618 .25081 .34035 .24927 .33774 .24641 Mtetra
.33774 .24641 .34035 .24927 .34453 .24772 .34193 .24485 Mtetra
.34193 .24485 .34453 .24772 .34872 .24617 .34612 .2433 Mtetra
.34612 .2433 .34872 .24617 .35291 .24461 .35031 .24174 Mtetra
.35031 .24174 .35291 .24461 .35711 .24306 .35451 .24018 Mtetra
.35451 .24018 .35711 .24306 .36132 .2415 .35872 .23862 Mtetra
0 .1 .616 r
.35872 .23862 .36132 .2415 .36526 .24501 .36267 .24213 Mtetra
.662 .744 .911 r
.36267 .24213 .36526 .24501 .36949 .24345 .3669 .24056 Mtetra
.3669 .24056 .36949 .24345 .37372 .24189 .37114 .23899 Mtetra
.37114 .23899 .37372 .24189 .37796 .24032 .37538 .23742 Mtetra
.37538 .23742 .37796 .24032 .38221 .23875 .37963 .23585 Mtetra
.37963 .23585 .38221 .23875 .38646 .23718 .38389 .23427 Mtetra
.38389 .23427 .38646 .23718 .39072 .23561 .38815 .2327 Mtetra
.38815 .2327 .39072 .23561 .39498 .23403 .39242 .23112 Mtetra
.39242 .23112 .39498 .23403 .39926 .23245 .3967 .22953 Mtetra
.3967 .22953 .39926 .23245 .40354 .23087 .40098 .22795 Mtetra
.40098 .22795 .40354 .23087 .40782 .22929 .40527 .22636 Mtetra
.40527 .22636 .40782 .22929 .41212 .2277 .40957 .22477 Mtetra
.40957 .22477 .41212 .2277 .41642 .22612 .41387 .22318 Mtetra
.41387 .22318 .41642 .22612 .42072 .22452 .41819 .22158 Mtetra
.41819 .22158 .42072 .22452 .42504 .22293 .4225 .21998 Mtetra
.4225 .21998 .42504 .22293 .42936 .22133 .42683 .21838 Mtetra
.42683 .21838 .42936 .22133 .43368 .21974 .43116 .21678 Mtetra
.969 .676 .416 r
.43116 .21678 .43368 .21974 .43802 .21813 .43092 .37075 Mtetra
.506 .266 .485 r
.43092 .37075 .43802 .21813 .43814 .37206 .43549 .36919 Mtetra
.65 .758 .928 r
.43549 .36919 .43814 .37206 .44271 .37051 .44006 .36762 Mtetra
.44006 .36762 .44271 .37051 .44728 .36895 .44464 .36606 Mtetra
.44464 .36606 .44728 .36895 .45186 .36738 .44923 .36449 Mtetra
.44923 .36449 .45186 .36738 .45645 .36582 .45382 .36292 Mtetra
.45382 .36292 .45645 .36582 .46105 .36425 .45843 .36135 Mtetra
.45843 .36135 .46105 .36425 .46566 .36268 .46304 .35977 Mtetra
.46304 .35977 .46566 .36268 .47027 .36111 .46766 .35819 Mtetra
.46766 .35819 .47027 .36111 .4749 .35953 .47228 .35661 Mtetra
.47228 .35661 .4749 .35953 .47953 .35795 .47692 .35503 Mtetra
.47692 .35503 .47953 .35795 .48416 .35637 .48156 .35344 Mtetra
.48156 .35344 .48416 .35637 .48881 .35479 .48621 .35185 Mtetra
.48621 .35185 .48881 .35479 .49346 .3532 .49087 .35026 Mtetra
.49087 .35026 .49346 .3532 .49812 .35161 .49554 .34867 Mtetra
.49554 .34867 .49812 .35161 .50279 .35002 .50021 .34707 Mtetra
.50021 .34707 .50279 .35002 .50747 .34842 .5049 .34547 Mtetra
.5049 .34547 .50747 .34842 .51216 .34683 .50959 .34387 Mtetra
.50959 .34387 .51216 .34683 .51685 .34523 .51429 .34226 Mtetra
.51429 .34226 .51685 .34523 .52155 .34362 .51899 .34066 Mtetra
.51899 .34066 .52155 .34362 .52626 .34202 .52371 .33904 Mtetra
.52371 .33904 .52626 .34202 .53098 .34041 .52843 .33743 Mtetra
0 .126 .644 r
.52843 .33743 .53098 .34041 .53572 .34449 .53318 .34151 Mtetra
.649 .759 .929 r
.53318 .34151 .53572 .34449 .54047 .34287 .53792 .33989 Mtetra
.53792 .33989 .54047 .34287 .54522 .34126 .54268 .33827 Mtetra
.54268 .33827 .54522 .34126 .54998 .33964 .54744 .33665 Mtetra
.54744 .33665 .54998 .33964 .55474 .33802 .55222 .33502 Mtetra
.55222 .33502 .55474 .33802 .55952 .3364 .557 .33339 Mtetra
.557 .33339 .55952 .3364 .5643 .33477 .56179 .33176 Mtetra
.56179 .33176 .5643 .33477 .56909 .33314 .56658 .33013 Mtetra
.56658 .33013 .56909 .33314 .57389 .33151 .57139 .32849 Mtetra
.57139 .32849 .57389 .33151 .5787 .32988 .5762 .32685 Mtetra
.5762 .32685 .5787 .32988 .58352 .32824 .58102 .32521 Mtetra
.58102 .32521 .58352 .32824 .58834 .3266 .58586 .32356 Mtetra
.58586 .32356 .58834 .3266 .59318 .32496 .59069 .32192 Mtetra
.59069 .32192 .59318 .32496 .59802 .32331 .59554 .32026 Mtetra
.59554 .32026 .59802 .32331 .60287 .32166 .6004 .31861 Mtetra
.6004 .31861 .60287 .32166 .60773 .32001 .60526 .31695 Mtetra
.60526 .31695 .60773 .32001 .61259 .31836 .61013 .31529 Mtetra
.61013 .31529 .61259 .31836 .61747 .3167 .61502 .31363 Mtetra
.61502 .31363 .61747 .3167 .62235 .31504 .61991 .31197 Mtetra
.61991 .31197 .62235 .31504 .62725 .31337 .6248 .3103 Mtetra
.6248 .3103 .62725 .31337 .63215 .31171 .62971 .30863 Mtetra
.62971 .30863 .63215 .31171 .63706 .31004 .63463 .30695 Mtetra
.63463 .30695 .63706 .31004 .64198 .30837 .63955 .30527 Mtetra
.63955 .30527 .64198 .30837 .6469 .30669 .64448 .30359 Mtetra
.64448 .30359 .6469 .30669 .65184 .30502 .64943 .30191 Mtetra
.64943 .30191 .65184 .30502 .65678 .30333 .65438 .30022 Mtetra
.65438 .30022 .65678 .30333 .66174 .30165 .65934 .29853 Mtetra
.65934 .29853 .66174 .30165 .6667 .29996 .6643 .29684 Mtetra
.6643 .29684 .6667 .29996 .67167 .29827 .66928 .29515 Mtetra
.66928 .29515 .67167 .29827 .67665 .29658 .67427 .29345 Mtetra
.67427 .29345 .67665 .29658 .68164 .29489 .67926 .29175 Mtetra
.67926 .29175 .68164 .29489 .68663 .29319 .68426 .29004 Mtetra
.68426 .29004 .68663 .29319 .69164 .29149 .68927 .28834 Mtetra
.68927 .28834 .69164 .29149 .69666 .28978 .6943 .28663 Mtetra
.6943 .28663 .69666 .28978 .70168 .28807 .69933 .28491 Mtetra
.69933 .28491 .70168 .28807 .70671 .28636 .70436 .2832 Mtetra
.70436 .2832 .70671 .28636 .71175 .28465 .70941 .28148 Mtetra
.70941 .28148 .71175 .28465 .7168 .28293 .71447 .27975 Mtetra
.71447 .27975 .7168 .28293 .72186 .28121 .71953 .27803 Mtetra
.71953 .27803 .72186 .28121 .72693 .27949 .72461 .2763 Mtetra
.72461 .2763 .72693 .27949 .73201 .27776 .72969 .27457 Mtetra
.72969 .27457 .73201 .27776 .73709 .27603 .73478 .27283 Mtetra
.73478 .27283 .73709 .27603 .74219 .2743 .73989 .2711 Mtetra
.73989 .2711 .74219 .2743 .74729 .27257 .745 .26936 Mtetra
.745 .26936 .74729 .27257 .75241 .27083 .75012 .26761 Mtetra
.653 .755 .925 r
.07461 .45796 .07758 .4605 .08153 .45912 .07856 .45659 Mtetra
.07856 .45659 .08153 .45912 .08548 .45775 .08251 .45521 Mtetra
.08251 .45521 .08548 .45775 .08943 .45637 .08647 .45383 Mtetra
.08647 .45383 .08943 .45637 .0934 .45499 .09044 .45244 Mtetra
.09044 .45244 .0934 .45499 .09024 .50822 .09441 .45106 Mtetra
.528 .315 .533 r
.09441 .45106 .09024 .50822 .09428 .50686 .09839 .44967 Mtetra
0 0 .117 r
.09839 .44967 .09428 .50686 .09832 .50549 .09531 .50297 Mtetra
.648 .76 .931 r
.09531 .50297 .09832 .50549 .10237 .50412 .09937 .5016 Mtetra
.09937 .5016 .10237 .50412 .10643 .50276 .10343 .50022 Mtetra
.10343 .50022 .10643 .50276 .11049 .50138 .10749 .49885 Mtetra
.10749 .49885 .11049 .50138 .11456 .50001 .11156 .49747 Mtetra
.11156 .49747 .11456 .50001 .11863 .49864 .11564 .49609 Mtetra
.11564 .49609 .11863 .49864 .12271 .49726 .11973 .49471 Mtetra
.11973 .49471 .12271 .49726 .1268 .49588 .12382 .49333 Mtetra
.12382 .49333 .1268 .49588 .1309 .4945 .12792 .49194 Mtetra
.12792 .49194 .1309 .4945 .135 .49311 .13202 .49055 Mtetra
.13202 .49055 .135 .49311 .13911 .49173 .13614 .48916 Mtetra
.13614 .48916 .13911 .49173 .14322 .49034 .14025 .48777 Mtetra
.14025 .48777 .14322 .49034 .14734 .48895 .14438 .48637 Mtetra
.14438 .48637 .14734 .48895 .15147 .48755 .14851 .48497 Mtetra
.14851 .48497 .15147 .48755 .15561 .48616 .15265 .48358 Mtetra
.15265 .48358 .15561 .48616 .15975 .48476 .15679 .48217 Mtetra
.15679 .48217 .15975 .48476 .1639 .48336 .16095 .48077 Mtetra
.16095 .48077 .1639 .48336 .16805 .48196 .1651 .47936 Mtetra
.1651 .47936 .16805 .48196 .17221 .48055 .16927 .47795 Mtetra
.16927 .47795 .17221 .48055 .17638 .47915 .17344 .47654 Mtetra
.17344 .47654 .17638 .47915 .18055 .47774 .17762 .47513 Mtetra
.17762 .47513 .18055 .47774 .18474 .47633 .18181 .47371 Mtetra
.933 .726 .6 r
.18181 .47371 .18474 .47633 .18893 .47491 .18829 .45002 Mtetra
.548 .36 .578 r
.18829 .45002 .18893 .47491 .19536 .45123 .19246 .44859 Mtetra
.65 .758 .928 r
.19246 .44859 .19536 .45123 .19954 .4498 .19664 .44716 Mtetra
.19664 .44716 .19954 .4498 .20372 .44837 .20083 .44573 Mtetra
.20083 .44573 .20372 .44837 .20791 .44694 .20502 .44429 Mtetra
.20502 .44429 .20791 .44694 .2121 .44551 .20922 .44285 Mtetra
.20922 .44285 .2121 .44551 .21631 .44407 .21343 .44141 Mtetra
.21343 .44141 .21631 .44407 .22052 .44263 .21764 .43997 Mtetra
.21764 .43997 .22052 .44263 .22473 .44119 .22186 .43853 Mtetra
.22186 .43853 .22473 .44119 .23487 .37453 .22609 .43708 Mtetra
0 0 .041 r
.22609 .43708 .23487 .37453 .23902 .37306 .23622 .37034 Mtetra
.655 .752 .921 r
.23622 .37034 .23902 .37306 .24318 .37159 .24039 .36887 Mtetra
.24039 .36887 .24318 .37159 .24734 .37012 .24455 .36739 Mtetra
.24455 .36739 .24734 .37012 .25151 .36864 .24873 .36591 Mtetra
.24873 .36591 .25151 .36864 .25569 .36716 .25291 .36443 Mtetra
.25291 .36443 .25569 .36716 .25987 .36568 .25709 .36295 Mtetra
.25709 .36295 .25987 .36568 .26406 .3642 .26129 .36146 Mtetra
.26129 .36146 .26406 .3642 .26826 .36272 .26549 .35997 Mtetra
.26549 .35997 .26826 .36272 .27246 .36123 .2697 .35848 Mtetra
.2697 .35848 .27246 .36123 .27667 .35974 .27391 .35698 Mtetra
.27391 .35698 .27667 .35974 .28089 .35825 .27813 .35549 Mtetra
.27813 .35549 .28089 .35825 .28511 .35675 .28236 .35399 Mtetra
.28236 .35399 .28511 .35675 .28934 .35526 .28659 .35249 Mtetra
.28659 .35249 .28934 .35526 .29358 .35376 .29084 .35098 Mtetra
.29084 .35098 .29358 .35376 .29782 .35226 .29508 .34948 Mtetra
.29508 .34948 .29782 .35226 .30208 .35075 .29934 .34797 Mtetra
.29934 .34797 .30208 .35075 .30633 .34925 .3036 .34646 Mtetra
.3036 .34646 .30633 .34925 .3106 .34774 .30787 .34495 Mtetra
.30787 .34495 .3106 .34774 .31487 .34623 .31215 .34343 Mtetra
.31215 .34343 .31487 .34623 .31915 .34471 .31643 .34191 Mtetra
.31643 .34191 .31915 .34471 .32343 .3432 .32072 .34039 Mtetra
.959 .701 .502 r
.32072 .34039 .32343 .3432 .33357 .24796 .33094 .24509 Mtetra
.662 .743 .91 r
.33094 .24509 .33357 .24796 .33774 .24641 .33512 .24354 Mtetra
.33512 .24354 .33774 .24641 .34193 .24485 .33931 .24198 Mtetra
.33931 .24198 .34193 .24485 .34612 .2433 .3435 .24042 Mtetra
.3435 .24042 .34612 .2433 .35031 .24174 .3477 .23886 Mtetra
.963 .679 .446 r
.3477 .23886 .35031 .24174 .35451 .24018 .34288 .3971 Mtetra
.506 .265 .484 r
.34288 .3971 .35451 .24018 .35872 .23862 .3473 .39558 Mtetra
.3473 .39558 .35872 .23862 .36267 .24213 .35174 .39406 Mtetra
.505 .265 .484 r
.35174 .39406 .36267 .24213 .3669 .24056 .35618 .39254 Mtetra
.35618 .39254 .3669 .24056 .37114 .23899 .36063 .39102 Mtetra
.36063 .39102 .37114 .23899 .37538 .23742 .36508 .38949 Mtetra
.36508 .38949 .37538 .23742 .37963 .23585 .36955 .38796 Mtetra
.36955 .38796 .37963 .23585 .38389 .23427 .37402 .38643 Mtetra
0 0 .188 r
.37402 .38643 .38389 .23427 .38815 .2327 .38558 .22978 Mtetra
.662 .744 .911 r
.38558 .22978 .38815 .2327 .39242 .23112 .38985 .22819 Mtetra
.38985 .22819 .39242 .23112 .3967 .22953 .39413 .2266 Mtetra
.39413 .2266 .3967 .22953 .40098 .22795 .39842 .22501 Mtetra
.39842 .22501 .40098 .22795 .40527 .22636 .40271 .22342 Mtetra
.40271 .22342 .40527 .22636 .40957 .22477 .40702 .22183 Mtetra
.40702 .22183 .40957 .22477 .41387 .22318 .41133 .22023 Mtetra
.41133 .22023 .41387 .22318 .41819 .22158 .41564 .21863 Mtetra
.41564 .21863 .41819 .22158 .4225 .21998 .41996 .21702 Mtetra
.41996 .21702 .4225 .21998 .42683 .21838 .42429 .21542 Mtetra
.969 .676 .418 r
.42429 .21542 .42683 .21838 .43116 .21678 .4237 .36943 Mtetra
.505 .265 .484 r
.4237 .36943 .43116 .21678 .43092 .37075 .42826 .36786 Mtetra
.65 .758 .928 r
.42826 .36786 .43092 .37075 .43549 .36919 .43283 .3663 Mtetra
.43283 .3663 .43549 .36919 .44006 .36762 .43741 .36473 Mtetra
.43741 .36473 .44006 .36762 .44464 .36606 .44199 .36316 Mtetra
.44199 .36316 .44464 .36606 .44923 .36449 .44658 .36159 Mtetra
.44658 .36159 .44923 .36449 .45382 .36292 .45118 .36002 Mtetra
.45118 .36002 .45382 .36292 .45843 .36135 .45579 .35844 Mtetra
.45579 .35844 .45843 .36135 .46304 .35977 .46041 .35686 Mtetra
.46041 .35686 .46304 .35977 .46766 .35819 .46503 .35527 Mtetra
.46503 .35527 .46766 .35819 .47228 .35661 .46967 .35369 Mtetra
.46967 .35369 .47228 .35661 .47692 .35503 .47431 .3521 Mtetra
.47431 .3521 .47692 .35503 .48156 .35344 .47895 .35051 Mtetra
.47895 .35051 .48156 .35344 .48621 .35185 .48361 .34891 Mtetra
.48361 .34891 .48621 .35185 .49087 .35026 .48827 .34732 Mtetra
.48827 .34732 .49087 .35026 .49554 .34867 .49294 .34572 Mtetra
.49294 .34572 .49554 .34867 .50021 .34707 .49762 .34412 Mtetra
.49762 .34412 .50021 .34707 .5049 .34547 .50231 .34251 Mtetra
.50231 .34251 .5049 .34547 .50959 .34387 .50701 .3409 Mtetra
.50701 .3409 .50959 .34387 .51429 .34226 .51171 .33929 Mtetra
.51171 .33929 .51429 .34226 .51899 .34066 .51642 .33768 Mtetra
.51642 .33768 .51899 .34066 .52371 .33904 .52114 .33606 Mtetra
.52114 .33606 .52371 .33904 .52843 .33743 .52587 .33444 Mtetra
0 .126 .644 r
.52587 .33444 .52843 .33743 .53318 .34151 .53062 .33852 Mtetra
.649 .759 .929 r
.53062 .33852 .53318 .34151 .53792 .33989 .53537 .3369 Mtetra
.53537 .3369 .53792 .33989 .54268 .33827 .54013 .33527 Mtetra
.54013 .33527 .54268 .33827 .54744 .33665 .5449 .33364 Mtetra
.5449 .33364 .54744 .33665 .55222 .33502 .54968 .33201 Mtetra
.54968 .33201 .55222 .33502 .557 .33339 .55447 .33038 Mtetra
.55447 .33038 .557 .33339 .56179 .33176 .55926 .32874 Mtetra
.55926 .32874 .56179 .33176 .56658 .33013 .56406 .3271 Mtetra
.56406 .3271 .56658 .33013 .57139 .32849 .56888 .32546 Mtetra
.56888 .32546 .57139 .32849 .5762 .32685 .57369 .32382 Mtetra
.57369 .32382 .5762 .32685 .58102 .32521 .57852 .32217 Mtetra
.57852 .32217 .58102 .32521 .58586 .32356 .58336 .32052 Mtetra
.58336 .32052 .58586 .32356 .59069 .32192 .5882 .31887 Mtetra
.5882 .31887 .59069 .32192 .59554 .32026 .59306 .31721 Mtetra
.59306 .31721 .59554 .32026 .6004 .31861 .59792 .31555 Mtetra
.59792 .31555 .6004 .31861 .60526 .31695 .60279 .31389 Mtetra
.60279 .31389 .60526 .31695 .61013 .31529 .60767 .31222 Mtetra
.60767 .31222 .61013 .31529 .61502 .31363 .61255 .31055 Mtetra
.61255 .31055 .61502 .31363 .61991 .31197 .61745 .30888 Mtetra
.61745 .30888 .61991 .31197 .6248 .3103 .62235 .30721 Mtetra
.62235 .30721 .6248 .3103 .62971 .30863 .62727 .30553 Mtetra
.62727 .30553 .62971 .30863 .63463 .30695 .63219 .30385 Mtetra
.63219 .30385 .63463 .30695 .63955 .30527 .63712 .30217 Mtetra
.63712 .30217 .63955 .30527 .64448 .30359 .64206 .30048 Mtetra
.64206 .30048 .64448 .30359 .64943 .30191 .64701 .29879 Mtetra
.64701 .29879 .64943 .30191 .65438 .30022 .65196 .2971 Mtetra
.65196 .2971 .65438 .30022 .65934 .29853 .65693 .29541 Mtetra
.65693 .29541 .65934 .29853 .6643 .29684 .6619 .29371 Mtetra
.6619 .29371 .6643 .29684 .66928 .29515 .66688 .29201 Mtetra
.66688 .29201 .66928 .29515 .67427 .29345 .67187 .29031 Mtetra
.67187 .29031 .67427 .29345 .67926 .29175 .67687 .2886 Mtetra
.67687 .2886 .67926 .29175 .68426 .29004 .68188 .28689 Mtetra
.68188 .28689 .68426 .29004 .68927 .28834 .6869 .28518 Mtetra
.6869 .28518 .68927 .28834 .6943 .28663 .69193 .28346 Mtetra
.69193 .28346 .6943 .28663 .69933 .28491 .69696 .28174 Mtetra
.69696 .28174 .69933 .28491 .70436 .2832 .70201 .28002 Mtetra
.70201 .28002 .70436 .2832 .70941 .28148 .70706 .2783 Mtetra
.70706 .2783 .70941 .28148 .71447 .27975 .71213 .27657 Mtetra
.71213 .27657 .71447 .27975 .71953 .27803 .7172 .27484 Mtetra
.7172 .27484 .71953 .27803 .72461 .2763 .72228 .2731 Mtetra
.72228 .2731 .72461 .2763 .72969 .27457 .72737 .27136 Mtetra
.72737 .27136 .72969 .27457 .73478 .27283 .73247 .26962 Mtetra
.73247 .26962 .73478 .27283 .73989 .2711 .73758 .26788 Mtetra
.73758 .26788 .73989 .2711 .745 .26936 .74269 .26613 Mtetra
.74269 .26613 .745 .26936 .75012 .26761 .74782 .26438 Mtetra
.653 .755 .925 r
.07163 .45542 .07461 .45796 .07856 .45659 .07558 .45404 Mtetra
.07558 .45404 .07856 .45659 .08251 .45521 .07954 .45266 Mtetra
.07954 .45266 .08251 .45521 .08647 .45383 .0835 .45127 Mtetra
.0835 .45127 .08647 .45383 .09044 .45244 .08747 .44989 Mtetra
.08747 .44989 .09044 .45244 .09441 .45106 .09145 .4485 Mtetra
.09145 .4485 .09441 .45106 .09839 .44967 .09543 .44711 Mtetra
.09543 .44711 .09839 .44967 .09531 .50297 .09942 .44571 Mtetra
.528 .314 .533 r
.09942 .44571 .09531 .50297 .09937 .5016 .10341 .44432 Mtetra
.10341 .44432 .09937 .5016 .10343 .50022 .10742 .44292 Mtetra
0 0 .123 r
.10742 .44292 .10343 .50022 .10749 .49885 .10448 .4963 Mtetra
.648 .76 .931 r
.10448 .4963 .10749 .49885 .11156 .49747 .10856 .49492 Mtetra
.10856 .49492 .11156 .49747 .11564 .49609 .11264 .49354 Mtetra
.11264 .49354 .11564 .49609 .11973 .49471 .11673 .49215 Mtetra
.11673 .49215 .11973 .49471 .12382 .49333 .12083 .49076 Mtetra
.12083 .49076 .12382 .49333 .12792 .49194 .12493 .48937 Mtetra
.12493 .48937 .12792 .49194 .13202 .49055 .12904 .48798 Mtetra
.12904 .48798 .13202 .49055 .13614 .48916 .13315 .48659 Mtetra
.13315 .48659 .13614 .48916 .14025 .48777 .13728 .48519 Mtetra
.13728 .48519 .14025 .48777 .14438 .48637 .14141 .48379 Mtetra
.14141 .48379 .14438 .48637 .14851 .48497 .14554 .48239 Mtetra
.14554 .48239 .14851 .48497 .15265 .48358 .14968 .48099 Mtetra
.14968 .48099 .15265 .48358 .15679 .48217 .15383 .47958 Mtetra
.15383 .47958 .15679 .48217 .16095 .48077 .15799 .47817 Mtetra
.15799 .47817 .16095 .48077 .1651 .47936 .16215 .47676 Mtetra
.16215 .47676 .1651 .47936 .16927 .47795 .16632 .47535 Mtetra
.16632 .47535 .16927 .47795 .17344 .47654 .1705 .47393 Mtetra
.1705 .47393 .17344 .47654 .17762 .47513 .17468 .47251 Mtetra
.933 .726 .6 r
.17468 .47251 .17762 .47513 .18181 .47371 .18121 .44881 Mtetra
.548 .36 .578 r
.18121 .44881 .18181 .47371 .18829 .45002 .18538 .44738 Mtetra
.65 .758 .928 r
.18538 .44738 .18829 .45002 .19246 .44859 .18955 .44595 Mtetra
.18955 .44595 .19246 .44859 .19664 .44716 .19374 .44451 Mtetra
.19374 .44451 .19664 .44716 .20083 .44573 .19793 .44308 Mtetra
.19793 .44308 .20083 .44573 .20502 .44429 .20213 .44164 Mtetra
.20213 .44164 .20502 .44429 .20922 .44285 .20633 .44019 Mtetra
.20633 .44019 .20922 .44285 .21343 .44141 .21054 .43875 Mtetra
.21054 .43875 .21343 .44141 .21764 .43997 .21476 .4373 Mtetra
.21476 .4373 .21764 .43997 .22186 .43853 .21898 .43585 Mtetra
.21898 .43585 .22186 .43853 .22609 .43708 .22321 .4344 Mtetra
.22321 .4344 .22609 .43708 .23622 .37034 .22745 .43295 Mtetra
0 0 .041 r
.22745 .43295 .23622 .37034 .24039 .36887 .23758 .36614 Mtetra
.655 .752 .921 r
.23758 .36614 .24039 .36887 .24455 .36739 .24175 .36466 Mtetra
.24175 .36466 .24455 .36739 .24873 .36591 .24593 .36317 Mtetra
.24593 .36317 .24873 .36591 .25291 .36443 .25012 .36169 Mtetra
.25012 .36169 .25291 .36443 .25709 .36295 .25431 .3602 Mtetra
.25431 .3602 .25709 .36295 .26129 .36146 .25851 .35871 Mtetra
.25851 .35871 .26129 .36146 .26549 .35997 .26271 .35721 Mtetra
.26271 .35721 .26549 .35997 .2697 .35848 .26692 .35572 Mtetra
.26692 .35572 .2697 .35848 .27391 .35698 .27114 .35422 Mtetra
.27114 .35422 .27391 .35698 .27813 .35549 .27537 .35272 Mtetra
.27537 .35272 .27813 .35549 .28236 .35399 .2796 .35122 Mtetra
.2796 .35122 .28236 .35399 .28659 .35249 .28384 .34971 Mtetra
.28384 .34971 .28659 .35249 .29084 .35098 .28808 .3482 Mtetra
.28808 .3482 .29084 .35098 .29508 .34948 .29233 .34669 Mtetra
.29233 .34669 .29508 .34948 .29934 .34797 .29659 .34518 Mtetra
.29659 .34518 .29934 .34797 .3036 .34646 .30086 .34366 Mtetra
.30086 .34366 .3036 .34646 .30787 .34495 .30513 .34214 Mtetra
.30513 .34214 .30787 .34495 .31215 .34343 .30941 .34062 Mtetra
.30941 .34062 .31215 .34343 .31643 .34191 .3137 .3391 Mtetra
.3137 .3391 .31643 .34191 .32072 .34039 .31799 .33758 Mtetra
.31799 .33758 .32072 .34039 .33094 .24509 .32229 .33605 Mtetra
0 0 .13 r
.32229 .33605 .33094 .24509 .33512 .24354 .3325 .24066 Mtetra
.662 .743 .91 r
.3325 .24066 .33512 .24354 .33931 .24198 .33669 .2391 Mtetra
.963 .679 .449 r
.33669 .2391 .33931 .24198 .3435 .24042 .33128 .39733 Mtetra
.505 .264 .484 r
.33128 .39733 .3435 .24042 .3477 .23886 .33569 .39581 Mtetra
.33569 .39581 .3477 .23886 .34288 .3971 .34012 .3943 Mtetra
.65 .758 .928 r
.34012 .3943 .34288 .3971 .3473 .39558 .34455 .39278 Mtetra
.34455 .39278 .3473 .39558 .35174 .39406 .34899 .39125 Mtetra
.34899 .39125 .35174 .39406 .35618 .39254 .35343 .38973 Mtetra
.35343 .38973 .35618 .39254 .36063 .39102 .35788 .3882 Mtetra
.35788 .3882 .36063 .39102 .36508 .38949 .36235 .38667 Mtetra
.36235 .38667 .36508 .38949 .36955 .38796 .36681 .38514 Mtetra
.36681 .38514 .36955 .38796 .37402 .38643 .37129 .3836 Mtetra
.37129 .3836 .37402 .38643 .38558 .22978 .37577 .38206 Mtetra
.505 .264 .483 r
.37577 .38206 .38558 .22978 .38985 .22819 .38026 .38052 Mtetra
.38026 .38052 .38985 .22819 .39413 .2266 .38476 .37898 Mtetra
.38476 .37898 .39413 .2266 .39842 .22501 .38927 .37743 Mtetra
.38927 .37743 .39842 .22501 .40271 .22342 .39378 .37589 Mtetra
0 0 .199 r
.39378 .37589 .40271 .22342 .40702 .22183 .40446 .21887 Mtetra
.662 .744 .911 r
.40446 .21887 .40702 .22183 .41133 .22023 .40877 .21727 Mtetra
.40877 .21727 .41133 .22023 .41564 .21863 .41309 .21567 Mtetra
.41309 .21567 .41564 .21863 .41996 .21702 .41742 .21406 Mtetra
.968 .676 .42 r
.41742 .21406 .41996 .21702 .42429 .21542 .41646 .3681 Mtetra
.505 .264 .483 r
.41646 .3681 .42429 .21542 .4237 .36943 .42102 .36654 Mtetra
.65 .758 .928 r
.42102 .36654 .4237 .36943 .42826 .36786 .42559 .36497 Mtetra
.42559 .36497 .42826 .36786 .43283 .3663 .43016 .3634 Mtetra
.43016 .3634 .43283 .3663 .43741 .36473 .43474 .36183 Mtetra
.43474 .36183 .43741 .36473 .44199 .36316 .43933 .36026 Mtetra
.43933 .36026 .44199 .36316 .44658 .36159 .44393 .35868 Mtetra
.44393 .35868 .44658 .36159 .45118 .36002 .44854 .3571 Mtetra
.44854 .3571 .45118 .36002 .45579 .35844 .45315 .35552 Mtetra
.45315 .35552 .45579 .35844 .46041 .35686 .45777 .35393 Mtetra
.45777 .35393 .46041 .35686 .46503 .35527 .4624 .35234 Mtetra
.4624 .35234 .46503 .35527 .46967 .35369 .46704 .35075 Mtetra
.46704 .35075 .46967 .35369 .47431 .3521 .47168 .34916 Mtetra
.47168 .34916 .47431 .3521 .47895 .35051 .47634 .34756 Mtetra
.47634 .34756 .47895 .35051 .48361 .34891 .481 .34596 Mtetra
.481 .34596 .48361 .34891 .48827 .34732 .48567 .34436 Mtetra
.48567 .34436 .48827 .34732 .49294 .34572 .49034 .34276 Mtetra
.49034 .34276 .49294 .34572 .49762 .34412 .49503 .34115 Mtetra
.49503 .34115 .49762 .34412 .50231 .34251 .49972 .33954 Mtetra
.49972 .33954 .50231 .34251 .50701 .3409 .50442 .33793 Mtetra
.50442 .33793 .50701 .3409 .51171 .33929 .50913 .33631 Mtetra
.50913 .33631 .51171 .33929 .51642 .33768 .51385 .33469 Mtetra
.51385 .33469 .51642 .33768 .52114 .33606 .51857 .33307 Mtetra
.51857 .33307 .52114 .33606 .52587 .33444 .52331 .33145 Mtetra
0 .126 .644 r
.52331 .33145 .52587 .33444 .53062 .33852 .52805 .33552 Mtetra
.649 .759 .929 r
.52805 .33552 .53062 .33852 .53537 .3369 .53281 .3339 Mtetra
.53281 .3339 .53537 .3369 .54013 .33527 .53758 .33226 Mtetra
.53758 .33226 .54013 .33527 .5449 .33364 .54235 .33063 Mtetra
.54235 .33063 .5449 .33364 .54968 .33201 .54714 .329 Mtetra
.54714 .329 .54968 .33201 .55447 .33038 .55193 .32736 Mtetra
.55193 .32736 .55447 .33038 .55926 .32874 .55673 .32572 Mtetra
.55673 .32572 .55926 .32874 .56406 .3271 .56154 .32407 Mtetra
.56154 .32407 .56406 .3271 .56888 .32546 .56635 .32242 Mtetra
.56635 .32242 .56888 .32546 .57369 .32382 .57118 .32077 Mtetra
.57118 .32077 .57369 .32382 .57852 .32217 .57601 .31912 Mtetra
.57601 .31912 .57852 .32217 .58336 .32052 .58085 .31746 Mtetra
.58085 .31746 .58336 .32052 .5882 .31887 .5857 .3158 Mtetra
.5857 .3158 .5882 .31887 .59306 .31721 .59056 .31414 Mtetra
.59056 .31414 .59306 .31721 .59792 .31555 .59543 .31248 Mtetra
.59543 .31248 .59792 .31555 .60279 .31389 .60031 .31081 Mtetra
.60031 .31081 .60279 .31389 .60767 .31222 .60519 .30914 Mtetra
.60519 .30914 .60767 .31222 .61255 .31055 .61008 .30747 Mtetra
.61008 .30747 .61255 .31055 .61745 .30888 .61499 .30579 Mtetra
.61499 .30579 .61745 .30888 .62235 .30721 .6199 .30411 Mtetra
.6199 .30411 .62235 .30721 .62727 .30553 .62481 .30243 Mtetra
.62481 .30243 .62727 .30553 .63219 .30385 .62974 .30074 Mtetra
.62974 .30074 .63219 .30385 .63712 .30217 .63468 .29905 Mtetra
.63468 .29905 .63712 .30217 .64206 .30048 .63962 .29736 Mtetra
.63962 .29736 .64206 .30048 .64701 .29879 .64458 .29567 Mtetra
.64458 .29567 .64701 .29879 .65196 .2971 .64954 .29397 Mtetra
.64954 .29397 .65196 .2971 .65693 .29541 .65451 .29227 Mtetra
.65451 .29227 .65693 .29541 .6619 .29371 .65949 .29057 Mtetra
.65949 .29057 .6619 .29371 .66688 .29201 .66448 .28886 Mtetra
.66448 .28886 .66688 .29201 .67187 .29031 .66947 .28715 Mtetra
.66947 .28715 .67187 .29031 .67687 .2886 .67448 .28544 Mtetra
.67448 .28544 .67687 .2886 .68188 .28689 .6795 .28373 Mtetra
.6795 .28373 .68188 .28689 .6869 .28518 .68452 .28201 Mtetra
.68452 .28201 .6869 .28518 .69193 .28346 .68955 .28029 Mtetra
.68955 .28029 .69193 .28346 .69696 .28174 .6946 .27856 Mtetra
.6946 .27856 .69696 .28174 .70201 .28002 .69965 .27683 Mtetra
.69965 .27683 .70201 .28002 .70706 .2783 .70471 .2751 Mtetra
.70471 .2751 .70706 .2783 .71213 .27657 .70978 .27337 Mtetra
.70978 .27337 .71213 .27657 .7172 .27484 .71485 .27163 Mtetra
.71485 .27163 .7172 .27484 .72228 .2731 .71994 .26989 Mtetra
.71994 .26989 .72228 .2731 .72737 .27136 .72504 .26815 Mtetra
.72504 .26815 .72737 .27136 .73247 .26962 .73014 .2664 Mtetra
.73014 .2664 .73247 .26962 .73758 .26788 .73526 .26465 Mtetra
.73526 .26465 .73758 .26788 .74269 .26613 .74038 .2629 Mtetra
.74038 .2629 .74269 .26613 .74782 .26438 .74551 .26115 Mtetra
.653 .755 .925 r
.06864 .45287 .07163 .45542 .07558 .45404 .07259 .45149 Mtetra
.07259 .45149 .07558 .45404 .07954 .45266 .07655 .4501 Mtetra
.07655 .4501 .07954 .45266 .0835 .45127 .08052 .44871 Mtetra
.08052 .44871 .0835 .45127 .08747 .44989 .0845 .44732 Mtetra
.0845 .44732 .08747 .44989 .09145 .4485 .08848 .44593 Mtetra
.08848 .44593 .09145 .4485 .09543 .44711 .09246 .44453 Mtetra
.09246 .44453 .09543 .44711 .09942 .44571 .09645 .44314 Mtetra
.09645 .44314 .09942 .44571 .10341 .44432 .10045 .44174 Mtetra
.10045 .44174 .10341 .44432 .10742 .44292 .10446 .44034 Mtetra
.10446 .44034 .10742 .44292 .10448 .4963 .10847 .43893 Mtetra
.527 .313 .532 r
.10847 .43893 .10448 .4963 .10856 .49492 .11249 .43753 Mtetra
0 0 .127 r
.11249 .43753 .10856 .49492 .11264 .49354 .10964 .49098 Mtetra
.648 .76 .931 r
.10964 .49098 .11264 .49354 .11673 .49215 .11373 .48959 Mtetra
.11373 .48959 .11673 .49215 .12083 .49076 .11783 .4882 Mtetra
.11783 .4882 .12083 .49076 .12493 .48937 .12193 .4868 Mtetra
.12193 .4868 .12493 .48937 .12904 .48798 .12605 .48541 Mtetra
.12605 .48541 .12904 .48798 .13315 .48659 .13017 .48401 Mtetra
.13017 .48401 .13315 .48659 .13728 .48519 .13429 .4826 Mtetra
.13429 .4826 .13728 .48519 .14141 .48379 .13842 .4812 Mtetra
.13842 .4812 .14141 .48379 .14554 .48239 .14256 .4798 Mtetra
.14256 .4798 .14554 .48239 .14968 .48099 .14671 .47839 Mtetra
.14671 .47839 .14968 .48099 .15383 .47958 .15086 .47698 Mtetra
.15086 .47698 .15383 .47958 .15799 .47817 .15502 .47556 Mtetra
.15502 .47556 .15799 .47817 .16215 .47676 .15919 .47415 Mtetra
.15919 .47415 .16215 .47676 .16632 .47535 .16336 .47273 Mtetra
.16336 .47273 .16632 .47535 .1705 .47393 .16754 .47131 Mtetra
.932 .726 .601 r
.16754 .47131 .1705 .47393 .17468 .47251 .17412 .4476 Mtetra
.547 .359 .578 r
.17412 .4476 .17468 .47251 .18121 .44881 .17828 .44617 Mtetra
.65 .758 .928 r
.17828 .44617 .18121 .44881 .18538 .44738 .18246 .44473 Mtetra
.18246 .44473 .18538 .44738 .18955 .44595 .18664 .4433 Mtetra
.18664 .4433 .18955 .44595 .19374 .44451 .19083 .44186 Mtetra
.19083 .44186 .19374 .44451 .19793 .44308 .19502 .44042 Mtetra
.19502 .44042 .19793 .44308 .20213 .44164 .19922 .43897 Mtetra
.19922 .43897 .20213 .44164 .20633 .44019 .20343 .43753 Mtetra
.20343 .43753 .20633 .44019 .21054 .43875 .20764 .43608 Mtetra
.20764 .43608 .21054 .43875 .21476 .4373 .21186 .43463 Mtetra
.21186 .43463 .21476 .4373 .21898 .43585 .21609 .43317 Mtetra
.21609 .43317 .21898 .43585 .22321 .4344 .22033 .43172 Mtetra
.22033 .43172 .22321 .4344 .22745 .43295 .22457 .43026 Mtetra
.22457 .43026 .22745 .43295 .23758 .36614 .22882 .4288 Mtetra
0 0 .041 r
.22882 .4288 .23758 .36614 .24175 .36466 .23895 .36192 Mtetra
.655 .752 .921 r
.23895 .36192 .24175 .36466 .24593 .36317 .24313 .36043 Mtetra
.24313 .36043 .24593 .36317 .25012 .36169 .24732 .35894 Mtetra
.24732 .35894 .25012 .36169 .25431 .3602 .25151 .35744 Mtetra
.25151 .35744 .25431 .3602 .25851 .35871 .25572 .35595 Mtetra
.25572 .35595 .25851 .35871 .26271 .35721 .25992 .35445 Mtetra
.25992 .35445 .26271 .35721 .26692 .35572 .26414 .35295 Mtetra
.26414 .35295 .26692 .35572 .27114 .35422 .26836 .35145 Mtetra
.26836 .35145 .27114 .35422 .27537 .35272 .27259 .34994 Mtetra
.27259 .34994 .27537 .35272 .2796 .35122 .27683 .34843 Mtetra
.27683 .34843 .2796 .35122 .28384 .34971 .28107 .34692 Mtetra
.28107 .34692 .28384 .34971 .28808 .3482 .28532 .34541 Mtetra
.28532 .34541 .28808 .3482 .29233 .34669 .28958 .3439 Mtetra
.28958 .3439 .29233 .34669 .29659 .34518 .29384 .34238 Mtetra
.29384 .34238 .29659 .34518 .30086 .34366 .29811 .34086 Mtetra
.29811 .34086 .30086 .34366 .30513 .34214 .30239 .33934 Mtetra
.30239 .33934 .30513 .34214 .30941 .34062 .30667 .33781 Mtetra
.30667 .33781 .30941 .34062 .3137 .3391 .31096 .33628 Mtetra
.31096 .33628 .3137 .3391 .31799 .33758 .31526 .33475 Mtetra
.31526 .33475 .31799 .33758 .32229 .33605 .31956 .33322 Mtetra
.962 .665 .422 r
.31956 .33322 .32229 .33605 .3325 .24066 .31968 .39756 Mtetra
.504 .263 .483 r
.31968 .39756 .3325 .24066 .33669 .2391 .32408 .39605 Mtetra
.32408 .39605 .33669 .2391 .33128 .39733 .3285 .39453 Mtetra
.65 .758 .928 r
.3285 .39453 .33128 .39733 .33569 .39581 .33292 .39301 Mtetra
.33292 .39301 .33569 .39581 .34012 .3943 .33735 .39149 Mtetra
.33735 .39149 .34012 .3943 .34455 .39278 .34178 .38996 Mtetra
.34178 .38996 .34455 .39278 .34899 .39125 .34623 .38844 Mtetra
.34623 .38844 .34899 .39125 .35343 .38973 .35068 .38691 Mtetra
.35068 .38691 .35343 .38973 .35788 .3882 .35513 .38537 Mtetra
.35513 .38537 .35788 .3882 .36235 .38667 .3596 .38384 Mtetra
.3596 .38384 .36235 .38667 .36681 .38514 .36407 .3823 Mtetra
.36407 .3823 .36681 .38514 .37129 .3836 .36855 .38076 Mtetra
.36855 .38076 .37129 .3836 .37577 .38206 .37304 .37922 Mtetra
.37304 .37922 .37577 .38206 .38026 .38052 .37753 .37767 Mtetra
.37753 .37767 .38026 .38052 .38476 .37898 .38204 .37612 Mtetra
.38204 .37612 .38476 .37898 .38927 .37743 .38655 .37457 Mtetra
.38655 .37457 .38927 .37743 .39378 .37589 .39106 .37302 Mtetra
.39106 .37302 .39378 .37589 .40446 .21887 .39559 .37146 Mtetra
.504 .263 .482 r
.39559 .37146 .40446 .21887 .40877 .21727 .40012 .36991 Mtetra
.40012 .36991 .40877 .21727 .41309 .21567 .40466 .36835 Mtetra
.40466 .36835 .41309 .21567 .41742 .21406 .40921 .36678 Mtetra
.40921 .36678 .41742 .21406 .41646 .3681 .41377 .36522 Mtetra
.65 .758 .928 r
.41377 .36522 .41646 .3681 .42102 .36654 .41833 .36365 Mtetra
.41833 .36365 .42102 .36654 .42559 .36497 .4229 .36207 Mtetra
.4229 .36207 .42559 .36497 .43016 .3634 .42748 .3605 Mtetra
.42748 .3605 .43016 .3634 .43474 .36183 .43207 .35892 Mtetra
.43207 .35892 .43474 .36183 .43933 .36026 .43667 .35734 Mtetra
.43667 .35734 .43933 .36026 .44393 .35868 .44127 .35576 Mtetra
.44127 .35576 .44393 .35868 .44854 .3571 .44588 .35418 Mtetra
.44588 .35418 .44854 .3571 .45315 .35552 .4505 .35259 Mtetra
.4505 .35259 .45315 .35552 .45777 .35393 .45513 .351 Mtetra
.45513 .351 .45777 .35393 .4624 .35234 .45976 .3494 Mtetra
.45976 .3494 .4624 .35234 .46704 .35075 .4644 .34781 Mtetra
.4644 .34781 .46704 .35075 .47168 .34916 .46905 .34621 Mtetra
.46905 .34621 .47168 .34916 .47634 .34756 .47371 .34461 Mtetra
.47371 .34461 .47634 .34756 .481 .34596 .47838 .343 Mtetra
.47838 .343 .481 .34596 .48567 .34436 .48305 .3414 Mtetra
.48305 .3414 .48567 .34436 .49034 .34276 .48773 .33979 Mtetra
.48773 .33979 .49034 .34276 .49503 .34115 .49242 .33818 Mtetra
.49242 .33818 .49503 .34115 .49972 .33954 .49712 .33656 Mtetra
.49712 .33656 .49972 .33954 .50442 .33793 .50183 .33494 Mtetra
.50183 .33494 .50442 .33793 .50913 .33631 .50654 .33332 Mtetra
.50654 .33332 .50913 .33631 .51385 .33469 .51126 .3317 Mtetra
.51126 .3317 .51385 .33469 .51857 .33307 .51599 .33007 Mtetra
.51599 .33007 .51857 .33307 .52331 .33145 .52073 .32844 Mtetra
0 .126 .644 r
.52073 .32844 .52331 .33145 .52805 .33552 .52548 .33252 Mtetra
.649 .759 .929 r
.52548 .33252 .52805 .33552 .53281 .3339 .53025 .33088 Mtetra
.53025 .33088 .53281 .3339 .53758 .33226 .53502 .32925 Mtetra
.53502 .32925 .53758 .33226 .54235 .33063 .5398 .32761 Mtetra
.5398 .32761 .54235 .33063 .54714 .329 .54459 .32597 Mtetra
.54459 .32597 .54714 .329 .55193 .32736 .54938 .32432 Mtetra
.54938 .32432 .55193 .32736 .55673 .32572 .55419 .32268 Mtetra
.55419 .32268 .55673 .32572 .56154 .32407 .559 .32103 Mtetra
.559 .32103 .56154 .32407 .56635 .32242 .56383 .31937 Mtetra
.56383 .31937 .56635 .32242 .57118 .32077 .56866 .31772 Mtetra
.56866 .31772 .57118 .32077 .57601 .31912 .57349 .31606 Mtetra
.57349 .31606 .57601 .31912 .58085 .31746 .57834 .3144 Mtetra
.57834 .3144 .58085 .31746 .5857 .3158 .5832 .31273 Mtetra
.5832 .31273 .5857 .3158 .59056 .31414 .58806 .31107 Mtetra
.58806 .31107 .59056 .31414 .59543 .31248 .59294 .3094 Mtetra
.59294 .3094 .59543 .31248 .60031 .31081 .59782 .30772 Mtetra
.59782 .30772 .60031 .31081 .60519 .30914 .60271 .30605 Mtetra
.60271 .30605 .60519 .30914 .61008 .30747 .60761 .30437 Mtetra
.60761 .30437 .61008 .30747 .61499 .30579 .61251 .30269 Mtetra
.61251 .30269 .61499 .30579 .6199 .30411 .61743 .301 Mtetra
.61743 .301 .6199 .30411 .62481 .30243 .62235 .29931 Mtetra
.62235 .29931 .62481 .30243 .62974 .30074 .62729 .29762 Mtetra
.62729 .29762 .62974 .30074 .63468 .29905 .63223 .29593 Mtetra
.63223 .29593 .63468 .29905 .63962 .29736 .63718 .29423 Mtetra
.63718 .29423 .63962 .29736 .64458 .29567 .64214 .29253 Mtetra
.64214 .29253 .64458 .29567 .64954 .29397 .64711 .29083 Mtetra
.64711 .29083 .64954 .29397 .65451 .29227 .65208 .28912 Mtetra
.65208 .28912 .65451 .29227 .65949 .29057 .65707 .28742 Mtetra
.65707 .28742 .65949 .29057 .66448 .28886 .66206 .2857 Mtetra
.66206 .2857 .66448 .28886 .66947 .28715 .66707 .28399 Mtetra
.66707 .28399 .66947 .28715 .67448 .28544 .67208 .28227 Mtetra
.67208 .28227 .67448 .28544 .6795 .28373 .6771 .28055 Mtetra
.6771 .28055 .6795 .28373 .68452 .28201 .68213 .27883 Mtetra
.68213 .27883 .68452 .28201 .68955 .28029 .68717 .2771 Mtetra
.68717 .2771 .68955 .28029 .6946 .27856 .69222 .27537 Mtetra
.69222 .27537 .6946 .27856 .69965 .27683 .69728 .27364 Mtetra
.69728 .27364 .69965 .27683 .70471 .2751 .70234 .2719 Mtetra
.70234 .2719 .70471 .2751 .70978 .27337 .70742 .27016 Mtetra
.70742 .27016 .70978 .27337 .71485 .27163 .7125 .26842 Mtetra
.7125 .26842 .71485 .27163 .71994 .26989 .7176 .26667 Mtetra
.7176 .26667 .71994 .26989 .72504 .26815 .7227 .26492 Mtetra
.7227 .26492 .72504 .26815 .73014 .2664 .72781 .26317 Mtetra
.72781 .26317 .73014 .2664 .73526 .26465 .73293 .26142 Mtetra
.73293 .26142 .73526 .26465 .74038 .2629 .73806 .25966 Mtetra
.73806 .25966 .74038 .2629 .74551 .26115 .7432 .2579 Mtetra
.653 .755 .925 r
.06564 .45031 .06864 .45287 .07259 .45149 .0696 .44893 Mtetra
.0696 .44893 .07259 .45149 .07655 .4501 .07356 .44754 Mtetra
.07356 .44754 .07655 .4501 .08052 .44871 .07753 .44614 Mtetra
.07753 .44614 .08052 .44871 .0845 .44732 .08151 .44475 Mtetra
.08151 .44475 .0845 .44732 .08848 .44593 .08549 .44335 Mtetra
.08549 .44335 .08848 .44593 .09246 .44453 .08948 .44195 Mtetra
.08948 .44195 .09246 .44453 .09645 .44314 .09348 .44055 Mtetra
.09348 .44055 .09645 .44314 .10045 .44174 .09748 .43915 Mtetra
.09748 .43915 .10045 .44174 .10446 .44034 .10149 .43774 Mtetra
.10149 .43774 .10446 .44034 .10847 .43893 .1055 .43634 Mtetra
.1055 .43634 .10847 .43893 .11249 .43753 .10953 .43493 Mtetra
.10953 .43493 .11249 .43753 .10964 .49098 .11355 .43351 Mtetra
.527 .312 .532 r
.11355 .43351 .10964 .49098 .11373 .48959 .11759 .4321 Mtetra
0 0 .13 r
.11759 .4321 .11373 .48959 .11783 .4882 .11482 .48562 Mtetra
.648 .76 .931 r
.11482 .48562 .11783 .4882 .12193 .4868 .11893 .48422 Mtetra
.11893 .48422 .12193 .4868 .12605 .48541 .12304 .48282 Mtetra
.12304 .48282 .12605 .48541 .13017 .48401 .12717 .48142 Mtetra
.12717 .48142 .13017 .48401 .13429 .4826 .1313 .48001 Mtetra
.1313 .48001 .13429 .4826 .13842 .4812 .13543 .4786 Mtetra
.13543 .4786 .13842 .4812 .14256 .4798 .13958 .47719 Mtetra
.13958 .47719 .14256 .4798 .14671 .47839 .14373 .47578 Mtetra
.14373 .47578 .14671 .47839 .15086 .47698 .14788 .47437 Mtetra
.14788 .47437 .15086 .47698 .15502 .47556 .15204 .47295 Mtetra
.15204 .47295 .15502 .47556 .15919 .47415 .15622 .47153 Mtetra
.15622 .47153 .15919 .47415 .16336 .47273 .16039 .47011 Mtetra
.932 .725 .601 r
.16039 .47011 .16336 .47273 .16754 .47131 .16702 .44639 Mtetra
.547 .358 .577 r
.16702 .44639 .16754 .47131 .17412 .4476 .17118 .44496 Mtetra
.65 .758 .928 r
.17118 .44496 .17412 .4476 .17828 .44617 .17535 .44352 Mtetra
.17535 .44352 .17828 .44617 .18246 .44473 .17953 .44208 Mtetra
.17953 .44208 .18246 .44473 .18664 .4433 .18371 .44064 Mtetra
.18371 .44064 .18664 .4433 .19083 .44186 .1879 .43919 Mtetra
.1879 .43919 .19083 .44186 .19502 .44042 .1921 .43775 Mtetra
.1921 .43775 .19502 .44042 .19922 .43897 .19631 .4363 Mtetra
.19631 .4363 .19922 .43897 .20343 .43753 .20052 .43485 Mtetra
.20052 .43485 .20343 .43753 .20764 .43608 .20474 .4334 Mtetra
.20474 .4334 .20764 .43608 .21186 .43463 .20896 .43194 Mtetra
.20896 .43194 .21186 .43463 .21609 .43317 .21319 .43048 Mtetra
.21319 .43048 .21609 .43317 .22033 .43172 .21743 .42902 Mtetra
.21743 .42902 .22033 .43172 .22457 .43026 .22168 .42756 Mtetra
.22168 .42756 .22457 .43026 .22882 .4288 .22593 .42609 Mtetra
.22593 .42609 .22882 .4288 .23895 .36192 .23019 .42463 Mtetra
0 0 .041 r
.23019 .42463 .23895 .36192 .24313 .36043 .24032 .35767 Mtetra
.655 .752 .921 r
.24032 .35767 .24313 .36043 .24732 .35894 .24451 .35618 Mtetra
.24451 .35618 .24732 .35894 .25151 .35744 .24871 .35468 Mtetra
.24871 .35468 .25151 .35744 .25572 .35595 .25292 .35318 Mtetra
.25292 .35318 .25572 .35595 .25992 .35445 .25713 .35168 Mtetra
.25713 .35168 .25992 .35445 .26414 .35295 .26135 .35017 Mtetra
.26135 .35017 .26414 .35295 .26836 .35145 .26558 .34867 Mtetra
.26558 .34867 .26836 .35145 .27259 .34994 .26981 .34716 Mtetra
.26981 .34716 .27259 .34994 .27683 .34843 .27405 .34564 Mtetra
.27405 .34564 .27683 .34843 .28107 .34692 .27829 .34413 Mtetra
.27829 .34413 .28107 .34692 .28532 .34541 .28255 .34261 Mtetra
.28255 .34261 .28532 .34541 .28958 .3439 .28681 .34109 Mtetra
.28681 .34109 .28958 .3439 .29384 .34238 .29108 .33957 Mtetra
.29108 .33957 .29384 .34238 .29811 .34086 .29535 .33805 Mtetra
.29535 .33805 .29811 .34086 .30239 .33934 .29963 .33652 Mtetra
.29963 .33652 .30239 .33934 .30667 .33781 .30392 .33499 Mtetra
.30392 .33499 .30667 .33781 .31096 .33628 .30822 .33346 Mtetra
.30822 .33346 .31096 .33628 .31526 .33475 .31252 .33192 Mtetra
.31252 .33192 .31526 .33475 .31956 .33322 .31683 .33039 Mtetra
.962 .665 .422 r
.31683 .33039 .31956 .33322 .31968 .39756 .31688 .39476 Mtetra
.65 .758 .928 r
.31688 .39476 .31968 .39756 .32408 .39605 .32129 .39324 Mtetra
.32129 .39324 .32408 .39605 .3285 .39453 .32571 .39172 Mtetra
.32571 .39172 .3285 .39453 .33292 .39301 .33014 .3902 Mtetra
.33014 .3902 .33292 .39301 .33735 .39149 .33457 .38867 Mtetra
.33457 .38867 .33735 .39149 .34178 .38996 .33901 .38714 Mtetra
.33901 .38714 .34178 .38996 .34623 .38844 .34346 .38561 Mtetra
.34346 .38561 .34623 .38844 .35068 .38691 .34791 .38407 Mtetra
.34791 .38407 .35068 .38691 .35513 .38537 .35237 .38254 Mtetra
.35237 .38254 .35513 .38537 .3596 .38384 .35684 .381 Mtetra
.35684 .381 .3596 .38384 .36407 .3823 .36132 .37945 Mtetra
.36132 .37945 .36407 .3823 .36855 .38076 .3658 .37791 Mtetra
.3658 .37791 .36855 .38076 .37304 .37922 .3703 .37636 Mtetra
.3703 .37636 .37304 .37922 .37753 .37767 .3748 .37481 Mtetra
.3748 .37481 .37753 .37767 .38204 .37612 .3793 .37326 Mtetra
.3793 .37326 .38204 .37612 .38655 .37457 .38382 .3717 Mtetra
.38382 .3717 .38655 .37457 .39106 .37302 .38834 .37015 Mtetra
.38834 .37015 .39106 .37302 .39559 .37146 .39287 .36859 Mtetra
.39287 .36859 .39559 .37146 .40012 .36991 .39741 .36702 Mtetra
.39741 .36702 .40012 .36991 .40466 .36835 .40196 .36546 Mtetra
.40196 .36546 .40466 .36835 .40921 .36678 .40651 .36389 Mtetra
.40651 .36389 .40921 .36678 .41377 .36522 .41107 .36232 Mtetra
.41107 .36232 .41377 .36522 .41833 .36365 .41564 .36074 Mtetra
.41564 .36074 .41833 .36365 .4229 .36207 .42022 .35917 Mtetra
.42022 .35917 .4229 .36207 .42748 .3605 .4248 .35759 Mtetra
.4248 .35759 .42748 .3605 .43207 .35892 .42939 .356 Mtetra
.42939 .356 .43207 .35892 .43667 .35734 .43399 .35442 Mtetra
.43399 .35442 .43667 .35734 .44127 .35576 .4386 .35283 Mtetra
.4386 .35283 .44127 .35576 .44588 .35418 .44322 .35124 Mtetra
.44322 .35124 .44588 .35418 .4505 .35259 .44784 .34965 Mtetra
.44784 .34965 .4505 .35259 .45513 .351 .45247 .34805 Mtetra
.45247 .34805 .45513 .351 .45976 .3494 .45711 .34646 Mtetra
.45711 .34646 .45976 .3494 .4644 .34781 .46176 .34486 Mtetra
.46176 .34486 .4644 .34781 .46905 .34621 .46641 .34325 Mtetra
.46641 .34325 .46905 .34621 .47371 .34461 .47108 .34165 Mtetra
.47108 .34165 .47371 .34461 .47838 .343 .47575 .34004 Mtetra
.47575 .34004 .47838 .343 .48305 .3414 .48043 .33842 Mtetra
.48043 .33842 .48305 .3414 .48773 .33979 .48511 .33681 Mtetra
.48511 .33681 .48773 .33979 .49242 .33818 .48981 .33519 Mtetra
.48981 .33519 .49242 .33818 .49712 .33656 .49451 .33357 Mtetra
.49451 .33357 .49712 .33656 .50183 .33494 .49922 .33195 Mtetra
.49922 .33195 .50183 .33494 .50654 .33332 .50394 .33032 Mtetra
.50394 .33032 .50654 .33332 .51126 .3317 .50867 .32869 Mtetra
.50867 .32869 .51126 .3317 .51599 .33007 .51341 .32706 Mtetra
.51341 .32706 .51599 .33007 .52073 .32844 .51815 .32543 Mtetra
0 .126 .644 r
.51815 .32543 .52073 .32844 .52548 .33252 .5229 .3295 Mtetra
.649 .759 .929 r
.5229 .3295 .52548 .33252 .53025 .33088 .52767 .32786 Mtetra
.52767 .32786 .53025 .33088 .53502 .32925 .53245 .32622 Mtetra
.53245 .32622 .53502 .32925 .5398 .32761 .53723 .32458 Mtetra
.53723 .32458 .5398 .32761 .54459 .32597 .54203 .32293 Mtetra
.54203 .32293 .54459 .32597 .54938 .32432 .54683 .32128 Mtetra
.54683 .32128 .54938 .32432 .55419 .32268 .55164 .31963 Mtetra
.55164 .31963 .55419 .32268 .559 .32103 .55646 .31797 Mtetra
.55646 .31797 .559 .32103 .56383 .31937 .56129 .31632 Mtetra
.56129 .31632 .56383 .31937 .56866 .31772 .56612 .31465 Mtetra
.56612 .31465 .56866 .31772 .57349 .31606 .57097 .31299 Mtetra
.57097 .31299 .57349 .31606 .57834 .3144 .57582 .31132 Mtetra
.57582 .31132 .57834 .3144 .5832 .31273 .58068 .30965 Mtetra
.58068 .30965 .5832 .31273 .58806 .31107 .58555 .30798 Mtetra
.58555 .30798 .58806 .31107 .59294 .3094 .59043 .30631 Mtetra
.59043 .30631 .59294 .3094 .59782 .30772 .59532 .30463 Mtetra
.59532 .30463 .59782 .30772 .60271 .30605 .60021 .30295 Mtetra
.60021 .30295 .60271 .30605 .60761 .30437 .60512 .30126 Mtetra
.60512 .30126 .60761 .30437 .61251 .30269 .61003 .29957 Mtetra
.61003 .29957 .61251 .30269 .61743 .301 .61495 .29788 Mtetra
.61495 .29788 .61743 .301 .62235 .29931 .61988 .29619 Mtetra
.61988 .29619 .62235 .29931 .62729 .29762 .62482 .29449 Mtetra
.62482 .29449 .62729 .29762 .63223 .29593 .62977 .2928 Mtetra
.62977 .2928 .63223 .29593 .63718 .29423 .63473 .29109 Mtetra
.63473 .29109 .63718 .29423 .64214 .29253 .63969 .28939 Mtetra
.63969 .28939 .64214 .29253 .64711 .29083 .64467 .28768 Mtetra
.64467 .28768 .64711 .29083 .65208 .28912 .64965 .28597 Mtetra
.64965 .28597 .65208 .28912 .65707 .28742 .65464 .28425 Mtetra
.65464 .28425 .65707 .28742 .66206 .2857 .65964 .28254 Mtetra
.65964 .28254 .66206 .2857 .66707 .28399 .66465 .28082 Mtetra
.66465 .28082 .66707 .28399 .67208 .28227 .66967 .27909 Mtetra
.66967 .27909 .67208 .28227 .6771 .28055 .6747 .27737 Mtetra
.6747 .27737 .6771 .28055 .68213 .27883 .67973 .27564 Mtetra
.67973 .27564 .68213 .27883 .68717 .2771 .68478 .2739 Mtetra
.68478 .2739 .68717 .2771 .69222 .27537 .68983 .27217 Mtetra
.68983 .27217 .69222 .27537 .69728 .27364 .6949 .27043 Mtetra
.6949 .27043 .69728 .27364 .70234 .2719 .69997 .26869 Mtetra
.69997 .26869 .70234 .2719 .70742 .27016 .70505 .26694 Mtetra
.70505 .26694 .70742 .27016 .7125 .26842 .71014 .26519 Mtetra
.71014 .26519 .7125 .26842 .7176 .26667 .71524 .26344 Mtetra
.71524 .26344 .7176 .26667 .7227 .26492 .72035 .26169 Mtetra
.72035 .26169 .7227 .26492 .72781 .26317 .72547 .25993 Mtetra
.72547 .25993 .72781 .26317 .73293 .26142 .7306 .25817 Mtetra
.7306 .25817 .73293 .26142 .73806 .25966 .73573 .2564 Mtetra
.73573 .2564 .73806 .25966 .7432 .2579 .74088 .25464 Mtetra
.653 .755 .925 r
.06263 .44775 .06564 .45031 .0696 .44893 .06659 .44636 Mtetra
.06659 .44636 .0696 .44893 .07356 .44754 .07056 .44496 Mtetra
.07056 .44496 .07356 .44754 .07753 .44614 .07454 .44357 Mtetra
.07454 .44357 .07753 .44614 .08151 .44475 .07852 .44217 Mtetra
.07852 .44217 .08151 .44475 .08549 .44335 .0825 .44077 Mtetra
.0825 .44077 .08549 .44335 .08948 .44195 .0865 .43936 Mtetra
.0865 .43936 .08948 .44195 .09348 .44055 .0905 .43796 Mtetra
.0905 .43796 .09348 .44055 .09748 .43915 .0945 .43655 Mtetra
.0945 .43655 .09748 .43915 .10149 .43774 .09851 .43514 Mtetra
.09851 .43514 .10149 .43774 .1055 .43634 .10253 .43373 Mtetra
.10253 .43373 .1055 .43634 .10953 .43493 .10656 .43232 Mtetra
.10656 .43232 .10953 .43493 .11355 .43351 .11059 .4309 Mtetra
.11059 .4309 .11355 .43351 .11759 .4321 .11463 .42948 Mtetra
.11463 .42948 .11759 .4321 .11482 .48562 .11867 .42806 Mtetra
.526 .311 .531 r
.11867 .42806 .11482 .48562 .11893 .48422 .12272 .42664 Mtetra
.12272 .42664 .11893 .48422 .12304 .48282 .12678 .42521 Mtetra
0 0 .136 r
.12678 .42521 .12304 .48282 .12717 .48142 .12416 .47882 Mtetra
.648 .76 .931 r
.12416 .47882 .12717 .48142 .1313 .48001 .12829 .47741 Mtetra
.12829 .47741 .1313 .48001 .13543 .4786 .13243 .476 Mtetra
.13243 .476 .13543 .4786 .13958 .47719 .13658 .47459 Mtetra
.13658 .47459 .13958 .47719 .14373 .47578 .14073 .47317 Mtetra
.14073 .47317 .14373 .47578 .14788 .47437 .14489 .47175 Mtetra
.14489 .47175 .14788 .47437 .15204 .47295 .14906 .47033 Mtetra
.14906 .47033 .15204 .47295 .15622 .47153 .15323 .46891 Mtetra
.932 .725 .602 r
.15323 .46891 .15622 .47153 .16039 .47011 .15991 .44518 Mtetra
.546 .358 .577 r
.15991 .44518 .16039 .47011 .16702 .44639 .16407 .44374 Mtetra
.65 .758 .928 r
.16407 .44374 .16702 .44639 .17118 .44496 .16823 .4423 Mtetra
.16823 .4423 .17118 .44496 .17535 .44352 .17241 .44086 Mtetra
.17241 .44086 .17535 .44352 .17953 .44208 .17659 .43942 Mtetra
.17659 .43942 .17953 .44208 .18371 .44064 .18078 .43797 Mtetra
.18078 .43797 .18371 .44064 .1879 .43919 .18497 .43652 Mtetra
.18497 .43652 .1879 .43919 .1921 .43775 .18918 .43507 Mtetra
.18918 .43507 .1921 .43775 .19631 .4363 .19338 .43362 Mtetra
.19338 .43362 .19631 .4363 .20052 .43485 .1976 .43216 Mtetra
.1976 .43216 .20052 .43485 .20474 .4334 .20182 .43071 Mtetra
.20182 .43071 .20474 .4334 .20896 .43194 .20605 .42925 Mtetra
.20605 .42925 .20896 .43194 .21319 .43048 .21029 .42778 Mtetra
.21029 .42778 .21319 .43048 .21743 .42902 .21453 .42632 Mtetra
.21453 .42632 .21743 .42902 .22168 .42756 .21878 .42485 Mtetra
.21878 .42485 .22168 .42756 .22593 .42609 .22304 .42338 Mtetra
.22304 .42338 .22593 .42609 .23019 .42463 .2273 .42191 Mtetra
.2273 .42191 .23019 .42463 .24032 .35767 .23157 .42044 Mtetra
0 0 .041 r
.23157 .42044 .24032 .35767 .24451 .35618 .2417 .35341 Mtetra
.655 .752 .921 r
.2417 .35341 .24451 .35618 .24871 .35468 .2459 .35191 Mtetra
.2459 .35191 .24871 .35468 .25292 .35318 .25011 .3504 Mtetra
.25011 .3504 .25292 .35318 .25713 .35168 .25433 .3489 Mtetra
.25433 .3489 .25713 .35168 .26135 .35017 .25855 .34739 Mtetra
.25855 .34739 .26135 .35017 .26558 .34867 .26278 .34588 Mtetra
.26278 .34588 .26558 .34867 .26981 .34716 .26702 .34436 Mtetra
.26702 .34436 .26981 .34716 .27405 .34564 .27126 .34285 Mtetra
.27126 .34285 .27405 .34564 .27829 .34413 .27551 .34133 Mtetra
.27551 .34133 .27829 .34413 .28255 .34261 .27977 .3398 Mtetra
.27977 .3398 .28255 .34261 .28681 .34109 .28403 .33828 Mtetra
.28403 .33828 .28681 .34109 .29108 .33957 .28831 .33675 Mtetra
.28831 .33675 .29108 .33957 .29535 .33805 .29259 .33523 Mtetra
.29259 .33523 .29535 .33805 .29963 .33652 .29687 .33369 Mtetra
.29687 .33369 .29963 .33652 .30392 .33499 .30116 .33216 Mtetra
.30116 .33216 .30392 .33499 .30822 .33346 .30546 .33062 Mtetra
.30546 .33062 .30822 .33346 .31252 .33192 .30977 .32908 Mtetra
.961 .665 .424 r
.30977 .32908 .31252 .33192 .31683 .33039 .30967 .39348 Mtetra
.492 .24 .46 r
.30967 .39348 .31683 .33039 .31688 .39476 .31408 .39196 Mtetra
.65 .758 .928 r
.31408 .39196 .31688 .39476 .32129 .39324 .31849 .39043 Mtetra
.31849 .39043 .32129 .39324 .32571 .39172 .32291 .38891 Mtetra
.32291 .38891 .32571 .39172 .33014 .3902 .32734 .38738 Mtetra
.32734 .38738 .33014 .3902 .33457 .38867 .33178 .38584 Mtetra
.33178 .38584 .33457 .38867 .33901 .38714 .33623 .38431 Mtetra
.33623 .38431 .33901 .38714 .34346 .38561 .34068 .38277 Mtetra
.34068 .38277 .34346 .38561 .34791 .38407 .34514 .38123 Mtetra
.34514 .38123 .34791 .38407 .35237 .38254 .3496 .37969 Mtetra
.3496 .37969 .35237 .38254 .35684 .381 .35408 .37815 Mtetra
.35408 .37815 .35684 .381 .36132 .37945 .35856 .3766 Mtetra
.35856 .3766 .36132 .37945 .3658 .37791 .36305 .37505 Mtetra
.36305 .37505 .3658 .37791 .3703 .37636 .36755 .3735 Mtetra
.36755 .3735 .3703 .37636 .3748 .37481 .37205 .37194 Mtetra
.37205 .37194 .3748 .37481 .3793 .37326 .37656 .37039 Mtetra
.37656 .37039 .3793 .37326 .38382 .3717 .38108 .36883 Mtetra
.38108 .36883 .38382 .3717 .38834 .37015 .38561 .36726 Mtetra
.38561 .36726 .38834 .37015 .39287 .36859 .39015 .3657 Mtetra
.39015 .3657 .39287 .36859 .39741 .36702 .39469 .36413 Mtetra
.39469 .36413 .39741 .36702 .40196 .36546 .39924 .36256 Mtetra
.39924 .36256 .40196 .36546 .40651 .36389 .4038 .36099 Mtetra
.4038 .36099 .40651 .36389 .41107 .36232 .40836 .35941 Mtetra
.40836 .35941 .41107 .36232 .41564 .36074 .41294 .35783 Mtetra
.41294 .35783 .41564 .36074 .42022 .35917 .41752 .35625 Mtetra
.41752 .35625 .42022 .35917 .4248 .35759 .42211 .35466 Mtetra
.42211 .35466 .4248 .35759 .42939 .356 .4267 .35308 Mtetra
.4267 .35308 .42939 .356 .43399 .35442 .43131 .35149 Mtetra
.43131 .35149 .43399 .35442 .4386 .35283 .43592 .3499 Mtetra
.43592 .3499 .4386 .35283 .44322 .35124 .44054 .3483 Mtetra
.44054 .3483 .44322 .35124 .44784 .34965 .44517 .3467 Mtetra
.44517 .3467 .44784 .34965 .45247 .34805 .44981 .3451 Mtetra
.44981 .3451 .45247 .34805 .45711 .34646 .45445 .3435 Mtetra
.45445 .3435 .45711 .34646 .46176 .34486 .4591 .34189 Mtetra
.4591 .34189 .46176 .34486 .46641 .34325 .46377 .34028 Mtetra
.46377 .34028 .46641 .34325 .47108 .34165 .46843 .33867 Mtetra
.46843 .33867 .47108 .34165 .47575 .34004 .47311 .33706 Mtetra
.47311 .33706 .47575 .34004 .48043 .33842 .47779 .33544 Mtetra
.47779 .33544 .48043 .33842 .48511 .33681 .48249 .33382 Mtetra
.48249 .33382 .48511 .33681 .48981 .33519 .48719 .3322 Mtetra
.48719 .3322 .48981 .33519 .49451 .33357 .4919 .33057 Mtetra
.4919 .33057 .49451 .33357 .49922 .33195 .49661 .32895 Mtetra
.49661 .32895 .49922 .33195 .50394 .33032 .50134 .32731 Mtetra
.50134 .32731 .50394 .33032 .50867 .32869 .50607 .32568 Mtetra
.50607 .32568 .50867 .32869 .51341 .32706 .51081 .32404 Mtetra
.51081 .32404 .51341 .32706 .51815 .32543 .51556 .3224 Mtetra
0 .126 .644 r
.51556 .3224 .51815 .32543 .5229 .3295 .52031 .32647 Mtetra
.649 .759 .929 r
.52031 .32647 .5229 .3295 .52767 .32786 .52509 .32483 Mtetra
.52509 .32483 .52767 .32786 .53245 .32622 .52987 .32318 Mtetra
.52987 .32318 .53245 .32622 .53723 .32458 .53466 .32153 Mtetra
.53466 .32153 .53723 .32458 .54203 .32293 .53946 .31988 Mtetra
.53946 .31988 .54203 .32293 .54683 .32128 .54427 .31823 Mtetra
.54427 .31823 .54683 .32128 .55164 .31963 .54908 .31657 Mtetra
.54908 .31657 .55164 .31963 .55646 .31797 .55391 .31491 Mtetra
.55391 .31491 .55646 .31797 .56129 .31632 .55874 .31325 Mtetra
.55874 .31325 .56129 .31632 .56612 .31465 .56358 .31158 Mtetra
.56358 .31158 .56612 .31465 .57097 .31299 .56843 .30991 Mtetra
.56843 .30991 .57097 .31299 .57582 .31132 .57329 .30824 Mtetra
.57329 .30824 .57582 .31132 .58068 .30965 .57816 .30656 Mtetra
.57816 .30656 .58068 .30965 .58555 .30798 .58304 .30489 Mtetra
.58304 .30489 .58555 .30798 .59043 .30631 .58792 .3032 Mtetra
.58792 .3032 .59043 .30631 .59532 .30463 .59281 .30152 Mtetra
.59281 .30152 .59532 .30463 .60021 .30295 .59771 .29983 Mtetra
.59771 .29983 .60021 .30295 .60512 .30126 .60262 .29814 Mtetra
.60262 .29814 .60512 .30126 .61003 .29957 .60754 .29645 Mtetra
.60754 .29645 .61003 .29957 .61495 .29788 .61247 .29476 Mtetra
.61247 .29476 .61495 .29788 .61988 .29619 .61741 .29306 Mtetra
.61741 .29306 .61988 .29619 .62482 .29449 .62235 .29135 Mtetra
.62235 .29135 .62482 .29449 .62977 .2928 .62731 .28965 Mtetra
.62731 .28965 .62977 .2928 .63473 .29109 .63227 .28794 Mtetra
.63227 .28794 .63473 .29109 .63969 .28939 .63724 .28623 Mtetra
.63724 .28623 .63969 .28939 .64467 .28768 .64222 .28452 Mtetra
.64222 .28452 .64467 .28768 .64965 .28597 .64721 .2828 Mtetra
.64721 .2828 .64965 .28597 .65464 .28425 .65221 .28108 Mtetra
.65221 .28108 .65464 .28425 .65964 .28254 .65721 .27936 Mtetra
.65721 .27936 .65964 .28254 .66465 .28082 .66223 .27763 Mtetra
.66223 .27763 .66465 .28082 .66967 .27909 .66725 .2759 Mtetra
.66725 .2759 .66967 .27909 .6747 .27737 .67229 .27417 Mtetra
.67229 .27417 .6747 .27737 .67973 .27564 .67733 .27243 Mtetra
.67733 .27243 .67973 .27564 .68478 .2739 .68238 .2707 Mtetra
.68238 .2707 .68478 .2739 .68983 .27217 .68744 .26895 Mtetra
.68744 .26895 .68983 .27217 .6949 .27043 .69251 .26721 Mtetra
.69251 .26721 .6949 .27043 .69997 .26869 .69759 .26546 Mtetra
.69759 .26546 .69997 .26869 .70505 .26694 .70268 .26371 Mtetra
.70268 .26371 .70505 .26694 .71014 .26519 .70777 .26196 Mtetra
.70777 .26196 .71014 .26519 .71524 .26344 .71288 .2602 Mtetra
.71288 .2602 .71524 .26344 .72035 .26169 .718 .25844 Mtetra
.718 .25844 .72035 .26169 .72547 .25993 .72312 .25667 Mtetra
.72312 .25667 .72547 .25993 .7306 .25817 .72825 .25491 Mtetra
.72825 .25491 .7306 .25817 .73573 .2564 .7334 .25314 Mtetra
.7334 .25314 .73573 .2564 .74088 .25464 .73855 .25136 Mtetra
.653 .755 .925 r
.05962 .44518 .06263 .44775 .06659 .44636 .06358 .44378 Mtetra
.06358 .44378 .06659 .44636 .07056 .44496 .06755 .44238 Mtetra
.06755 .44238 .07056 .44496 .07454 .44357 .07153 .44098 Mtetra
.07153 .44098 .07454 .44357 .07852 .44217 .07551 .43958 Mtetra
.07551 .43958 .07852 .44217 .0825 .44077 .0795 .43818 Mtetra
.0795 .43818 .0825 .44077 .0865 .43936 .0835 .43677 Mtetra
.0835 .43677 .0865 .43936 .0905 .43796 .0875 .43536 Mtetra
.0875 .43536 .0905 .43796 .0945 .43655 .09151 .43395 Mtetra
.09151 .43395 .0945 .43655 .09851 .43514 .09553 .43253 Mtetra
.09553 .43253 .09851 .43514 .10253 .43373 .09955 .43112 Mtetra
.09955 .43112 .10253 .43373 .10656 .43232 .10358 .4297 Mtetra
.10358 .4297 .10656 .43232 .11059 .4309 .10761 .42828 Mtetra
.10761 .42828 .11059 .4309 .11463 .42948 .11165 .42686 Mtetra
.11165 .42686 .11463 .42948 .11867 .42806 .1157 .42543 Mtetra
.1157 .42543 .11867 .42806 .12272 .42664 .11976 .424 Mtetra
.11976 .424 .12272 .42664 .12678 .42521 .12382 .42257 Mtetra
.12382 .42257 .12678 .42521 .12416 .47882 .12788 .42114 Mtetra
.525 .31 .53 r
.12788 .42114 .12416 .47882 .12829 .47741 .13196 .41971 Mtetra
0 0 .139 r
.13196 .41971 .12829 .47741 .13243 .476 .12942 .47339 Mtetra
.648 .76 .931 r
.12942 .47339 .13243 .476 .13658 .47459 .13357 .47197 Mtetra
.13357 .47197 .13658 .47459 .14073 .47317 .13773 .47055 Mtetra
.13773 .47055 .14073 .47317 .14489 .47175 .1419 .46913 Mtetra
.1419 .46913 .14489 .47175 .14906 .47033 .14607 .4677 Mtetra
.931 .725 .602 r
.14607 .4677 .14906 .47033 .15323 .46891 .15279 .44396 Mtetra
.546 .357 .576 r
.15279 .44396 .15323 .46891 .15991 .44518 .15694 .44252 Mtetra
.65 .758 .928 r
.15694 .44252 .15991 .44518 .16407 .44374 .16111 .44108 Mtetra
.16111 .44108 .16407 .44374 .16823 .4423 .16528 .43964 Mtetra
.16528 .43964 .16823 .4423 .17241 .44086 .16946 .43819 Mtetra
.16946 .43819 .17241 .44086 .17659 .43942 .17364 .43675 Mtetra
.17364 .43675 .17659 .43942 .18078 .43797 .17784 .4353 Mtetra
.17784 .4353 .18078 .43797 .18497 .43652 .18203 .43384 Mtetra
.18203 .43384 .18497 .43652 .18918 .43507 .18624 .43239 Mtetra
.18624 .43239 .18918 .43507 .19338 .43362 .19045 .43093 Mtetra
.19045 .43093 .19338 .43362 .1976 .43216 .19467 .42947 Mtetra
.19467 .42947 .1976 .43216 .20182 .43071 .1989 .42801 Mtetra
.1989 .42801 .20182 .43071 .20605 .42925 .20313 .42654 Mtetra
.20313 .42654 .20605 .42925 .21029 .42778 .20737 .42508 Mtetra
.20737 .42508 .21029 .42778 .21453 .42632 .21162 .42361 Mtetra
.21162 .42361 .21453 .42632 .21878 .42485 .21587 .42214 Mtetra
.21587 .42214 .21878 .42485 .22304 .42338 .22014 .42066 Mtetra
.22014 .42066 .22304 .42338 .2273 .42191 .2244 .41919 Mtetra
.2244 .41919 .2273 .42191 .23157 .42044 .22868 .41771 Mtetra
.22868 .41771 .23157 .42044 .2417 .35341 .23296 .41623 Mtetra
0 0 .041 r
.23296 .41623 .2417 .35341 .2459 .35191 .24308 .34913 Mtetra
.655 .752 .921 r
.24308 .34913 .2459 .35191 .25011 .3504 .24729 .34762 Mtetra
.24729 .34762 .25011 .3504 .25433 .3489 .25151 .34611 Mtetra
.25151 .34611 .25433 .3489 .25855 .34739 .25574 .3446 Mtetra
.25574 .3446 .25855 .34739 .26278 .34588 .25998 .34308 Mtetra
.25998 .34308 .26278 .34588 .26702 .34436 .26422 .34156 Mtetra
.26422 .34156 .26702 .34436 .27126 .34285 .26847 .34004 Mtetra
.26847 .34004 .27126 .34285 .27551 .34133 .27272 .33852 Mtetra
.27272 .33852 .27551 .34133 .27977 .3398 .27698 .33699 Mtetra
.27698 .33699 .27977 .3398 .28403 .33828 .28125 .33546 Mtetra
.28125 .33546 .28403 .33828 .28831 .33675 .28553 .33393 Mtetra
.28553 .33393 .28831 .33675 .29259 .33523 .28981 .3324 Mtetra
.28981 .3324 .29259 .33523 .29687 .33369 .2941 .33086 Mtetra
.2941 .33086 .29687 .33369 .30116 .33216 .2984 .32932 Mtetra
.2984 .32932 .30116 .33216 .30546 .33062 .3027 .32778 Mtetra
.961 .665 .425 r
.3027 .32778 .30546 .33062 .30977 .32908 .30245 .39219 Mtetra
.492 .239 .459 r
.30245 .39219 .30977 .32908 .30967 .39348 .30685 .39067 Mtetra
.65 .758 .928 r
.30685 .39067 .30967 .39348 .31408 .39196 .31126 .38914 Mtetra
.31126 .38914 .31408 .39196 .31849 .39043 .31568 .38761 Mtetra
.31568 .38761 .31849 .39043 .32291 .38891 .32011 .38608 Mtetra
.32011 .38608 .32291 .38891 .32734 .38738 .32454 .38455 Mtetra
.32454 .38455 .32734 .38738 .33178 .38584 .32899 .38301 Mtetra
.32899 .38301 .33178 .38584 .33623 .38431 .33343 .38147 Mtetra
.33343 .38147 .33623 .38431 .34068 .38277 .33789 .37993 Mtetra
.33789 .37993 .34068 .38277 .34514 .38123 .34236 .37839 Mtetra
.34236 .37839 .34514 .38123 .3496 .37969 .34683 .37684 Mtetra
.34683 .37684 .3496 .37969 .35408 .37815 .35131 .37529 Mtetra
.35131 .37529 .35408 .37815 .35856 .3766 .35579 .37374 Mtetra
.35579 .37374 .35856 .3766 .36305 .37505 .36029 .37218 Mtetra
.36029 .37218 .36305 .37505 .36755 .3735 .36479 .37063 Mtetra
.36479 .37063 .36755 .3735 .37205 .37194 .3693 .36907 Mtetra
.3693 .36907 .37205 .37194 .37656 .37039 .37381 .3675 Mtetra
.37381 .3675 .37656 .37039 .38108 .36883 .37834 .36594 Mtetra
.37834 .36594 .38108 .36883 .38561 .36726 .38287 .36437 Mtetra
.38287 .36437 .38561 .36726 .39015 .3657 .38741 .3628 Mtetra
.38741 .3628 .39015 .3657 .39469 .36413 .39196 .36123 Mtetra
.39196 .36123 .39469 .36413 .39924 .36256 .39651 .35965 Mtetra
.39651 .35965 .39924 .36256 .4038 .36099 .40108 .35807 Mtetra
.40108 .35807 .4038 .36099 .40836 .35941 .40565 .35649 Mtetra
.40565 .35649 .40836 .35941 .41294 .35783 .41023 .35491 Mtetra
.41023 .35491 .41294 .35783 .41752 .35625 .41481 .35332 Mtetra
.41481 .35332 .41752 .35625 .42211 .35466 .41941 .35173 Mtetra
.41941 .35173 .42211 .35466 .4267 .35308 .42401 .35014 Mtetra
.42401 .35014 .4267 .35308 .43131 .35149 .42862 .34855 Mtetra
.42862 .34855 .43131 .35149 .43592 .3499 .43324 .34695 Mtetra
.43324 .34695 .43592 .3499 .44054 .3483 .43786 .34535 Mtetra
.43786 .34535 .44054 .3483 .44517 .3467 .4425 .34375 Mtetra
.4425 .34375 .44517 .3467 .44981 .3451 .44714 .34214 Mtetra
.44714 .34214 .44981 .3451 .45445 .3435 .45179 .34053 Mtetra
.45179 .34053 .45445 .3435 .4591 .34189 .45644 .33892 Mtetra
.45644 .33892 .4591 .34189 .46377 .34028 .46111 .33731 Mtetra
.46111 .33731 .46377 .34028 .46843 .33867 .46578 .33569 Mtetra
.46578 .33569 .46843 .33867 .47311 .33706 .47046 .33407 Mtetra
.47046 .33407 .47311 .33706 .47779 .33544 .47515 .33245 Mtetra
.47515 .33245 .47779 .33544 .48249 .33382 .47985 .33082 Mtetra
.47985 .33082 .48249 .33382 .48719 .3322 .48456 .3292 Mtetra
.48456 .3292 .48719 .3322 .4919 .33057 .48927 .32757 Mtetra
.48927 .32757 .4919 .33057 .49661 .32895 .49399 .32593 Mtetra
.49399 .32593 .49661 .32895 .50134 .32731 .49872 .3243 Mtetra
.49872 .3243 .50134 .32731 .50607 .32568 .50346 .32266 Mtetra
.50346 .32266 .50607 .32568 .51081 .32404 .50821 .32101 Mtetra
.50821 .32101 .51081 .32404 .51556 .3224 .51296 .31937 Mtetra
0 .126 .644 r
.51296 .31937 .51556 .3224 .52031 .32647 .51771 .32344 Mtetra
.649 .759 .929 r
.51771 .32344 .52031 .32647 .52509 .32483 .52249 .32179 Mtetra
.52249 .32179 .52509 .32483 .52987 .32318 .52728 .32014 Mtetra
.52728 .32014 .52987 .32318 .53466 .32153 .53208 .31848 Mtetra
.53208 .31848 .53466 .32153 .53946 .31988 .53688 .31683 Mtetra
.53688 .31683 .53946 .31988 .54427 .31823 .5417 .31517 Mtetra
.5417 .31517 .54427 .31823 .54908 .31657 .54652 .3135 Mtetra
.54652 .3135 .54908 .31657 .55391 .31491 .55135 .31184 Mtetra
.55135 .31184 .55391 .31491 .55874 .31325 .55619 .31017 Mtetra
.55619 .31017 .55874 .31325 .56358 .31158 .56104 .3085 Mtetra
.56104 .3085 .56358 .31158 .56843 .30991 .56589 .30682 Mtetra
.56589 .30682 .56843 .30991 .57329 .30824 .57076 .30514 Mtetra
.57076 .30514 .57329 .30824 .57816 .30656 .57563 .30346 Mtetra
.57563 .30346 .57816 .30656 .58304 .30489 .58051 .30178 Mtetra
.58051 .30178 .58304 .30489 .58792 .3032 .5854 .30009 Mtetra
.5854 .30009 .58792 .3032 .59281 .30152 .5903 .2984 Mtetra
.5903 .2984 .59281 .30152 .59771 .29983 .59521 .29671 Mtetra
.59521 .29671 .59771 .29983 .60262 .29814 .60012 .29502 Mtetra
.60012 .29502 .60262 .29814 .60754 .29645 .60505 .29332 Mtetra
.60505 .29332 .60754 .29645 .61247 .29476 .60998 .29162 Mtetra
.60998 .29162 .61247 .29476 .61741 .29306 .61492 .28991 Mtetra
.61492 .28991 .61741 .29306 .62235 .29135 .61987 .28821 Mtetra
.61987 .28821 .62235 .29135 .62731 .28965 .62483 .28649 Mtetra
.62483 .28649 .62731 .28965 .63227 .28794 .6298 .28478 Mtetra
.6298 .28478 .63227 .28794 .63724 .28623 .63478 .28306 Mtetra
.63478 .28306 .63724 .28623 .64222 .28452 .63976 .28134 Mtetra
.63976 .28134 .64222 .28452 .64721 .2828 .64476 .27962 Mtetra
.64476 .27962 .64721 .2828 .65221 .28108 .64976 .2779 Mtetra
.64976 .2779 .65221 .28108 .65721 .27936 .65478 .27617 Mtetra
.65478 .27617 .65721 .27936 .66223 .27763 .6598 .27444 Mtetra
.6598 .27444 .66223 .27763 .66725 .2759 .66483 .2727 Mtetra
.66483 .2727 .66725 .2759 .67229 .27417 .66987 .27096 Mtetra
.66987 .27096 .67229 .27417 .67733 .27243 .67492 .26922 Mtetra
.67492 .26922 .67733 .27243 .68238 .2707 .67997 .26748 Mtetra
.67997 .26748 .68238 .2707 .68744 .26895 .68504 .26573 Mtetra
.68504 .26573 .68744 .26895 .69251 .26721 .69012 .26398 Mtetra
.69012 .26398 .69251 .26721 .69759 .26546 .6952 .26223 Mtetra
.6952 .26223 .69759 .26546 .70268 .26371 .7003 .26047 Mtetra
.7003 .26047 .70268 .26371 .70777 .26196 .7054 .25871 Mtetra
.7054 .25871 .70777 .26196 .71288 .2602 .71051 .25695 Mtetra
.71051 .25695 .71288 .2602 .718 .25844 .71563 .25518 Mtetra
.71563 .25518 .718 .25844 .72312 .25667 .72076 .25341 Mtetra
.72076 .25341 .72312 .25667 .72825 .25491 .7259 .25164 Mtetra
.7259 .25164 .72825 .25491 .7334 .25314 .73105 .24986 Mtetra
.73105 .24986 .7334 .25314 .73855 .25136 .73621 .24808 Mtetra
.653 .755 .925 r
.05659 .4426 .05962 .44518 .06358 .44378 .06056 .4412 Mtetra
.06056 .4412 .06358 .44378 .06755 .44238 .06453 .4398 Mtetra
.06453 .4398 .06755 .44238 .07153 .44098 .06852 .43839 Mtetra
.06852 .43839 .07153 .44098 .07551 .43958 .0725 .43699 Mtetra
.0725 .43699 .07551 .43958 .0795 .43818 .0765 .43558 Mtetra
.0765 .43558 .0795 .43818 .0835 .43677 .0805 .43417 Mtetra
.0805 .43417 .0835 .43677 .0875 .43536 .0845 .43275 Mtetra
.0845 .43275 .0875 .43536 .09151 .43395 .08852 .43134 Mtetra
.08852 .43134 .09151 .43395 .09553 .43253 .09253 .42992 Mtetra
.09253 .42992 .09553 .43253 .09955 .43112 .09656 .4285 Mtetra
.09656 .4285 .09955 .43112 .10358 .4297 .10059 .42708 Mtetra
.10059 .42708 .10358 .4297 .10761 .42828 .10463 .42565 Mtetra
.10463 .42565 .10761 .42828 .11165 .42686 .10867 .42422 Mtetra
.10867 .42422 .11165 .42686 .1157 .42543 .11273 .42279 Mtetra
.11273 .42279 .1157 .42543 .11976 .424 .11678 .42136 Mtetra
.11678 .42136 .11976 .424 .12382 .42257 .12085 .41993 Mtetra
.12085 .41993 .12382 .42257 .12788 .42114 .12492 .41849 Mtetra
.12492 .41849 .12788 .42114 .13196 .41971 .12899 .41706 Mtetra
.12899 .41706 .13196 .41971 .12942 .47339 .13308 .41561 Mtetra
.525 .31 .53 r
.13308 .41561 .12942 .47339 .13357 .47197 .13717 .41417 Mtetra
.13717 .41417 .13357 .47197 .13773 .47055 .14127 .41273 Mtetra
0 0 .145 r
.14127 .41273 .13773 .47055 .1419 .46913 .13889 .46649 Mtetra
.931 .725 .603 r
.13889 .46649 .1419 .46913 .14607 .4677 .14566 .44274 Mtetra
.545 .356 .576 r
.14566 .44274 .14607 .4677 .15279 .44396 .14981 .4413 Mtetra
.65 .758 .928 r
.14981 .4413 .15279 .44396 .15694 .44252 .15397 .43986 Mtetra
.15397 .43986 .15694 .44252 .16111 .44108 .15814 .43842 Mtetra
.15814 .43842 .16111 .44108 .16528 .43964 .16232 .43697 Mtetra
.16232 .43697 .16528 .43964 .16946 .43819 .1665 .43552 Mtetra
.1665 .43552 .16946 .43819 .17364 .43675 .17069 .43407 Mtetra
.17069 .43407 .17364 .43675 .17784 .4353 .17488 .43261 Mtetra
.17488 .43261 .17784 .4353 .18203 .43384 .17909 .43116 Mtetra
.17909 .43116 .18203 .43384 .18624 .43239 .1833 .4297 Mtetra
.1833 .4297 .18624 .43239 .19045 .43093 .18751 .42823 Mtetra
.18751 .42823 .19045 .43093 .19467 .42947 .19174 .42677 Mtetra
.19174 .42677 .19467 .42947 .1989 .42801 .19597 .4253 Mtetra
.19597 .4253 .1989 .42801 .20313 .42654 .2002 .42384 Mtetra
.2002 .42384 .20313 .42654 .20737 .42508 .20445 .42236 Mtetra
.20445 .42236 .20737 .42508 .21162 .42361 .2087 .42089 Mtetra
.2087 .42089 .21162 .42361 .21587 .42214 .21296 .41941 Mtetra
.21296 .41941 .21587 .42214 .22014 .42066 .21722 .41794 Mtetra
.21722 .41794 .22014 .42066 .2244 .41919 .2215 .41645 Mtetra
.2215 .41645 .2244 .41919 .22868 .41771 .22578 .41497 Mtetra
.22578 .41497 .22868 .41771 .23296 .41623 .23006 .41349 Mtetra
.23006 .41349 .23296 .41623 .24308 .34913 .23435 .412 Mtetra
0 0 .041 r
.23435 .412 .24308 .34913 .24729 .34762 .24447 .34483 Mtetra
.655 .752 .921 r
.24447 .34483 .24729 .34762 .25151 .34611 .24869 .34331 Mtetra
.24869 .34331 .25151 .34611 .25574 .3446 .25293 .34179 Mtetra
.25293 .34179 .25574 .3446 .25998 .34308 .25716 .34027 Mtetra
.25716 .34027 .25998 .34308 .26422 .34156 .26141 .33875 Mtetra
.26141 .33875 .26422 .34156 .26847 .34004 .26566 .33722 Mtetra
.26566 .33722 .26847 .34004 .27272 .33852 .26992 .3357 Mtetra
.26992 .3357 .27272 .33852 .27698 .33699 .27419 .33417 Mtetra
.27419 .33417 .27698 .33699 .28125 .33546 .27846 .33263 Mtetra
.27846 .33263 .28125 .33546 .28553 .33393 .28274 .3311 Mtetra
.28274 .3311 .28553 .33393 .28981 .3324 .28703 .32956 Mtetra
.28703 .32956 .28981 .3324 .2941 .33086 .29132 .32802 Mtetra
.29132 .32802 .2941 .33086 .2984 .32932 .29562 .32647 Mtetra
.29562 .32647 .2984 .32932 .3027 .32778 .29993 .32493 Mtetra
.961 .665 .425 r
.29993 .32493 .3027 .32778 .30245 .39219 .29962 .38938 Mtetra
.65 .758 .928 r
.29962 .38938 .30245 .39219 .30685 .39067 .30403 .38785 Mtetra
.30403 .38785 .30685 .39067 .31126 .38914 .30844 .38632 Mtetra
.30844 .38632 .31126 .38914 .31568 .38761 .31287 .38478 Mtetra
.31287 .38478 .31568 .38761 .32011 .38608 .3173 .38325 Mtetra
.3173 .38325 .32011 .38608 .32454 .38455 .32174 .38171 Mtetra
.32174 .38171 .32454 .38455 .32899 .38301 .32618 .38017 Mtetra
.32618 .38017 .32899 .38301 .33343 .38147 .33064 .37862 Mtetra
.33064 .37862 .33343 .38147 .33789 .37993 .3351 .37708 Mtetra
.3351 .37708 .33789 .37993 .34236 .37839 .33956 .37553 Mtetra
.33956 .37553 .34236 .37839 .34683 .37684 .34404 .37398 Mtetra
.34404 .37398 .34683 .37684 .35131 .37529 .34852 .37242 Mtetra
.34852 .37242 .35131 .37529 .35579 .37374 .35302 .37087 Mtetra
.35302 .37087 .35579 .37374 .36029 .37218 .35751 .36931 Mtetra
.35751 .36931 .36029 .37218 .36479 .37063 .36202 .36774 Mtetra
.36202 .36774 .36479 .37063 .3693 .36907 .36653 .36618 Mtetra
.36653 .36618 .3693 .36907 .37381 .3675 .37106 .36461 Mtetra
.37106 .36461 .37381 .3675 .37834 .36594 .37559 .36304 Mtetra
.37559 .36304 .37834 .36594 .38287 .36437 .38012 .36147 Mtetra
.38012 .36147 .38287 .36437 .38741 .3628 .38467 .35989 Mtetra
.38467 .35989 .38741 .3628 .39196 .36123 .38922 .35832 Mtetra
.38922 .35832 .39196 .36123 .39651 .35965 .39378 .35674 Mtetra
.39378 .35674 .39651 .35965 .40108 .35807 .39835 .35515 Mtetra
.39835 .35515 .40108 .35807 .40565 .35649 .40292 .35357 Mtetra
.40292 .35357 .40565 .35649 .41023 .35491 .40751 .35198 Mtetra
.40751 .35198 .41023 .35491 .41481 .35332 .4121 .35039 Mtetra
.4121 .35039 .41481 .35332 .41941 .35173 .4167 .34879 Mtetra
.4167 .34879 .41941 .35173 .42401 .35014 .4213 .34719 Mtetra
.4213 .34719 .42401 .35014 .42862 .34855 .42592 .34559 Mtetra
.42592 .34559 .42862 .34855 .43324 .34695 .43054 .34399 Mtetra
.43054 .34399 .43324 .34695 .43786 .34535 .43517 .34239 Mtetra
.43517 .34239 .43786 .34535 .4425 .34375 .43981 .34078 Mtetra
.43981 .34078 .4425 .34375 .44714 .34214 .44446 .33917 Mtetra
.44446 .33917 .44714 .34214 .45179 .34053 .44911 .33756 Mtetra
.44911 .33756 .45179 .34053 .45644 .33892 .45377 .33594 Mtetra
.45377 .33594 .45644 .33892 .46111 .33731 .45845 .33432 Mtetra
.45845 .33432 .46111 .33731 .46578 .33569 .46312 .3327 Mtetra
.46312 .3327 .46578 .33569 .47046 .33407 .46781 .33107 Mtetra
.46781 .33107 .47046 .33407 .47515 .33245 .47251 .32945 Mtetra
.47251 .32945 .47515 .33245 .47985 .33082 .47721 .32782 Mtetra
.47721 .32782 .47985 .33082 .48456 .3292 .48192 .32618 Mtetra
.48192 .32618 .48456 .3292 .48927 .32757 .48664 .32455 Mtetra
.48664 .32455 .48927 .32757 .49399 .32593 .49137 .32291 Mtetra
.49137 .32291 .49399 .32593 .49872 .3243 .4961 .32127 Mtetra
.4961 .32127 .49872 .3243 .50346 .32266 .50084 .31962 Mtetra
.50084 .31962 .50346 .32266 .50821 .32101 .5056 .31798 Mtetra
.5056 .31798 .50821 .32101 .51296 .31937 .51036 .31633 Mtetra
0 .126 .644 r
.51036 .31633 .51296 .31937 .51771 .32344 .51511 .32039 Mtetra
.649 .759 .929 r
.51511 .32039 .51771 .32344 .52249 .32179 .51989 .31874 Mtetra
.51989 .31874 .52249 .32179 .52728 .32014 .52469 .31708 Mtetra
.52469 .31708 .52728 .32014 .53208 .31848 .52949 .31542 Mtetra
.52949 .31542 .53208 .31848 .53688 .31683 .5343 .31376 Mtetra
.5343 .31376 .53688 .31683 .5417 .31517 .53912 .31209 Mtetra
.53912 .31209 .5417 .31517 .54652 .3135 .54395 .31043 Mtetra
.54395 .31043 .54652 .3135 .55135 .31184 .54878 .30875 Mtetra
.54878 .30875 .55135 .31184 .55619 .31017 .55363 .30708 Mtetra
.55363 .30708 .55619 .31017 .56104 .3085 .55848 .3054 Mtetra
.55848 .3054 .56104 .3085 .56589 .30682 .56334 .30372 Mtetra
.56334 .30372 .56589 .30682 .57076 .30514 .56821 .30204 Mtetra
.56821 .30204 .57076 .30514 .57563 .30346 .57309 .30035 Mtetra
.57309 .30035 .57563 .30346 .58051 .30178 .57798 .29866 Mtetra
.57798 .29866 .58051 .30178 .5854 .30009 .58287 .29697 Mtetra
.58287 .29697 .5854 .30009 .5903 .2984 .58778 .29528 Mtetra
.58778 .29528 .5903 .2984 .59521 .29671 .59269 .29358 Mtetra
.59269 .29358 .59521 .29671 .60012 .29502 .59761 .29188 Mtetra
.59761 .29188 .60012 .29502 .60505 .29332 .60254 .29017 Mtetra
.60254 .29017 .60505 .29332 .60998 .29162 .60748 .28847 Mtetra
.60748 .28847 .60998 .29162 .61492 .28991 .61243 .28676 Mtetra
.61243 .28676 .61492 .28991 .61987 .28821 .61739 .28504 Mtetra
.61739 .28504 .61987 .28821 .62483 .28649 .62235 .28333 Mtetra
.62235 .28333 .62483 .28649 .6298 .28478 .62733 .28161 Mtetra
.62733 .28161 .6298 .28478 .63478 .28306 .63231 .27989 Mtetra
.63231 .27989 .63478 .28306 .63976 .28134 .6373 .27816 Mtetra
.6373 .27816 .63976 .28134 .64476 .27962 .6423 .27643 Mtetra
.6423 .27643 .64476 .27962 .64976 .2779 .64731 .2747 Mtetra
.64731 .2747 .64976 .2779 .65478 .27617 .65233 .27297 Mtetra
.65233 .27297 .65478 .27617 .6598 .27444 .65736 .27123 Mtetra
.65736 .27123 .6598 .27444 .66483 .2727 .6624 .26949 Mtetra
.6624 .26949 .66483 .2727 .66987 .27096 .66744 .26775 Mtetra
.66744 .26775 .66987 .27096 .67492 .26922 .6725 .266 Mtetra
.6725 .266 .67492 .26922 .67997 .26748 .67756 .26425 Mtetra
.67756 .26425 .67997 .26748 .68504 .26573 .68263 .2625 Mtetra
.68263 .2625 .68504 .26573 .69012 .26398 .68772 .26074 Mtetra
.68772 .26074 .69012 .26398 .6952 .26223 .69281 .25898 Mtetra
.69281 .25898 .6952 .26223 .7003 .26047 .69791 .25722 Mtetra
.69791 .25722 .7003 .26047 .7054 .25871 .70302 .25545 Mtetra
.70302 .25545 .7054 .25871 .71051 .25695 .70814 .25368 Mtetra
.70814 .25368 .71051 .25695 .71563 .25518 .71326 .25191 Mtetra
.71326 .25191 .71563 .25518 .72076 .25341 .7184 .25013 Mtetra
.7184 .25013 .72076 .25341 .7259 .25164 .72355 .24836 Mtetra
.72355 .24836 .7259 .25164 .73105 .24986 .7287 .24657 Mtetra
.7287 .24657 .73105 .24986 .73621 .24808 .73387 .24479 Mtetra
.653 .755 .925 r
.05356 .44001 .05659 .4426 .06056 .4412 .05753 .43861 Mtetra
.05753 .43861 .06056 .4412 .06453 .4398 .06151 .4372 Mtetra
.06151 .4372 .06453 .4398 .06852 .43839 .06549 .43579 Mtetra
.06549 .43579 .06852 .43839 .0725 .43699 .06948 .43438 Mtetra
.06948 .43438 .0725 .43699 .0765 .43558 .07348 .43297 Mtetra
.07348 .43297 .0765 .43558 .0805 .43417 .07748 .43155 Mtetra
.07748 .43155 .0805 .43417 .0845 .43275 .08149 .43014 Mtetra
.08149 .43014 .0845 .43275 .08852 .43134 .08551 .42872 Mtetra
.08551 .42872 .08852 .43134 .09253 .42992 .08953 .42729 Mtetra
.08953 .42729 .09253 .42992 .09656 .4285 .09356 .42587 Mtetra
.09356 .42587 .09656 .4285 .10059 .42708 .0976 .42444 Mtetra
.0976 .42444 .10059 .42708 .10463 .42565 .10164 .42301 Mtetra
.10164 .42301 .10463 .42565 .10867 .42422 .10569 .42158 Mtetra
.10569 .42158 .10867 .42422 .11273 .42279 .10974 .42015 Mtetra
.10974 .42015 .11273 .42279 .11678 .42136 .1138 .41871 Mtetra
.1138 .41871 .11678 .42136 .12085 .41993 .11787 .41728 Mtetra
.11787 .41728 .12085 .41993 .12492 .41849 .12194 .41584 Mtetra
.12194 .41584 .12492 .41849 .12899 .41706 .12602 .41439 Mtetra
.12602 .41439 .12899 .41706 .13308 .41561 .13011 .41295 Mtetra
.13011 .41295 .13308 .41561 .13717 .41417 .13421 .4115 Mtetra
.13421 .4115 .13717 .41417 .14127 .41273 .13831 .41005 Mtetra
.13831 .41005 .14127 .41273 .13889 .46649 .14241 .4086 Mtetra
.061 0 .387 r
.14241 .4086 .13889 .46649 .14566 .44274 .14267 .44008 Mtetra
.65 .758 .928 r
.14267 .44008 .14566 .44274 .14981 .4413 .14683 .43864 Mtetra
.14683 .43864 .14981 .4413 .15397 .43986 .15099 .43719 Mtetra
.15099 .43719 .15397 .43986 .15814 .43842 .15517 .43574 Mtetra
.15517 .43574 .15814 .43842 .16232 .43697 .15934 .43429 Mtetra
.15934 .43429 .16232 .43697 .1665 .43552 .16353 .43284 Mtetra
.16353 .43284 .1665 .43552 .17069 .43407 .16772 .43138 Mtetra
.16772 .43138 .17069 .43407 .17488 .43261 .17192 .42992 Mtetra
.17192 .42992 .17488 .43261 .17909 .43116 .17613 .42846 Mtetra
.17613 .42846 .17909 .43116 .1833 .4297 .18034 .427 Mtetra
.18034 .427 .1833 .4297 .18751 .42823 .18456 .42553 Mtetra
.18456 .42553 .18751 .42823 .19174 .42677 .18879 .42406 Mtetra
.18879 .42406 .19174 .42677 .19597 .4253 .19303 .42259 Mtetra
.19303 .42259 .19597 .4253 .2002 .42384 .19727 .42112 Mtetra
.19727 .42112 .2002 .42384 .20445 .42236 .20152 .41964 Mtetra
.20152 .41964 .20445 .42236 .2087 .42089 .20577 .41816 Mtetra
.20577 .41816 .2087 .42089 .21296 .41941 .21003 .41668 Mtetra
.21003 .41668 .21296 .41941 .21722 .41794 .2143 .4152 Mtetra
.2143 .4152 .21722 .41794 .2215 .41645 .21858 .41371 Mtetra
.21858 .41371 .2215 .41645 .22578 .41497 .22286 .41223 Mtetra
.22286 .41223 .22578 .41497 .23006 .41349 .22715 .41074 Mtetra
.22715 .41074 .23006 .41349 .23435 .412 .23145 .40924 Mtetra
.23145 .40924 .23435 .412 .24447 .34483 .23576 .40775 Mtetra
0 0 .041 r
.23576 .40775 .24447 .34483 .24869 .34331 .24587 .34051 Mtetra
.655 .752 .921 r
.24587 .34051 .24869 .34331 .25293 .34179 .2501 .33898 Mtetra
.2501 .33898 .25293 .34179 .25716 .34027 .25434 .33746 Mtetra
.25434 .33746 .25716 .34027 .26141 .33875 .25859 .33593 Mtetra
.25859 .33593 .26141 .33875 .26566 .33722 .26285 .3344 Mtetra
.26285 .3344 .26566 .33722 .26992 .3357 .26711 .33287 Mtetra
.26711 .33287 .26992 .3357 .27419 .33417 .27138 .33133 Mtetra
.27138 .33133 .27419 .33417 .27846 .33263 .27566 .32979 Mtetra
.27566 .32979 .27846 .33263 .28274 .3311 .27995 .32825 Mtetra
.27995 .32825 .28274 .3311 .28703 .32956 .28424 .32671 Mtetra
.28424 .32671 .28703 .32956 .29132 .32802 .28853 .32517 Mtetra
.28853 .32517 .29132 .32802 .29562 .32647 .29284 .32362 Mtetra
.961 .665 .427 r
.29284 .32362 .29562 .32647 .29993 .32493 .29237 .38808 Mtetra
.49 .237 .457 r
.29237 .38808 .29993 .32493 .29962 .38938 .29678 .38655 Mtetra
.65 .758 .928 r
.29678 .38655 .29962 .38938 .30403 .38785 .30119 .38502 Mtetra
.30119 .38502 .30403 .38785 .30844 .38632 .30561 .38348 Mtetra
.30561 .38348 .30844 .38632 .31287 .38478 .31004 .38195 Mtetra
.31004 .38195 .31287 .38478 .3173 .38325 .31448 .3804 Mtetra
.31448 .3804 .3173 .38325 .32174 .38171 .31892 .37886 Mtetra
.31892 .37886 .32174 .38171 .32618 .38017 .32337 .37732 Mtetra
.32337 .37732 .32618 .38017 .33064 .37862 .32783 .37577 Mtetra
.32783 .37577 .33064 .37862 .3351 .37708 .33229 .37422 Mtetra
.33229 .37422 .3351 .37708 .33956 .37553 .33677 .37266 Mtetra
.33677 .37266 .33956 .37553 .34404 .37398 .34125 .37111 Mtetra
.34125 .37111 .34404 .37398 .34852 .37242 .34573 .36955 Mtetra
.34573 .36955 .34852 .37242 .35302 .37087 .35023 .36798 Mtetra
.35023 .36798 .35302 .37087 .35751 .36931 .35473 .36642 Mtetra
.35473 .36642 .35751 .36931 .36202 .36774 .35924 .36485 Mtetra
.35924 .36485 .36202 .36774 .36653 .36618 .36376 .36328 Mtetra
.36376 .36328 .36653 .36618 .37106 .36461 .36829 .36171 Mtetra
.36829 .36171 .37106 .36461 .37559 .36304 .37282 .36014 Mtetra
.37282 .36014 .37559 .36304 .38012 .36147 .37737 .35856 Mtetra
.37737 .35856 .38012 .36147 .38467 .35989 .38191 .35698 Mtetra
.38191 .35698 .38467 .35989 .38922 .35832 .38647 .3554 Mtetra
.38647 .3554 .38922 .35832 .39378 .35674 .39104 .35381 Mtetra
.39104 .35381 .39378 .35674 .39835 .35515 .39561 .35222 Mtetra
.39561 .35222 .39835 .35515 .40292 .35357 .40019 .35063 Mtetra
.40019 .35063 .40292 .35357 .40751 .35198 .40478 .34904 Mtetra
.40478 .34904 .40751 .35198 .4121 .35039 .40937 .34744 Mtetra
.40937 .34744 .4121 .35039 .4167 .34879 .41398 .34584 Mtetra
.41398 .34584 .4167 .34879 .4213 .34719 .41859 .34424 Mtetra
.41859 .34424 .4213 .34719 .42592 .34559 .42321 .34263 Mtetra
.42321 .34263 .42592 .34559 .43054 .34399 .42784 .34103 Mtetra
.42784 .34103 .43054 .34399 .43517 .34239 .43247 .33942 Mtetra
.43247 .33942 .43517 .34239 .43981 .34078 .43712 .3378 Mtetra
.43712 .3378 .43981 .34078 .44446 .33917 .44177 .33619 Mtetra
.44177 .33619 .44446 .33917 .44911 .33756 .44643 .33457 Mtetra
.44643 .33457 .44911 .33756 .45377 .33594 .4511 .33295 Mtetra
.4511 .33295 .45377 .33594 .45845 .33432 .45577 .33132 Mtetra
.45577 .33132 .45845 .33432 .46312 .3327 .46046 .3297 Mtetra
.46046 .3297 .46312 .3327 .46781 .33107 .46515 .32807 Mtetra
.46515 .32807 .46781 .33107 .47251 .32945 .46985 .32643 Mtetra
.46985 .32643 .47251 .32945 .47721 .32782 .47456 .3248 Mtetra
.47456 .3248 .47721 .32782 .48192 .32618 .47927 .32316 Mtetra
.47927 .32316 .48192 .32618 .48664 .32455 .484 .32152 Mtetra
.484 .32152 .48664 .32455 .49137 .32291 .48873 .31988 Mtetra
.48873 .31988 .49137 .32291 .4961 .32127 .49347 .31823 Mtetra
.49347 .31823 .4961 .32127 .50084 .31962 .49822 .31658 Mtetra
.49822 .31658 .50084 .31962 .5056 .31798 .50298 .31493 Mtetra
.50298 .31493 .5056 .31798 .51036 .31633 .50774 .31327 Mtetra
0 .126 .644 r
.50774 .31327 .51036 .31633 .51511 .32039 .51249 .31734 Mtetra
.649 .759 .929 r
.51249 .31734 .51511 .32039 .51989 .31874 .51728 .31568 Mtetra
.51728 .31568 .51989 .31874 .52469 .31708 .52208 .31401 Mtetra
.52208 .31401 .52469 .31708 .52949 .31542 .52689 .31235 Mtetra
.52689 .31235 .52949 .31542 .5343 .31376 .53171 .31068 Mtetra
.53171 .31068 .5343 .31376 .53912 .31209 .53653 .30901 Mtetra
.53653 .30901 .53912 .31209 .54395 .31043 .54136 .30734 Mtetra
.54136 .30734 .54395 .31043 .54878 .30875 .54621 .30566 Mtetra
.54621 .30566 .54878 .30875 .55363 .30708 .55106 .30398 Mtetra
.55106 .30398 .55363 .30708 .55848 .3054 .55591 .3023 Mtetra
.55591 .3023 .55848 .3054 .56334 .30372 .56078 .30061 Mtetra
.56078 .30061 .56334 .30372 .56821 .30204 .56566 .29892 Mtetra
.56566 .29892 .56821 .30204 .57309 .30035 .57054 .29723 Mtetra
.57054 .29723 .57309 .30035 .57798 .29866 .57543 .29554 Mtetra
.57543 .29554 .57798 .29866 .58287 .29697 .58034 .29384 Mtetra
.58034 .29384 .58287 .29697 .58778 .29528 .58525 .29214 Mtetra
.58525 .29214 .58778 .29528 .59269 .29358 .59017 .29044 Mtetra
.59017 .29044 .59269 .29358 .59761 .29188 .59509 .28873 Mtetra
.59509 .28873 .59761 .29188 .60254 .29017 .60003 .28702 Mtetra
.60003 .28702 .60254 .29017 .60748 .28847 .60497 .28531 Mtetra
.60497 .28531 .60748 .28847 .61243 .28676 .60993 .28359 Mtetra
.60993 .28359 .61243 .28676 .61739 .28504 .61489 .28187 Mtetra
.61489 .28187 .61739 .28504 .62235 .28333 .61986 .28015 Mtetra
.61986 .28015 .62235 .28333 .62733 .28161 .62484 .27843 Mtetra
.62484 .27843 .62733 .28161 .63231 .27989 .62983 .2767 Mtetra
.62983 .2767 .63231 .27989 .6373 .27816 .63483 .27497 Mtetra
.63483 .27497 .6373 .27816 .6423 .27643 .63984 .27324 Mtetra
.63984 .27324 .6423 .27643 .64731 .2747 .64485 .2715 Mtetra
.64485 .2715 .64731 .2747 .65233 .27297 .64988 .26976 Mtetra
.64988 .26976 .65233 .27297 .65736 .27123 .65491 .26801 Mtetra
.65491 .26801 .65736 .27123 .6624 .26949 .65995 .26627 Mtetra
.65995 .26627 .6624 .26949 .66744 .26775 .66501 .26452 Mtetra
.66501 .26452 .66744 .26775 .6725 .266 .67007 .26277 Mtetra
.67007 .26277 .6725 .266 .67756 .26425 .67514 .26101 Mtetra
.67514 .26101 .67756 .26425 .68263 .2625 .68022 .25925 Mtetra
.68022 .25925 .68263 .2625 .68772 .26074 .68531 .25749 Mtetra
.68531 .25749 .68772 .26074 .69281 .25898 .6904 .25572 Mtetra
.6904 .25572 .69281 .25898 .69791 .25722 .69551 .25395 Mtetra
.69551 .25395 .69791 .25722 .70302 .25545 .70063 .25218 Mtetra
.70063 .25218 .70302 .25545 .70814 .25368 .70575 .25041 Mtetra
.70575 .25041 .70814 .25368 .71326 .25191 .71089 .24863 Mtetra
.71089 .24863 .71326 .25191 .7184 .25013 .71603 .24685 Mtetra
.71603 .24685 .7184 .25013 .72355 .24836 .72118 .24506 Mtetra
.72118 .24506 .72355 .24836 .7287 .24657 .72634 .24328 Mtetra
.72634 .24328 .7287 .24657 .73387 .24479 .73152 .24149 Mtetra
.653 .755 .925 r
.05052 .43742 .05356 .44001 .05753 .43861 .05449 .43601 Mtetra
.05449 .43601 .05753 .43861 .06151 .4372 .05847 .4346 Mtetra
.05847 .4346 .06151 .4372 .06549 .43579 .06246 .43319 Mtetra
.06246 .43319 .06549 .43579 .06948 .43438 .06645 .43177 Mtetra
.06645 .43177 .06948 .43438 .07348 .43297 .07046 .43035 Mtetra
.07046 .43035 .07348 .43297 .07748 .43155 .07446 .42894 Mtetra
.07446 .42894 .07748 .43155 .08149 .43014 .07848 .42751 Mtetra
.07848 .42751 .08149 .43014 .08551 .42872 .08249 .42609 Mtetra
.08249 .42609 .08551 .42872 .08953 .42729 .08652 .42466 Mtetra
.08652 .42466 .08953 .42729 .09356 .42587 .09055 .42323 Mtetra
.09055 .42323 .09356 .42587 .0976 .42444 .09459 .4218 Mtetra
.09459 .4218 .0976 .42444 .10164 .42301 .09864 .42037 Mtetra
.09864 .42037 .10164 .42301 .10569 .42158 .10269 .41894 Mtetra
.10269 .41894 .10569 .42158 .10974 .42015 .10675 .4175 Mtetra
.10675 .4175 .10974 .42015 .1138 .41871 .11081 .41606 Mtetra
.11081 .41606 .1138 .41871 .11787 .41728 .11488 .41462 Mtetra
.11488 .41462 .11787 .41728 .12194 .41584 .11896 .41317 Mtetra
.11896 .41317 .12194 .41584 .12602 .41439 .12305 .41172 Mtetra
.12305 .41172 .12602 .41439 .13011 .41295 .12714 .41028 Mtetra
.12714 .41028 .13011 .41295 .13421 .4115 .13123 .40882 Mtetra
.13123 .40882 .13421 .4115 .13831 .41005 .13534 .40737 Mtetra
.13534 .40737 .13831 .41005 .14241 .4086 .13945 .40591 Mtetra
.949 .647 .428 r
.13945 .40591 .14241 .4086 .14267 .44008 .13967 .43741 Mtetra
.65 .758 .928 r
.13967 .43741 .14267 .44008 .14683 .43864 .14383 .43597 Mtetra
.14383 .43597 .14683 .43864 .15099 .43719 .148 .43451 Mtetra
.148 .43451 .15099 .43719 .15517 .43574 .15218 .43306 Mtetra
.15218 .43306 .15517 .43574 .15934 .43429 .15636 .4316 Mtetra
.15636 .4316 .15934 .43429 .16353 .43284 .16055 .43015 Mtetra
.16055 .43015 .16353 .43284 .16772 .43138 .16475 .42868 Mtetra
.16475 .42868 .16772 .43138 .17192 .42992 .16895 .42722 Mtetra
.16895 .42722 .17192 .42992 .17613 .42846 .17316 .42576 Mtetra
.17316 .42576 .17613 .42846 .18034 .427 .17738 .42429 Mtetra
.17738 .42429 .18034 .427 .18456 .42553 .18161 .42282 Mtetra
.18161 .42282 .18456 .42553 .18879 .42406 .18584 .42134 Mtetra
.18584 .42134 .18879 .42406 .19303 .42259 .19008 .41987 Mtetra
.19008 .41987 .19303 .42259 .19727 .42112 .19432 .41839 Mtetra
.19432 .41839 .19727 .42112 .20152 .41964 .19857 .41691 Mtetra
.19857 .41691 .20152 .41964 .20577 .41816 .20283 .41543 Mtetra
.20283 .41543 .20577 .41816 .21003 .41668 .2071 .41394 Mtetra
.2071 .41394 .21003 .41668 .2143 .4152 .21137 .41246 Mtetra
.21137 .41246 .2143 .4152 .21858 .41371 .21565 .41097 Mtetra
.21565 .41097 .21858 .41371 .22286 .41223 .21994 .40947 Mtetra
.21994 .40947 .22286 .41223 .22715 .41074 .22424 .40798 Mtetra
.22424 .40798 .22715 .41074 .23145 .40924 .22854 .40648 Mtetra
.22854 .40648 .23145 .40924 .23576 .40775 .23285 .40498 Mtetra
.23285 .40498 .23576 .40775 .24587 .34051 .23716 .40348 Mtetra
0 0 .041 r
.23716 .40348 .24587 .34051 .2501 .33898 .24727 .33617 Mtetra
.655 .752 .921 r
.24727 .33617 .2501 .33898 .25434 .33746 .25152 .33464 Mtetra
.25152 .33464 .25434 .33746 .25859 .33593 .25577 .3331 Mtetra
.25577 .3331 .25859 .33593 .26285 .3344 .26003 .33157 Mtetra
.26003 .33157 .26285 .3344 .26711 .33287 .2643 .33003 Mtetra
.2643 .33003 .26711 .33287 .27138 .33133 .26857 .32849 Mtetra
.26857 .32849 .27138 .33133 .27566 .32979 .27285 .32695 Mtetra
.27285 .32695 .27566 .32979 .27995 .32825 .27714 .3254 Mtetra
.27714 .3254 .27995 .32825 .28424 .32671 .28144 .32386 Mtetra
.28144 .32386 .28424 .32671 .28853 .32517 .28574 .32231 Mtetra
.28574 .32231 .28853 .32517 .29284 .32362 .29005 .32075 Mtetra
.961 .665 .427 r
.29005 .32075 .29284 .32362 .29237 .38808 .28952 .38525 Mtetra
.65 .758 .928 r
.28952 .38525 .29237 .38808 .29678 .38655 .29393 .38372 Mtetra
.29393 .38372 .29678 .38655 .30119 .38502 .29835 .38218 Mtetra
.29835 .38218 .30119 .38502 .30561 .38348 .30277 .38064 Mtetra
.30277 .38064 .30561 .38348 .31004 .38195 .3072 .3791 Mtetra
.3072 .3791 .31004 .38195 .31448 .3804 .31164 .37755 Mtetra
.31164 .37755 .31448 .3804 .31892 .37886 .31609 .37601 Mtetra
.31609 .37601 .31892 .37886 .32337 .37732 .32055 .37445 Mtetra
.32055 .37445 .32337 .37732 .32783 .37577 .32501 .3729 Mtetra
.32501 .3729 .32783 .37577 .33229 .37422 .32948 .37134 Mtetra
.32948 .37134 .33229 .37422 .33677 .37266 .33396 .36979 Mtetra
.33396 .36979 .33677 .37266 .34125 .37111 .33844 .36823 Mtetra
.33844 .36823 .34125 .37111 .34573 .36955 .34294 .36666 Mtetra
.34294 .36666 .34573 .36955 .35023 .36798 .34744 .36509 Mtetra
.34744 .36509 .35023 .36798 .35473 .36642 .35194 .36353 Mtetra
.35194 .36353 .35473 .36642 .35924 .36485 .35646 .36195 Mtetra
.35646 .36195 .35924 .36485 .36376 .36328 .36098 .36038 Mtetra
.36098 .36038 .36376 .36328 .36829 .36171 .36551 .3588 Mtetra
.36551 .3588 .36829 .36171 .37282 .36014 .37005 .35722 Mtetra
.37005 .35722 .37282 .36014 .37737 .35856 .3746 .35564 Mtetra
.3746 .35564 .37737 .35856 .38191 .35698 .37915 .35405 Mtetra
.37915 .35405 .38191 .35698 .38647 .3554 .38372 .35247 Mtetra
.38372 .35247 .38647 .3554 .39104 .35381 .38829 .35088 Mtetra
.38829 .35088 .39104 .35381 .39561 .35222 .39286 .34928 Mtetra
.39286 .34928 .39561 .35222 .40019 .35063 .39745 .34769 Mtetra
.39745 .34769 .40019 .35063 .40478 .34904 .40204 .34609 Mtetra
.40204 .34609 .40478 .34904 .40937 .34744 .40664 .34449 Mtetra
.40664 .34449 .40937 .34744 .41398 .34584 .41125 .34288 Mtetra
.41125 .34288 .41398 .34584 .41859 .34424 .41587 .34127 Mtetra
.41587 .34127 .41859 .34424 .42321 .34263 .42049 .33966 Mtetra
.42049 .33966 .42321 .34263 .42784 .34103 .42513 .33805 Mtetra
.42513 .33805 .42784 .34103 .43247 .33942 .42977 .33644 Mtetra
.42977 .33644 .43247 .33942 .43712 .3378 .43442 .33482 Mtetra
.43442 .33482 .43712 .3378 .44177 .33619 .43907 .3332 Mtetra
.43907 .3332 .44177 .33619 .44643 .33457 .44374 .33157 Mtetra
.44374 .33157 .44643 .33457 .4511 .33295 .44841 .32995 Mtetra
.44841 .32995 .4511 .33295 .45577 .33132 .45309 .32832 Mtetra
.45309 .32832 .45577 .33132 .46046 .3297 .45778 .32669 Mtetra
.45778 .32669 .46046 .3297 .46515 .32807 .46248 .32505 Mtetra
.46248 .32505 .46515 .32807 .46985 .32643 .46718 .32341 Mtetra
.46718 .32341 .46985 .32643 .47456 .3248 .4719 .32177 Mtetra
.4719 .32177 .47456 .3248 .47927 .32316 .47662 .32013 Mtetra
.47662 .32013 .47927 .32316 .484 .32152 .48135 .31848 Mtetra
.48135 .31848 .484 .32152 .48873 .31988 .48608 .31683 Mtetra
.48608 .31683 .48873 .31988 .49347 .31823 .49083 .31518 Mtetra
.49083 .31518 .49347 .31823 .49822 .31658 .49558 .31353 Mtetra
.49558 .31353 .49822 .31658 .50298 .31493 .50035 .31187 Mtetra
.50035 .31187 .50298 .31493 .50774 .31327 .50512 .31021 Mtetra
0 .126 .644 r
.50512 .31021 .50774 .31327 .51249 .31734 .50987 .31427 Mtetra
.649 .759 .929 r
.50987 .31427 .51249 .31734 .51728 .31568 .51467 .31261 Mtetra
.51467 .31261 .51728 .31568 .52208 .31401 .51947 .31094 Mtetra
.51947 .31094 .52208 .31401 .52689 .31235 .52428 .30927 Mtetra
.52428 .30927 .52689 .31235 .53171 .31068 .52911 .3076 Mtetra
.52911 .3076 .53171 .31068 .53653 .30901 .53394 .30592 Mtetra
.53394 .30592 .53653 .30901 .54136 .30734 .53877 .30424 Mtetra
.53877 .30424 .54136 .30734 .54621 .30566 .54362 .30256 Mtetra
.54362 .30256 .54621 .30566 .55106 .30398 .54848 .30087 Mtetra
.54848 .30087 .55106 .30398 .55591 .3023 .55334 .29918 Mtetra
.55334 .29918 .55591 .3023 .56078 .30061 .55821 .29749 Mtetra
.55821 .29749 .56078 .30061 .56566 .29892 .5631 .2958 Mtetra
.5631 .2958 .56566 .29892 .57054 .29723 .56799 .2941 Mtetra
.56799 .2941 .57054 .29723 .57543 .29554 .57288 .2924 Mtetra
.57288 .2924 .57543 .29554 .58034 .29384 .57779 .2907 Mtetra
.57779 .2907 .58034 .29384 .58525 .29214 .58271 .28899 Mtetra
.58271 .28899 .58525 .29214 .59017 .29044 .58763 .28728 Mtetra
.58763 .28728 .59017 .29044 .59509 .28873 .59257 .28557 Mtetra
.59257 .28557 .59509 .28873 .60003 .28702 .59751 .28386 Mtetra
.59751 .28386 .60003 .28702 .60497 .28531 .60246 .28214 Mtetra
.60246 .28214 .60497 .28531 .60993 .28359 .60742 .28042 Mtetra
.60742 .28042 .60993 .28359 .61489 .28187 .61239 .27869 Mtetra
.61239 .27869 .61489 .28187 .61986 .28015 .61736 .27697 Mtetra
.61736 .27697 .61986 .28015 .62484 .27843 .62235 .27524 Mtetra
.62235 .27524 .62484 .27843 .62983 .2767 .62735 .2735 Mtetra
.62735 .2735 .62983 .2767 .63483 .27497 .63235 .27177 Mtetra
.63235 .27177 .63483 .27497 .63984 .27324 .63736 .27003 Mtetra
.63736 .27003 .63984 .27324 .64485 .2715 .64238 .26828 Mtetra
.64238 .26828 .64485 .2715 .64988 .26976 .64742 .26654 Mtetra
.64742 .26654 .64988 .26976 .65491 .26801 .65246 .26479 Mtetra
.65246 .26479 .65491 .26801 .65995 .26627 .65751 .26304 Mtetra
.65751 .26304 .65995 .26627 .66501 .26452 .66256 .26128 Mtetra
.66256 .26128 .66501 .26452 .67007 .26277 .66763 .25952 Mtetra
.66763 .25952 .67007 .26277 .67514 .26101 .67271 .25776 Mtetra
.67271 .25776 .67514 .26101 .68022 .25925 .67779 .256 Mtetra
.67779 .256 .68022 .25925 .68531 .25749 .68289 .25423 Mtetra
.68289 .25423 .68531 .25749 .6904 .25572 .68799 .25246 Mtetra
.68799 .25246 .6904 .25572 .69551 .25395 .6931 .25068 Mtetra
.6931 .25068 .69551 .25395 .70063 .25218 .69823 .2489 Mtetra
.69823 .2489 .70063 .25218 .70575 .25041 .70336 .24712 Mtetra
.70336 .24712 .70575 .25041 .71089 .24863 .7085 .24534 Mtetra
.7085 .24534 .71089 .24863 .71603 .24685 .71365 .24355 Mtetra
.71365 .24355 .71603 .24685 .72118 .24506 .71881 .24176 Mtetra
.71881 .24176 .72118 .24506 .72634 .24328 .72398 .23997 Mtetra
.72398 .23997 .72634 .24328 .73152 .24149 .72916 .23817 Mtetra
.653 .755 .925 r
.04746 .43482 .05052 .43742 .05449 .43601 .05144 .4334 Mtetra
.05144 .4334 .05449 .43601 .05847 .4346 .05543 .43199 Mtetra
.05543 .43199 .05847 .4346 .06246 .43319 .05942 .43057 Mtetra
.05942 .43057 .06246 .43319 .06645 .43177 .06342 .42915 Mtetra
.06342 .42915 .06645 .43177 .07046 .43035 .06742 .42773 Mtetra
.06742 .42773 .07046 .43035 .07446 .42894 .07143 .42631 Mtetra
.07143 .42631 .07446 .42894 .07848 .42751 .07545 .42488 Mtetra
.07545 .42488 .07848 .42751 .08249 .42609 .07947 .42345 Mtetra
.07947 .42345 .08249 .42609 .08652 .42466 .0835 .42202 Mtetra
.0835 .42202 .08652 .42466 .09055 .42323 .08754 .42059 Mtetra
.08754 .42059 .09055 .42323 .09459 .4218 .09158 .41916 Mtetra
.09158 .41916 .09459 .4218 .09864 .42037 .09563 .41772 Mtetra
.09563 .41772 .09864 .42037 .10269 .41894 .09968 .41628 Mtetra
.09968 .41628 .10269 .41894 .10675 .4175 .10375 .41484 Mtetra
.10375 .41484 .10675 .4175 .11081 .41606 .10781 .41339 Mtetra
.10781 .41339 .11081 .41606 .11488 .41462 .11189 .41195 Mtetra
.11189 .41195 .11488 .41462 .11896 .41317 .11597 .4105 Mtetra
.11597 .4105 .11896 .41317 .12305 .41172 .12006 .40905 Mtetra
.12006 .40905 .12305 .41172 .12714 .41028 .12415 .40759 Mtetra
.12415 .40759 .12714 .41028 .13123 .40882 .12825 .40614 Mtetra
.12825 .40614 .13123 .40882 .13534 .40737 .13236 .40468 Mtetra
.13236 .40468 .13534 .40737 .13945 .40591 .13648 .40322 Mtetra
.949 .647 .428 r
.13648 .40322 .13945 .40591 .13967 .43741 .13667 .43474 Mtetra
.65 .758 .928 r
.13667 .43474 .13967 .43741 .14383 .43597 .14083 .43328 Mtetra
.14083 .43328 .14383 .43597 .148 .43451 .14501 .43183 Mtetra
.14501 .43183 .148 .43451 .15218 .43306 .14919 .43037 Mtetra
.14919 .43037 .15218 .43306 .15636 .4316 .15337 .42891 Mtetra
.15337 .42891 .15636 .4316 .16055 .43015 .15757 .42745 Mtetra
.15757 .42745 .16055 .43015 .16475 .42868 .16177 .42598 Mtetra
.16177 .42598 .16475 .42868 .16895 .42722 .16598 .42451 Mtetra
.16598 .42451 .16895 .42722 .17316 .42576 .17019 .42304 Mtetra
.17019 .42304 .17316 .42576 .17738 .42429 .17441 .42157 Mtetra
.17441 .42157 .17738 .42429 .18161 .42282 .17864 .4201 Mtetra
.17864 .4201 .18161 .42282 .18584 .42134 .18288 .41862 Mtetra
.18288 .41862 .18584 .42134 .19008 .41987 .18712 .41714 Mtetra
.18712 .41714 .19008 .41987 .19432 .41839 .19137 .41566 Mtetra
.19137 .41566 .19432 .41839 .19857 .41691 .19562 .41417 Mtetra
.19562 .41417 .19857 .41691 .20283 .41543 .19989 .41268 Mtetra
.19989 .41268 .20283 .41543 .2071 .41394 .20416 .4112 Mtetra
.20416 .4112 .2071 .41394 .21137 .41246 .20843 .4097 Mtetra
.20843 .4097 .21137 .41246 .21565 .41097 .21272 .40821 Mtetra
.21272 .40821 .21565 .41097 .21994 .40947 .21701 .40671 Mtetra
.21701 .40671 .21994 .40947 .22424 .40798 .22131 .40521 Mtetra
.22131 .40521 .22424 .40798 .22854 .40648 .22562 .40371 Mtetra
.22562 .40371 .22854 .40648 .23285 .40498 .22993 .40221 Mtetra
.22993 .40221 .23285 .40498 .23716 .40348 .23425 .4007 Mtetra
.23425 .4007 .23716 .40348 .24727 .33617 .23858 .39919 Mtetra
.488 .235 .456 r
.23858 .39919 .24727 .33617 .25152 .33464 .24291 .39768 Mtetra
0 0 .045 r
.24291 .39768 .25152 .33464 .25577 .3331 .25294 .33027 Mtetra
.655 .752 .921 r
.25294 .33027 .25577 .3331 .26003 .33157 .2572 .32873 Mtetra
.2572 .32873 .26003 .33157 .2643 .33003 .26147 .32719 Mtetra
.26147 .32719 .2643 .33003 .26857 .32849 .26575 .32564 Mtetra
.26575 .32564 .26857 .32849 .27285 .32695 .27004 .32409 Mtetra
.27004 .32409 .27285 .32695 .27714 .3254 .27433 .32254 Mtetra
.27433 .32254 .27714 .3254 .28144 .32386 .27863 .32099 Mtetra
.27863 .32099 .28144 .32386 .28574 .32231 .28293 .31944 Mtetra
.961 .665 .428 r
.28293 .31944 .28574 .32231 .29005 .32075 .28225 .38396 Mtetra
.488 .235 .456 r
.28225 .38396 .29005 .32075 .28952 .38525 .28666 .38242 Mtetra
.65 .758 .928 r
.28666 .38242 .28952 .38525 .29393 .38372 .29107 .38088 Mtetra
.29107 .38088 .29393 .38372 .29835 .38218 .29549 .37934 Mtetra
.29549 .37934 .29835 .38218 .30277 .38064 .29992 .37779 Mtetra
.29992 .37779 .30277 .38064 .3072 .3791 .30436 .37624 Mtetra
.30436 .37624 .3072 .3791 .31164 .37755 .3088 .37469 Mtetra
.3088 .37469 .31164 .37755 .31609 .37601 .31326 .37314 Mtetra
.31326 .37314 .31609 .37601 .32055 .37445 .31772 .37158 Mtetra
.31772 .37158 .32055 .37445 .32501 .3729 .32218 .37003 Mtetra
.32218 .37003 .32501 .3729 .32948 .37134 .32666 .36847 Mtetra
.32666 .36847 .32948 .37134 .33396 .36979 .33114 .3669 Mtetra
.33114 .3669 .33396 .36979 .33844 .36823 .33563 .36534 Mtetra
.33563 .36534 .33844 .36823 .34294 .36666 .34013 .36377 Mtetra
.34013 .36377 .34294 .36666 .34744 .36509 .34463 .3622 Mtetra
.34463 .3622 .34744 .36509 .35194 .36353 .34915 .36062 Mtetra
.34915 .36062 .35194 .36353 .35646 .36195 .35367 .35904 Mtetra
.35367 .35904 .35646 .36195 .36098 .36038 .35819 .35747 Mtetra
.35819 .35747 .36098 .36038 .36551 .3588 .36273 .35588 Mtetra
.36273 .35588 .36551 .3588 .37005 .35722 .36727 .3543 Mtetra
.36727 .3543 .37005 .35722 .3746 .35564 .37183 .35271 Mtetra
.37183 .35271 .3746 .35564 .37915 .35405 .37638 .35112 Mtetra
.37638 .35112 .37915 .35405 .38372 .35247 .38095 .34953 Mtetra
.38095 .34953 .38372 .35247 .38829 .35088 .38553 .34793 Mtetra
.38553 .34793 .38829 .35088 .39286 .34928 .39011 .34633 Mtetra
.39011 .34633 .39286 .34928 .39745 .34769 .3947 .34473 Mtetra
.3947 .34473 .39745 .34769 .40204 .34609 .3993 .34313 Mtetra
.3993 .34313 .40204 .34609 .40664 .34449 .4039 .34152 Mtetra
.4039 .34152 .40664 .34449 .41125 .34288 .40852 .33991 Mtetra
.40852 .33991 .41125 .34288 .41587 .34127 .41314 .3383 Mtetra
.41314 .3383 .41587 .34127 .42049 .33966 .41777 .33669 Mtetra
.41777 .33669 .42049 .33966 .42513 .33805 .42241 .33507 Mtetra
.42241 .33507 .42513 .33805 .42977 .33644 .42705 .33345 Mtetra
.42705 .33345 .42977 .33644 .43442 .33482 .43171 .33182 Mtetra
.43171 .33182 .43442 .33482 .43907 .3332 .43637 .3302 Mtetra
.43637 .3302 .43907 .3332 .44374 .33157 .44104 .32857 Mtetra
.44104 .32857 .44374 .33157 .44841 .32995 .44572 .32694 Mtetra
.44572 .32694 .44841 .32995 .45309 .32832 .4504 .3253 Mtetra
.4504 .3253 .45309 .32832 .45778 .32669 .4551 .32367 Mtetra
.4551 .32367 .45778 .32669 .46248 .32505 .4598 .32203 Mtetra
.4598 .32203 .46248 .32505 .46718 .32341 .46451 .32038 Mtetra
.46451 .32038 .46718 .32341 .4719 .32177 .46923 .31874 Mtetra
.46923 .31874 .4719 .32177 .47662 .32013 .47395 .31709 Mtetra
.47395 .31709 .47662 .32013 .48135 .31848 .47869 .31544 Mtetra
.47869 .31544 .48135 .31848 .48608 .31683 .48343 .31378 Mtetra
.48343 .31378 .48608 .31683 .49083 .31518 .48818 .31212 Mtetra
.48818 .31212 .49083 .31518 .49558 .31353 .49294 .31046 Mtetra
.49294 .31046 .49558 .31353 .50035 .31187 .49771 .3088 Mtetra
.49771 .3088 .50035 .31187 .50512 .31021 .50249 .30713 Mtetra
0 .126 .644 r
.50249 .30713 .50512 .31021 .50987 .31427 .50724 .3112 Mtetra
.649 .759 .929 r
.50724 .3112 .50987 .31427 .51467 .31261 .51204 .30953 Mtetra
.51204 .30953 .51467 .31261 .51947 .31094 .51685 .30785 Mtetra
.51685 .30785 .51947 .31094 .52428 .30927 .52167 .30618 Mtetra
.52167 .30618 .52428 .30927 .52911 .3076 .5265 .3045 Mtetra
.5265 .3045 .52911 .3076 .53394 .30592 .53133 .30282 Mtetra
.53133 .30282 .53394 .30592 .53877 .30424 .53618 .30113 Mtetra
.53618 .30113 .53877 .30424 .54362 .30256 .54103 .29944 Mtetra
.54103 .29944 .54362 .30256 .54848 .30087 .54589 .29775 Mtetra
.54589 .29775 .54848 .30087 .55334 .29918 .55076 .29606 Mtetra
.55076 .29606 .55334 .29918 .55821 .29749 .55564 .29436 Mtetra
.55564 .29436 .55821 .29749 .5631 .2958 .56053 .29266 Mtetra
.56053 .29266 .5631 .2958 .56799 .2941 .56542 .29096 Mtetra
.56542 .29096 .56799 .2941 .57288 .2924 .57033 .28926 Mtetra
.57033 .28926 .57288 .2924 .57779 .2907 .57524 .28755 Mtetra
.57524 .28755 .57779 .2907 .58271 .28899 .58016 .28584 Mtetra
.58016 .28584 .58271 .28899 .58763 .28728 .58509 .28412 Mtetra
.58509 .28412 .58763 .28728 .59257 .28557 .59003 .2824 Mtetra
.59003 .2824 .59257 .28557 .59751 .28386 .59498 .28068 Mtetra
.59498 .28068 .59751 .28386 .60246 .28214 .59993 .27896 Mtetra
.59993 .27896 .60246 .28214 .60742 .28042 .6049 .27723 Mtetra
.6049 .27723 .60742 .28042 .61239 .27869 .60987 .2755 Mtetra
.60987 .2755 .61239 .27869 .61736 .27697 .61486 .27377 Mtetra
.61486 .27377 .61736 .27697 .62235 .27524 .61985 .27203 Mtetra
.61985 .27203 .62235 .27524 .62735 .2735 .62485 .27029 Mtetra
.62485 .27029 .62735 .2735 .63235 .27177 .62986 .26855 Mtetra
.62986 .26855 .63235 .27177 .63736 .27003 .63488 .26681 Mtetra
.63488 .26681 .63736 .27003 .64238 .26828 .63991 .26506 Mtetra
.63991 .26506 .64238 .26828 .64742 .26654 .64495 .26331 Mtetra
.64495 .26331 .64742 .26654 .65246 .26479 .64999 .26155 Mtetra
.64999 .26155 .65246 .26479 .65751 .26304 .65505 .25979 Mtetra
.65505 .25979 .65751 .26304 .66256 .26128 .66011 .25803 Mtetra
.66011 .25803 .66256 .26128 .66763 .25952 .66519 .25627 Mtetra
.66519 .25627 .66763 .25952 .67271 .25776 .67027 .2545 Mtetra
.67027 .2545 .67271 .25776 .67779 .256 .67536 .25273 Mtetra
.67536 .25273 .67779 .256 .68289 .25423 .68046 .25095 Mtetra
.68046 .25095 .68289 .25423 .68799 .25246 .68557 .24918 Mtetra
.68557 .24918 .68799 .25246 .6931 .25068 .69069 .2474 Mtetra
.69069 .2474 .6931 .25068 .69823 .2489 .69582 .24561 Mtetra
.69582 .24561 .69823 .2489 .70336 .24712 .70096 .24383 Mtetra
.70096 .24383 .70336 .24712 .7085 .24534 .7061 .24204 Mtetra
.7061 .24204 .7085 .24534 .71365 .24355 .71126 .24024 Mtetra
.71126 .24024 .71365 .24355 .71881 .24176 .71643 .23845 Mtetra
.71643 .23845 .71881 .24176 .72398 .23997 .7216 .23665 Mtetra
.7216 .23665 .72398 .23997 .72916 .23817 .72679 .23484 Mtetra
.653 .755 .925 r
.0444 .43221 .04746 .43482 .05144 .4334 .04839 .43079 Mtetra
.04839 .43079 .05144 .4334 .05543 .43199 .05237 .42937 Mtetra
.05237 .42937 .05543 .43199 .05942 .43057 .05637 .42795 Mtetra
.05637 .42795 .05942 .43057 .06342 .42915 .06037 .42653 Mtetra
.06037 .42653 .06342 .42915 .06742 .42773 .06438 .4251 Mtetra
.06438 .4251 .06742 .42773 .07143 .42631 .06839 .42367 Mtetra
.06839 .42367 .07143 .42631 .07545 .42488 .07241 .42224 Mtetra
.07241 .42224 .07545 .42488 .07947 .42345 .07644 .42081 Mtetra
.07644 .42081 .07947 .42345 .0835 .42202 .08047 .41938 Mtetra
.08047 .41938 .0835 .42202 .08754 .42059 .08451 .41794 Mtetra
.08451 .41794 .08754 .42059 .09158 .41916 .08856 .4165 Mtetra
.08856 .4165 .09158 .41916 .09563 .41772 .09261 .41506 Mtetra
.09261 .41506 .09563 .41772 .09968 .41628 .09667 .41362 Mtetra
.09667 .41362 .09968 .41628 .10375 .41484 .10073 .41217 Mtetra
.10073 .41217 .10375 .41484 .10781 .41339 .10481 .41072 Mtetra
.10481 .41072 .10781 .41339 .11189 .41195 .10888 .40927 Mtetra
.10888 .40927 .11189 .41195 .11597 .4105 .11297 .40782 Mtetra
.11297 .40782 .11597 .4105 .12006 .40905 .11706 .40636 Mtetra
.11706 .40636 .12006 .40905 .12415 .40759 .12116 .4049 Mtetra
.12116 .4049 .12415 .40759 .12825 .40614 .12526 .40344 Mtetra
.12526 .40344 .12825 .40614 .13236 .40468 .12938 .40198 Mtetra
.12938 .40198 .13236 .40468 .13648 .40322 .13349 .40052 Mtetra
.949 .647 .428 r
.13349 .40052 .13648 .40322 .13667 .43474 .13365 .43205 Mtetra
.65 .758 .928 r
.13365 .43205 .13667 .43474 .14083 .43328 .13782 .43059 Mtetra
.13782 .43059 .14083 .43328 .14501 .43183 .142 .42913 Mtetra
.142 .42913 .14501 .43183 .14919 .43037 .14618 .42767 Mtetra
.14618 .42767 .14919 .43037 .15337 .42891 .15037 .42621 Mtetra
.15037 .42621 .15337 .42891 .15757 .42745 .15457 .42474 Mtetra
.15457 .42474 .15757 .42745 .16177 .42598 .15878 .42327 Mtetra
.15878 .42327 .16177 .42598 .16598 .42451 .16299 .4218 Mtetra
.16299 .4218 .16598 .42451 .17019 .42304 .16721 .42032 Mtetra
.16721 .42032 .17019 .42304 .17441 .42157 .17143 .41885 Mtetra
.17143 .41885 .17441 .42157 .17864 .4201 .17566 .41737 Mtetra
.17566 .41737 .17864 .4201 .18288 .41862 .1799 .41588 Mtetra
.1799 .41588 .18288 .41862 .18712 .41714 .18415 .4144 Mtetra
.18415 .4144 .18712 .41714 .19137 .41566 .1884 .41291 Mtetra
.1884 .41291 .19137 .41566 .19562 .41417 .19266 .41142 Mtetra
.19266 .41142 .19562 .41417 .19989 .41268 .19693 .40993 Mtetra
.19693 .40993 .19989 .41268 .20416 .4112 .20121 .40844 Mtetra
.20121 .40844 .20416 .4112 .20843 .4097 .20549 .40694 Mtetra
.20549 .40694 .20843 .4097 .21272 .40821 .20978 .40544 Mtetra
.20978 .40544 .21272 .40821 .21701 .40671 .21407 .40394 Mtetra
.21407 .40394 .21701 .40671 .22131 .40521 .21837 .40244 Mtetra
.21837 .40244 .22131 .40521 .22562 .40371 .22268 .40093 Mtetra
.22268 .40093 .22562 .40371 .22993 .40221 .227 .39942 Mtetra
.227 .39942 .22993 .40221 .23425 .4007 .23133 .39791 Mtetra
.23133 .39791 .23425 .4007 .23858 .39919 .23566 .3964 Mtetra
.23566 .3964 .23858 .39919 .24291 .39768 .24 .39488 Mtetra
.24 .39488 .24291 .39768 .25294 .33027 .24434 .39336 Mtetra
0 0 .045 r
.24434 .39336 .25294 .33027 .2572 .32873 .25436 .32588 Mtetra
.655 .752 .921 r
.25436 .32588 .2572 .32873 .26147 .32719 .25864 .32433 Mtetra
.25864 .32433 .26147 .32719 .26575 .32564 .26292 .32278 Mtetra
.26292 .32278 .26575 .32564 .27004 .32409 .26721 .32123 Mtetra
.26721 .32123 .27004 .32409 .27433 .32254 .27151 .31968 Mtetra
.27151 .31968 .27433 .32254 .27863 .32099 .27581 .31812 Mtetra
.96 .666 .43 r
.27581 .31812 .27863 .32099 .28293 .31944 .27497 .38266 Mtetra
.487 .233 .455 r
.27497 .38266 .28293 .31944 .28225 .38396 .27937 .38112 Mtetra
.65 .758 .928 r
.27937 .38112 .28225 .38396 .28666 .38242 .28379 .37957 Mtetra
.28379 .37957 .28666 .38242 .29107 .38088 .2882 .37803 Mtetra
.2882 .37803 .29107 .38088 .29549 .37934 .29263 .37648 Mtetra
.29263 .37648 .29549 .37934 .29992 .37779 .29707 .37493 Mtetra
.29707 .37493 .29992 .37779 .30436 .37624 .30151 .37338 Mtetra
.30151 .37338 .30436 .37624 .3088 .37469 .30596 .37182 Mtetra
.30596 .37182 .3088 .37469 .31326 .37314 .31041 .37027 Mtetra
.31041 .37027 .31326 .37314 .31772 .37158 .31488 .36871 Mtetra
.31488 .36871 .31772 .37158 .32218 .37003 .31935 .36714 Mtetra
.31935 .36714 .32218 .37003 .32666 .36847 .32383 .36558 Mtetra
.32383 .36558 .32666 .36847 .33114 .3669 .32832 .36401 Mtetra
.32832 .36401 .33114 .3669 .33563 .36534 .33281 .36244 Mtetra
.33281 .36244 .33563 .36534 .34013 .36377 .33731 .36086 Mtetra
.33731 .36086 .34013 .36377 .34463 .3622 .34182 .35929 Mtetra
.34182 .35929 .34463 .3622 .34915 .36062 .34634 .35771 Mtetra
.34634 .35771 .34915 .36062 .35367 .35904 .35086 .35613 Mtetra
.35086 .35613 .35367 .35904 .35819 .35747 .3554 .35454 Mtetra
.3554 .35454 .35819 .35747 .36273 .35588 .35994 .35296 Mtetra
.35994 .35296 .36273 .35588 .36727 .3543 .36449 .35137 Mtetra
.36449 .35137 .36727 .3543 .37183 .35271 .36904 .34977 Mtetra
.36904 .34977 .37183 .35271 .37638 .35112 .37361 .34818 Mtetra
.37361 .34818 .37638 .35112 .38095 .34953 .37818 .34658 Mtetra
.37818 .34658 .38095 .34953 .38553 .34793 .38276 .34498 Mtetra
.38276 .34498 .38553 .34793 .39011 .34633 .38734 .34338 Mtetra
.38734 .34338 .39011 .34633 .3947 .34473 .39194 .34177 Mtetra
.39194 .34177 .3947 .34473 .3993 .34313 .39654 .34016 Mtetra
.39654 .34016 .3993 .34313 .4039 .34152 .40115 .33855 Mtetra
.40115 .33855 .4039 .34152 .40852 .33991 .40577 .33693 Mtetra
.40577 .33693 .40852 .33991 .41314 .3383 .4104 .33532 Mtetra
.4104 .33532 .41314 .3383 .41777 .33669 .41503 .3337 Mtetra
.41503 .3337 .41777 .33669 .42241 .33507 .41968 .33207 Mtetra
.41968 .33207 .42241 .33507 .42705 .33345 .42433 .33045 Mtetra
.42433 .33045 .42705 .33345 .43171 .33182 .42899 .32882 Mtetra
.42899 .32882 .43171 .33182 .43637 .3302 .43365 .32719 Mtetra
.43365 .32719 .43637 .3302 .44104 .32857 .43833 .32555 Mtetra
.43833 .32555 .44104 .32857 .44572 .32694 .44301 .32392 Mtetra
.44301 .32392 .44572 .32694 .4504 .3253 .4477 .32228 Mtetra
.4477 .32228 .4504 .3253 .4551 .32367 .4524 .32064 Mtetra
.4524 .32064 .4551 .32367 .4598 .32203 .45711 .31899 Mtetra
.45711 .31899 .4598 .32203 .46451 .32038 .46182 .31734 Mtetra
.46182 .31734 .46451 .32038 .46923 .31874 .46655 .31569 Mtetra
.46655 .31569 .46923 .31874 .47395 .31709 .47128 .31404 Mtetra
.47128 .31404 .47395 .31709 .47869 .31544 .47602 .31238 Mtetra
.47602 .31238 .47869 .31544 .48343 .31378 .48077 .31072 Mtetra
.48077 .31072 .48343 .31378 .48818 .31212 .48553 .30906 Mtetra
.48553 .30906 .48818 .31212 .49294 .31046 .49029 .30739 Mtetra
.49029 .30739 .49294 .31046 .49771 .3088 .49506 .30572 Mtetra
.49506 .30572 .49771 .3088 .50249 .30713 .49985 .30405 Mtetra
0 .126 .644 r
.49985 .30405 .50249 .30713 .50724 .3112 .5046 .30811 Mtetra
.649 .759 .929 r
.5046 .30811 .50724 .3112 .51204 .30953 .50941 .30644 Mtetra
.50941 .30644 .51204 .30953 .51685 .30785 .51422 .30476 Mtetra
.51422 .30476 .51685 .30785 .52167 .30618 .51905 .30308 Mtetra
.51905 .30308 .52167 .30618 .5265 .3045 .52388 .30139 Mtetra
.52388 .30139 .5265 .3045 .53133 .30282 .52872 .2997 Mtetra
.52872 .2997 .53133 .30282 .53618 .30113 .53357 .29801 Mtetra
.53357 .29801 .53618 .30113 .54103 .29944 .53843 .29632 Mtetra
.53843 .29632 .54103 .29944 .54589 .29775 .54329 .29462 Mtetra
.54329 .29462 .54589 .29775 .55076 .29606 .54817 .29293 Mtetra
.54817 .29293 .55076 .29606 .55564 .29436 .55305 .29122 Mtetra
.55305 .29122 .55564 .29436 .56053 .29266 .55795 .28952 Mtetra
.55795 .28952 .56053 .29266 .56542 .29096 .56285 .28781 Mtetra
.56285 .28781 .56542 .29096 .57033 .28926 .56776 .2861 Mtetra
.56776 .2861 .57033 .28926 .57524 .28755 .57268 .28439 Mtetra
.57268 .28439 .57524 .28755 .58016 .28584 .5776 .28267 Mtetra
.5776 .28267 .58016 .28584 .58509 .28412 .58254 .28095 Mtetra
.58254 .28095 .58509 .28412 .59003 .2824 .58749 .27922 Mtetra
.58749 .27922 .59003 .2824 .59498 .28068 .59244 .2775 Mtetra
.59244 .2775 .59498 .28068 .59993 .27896 .5974 .27577 Mtetra
.5974 .27577 .59993 .27896 .6049 .27723 .60237 .27404 Mtetra
.60237 .27404 .6049 .27723 .60987 .2755 .60735 .2723 Mtetra
.60735 .2723 .60987 .2755 .61486 .27377 .61234 .27056 Mtetra
.61234 .27056 .61486 .27377 .61985 .27203 .61734 .26882 Mtetra
.61734 .26882 .61985 .27203 .62485 .27029 .62235 .26707 Mtetra
.62235 .26707 .62485 .27029 .62986 .26855 .62737 .26533 Mtetra
.62737 .26533 .62986 .26855 .63488 .26681 .63239 .26358 Mtetra
.63239 .26358 .63488 .26681 .63991 .26506 .63743 .26182 Mtetra
.63743 .26182 .63991 .26506 .64495 .26331 .64247 .26006 Mtetra
.64247 .26006 .64495 .26331 .64999 .26155 .64752 .2583 Mtetra
.64752 .2583 .64999 .26155 .65505 .25979 .65258 .25654 Mtetra
.65258 .25654 .65505 .25979 .66011 .25803 .65765 .25477 Mtetra
.65765 .25477 .66011 .25803 .66519 .25627 .66273 .253 Mtetra
.66273 .253 .66519 .25627 .67027 .2545 .66782 .25123 Mtetra
.66782 .25123 .67027 .2545 .67536 .25273 .67292 .24945 Mtetra
.67292 .24945 .67536 .25273 .68046 .25095 .67803 .24767 Mtetra
.67803 .24767 .68046 .25095 .68557 .24918 .68314 .24589 Mtetra
.68314 .24589 .68557 .24918 .69069 .2474 .68827 .2441 Mtetra
.68827 .2441 .69069 .2474 .69582 .24561 .6934 .24231 Mtetra
.6934 .24231 .69582 .24561 .70096 .24383 .69855 .24052 Mtetra
.69855 .24052 .70096 .24383 .7061 .24204 .7037 .23872 Mtetra
.7037 .23872 .7061 .24204 .71126 .24024 .70887 .23692 Mtetra
.70887 .23692 .71126 .24024 .71643 .23845 .71404 .23512 Mtetra
.71404 .23512 .71643 .23845 .7216 .23665 .71922 .23332 Mtetra
.71922 .23332 .7216 .23665 .72679 .23484 .72441 .23151 Mtetra
.653 .755 .925 r
.04134 .42959 .0444 .43221 .04839 .43079 .04532 .42817 Mtetra
.04532 .42817 .04839 .43079 .05237 .42937 .04931 .42675 Mtetra
.04931 .42675 .05237 .42937 .05637 .42795 .05331 .42532 Mtetra
.05331 .42532 .05637 .42795 .06037 .42653 .05731 .42389 Mtetra
.05731 .42389 .06037 .42653 .06438 .4251 .06133 .42246 Mtetra
.06133 .42246 .06438 .4251 .06839 .42367 .06534 .42103 Mtetra
.06534 .42103 .06839 .42367 .07241 .42224 .06937 .4196 Mtetra
.06937 .4196 .07241 .42224 .07644 .42081 .0734 .41816 Mtetra
.0734 .41816 .07644 .42081 .08047 .41938 .07743 .41672 Mtetra
.07743 .41672 .08047 .41938 .08451 .41794 .08148 .41528 Mtetra
.08148 .41528 .08451 .41794 .08856 .4165 .08553 .41384 Mtetra
.08553 .41384 .08856 .4165 .09261 .41506 .08958 .41239 Mtetra
.08958 .41239 .09261 .41506 .09667 .41362 .09364 .41094 Mtetra
.09364 .41094 .09667 .41362 .10073 .41217 .09771 .40949 Mtetra
.09771 .40949 .10073 .41217 .10481 .41072 .10179 .40804 Mtetra
.10179 .40804 .10481 .41072 .10888 .40927 .10587 .40659 Mtetra
.10587 .40659 .10888 .40927 .11297 .40782 .10996 .40513 Mtetra
.10996 .40513 .11297 .40782 .11706 .40636 .11406 .40367 Mtetra
.11406 .40367 .11706 .40636 .12116 .4049 .11816 .40221 Mtetra
.11816 .40221 .12116 .4049 .12526 .40344 .12227 .40074 Mtetra
.12227 .40074 .12526 .40344 .12938 .40198 .12638 .39927 Mtetra
.12638 .39927 .12938 .40198 .13349 .40052 .1305 .39781 Mtetra
.949 .647 .428 r
.1305 .39781 .13349 .40052 .13365 .43205 .13063 .42936 Mtetra
.65 .758 .928 r
.13063 .42936 .13365 .43205 .13782 .43059 .1348 .4279 Mtetra
.1348 .4279 .13782 .43059 .142 .42913 .13898 .42643 Mtetra
.13898 .42643 .142 .42913 .14618 .42767 .14317 .42497 Mtetra
.14317 .42497 .14618 .42767 .15037 .42621 .14737 .4235 Mtetra
.14737 .4235 .15037 .42621 .15457 .42474 .15157 .42202 Mtetra
.15157 .42202 .15457 .42474 .15878 .42327 .15578 .42055 Mtetra
.15578 .42055 .15878 .42327 .16299 .4218 .15999 .41907 Mtetra
.15999 .41907 .16299 .4218 .16721 .42032 .16421 .41759 Mtetra
.16421 .41759 .16721 .42032 .17143 .41885 .16844 .41611 Mtetra
.16844 .41611 .17143 .41885 .17566 .41737 .17268 .41463 Mtetra
.17268 .41463 .17566 .41737 .1799 .41588 .17692 .41314 Mtetra
.17692 .41314 .1799 .41588 .18415 .4144 .18117 .41165 Mtetra
.18117 .41165 .18415 .4144 .1884 .41291 .18543 .41016 Mtetra
.18543 .41016 .1884 .41291 .19266 .41142 .1897 .40867 Mtetra
.1897 .40867 .19266 .41142 .19693 .40993 .19397 .40717 Mtetra
.19397 .40717 .19693 .40993 .20121 .40844 .19825 .40567 Mtetra
.19825 .40567 .20121 .40844 .20549 .40694 .20253 .40417 Mtetra
.20253 .40417 .20549 .40694 .20978 .40544 .20682 .40267 Mtetra
.20682 .40267 .20978 .40544 .21407 .40394 .21112 .40116 Mtetra
.21112 .40116 .21407 .40394 .21837 .40244 .21543 .39965 Mtetra
.21543 .39965 .21837 .40244 .22268 .40093 .21974 .39814 Mtetra
.21974 .39814 .22268 .40093 .227 .39942 .22407 .39663 Mtetra
.22407 .39663 .227 .39942 .23133 .39791 .22839 .39511 Mtetra
.22839 .39511 .23133 .39791 .23566 .3964 .23273 .39359 Mtetra
.23273 .39359 .23566 .3964 .24 .39488 .23707 .39207 Mtetra
.23707 .39207 .24 .39488 .24434 .39336 .24142 .39055 Mtetra
.24142 .39055 .24434 .39336 .25436 .32588 .24578 .38902 Mtetra
0 0 .045 r
.24578 .38902 .25436 .32588 .25864 .32433 .2558 .32147 Mtetra
.655 .752 .921 r
.2558 .32147 .25864 .32433 .26292 .32278 .26008 .31992 Mtetra
.26008 .31992 .26292 .32278 .26721 .32123 .26438 .31836 Mtetra
.26438 .31836 .26721 .32123 .27151 .31968 .26868 .3168 Mtetra
.26868 .3168 .27151 .31968 .27581 .31812 .27299 .31524 Mtetra
.96 .666 .43 r
.27299 .31524 .27581 .31812 .27497 .38266 .27208 .37981 Mtetra
.65 .758 .928 r
.27208 .37981 .27497 .38266 .27937 .38112 .27649 .37827 Mtetra
.27649 .37827 .27937 .38112 .28379 .37957 .28091 .37672 Mtetra
.28091 .37672 .28379 .37957 .2882 .37803 .28533 .37517 Mtetra
.28533 .37517 .2882 .37803 .29263 .37648 .28976 .37362 Mtetra
.28976 .37362 .29263 .37648 .29707 .37493 .2942 .37206 Mtetra
.2942 .37206 .29707 .37493 .30151 .37338 .29865 .37051 Mtetra
.29865 .37051 .30151 .37338 .30596 .37182 .3031 .36895 Mtetra
.3031 .36895 .30596 .37182 .31041 .37027 .30756 .36738 Mtetra
.30756 .36738 .31041 .37027 .31488 .36871 .31203 .36582 Mtetra
.31203 .36582 .31488 .36871 .31935 .36714 .31651 .36425 Mtetra
.31651 .36425 .31935 .36714 .32383 .36558 .32099 .36268 Mtetra
.32099 .36268 .32383 .36558 .32832 .36401 .32548 .36111 Mtetra
.32548 .36111 .32832 .36401 .33281 .36244 .32998 .35953 Mtetra
.32998 .35953 .33281 .36244 .33731 .36086 .33449 .35795 Mtetra
.33449 .35795 .33731 .36086 .34182 .35929 .339 .35637 Mtetra
.339 .35637 .34182 .35929 .34634 .35771 .34352 .35479 Mtetra
.34352 .35479 .34634 .35771 .35086 .35613 .34805 .3532 Mtetra
.34805 .3532 .35086 .35613 .3554 .35454 .35259 .35161 Mtetra
.35259 .35161 .3554 .35454 .35994 .35296 .35714 .35002 Mtetra
.35714 .35002 .35994 .35296 .36449 .35137 .36169 .34842 Mtetra
.36169 .34842 .36449 .35137 .36904 .34977 .36625 .34683 Mtetra
.36625 .34683 .36904 .34977 .37361 .34818 .37082 .34523 Mtetra
.37082 .34523 .37361 .34818 .37818 .34658 .3754 .34362 Mtetra
.3754 .34362 .37818 .34658 .38276 .34498 .37998 .34202 Mtetra
.37998 .34202 .38276 .34498 .38734 .34338 .38457 .34041 Mtetra
.38457 .34041 .38734 .34338 .39194 .34177 .38917 .3388 Mtetra
.38917 .3388 .39194 .34177 .39654 .34016 .39378 .33718 Mtetra
.39378 .33718 .39654 .34016 .40115 .33855 .3984 .33557 Mtetra
.3984 .33557 .40115 .33855 .40577 .33693 .40302 .33395 Mtetra
.40302 .33395 .40577 .33693 .4104 .33532 .40765 .33232 Mtetra
.40765 .33232 .4104 .33532 .41503 .3337 .41229 .3307 Mtetra
.41229 .3307 .41503 .3337 .41968 .33207 .41694 .32907 Mtetra
.41694 .32907 .41968 .33207 .42433 .33045 .4216 .32744 Mtetra
.4216 .32744 .42433 .33045 .42899 .32882 .42626 .32581 Mtetra
.42626 .32581 .42899 .32882 .43365 .32719 .43093 .32417 Mtetra
.43093 .32417 .43365 .32719 .43833 .32555 .43561 .32253 Mtetra
.43561 .32253 .43833 .32555 .44301 .32392 .4403 .32089 Mtetra
.4403 .32089 .44301 .32392 .4477 .32228 .445 .31924 Mtetra
.445 .31924 .4477 .32228 .4524 .32064 .4497 .3176 Mtetra
.4497 .3176 .4524 .32064 .45711 .31899 .45441 .31594 Mtetra
.45441 .31594 .45711 .31899 .46182 .31734 .45913 .31429 Mtetra
.45913 .31429 .46182 .31734 .46655 .31569 .46386 .31263 Mtetra
.46386 .31263 .46655 .31569 .47128 .31404 .4686 .31098 Mtetra
.4686 .31098 .47128 .31404 .47602 .31238 .47335 .30931 Mtetra
.47335 .30931 .47602 .31238 .48077 .31072 .4781 .30765 Mtetra
.4781 .30765 .48077 .31072 .48553 .30906 .48286 .30598 Mtetra
.48286 .30598 .48553 .30906 .49029 .30739 .48763 .30431 Mtetra
.48763 .30431 .49029 .30739 .49506 .30572 .49241 .30263 Mtetra
.49241 .30263 .49506 .30572 .49985 .30405 .4972 .30096 Mtetra
0 .126 .644 r
.4972 .30096 .49985 .30405 .5046 .30811 .50195 .30502 Mtetra
.649 .759 .929 r
.50195 .30502 .5046 .30811 .50941 .30644 .50676 .30333 Mtetra
.50676 .30333 .50941 .30644 .51422 .30476 .51158 .30165 Mtetra
.51158 .30165 .51422 .30476 .51905 .30308 .51641 .29996 Mtetra
.51641 .29996 .51905 .30308 .52388 .30139 .52125 .29827 Mtetra
.52125 .29827 .52388 .30139 .52872 .2997 .5261 .29658 Mtetra
.5261 .29658 .52872 .2997 .53357 .29801 .53095 .29489 Mtetra
.53095 .29489 .53357 .29801 .53843 .29632 .53582 .29319 Mtetra
.53582 .29319 .53843 .29632 .54329 .29462 .54069 .29149 Mtetra
.54069 .29149 .54329 .29462 .54817 .29293 .54557 .28978 Mtetra
.54557 .28978 .54817 .29293 .55305 .29122 .55046 .28807 Mtetra
.55046 .28807 .55305 .29122 .55795 .28952 .55536 .28636 Mtetra
.55536 .28636 .55795 .28952 .56285 .28781 .56027 .28465 Mtetra
.56027 .28465 .56285 .28781 .56776 .2861 .56518 .28293 Mtetra
.56518 .28293 .56776 .2861 .57268 .28439 .57011 .28121 Mtetra
.57011 .28121 .57268 .28439 .5776 .28267 .57504 .27949 Mtetra
.57504 .27949 .5776 .28267 .58254 .28095 .57998 .27776 Mtetra
.57998 .27776 .58254 .28095 .58749 .27922 .58493 .27603 Mtetra
.58493 .27603 .58749 .27922 .59244 .2775 .58989 .2743 Mtetra
.58989 .2743 .59244 .2775 .5974 .27577 .59486 .27257 Mtetra
.59486 .27257 .5974 .27577 .60237 .27404 .59984 .27083 Mtetra
.59984 .27083 .60237 .27404 .60735 .2723 .60483 .26909 Mtetra
.60483 .26909 .60735 .2723 .61234 .27056 .60982 .26734 Mtetra
.60982 .26734 .61234 .27056 .61734 .26882 .61483 .2656 Mtetra
.61483 .2656 .61734 .26882 .62235 .26707 .61984 .26384 Mtetra
.61984 .26384 .62235 .26707 .62737 .26533 .62486 .26209 Mtetra
.62486 .26209 .62737 .26533 .63239 .26358 .62989 .26033 Mtetra
.62989 .26033 .63239 .26358 .63743 .26182 .63493 .25857 Mtetra
.63493 .25857 .63743 .26182 .64247 .26006 .63998 .25681 Mtetra
.63998 .25681 .64247 .26006 .64752 .2583 .64504 .25504 Mtetra
.64504 .25504 .64752 .2583 .65258 .25654 .65011 .25327 Mtetra
.65011 .25327 .65258 .25654 .65765 .25477 .65519 .2515 Mtetra
.65519 .2515 .65765 .25477 .66273 .253 .66027 .24972 Mtetra
.66027 .24972 .66273 .253 .66782 .25123 .66537 .24795 Mtetra
.66537 .24795 .66782 .25123 .67292 .24945 .67047 .24616 Mtetra
.67047 .24616 .67292 .24945 .67803 .24767 .67558 .24438 Mtetra
.67558 .24438 .67803 .24767 .68314 .24589 .68071 .24259 Mtetra
.68071 .24259 .68314 .24589 .68827 .2441 .68584 .2408 Mtetra
.68584 .2408 .68827 .2441 .6934 .24231 .69098 .239 Mtetra
.69098 .239 .6934 .24231 .69855 .24052 .69613 .2372 Mtetra
.69613 .2372 .69855 .24052 .7037 .23872 .70129 .2354 Mtetra
.70129 .2354 .7037 .23872 .70887 .23692 .70646 .23359 Mtetra
.70646 .23359 .70887 .23692 .71404 .23512 .71164 .23178 Mtetra
.71164 .23178 .71404 .23512 .71922 .23332 .71683 .22997 Mtetra
.71683 .22997 .71922 .23332 .72441 .23151 .72203 .22816 Mtetra
.653 .755 .925 r
.03826 .42697 .04134 .42959 .04532 .42817 .04225 .42554 Mtetra
.04225 .42554 .04532 .42817 .04931 .42675 .04624 .42411 Mtetra
.04624 .42411 .04931 .42675 .05331 .42532 .05024 .42268 Mtetra
.05024 .42268 .05331 .42532 .05731 .42389 .05425 .42125 Mtetra
.05425 .42125 .05731 .42389 .06133 .42246 .05826 .41982 Mtetra
.05826 .41982 .06133 .42246 .06534 .42103 .06229 .41838 Mtetra
.06229 .41838 .06534 .42103 .06937 .4196 .06631 .41694 Mtetra
.06631 .41694 .06937 .4196 .0734 .41816 .07035 .4155 Mtetra
.07035 .4155 .0734 .41816 .07743 .41672 .07439 .41406 Mtetra
.07439 .41406 .07743 .41672 .08148 .41528 .07843 .41262 Mtetra
.07843 .41262 .08148 .41528 .08553 .41384 .08249 .41117 Mtetra
.08249 .41117 .08553 .41384 .08958 .41239 .08655 .40972 Mtetra
.08655 .40972 .08958 .41239 .09364 .41094 .09061 .40826 Mtetra
.09061 .40826 .09364 .41094 .09771 .40949 .09468 .40681 Mtetra
.09468 .40681 .09771 .40949 .10179 .40804 .09876 .40535 Mtetra
.09876 .40535 .10179 .40804 .10587 .40659 .10285 .40389 Mtetra
.10285 .40389 .10587 .40659 .10996 .40513 .10694 .40243 Mtetra
.10694 .40243 .10996 .40513 .11406 .40367 .11104 .40097 Mtetra
.11104 .40097 .11406 .40367 .11816 .40221 .11515 .3995 Mtetra
.11515 .3995 .11816 .40221 .12227 .40074 .11926 .39803 Mtetra
.11926 .39803 .12227 .40074 .12638 .39927 .12338 .39656 Mtetra
.12338 .39656 .12638 .39927 .1305 .39781 .1275 .39509 Mtetra
.949 .647 .428 r
.1275 .39509 .1305 .39781 .13063 .42936 .12759 .42666 Mtetra
.65 .758 .928 r
.12759 .42666 .13063 .42936 .1348 .4279 .13177 .42519 Mtetra
.13177 .42519 .1348 .4279 .13898 .42643 .13596 .42372 Mtetra
.13596 .42372 .13898 .42643 .14317 .42497 .14015 .42225 Mtetra
.14015 .42225 .14317 .42497 .14737 .4235 .14435 .42078 Mtetra
.14435 .42078 .14737 .4235 .15157 .42202 .14855 .4193 Mtetra
.14855 .4193 .15157 .42202 .15578 .42055 .15277 .41782 Mtetra
.15277 .41782 .15578 .42055 .15999 .41907 .15699 .41634 Mtetra
.15699 .41634 .15999 .41907 .16421 .41759 .16121 .41486 Mtetra
.16121 .41486 .16421 .41759 .16844 .41611 .16545 .41337 Mtetra
.16545 .41337 .16844 .41611 .17268 .41463 .16969 .41188 Mtetra
.16969 .41188 .17268 .41463 .17692 .41314 .17393 .41039 Mtetra
.17393 .41039 .17692 .41314 .18117 .41165 .17819 .4089 Mtetra
.17819 .4089 .18117 .41165 .18543 .41016 .18245 .4074 Mtetra
.18245 .4074 .18543 .41016 .1897 .40867 .18672 .4059 Mtetra
.18672 .4059 .1897 .40867 .19397 .40717 .19099 .4044 Mtetra
.19099 .4044 .19397 .40717 .19825 .40567 .19528 .4029 Mtetra
.19528 .4029 .19825 .40567 .20253 .40417 .19957 .40139 Mtetra
.19957 .40139 .20253 .40417 .20682 .40267 .20386 .39989 Mtetra
.20386 .39989 .20682 .40267 .21112 .40116 .20817 .39838 Mtetra
.20817 .39838 .21112 .40116 .21543 .39965 .21248 .39686 Mtetra
.21248 .39686 .21543 .39965 .21974 .39814 .2168 .39535 Mtetra
.2168 .39535 .21974 .39814 .22407 .39663 .22112 .39383 Mtetra
.22112 .39383 .22407 .39663 .22839 .39511 .22545 .39231 Mtetra
.22545 .39231 .22839 .39511 .23273 .39359 .22979 .39078 Mtetra
.22979 .39078 .23273 .39359 .23707 .39207 .23414 .38926 Mtetra
.23414 .38926 .23707 .39207 .24142 .39055 .2385 .38773 Mtetra
.2385 .38773 .24142 .39055 .24578 .38902 .24286 .3862 Mtetra
.24286 .3862 .24578 .38902 .2558 .32147 .24723 .38466 Mtetra
0 0 .045 r
.24723 .38466 .2558 .32147 .26008 .31992 .25724 .31704 Mtetra
.655 .752 .921 r
.25724 .31704 .26008 .31992 .26438 .31836 .26154 .31548 Mtetra
.26154 .31548 .26438 .31836 .26868 .3168 .26584 .31392 Mtetra
.96 .666 .431 r
.26584 .31392 .26868 .3168 .27299 .31524 .26478 .3785 Mtetra
.486 .231 .453 r
.26478 .3785 .27299 .31524 .27208 .37981 .26918 .37696 Mtetra
.65 .758 .928 r
.26918 .37696 .27208 .37981 .27649 .37827 .2736 .37541 Mtetra
.2736 .37541 .27649 .37827 .28091 .37672 .27802 .37386 Mtetra
.27802 .37386 .28091 .37672 .28533 .37517 .28245 .3723 Mtetra
.28245 .3723 .28533 .37517 .28976 .37362 .28688 .37075 Mtetra
.28688 .37075 .28976 .37362 .2942 .37206 .29132 .36919 Mtetra
.29132 .36919 .2942 .37206 .29865 .37051 .29577 .36762 Mtetra
.29577 .36762 .29865 .37051 .3031 .36895 .30023 .36606 Mtetra
.30023 .36606 .3031 .36895 .30756 .36738 .3047 .36449 Mtetra
.3047 .36449 .30756 .36738 .31203 .36582 .30917 .36292 Mtetra
.30917 .36292 .31203 .36582 .31651 .36425 .31365 .36135 Mtetra
.31365 .36135 .31651 .36425 .32099 .36268 .31814 .35977 Mtetra
.31814 .35977 .32099 .36268 .32548 .36111 .32264 .35819 Mtetra
.32264 .35819 .32548 .36111 .32998 .35953 .32714 .35661 Mtetra
.32714 .35661 .32998 .35953 .33449 .35795 .33165 .35503 Mtetra
.33165 .35503 .33449 .35795 .339 .35637 .33617 .35344 Mtetra
.33617 .35344 .339 .35637 .34352 .35479 .3407 .35185 Mtetra
.3407 .35185 .34352 .35479 .34805 .3532 .34523 .35026 Mtetra
.34523 .35026 .34805 .3532 .35259 .35161 .34978 .34867 Mtetra
.34978 .34867 .35259 .35161 .35714 .35002 .35433 .34707 Mtetra
.35433 .34707 .35714 .35002 .36169 .34842 .35888 .34547 Mtetra
.35888 .34547 .36169 .34842 .36625 .34683 .36345 .34387 Mtetra
.36345 .34387 .36625 .34683 .37082 .34523 .36802 .34226 Mtetra
.36802 .34226 .37082 .34523 .3754 .34362 .3726 .34066 Mtetra
.3726 .34066 .3754 .34362 .37998 .34202 .37719 .33904 Mtetra
.37719 .33904 .37998 .34202 .38457 .34041 .38179 .33743 Mtetra
.38179 .33743 .38457 .34041 .38917 .3388 .3864 .33581 Mtetra
.3864 .33581 .38917 .3388 .39378 .33718 .39101 .3342 Mtetra
.39101 .3342 .39378 .33718 .3984 .33557 .39563 .33257 Mtetra
.39563 .33257 .3984 .33557 .40302 .33395 .40026 .33095 Mtetra
.40026 .33095 .40302 .33395 .40765 .33232 .4049 .32932 Mtetra
.4049 .32932 .40765 .33232 .41229 .3307 .40954 .32769 Mtetra
.40954 .32769 .41229 .3307 .41694 .32907 .41419 .32606 Mtetra
.41419 .32606 .41694 .32907 .4216 .32744 .41885 .32442 Mtetra
.41885 .32442 .4216 .32744 .42626 .32581 .42352 .32278 Mtetra
.42352 .32278 .42626 .32581 .43093 .32417 .4282 .32114 Mtetra
.4282 .32114 .43093 .32417 .43561 .32253 .43288 .3195 Mtetra
.43288 .3195 .43561 .32253 .4403 .32089 .43758 .31785 Mtetra
.43758 .31785 .4403 .32089 .445 .31924 .44228 .3162 Mtetra
.44228 .3162 .445 .31924 .4497 .3176 .44699 .31455 Mtetra
.44699 .31455 .4497 .3176 .45441 .31594 .45171 .31289 Mtetra
.45171 .31289 .45441 .31594 .45913 .31429 .45643 .31123 Mtetra
.45643 .31123 .45913 .31429 .46386 .31263 .46117 .30957 Mtetra
.46117 .30957 .46386 .31263 .4686 .31098 .46591 .3079 Mtetra
.46591 .3079 .4686 .31098 .47335 .30931 .47066 .30624 Mtetra
.47066 .30624 .47335 .30931 .4781 .30765 .47542 .30457 Mtetra
.47542 .30457 .4781 .30765 .48286 .30598 .48019 .30289 Mtetra
.48019 .30289 .48286 .30598 .48763 .30431 .48496 .30122 Mtetra
.48496 .30122 .48763 .30431 .49241 .30263 .48975 .29954 Mtetra
.48975 .29954 .49241 .30263 .4972 .30096 .49454 .29785 Mtetra
0 .126 .644 r
.49454 .29785 .4972 .30096 .50195 .30502 .49929 .30191 Mtetra
.649 .759 .929 r
.49929 .30191 .50195 .30502 .50676 .30333 .50411 .30022 Mtetra
.50411 .30022 .50676 .30333 .51158 .30165 .50894 .29853 Mtetra
.50894 .29853 .51158 .30165 .51641 .29996 .51377 .29684 Mtetra
.51377 .29684 .51641 .29996 .52125 .29827 .51862 .29515 Mtetra
.51862 .29515 .52125 .29827 .5261 .29658 .52347 .29345 Mtetra
.52347 .29345 .5261 .29658 .53095 .29489 .52833 .29175 Mtetra
.52833 .29175 .53095 .29489 .53582 .29319 .5332 .29004 Mtetra
.5332 .29004 .53582 .29319 .54069 .29149 .53808 .28834 Mtetra
.53808 .28834 .54069 .29149 .54557 .28978 .54297 .28663 Mtetra
.54297 .28663 .54557 .28978 .55046 .28807 .54786 .28491 Mtetra
.54786 .28491 .55046 .28807 .55536 .28636 .55276 .2832 Mtetra
.55276 .2832 .55536 .28636 .56027 .28465 .55768 .28148 Mtetra
.55768 .28148 .56027 .28465 .56518 .28293 .5626 .27975 Mtetra
.5626 .27975 .56518 .28293 .57011 .28121 .56753 .27803 Mtetra
.56753 .27803 .57011 .28121 .57504 .27949 .57247 .2763 Mtetra
.57247 .2763 .57504 .27949 .57998 .27776 .57742 .27457 Mtetra
.57742 .27457 .57998 .27776 .58493 .27603 .58237 .27283 Mtetra
.58237 .27283 .58493 .27603 .58989 .2743 .58734 .2711 Mtetra
.58734 .2711 .58989 .2743 .59486 .27257 .59231 .26936 Mtetra
.59231 .26936 .59486 .27257 .59984 .27083 .5973 .26761 Mtetra
.5973 .26761 .59984 .27083 .60483 .26909 .60229 .26586 Mtetra
.60229 .26586 .60483 .26909 .60982 .26734 .60729 .26411 Mtetra
.60729 .26411 .60982 .26734 .61483 .2656 .6123 .26236 Mtetra
.6123 .26236 .61483 .2656 .61984 .26384 .61732 .2606 Mtetra
.61732 .2606 .61984 .26384 .62486 .26209 .62235 .25884 Mtetra
.62235 .25884 .62486 .26209 .62989 .26033 .62739 .25708 Mtetra
.62739 .25708 .62989 .26033 .63493 .25857 .63243 .25532 Mtetra
.63243 .25532 .63493 .25857 .63998 .25681 .63749 .25355 Mtetra
.63749 .25355 .63998 .25681 .64504 .25504 .64255 .25177 Mtetra
.64255 .25177 .64504 .25504 .65011 .25327 .64763 .25 Mtetra
.64763 .25 .65011 .25327 .65519 .2515 .65271 .24822 Mtetra
.65271 .24822 .65519 .2515 .66027 .24972 .6578 .24644 Mtetra
.6578 .24644 .66027 .24972 .66537 .24795 .6629 .24465 Mtetra
.6629 .24465 .66537 .24795 .67047 .24616 .66801 .24286 Mtetra
.66801 .24286 .67047 .24616 .67558 .24438 .67313 .24107 Mtetra
.67313 .24107 .67558 .24438 .68071 .24259 .67826 .23928 Mtetra
.67826 .23928 .68071 .24259 .68584 .2408 .6834 .23748 Mtetra
.6834 .23748 .68584 .2408 .69098 .239 .68855 .23568 Mtetra
.68855 .23568 .69098 .239 .69613 .2372 .69371 .23387 Mtetra
.69371 .23387 .69613 .2372 .70129 .2354 .69887 .23206 Mtetra
.69887 .23206 .70129 .2354 .70646 .23359 .70405 .23025 Mtetra
.70405 .23025 .70646 .23359 .71164 .23178 .70924 .22844 Mtetra
.70924 .22844 .71164 .23178 .71683 .22997 .71443 .22662 Mtetra
.71443 .22662 .71683 .22997 .72203 .22816 .71963 .2248 Mtetra
.653 .755 .925 r
.03517 .42433 .03826 .42697 .04225 .42554 .03916 .4229 Mtetra
.03916 .4229 .04225 .42554 .04624 .42411 .04316 .42147 Mtetra
.04316 .42147 .04624 .42411 .05024 .42268 .04717 .42004 Mtetra
.04717 .42004 .05024 .42268 .05425 .42125 .05118 .4186 Mtetra
.05118 .4186 .05425 .42125 .05826 .41982 .05519 .41717 Mtetra
.05519 .41717 .05826 .41982 .06229 .41838 .05922 .41573 Mtetra
.05922 .41573 .06229 .41838 .06631 .41694 .06325 .41428 Mtetra
.06325 .41428 .06631 .41694 .07035 .4155 .06729 .41284 Mtetra
.06729 .41284 .07035 .4155 .07439 .41406 .07133 .41139 Mtetra
.07133 .41139 .07439 .41406 .07843 .41262 .07538 .40994 Mtetra
.07538 .40994 .07843 .41262 .08249 .41117 .07944 .40849 Mtetra
.07944 .40849 .08249 .41117 .08655 .40972 .0835 .40703 Mtetra
.0835 .40703 .08655 .40972 .09061 .40826 .08757 .40558 Mtetra
.08757 .40558 .09061 .40826 .09468 .40681 .09165 .40412 Mtetra
.09165 .40412 .09468 .40681 .09876 .40535 .09573 .40266 Mtetra
.09573 .40266 .09876 .40535 .10285 .40389 .09982 .40119 Mtetra
.09982 .40119 .10285 .40389 .10694 .40243 .10391 .39973 Mtetra
.10391 .39973 .10694 .40243 .11104 .40097 .10802 .39826 Mtetra
.10802 .39826 .11104 .40097 .11515 .3995 .11213 .39679 Mtetra
.11213 .39679 .11515 .3995 .11926 .39803 .11624 .39531 Mtetra
.11624 .39531 .11926 .39803 .12338 .39656 .12036 .39384 Mtetra
.12036 .39384 .12338 .39656 .1275 .39509 .12449 .39236 Mtetra
.949 .647 .428 r
.12449 .39236 .1275 .39509 .12759 .42666 .12455 .42395 Mtetra
.65 .758 .928 r
.12455 .42395 .12759 .42666 .13177 .42519 .12873 .42248 Mtetra
.12873 .42248 .13177 .42519 .13596 .42372 .13292 .421 Mtetra
.13292 .421 .13596 .42372 .14015 .42225 .13712 .41953 Mtetra
.13712 .41953 .14015 .42225 .14435 .42078 .14132 .41805 Mtetra
.14132 .41805 .14435 .42078 .14855 .4193 .14553 .41657 Mtetra
.14553 .41657 .14855 .4193 .15277 .41782 .14975 .41509 Mtetra
.14975 .41509 .15277 .41782 .15699 .41634 .15397 .4136 Mtetra
.15397 .4136 .15699 .41634 .16121 .41486 .1582 .41211 Mtetra
.1582 .41211 .16121 .41486 .16545 .41337 .16244 .41062 Mtetra
.16244 .41062 .16545 .41337 .16969 .41188 .16668 .40913 Mtetra
.16668 .40913 .16969 .41188 .17393 .41039 .17093 .40763 Mtetra
.17093 .40763 .17393 .41039 .17819 .4089 .17519 .40614 Mtetra
.17519 .40614 .17819 .4089 .18245 .4074 .17946 .40463 Mtetra
.17946 .40463 .18245 .4074 .18672 .4059 .18373 .40313 Mtetra
.18373 .40313 .18672 .4059 .19099 .4044 .18801 .40163 Mtetra
.18801 .40163 .19099 .4044 .19528 .4029 .1923 .40012 Mtetra
.1923 .40012 .19528 .4029 .19957 .40139 .19659 .39861 Mtetra
.19659 .39861 .19957 .40139 .20386 .39989 .20089 .3971 Mtetra
.20089 .3971 .20386 .39989 .20817 .39838 .2052 .39558 Mtetra
.2052 .39558 .20817 .39838 .21248 .39686 .20952 .39406 Mtetra
.20952 .39406 .21248 .39686 .2168 .39535 .21384 .39254 Mtetra
.21384 .39254 .2168 .39535 .22112 .39383 .21817 .39102 Mtetra
.21817 .39102 .22112 .39383 .22545 .39231 .2225 .38949 Mtetra
.2225 .38949 .22545 .39231 .22979 .39078 .22685 .38796 Mtetra
.22685 .38796 .22979 .39078 .23414 .38926 .2312 .38643 Mtetra
.2312 .38643 .23414 .38926 .2385 .38773 .23556 .3849 Mtetra
.23556 .3849 .2385 .38773 .24286 .3862 .23993 .38337 Mtetra
.23993 .38337 .24286 .3862 .24723 .38466 .2443 .38183 Mtetra
.2443 .38183 .24723 .38466 .25724 .31704 .24868 .38029 Mtetra
0 0 .045 r
.24868 .38029 .25724 .31704 .26154 .31548 .25868 .31259 Mtetra
.96 .666 .433 r
.25868 .31259 .26154 .31548 .26584 .31392 .25746 .3772 Mtetra
.485 .23 .452 r
.25746 .3772 .26584 .31392 .26478 .3785 .26187 .37565 Mtetra
.65 .758 .928 r
.26187 .37565 .26478 .3785 .26918 .37696 .26628 .3741 Mtetra
.26628 .3741 .26918 .37696 .2736 .37541 .27069 .37254 Mtetra
.27069 .37254 .2736 .37541 .27802 .37386 .27512 .37099 Mtetra
.27512 .37099 .27802 .37386 .28245 .3723 .27955 .36943 Mtetra
.27955 .36943 .28245 .3723 .28688 .37075 .28399 .36786 Mtetra
.28399 .36786 .28688 .37075 .29132 .36919 .28844 .3663 Mtetra
.28844 .3663 .29132 .36919 .29577 .36762 .2929 .36473 Mtetra
.2929 .36473 .29577 .36762 .30023 .36606 .29736 .36316 Mtetra
.29736 .36316 .30023 .36606 .3047 .36449 .30183 .36159 Mtetra
.30183 .36159 .3047 .36449 .30917 .36292 .30631 .36002 Mtetra
.30631 .36002 .30917 .36292 .31365 .36135 .31079 .35844 Mtetra
.31079 .35844 .31365 .36135 .31814 .35977 .31528 .35686 Mtetra
.31528 .35686 .31814 .35977 .32264 .35819 .31979 .35527 Mtetra
.31979 .35527 .32264 .35819 .32714 .35661 .32429 .35369 Mtetra
.32429 .35369 .32714 .35661 .33165 .35503 .32881 .3521 Mtetra
.32881 .3521 .33165 .35503 .33617 .35344 .33333 .35051 Mtetra
.33333 .35051 .33617 .35344 .3407 .35185 .33787 .34891 Mtetra
.33787 .34891 .3407 .35185 .34523 .35026 .3424 .34732 Mtetra
.3424 .34732 .34523 .35026 .34978 .34867 .34695 .34572 Mtetra
.34695 .34572 .34978 .34867 .35433 .34707 .35151 .34412 Mtetra
.35151 .34412 .35433 .34707 .35888 .34547 .35607 .34251 Mtetra
.35607 .34251 .35888 .34547 .36345 .34387 .36064 .3409 Mtetra
.36064 .3409 .36345 .34387 .36802 .34226 .36522 .33929 Mtetra
.36522 .33929 .36802 .34226 .3726 .34066 .3698 .33768 Mtetra
.3698 .33768 .3726 .34066 .37719 .33904 .3744 .33606 Mtetra
.3744 .33606 .37719 .33904 .38179 .33743 .379 .33444 Mtetra
.379 .33444 .38179 .33743 .3864 .33581 .38361 .33282 Mtetra
.38361 .33282 .3864 .33581 .39101 .3342 .38823 .3312 Mtetra
.38823 .3312 .39101 .3342 .39563 .33257 .39285 .32957 Mtetra
.39285 .32957 .39563 .33257 .40026 .33095 .39749 .32794 Mtetra
.39749 .32794 .40026 .33095 .4049 .32932 .40213 .32631 Mtetra
.40213 .32631 .4049 .32932 .40954 .32769 .40678 .32467 Mtetra
.40678 .32467 .40954 .32769 .41419 .32606 .41144 .32303 Mtetra
.41144 .32303 .41419 .32606 .41885 .32442 .4161 .32139 Mtetra
.4161 .32139 .41885 .32442 .42352 .32278 .42078 .31975 Mtetra
.42078 .31975 .42352 .32278 .4282 .32114 .42546 .3181 Mtetra
.42546 .3181 .4282 .32114 .43288 .3195 .43015 .31645 Mtetra
.43015 .31645 .43288 .3195 .43758 .31785 .43485 .3148 Mtetra
.43485 .3148 .43758 .31785 .44228 .3162 .43956 .31314 Mtetra
.43956 .31314 .44228 .3162 .44699 .31455 .44427 .31149 Mtetra
.44427 .31149 .44699 .31455 .45171 .31289 .44899 .30982 Mtetra
.44899 .30982 .45171 .31289 .45643 .31123 .45372 .30816 Mtetra
.45372 .30816 .45643 .31123 .46117 .30957 .45846 .30649 Mtetra
.45846 .30649 .46117 .30957 .46591 .3079 .46321 .30482 Mtetra
.46321 .30482 .46591 .3079 .47066 .30624 .46797 .30315 Mtetra
.46797 .30315 .47066 .30624 .47542 .30457 .47273 .30147 Mtetra
.47273 .30147 .47542 .30457 .48019 .30289 .4775 .2998 Mtetra
.4775 .2998 .48019 .30289 .48496 .30122 .48229 .29811 Mtetra
.48229 .29811 .48496 .30122 .48975 .29954 .48708 .29643 Mtetra
.48708 .29643 .48975 .29954 .49454 .29785 .49187 .29474 Mtetra
0 .126 .644 r
.49187 .29474 .49454 .29785 .49929 .30191 .49663 .29879 Mtetra
.649 .759 .929 r
.49663 .29879 .49929 .30191 .50411 .30022 .50145 .2971 Mtetra
.50145 .2971 .50411 .30022 .50894 .29853 .50628 .29541 Mtetra
.50628 .29541 .50894 .29853 .51377 .29684 .51112 .29371 Mtetra
.51112 .29371 .51377 .29684 .51862 .29515 .51597 .29201 Mtetra
.51597 .29201 .51862 .29515 .52347 .29345 .52083 .29031 Mtetra
.52083 .29031 .52347 .29345 .52833 .29175 .5257 .2886 Mtetra
.5257 .2886 .52833 .29175 .5332 .29004 .53057 .28689 Mtetra
.53057 .28689 .5332 .29004 .53808 .28834 .53546 .28518 Mtetra
.53546 .28518 .53808 .28834 .54297 .28663 .54035 .28346 Mtetra
.54035 .28346 .54297 .28663 .54786 .28491 .54525 .28174 Mtetra
.54525 .28174 .54786 .28491 .55276 .2832 .55016 .28002 Mtetra
.55016 .28002 .55276 .2832 .55768 .28148 .55508 .2783 Mtetra
.55508 .2783 .55768 .28148 .5626 .27975 .56001 .27657 Mtetra
.56001 .27657 .5626 .27975 .56753 .27803 .56494 .27484 Mtetra
.56494 .27484 .56753 .27803 .57247 .2763 .56989 .2731 Mtetra
.56989 .2731 .57247 .2763 .57742 .27457 .57484 .27136 Mtetra
.57484 .27136 .57742 .27457 .58237 .27283 .5798 .26962 Mtetra
.5798 .26962 .58237 .27283 .58734 .2711 .58478 .26788 Mtetra
.58478 .26788 .58734 .2711 .59231 .26936 .58976 .26613 Mtetra
.58976 .26613 .59231 .26936 .5973 .26761 .59475 .26438 Mtetra
.59475 .26438 .5973 .26761 .60229 .26586 .59974 .26263 Mtetra
.59974 .26263 .60229 .26586 .60729 .26411 .60475 .26087 Mtetra
.60475 .26087 .60729 .26411 .6123 .26236 .60977 .25912 Mtetra
.60977 .25912 .6123 .26236 .61732 .2606 .61479 .25735 Mtetra
.61479 .25735 .61732 .2606 .62235 .25884 .61983 .25559 Mtetra
.61983 .25559 .62235 .25884 .62739 .25708 .62487 .25382 Mtetra
.62487 .25382 .62739 .25708 .63243 .25532 .62992 .25205 Mtetra
.62992 .25205 .63243 .25532 .63749 .25355 .63499 .25027 Mtetra
.63499 .25027 .63749 .25355 .64255 .25177 .64006 .24849 Mtetra
.64006 .24849 .64255 .25177 .64763 .25 .64514 .24671 Mtetra
.64514 .24671 .64763 .25 .65271 .24822 .65023 .24493 Mtetra
.65023 .24493 .65271 .24822 .6578 .24644 .65532 .24314 Mtetra
.65532 .24314 .6578 .24644 .6629 .24465 .66043 .24135 Mtetra
.66043 .24135 .6629 .24465 .66801 .24286 .66555 .23955 Mtetra
.66555 .23955 .66801 .24286 .67313 .24107 .67068 .23775 Mtetra
.67068 .23775 .67313 .24107 .67826 .23928 .67581 .23595 Mtetra
.67581 .23595 .67826 .23928 .6834 .23748 .68096 .23415 Mtetra
.68096 .23415 .6834 .23748 .68855 .23568 .68611 .23234 Mtetra
.68611 .23234 .68855 .23568 .69371 .23387 .69127 .23053 Mtetra
.69127 .23053 .69371 .23387 .69887 .23206 .69645 .22872 Mtetra
.69645 .22872 .69887 .23206 .70405 .23025 .70163 .2269 Mtetra
.70163 .2269 .70405 .23025 .70924 .22844 .70682 .22508 Mtetra
.70682 .22508 .70924 .22844 .71443 .22662 .71202 .22325 Mtetra
.71202 .22325 .71443 .22662 .71963 .2248 .71723 .22143 Mtetra
.653 .755 .925 r
.03207 .42169 .03517 .42433 .03916 .4229 .03607 .42026 Mtetra
.03607 .42026 .03916 .4229 .04316 .42147 .04007 .41883 Mtetra
.04007 .41883 .04316 .42147 .04717 .42004 .04408 .41739 Mtetra
.04408 .41739 .04717 .42004 .05118 .4186 .04809 .41595 Mtetra
.04809 .41595 .05118 .4186 .05519 .41717 .05212 .4145 Mtetra
.05212 .4145 .05519 .41717 .05922 .41573 .05614 .41306 Mtetra
.05614 .41306 .05922 .41573 .06325 .41428 .06018 .41161 Mtetra
.06018 .41161 .06325 .41428 .06729 .41284 .06422 .41016 Mtetra
.06422 .41016 .06729 .41284 .07133 .41139 .06827 .40871 Mtetra
.06827 .40871 .07133 .41139 .07538 .40994 .07232 .40726 Mtetra
.07232 .40726 .07538 .40994 .07944 .40849 .07638 .4058 Mtetra
.07638 .4058 .07944 .40849 .0835 .40703 .08045 .40434 Mtetra
.08045 .40434 .0835 .40703 .08757 .40558 .08452 .40288 Mtetra
.08452 .40288 .08757 .40558 .09165 .40412 .0886 .40142 Mtetra
.0886 .40142 .09165 .40412 .09573 .40266 .09269 .39995 Mtetra
.09269 .39995 .09573 .40266 .09982 .40119 .09678 .39848 Mtetra
.09678 .39848 .09982 .40119 .10391 .39973 .10088 .39701 Mtetra
.10088 .39701 .10391 .39973 .10802 .39826 .10498 .39554 Mtetra
.10498 .39554 .10802 .39826 .11213 .39679 .1091 .39407 Mtetra
.1091 .39407 .11213 .39679 .11624 .39531 .11322 .39259 Mtetra
.11322 .39259 .11624 .39531 .12036 .39384 .11734 .39111 Mtetra
.11734 .39111 .12036 .39384 .12449 .39236 .12148 .38962 Mtetra
.949 .647 .428 r
.12148 .38962 .12449 .39236 .12455 .42395 .1215 .42123 Mtetra
.65 .758 .928 r
.1215 .42123 .12455 .42395 .12873 .42248 .12569 .41976 Mtetra
.12569 .41976 .12873 .42248 .13292 .421 .12988 .41828 Mtetra
.12988 .41828 .13292 .421 .13712 .41953 .13408 .4168 Mtetra
.13408 .4168 .13712 .41953 .14132 .41805 .13829 .41531 Mtetra
.13829 .41531 .14132 .41805 .14553 .41657 .1425 .41383 Mtetra
.1425 .41383 .14553 .41657 .14975 .41509 .14672 .41234 Mtetra
.14672 .41234 .14975 .41509 .15397 .4136 .15095 .41085 Mtetra
.15095 .41085 .15397 .4136 .1582 .41211 .15518 .40936 Mtetra
.15518 .40936 .1582 .41211 .16244 .41062 .15942 .40786 Mtetra
.15942 .40786 .16244 .41062 .16668 .40913 .16367 .40637 Mtetra
.16367 .40637 .16668 .40913 .17093 .40763 .16793 .40487 Mtetra
.16793 .40487 .17093 .40763 .17519 .40614 .17219 .40336 Mtetra
.17219 .40336 .17519 .40614 .17946 .40463 .17646 .40186 Mtetra
.17646 .40186 .17946 .40463 .18373 .40313 .18073 .40035 Mtetra
.18073 .40035 .18373 .40313 .18801 .40163 .18502 .39884 Mtetra
.18502 .39884 .18801 .40163 .1923 .40012 .18931 .39733 Mtetra
.18931 .39733 .1923 .40012 .19659 .39861 .19361 .39581 Mtetra
.19361 .39581 .19659 .39861 .20089 .3971 .19791 .3943 Mtetra
.19791 .3943 .20089 .3971 .2052 .39558 .20222 .39278 Mtetra
.20222 .39278 .2052 .39558 .20952 .39406 .20654 .39125 Mtetra
.20654 .39125 .20952 .39406 .21384 .39254 .21087 .38973 Mtetra
.21087 .38973 .21384 .39254 .21817 .39102 .2152 .3882 Mtetra
.2152 .3882 .21817 .39102 .2225 .38949 .21955 .38667 Mtetra
.21955 .38667 .2225 .38949 .22685 .38796 .22389 .38514 Mtetra
.22389 .38514 .22685 .38796 .2312 .38643 .22825 .3836 Mtetra
.22825 .3836 .2312 .38643 .23556 .3849 .23261 .38206 Mtetra
.23261 .38206 .23556 .3849 .23993 .38337 .23698 .38052 Mtetra
.23698 .38052 .23993 .38337 .2443 .38183 .24136 .37898 Mtetra
.24136 .37898 .2443 .38183 .24868 .38029 .24575 .37743 Mtetra
.24575 .37743 .24868 .38029 .25868 .31259 .25014 .37589 Mtetra
.484 .228 .451 r
.25014 .37589 .25868 .31259 .25746 .3772 .25454 .37433 Mtetra
.65 .758 .928 r
.25454 .37433 .25746 .3772 .26187 .37565 .25895 .37278 Mtetra
.25895 .37278 .26187 .37565 .26628 .3741 .26336 .37123 Mtetra
.26336 .37123 .26628 .3741 .27069 .37254 .26778 .36967 Mtetra
.26778 .36967 .27069 .37254 .27512 .37099 .27221 .3681 Mtetra
.27221 .3681 .27512 .37099 .27955 .36943 .27665 .36654 Mtetra
.27665 .36654 .27955 .36943 .28399 .36786 .28109 .36497 Mtetra
.28109 .36497 .28399 .36786 .28844 .3663 .28555 .3634 Mtetra
.28555 .3634 .28844 .3663 .2929 .36473 .29001 .36183 Mtetra
.29001 .36183 .2929 .36473 .29736 .36316 .29447 .36026 Mtetra
.29447 .36026 .29736 .36316 .30183 .36159 .29895 .35868 Mtetra
.29895 .35868 .30183 .36159 .30631 .36002 .30343 .3571 Mtetra
.30343 .3571 .30631 .36002 .31079 .35844 .30792 .35552 Mtetra
.30792 .35552 .31079 .35844 .31528 .35686 .31242 .35393 Mtetra
.31242 .35393 .31528 .35686 .31979 .35527 .31692 .35234 Mtetra
.31692 .35234 .31979 .35527 .32429 .35369 .32144 .35075 Mtetra
.32144 .35075 .32429 .35369 .32881 .3521 .32596 .34916 Mtetra
.32596 .34916 .32881 .3521 .33333 .35051 .33049 .34756 Mtetra
.33049 .34756 .33333 .35051 .33787 .34891 .33502 .34596 Mtetra
.33502 .34596 .33787 .34891 .3424 .34732 .33957 .34436 Mtetra
.33957 .34436 .3424 .34732 .34695 .34572 .34412 .34276 Mtetra
.34412 .34276 .34695 .34572 .35151 .34412 .34868 .34115 Mtetra
.34868 .34115 .35151 .34412 .35607 .34251 .35325 .33954 Mtetra
.35325 .33954 .35607 .34251 .36064 .3409 .35782 .33793 Mtetra
.35782 .33793 .36064 .3409 .36522 .33929 .3624 .33631 Mtetra
.3624 .33631 .36522 .33929 .3698 .33768 .367 .33469 Mtetra
.367 .33469 .3698 .33768 .3744 .33606 .37159 .33307 Mtetra
.37159 .33307 .3744 .33606 .379 .33444 .3762 .33145 Mtetra
.3762 .33145 .379 .33444 .38361 .33282 .38082 .32982 Mtetra
.38082 .32982 .38361 .33282 .38823 .3312 .38544 .32819 Mtetra
.38544 .32819 .38823 .3312 .39285 .32957 .39007 .32656 Mtetra
.39007 .32656 .39285 .32957 .39749 .32794 .39471 .32493 Mtetra
.39471 .32493 .39749 .32794 .40213 .32631 .39936 .32329 Mtetra
.39936 .32329 .40213 .32631 .40678 .32467 .40401 .32165 Mtetra
.40401 .32165 .40678 .32467 .41144 .32303 .40867 .32 Mtetra
.40867 .32 .41144 .32303 .4161 .32139 .41334 .31836 Mtetra
.41334 .31836 .4161 .32139 .42078 .31975 .41802 .31671 Mtetra
.41802 .31671 .42078 .31975 .42546 .3181 .42271 .31505 Mtetra
.42271 .31505 .42546 .3181 .43015 .31645 .42741 .3134 Mtetra
.42741 .3134 .43015 .31645 .43485 .3148 .43211 .31174 Mtetra
.43211 .31174 .43485 .3148 .43956 .31314 .43682 .31008 Mtetra
.43682 .31008 .43956 .31314 .44427 .31149 .44154 .30842 Mtetra
.44154 .30842 .44427 .31149 .44899 .30982 .44627 .30675 Mtetra
.44627 .30675 .44899 .30982 .45372 .30816 .45101 .30508 Mtetra
.45101 .30508 .45372 .30816 .45846 .30649 .45575 .30341 Mtetra
.45575 .30341 .45846 .30649 .46321 .30482 .4605 .30173 Mtetra
.4605 .30173 .46321 .30482 .46797 .30315 .46527 .30005 Mtetra
.46527 .30005 .46797 .30315 .47273 .30147 .47004 .29837 Mtetra
.47004 .29837 .47273 .30147 .4775 .2998 .47481 .29669 Mtetra
.47481 .29669 .4775 .2998 .48229 .29811 .4796 .295 Mtetra
.4796 .295 .48229 .29811 .48708 .29643 .4844 .29331 Mtetra
.4844 .29331 .48708 .29643 .49187 .29474 .4892 .29162 Mtetra
0 .126 .644 r
.4892 .29162 .49187 .29474 .49663 .29879 .49395 .29567 Mtetra
.649 .759 .929 r
.49395 .29567 .49663 .29879 .50145 .2971 .49878 .29397 Mtetra
.49878 .29397 .50145 .2971 .50628 .29541 .50362 .29227 Mtetra
.50362 .29227 .50628 .29541 .51112 .29371 .50847 .29057 Mtetra
.50847 .29057 .51112 .29371 .51597 .29201 .51332 .28886 Mtetra
.51332 .28886 .51597 .29201 .52083 .29031 .51819 .28715 Mtetra
.51819 .28715 .52083 .29031 .5257 .2886 .52306 .28544 Mtetra
.52306 .28544 .5257 .2886 .53057 .28689 .52794 .28373 Mtetra
.52794 .28373 .53057 .28689 .53546 .28518 .53283 .28201 Mtetra
.53283 .28201 .53546 .28518 .54035 .28346 .53773 .28029 Mtetra
.53773 .28029 .54035 .28346 .54525 .28174 .54263 .27856 Mtetra
.54263 .27856 .54525 .28174 .55016 .28002 .54755 .27683 Mtetra
.54755 .27683 .55016 .28002 .55508 .2783 .55247 .2751 Mtetra
.55247 .2751 .55508 .2783 .56001 .27657 .55741 .27337 Mtetra
.55741 .27337 .56001 .27657 .56494 .27484 .56235 .27163 Mtetra
.56235 .27163 .56494 .27484 .56989 .2731 .5673 .26989 Mtetra
.5673 .26989 .56989 .2731 .57484 .27136 .57226 .26815 Mtetra
.57226 .26815 .57484 .27136 .5798 .26962 .57723 .2664 Mtetra
.57723 .2664 .5798 .26962 .58478 .26788 .5822 .26465 Mtetra
.5822 .26465 .58478 .26788 .58976 .26613 .58719 .2629 Mtetra
.58719 .2629 .58976 .26613 .59475 .26438 .59219 .26115 Mtetra
.59219 .26115 .59475 .26438 .59974 .26263 .59719 .25939 Mtetra
.59719 .25939 .59974 .26263 .60475 .26087 .6022 .25762 Mtetra
.6022 .25762 .60475 .26087 .60977 .25912 .60723 .25586 Mtetra
.60723 .25586 .60977 .25912 .61479 .25735 .61226 .25409 Mtetra
.61226 .25409 .61479 .25735 .61983 .25559 .6173 .25232 Mtetra
.6173 .25232 .61983 .25559 .62487 .25382 .62235 .25054 Mtetra
.62235 .25054 .62487 .25382 .62992 .25205 .62741 .24877 Mtetra
.62741 .24877 .62992 .25205 .63499 .25027 .63247 .24699 Mtetra
.63247 .24699 .63499 .25027 .64006 .24849 .63755 .2452 Mtetra
.63755 .2452 .64006 .24849 .64514 .24671 .64264 .24341 Mtetra
.64264 .24341 .64514 .24671 .65023 .24493 .64773 .24162 Mtetra
.64773 .24162 .65023 .24493 .65532 .24314 .65284 .23983 Mtetra
.65284 .23983 .65532 .24314 .66043 .24135 .65795 .23803 Mtetra
.65795 .23803 .66043 .24135 .66555 .23955 .66308 .23623 Mtetra
.66308 .23623 .66555 .23955 .67068 .23775 .66821 .23443 Mtetra
.66821 .23443 .67068 .23775 .67581 .23595 .67335 .23262 Mtetra
.67335 .23262 .67581 .23595 .68096 .23415 .6785 .23081 Mtetra
.6785 .23081 .68096 .23415 .68611 .23234 .68366 .229 Mtetra
.68366 .229 .68611 .23234 .69127 .23053 .68883 .22718 Mtetra
.68883 .22718 .69127 .23053 .69645 .22872 .69401 .22536 Mtetra
.69401 .22536 .69645 .22872 .70163 .2269 .6992 .22353 Mtetra
.6992 .22353 .70163 .2269 .70682 .22508 .7044 .22171 Mtetra
.7044 .22171 .70682 .22508 .71202 .22325 .70961 .21988 Mtetra
.70961 .21988 .71202 .22325 .71723 .22143 .71483 .21804 Mtetra
.653 .755 .925 r
.02897 .41905 .03207 .42169 .03607 .42026 .03297 .41761 Mtetra
.03297 .41761 .03607 .42026 .04007 .41883 .03697 .41617 Mtetra
.03697 .41617 .04007 .41883 .04408 .41739 .04098 .41473 Mtetra
.04098 .41473 .04408 .41739 .04809 .41595 .045 .41328 Mtetra
.045 .41328 .04809 .41595 .05212 .4145 .04903 .41184 Mtetra
.04903 .41184 .05212 .4145 .05614 .41306 .05306 .41039 Mtetra
.05306 .41039 .05614 .41306 .06018 .41161 .0571 .40894 Mtetra
.0571 .40894 .06018 .41161 .06422 .41016 .06114 .40748 Mtetra
.06114 .40748 .06422 .41016 .06827 .40871 .06519 .40603 Mtetra
.06519 .40603 .06827 .40871 .07232 .40726 .06925 .40457 Mtetra
.06925 .40457 .07232 .40726 .07638 .4058 .07331 .40311 Mtetra
.07331 .40311 .07638 .4058 .08045 .40434 .07738 .40164 Mtetra
.07738 .40164 .08045 .40434 .08452 .40288 .08146 .40018 Mtetra
.08146 .40018 .08452 .40288 .0886 .40142 .08554 .39871 Mtetra
.08554 .39871 .0886 .40142 .09269 .39995 .08963 .39724 Mtetra
.08963 .39724 .09269 .39995 .09678 .39848 .09373 .39577 Mtetra
.09373 .39577 .09678 .39848 .10088 .39701 .09783 .39429 Mtetra
.09783 .39429 .10088 .39701 .10498 .39554 .10194 .39282 Mtetra
.10194 .39282 .10498 .39554 .1091 .39407 .10606 .39134 Mtetra
.10606 .39134 .1091 .39407 .11322 .39259 .11018 .38985 Mtetra
.11018 .38985 .11322 .39259 .11734 .39111 .11431 .38837 Mtetra
.11431 .38837 .11734 .39111 .12148 .38962 .11845 .38688 Mtetra
.949 .647 .428 r
.11845 .38688 .12148 .38962 .1215 .42123 .11844 .4185 Mtetra
.65 .758 .928 r
.11844 .4185 .1215 .42123 .12569 .41976 .12263 .41702 Mtetra
.12263 .41702 .12569 .41976 .12988 .41828 .12683 .41554 Mtetra
.12683 .41554 .12988 .41828 .13408 .4168 .13103 .41406 Mtetra
.13103 .41406 .13408 .4168 .13829 .41531 .13524 .41257 Mtetra
.13524 .41257 .13829 .41531 .1425 .41383 .13946 .41108 Mtetra
.13946 .41108 .1425 .41383 .14672 .41234 .14368 .40959 Mtetra
.14368 .40959 .14672 .41234 .15095 .41085 .14791 .40809 Mtetra
.14791 .40809 .15095 .41085 .15518 .40936 .15215 .4066 Mtetra
.15215 .4066 .15518 .40936 .15942 .40786 .1564 .4051 Mtetra
.1564 .4051 .15942 .40786 .16367 .40637 .16065 .40359 Mtetra
.16065 .40359 .16367 .40637 .16793 .40487 .16491 .40209 Mtetra
.16491 .40209 .16793 .40487 .17219 .40336 .16918 .40058 Mtetra
.16918 .40058 .17219 .40336 .17646 .40186 .17345 .39907 Mtetra
.17345 .39907 .17646 .40186 .18073 .40035 .17773 .39756 Mtetra
.17773 .39756 .18073 .40035 .18502 .39884 .18202 .39605 Mtetra
.18202 .39605 .18502 .39884 .18931 .39733 .18631 .39453 Mtetra
.18631 .39453 .18931 .39733 .19361 .39581 .19061 .39301 Mtetra
.19061 .39301 .19361 .39581 .19791 .3943 .19492 .39149 Mtetra
.19492 .39149 .19791 .3943 .20222 .39278 .19924 .38996 Mtetra
.19924 .38996 .20222 .39278 .20654 .39125 .20356 .38844 Mtetra
.20356 .38844 .20654 .39125 .21087 .38973 .20789 .38691 Mtetra
.20789 .38691 .21087 .38973 .2152 .3882 .21223 .38537 Mtetra
.21223 .38537 .2152 .3882 .21955 .38667 .21658 .38384 Mtetra
.21658 .38384 .21955 .38667 .22389 .38514 .22093 .3823 Mtetra
.22093 .3823 .22389 .38514 .22825 .3836 .22529 .38076 Mtetra
.22529 .38076 .22825 .3836 .23261 .38206 .22966 .37922 Mtetra
.22966 .37922 .23261 .38206 .23698 .38052 .23403 .37767 Mtetra
.23403 .37767 .23698 .38052 .24136 .37898 .23841 .37612 Mtetra
.23841 .37612 .24136 .37898 .24575 .37743 .2428 .37457 Mtetra
.2428 .37457 .24575 .37743 .25014 .37589 .2472 .37302 Mtetra
.2472 .37302 .25014 .37589 .25454 .37433 .25161 .37146 Mtetra
.25161 .37146 .25454 .37433 .25895 .37278 .25602 .36991 Mtetra
.25602 .36991 .25895 .37278 .26336 .37123 .26044 .36835 Mtetra
.26044 .36835 .26336 .37123 .26778 .36967 .26486 .36678 Mtetra
.26486 .36678 .26778 .36967 .27221 .3681 .2693 .36522 Mtetra
.2693 .36522 .27221 .3681 .27665 .36654 .27374 .36365 Mtetra
.27374 .36365 .27665 .36654 .28109 .36497 .27819 .36207 Mtetra
.27819 .36207 .28109 .36497 .28555 .3634 .28264 .3605 Mtetra
.28264 .3605 .28555 .3634 .29001 .36183 .28711 .35892 Mtetra
.28711 .35892 .29001 .36183 .29447 .36026 .29158 .35734 Mtetra
.29158 .35734 .29447 .36026 .29895 .35868 .29606 .35576 Mtetra
.29606 .35576 .29895 .35868 .30343 .3571 .30055 .35418 Mtetra
.30055 .35418 .30343 .3571 .30792 .35552 .30504 .35259 Mtetra
.30504 .35259 .30792 .35552 .31242 .35393 .30954 .351 Mtetra
.30954 .351 .31242 .35393 .31692 .35234 .31405 .3494 Mtetra
.31405 .3494 .31692 .35234 .32144 .35075 .31857 .34781 Mtetra
.31857 .34781 .32144 .35075 .32596 .34916 .3231 .34621 Mtetra
.3231 .34621 .32596 .34916 .33049 .34756 .32763 .34461 Mtetra
.32763 .34461 .33049 .34756 .33502 .34596 .33217 .343 Mtetra
.33217 .343 .33502 .34596 .33957 .34436 .33672 .3414 Mtetra
.33672 .3414 .33957 .34436 .34412 .34276 .34128 .33979 Mtetra
.34128 .33979 .34412 .34276 .34868 .34115 .34584 .33818 Mtetra
.34584 .33818 .34868 .34115 .35325 .33954 .35041 .33656 Mtetra
.35041 .33656 .35325 .33954 .35782 .33793 .35499 .33494 Mtetra
.35499 .33494 .35782 .33793 .3624 .33631 .35958 .33332 Mtetra
.35958 .33332 .3624 .33631 .367 .33469 .36418 .3317 Mtetra
.36418 .3317 .367 .33469 .37159 .33307 .36878 .33007 Mtetra
.36878 .33007 .37159 .33307 .3762 .33145 .37339 .32844 Mtetra
.37339 .32844 .3762 .33145 .38082 .32982 .37801 .32681 Mtetra
.37801 .32681 .38082 .32982 .38544 .32819 .38264 .32518 Mtetra
.38264 .32518 .38544 .32819 .39007 .32656 .38728 .32354 Mtetra
.38728 .32354 .39007 .32656 .39471 .32493 .39192 .3219 Mtetra
.39192 .3219 .39471 .32493 .39936 .32329 .39657 .32026 Mtetra
.39657 .32026 .39936 .32329 .40401 .32165 .40123 .31861 Mtetra
.40123 .31861 .40401 .32165 .40867 .32 .4059 .31696 Mtetra
.4059 .31696 .40867 .32 .41334 .31836 .41058 .31531 Mtetra
.41058 .31531 .41334 .31836 .41802 .31671 .41526 .31365 Mtetra
.41526 .31365 .41802 .31671 .42271 .31505 .41995 .312 Mtetra
.41995 .312 .42271 .31505 .42741 .3134 .42465 .31034 Mtetra
.42465 .31034 .42741 .3134 .43211 .31174 .42936 .30867 Mtetra
.42936 .30867 .43211 .31174 .43682 .31008 .43408 .30701 Mtetra
.43408 .30701 .43682 .31008 .44154 .30842 .4388 .30534 Mtetra
.4388 .30534 .44154 .30842 .44627 .30675 .44354 .30367 Mtetra
.44354 .30367 .44627 .30675 .45101 .30508 .44828 .30199 Mtetra
.44828 .30199 .45101 .30508 .45575 .30341 .45303 .30031 Mtetra
.45303 .30031 .45575 .30341 .4605 .30173 .45779 .29863 Mtetra
.45779 .29863 .4605 .30173 .46527 .30005 .46256 .29695 Mtetra
.46256 .29695 .46527 .30005 .47004 .29837 .46733 .29526 Mtetra
.46733 .29526 .47004 .29837 .47481 .29669 .47211 .29357 Mtetra
.47211 .29357 .47481 .29669 .4796 .295 .47691 .29188 Mtetra
.47691 .29188 .4796 .295 .4844 .29331 .48171 .29018 Mtetra
.48171 .29018 .4844 .29331 .4892 .29162 .48652 .28848 Mtetra
0 .126 .644 r
.48652 .28848 .4892 .29162 .49395 .29567 .49127 .29253 Mtetra
.649 .759 .929 r
.49127 .29253 .49395 .29567 .49878 .29397 .49611 .29083 Mtetra
.49611 .29083 .49878 .29397 .50362 .29227 .50095 .28912 Mtetra
.50095 .28912 .50362 .29227 .50847 .29057 .5058 .28742 Mtetra
.5058 .28742 .50847 .29057 .51332 .28886 .51066 .2857 Mtetra
.51066 .2857 .51332 .28886 .51819 .28715 .51553 .28399 Mtetra
.51553 .28399 .51819 .28715 .52306 .28544 .52041 .28227 Mtetra
.52041 .28227 .52306 .28544 .52794 .28373 .52529 .28055 Mtetra
.52529 .28055 .52794 .28373 .53283 .28201 .53019 .27883 Mtetra
.53019 .27883 .53283 .28201 .53773 .28029 .53509 .2771 Mtetra
.53509 .2771 .53773 .28029 .54263 .27856 .54001 .27537 Mtetra
.54001 .27537 .54263 .27856 .54755 .27683 .54493 .27364 Mtetra
.54493 .27364 .54755 .27683 .55247 .2751 .54986 .2719 Mtetra
.54986 .2719 .55247 .2751 .55741 .27337 .5548 .27016 Mtetra
.5548 .27016 .55741 .27337 .56235 .27163 .55974 .26842 Mtetra
.55974 .26842 .56235 .27163 .5673 .26989 .5647 .26667 Mtetra
.5647 .26667 .5673 .26989 .57226 .26815 .56967 .26492 Mtetra
.56967 .26492 .57226 .26815 .57723 .2664 .57464 .26317 Mtetra
.57464 .26317 .57723 .2664 .5822 .26465 .57962 .26142 Mtetra
.57962 .26142 .5822 .26465 .58719 .2629 .58462 .25966 Mtetra
.58462 .25966 .58719 .2629 .59219 .26115 .58962 .2579 Mtetra
.58962 .2579 .59219 .26115 .59719 .25939 .59463 .25613 Mtetra
.59463 .25613 .59719 .25939 .6022 .25762 .59965 .25436 Mtetra
.59965 .25436 .6022 .25762 .60723 .25586 .60468 .25259 Mtetra
.60468 .25259 .60723 .25586 .61226 .25409 .60971 .25082 Mtetra
.60971 .25082 .61226 .25409 .6173 .25232 .61476 .24904 Mtetra
.61476 .24904 .6173 .25232 .62235 .25054 .61982 .24726 Mtetra
.61982 .24726 .62235 .25054 .62741 .24877 .62488 .24548 Mtetra
.62488 .24548 .62741 .24877 .63247 .24699 .62996 .24369 Mtetra
.62996 .24369 .63247 .24699 .63755 .2452 .63504 .2419 Mtetra
.63504 .2419 .63755 .2452 .64264 .24341 .64013 .24011 Mtetra
.64013 .24011 .64264 .24341 .64773 .24162 .64523 .23831 Mtetra
.64523 .23831 .64773 .24162 .65284 .23983 .65034 .23651 Mtetra
.65034 .23651 .65284 .23983 .65795 .23803 .65546 .2347 Mtetra
.65546 .2347 .65795 .23803 .66308 .23623 .66059 .2329 Mtetra
.66059 .2329 .66308 .23623 .66821 .23443 .66573 .23109 Mtetra
.66573 .23109 .66821 .23443 .67335 .23262 .67088 .22927 Mtetra
.67088 .22927 .67335 .23262 .6785 .23081 .67604 .22746 Mtetra
.67604 .22746 .6785 .23081 .68366 .229 .68121 .22564 Mtetra
.68121 .22564 .68366 .229 .68883 .22718 .68638 .22382 Mtetra
.68638 .22382 .68883 .22718 .69401 .22536 .69157 .22199 Mtetra
.69157 .22199 .69401 .22536 .6992 .22353 .69676 .22016 Mtetra
.69676 .22016 .6992 .22353 .7044 .22171 .70197 .21833 Mtetra
.70197 .21833 .7044 .22171 .70961 .21988 .70718 .21649 Mtetra
.70718 .21649 .70961 .21988 .71483 .21804 .71241 .21465 Mtetra
.653 .755 .925 r
.02585 .41639 .02897 .41905 .03297 .41761 .02986 .41495 Mtetra
.02986 .41495 .03297 .41761 .03697 .41617 .03386 .4135 Mtetra
.03386 .4135 .03697 .41617 .04098 .41473 .03788 .41206 Mtetra
.03788 .41206 .04098 .41473 .045 .41328 .0419 .41061 Mtetra
.0419 .41061 .045 .41328 .04903 .41184 .04593 .40916 Mtetra
.04593 .40916 .04903 .41184 .05306 .41039 .04996 .40771 Mtetra
.04996 .40771 .05306 .41039 .0571 .40894 .05401 .40625 Mtetra
.05401 .40625 .0571 .40894 .06114 .40748 .05805 .40479 Mtetra
.05805 .40479 .06114 .40748 .06519 .40603 .06211 .40333 Mtetra
.06211 .40333 .06519 .40603 .06925 .40457 .06617 .40187 Mtetra
.06617 .40187 .06925 .40457 .07331 .40311 .07024 .4004 Mtetra
.07024 .4004 .07331 .40311 .07738 .40164 .07431 .39894 Mtetra
.07431 .39894 .07738 .40164 .08146 .40018 .07839 .39747 Mtetra
.07839 .39747 .08146 .40018 .08554 .39871 .08248 .39599 Mtetra
.08248 .39599 .08554 .39871 .08963 .39724 .08657 .39452 Mtetra
.08657 .39452 .08963 .39724 .09373 .39577 .09067 .39304 Mtetra
.09067 .39304 .09373 .39577 .09783 .39429 .09478 .39156 Mtetra
.09478 .39156 .09783 .39429 .10194 .39282 .09889 .39008 Mtetra
.09889 .39008 .10194 .39282 .10606 .39134 .10301 .3886 Mtetra
.10301 .3886 .10606 .39134 .11018 .38985 .10714 .38711 Mtetra
.10714 .38711 .11018 .38985 .11431 .38837 .11127 .38562 Mtetra
.11127 .38562 .11431 .38837 .11845 .38688 .11541 .38413 Mtetra
.949 .647 .428 r
.11541 .38413 .11845 .38688 .11844 .4185 .11537 .41577 Mtetra
.65 .758 .928 r
.11537 .41577 .11844 .4185 .12263 .41702 .11956 .41429 Mtetra
.11956 .41429 .12263 .41702 .12683 .41554 .12376 .4128 Mtetra
.12376 .4128 .12683 .41554 .13103 .41406 .12797 .41131 Mtetra
.12797 .41131 .13103 .41406 .13524 .41257 .13219 .40982 Mtetra
.13219 .40982 .13524 .41257 .13946 .41108 .13641 .40832 Mtetra
.13641 .40832 .13946 .41108 .14368 .40959 .14064 .40683 Mtetra
.14064 .40683 .14368 .40959 .14791 .40809 .14487 .40533 Mtetra
.14487 .40533 .14791 .40809 .15215 .4066 .14911 .40383 Mtetra
.14911 .40383 .15215 .4066 .1564 .4051 .15336 .40232 Mtetra
.15336 .40232 .1564 .4051 .16065 .40359 .15762 .40081 Mtetra
.15762 .40081 .16065 .40359 .16491 .40209 .16188 .39931 Mtetra
.16188 .39931 .16491 .40209 .16918 .40058 .16615 .39779 Mtetra
.16615 .39779 .16918 .40058 .17345 .39907 .17043 .39628 Mtetra
.17043 .39628 .17345 .39907 .17773 .39756 .17471 .39476 Mtetra
.17471 .39476 .17773 .39756 .18202 .39605 .17901 .39324 Mtetra
.17901 .39324 .18202 .39605 .18631 .39453 .18331 .39172 Mtetra
.18331 .39172 .18631 .39453 .19061 .39301 .18761 .3902 Mtetra
.18761 .3902 .19061 .39301 .19492 .39149 .19193 .38867 Mtetra
.19193 .38867 .19492 .39149 .19924 .38996 .19625 .38714 Mtetra
.19625 .38714 .19924 .38996 .20356 .38844 .20057 .38561 Mtetra
.20057 .38561 .20356 .38844 .20789 .38691 .20491 .38407 Mtetra
.20491 .38407 .20789 .38691 .21223 .38537 .20925 .38254 Mtetra
.20925 .38254 .21223 .38537 .21658 .38384 .2136 .381 Mtetra
.2136 .381 .21658 .38384 .22093 .3823 .21796 .37945 Mtetra
.21796 .37945 .22093 .3823 .22529 .38076 .22232 .37791 Mtetra
.22232 .37791 .22529 .38076 .22966 .37922 .22669 .37636 Mtetra
.22669 .37636 .22966 .37922 .23403 .37767 .23107 .37481 Mtetra
.23107 .37481 .23403 .37767 .23841 .37612 .23546 .37326 Mtetra
.23546 .37326 .23841 .37612 .2428 .37457 .23985 .3717 Mtetra
.23985 .3717 .2428 .37457 .2472 .37302 .24425 .37015 Mtetra
.24425 .37015 .2472 .37302 .25161 .37146 .24866 .36859 Mtetra
.24866 .36859 .25161 .37146 .25602 .36991 .25308 .36702 Mtetra
.25308 .36702 .25602 .36991 .26044 .36835 .2575 .36546 Mtetra
.2575 .36546 .26044 .36835 .26486 .36678 .26193 .36389 Mtetra
.26193 .36389 .26486 .36678 .2693 .36522 .26637 .36232 Mtetra
.26637 .36232 .2693 .36522 .27374 .36365 .27082 .36074 Mtetra
.27082 .36074 .27374 .36365 .27819 .36207 .27527 .35917 Mtetra
.27527 .35917 .27819 .36207 .28264 .3605 .27973 .35759 Mtetra
.27973 .35759 .28264 .3605 .28711 .35892 .2842 .356 Mtetra
.2842 .356 .28711 .35892 .29158 .35734 .28868 .35442 Mtetra
.28868 .35442 .29158 .35734 .29606 .35576 .29316 .35283 Mtetra
.29316 .35283 .29606 .35576 .30055 .35418 .29765 .35124 Mtetra
.29765 .35124 .30055 .35418 .30504 .35259 .30215 .34965 Mtetra
.30215 .34965 .30504 .35259 .30954 .351 .30666 .34805 Mtetra
.30666 .34805 .30954 .351 .31405 .3494 .31118 .34646 Mtetra
.31118 .34646 .31405 .3494 .31857 .34781 .3157 .34486 Mtetra
.3157 .34486 .31857 .34781 .3231 .34621 .32023 .34325 Mtetra
.32023 .34325 .3231 .34621 .32763 .34461 .32477 .34165 Mtetra
.32477 .34165 .32763 .34461 .33217 .343 .32931 .34004 Mtetra
.32931 .34004 .33217 .343 .33672 .3414 .33386 .33842 Mtetra
.33386 .33842 .33672 .3414 .34128 .33979 .33843 .33681 Mtetra
.33843 .33681 .34128 .33979 .34584 .33818 .343 .33519 Mtetra
.343 .33519 .34584 .33818 .35041 .33656 .34757 .33357 Mtetra
.34757 .33357 .35041 .33656 .35499 .33494 .35216 .33195 Mtetra
.35216 .33195 .35499 .33494 .35958 .33332 .35675 .33032 Mtetra
.35675 .33032 .35958 .33332 .36418 .3317 .36135 .32869 Mtetra
.36135 .32869 .36418 .3317 .36878 .33007 .36596 .32706 Mtetra
.36596 .32706 .36878 .33007 .37339 .32844 .37058 .32543 Mtetra
.37058 .32543 .37339 .32844 .37801 .32681 .3752 .32379 Mtetra
.3752 .32379 .37801 .32681 .38264 .32518 .37983 .32215 Mtetra
.37983 .32215 .38264 .32518 .38728 .32354 .38447 .32051 Mtetra
.38447 .32051 .38728 .32354 .39192 .3219 .38912 .31886 Mtetra
.38912 .31886 .39192 .3219 .39657 .32026 .39378 .31721 Mtetra
.39378 .31721 .39657 .32026 .40123 .31861 .39845 .31556 Mtetra
.39845 .31556 .40123 .31861 .4059 .31696 .40312 .31391 Mtetra
.40312 .31391 .4059 .31696 .41058 .31531 .4078 .31225 Mtetra
.4078 .31225 .41058 .31531 .41526 .31365 .41249 .31059 Mtetra
.41249 .31059 .41526 .31365 .41995 .312 .41719 .30893 Mtetra
.41719 .30893 .41995 .312 .42465 .31034 .42189 .30726 Mtetra
.42189 .30726 .42465 .31034 .42936 .30867 .42661 .30559 Mtetra
.42661 .30559 .42936 .30867 .43408 .30701 .43133 .30392 Mtetra
.43133 .30392 .43408 .30701 .4388 .30534 .43606 .30225 Mtetra
.43606 .30225 .4388 .30534 .44354 .30367 .4408 .30057 Mtetra
.4408 .30057 .44354 .30367 .44828 .30199 .44555 .29889 Mtetra
.44555 .29889 .44828 .30199 .45303 .30031 .4503 .29721 Mtetra
.4503 .29721 .45303 .30031 .45779 .29863 .45506 .29552 Mtetra
.45506 .29552 .45779 .29863 .46256 .29695 .45984 .29383 Mtetra
.45984 .29383 .46256 .29695 .46733 .29526 .46462 .29214 Mtetra
.46462 .29214 .46733 .29526 .47211 .29357 .46941 .29044 Mtetra
.46941 .29044 .47211 .29357 .47691 .29188 .4742 .28875 Mtetra
.4742 .28875 .47691 .29188 .48171 .29018 .47901 .28704 Mtetra
.47901 .28704 .48171 .29018 .48652 .28848 .48382 .28534 Mtetra
0 .126 .644 r
.48382 .28534 .48652 .28848 .49127 .29253 .48858 .28939 Mtetra
.649 .759 .929 r
.48858 .28939 .49127 .29253 .49611 .29083 .49342 .28768 Mtetra
.49342 .28768 .49611 .29083 .50095 .28912 .49827 .28597 Mtetra
.49827 .28597 .50095 .28912 .5058 .28742 .50313 .28425 Mtetra
.50313 .28425 .5058 .28742 .51066 .2857 .50799 .28254 Mtetra
.50799 .28254 .51066 .2857 .51553 .28399 .51287 .28082 Mtetra
.51287 .28082 .51553 .28399 .52041 .28227 .51775 .27909 Mtetra
.51775 .27909 .52041 .28227 .52529 .28055 .52264 .27737 Mtetra
.52264 .27737 .52529 .28055 .53019 .27883 .52754 .27564 Mtetra
.52754 .27564 .53019 .27883 .53509 .2771 .53245 .2739 Mtetra
.53245 .2739 .53509 .2771 .54001 .27537 .53737 .27217 Mtetra
.53737 .27217 .54001 .27537 .54493 .27364 .5423 .27043 Mtetra
.5423 .27043 .54493 .27364 .54986 .2719 .54723 .26869 Mtetra
.54723 .26869 .54986 .2719 .5548 .27016 .55218 .26694 Mtetra
.55218 .26694 .5548 .27016 .55974 .26842 .55713 .26519 Mtetra
.55713 .26519 .55974 .26842 .5647 .26667 .56209 .26344 Mtetra
.56209 .26344 .5647 .26667 .56967 .26492 .56707 .26169 Mtetra
.56707 .26169 .56967 .26492 .57464 .26317 .57205 .25993 Mtetra
.57205 .25993 .57464 .26317 .57962 .26142 .57704 .25817 Mtetra
.57704 .25817 .57962 .26142 .58462 .25966 .58203 .2564 Mtetra
.58203 .2564 .58462 .25966 .58962 .2579 .58704 .25464 Mtetra
.58704 .25464 .58962 .2579 .59463 .25613 .59206 .25286 Mtetra
.59206 .25286 .59463 .25613 .59965 .25436 .59708 .25109 Mtetra
.59708 .25109 .59965 .25436 .60468 .25259 .60212 .24931 Mtetra
.60212 .24931 .60468 .25259 .60971 .25082 .60716 .24753 Mtetra
.60716 .24753 .60971 .25082 .61476 .24904 .61221 .24575 Mtetra
.61221 .24575 .61476 .24904 .61982 .24726 .61728 .24396 Mtetra
.61728 .24396 .61982 .24726 .62488 .24548 .62235 .24217 Mtetra
.62235 .24217 .62488 .24548 .62996 .24369 .62743 .24038 Mtetra
.62743 .24038 .62996 .24369 .63504 .2419 .63252 .23858 Mtetra
.63252 .23858 .63504 .2419 .64013 .24011 .63762 .23679 Mtetra
.63762 .23679 .64013 .24011 .64523 .23831 .64272 .23498 Mtetra
.64272 .23498 .64523 .23831 .65034 .23651 .64784 .23318 Mtetra
.64784 .23318 .65034 .23651 .65546 .2347 .65297 .23137 Mtetra
.65297 .23137 .65546 .2347 .66059 .2329 .6581 .22955 Mtetra
.6581 .22955 .66059 .2329 .66573 .23109 .66325 .22774 Mtetra
.66325 .22774 .66573 .23109 .67088 .22927 .6684 .22592 Mtetra
.6684 .22592 .67088 .22927 .67604 .22746 .67357 .2241 Mtetra
.67357 .2241 .67604 .22746 .68121 .22564 .67874 .22227 Mtetra
.67874 .22227 .68121 .22564 .68638 .22382 .68393 .22044 Mtetra
.68393 .22044 .68638 .22382 .69157 .22199 .68912 .21861 Mtetra
.68912 .21861 .69157 .22199 .69676 .22016 .69432 .21677 Mtetra
.69432 .21677 .69676 .22016 .70197 .21833 .69953 .21493 Mtetra
.69953 .21493 .70197 .21833 .70718 .21649 .70475 .21309 Mtetra
.70475 .21309 .70718 .21649 .71241 .21465 .70998 .21124 Mtetra
.653 .755 .925 r
.02273 .41373 .02585 .41639 .02986 .41495 .02674 .41228 Mtetra
.02674 .41228 .02986 .41495 .03386 .4135 .03075 .41083 Mtetra
.03075 .41083 .03386 .4135 .03788 .41206 .03477 .40938 Mtetra
.03477 .40938 .03788 .41206 .0419 .41061 .03879 .40793 Mtetra
.03879 .40793 .0419 .41061 .04593 .40916 .04282 .40647 Mtetra
.04282 .40647 .04593 .40916 .04996 .40771 .04686 .40502 Mtetra
.04686 .40502 .04996 .40771 .05401 .40625 .05091 .40356 Mtetra
.05091 .40356 .05401 .40625 .05805 .40479 .05496 .40209 Mtetra
.05496 .40209 .05805 .40479 .06211 .40333 .05902 .40063 Mtetra
.05902 .40063 .06211 .40333 .06617 .40187 .06308 .39916 Mtetra
.06308 .39916 .06617 .40187 .07024 .4004 .06715 .39769 Mtetra
.06715 .39769 .07024 .4004 .07431 .39894 .07123 .39622 Mtetra
.07123 .39622 .07431 .39894 .07839 .39747 .07531 .39475 Mtetra
.07531 .39475 .07839 .39747 .08248 .39599 .0794 .39327 Mtetra
.0794 .39327 .08248 .39599 .08657 .39452 .0835 .39179 Mtetra
.0835 .39179 .08657 .39452 .09067 .39304 .0876 .39031 Mtetra
.0876 .39031 .09067 .39304 .09478 .39156 .09171 .38883 Mtetra
.09171 .38883 .09478 .39156 .09889 .39008 .09583 .38734 Mtetra
.09583 .38734 .09889 .39008 .10301 .3886 .09996 .38585 Mtetra
.09996 .38585 .10301 .3886 .10714 .38711 .10409 .38436 Mtetra
.10409 .38436 .10714 .38711 .11127 .38562 .10822 .38287 Mtetra
.10822 .38287 .11127 .38562 .11541 .38413 .11237 .38137 Mtetra
.11237 .38137 .11541 .38413 .11537 .41577 .11652 .37987 Mtetra
0 0 .18 r
.11652 .37987 .11537 .41577 .11956 .41429 .11649 .41154 Mtetra
.65 .758 .928 r
.11649 .41154 .11956 .41429 .12376 .4128 .12069 .41005 Mtetra
.12069 .41005 .12376 .4128 .12797 .41131 .1249 .40855 Mtetra
.1249 .40855 .12797 .41131 .13219 .40982 .12912 .40706 Mtetra
.12912 .40706 .13219 .40982 .13641 .40832 .13335 .40556 Mtetra
.13335 .40556 .13641 .40832 .14064 .40683 .13758 .40406 Mtetra
.13758 .40406 .14064 .40683 .14487 .40533 .14182 .40255 Mtetra
.14182 .40255 .14487 .40533 .14911 .40383 .14606 .40105 Mtetra
.14606 .40105 .14911 .40383 .15336 .40232 .15032 .39954 Mtetra
.15032 .39954 .15336 .40232 .15762 .40081 .15458 .39803 Mtetra
.15458 .39803 .15762 .40081 .16188 .39931 .15885 .39651 Mtetra
.15885 .39651 .16188 .39931 .16615 .39779 .16312 .395 Mtetra
.16312 .395 .16615 .39779 .17043 .39628 .1674 .39348 Mtetra
.1674 .39348 .17043 .39628 .17471 .39476 .17169 .39196 Mtetra
.17169 .39196 .17471 .39476 .17901 .39324 .17599 .39043 Mtetra
.17599 .39043 .17901 .39324 .18331 .39172 .18029 .38891 Mtetra
.18029 .38891 .18331 .39172 .18761 .3902 .1846 .38738 Mtetra
.1846 .38738 .18761 .3902 .19193 .38867 .18892 .38584 Mtetra
.18892 .38584 .19193 .38867 .19625 .38714 .19324 .38431 Mtetra
.19324 .38431 .19625 .38714 .20057 .38561 .19757 .38277 Mtetra
.19757 .38277 .20057 .38561 .20491 .38407 .20191 .38123 Mtetra
.20191 .38123 .20491 .38407 .20925 .38254 .20626 .37969 Mtetra
.20626 .37969 .20925 .38254 .2136 .381 .21061 .37815 Mtetra
.21061 .37815 .2136 .381 .21796 .37945 .21498 .3766 Mtetra
.21498 .3766 .21796 .37945 .22232 .37791 .21934 .37505 Mtetra
.21934 .37505 .22232 .37791 .22669 .37636 .22372 .3735 Mtetra
.22372 .3735 .22669 .37636 .23107 .37481 .2281 .37194 Mtetra
.2281 .37194 .23107 .37481 .23546 .37326 .23249 .37039 Mtetra
.23249 .37039 .23546 .37326 .23985 .3717 .23689 .36883 Mtetra
.23689 .36883 .23985 .3717 .24425 .37015 .2413 .36726 Mtetra
.2413 .36726 .24425 .37015 .24866 .36859 .24571 .3657 Mtetra
.24571 .3657 .24866 .36859 .25308 .36702 .25013 .36413 Mtetra
.25013 .36413 .25308 .36702 .2575 .36546 .25456 .36256 Mtetra
.25456 .36256 .2575 .36546 .26193 .36389 .259 .36099 Mtetra
.259 .36099 .26193 .36389 .26637 .36232 .26344 .35941 Mtetra
.26344 .35941 .26637 .36232 .27082 .36074 .26789 .35783 Mtetra
.26789 .35783 .27082 .36074 .27527 .35917 .27235 .35625 Mtetra
.27235 .35625 .27527 .35917 .27973 .35759 .27681 .35466 Mtetra
.27681 .35466 .27973 .35759 .2842 .356 .28129 .35308 Mtetra
.28129 .35308 .2842 .356 .28868 .35442 .28577 .35149 Mtetra
.28577 .35149 .28868 .35442 .29316 .35283 .29026 .3499 Mtetra
.29026 .3499 .29316 .35283 .29765 .35124 .29475 .3483 Mtetra
.29475 .3483 .29765 .35124 .30215 .34965 .29926 .3467 Mtetra
.29926 .3467 .30215 .34965 .30666 .34805 .30377 .3451 Mtetra
.30377 .3451 .30666 .34805 .31118 .34646 .30829 .3435 Mtetra
.30829 .3435 .31118 .34646 .3157 .34486 .31281 .34189 Mtetra
.31281 .34189 .3157 .34486 .32023 .34325 .31735 .34028 Mtetra
.31735 .34028 .32023 .34325 .32477 .34165 .32189 .33867 Mtetra
.32189 .33867 .32477 .34165 .32931 .34004 .32644 .33706 Mtetra
.32644 .33706 .32931 .34004 .33386 .33842 .331 .33544 Mtetra
.331 .33544 .33386 .33842 .33843 .33681 .33557 .33382 Mtetra
.33557 .33382 .33843 .33681 .343 .33519 .34014 .3322 Mtetra
.34014 .3322 .343 .33519 .34757 .33357 .34472 .33057 Mtetra
.34472 .33057 .34757 .33357 .35216 .33195 .34931 .32895 Mtetra
.34931 .32895 .35216 .33195 .35675 .33032 .35391 .32731 Mtetra
.35391 .32731 .35675 .33032 .36135 .32869 .35852 .32568 Mtetra
.35852 .32568 .36135 .32869 .36596 .32706 .36313 .32404 Mtetra
.36313 .32404 .36596 .32706 .37058 .32543 .36775 .3224 Mtetra
.36775 .3224 .37058 .32543 .3752 .32379 .37238 .32076 Mtetra
.37238 .32076 .3752 .32379 .37983 .32215 .37702 .31912 Mtetra
.37702 .31912 .37983 .32215 .38447 .32051 .38166 .31747 Mtetra
.38166 .31747 .38447 .32051 .38912 .31886 .38632 .31582 Mtetra
.38632 .31582 .38912 .31886 .39378 .31721 .39098 .31416 Mtetra
.39098 .31416 .39378 .31721 .39845 .31556 .39565 .31251 Mtetra
.39565 .31251 .39845 .31556 .40312 .31391 .40033 .31085 Mtetra
.40033 .31085 .40312 .31391 .4078 .31225 .40501 .30918 Mtetra
.40501 .30918 .4078 .31225 .41249 .31059 .40971 .30752 Mtetra
.40971 .30752 .41249 .31059 .41719 .30893 .41441 .30585 Mtetra
.41441 .30585 .41719 .30893 .42189 .30726 .41912 .30418 Mtetra
.41912 .30418 .42189 .30726 .42661 .30559 .42384 .30251 Mtetra
.42384 .30251 .42661 .30559 .43133 .30392 .42857 .30083 Mtetra
.42857 .30083 .43133 .30392 .43606 .30225 .4333 .29915 Mtetra
.4333 .29915 .43606 .30225 .4408 .30057 .43805 .29747 Mtetra
.43805 .29747 .4408 .30057 .44555 .29889 .4428 .29578 Mtetra
.4428 .29578 .44555 .29889 .4503 .29721 .44756 .29409 Mtetra
.44756 .29409 .4503 .29721 .45506 .29552 .45233 .2924 Mtetra
.45233 .2924 .45506 .29552 .45984 .29383 .45711 .2907 Mtetra
.45711 .2907 .45984 .29383 .46462 .29214 .46189 .28901 Mtetra
.46189 .28901 .46462 .29214 .46941 .29044 .46669 .28731 Mtetra
.46669 .28731 .46941 .29044 .4742 .28875 .47149 .2856 Mtetra
.47149 .2856 .4742 .28875 .47901 .28704 .4763 .2839 Mtetra
.4763 .2839 .47901 .28704 .48382 .28534 .48112 .28219 Mtetra
0 .126 .644 r
.48112 .28219 .48382 .28534 .48858 .28939 .48588 .28623 Mtetra
.649 .759 .929 r
.48588 .28623 .48858 .28939 .49342 .28768 .49072 .28452 Mtetra
.49072 .28452 .49342 .28768 .49827 .28597 .49558 .2828 Mtetra
.49558 .2828 .49827 .28597 .50313 .28425 .50044 .28108 Mtetra
.50044 .28108 .50313 .28425 .50799 .28254 .50531 .27936 Mtetra
.50531 .27936 .50799 .28254 .51287 .28082 .51019 .27763 Mtetra
.51019 .27763 .51287 .28082 .51775 .27909 .51508 .2759 Mtetra
.51508 .2759 .51775 .27909 .52264 .27737 .51998 .27417 Mtetra
.51998 .27417 .52264 .27737 .52754 .27564 .52489 .27243 Mtetra
.52489 .27243 .52754 .27564 .53245 .2739 .5298 .2707 Mtetra
.5298 .2707 .53245 .2739 .53737 .27217 .53473 .26895 Mtetra
.53473 .26895 .53737 .27217 .5423 .27043 .53966 .26721 Mtetra
.53966 .26721 .5423 .27043 .54723 .26869 .5446 .26546 Mtetra
.5446 .26546 .54723 .26869 .55218 .26694 .54955 .26371 Mtetra
.54955 .26371 .55218 .26694 .55713 .26519 .55451 .26196 Mtetra
.55451 .26196 .55713 .26519 .56209 .26344 .55948 .2602 Mtetra
.55948 .2602 .56209 .26344 .56707 .26169 .56446 .25844 Mtetra
.56446 .25844 .56707 .26169 .57205 .25993 .56944 .25667 Mtetra
.56944 .25667 .57205 .25993 .57704 .25817 .57444 .25491 Mtetra
.57444 .25491 .57704 .25817 .58203 .2564 .57944 .25314 Mtetra
.57944 .25314 .58203 .2564 .58704 .25464 .58446 .25136 Mtetra
.58446 .25136 .58704 .25464 .59206 .25286 .58948 .24959 Mtetra
.58948 .24959 .59206 .25286 .59708 .25109 .59451 .24781 Mtetra
.59451 .24781 .59708 .25109 .60212 .24931 .59955 .24603 Mtetra
.59955 .24603 .60212 .24931 .60716 .24753 .6046 .24424 Mtetra
.6046 .24424 .60716 .24753 .61221 .24575 .60966 .24245 Mtetra
.60966 .24245 .61221 .24575 .61728 .24396 .61473 .24066 Mtetra
.61473 .24066 .61728 .24396 .62235 .24217 .6198 .23886 Mtetra
.6198 .23886 .62235 .24217 .62743 .24038 .62489 .23706 Mtetra
.62489 .23706 .62743 .24038 .63252 .23858 .62999 .23526 Mtetra
.62999 .23526 .63252 .23858 .63762 .23679 .63509 .23345 Mtetra
.63509 .23345 .63762 .23679 .64272 .23498 .64021 .23165 Mtetra
.64021 .23165 .64272 .23498 .64784 .23318 .64533 .22983 Mtetra
.64533 .22983 .64784 .23318 .65297 .23137 .65046 .22802 Mtetra
.65046 .22802 .65297 .23137 .6581 .22955 .65561 .2262 Mtetra
.65561 .2262 .6581 .22955 .66325 .22774 .66076 .22438 Mtetra
.66076 .22438 .66325 .22774 .6684 .22592 .66592 .22255 Mtetra
.66592 .22255 .6684 .22592 .67357 .2241 .67109 .22072 Mtetra
.67109 .22072 .67357 .2241 .67874 .22227 .67627 .21889 Mtetra
.67627 .21889 .67874 .22227 .68393 .22044 .68146 .21705 Mtetra
.68146 .21705 .68393 .22044 .68912 .21861 .68666 .21522 Mtetra
.68666 .21522 .68912 .21861 .69432 .21677 .69187 .21337 Mtetra
.69187 .21337 .69432 .21677 .69953 .21493 .69709 .21153 Mtetra
.69709 .21153 .69953 .21493 .70475 .21309 .70231 .20968 Mtetra
.70231 .20968 .70475 .21309 .70998 .21124 .70755 .20783 Mtetra
.653 .755 .925 r
.0196 .41106 .02273 .41373 .02674 .41228 .02361 .40961 Mtetra
.02361 .40961 .02674 .41228 .03075 .41083 .02762 .40815 Mtetra
.02762 .40815 .03075 .41083 .03477 .40938 .03164 .4067 Mtetra
.03164 .4067 .03477 .40938 .03879 .40793 .03567 .40524 Mtetra
.03567 .40524 .03879 .40793 .04282 .40647 .03971 .40378 Mtetra
.03971 .40378 .04282 .40647 .04686 .40502 .04375 .40232 Mtetra
.04375 .40232 .04686 .40502 .05091 .40356 .0478 .40085 Mtetra
.0478 .40085 .05091 .40356 .05496 .40209 .05185 .39939 Mtetra
.05185 .39939 .05496 .40209 .05902 .40063 .05591 .39792 Mtetra
.05591 .39792 .05902 .40063 .06308 .39916 .05998 .39645 Mtetra
.05998 .39645 .06308 .39916 .06715 .39769 .06406 .39497 Mtetra
.06406 .39497 .06715 .39769 .07123 .39622 .06814 .3935 Mtetra
.06814 .3935 .07123 .39622 .07531 .39475 .07222 .39202 Mtetra
.07222 .39202 .07531 .39475 .0794 .39327 .07632 .39054 Mtetra
.07632 .39054 .0794 .39327 .0835 .39179 .08042 .38905 Mtetra
.08042 .38905 .0835 .39179 .0876 .39031 .08453 .38757 Mtetra
.08453 .38757 .0876 .39031 .09171 .38883 .08864 .38608 Mtetra
.08864 .38608 .09171 .38883 .09583 .38734 .09276 .38459 Mtetra
.09276 .38459 .09583 .38734 .09996 .38585 .09689 .3831 Mtetra
.09689 .3831 .09996 .38585 .10409 .38436 .10102 .3816 Mtetra
.10102 .3816 .10409 .38436 .10822 .38287 .10517 .3801 Mtetra
.10517 .3801 .10822 .38287 .11237 .38137 .10931 .3786 Mtetra
.10931 .3786 .11237 .38137 .11652 .37987 .11347 .3771 Mtetra
.95 .647 .427 r
.11347 .3771 .11652 .37987 .11649 .41154 .1134 .40878 Mtetra
.65 .758 .928 r
.1134 .40878 .11649 .41154 .12069 .41005 .11761 .40729 Mtetra
.11761 .40729 .12069 .41005 .1249 .40855 .12183 .40579 Mtetra
.12183 .40579 .1249 .40855 .12912 .40706 .12605 .40429 Mtetra
.12605 .40429 .12912 .40706 .13335 .40556 .13028 .40278 Mtetra
.13028 .40278 .13335 .40556 .13758 .40406 .13451 .40128 Mtetra
.13451 .40128 .13758 .40406 .14182 .40255 .13876 .39977 Mtetra
.13876 .39977 .14182 .40255 .14606 .40105 .14301 .39826 Mtetra
.14301 .39826 .14606 .40105 .15032 .39954 .14726 .39675 Mtetra
.14726 .39675 .15032 .39954 .15458 .39803 .15153 .39523 Mtetra
.15153 .39523 .15458 .39803 .15885 .39651 .1558 .39371 Mtetra
.1558 .39371 .15885 .39651 .16312 .395 .16008 .39219 Mtetra
.16008 .39219 .16312 .395 .1674 .39348 .16437 .39067 Mtetra
.16437 .39067 .1674 .39348 .17169 .39196 .16866 .38914 Mtetra
.16866 .38914 .17169 .39196 .17599 .39043 .17296 .38761 Mtetra
.17296 .38761 .17599 .39043 .18029 .38891 .17727 .38608 Mtetra
.17727 .38608 .18029 .38891 .1846 .38738 .18158 .38455 Mtetra
.18158 .38455 .1846 .38738 .18892 .38584 .1859 .38301 Mtetra
.1859 .38301 .18892 .38584 .19324 .38431 .19023 .38147 Mtetra
.19023 .38147 .19324 .38431 .19757 .38277 .19457 .37993 Mtetra
.19457 .37993 .19757 .38277 .20191 .38123 .19891 .37839 Mtetra
.19891 .37839 .20191 .38123 .20626 .37969 .20326 .37684 Mtetra
.20326 .37684 .20626 .37969 .21061 .37815 .20762 .37529 Mtetra
.20762 .37529 .21061 .37815 .21498 .3766 .21198 .37374 Mtetra
.21198 .37374 .21498 .3766 .21934 .37505 .21636 .37218 Mtetra
.21636 .37218 .21934 .37505 .22372 .3735 .22074 .37063 Mtetra
.22074 .37063 .22372 .3735 .2281 .37194 .22513 .36907 Mtetra
.22513 .36907 .2281 .37194 .23249 .37039 .22952 .3675 Mtetra
.22952 .3675 .23249 .37039 .23689 .36883 .23392 .36594 Mtetra
.23392 .36594 .23689 .36883 .2413 .36726 .23833 .36437 Mtetra
.23833 .36437 .2413 .36726 .24571 .3657 .24275 .3628 Mtetra
.24275 .3628 .24571 .3657 .25013 .36413 .24718 .36123 Mtetra
.24718 .36123 .25013 .36413 .25456 .36256 .25161 .35965 Mtetra
.25161 .35965 .25456 .36256 .259 .36099 .25605 .35807 Mtetra
.25605 .35807 .259 .36099 .26344 .35941 .26049 .35649 Mtetra
.26049 .35649 .26344 .35941 .26789 .35783 .26495 .35491 Mtetra
.26495 .35491 .26789 .35783 .27235 .35625 .26941 .35332 Mtetra
.26941 .35332 .27235 .35625 .27681 .35466 .27388 .35173 Mtetra
.27388 .35173 .27681 .35466 .28129 .35308 .27836 .35014 Mtetra
.27836 .35014 .28129 .35308 .28577 .35149 .28285 .34855 Mtetra
.28285 .34855 .28577 .35149 .29026 .3499 .28734 .34695 Mtetra
.28734 .34695 .29026 .3499 .29475 .3483 .29184 .34535 Mtetra
.29184 .34535 .29475 .3483 .29926 .3467 .29635 .34375 Mtetra
.29635 .34375 .29926 .3467 .30377 .3451 .30087 .34214 Mtetra
.30087 .34214 .30377 .3451 .30829 .3435 .30539 .34053 Mtetra
.30539 .34053 .30829 .3435 .31281 .34189 .30992 .33892 Mtetra
.30992 .33892 .31281 .34189 .31735 .34028 .31446 .33731 Mtetra
.31446 .33731 .31735 .34028 .32189 .33867 .31901 .33569 Mtetra
.31901 .33569 .32189 .33867 .32644 .33706 .32356 .33407 Mtetra
.32356 .33407 .32644 .33706 .331 .33544 .32813 .33245 Mtetra
.32813 .33245 .331 .33544 .33557 .33382 .3327 .33082 Mtetra
.3327 .33082 .33557 .33382 .34014 .3322 .33728 .3292 Mtetra
.33728 .3292 .34014 .3322 .34472 .33057 .34186 .32757 Mtetra
.34186 .32757 .34472 .33057 .34931 .32895 .34646 .32593 Mtetra
.34646 .32593 .34931 .32895 .35391 .32731 .35106 .3243 Mtetra
.35106 .3243 .35391 .32731 .35852 .32568 .35567 .32266 Mtetra
.35567 .32266 .35852 .32568 .36313 .32404 .36029 .32101 Mtetra
.36029 .32101 .36313 .32404 .36775 .3224 .36492 .31937 Mtetra
.36492 .31937 .36775 .3224 .37238 .32076 .36955 .31772 Mtetra
.36955 .31772 .37238 .32076 .37702 .31912 .37419 .31607 Mtetra
.37419 .31607 .37702 .31912 .38166 .31747 .37884 .31442 Mtetra
.37884 .31442 .38166 .31747 .38632 .31582 .3835 .31276 Mtetra
.3835 .31276 .38632 .31582 .39098 .31416 .38817 .3111 Mtetra
.38817 .3111 .39098 .31416 .39565 .31251 .39284 .30944 Mtetra
.39284 .30944 .39565 .31251 .40033 .31085 .39753 .30778 Mtetra
.39753 .30778 .40033 .31085 .40501 .30918 .40222 .30611 Mtetra
.40222 .30611 .40501 .30918 .40971 .30752 .40692 .30444 Mtetra
.40692 .30444 .40971 .30752 .41441 .30585 .41163 .30276 Mtetra
.41163 .30276 .41441 .30585 .41912 .30418 .41634 .30109 Mtetra
.41634 .30109 .41912 .30418 .42384 .30251 .42107 .29941 Mtetra
.42107 .29941 .42384 .30251 .42857 .30083 .4258 .29772 Mtetra
.4258 .29772 .42857 .30083 .4333 .29915 .43054 .29604 Mtetra
.43054 .29604 .4333 .29915 .43805 .29747 .43529 .29435 Mtetra
.43529 .29435 .43805 .29747 .4428 .29578 .44005 .29266 Mtetra
.44005 .29266 .4428 .29578 .44756 .29409 .44481 .29097 Mtetra
.44481 .29097 .44756 .29409 .45233 .2924 .44959 .28927 Mtetra
.44959 .28927 .45233 .2924 .45711 .2907 .45437 .28757 Mtetra
.45437 .28757 .45711 .2907 .46189 .28901 .45916 .28586 Mtetra
.45916 .28586 .46189 .28901 .46669 .28731 .46396 .28416 Mtetra
.46396 .28416 .46669 .28731 .47149 .2856 .46877 .28245 Mtetra
.46877 .28245 .47149 .2856 .4763 .2839 .47359 .28074 Mtetra
.47359 .28074 .4763 .2839 .48112 .28219 .47841 .27902 Mtetra
.47841 .27902 .48112 .28219 .48588 .28623 .48325 .2773 Mtetra
.23 .266 .693 r
.48325 .2773 .48588 .28623 .49072 .28452 .48802 .28134 Mtetra
.649 .759 .929 r
.48802 .28134 .49072 .28452 .49558 .2828 .49288 .27962 Mtetra
.49288 .27962 .49558 .2828 .50044 .28108 .49775 .2779 Mtetra
.49775 .2779 .50044 .28108 .50531 .27936 .50263 .27617 Mtetra
.50263 .27617 .50531 .27936 .51019 .27763 .50751 .27444 Mtetra
.50751 .27444 .51019 .27763 .51508 .2759 .51241 .2727 Mtetra
.51241 .2727 .51508 .2759 .51998 .27417 .51731 .27096 Mtetra
.51731 .27096 .51998 .27417 .52489 .27243 .52222 .26922 Mtetra
.52222 .26922 .52489 .27243 .5298 .2707 .52714 .26748 Mtetra
.52714 .26748 .5298 .2707 .53473 .26895 .53207 .26573 Mtetra
.53207 .26573 .53473 .26895 .53966 .26721 .53701 .26398 Mtetra
.53701 .26398 .53966 .26721 .5446 .26546 .54196 .26223 Mtetra
.54196 .26223 .5446 .26546 .54955 .26371 .54692 .26047 Mtetra
.54692 .26047 .54955 .26371 .55451 .26196 .55188 .25871 Mtetra
.55188 .25871 .55451 .26196 .55948 .2602 .55686 .25695 Mtetra
.55686 .25695 .55948 .2602 .56446 .25844 .56184 .25518 Mtetra
.56184 .25518 .56446 .25844 .56944 .25667 .56683 .25341 Mtetra
.56683 .25341 .56944 .25667 .57444 .25491 .57183 .25164 Mtetra
.57183 .25164 .57444 .25491 .57944 .25314 .57684 .24986 Mtetra
.57684 .24986 .57944 .25314 .58446 .25136 .58186 .24808 Mtetra
.58186 .24808 .58446 .25136 .58948 .24959 .58689 .2463 Mtetra
.58689 .2463 .58948 .24959 .59451 .24781 .59193 .24451 Mtetra
.59193 .24451 .59451 .24781 .59955 .24603 .59697 .24273 Mtetra
.59697 .24273 .59955 .24603 .6046 .24424 .60203 .24093 Mtetra
.60203 .24093 .6046 .24424 .60966 .24245 .6071 .23914 Mtetra
.6071 .23914 .60966 .24245 .61473 .24066 .61217 .23734 Mtetra
.61217 .23734 .61473 .24066 .6198 .23886 .61725 .23554 Mtetra
.61725 .23554 .6198 .23886 .62489 .23706 .62235 .23373 Mtetra
.62235 .23373 .62489 .23706 .62999 .23526 .62745 .23192 Mtetra
.62745 .23192 .62999 .23526 .63509 .23345 .63256 .23011 Mtetra
.63256 .23011 .63509 .23345 .64021 .23165 .63768 .2283 Mtetra
.63768 .2283 .64021 .23165 .64533 .22983 .64281 .22648 Mtetra
.64281 .22648 .64533 .22983 .65046 .22802 .64795 .22466 Mtetra
.64795 .22466 .65046 .22802 .65561 .2262 .6531 .22283 Mtetra
.6531 .22283 .65561 .2262 .66076 .22438 .65826 .221 Mtetra
.65826 .221 .66076 .22438 .66592 .22255 .66342 .21917 Mtetra
.66342 .21917 .66592 .22255 .67109 .22072 .6686 .21734 Mtetra
.6686 .21734 .67109 .22072 .67627 .21889 .67379 .2155 Mtetra
.67379 .2155 .67627 .21889 .68146 .21705 .67898 .21366 Mtetra
.67898 .21366 .68146 .21705 .68666 .21522 .68419 .21181 Mtetra
.68419 .21181 .68666 .21522 .69187 .21337 .68941 .20996 Mtetra
.68941 .20996 .69187 .21337 .69709 .21153 .69463 .20811 Mtetra
.69463 .20811 .69709 .21153 .70231 .20968 .69987 .20626 Mtetra
.69987 .20626 .70231 .20968 .70755 .20783 .70511 .2044 Mtetra
.653 .755 .925 r
.01645 .40838 .0196 .41106 .02361 .40961 .02047 .40692 Mtetra
.02047 .40692 .02361 .40961 .02762 .40815 .02449 .40546 Mtetra
.02449 .40546 .02762 .40815 .03164 .4067 .02851 .40401 Mtetra
.02851 .40401 .03164 .4067 .03567 .40524 .03254 .40254 Mtetra
.03254 .40254 .03567 .40524 .03971 .40378 .03658 .40108 Mtetra
.03658 .40108 .03971 .40378 .04375 .40232 .04063 .39961 Mtetra
.04063 .39961 .04375 .40232 .0478 .40085 .04468 .39814 Mtetra
.04468 .39814 .0478 .40085 .05185 .39939 .04874 .39667 Mtetra
.04874 .39667 .05185 .39939 .05591 .39792 .0528 .3952 Mtetra
.0528 .3952 .05591 .39792 .05998 .39645 .05687 .39372 Mtetra
.05687 .39372 .05998 .39645 .06406 .39497 .06095 .39225 Mtetra
.06095 .39225 .06406 .39497 .06814 .3935 .06504 .39077 Mtetra
.06504 .39077 .06814 .3935 .07222 .39202 .06913 .38928 Mtetra
.06913 .38928 .07222 .39202 .07632 .39054 .07323 .3878 Mtetra
.07323 .3878 .07632 .39054 .08042 .38905 .07733 .38631 Mtetra
.07733 .38631 .08042 .38905 .08453 .38757 .08144 .38482 Mtetra
.08144 .38482 .08453 .38757 .08864 .38608 .08556 .38333 Mtetra
.08556 .38333 .08864 .38608 .09276 .38459 .08968 .38183 Mtetra
.08968 .38183 .09276 .38459 .09689 .3831 .09382 .38033 Mtetra
.09382 .38033 .09689 .3831 .10102 .3816 .09795 .37883 Mtetra
.09795 .37883 .10102 .3816 .10517 .3801 .1021 .37733 Mtetra
.1021 .37733 .10517 .3801 .10931 .3786 .10625 .37583 Mtetra
.10625 .37583 .10931 .3786 .11347 .3771 .11041 .37432 Mtetra
.95 .647 .427 r
.11041 .37432 .11347 .3771 .1134 .40878 .11031 .40602 Mtetra
.65 .758 .928 r
.11031 .40602 .1134 .40878 .11761 .40729 .11452 .40452 Mtetra
.11452 .40452 .11761 .40729 .12183 .40579 .11874 .40302 Mtetra
.11874 .40302 .12183 .40579 .12605 .40429 .12297 .40151 Mtetra
.12297 .40151 .12605 .40429 .13028 .40278 .1272 .4 Mtetra
.1272 .4 .13028 .40278 .13451 .40128 .13144 .39849 Mtetra
.13144 .39849 .13451 .40128 .13876 .39977 .13569 .39698 Mtetra
.13569 .39698 .13876 .39977 .14301 .39826 .13994 .39546 Mtetra
.13994 .39546 .14301 .39826 .14726 .39675 .1442 .39395 Mtetra
.1442 .39395 .14726 .39675 .15153 .39523 .14847 .39242 Mtetra
.14847 .39242 .15153 .39523 .1558 .39371 .15275 .3909 Mtetra
.15275 .3909 .1558 .39371 .16008 .39219 .15703 .38938 Mtetra
.15703 .38938 .16008 .39219 .16437 .39067 .16132 .38785 Mtetra
.16132 .38785 .16437 .39067 .16866 .38914 .16562 .38632 Mtetra
.16562 .38632 .16866 .38914 .17296 .38761 .16992 .38478 Mtetra
.16992 .38478 .17296 .38761 .17727 .38608 .17423 .38325 Mtetra
.17423 .38325 .17727 .38608 .18158 .38455 .17855 .38171 Mtetra
.17855 .38171 .18158 .38455 .1859 .38301 .18288 .38017 Mtetra
.18288 .38017 .1859 .38301 .19023 .38147 .18721 .37862 Mtetra
.18721 .37862 .19023 .38147 .19457 .37993 .19155 .37708 Mtetra
.19155 .37708 .19457 .37993 .19891 .37839 .1959 .37553 Mtetra
.1959 .37553 .19891 .37839 .20326 .37684 .20025 .37398 Mtetra
.20025 .37398 .20326 .37684 .20762 .37529 .20461 .37242 Mtetra
.20461 .37242 .20762 .37529 .21198 .37374 .20898 .37087 Mtetra
.20898 .37087 .21198 .37374 .21636 .37218 .21336 .36931 Mtetra
.21336 .36931 .21636 .37218 .22074 .37063 .21775 .36774 Mtetra
.21775 .36774 .22074 .37063 .22513 .36907 .22214 .36618 Mtetra
.22214 .36618 .22513 .36907 .22952 .3675 .22654 .36461 Mtetra
.22654 .36461 .22952 .3675 .23392 .36594 .23094 .36304 Mtetra
.23094 .36304 .23392 .36594 .23833 .36437 .23536 .36147 Mtetra
.23536 .36147 .23833 .36437 .24275 .3628 .23978 .35989 Mtetra
.23978 .35989 .24275 .3628 .24718 .36123 .24421 .35832 Mtetra
.24421 .35832 .24718 .36123 .25161 .35965 .24865 .35674 Mtetra
.24865 .35674 .25161 .35965 .25605 .35807 .25309 .35515 Mtetra
.25309 .35515 .25605 .35807 .26049 .35649 .25754 .35357 Mtetra
.25754 .35357 .26049 .35649 .26495 .35491 .262 .35198 Mtetra
.262 .35198 .26495 .35491 .26941 .35332 .26647 .35039 Mtetra
.26647 .35039 .26941 .35332 .27388 .35173 .27094 .34879 Mtetra
.27094 .34879 .27388 .35173 .27836 .35014 .27543 .34719 Mtetra
.27543 .34719 .27836 .35014 .28285 .34855 .27992 .34559 Mtetra
.27992 .34559 .28285 .34855 .28734 .34695 .28441 .34399 Mtetra
.28441 .34399 .28734 .34695 .29184 .34535 .28892 .34239 Mtetra
.28892 .34239 .29184 .34535 .29635 .34375 .29343 .34078 Mtetra
.29343 .34078 .29635 .34375 .30087 .34214 .29795 .33917 Mtetra
.29795 .33917 .30087 .34214 .30539 .34053 .30248 .33756 Mtetra
.30248 .33756 .30539 .34053 .30992 .33892 .30702 .33594 Mtetra
.30702 .33594 .30992 .33892 .31446 .33731 .31156 .33432 Mtetra
.31156 .33432 .31446 .33731 .31901 .33569 .31612 .3327 Mtetra
.31612 .3327 .31901 .33569 .32356 .33407 .32068 .33107 Mtetra
.32068 .33107 .32356 .33407 .32813 .33245 .32524 .32945 Mtetra
.32524 .32945 .32813 .33245 .3327 .33082 .32982 .32782 Mtetra
.32982 .32782 .3327 .33082 .33728 .3292 .3344 .32618 Mtetra
.3344 .32618 .33728 .3292 .34186 .32757 .33899 .32455 Mtetra
.33899 .32455 .34186 .32757 .34646 .32593 .34359 .32291 Mtetra
.34359 .32291 .34646 .32593 .35106 .3243 .3482 .32127 Mtetra
.3482 .32127 .35106 .3243 .35567 .32266 .35282 .31962 Mtetra
.35282 .31962 .35567 .32266 .36029 .32101 .35744 .31798 Mtetra
.35744 .31798 .36029 .32101 .36492 .31937 .36207 .31633 Mtetra
.36207 .31633 .36492 .31937 .36955 .31772 .36671 .31467 Mtetra
.36671 .31467 .36955 .31772 .37419 .31607 .37136 .31302 Mtetra
.37136 .31302 .37419 .31607 .37884 .31442 .37601 .31136 Mtetra
.37601 .31136 .37884 .31442 .3835 .31276 .38068 .3097 Mtetra
.38068 .3097 .3835 .31276 .38817 .3111 .38535 .30803 Mtetra
.38535 .30803 .38817 .3111 .39284 .30944 .39003 .30636 Mtetra
.39003 .30636 .39284 .30944 .39753 .30778 .39472 .30469 Mtetra
.39472 .30469 .39753 .30778 .40222 .30611 .39942 .30302 Mtetra
.39942 .30302 .40222 .30611 .40692 .30444 .40412 .30135 Mtetra
.40412 .30135 .40692 .30444 .41163 .30276 .40883 .29967 Mtetra
.40883 .29967 .41163 .30276 .41634 .30109 .41355 .29798 Mtetra
.41355 .29798 .41634 .30109 .42107 .29941 .41828 .2963 Mtetra
.41828 .2963 .42107 .29941 .4258 .29772 .42302 .29461 Mtetra
.42302 .29461 .4258 .29772 .43054 .29604 .42777 .29292 Mtetra
.42777 .29292 .43054 .29604 .43529 .29435 .43252 .29123 Mtetra
.43252 .29123 .43529 .29435 .44005 .29266 .43729 .28953 Mtetra
.43729 .28953 .44005 .29266 .44481 .29097 .44206 .28783 Mtetra
.44206 .28783 .44481 .29097 .44959 .28927 .44684 .28613 Mtetra
.44684 .28613 .44959 .28927 .45437 .28757 .45163 .28442 Mtetra
.45163 .28442 .45437 .28757 .45916 .28586 .45642 .28271 Mtetra
.45642 .28271 .45916 .28586 .46396 .28416 .46123 .281 Mtetra
.46123 .281 .46396 .28416 .46877 .28245 .46604 .27929 Mtetra
.46604 .27929 .46877 .28245 .47359 .28074 .47086 .27757 Mtetra
.47086 .27757 .47359 .28074 .47841 .27902 .47569 .27585 Mtetra
.47569 .27585 .47841 .27902 .48325 .2773 .48053 .27412 Mtetra
0 .129 .647 r
.48053 .27412 .48325 .2773 .48802 .28134 .48531 .27816 Mtetra
.649 .759 .929 r
.48531 .27816 .48802 .28134 .49288 .27962 .49017 .27643 Mtetra
.49017 .27643 .49288 .27962 .49775 .2779 .49505 .2747 Mtetra
.49505 .2747 .49775 .2779 .50263 .27617 .49993 .27297 Mtetra
.49993 .27297 .50263 .27617 .50751 .27444 .50482 .27123 Mtetra
.50482 .27123 .50751 .27444 .51241 .2727 .50972 .26949 Mtetra
.50972 .26949 .51241 .2727 .51731 .27096 .51463 .26775 Mtetra
.51463 .26775 .51731 .27096 .52222 .26922 .51955 .266 Mtetra
.51955 .266 .52222 .26922 .52714 .26748 .52448 .26425 Mtetra
.52448 .26425 .52714 .26748 .53207 .26573 .52941 .2625 Mtetra
.52941 .2625 .53207 .26573 .53701 .26398 .53436 .26074 Mtetra
.53436 .26074 .53701 .26398 .54196 .26223 .53931 .25898 Mtetra
.53931 .25898 .54196 .26223 .54692 .26047 .54427 .25722 Mtetra
.54427 .25722 .54692 .26047 .55188 .25871 .54924 .25545 Mtetra
.54924 .25545 .55188 .25871 .55686 .25695 .55422 .25368 Mtetra
.55422 .25368 .55686 .25695 .56184 .25518 .55921 .25191 Mtetra
.55921 .25191 .56184 .25518 .56683 .25341 .56421 .25013 Mtetra
.56421 .25013 .56683 .25341 .57183 .25164 .56922 .24836 Mtetra
.56922 .24836 .57183 .25164 .57684 .24986 .57423 .24657 Mtetra
.57423 .24657 .57684 .24986 .58186 .24808 .57926 .24479 Mtetra
.57926 .24479 .58186 .24808 .58689 .2463 .58429 .243 Mtetra
.58429 .243 .58689 .2463 .59193 .24451 .58934 .24121 Mtetra
.58934 .24121 .59193 .24451 .59697 .24273 .59439 .23941 Mtetra
.59439 .23941 .59697 .24273 .60203 .24093 .59945 .23762 Mtetra
.59945 .23762 .60203 .24093 .6071 .23914 .60452 .23581 Mtetra
.60452 .23581 .6071 .23914 .61217 .23734 .6096 .23401 Mtetra
.6096 .23401 .61217 .23734 .61725 .23554 .61469 .2322 Mtetra
.61469 .2322 .61725 .23554 .62235 .23373 .61979 .23039 Mtetra
.61979 .23039 .62235 .23373 .62745 .23192 .6249 .22858 Mtetra
.6249 .22858 .62745 .23192 .63256 .23011 .63002 .22676 Mtetra
.63002 .22676 .63256 .23011 .63768 .2283 .63515 .22494 Mtetra
.63515 .22494 .63768 .2283 .64281 .22648 .64028 .22311 Mtetra
.64028 .22311 .64281 .22648 .64795 .22466 .64543 .22129 Mtetra
.64543 .22129 .64795 .22466 .6531 .22283 .65058 .21945 Mtetra
.65058 .21945 .6531 .22283 .65826 .221 .65575 .21762 Mtetra
.65575 .21762 .65826 .221 .66342 .21917 .66092 .21578 Mtetra
.66092 .21578 .66342 .21917 .6686 .21734 .66611 .21394 Mtetra
.66611 .21394 .6686 .21734 .67379 .2155 .6713 .2121 Mtetra
.6713 .2121 .67379 .2155 .67898 .21366 .6765 .21025 Mtetra
.6765 .21025 .67898 .21366 .68419 .21181 .68171 .2084 Mtetra
.68171 .2084 .68419 .21181 .68941 .20996 .68694 .20654 Mtetra
.68694 .20654 .68941 .20996 .69463 .20811 .69217 .20468 Mtetra
.69217 .20468 .69463 .20811 .69987 .20626 .69741 .20282 Mtetra
.69741 .20282 .69987 .20626 .70511 .2044 .70266 .20096 Mtetra
.653 .755 .925 r
.0133 .40569 .01645 .40838 .02047 .40692 .01732 .40423 Mtetra
.01732 .40423 .02047 .40692 .02449 .40546 .02134 .40277 Mtetra
.02134 .40277 .02449 .40546 .02851 .40401 .02537 .40131 Mtetra
.02537 .40131 .02851 .40401 .03254 .40254 .02941 .39984 Mtetra
.02941 .39984 .03254 .40254 .03658 .40108 .03345 .39837 Mtetra
.03345 .39837 .03658 .40108 .04063 .39961 .0375 .3969 Mtetra
.0375 .3969 .04063 .39961 .04468 .39814 .04155 .39543 Mtetra
.04155 .39543 .04468 .39814 .04874 .39667 .04561 .39395 Mtetra
.04561 .39395 .04874 .39667 .0528 .3952 .04968 .39247 Mtetra
.04968 .39247 .0528 .3952 .05687 .39372 .05376 .39099 Mtetra
.05376 .39099 .05687 .39372 .06095 .39225 .05784 .38951 Mtetra
.05784 .38951 .06095 .39225 .06504 .39077 .06193 .38803 Mtetra
.06193 .38803 .06504 .39077 .06913 .38928 .06602 .38654 Mtetra
.06602 .38654 .06913 .38928 .07323 .3878 .07012 .38505 Mtetra
.07012 .38505 .07323 .3878 .07733 .38631 .07423 .38356 Mtetra
.07423 .38356 .07733 .38631 .08144 .38482 .07835 .38206 Mtetra
.07835 .38206 .08144 .38482 .08556 .38333 .08247 .38056 Mtetra
.08247 .38056 .08556 .38333 .08968 .38183 .0866 .37906 Mtetra
.0866 .37906 .08968 .38183 .09382 .38033 .09073 .37756 Mtetra
.09073 .37756 .09382 .38033 .09795 .37883 .09487 .37606 Mtetra
.09487 .37606 .09795 .37883 .1021 .37733 .09902 .37455 Mtetra
.09902 .37455 .1021 .37733 .10625 .37583 .10318 .37304 Mtetra
.10318 .37304 .10625 .37583 .11041 .37432 .10734 .37153 Mtetra
.95 .647 .427 r
.10734 .37153 .11041 .37432 .11031 .40602 .10721 .40325 Mtetra
.65 .758 .928 r
.10721 .40325 .11031 .40602 .11452 .40452 .11142 .40174 Mtetra
.11142 .40174 .11452 .40452 .11874 .40302 .11564 .40023 Mtetra
.11564 .40023 .11874 .40302 .12297 .40151 .11987 .39872 Mtetra
.11987 .39872 .12297 .40151 .1272 .4 .12411 .39721 Mtetra
.12411 .39721 .1272 .4 .13144 .39849 .12836 .3957 Mtetra
.12836 .3957 .13144 .39849 .13569 .39698 .13261 .39418 Mtetra
.13261 .39418 .13569 .39698 .13994 .39546 .13686 .39266 Mtetra
.13686 .39266 .13994 .39546 .1442 .39395 .14113 .39114 Mtetra
.14113 .39114 .1442 .39395 .14847 .39242 .1454 .38961 Mtetra
.1454 .38961 .14847 .39242 .15275 .3909 .14968 .38808 Mtetra
.14968 .38808 .15275 .3909 .15703 .38938 .15397 .38655 Mtetra
.15397 .38655 .15703 .38938 .16132 .38785 .15826 .38502 Mtetra
.15826 .38502 .16132 .38785 .16562 .38632 .16256 .38348 Mtetra
.16256 .38348 .16562 .38632 .16992 .38478 .16687 .38195 Mtetra
.16687 .38195 .16992 .38478 .17423 .38325 .17119 .3804 Mtetra
.17119 .3804 .17423 .38325 .17855 .38171 .17551 .37886 Mtetra
.17551 .37886 .17855 .38171 .18288 .38017 .17984 .37732 Mtetra
.17984 .37732 .18288 .38017 .18721 .37862 .18418 .37577 Mtetra
.18418 .37577 .18721 .37862 .19155 .37708 .18852 .37422 Mtetra
.18852 .37422 .19155 .37708 .1959 .37553 .19287 .37266 Mtetra
.19287 .37266 .1959 .37553 .20025 .37398 .19723 .37111 Mtetra
.19723 .37111 .20025 .37398 .20461 .37242 .2016 .36955 Mtetra
.2016 .36955 .20461 .37242 .20898 .37087 .20597 .36798 Mtetra
.20597 .36798 .20898 .37087 .21336 .36931 .21036 .36642 Mtetra
.21036 .36642 .21336 .36931 .21775 .36774 .21474 .36485 Mtetra
.21474 .36485 .21775 .36774 .22214 .36618 .21914 .36328 Mtetra
.21914 .36328 .22214 .36618 .22654 .36461 .22354 .36171 Mtetra
.22354 .36171 .22654 .36461 .23094 .36304 .22796 .36014 Mtetra
.22796 .36014 .23094 .36304 .23536 .36147 .23237 .35856 Mtetra
.23237 .35856 .23536 .36147 .23978 .35989 .2368 .35698 Mtetra
.2368 .35698 .23978 .35989 .24421 .35832 .24123 .3554 Mtetra
.24123 .3554 .24421 .35832 .24865 .35674 .24568 .35381 Mtetra
.24568 .35381 .24865 .35674 .25309 .35515 .25012 .35222 Mtetra
.25012 .35222 .25309 .35515 .25754 .35357 .25458 .35063 Mtetra
.25458 .35063 .25754 .35357 .262 .35198 .25904 .34904 Mtetra
.25904 .34904 .262 .35198 .26647 .35039 .26352 .34744 Mtetra
.26352 .34744 .26647 .35039 .27094 .34879 .268 .34584 Mtetra
.268 .34584 .27094 .34879 .27543 .34719 .27248 .34424 Mtetra
.27248 .34424 .27543 .34719 .27992 .34559 .27698 .34263 Mtetra
.27698 .34263 .27992 .34559 .28441 .34399 .28148 .34103 Mtetra
.28148 .34103 .28441 .34399 .28892 .34239 .28599 .33942 Mtetra
.28599 .33942 .28892 .34239 .29343 .34078 .29051 .3378 Mtetra
.29051 .3378 .29343 .34078 .29795 .33917 .29503 .33619 Mtetra
.29503 .33619 .29795 .33917 .30248 .33756 .29957 .33457 Mtetra
.29957 .33457 .30248 .33756 .30702 .33594 .30411 .33295 Mtetra
.30411 .33295 .30702 .33594 .31156 .33432 .30866 .33132 Mtetra
.30866 .33132 .31156 .33432 .31612 .3327 .31321 .3297 Mtetra
.31321 .3297 .31612 .3327 .32068 .33107 .31778 .32807 Mtetra
.31778 .32807 .32068 .33107 .32524 .32945 .32235 .32643 Mtetra
.32235 .32643 .32524 .32945 .32982 .32782 .32693 .3248 Mtetra
.32693 .3248 .32982 .32782 .3344 .32618 .33152 .32316 Mtetra
.33152 .32316 .3344 .32618 .33899 .32455 .33612 .32152 Mtetra
.33612 .32152 .33899 .32455 .34359 .32291 .34072 .31988 Mtetra
.34072 .31988 .34359 .32291 .3482 .32127 .34533 .31823 Mtetra
.34533 .31823 .3482 .32127 .35282 .31962 .34995 .31658 Mtetra
.34995 .31658 .35282 .31962 .35744 .31798 .35458 .31493 Mtetra
.35458 .31493 .35744 .31798 .36207 .31633 .35922 .31327 Mtetra
.35922 .31327 .36207 .31633 .36671 .31467 .36386 .31161 Mtetra
.36386 .31161 .36671 .31467 .37136 .31302 .36852 .30995 Mtetra
.36852 .30995 .37136 .31302 .37601 .31136 .37318 .30829 Mtetra
.37318 .30829 .37601 .31136 .38068 .3097 .37785 .30662 Mtetra
.37785 .30662 .38068 .3097 .38535 .30803 .38252 .30495 Mtetra
.38252 .30495 .38535 .30803 .39003 .30636 .38721 .30328 Mtetra
.38721 .30328 .39003 .30636 .39472 .30469 .3919 .3016 Mtetra
.3919 .3016 .39472 .30469 .39942 .30302 .3966 .29992 Mtetra
.3966 .29992 .39942 .30302 .40412 .30135 .40131 .29824 Mtetra
.40131 .29824 .40412 .30135 .40883 .29967 .40603 .29656 Mtetra
.40603 .29656 .40883 .29967 .41355 .29798 .41076 .29487 Mtetra
.41076 .29487 .41355 .29798 .41828 .2963 .41549 .29318 Mtetra
.41549 .29318 .41828 .2963 .42302 .29461 .42024 .29149 Mtetra
.42024 .29149 .42302 .29461 .42777 .29292 .42499 .28979 Mtetra
.42499 .28979 .42777 .29292 .43252 .29123 .42975 .28809 Mtetra
.42975 .28809 .43252 .29123 .43729 .28953 .43452 .28639 Mtetra
.43452 .28639 .43729 .28953 .44206 .28783 .43929 .28468 Mtetra
.43929 .28468 .44206 .28783 .44684 .28613 .44408 .28298 Mtetra
.44408 .28298 .44684 .28613 .45163 .28442 .44887 .28126 Mtetra
.44887 .28126 .45163 .28442 .45642 .28271 .45367 .27955 Mtetra
.45367 .27955 .45642 .28271 .46123 .281 .45848 .27783 Mtetra
.45848 .27783 .46123 .281 .46604 .27929 .4633 .27611 Mtetra
.4633 .27611 .46604 .27929 .47086 .27757 .46813 .27439 Mtetra
.46813 .27439 .47086 .27757 .47569 .27585 .47297 .27266 Mtetra
.47297 .27266 .47569 .27585 .48053 .27412 .47781 .27093 Mtetra
0 .129 .647 r
.47781 .27093 .48053 .27412 .48531 .27816 .48259 .27497 Mtetra
.649 .759 .929 r
.48259 .27497 .48531 .27816 .49017 .27643 .48746 .27324 Mtetra
.48746 .27324 .49017 .27643 .49505 .2747 .49234 .2715 Mtetra
.49234 .2715 .49505 .2747 .49993 .27297 .49723 .26976 Mtetra
.49723 .26976 .49993 .27297 .50482 .27123 .50212 .26801 Mtetra
.50212 .26801 .50482 .27123 .50972 .26949 .50703 .26627 Mtetra
.50703 .26627 .50972 .26949 .51463 .26775 .51194 .26452 Mtetra
.51194 .26452 .51463 .26775 .51955 .266 .51687 .26277 Mtetra
.51687 .26277 .51955 .266 .52448 .26425 .5218 .26101 Mtetra
.5218 .26101 .52448 .26425 .52941 .2625 .52674 .25925 Mtetra
.52674 .25925 .52941 .2625 .53436 .26074 .53169 .25749 Mtetra
.53169 .25749 .53436 .26074 .53931 .25898 .53665 .25572 Mtetra
.53665 .25572 .53931 .25898 .54427 .25722 .54162 .25395 Mtetra
.54162 .25395 .54427 .25722 .54924 .25545 .5466 .25218 Mtetra
.5466 .25218 .54924 .25545 .55422 .25368 .55158 .25041 Mtetra
.55158 .25041 .55422 .25368 .55921 .25191 .55658 .24863 Mtetra
.55658 .24863 .55921 .25191 .56421 .25013 .56158 .24685 Mtetra
.56158 .24685 .56421 .25013 .56922 .24836 .56659 .24506 Mtetra
.56659 .24506 .56922 .24836 .57423 .24657 .57162 .24328 Mtetra
.57162 .24328 .57423 .24657 .57926 .24479 .57665 .24149 Mtetra
.57665 .24149 .57926 .24479 .58429 .243 .58169 .23969 Mtetra
.58169 .23969 .58429 .243 .58934 .24121 .58674 .23789 Mtetra
.58674 .23789 .58934 .24121 .59439 .23941 .5918 .23609 Mtetra
.5918 .23609 .59439 .23941 .59945 .23762 .59687 .23429 Mtetra
.59687 .23429 .59945 .23762 .60452 .23581 .60194 .23248 Mtetra
.60194 .23248 .60452 .23581 .6096 .23401 .60703 .23067 Mtetra
.60703 .23067 .6096 .23401 .61469 .2322 .61213 .22886 Mtetra
.61213 .22886 .61469 .2322 .61979 .23039 .61723 .22704 Mtetra
.61723 .22704 .61979 .23039 .6249 .22858 .62235 .22522 Mtetra
.62235 .22522 .6249 .22858 .63002 .22676 .62747 .22339 Mtetra
.62747 .22339 .63002 .22676 .63515 .22494 .6326 .22157 Mtetra
.6326 .22157 .63515 .22494 .64028 .22311 .63775 .21974 Mtetra
.63775 .21974 .64028 .22311 .64543 .22129 .6429 .2179 Mtetra
.6429 .2179 .64543 .22129 .65058 .21945 .64806 .21606 Mtetra
.64806 .21606 .65058 .21945 .65575 .21762 .65323 .21422 Mtetra
.65323 .21422 .65575 .21762 .66092 .21578 .65841 .21238 Mtetra
.65841 .21238 .66092 .21578 .66611 .21394 .6636 .21053 Mtetra
.6636 .21053 .66611 .21394 .6713 .2121 .6688 .20868 Mtetra
.6688 .20868 .6713 .2121 .6765 .21025 .67401 .20683 Mtetra
.67401 .20683 .6765 .21025 .68171 .2084 .67923 .20497 Mtetra
.67923 .20497 .68171 .2084 .68694 .20654 .68446 .20311 Mtetra
.68446 .20311 .68694 .20654 .69217 .20468 .6897 .20124 Mtetra
.6897 .20124 .69217 .20468 .69741 .20282 .69494 .19937 Mtetra
.69494 .19937 .69741 .20282 .70266 .20096 .7002 .1975 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 154.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000VR000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00QOooool2o`000<Cooooo0_l0
0013ooooo`00P_ooool3o`000003ooooool0003ooooo0<3ooooo0ol000000ooooooo0000ooooo`12
ooooo`00P?ooool2o`0000;ooooo0P2Y_NP2o`000;kooooo0_l00004ooooo`;o0000@_ooool007go
oooo0ol000002Oooool0ZKgX0:Vmj02Y_NSoZKgX0:Vmj?l0003oooooo`00002jooooo`?o00001_oo
ool00ol0003oooooo`000011ooooo`00N_ooool3o`0000;ooooo00?oZKgX0:Vmj?nY_NP0102Y_NP0
0ol00000ZKgXo`00002hooooo`;o00002Oooool00ol0003oooooo`000011ooooo`00N?ooool2o`00
00;ooooo1`2Y_NP01?nY_NP0ZKgXojVmj?l000020:Vmj003o`000?oooooooooo0;;ooooo0ol0000;
ooooo`04o`000?ooooooooooo`00043ooooo001eooooo`?o00000_ooool01OnY_NP0ZKgXojVmj02Y
_NSoZKgX00L0ZKgX00Go00000:Vmj?nY_NSoooooo`00002`ooooo`?o00003_ooool01Ol0003ooooo
oooooooooooo000003oooooo001cooooo`;o00000_ooool00onY_NP0ZKgX0:Vmj0060:Vmj003ojVm
j02Y_NP0ZKgX00<0ZKgX00Go00000:Vmj02Y_NP0ZKgXo`00002^ooooo`;o00004Oooool01Ol0003o
oooooooooooooooo000003oooooo001`ooooo`?o000000?ooooo0:Vmj02Y_NP00`2Y_NP00onY_NP0
ZKgXojVmj0070:Vmj005ojVmj02Y_NSoZKgXo`000?nY_NP00P2Y_NP00ooooooo0000ooooo`2Yoooo
o`?o00005?ooool01Ol0003ooooooooooooooooo000003kooooo001^ooooo`;o00000_ooool00onY
_NP0ZKgX0:Vmj0080:Vmj003ojVmj02Y_NP0ZKgX00H0ZKgX00Oo00000:Vmj02Y_NSoZKgX0:Vmj?oo
oooo00000:Oooooo0_l0000Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>ooo
ool006_ooooo0ol000000oooool0ZKgX0:Vmj0030:Vmj005ojVmj02Y_NSoZKgX0:Vmj?nY_NP01`2Y
_NP01onY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj?l000001@2Y_NP00ol0003oooooooooo`2Rooooo`?o
00006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo001Xooooo`?o0000
0_ooool00onY_NP0ZKgXojVmj0090:Vmj005ojVmj02Y_NSoZKgX0:Vmj?nY_NP0202Y_NP01?l0003o
ZKgX0:Vmj?nY_NP20:Vmj003ooooool0003ooooo0:3ooooo0_l0000Looooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0>_ooool006Kooooo0_l00002ooooo`L0ZKgX00?oZKgX0:Vmj?nY
_NP02`2Y_NP00onY_NP0ZKgX0:Vmj0050:Vmj007o`00002Y_NP0ZKgX0:Vmj?nY_NP0ZKgXo`00002N
ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo001Soooo
o`?o00000_ooool00onY_NP0ZKgXojVmj0090:Vmj005ojVmj02Y_NSoZKgX0:Vmj?nY_NP02@2Y_NP0
1_nY_NP0ZKgXojVmj02Y_NSoZKgXo`0000H0ZKgX00?o0000ooooooooool0VOooool2o`00027ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0iooooo`00HOooool2o`0000;ooooo1`2Y
_NP00onY_NP0ZKgX0:Vmj00;0:Vmj004ojVmj02Y_NP0ZKgXojVmj0T0ZKgX00Go00000:Vmj?nY_NP0
ZKgXojVmj0020:Vmj003ooooool0003ooooo09Kooooo0ol0000Sooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0>?ooool005kooooo0ol00002ooooo`05ojVmj02Y_NSoZKgX0:Vmj?nY
_NP01`2Y_NP01onY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NP02@2Y_NP01OnY_NP0ZKgXojVmj02Y
_NSoZKgX00<0ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00onY_NP0ZKgXo`00002Eooooo`;o00009_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Oooooo001Looooo`;o00000oooool0
0`3RbKl0ZKgX0:Vmj0040:Vmj003ojVmj02Y_NP0ZKgX00T0ZKgX00GoZKgX0:Vmj?nY_NP0ZKgXojVm
j0090:Vmj007ojVmj02Y_NSoZKgX0:Vmj?nY_NSo0000ojVmj0070:Vmj003o`000?oooooooooo08oo
oooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool005Wooooo
0ol00004ooooo`030:Vmj03RbKl0foRW00L0ZKgX00GoZKgX0:Vmj?nY_NP0ZKgXojVmj00;0:Vmj004
ojVmj02Y_NP0ZKgXojVmj0T0ZKgX00Oo00000:Vmj02Y_NP0ZKgXojVmj02Y_NSoZKgX0080ZKgX00?o
ooooo`000?ooool0S?ooool3o`0002_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0fooooo`00Eoooool2o`0000Gooooo1@2Y_NP00onY_NP0ZKgX0:Vmj0090:Vmj007ojVmj02Y_NSo
ZKgX0:Vmj?nY_NP0ZKgXojVmj0090:Vmj005ojVmj02Y_NSoZKgX0:Vmj?nY_NP00`2Y_NP00ol00000
ZKgX0:Vmj0050:Vmj003ojVmj02Y_NSo000008_ooooo0_l0000^ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0=Oooool005Cooooo0ol00004ooooo`80ZKgX00CoZKgX0:Vmj?nY_NP0
ZKgX0P3RbKl20:Vmj003ojVmj02Y_NP0ZKgX00`0ZKgX00OoZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSo
ZKgX00T0ZKgX00OoZKgX0:Vmj?nY_NSo0000ojVmj02Y_NSoZKgX00L0ZKgX00?o0000ooooooooool0
QOooool3o`00033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0eooooo`00DOoo
ool3o`0000Cooooo2P2Y_NP20>;9_`@0ZKgX00GoZKgX0:Vmj?nY_NP0ZKgXojVmj00>0:Vmj005ojVm
j02Y_NSoZKgX0:Vmj?nY_NP01`2Y_NP03Ol00000ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVm
j02Y_NSoZKgXooooool00000Q?ooool2o`0003?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0dooooo`00Coooool2o`0000Gooooo00GoZKgX0:Vmj?nY_NP0ZKgXojVmj0080:Vmj003
0>;9_`2Y_NP0ZKgX00D0ZKgX00WoZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NP03@2Y
_NP01?nY_NP0ZKgX0:Vmj?nY_NP20:Vmj003o`00002Y_NP0ZKgX00H0ZKgX00CoZKgX0:Vmj?nY_NSo
0000POooool3o`0003Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0cooooo`00
C?ooool3o`0000Cooooo1P2Y_NP01onY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NP0102Y_NP00`3R
bKl0ZKgX0:Vmj00;0:Vmj009ojVmj02Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSoZKgX00/0ZKgX
00?oZKgXo`000?nY_NP00P2Y_NP00onY_NP0ZKgX0:Vmj0060:Vmj003o`000?oooooooooo07cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<oooool004[ooooo0_l0
0005ooooo`03ojVmj02Y_NP0ZKgX00`0ZKgX00?oZKgX0:Vmj?nY_NP00P2Y_NP0103RbKooZKgX0:Vm
j?nY_NP@0:Vmj007ojVmj02Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVmj0070:Vmj003o`00002Y_NP0ZKgX
00<0ZKgX00?oZKgX0:Vmj?nY_NP00P2Y_NP01?nY_NP0ZKgX0:Vmj?l0001jooooo`?o0000>oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03;ooooo0017ooooo`?o00000_ooool40:Vm
j007ojVmj02Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVmj00=0:Vmj003ojVmj03RbKl0h/Vo0080ZKgX00Oo
ZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSoZKgX0100ZKgX00SoZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSo
ZKgXo`0000`0ZKgX00?oZKgXo`000?ooool0Moooool2o`0003kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0aooooo`00AOooool2o`0000;ooooo302Y_NP01OnY_NP0ZKgXojVmj02Y
_NSoZKgX00`0ZKgX0P3RbKl60:Vmj009ojVmj02Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSoZKgX
0100ZKgX00Wo00000:Vmj?nY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NP01P2Y_NP00ol0003ooooo
ooooo`1booooo`?o0000@?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo037ooooo
0012ooooo`?o00000_ooool01OnY_NP0ZKgXojVmj02Y_NSoZKgX00@0ZKgX00<0@DVc0:Vmj02Y_NP0
2@2Y_NP00onY_NP0ZKgX0:Vmj0080:Vmj0030>;9_`2Y_NP0ZKgX00T0ZKgX00_oZKgX0:Vmj?nY_NP0
ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVmj0090:Vmj003o`00002Y_NP0ZKgX0080ZKgX00co
ZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NP0ZKgXooooool0001aooooo`;o0000@ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo033ooooo000oooooo`?o00000_ooool6
0:Vmj007ojVmj02Y_NSoZKgX0:Vmj?nY_NP0ZKgX000]/@0=0:Vmj004ojVmj02Y_NP0ZKgXojVmj0H0
ZKgX00<0h/VoojVmj02Y_NP04@2Y_NP01onY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NP0102Y_NP0
0ol00000ZKgX0:Vmj00;0:Vmj003ojVmj02Y_NSo000006kooooo0ol00015ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0;oooool003gooooo0_l00002ooooo``0ZKgX00GoZKgX0:Vm
j?nY_NP0ZKgX000]/@0A0:Vmj003ojVmj02Y_NSoZKgX0080ZKgX0P3RbKl01onY_NP0ZKgXojVmj02Y
_NSoZKgX0:Vmj?nY_NP0502Y_NP01OnY_NP0ZKgXo`00002Y_NSoZKgX0080ZKgX00?oZKgX0:Vmj?nY
_NP02@2Y_NP00ol0003oooooooooo`1Yooooo`;o0000B?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02oooooo000jooooo`?o00000_ooool00onY_NP0ZKgX0:Vmj00W0:Vmj0030>;9
_`25C8@0QDb400@0QDb400H0ZKgX08I=Q02Y_NSoZKgX0:Vmj?nY_NP20:Vmj003ojVmj02Y_NSoZKgX
00`0ZKgX00?o00000:Vmj02Y_NP01`2Y_NP02OnY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NSooooo
o`00001Wooooo`?o0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02kooooo
000hooooo`;o00000oooool30:Vmj003ojVmj02Y_NSoZKgX0140ZKgX00GoZKgX0:Vmj?nY_NP0ZKgX
ojVmj00@0:Vmj00308Y@Q025C8@0QDb400@0QDb40`26CH@00`26CHD0n[9[0:Vmj0070:Vmj00;ojVm
j02Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj?l000003P2Y_NP01?nY_NP0ZKgXojVm
j?l0001Tooooo`?o0000COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo
000eooooo`?o00000_ooool;0:Vmj003ojVmj02Y_NP0ZKgX00/0ZKgX00<0@dZc0:Vmj02Y_NP00`2Y
_NP01OnY_NP0ZKgXojVmj02Y_NSoZKgX00/0ZKgX00<0RU2408E<Q025C8@01025C8@308I=Q00308I=
Q@3j/V/0n[9[00h0ZKgX00WoZKgX0:Vmj?nY_NSo0000ojVmj02Y_NSoZKgX0:Vmj?nY_NP03@2Y_NP0
0ol0003oooooooooo`1Oooooo`;o0000D?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02gooooo000cooooo`;o00000_ooool@0:Vmj008ojVmj02Y_NP0ZKgXojVmj02Y_NSoZKgX0:Vm
j?nY_NP40:Vmj003000//02Y_NP0ZKgX00X0ZKgX00?oZKgX0:Vmj?nY_NP00P2Y_NP01OnY_NP0ZKgX
08E<Q02Y_NP0RU2400H0QDb40`26CH@01P26CHD0n[9[0?ZbJonY_NP0ZKgXojVmj0h0ZKgX00?o0000
0:Vmj02Y_NP01@2Y_NP00onY_NP0ZKgXojVmj0020:Vmj007ojVmj02Y_NSoZKgX0:Vmj?nY_NP0ZKgX
o`00001Nooooo`?o0000D_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02cooooo
000`ooooo`?o00000_oooolJ0:Vmj005ojVmj02Y_NSoZKgX0:Vmj?nY_NP04@2Y_NP01@25C8@0ZKgX
08E<Q02Y_NP0RU2400H0QDb40`26CH@02`26CHD0n[9[0?ZbJ`3j/V_oZKgX0:Vmj?nY_NP0ZKgXojVm
j02Y_NSoZKgX00T0ZKgX00?o00000:Vmj02Y_NP03`2Y_NP00onY_NP0ZKgXo`00001Kooooo`;o0000
EOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02_ooooo000]ooooo`?o00000_oo
oolR0:Vmj00308=9P@2Y_NP0ZKgX00h0ZKgX00D0QDb40:Vmj025C8@0ZKgX08Y@Q00608E<Q0<0QTf4
00<0QTf50?ZbJ`3j/V/00P3j/V/80:Vmj003ojVmj02Y_NSoZKgX0080ZKgX00WoZKgX0:Vmj?nY_NSo
0000ojVmj02Y_NSoZKgX0:Vmj?nY_NP03@2Y_NP00ooooooo0000ooooo`1Fooooo`?o0000Eoooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02_ooooo000[ooooo`;o00000oooool00onY
_NP0ZKgX0:Vmj00O0:Vmj0<0PdV100@0PDN108A9P@2Y_NSoZKgX2P2Y_NP01`26CH@0ZKgX08E<Q02Y
_NP0QDb40:Vmj02:D8@01P25C8@308I=Q00308I=Q@3j/V/0n[9[0080n[9[00<0Qdj508M?Q@2Y_NP0
0P27ChH;0:Vmj00;o`00002Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NP00P2Y
_NP02?nY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NSo0000EOooool2o`0003cooooo00P0QDMloooo
o`3iZeoooooo0?V[GP3iZegooooo0?VZG1Kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Zooooo`00:?ooool3o`0000;ooooo00OoZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSoZKgX00D0
ZKgX00CoZKgX09^2]`2KP[L0Vh:g502Y_NP01`24BH40PdV108=9P@23BH40PDN108A9P@24BH801024
BX820:Vmj00<ohE;P`25Bh?oQD^308E;P`2Y_NP0QTf40:Vmj025C8@0ZKgX08E<Q02Y_NP0RU241P25
C8@308I=Q00308I=Q@3j/V/0n[9[0080n[9[00<0Qdj508M?Q@27ChH00P27ChH20:Vmj00308Q@QP2Y
_NP0ZKgX00H0ZKgX00?o00000:Vmj02Y_NP04P2Y_NP00ol0003oooooooooo`1?ooooo`?o0000<_oo
ool01022AGd0n:eX0?R]J03eWDT7ooooo`060854O025Ag`0nJ]O0?V[G`22A7`0nJ]N0P3iZed20?VZ
G0030?VZF`3hZEWooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Yoooo
o`009_ooool2o`0000?ooooo0`2Y_NP03_nY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVm
j02Y_NSoZKgX0:Vmj00g@[40Vh:g0P3Na;l209^2]`l0ZKgX0`24BH4308=9P@030857P@24BH40Q4V2
00@0Q4Z20P25Bh<03?n5Bh<0QD^3ohE;P`25Bh<0ZKgX08I=Q02Y_NP0QDb40:Vmj025C8@0ZKgX08Y@
Q0H0QDb40`26CH@00`26CHD0n[9[0?ZbJ`020?ZbJ`0308M>Q@27ChD0Qdn60080Qdn600<0R4n608Q@
QP28D8H00P28D8H20:Vmj009ojVmj02Y_NSoZKgX0:Vmj?l00000ZKgXojVmj02Y_NSoZKgX0140ZKgX
00?o0000ooooooooool0C?ooool2o`0003?ooooo00<0000D0?R]J@22AGd00P3h[FP20?FMB@Cooooo
0`21A7`01@25Ag`0nJ]O0?V[G`22A7`0nJ]N0080nJ]M0P3iZU`00`3iZU/0n:UIooooo`0?ooooo`<0
Y/;]00?o0000ooooooooool04oooool00ol0003oooooooooo`0Yooooo`008oooool3o`0000;ooooo
00?oZKgX0:Vmj02Y_NP0202Y_NP01onY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj00g@[40102Y_NP209^2
]`090=k4_`2KP[OoZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSoZKgX00@0ZKgX0P24BH8308A9P@<0PdV1
00<0PDN108A9P@24BH801024BX8208E;P`0<ohE;P`25Bh?oQD^308E;P`2Y_NP0QTf40:Vmj025C8@0
ZKgX08E<Q02Y_NP0RU241P25C8@308I=Q00308I=Q@3j/V/0n[9[0080n[9[00<0Qdj508M?Q@27ChH0
0P27ChH00`28ChH0R52608Q@QP0208Q@QP030?Z`I@2Y_NP0ZKgX0080ZKgX00_oZKgXo`000?nY_NP0
ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVmj0020:Vmj00;ojVmj02Y_NSoZKgX0:Vmj?nY_NP0
ZKgXojVmj02Y_NSoZKgX0:Vmj?l00000Boooool3o`0003Gooooo00<0000D0?R]J@22AGd00P3h[FP0
1P22AGd0mIe90?FMBOooooooPTAl0894O0<0PDAl00D0QDMl0?V[G`3iZel0PTAl0?V[GP020?V[G@80
nJYL00<0nJYK0?RYF@3hZET03Oooool20:K2k@05ojK2k@2V`^d0Y/;]0:K2kOl000005Oooool00ol0
003oooooooooo`0Xooooo`008Oooool2o`0000?ooooo0`2Y_NP00onY_NP0ZKgXojVmj00:0:Vmj004
ojVmj02Y_NP0ZKgX03M2/@80ZKgX00ooZKgX0:Vmj?nY_NP0ZKgX0=k4_`2KP[L0g/Fo09^2]`2LP[Oo
ZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NP01024BH8308A9P@<0PdV100<0PDN108A9P@24BH801024BX82
08E;P`0<ohE;P`25Bh?oQD^308E;P`2Y_NP0QTf40:Vmj025C8@0ZKgX08E<Q02Y_NP0RU241P25C8@3
08I=Q00308I=Q@3j/V/0n[9[0080n[9[00<0Qdj508M?Q@27ChH00P27ChH00`28ChH0R52608Q@QP02
08Q@QP040?Z`I@29DHL0RE6708UAQ`80ZKgX00?o00000:Vmj02Y_NP0502Y_NP00ol0003ooooooooo
o`16ooooo`;o0000<Oooool00`3g[F_oooooooooo`04ooooo`030?R/J@3h[FT0PTEm0080n:eX00H0
PTEm0?FMB@3eWDT0mIe9oh94O022A7`30854O00508E7O03iZel0nJ]O0894O03iZeh00P3iZed20?VZ
G0060?VZF`3hZET0n:UI0?RYFOooool0000B0P3iZET20?VYF0?ooooo00?oY/;]0:K2kOnV`^d00`2V
`^d01OnV`^d0Y/;]ojK2kOl00000Y/;]01Gooooo00?o0000ooooooooool09oooool001kooooo0ol0
0002ooooo`T0ZKgX00?oZKgX0:Vmj?nY_NP02@2Y_NP02P2KP[L0=d:a0:Vmj?nY_NP0ZKgXojVmj02Y
_NSoZKgX0:Vmj?nY_NP20=k5_`0309b2]`24Bh<0Q4^30080Q4^30P25Bh<408A9PP<0Q4V10`23BH40
0`21Ah40Q4V108A9PP0408A:PP80QD^300koQD^308E;Pon5Bh<0QD^30:Vmj026CH@0ZKgX08E<Q02Y
_NP0QDb40:Vmj025C8@0RU240?VbKP@0QDb400@0n[9]08I=Q03j/V`0QTf5103j/V/00`27CXD0Qdn5
08M?QP0208M?QP0308Q?QP28D8H0R5260080R52600@0n[1U08UAQ`29DHL0RE670P29DXP00ol0003o
ZKgX0:Vmj00E0:Vmj003o`000?oooooooooo04;ooooo0ol0000aooooo`80PD=k00D0mje[0?R]J`3h
[F/0n:eZooooo`030?R/J@060?R]J@22AGd0n:eX0?R]J022AGd0mIe90P22AG`00on2A7`0PTAl0854
O0020854O00508E7O03iZel0nJ]O0894O03iZeh00P3iZed20?VZG0030?VZF`3hZET0n:UI00<0n:UI
0P3iZET20?VYF003ojK2k@2V`^d0Y/;]00<0Y/;]00?oY/;]0:K2k@2V`^d00`2V`^d00ol0003oY/;]
ooooo`0Dooooo`03o`000?oooooooooo02Oooooo000Looooo`;o00000oooool>0:Vmj003ojVmj02Y
_NP0ZKgX00H0ZKgX00<0Vh:gojVmj02Y_NP00`2Y_NP01onY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj?nY
_NP01024Bh<208E;P`@0Q4V20`24BH4308=9P@030857P@24BH40Q4V200@0Q4Z20P25Bh<02On5Bh<0
QD^3ohE;P`25Bh<0ZKgX08I=Q02Y_NP0QDb40:Vmj00308E<Q00408Y@Q03i/Vh0nK9^08E<Q0<0n[9]
0P3j/V`50?ZbJ`0308M>Q@27ChD0Qdn60080Qdn600<0R4n608Q@QP28D8H00P28D8H0103j/6D0RE67
08UAQ`29DHL208UBR005o`00003j/6<0RU:80:Vmj?nY_NP00P2Y_NP02onY_NP0ZKgXojVmj02Y_NSo
ZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSoZKgX0080ZKgX00GoZKgX0:Vmj?nY_NP0ZKgXo`000011oooo
o`?o0000<oooool30853N`030?N]J`3h[F/0n:e[0080n:eZ0`3h[6T01@3h[FT0PTEm0?R]J03h[FP0
PTEm00<0PTEl00?oPTAl0894O021A7`00P21A7`01@25Ag`0nJ]O0?V[G`22A7`0nJ]N0080nJ]M0P3i
ZU`00`3iZU/0n:UI0?RYF@030?RYF@030?VYF@2V`^d0Y/;]00T0Y/;]00GoY/;]0:K2kOnV`^d0Y/;]
o`0000020:K2kAGooooo00?o0000ooooooooool09_ooool001Wooooo0ol00002oooooaX0ZKgX00?o
ZKgX0:Vmj02Y_NP01P2Y_NP01?nY_NP0ZKgXojVmj02Y_NP408A;P`80QD^31024BH8308A9P@<0PdV1
00<0PDN108A9P@24BH801024BX8208E;P`09ohE;P`25Bh?oQD^308E;P`2Y_NP0QTf40:Vmj025C8@0
ZKgX00<0QDb400@0RU240?VbKP3i/Vh0QDb40`3j/Vd20?ZbK0D0n[9[00<0Qdj50?ZaJ027ChH00P27
ChH00`28ChH0R52608Q@QP0208Q@QP040?Z`I@29DHL0RE6708UAQ`80RE:800Go00000?Z`H`2:DXP0
RU:80?Z`HP0D0:Vmj003o`000?oooooooooo03cooooo0_l0000cooooo`H0PD=k00<0mje[0?R]J`3h
[F/00P3h[FX30?R/J@050?R]J@22AGd0n:eX0?R]J022AGd00`22AG`00on2A7`0PTAl0854O0020854
O00:08E7O03iZel0nJ]O0894O03iZeh0PTEl0?V[G@22AGd0nJYL0?VZF`<0n:UI2@2V`^d00onV`^d0
Y/;]ojK2k@060:K2k@04o`00002V`^d0Y/;]0:K2kACooooo00?o0000ooooooooool09_ooool001Ko
oooo0ol00002ooooo`03ojVmj02Y_NP0ZKgX01T0ZKgX00?o=d:a0:Vmj?nY_NP02P2Y_NP00onY_NP0
Q4^308A;P`0208A;P`80QD^31024BH8308A9P@<0PdV100<0PDN108A9P@24BH801024BX8208E;P`07
ohE;P`25Bh?oQD^308E;P`2Y_NP0QTf40:Vmj00508E<Q00408Y@Q03i/Vh0nK9^08E<Q0<0n[9]0P3j
/V`50?ZbJ`0308M>Q@3j/FP0n[5X0080Qdn600<0R4n608Q@QP28D8H00P28D8H0103j/6D0RE6708UA
Q`29DHL208UBR006o`00003j/6<0RU:808YBR03j/680001T502Y_NP00ol0003oooooooooo`0hoooo
o`?o0000=?ooool70853N`030?N]J`3h[F/0n:e[0080n:eZ0`3h[6T01@3h[FT0PTEm0?R]J03h[FP0
PTEm00<0PTEl00?oPTAl0894O021A7`00P21A7`03025Ag`0nJ]O0?V[G`22A7`0nJ]N0895O03iZed0
PTEm0?VZG03iZU/0n:UIojK2k@D0Y/;]00?oY/;]0:K2kOnV`^d02`2V`^d01?l0003oY/;]0:K2kOnV
`^dEooooo`03o`000?oooooooooo02Gooooo000Dooooo`;o00000oooool50:Vmj003ojVmj02Y_NP0
ZKgX01D0ZKgX0P0g@[4=0:Vmj0@0Q4^30P25Bh<408A9PP<0Q4V10`23BH400`21Ah40Q4V108A9PP04
08A:PP80QD^300GoQD^308E;Pon5Bh<0QD^30:Vmj00208I=Q0D0QDb400@0RU240?VbKP3i/Vh0QDb4
0`3j/Vd20?ZbK0D0n[9[00<0Qdj50?ZaJ03j/FP00P27ChH00`3j/FL0n[1V08Q@QP0208Q@QP050?Z`
I@29DHL0RE6708UAQ`29DXP00_l000002P3j/6<0RU:808YBR03j/680ZKgXojVmj02Y_NSoZKgX0:Vm
j?nY_NP20:Vmj009ojVmj02Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSoZKgX0080ZKgX00?oZKgX
0:Vmj?l00000>?ooool2o`0002oooooo00@0PD=k0?J]LP21@g/0mZeb2`21@g/00`3g[F/0n:e[0?R]
J`020?R]JP<0n:aY00D0n:eY0895O@3h[FP0n:eX0895O@030895O003oh94O022A7`0PDAl0080PDAl
00P0QDMl0?V[G`3iZel0PTAl0?V[GP22AG`0nJ]M0895O@H0Y/;]00?oY/;]0:K2k@2V`^d0102V`^d0
0onV`^d0Y/;]0:K2k@030:K2k@03ojK2k@2V`^goY/;]00;o0000102V`^dEooooo`03o`000?oooooo
oooo02Cooooo000Aooooo`?o00000_ooool00onY_NP0ZKgXojVmj0060:Vmj003ojVmj02Y_NSoZKgX
01D0ZKgX00<0=d:a0:Vmj02Y_NP02`2Y_NP408A;P`80QD^31024BH8308A9P@<0PdV100<0mk5e08A9
P@24BH801024BX8208E;P`05ohE;P`25Bh?oQD^308E;P`2Y_NP00P26CH@508E<Q00408Y@Q03i/Vh0
nK9^08E<Q0<0n[9]0P3j/V`50?ZbJ`0308M>Q@3j/FP0n[5X0080Qdn600<0n[5W0?Z`IP28D8H00P28
D8H00`3j/6D0RE67o`000002o`00000308UBR?l00000n[1S0080RU:800@0n[1R0?Z`H`2Y_NSoZKgX
1P2Y_NP00onY_NP0ZKgX0:Vmj00:0:Vmj003o`000?oooooooooo03;ooooo0ol0000aooooo`040853
N`3f[G80PD=k0?J]LP/0PD=k00<0mje[0?R]J`3h[F/00P3h[FX30?R/J@050?R]J@22AGd0n:eX0?R]
J022AGd00`22AG`00on2A7`0PTAl0854O0020854O00508E7O03iZel0nJ]O0894O03iZeh0102V`^d0
0onV`^d0Y/;]0:K2k@040:K2k@03ojK2k@2V`^d0Y/;]00<0Y/;]00?oY/;]0:K2kOnV`^d00P2V`^d3
o`0000030:K2kOl00000Y/;]00@0Y/;]5?ooool00ol0003oooooooooo`0Tooooo`004?ooool2o`00
00;ooooo0`2Y_NP01OnY_NP0ZKgXojVmj02Y_NSoZKgX00H0ZKgX00?oZKgX0:Vmj02Y_NP04@2Y_NP0
0olg@[40ZKgX0:Vmj00<0:Vmj0@0Q4^30P25Bh<408A9PP<0Q4V10`23BH401`3g/GD0n;5d0?RaM024
BX80n;5d0?RaL`24BX800P25Bh<01?n5Bh<0QD^3ohE;P`25Bh<308I=Q0D0QDb400@0RU240?VbKP3i
/Vh0QDb40`3j/Vd20?ZbK0D0n[9[00<0Qdj50?ZaJ03j/FP00P27ChH0103j/FL0n[1V08Q@QP28D8H3
o`0000060?Z`I@29DHL0n[1U0?Z`I029DXSo00000P2:DXP00`3j/680n[1S08]DR@0E0:Vmj003o`00
0?oooooooooo033ooooo0_l0000cooooo`040853N`3f[G80PD=k0?J]LP/0PD=k00<0mje[0?R]J`3h
[F/00P3h[FX30?R/J@050?R]J@22AGd0n:eX0?R]J022AGd00`22AG`00on2A7`0PTAl0854O0020854
O00508E7O03iZel0Y/;]0:K2kOnV`^d01P2V`^d00onV`^d0Y/;]0:K2k@030:K2k@03ojK2k@2V`^go
Y/;]00@0Y/;]0ol000050:K2k@03o`00002V`^goY/;]0080Y/;]5Oooool00ol0003oooooooooo`0S
ooooo`004?ooool01?l00000ZKgX0:Vmj?nY_NP60:Vmj003ojVmj02Y_NSoZKgX00H0ZKgX00?oZKgX
0:Vmj02Y_NP03`2Y_NP203M2/@h0ZKgX00@0Q4^30?JbO@24Bh<0m[9m0P25Bh<408A9PP<0Q4V10`23
BH401@3g/GD0n;5d0?RaM024BX80n;5d0080n;5c0P25Bh<01?n5Bh<0QD^3ohE;P`25Bh<308I=Q0D0
QDb400@0RU240?VbKP3i/Vh0QDb40`3j/Vd20?ZbK0D0n[9[00<0Qdj50?ZaJ03j/FP00P27ChH01@3j
/FOo0000o`000?l00000R52600<0n[1U0180RE670?Z`I@3j/6@0n[1T0?Z`Hol00000RU:80?Z`HP3j
/6<0ReB90:Vmj02<E8X0ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NP20:Vmj009ojVmj02Y_NSoZKgX0:Vm
j?nY_NP0ZKgXojVmj02Y_NSoZKgX0080ZKgX00?o0000ooooooooool0<?ooool00ol0003oooooo`00
000booooo`040853N`3f[G80PD=k0?J]LP/0PD=k00<0mje[0?R]J`3h[F/00P3h[FX30?R/J@050?R]
J@22AGd0n:eX0?R]J022AGd00`22AG`01On2A7`0PTAl0854O021A7coY/;]00H0Y/;]00?oY/;]0:K2
k@2V`^d00`2V`^d00onV`^d0Y/;]ojK2k@060:K2k@?o00001@2V`^d01OnV`^d0Y/;]0:K2k@2V`^go
000000<0Y/;]00?oY/;]ooooooooool04oooool00ol0003oooooooooo`0Rooooo`004?ooool00ol0
0000ZKgX0:Vmj0080:Vmj005ojVmj02Y_NSoZKgX0:Vmj?nY_NP0102Y_NP00onY_NP0ZKgXojVmj00?
0:Vmj00303M2/@2Y_NP0ZKgX00`0ZKgX00@0Q4^30?JbO@24Bh<0m[9m0P25Bh<308A9PP040000?@24
BH40Q4V108A9P@<0PdV100D0mk5e0?RaM03h/G@0Q4Z20?RaM0020?RaL`80QD^300CoQD^308E;Pon5
Bh<0QD^30`26CH@508E<Q00408Y@Q03i/Vh0nK9^08E<Q0<0n[9]0P3j/V`60?ZbJ`80n[5X0ol00000
103j/6H0R52608Q@QP28D8H30?Z`I@0408UAQ`3j/6D0n[1T0?Z`I080n[1S00Co00000?Z`HP3j/6<0
ReB90P2<E8X01@2<EHX0ZKgXojVmj02Y_NSoZKgX00@0ZKgX00?oZKgX0:Vmj02Y_NP0202Y_NP00ol0
003oooooooooo`0_ooooo`04o`000?ooooooooooo`00037ooooo00@0PD=k0?J]LP21@g/0mZeb2`21
@g/00`3g[F/0n:e[0853N`020?R]JP<0n:aY00D0n:eY0895O@3h[FP0n:eX0895O@030895O003oh94
O02V`^d0Y/;]00<0Y/;]00?oY/;]0:K2k@2V`^d00`2V`^d00onV`^d0Y/;]ojK2k@060:K2k@03ojK2
k@2V`^go000000;o00000`2V`^d00onV`^d0Y/;]0:K2k@050:K2k@03ojK2k@2V`^go000000@0Y/;]
5?ooool00ol0003oooooooooo`0Rooooo`004?ooool00ol0003ooooo0:Vmj00;0:Vmj003ojVmj02Y
_NSoZKgX0080ZKgX00GoZKgX0:Vmj?nY_NP0ZKgXojVmj00=0:Vmj003ocM2/@2Y_NP0ZKgX00d0ZKgX
00D0Q4^30?JbO@24Bh<0m[9m08E;P`0408A9PP040000?@24BH40Q4V108A9P@<0PdV100D0mk5e0?Ra
M03h/G@0Q4Z20?RaM0020?RaL`80QD^300CoQD^308E;Pon5Bh<0QD^30`26CH@508E<Q00408Y@Q03i
/Vh0nK9^08E<Q0<0n[9]0P3j/V`50?ZbJ`?o000000@0Qdn60?ZaI`3j/FL0n[1V0`28D8H30?Z`I@04
08UAQ`3j/6D0n[1T0?Z`I080n[1S00Co00000?Z`HP3j/6<0ReB90P2<E8X308aERPh0ZKgX00CoZKgX
0:Vmj02Y_NSo0000<Oooool01Ol0003ooooooooooooooooo000002oooooo00D0mZY/0853N`3f[G80
PD=k0?J]LP0;0853N`030?N]J`3h[F/0PD=k0080n:eZ0`3h[6T01@3h[FT0PTEm0?R]J03h[FP0PTEm
0080PTEl0P2V`^d00onV`^d0Y/;]0:K2k@030:K2k@03ojK2k@2V`^goY/;]00H0Y/;]00CoY/;]0:K2
k@2V`^d0Y/;]0ol000000`2V`^goY/;]0:K2k@060:K2k@03ojK2k@2V`^d0Y/;]00@0Y/;]00?o0000
0:K2kOnV`^d00`2V`^dDooooo`03o`000?oooooooooo027ooooo000?ooooo`04o`000?oooooooooo
ooooo``0ZKgX00?oZKgX0:Vmj?nY_NP00P2Y_NP01OnY_NP0ZKgXojVmj02Y_NSoZKgX00/0ZKgX00?o
=T:a0:Vmj02Y_NP03P2Y_NP01@24Bh<0m[9m08A;P`3f/Wd0QD^300@0Q4V200@0000m08A9P@24BH40
Q4V10`23BH401@3g/GD0n;5d0?RaM024BX80n;5d0080n;5c0P25Bh<01?n5Bh<0QD^3ohE;P`25Bh<3
08I=Q0D0QDb400@0RU240?VbKP3i/Vh0QDb40`3j/Vd20?ZbK080n[9[0ol00000103j/V/0n[5X08M?
Q@27ChH20?ZaI`0408Q?QP28D8H0n[1V08Q@QP<0n[1U00@0RE670?Z`I@3j/6@0n[1T0`3j/6<00ol0
0000n[1S08]DR@0208aDRP<0S5F:00<0S5J;0:Vmj?nY_NP0102Y_NP02OnY_NP0ZKgXojVmj02Y_NSo
ZKgX0:Vmj?nY_NP0ZKgXojVmj0020:Vmj003o`000?oooooooooo02gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0/ooooo`050?JZK021@g/0mZeb0853N`3f[G801021@g/00`2V`^d0
PD=k0853N`040853N`030?N]J`3h[F/0PD=k0080n:eZ0`3h[6T30:K2k@;oY/;]1@2V`^d00onV`^d0
Y/;]0:K2k@0<0:K2k@?o00001`2V`^d00onV`^d0Y/;]0:K2k@040:K2k@03ojK2k@2V`^goY/;]00<0
Y/;]00So00000:K2kOnV`^d0Y/;]ojK2k@3/SR3ooooo07`iL1;ooooo00?o0000ooooooooool08?oo
ool000oooooo00?o0000ooooooooool00oooool;0:Vmj003ojVmj02Y_NSoZKgX0080ZKgX00GoZKgX
0:Vmj?nY_NP0ZKgXojVmj00F0:Vmj00308I=Q02Y_NP0QTf40080ZKgX00D0Q4^30?JbO@24Bh<0m[9m
08E;P`0408A9PP040000?@24BH40Q4V108A9P@<0PdV100D0mk5e0?RaM03h/G@0Q4Z20?RaM0020?Ra
L`80QD^300CoQD^308E;Pon5Bh<0QD^30`26CH@408E<Q004ojO0j`2W`>/0Yl3[0?VbKP<0Yl3[00<0
n[9]0:O0j`3j/V`00_l000040?ZbJ`030?ZaJ027ChD0Qdn60080n[5W00@0R4n608Q@QP3j/6H0n[1V
0P3j/6D00`3k/e/0RE670?Z`I@020?Z`I0<0n[1S00<0n[1Ro`00002;E8T00P2<E8X308aERP0408aF
R`3j/600ZKgXojVmj080ZKgX00GoZKgX0:Vmj?nY_NP0ZKgXojVmj0080:Vmj003o`000?oooooooooo
02cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`050?JZK021@g/0mZeb
0853N`3f[G801021@g/00`2V`^d0PD=k0853N`040853N`030?N]J`3h[F/0PD=k0080n:eZ00<0n:aY
ojK2k@2V`^d01@2V`^d00onV`^d0Y/;]0:K2k@040:K2k@03ojK2k@2V`^d0Y/;]00D0Y/;]00?oY/;]
0:K2kOl000000_l000030:K2k@03ojK2k@2V`^goY/;]00H0Y/;]00?oY/;]0:K2kOnV`^d01@2V`^d0
1OnV`^d0Y/;]ojK2k@2V`^go000000@0Y/;]00<0k8hP07`iL?ooool04Oooool00ol0003ooooooooo
o`0Pooooo`003oooool00ol0003oooooooooo`04oooooa00ZKgX00GoZKgX0:Vmj?nY_NP0ZKgXojVm
j00=0:Vmj080QDb41026C8@608I=Q080Q4^300@0m[9m08A;P`3f/Wd0QD^31024BH80100003d0Q4V1
08A9P@24BH4308=9P@050?NaM@3h/G@0n;5d08A:PP3h/G@00P3h/G<208E;P`04ohE;P`25Bh?oQD^3
08E;P`<0QTf40`25C8@01OnW`>/0Yl3[ojO0j`2W`>_oYl3[00<0Yl3[0ol000020:O0j`@0n[9[00<0
n[5X08M?Q@27ChH00P3j/FL01028ChH0R5260?Z`IP3j/6H20?Z`I@80RE6700<0n[1U08UBR03j/6@0
0`3j/6<01@3j/680n[1So`00003j/680S5B:00<0S5F:00<0S5J;0?Z`H02Y_NP0402Y_NP00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:_ooool90853N`03
0:K2k@21@g/0PD=k00@0PD=k00<0mje[0?R]J`21@g/0502V`^d01?nV`^d0Y/;]0:K2k@2V`^d3o`00
00030:K2kOnV`^d0Y/;]00L0Y/;]00?oY/;]0:K2k@2V`^d00`2V`^d00onV`^d0Y/;]ojK2k@080:K2
k@03o`00002V`^d0Y/;]00<0Y/;]00<0O3U`ooooooooool04Oooool00ol0003oooooooooo`0Ooooo
o`003oooool00ol0003oooooooooo`05oooooa00ZKgX00?oZKgX0:Vmj?nY_NP0302Y_NP01025C8<0
QDb408E<Q025C8@408I<Q0H0QTf40P24Bh<0103f/Wd0Q4^30?JbO@25Bh<408A9PP040000?@24BH40
Q4V108A9P@<0PdV100D0mk5e0?RaM03h/G@0Q4Z20?RaM0030?RaL`0508E;Pon5Bh<0n;5bohE;P`25
Bh<00`26CH@208E<Q0@0Yl3[00?oYl3[0:O0jol000000_l000060:O0j`<0n[9[00<0n[5X08M?Q@27
ChH00P3j/FL01028ChH0R5260?Z`IP3j/6H20?Z`I@80RE6700@0n[1U08UBR029DXP0RE:80P3j/6<0
2P3j/680n[1So`00003j/680S5B:08aERP3j/640S5F:08aFR`3j/6070:Vmj005ojVmj02Y_NSoZKgX
0:Vmj?nY_NP00P2Y_NP01OnY_NP0ZKgXojVmj02Y_NSo000002gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Yooooo`T0PD=k00<0Y/;]0853N`21@g/01021@g/00`3g[F/0Y/;]0:K2
k@060:K2k@03ojK2k@2V`^goY/;]00@0Y/;]00?oY/;]0:K2kOnV`^d01@2V`^d00onV`^go0000o`00
00060:K2k@03ojK2k@2V`^goY/;]00D0Y/;]00?oY/;]0:K2kOnV`^d01`2V`^d00onV`^d0Y/;]0:K2
k@040:K2k@03o`00002V`^goY/;]0080Y/;]0P1l>G000`2V`Ngoooooooooo`0@ooooo`03o`000?oo
oooooooo01kooooo000?ooooo`03o`000?oooooooooo00Kooooo402Y_NP00onY_NP0ZKgXojVmj004
0:Vmj003ojVmj02Y_NP0ZKgX00@0ZKgX00@0QDb308E<Q025C8@0QDb41026C8@608I=Q080Q4^300@0
m[9m08A;P`3f/Wd0QD^31024BH80100003d0Q4V108A9P@24BH4208=9P@060857P@3g/GD0n;5d0?Ra
M024BX80n;5d0`3h/G<01@25Bh?oQD^30?RaL_n5Bh<0QD^300<0QTf41@2W`>/3o`0000080:O0jonW
`>/0Yl3[ojO0j`2W`>_oYl3[0:O0jonW`>/20:O0j`80n[9[00<0n[5X08M?Q@27ChH00P3j/FL01028
ChH0R5260?Z`IP3j/6H20?Z`I@80RE6700D0n[1U08UBR029DXP0RE:80?Z`H`0208YBR0090?Z`H`3i
[VOo000008aDRP3j/680n[1Q08aERP3j/640n[1P0080ZKgX00OoZKgX0:Vmj?nY_NP0ZKgXojVmj02Y
_NSoZKgX00@0ZKgX00?oZKgX0:Vmj02Y_NP00`2Y_NP00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0:?ooool90853N`040:K2k@21@g/0PD=k0853N`D0Y/;]
00?oY/;]0:K2kOnV`^d01@2V`^d00onV`^d0Y/;]ojK2k@040:K2k@03ojK2k@2V`^goY/;]0080Y/;]
0ol000030:K2k@03ojK2k@2V`^d0Y/;]00D0Y/;]00?oY/;]0:K2kOnV`^d01@2V`^d00onV`^d0Y/;]
ojK2k@060:K2k@03ojK2k@2V`^goY/;]00<0Y/;]00Ko00000:K2kOnV`^d0Y/;]ojK2k@1l>G020:K1
kA7ooooo00?o0000ooooooooool07_ooool000oooooo00?o0000ooooooooool01oooool@0:Vmj003
ojVmj02Y_NSoZKgX0080ZKgX00?oZKgX0:Vmj?nY_NP01@2Y_NP01025C8<0QDb408E<Q025C8@408I<
Q0H0QTf40P24Bh<0103f/Wd0Q4^30?JbO@25Bh<408A9PP030000?@24BH40Q4V100<0PdV100@0PDN1
08A9P@24BH80n;5d0P24BX830?RaL`0508E;Pon5Bh<0n;5bohE;P`25Bh<00P26CH@00`2W`>_oYl3[
0:O0j`03o`0000L0Yl3[00KoYl3[0:O0jonW`>/0Yl3[ojO0j`2W`>/20?ZbJ`030?ZaJ027ChD0Qdn6
0080n[5W00@0R4n608Q@QP3j/6H0n[1V0P3j/6D208UAQ`050?Z`I@29DXP0RE:808UBR03j/6<00P2:
DXP03@3j/680nJiW0?Z`H_l00000n[1R0?Z`H@2<EHX0n[1Q0?Z`H02Y_NSoZKgX0:Vmj?nY_NP03@2Y
_NP00onY_NP0ZKgXo`00000/ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09ooo
ool90853N`050:K2k@21@g_oY/;]0:K2kOnV`^d01@2V`^d00onV`^d0Y/;]ojK2k@0=0:K2k@?o0000
1`2V`^d00onV`^d0Y/;]ojK2k@050:K2k@03ojK2k@2V`^goY/;]00P0Y/;]00?oY/;]0:K2k@2V`^d0
1@2V`^d02OnV`^d0Y/;]ojK2k@2V`^go00000:K2kOnV`Nd0Y/;]ojK1k@020:K1kA;ooooo00?o0000
ooooooooool07Oooool000oooooo00?o0000ooooooooool02?ooool@0:Vmj006ojVmj02Y_NP0ZKgX
ojVmj02Y_NSoZKgX1P2Y_NP01025C8<0QDb408E<Q025C8@408I<Q0H0QTf40P24Bh<0103f/Wd0Q4^3
0?JbO@25Bh<408A9PP030000?@24BH40Q4V100<0PdV100@0PDN108A9P@24BH80n;5d0`24BX820?Ra
L`0708E;Pon5Bh<0n;5bohE;P`25Bh<0QTf40:O0j`03o`0000030:O0jonW`>/0Yl3[00X0Yl3[00Go
Yl3[0:O0jonW`>/0Yl3[0?ZbJ`030?ZaJ080n[5W00@0R4n608Q@QP3j/6H0n[1V0P3j/6D208UAQ`05
0?Z`I@29DXP0RE:808UBR03j/6<00P2:DXP02P3j/680nJiW0?Z`HP2<E8[o00000?Z`H@2<EHX0n[1Q
0?Z`H02>F8`;0:Vmj009ojVmj02Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSo000002[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`P0PD=k102V`^d00onV`^d0Y/;]ojK2
k@0@0:K2k@04ojK2kOl0003o0000o`0000<0Y/;]00?oY/;]0:K2kOnV`^d01@2V`^d01OnV`^d0Y/;]
ojK2k@2V`^goY/;]00H0Y/;]00?oY/;]0:K2k@2V`^d0102V`N`01P2V`^d0Y/7/0:K1k?nV`N`0Y/7/
ojK1k0<0Y/7/00@0U6fT02lZVP2DKJCo0000102V`Nd00onV`Nd0Y/7]ojK1k@0Booooo`03o`000?oo
oooooooo01cooooo000>ooooo`03o`000?oooooooooo00[ooooo4`2Y_NP00onY_NP0ZKgXojVmj005
0:Vmj00408E<P`25C8@0QDb408E<Q0@0QTb41P26CH@208A;P`040?JbO@24Bh<0m[9m08E;P`@0Q4V2
0`24BH4308=9P@040857P@24BH40Q4V20?RaM0<0Q4Z20P3h/G<01025Bh?oQD^30?RaL_n5Bh<3o`00
00L0Yl3[00?oYl3[0:O0jonW`>/02@2W`>/00`2<FI00n[9[0?ZaJ0020?ZaJ0<0n[5W0`3j/6H20?Z`
I@80RE6700D0n[1U08UBR029DXP0RE:80?Z`H`0208YBR0090?Z`HP3i[VL0n[1R08aDR_l00000n[1Q
08aERP3j/640S5J;0080SUR<00<0n[1Q0:Vmj?nY_NP00P2Y_NP01onY_NP0ZKgXojVmj02Y_NSoZKgX
0:Vmj?nY_NP01`2Y_NP00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool09Oooool50853N`03ojK2k@2V`^d0Y/;]0100Y/;]00?oY/;]0:K2kOnV`^d00P2V`^d3
o`0000030:K2kOnV`^d0Y/;]00H0Y/;]00?oY/;]0:K2kOnV`^d02`2V`^d30:K1k005ojK1k02V`Nco
Y/7/0:K1k?nV`N`01`2V`N`02OnV`N`0U6fT09A]Y02DKJ@0;bZJ0:K1kOnV`Ngo0000ojK1k@050:K1
k@03ojK1kOoooooooooo00oooooo00?o0000ooooooooool07?ooool000kooooo00?o0000oooooooo
ool02oooool00`2Y_NSoZKgX0:Vmj00@0:Vmj003ojVmj02Y_NSoZKgX0080ZKgX00?oZKgX0:Vmj025
C8<00`25C8@308I<Q0080?>aPP26CH@0QTf40?BaP@26CH@0m;6008I=Q024Bh<40?JbO@0308E;P`24
BH80Q4V20080Q4V20`24BH4308=9P@040857P@24BH40Q4V20?RaM0<0Q4Z20P3h/G<01@25Bh?o0000
o`000?l00000QD^30080n;Ik2P2W`>/01OnW`>/0Yl3[ojO0j`2W`>_oYl3[00<0Yl3[00<0S5Z@08aI
T03j/V/00`3j/FP30?ZaI`<0n[1V0P3j/6D00`29DHL0n[1U0?Z`I@0308UBR00<0?Z`H`2:DXP0RU:8
0?Z`HP3i[VL0n[1R08aDRP3j/6;o000008aERP3j/640S5J;0P2>F8`01`3j/640SUR=0:Vmj02Y_NSo
ZKgX0:Vmj?nY_NP02`2Y_NP00onY_NSo0000ooooo`0Xooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool05oooool0100000/0mJY^0?FZKP3eZVh2ooooo`030?JZKOoooooooooo00?ooooo
00<0mZY/0853N`21@g/03`2V`^d00onV`^d0Y/;]ojK2k@050:K2k@04ojK2kOl0003o0000o`0000D0
Y/;]00?oY/;]0:K2kOnV`^d01`2V`^d00onV`^d0Y/;]0:K2k@060:K2k@03ojK2k@2V`N`0Y/7/00D0
Y/7/00GoY/7/0:K1k?nV`N`0Y/7/ojK1k0040:K1k00409A^Y00_:YT0U6fT02lZV@<0Y/7]00GoY/7]
o`000?nV`Nd0Y/7]ojK1k@040:K1kA7ooooo00?o0000ooooooooool06oooool000kooooo00?o0000
ooooooooool03?ooool00`2Y_NSoZKgX0:Vmj00@0:Vmj004ojVmj02Y_NP0ZKgXojVmj080ZKgX00P0
l[6408E<Q025C8@0lk6308I<Q03c/H80QTb40?>aPP80QTf400D0m;6108I=Q03d/H00QTf408A;P`04
0?JbO@0308E;P`24BH80Q4V20080Q4V20`24BH4308=9P@040857P@24BH40Q4V20?RaM0<0Q4Z200L0
n;5co`000?l0003oQD^30?RaL_n5Bh<0QD^30080n;Ik3@2W`>/00onW`>/0Yl3[ojO0j`020:O0j`03
08aJT02<FI000@1c00<0n[5X0`3j/FL30?Z`IPH0n[1U00<0n[1T08UBR03j/6<00P2:DXP02@3j/680
nJiW0?Z`HP2<E8X0n[1R0?Z`HOl00000n[1Q08aFR`0208iHS0040?Z`H@2>F8d0n[1Q08iIS@H0ZKgX
00_oZKgX0:Vmj02Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSoZKgXo`00000Xooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool05_ooool00`0000/0mJY^0?FZKP020?FZKP80mZY]00?o
oooo0?JZK?ooool00_ooool00`3fZV`0Y/;]0:K2k@060:K2k@03ojK2k@2V`^goY/;]00L0Y/;]00?o
Y/;]0:K2kOnV`^d00P2V`^d3o`000080Y/;]00?oY/;]0:K2kOnV`^d01P2V`^d00onV`^d0Y/;]0:K2
k@060:K2k@03ojK2k@2V`^goY/;]00@0Y/;]00@0Y/7/ojK1k02V`NcoY/7/2@2V`N`02OnV`N`0Y/7/
0:K1k02DKZ@0;RVI02lZVOnV`Nd0Y/7]ojK1k@040:K1k@07o`000?nV`Nd0Y/7]ojK1k@2V`NgoY/7]
0:K1k@0Booooo`03o`000?oooooooooo01[ooooo000>ooooo`03o`000?oooooooooo00gooooo00<0
ZKgXojVmj02Y_NP04@2Y_NP01OnY_NP0ZKgXojVmj02Y_NP0l[640080QDb400D0lk6308I<Q03c/H80
QTb40?>aPP0608I=Q00308A;P`3f/Wd0m[9m0080m[9m00<0QD^308A9PP24BH800P24BH8308A9P@<0
PdV100D0PDN108A9P@24BH80n;5d08A:PP03o`0000060?RaL`25Bh?oQD^30?RaL_n5Bh<0QD^30`3h
]W/=0:O0j`07ojO0j`2W`>/0Yl3[0:O0j`2<FY00Yl3[08aIT0030?ZaJ0<0n[5W0`3j/6H60?Z`I@80
n[1T0P3j/6<02P2:DXP0n[1R0?V^I`2;E8T0S5B:0?Z`HP3j/67o00000?Z`H@2<EX/208iHS0080?Z`
H@2>F8d0n[1Q08iIS@2OQKOoZKgX0:Vmj?nY_NP20:Vmj005ojVmj02Y_NSoZKgX0:Vmj?nY_NP01@2Y
_NP00ooooooo0000ooooo`0Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Ooo
ool00`0000/0mJY^0?FZKP020?FZKP<0mZY]0P3fZV`20:K2k@03ojK2k@2V`^goY/;]00L0Y/;]00?o
Y/;]0:K2kOnV`^d01`2V`^d01?nV`^go0000o`000?l0000@0:K2k@03ojK2k@2V`^d0Y/;]00L0Y/;]
00?oY/;]0:K2k@2V`N`00`2V`N`01onV`N`0Y/7/ojK1k02V`NcoY/7/0:K1k?nV`N`01@2V`N`0102D
KZ@0Y/7/09A^Y00^:IT20:K1k@07ojK1k@2V`NgoY/7]0:K1kOnV`Nd0Y/7]o`0000050:K1k@05ojK1
k@2V`Ngooooooooooomo?7803_ooool00ol0003oooooooooo`0Jooooo`003_ooool00ol0003ooooo
ooooo`0>ooooo`050:Vmj?nY_NP0ZKgX0:Vmj?nY_NP03`2Y_NP00onY_NP0ZKgX08E<P`0308E<Q0@0
QTb400<0lk6208I=Q026CH@01026CH@00`24Bh<0m[9m0?JbO@020?JbO@0308E;P`24BH80Q4V20080
Q4V20`24BH4308=9P@030857P@24BH7o000000;o00000P24BX820?RaL`0508E;Pon5Bh<0n;5bohE;
P`25Bh<0103h]W/00`2W`>_oYl3[0:O0j`0>0:O0j`0308aJT02<FI00n[5X0080n[5X0`3j/FL30?Z`
IPH0n[1U0P3j/6@30?Z`H`050?Z`HP3i[VL0ReB90?Z`HP2<E8X00P2<EHX03_l00000S5J;08iHS02>
F8`0n[1Q08iHS@3j/640SUV=0:Vmj03Tc;l0ZKgXojVmj02Y_NSoZKgX2@2Y_NP00onY_NP0ZKgXo`00
000Wooooo`03o`000?oooooooooo00oooooo0_l0000Dooooo`0300002`1k>W<0O3Yc00<0mJY^0P3f
ZVd60:K2k@03ojK2k@2V`^goY/;]00T0Y/;]00?oY/;]0:K2k@2V`^d00P2V`^d3o`0000d0Y/;]00Co
Y/;]0:K2kOnV`^d0022T0`2V`^d01OnV`^d0Y/;]ojK2k@2V`^goY/;]00D0Y/;]00<0n;9c0:K1k02V
`N`01`2V`N`01OnV`N`0Y/7/ojK1k02V`NcoY/7/00<0Y/7/0P2DKZ@60:K1k@07ojK1k@2V`NgoY/7]
0:K1kOl00000Y/7]ojK1k@050:K1k@0307llL_mo?780Yl7/00kooooo00?o0000ooooooooool06Ooo
ool000kooooo00?o0000ooooooooool04?ooool30:Vmj003ojVmj02Y_NP0ZKgX00/0ZKgX0`2MPkL0
1025C8<0QDb408E<Q025C8@408I<Q0030?>aPP26CH@0QTf400@0QTf400<0Q4^30?JbO@3f/Wd00P3f
/Wd00`25Bh<0Q4V208A9PP0208A9PP<0Q4V10P23BH43o`00000308A9PP3h/G@0Q4Z20080Q4Z20P3h
/G<01@25Bh?oQD^30?RaL_n5Bh<0QD^300D0n;Ik0`2W`>/01OnW`>/0Yl3[ojO0j`2W`>_oYl3[00@0
Yl3[00OoSEZA0:O0j`000780001b08aJT02<FI000@1c0080n[5X0`3j/FL30?Z`IPH0n[1U0P3j/6@3
0?Z`H`0@0?Z`HP3i[VL0ReB90?Z`HP2<E8X0S5F:0?Z`H@2<EH[o00000?Z`H`2>F8`0n[1Q08iHS@3j
/640SUV=0:Vmj080i<bo1P2Y_NP02_nY_NP0ZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSoZKgX0:Vmj?l0
000Uooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool0100000X0000;07/j
L`1l>W<20?FZKP03ojK2k@2V`^d0Y/;]01D0Y/;]0_l000070:K2k@03ojK2k@2V`^goY/;]00L0Y/;]
00GoY/;]0:K2k@2;E8WoReB908]DR@040:K2k@03ojK2k@2V`^goY/;]00<0Y/;]00D0S5J;0?RbL`3h
/W<0Y/7/ojK1k0090:K1k003ojK1k02V`N`0Y/7/0080;RVI00H0U6jTojK1k@2V`NgoY/7]0:K1kOnV
`Nd70:K1k@09o`00002V`NgoY/7]0:K1kOnV`Nd0Y/7]ojK1k@1o?7;oOcab0080Yl7/3_ooool00ol0
003oooooooooo`0Hooooo`003_ooool00ol0003oooooooooo`0Aooooo`<0ZKgX00CoZKgX0:Vmj02Y
_NSoZKgX1`2Y_NP00onY_NP0WH>g09f3]`020:Vmj00408E<P`25C8@0QDb408E<Q0@0QTb400<0lk62
08I=Q026CH@01026CH@01P0003P0Yl3/0?JbO@2W`>`0m[9m08E;P`@0Q4V20P24BH43o`00000508=9
P@21Ah40Q4V108A9PP3h/G@00`24BX820?RaL`0408E;Pon5Bh<0n;5bohE;P`L0n;Ik0`2W`>/01029
DXT0Yl3[08UBR@2W`>/408UCR@06oheJT@000780S5Z@0000LP2<FY00S5V@102W`N`20?ZaI`<0n[1V
1P3j/6D20?Z`I0<0n[1S0180n[1R0?V^I`2;E8T0n[1R08aDRP2<EHX0n[1Q08aERP3j/67o00000?Z`
HP3j/640SUR=0?Z`H@2>FHgoZKgX0:Vmj03Tc;l40:Vmj005ojVmj02Y_NSoZKgX0:Vmj?nY_NP01`2Y
_NP00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03ooo
ool00`0000X0Y/;]07/jL`0?0:K2k@03ojK2k@2V`^d0Y/;]00H0Y/;]0ol000000onV`^d0Y/;]ojK2
k@070:K2k@05ojK2k@2V`^goY/;]0:K2kOnV`^d01@2V`^d208]DR@0=oh]DR@2;E8T0ReB909=JRP3h
/WD0ReB90?RbM02;E8X0n;9d08aERP2V`^d0n;9c08aFR`020?RbL`050:Vmj?nY_NP0ZKgXojVmj02Y
_NP01`2V`N`0102DKZ@0Y/7/09A^Y00^:IT40:K1k@05ojK1k@2V`NgoY/7]0:K1kOnV`Nd0102V`Nd0
0ol00000Y/7]0:K1k@020:K1k@06ojK1k@2V`NgoY/7]ogllL_nW`N`0Yl7/3_ooool00ol0003ooooo
ooooo`0Hooooo`003Oooool00ol0003oooooooooo`0Cooooo`H0ZKgX00?oZKgX0:Vmj02Y_NP01@2Y
_NP01@0g@[40ZKgX0:Vmj02Y_NP0QDb300<0QDb41026C8@00`3c/H80QTf408I=Q00408I=Q0030000
>@2W`>`0Yl3/0080Yl3/00@0QD^308A9PP24BH80Q4V20ol000002024BH40PdV108=9P@23BH40mk5e
08A9P@24BH80n;5d0`24BX820?RaL`0408E;Pon5Bh<0n;5bohE;P`L0n;Ik1P29DXT508UCR@05oheJ
T@000780S5Z@0000LP2<FY000`2W`N`00onW`N`0Yl7/ojO1k0020:O1k0030?Z`IP2W`N`0n[1U00D0
n[1U0P3j/6@30?Z`H`0;0?Z`HP3i[VL0ReB90?Z`HP2<E8X0S5F:0?Z`H@2<EHX0n[1Qo`00003j/680
0`3j/6402P2>FHd0ZKgX0:Vmj03Tc;l0ZKgXojVmj02Y_NSoZKgX0:Vmj?nY_NP90:Vmj003ojVmj?l0
003ooooo02?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`T0Y/;]00?o
Y/;]0:K2k@2V`^d01`2V`^d00onV`^d0Y/;]ojK2k@020:K2k@?o0000102V`^d00onV`^d0Y/;]ojK2
k@090:K2k@03ojK2k@2V`^goY/;]0080Y/;]00D0mkAl08aFR`2;E8T0ReB9oh]DR@0208]DR@0:09=J
RP3h/WD0ReB90?RbM02;E8X0n;9d08aERP2<EH/0n;9c08aFR`80n;9c00?oZKgX0:Vmj02Y_NP01@2Y
_NP20:K1k0030:Vmj02DKZ@0Y/7/0080U6jT00?oY/7]0:K1k@2V`Nd01`2V`Nd00onV`Nd0Y/7]ojK1
k@020:K1k@03o`00002V`Nd0Y/7]00D0Y/7]0`2W`N`>ooooo`03o`000?oooooooooo01Oooooo000=
ooooo`03o`000?oooooooooo01Cooooo102Y_NP01?nY_NP0ZKgX0:Vmj?nY_NP90:Vmj00408E<P`25
C8@0QDb408E<Q0@0QTb400<0lk6208I=Q026CH@01026CH@00`0003T0Yl3/0:O0k0020:O0k00508E;
Pol0003o0000o`000024BH800`24BH4308=9P@030?NaM@3h/G@0n;5d0080n;5d00P0n;5c08A:PP3h
/G<0n;5c08E;Pon5Bh<0n;5bohE;P`L0n;Ik1P29DXT508UCR@04oheJT@000780S5Z@0000LPL0Yl7/
00GoYl7/0:O1k?nW`N`0Yl7/ojO1k0020?Z`I@80Yl7/00<0n[1U0?Z`I03j/6@00`3j/6<02`3j/680
nJiW08]DR@3j/680S5B:08aERP3j/640S5F:0?Z`H@3j/63o000000@0n[1Q0`2Y_NP00`3Tc;l0ZKgX
0:Vmj0070:Vmj005ojVmj02Y_NSoZKgX0:Vmj?nY_NP00P2Y_NP00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00onV`^d0Y/;]0:K2k@070:K2k@03
ojK2k@2V`^goY/;]00T0Y/;]00GoY/;]o`000?l0003o0000ojK2k@070:K2k@05ojK2k@2V`^goY/;]
0:K2kOnV`^d01`2V`^d00onV`^d0Y/;]0?NdO@020?NdO00408aFR`2;E8T0ReB9oh]DR@<0ReB90P3h
/WD01`3h/W@0ReB:0?RbM02<EHX0S5F;0?RbL`2<EX/00P3h/W<00`0005X0ZKgX0:Vmj0060:Vmj00:
ojVmj02Y_NP0Y/7/02dXV@2DKZCoY/7]0:K1kOnV`Nd0Y/7]ojK1k@/0Y/7]00KoY/7]o`00002V`Ngo
Y/7]0:K1kOnW`N`60:O1k0kooooo00?o0000ooooooooool05_ooool000gooooo00?o0000oooooooo
ool05Oooool70:Vmj003ojVmj02Y_NP0ZKgX00<0ZKgX00@0>4>a0:Vmj02Y_NP0QDb30`25C8@408I<
Q0030?>aPP26CH@0QTf400@0QTf400@0000j0:O0k02W`>`0Yl3/0_l0000408A9PP<0Q4V10`23BH40
0`3g/GD0n;5d0?RaM0020?RaM0@0n;5c00@0QD^3ohE;P`3h/G;oQD^31`3h]W/608UBR@D0RE>900?o
SEZA0000LP0007802@2W`N`01OnW`N`0Yl7/ojO1k02W`NcoYl7/00L0Yl7/0P3j/6<0303j/680nJiW
0?V^I`3j/680S5B:08aERP3j/640S5F:0?Z`H@3j/600n[1Ro`0000<0n[1Q00D0ZKgXojVmj02Y_NP0
i<bo000000050:Vmj005ojVmj02Y_NSoZKgX0:Vmj?nY_NP01P2Y_NP00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool20:K2k@03ojK2k@2V`^goY/;]
00T0Y/;]00?oY/;]0:K2kOnV`^d01P2V`^d3o`000005ojK2k@2V`^goY/;]0:K2kOnV`^d01`2V`^d0
1OnV`^d0Y/;]ojK2k@2V`^goY/;]00L0Y/;]0P3g]7d20?NdO00408aFR`2;E8T0ReB9oh]DR@<0ReB9
0P3h/WD30?RbM00408aERP2<EH/0n;9c08aFR`80n;9c00<0001J0:Vmj02Y_NP00`2Y_NP01_nY_NP0
ZKgX0:Vmj?nY_NP0ZKgX02`XV0L0Y/7]00CoY/7]0:K1k@2V`NgoY/7]2@2V`Nd02_l00000Yl7/ojO1
k02W`NcoYl7/0:O1k?nW`N`0Yl7/ojO1k02W`N`>ooooo`03o`000?oooooooooo01Kooooo000=oooo
o`03o`000?oooooooooo01Kooooo202Y_NP00onY_NP0ZKgXojVmj0040:Vmj00408E<P`25C8@0QDb4
08E<Q0<0QTb400H0lk6208I=Q026CH@0m;6108I=Q03d/H0208I=Q0060000>_l0003o0000o`00002W
`>`0QD^30`24BH80100003d0Q4V108A9P@24BH4308=9P@030?NaM@3h/G@0n;5d0080n;5d103h/G<0
1025Bh?oQD^30?RaL_n5Bh<70?RfN`H0RE:91@29DhT01_n=FY40001b0:O1k?nW`N`0Yl7/ojO1k0/0
Yl7/00?oYl7/0:O1k02W`N`01`2W`N`20?V^I`0:0?Z`HP2<E8X0n[1R0?Z`H@2<EHX0n[1Q0?Z`H03j
/680n[1Qo`000080n[1Q00<0ZKgXojVmj02Y_NP00P2Y_NP01OnY_NP0ZKgXojVmj02Y_NSoZKgX00T0
ZKgX00?oZKgX0:Vmj?l000008_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?o
oooo102V`^d00onV`^d0Y/;]ojK2k@0;0:K2k@03ojK2k@2V`^goY/;]0080Y/;]0ol000040:K2k@06
ojK2k@2V`^goY/;]0:K2kOnV`^d0Y/;]102Y_NP02@2NPkL0BDjd0:Vmj02V`^goY/;]0:K2kOnV`^d0
Y/;]ojK2k@030:K2k@<0mkAm0P3g]7`208aFR`0308]DROn;E8T0ReB90080ReB90P3h/WD30?RbM004
08aERP2<EH/0n;9c08aFR`80n;9c1P2Y_NP00onY_NP0ZKgXojVmj0020:Vmj00302`XV02V`Nd0Y/7]
00/0Y/7]00?oY/7]0:K1kOnV`Nd00`2V`Nd00`2W`Nco00000:O1k0090:O1k0kooooo00?o0000oooo
ooooool05Oooool000gooooo00?o0000ooooooooool05oooool80:Vmj003ojVmj02Y_NP0ZKgX00<0
ZKgX00P0l[6408E<Q025C8@0lk6308I<Q03c/H80QTb40?>aPP80QTf400<0m;6108I=Q03d/H000ol0
00040:O0k0@0Q4V200@0000m08A9P@24BH40Q4V10`23BH400`3g/GD0n;5d0?RaM0020?RaM0<0n;5c
1P2V`^d60?RfN`H0RE:91@29DhT03@000780Yl7/ojO1k02W`NcoYl7/0:O1k?nW`N`0Yl7/ojO1k02W
`NcoYl7/0:O1k?nW`N`01@2W`N`02OnW`N`0Yl7/0:O1k?nW`N`0Yl7/ojO1k02W`NcoYl7/0:O1k002
0?V^I`0:0?Z`HP2<E8X0n[1R0?Z`H@2<EHX0n[1Q0?Z`H03j/680n[1Qo`000080n[1Q00OoZKgX0:Vm
j02Y_NP0ZKgX0>C<_`2Y_NSoZKgX00L0ZKgX00?oZKgX0:Vmj?nY_NP00P2Y_NP01?nY_NP0ZKgXojVm
j?l0000Pooooo`03o`000?oooooooooo00_ooooo0P2W`N`00`3cYFgoooooooooo`09ooooo`03o`00
0?ooool0Y/;]00T0Y/;]00GoY/;]0:K2k@2W`>/0Y/;]0:O0j`070:K2k@04ojK2kOl0003o0000o`00
00X0Y/;]00?oY/;]0:K2k@2Y_NP0102Y_NP0102NPkL0ZKgX0:Vmj?nY_NP20:Vmj0030?JdO`3f]7h0
m[An0080m[An103g]7d20?NdO080S5J;00<0ReB9oh]DR@2;E8T00P2;E8T20?RbM@D0n;9d00@0n;9c
08aFR`3h/W<0n;9c0`2Y_NP01OnY_NP0ZKgXojVmj02Y_NSoZKgX00D0ZKgX00@0Y/7]ojK1k@2V`Ngo
Y/7]2@2V`Nd01OnV`Nd0Y/7]ojO1k02W`NcoYl7/0080Yl7/00?o00000:O1k02W`N`0202W`N`>oooo
o`03o`000?oooooooooo01Cooooo000=ooooo`03o`000?oooooooooo01Sooooo2@2Y_NP01OnY_NP0
ZKgX03U3/@2Y_NP0l[640080QDb400D0lk6308I<Q03c/H80QTb40?>aPP0208I=Q0?o00000P26CH@0
0`0003X0Yl3/0:O0k0020:O0k0@0Q4V200@0000m08A9P@24BH40Q4V10`23BH400`3g/GD0n;5d0?Ra
M0020?RaM0<0n;5c1`2V`^d50?RfN`H0RE:91@29DhT00`3i^7`0Yl7/0:O1k0040:O1k007ojO1k02W
`NcoYl7/0:O1k?nW`N`0Yl7/ojO1k0060:O1k007ojO1k02W`NcoYl7/0:O1k?nW`N`0Yl7/ojO1k002
0?V^I`070?Z`HP2<E8X0n[1R0?Z`H@2<EHX0n[1Q0?Z`H00208iHS0030?Z`HOl00000n[1Q00@0ZKgX
0P3Tc;l50:Vmj006ojVmj02Y_NP0ZKgXojVmj02Y_NSoZKgX1@2Y_NP00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Wooooo00CoYl7/0:O1k02W`N`0Yl7/0P3cYFd:ooooo`h0Y/;]1P2W`>/2
0:K2k@?o00000P2V`^d00onV`^d0Y/;]0:K2k@080:K2k@H0ZKgX00CoWX>g04U>]02Y_NSoZKgX0P2Y
_NP01OnY_NP0Z;oZ0:RojP2X_nX0m[An0080Z;oZ0`3g]7d20?NdO080S5J;00<0ReB9oh]DR@2;E8T0
0P2;E8T20?RbM@D0n;9d103h/W<20:Vmj004ojVmj02Y_NP0ZKgXojVmj0P0ZKgX00SoZKgX0:Vmj02V
`NgoY/7]0:K1kOnV`Nd0Y/7]ojK1k@@0Y/7]202W`N`02_l00000Yl7/ojO1k02W`NcoYl7/0:O1k?nW
`N`0Yl7/oif3]`2MPkL>ooooo`03o`000?oooooooooo01Cooooo000=ooooo`03o`000?oooooooooo
01Wooooo2@2Y_NP01?nY_NP0>DBa0:Vmj03b/H@208E<Q0040?>aP`26C8@0lk6208I<Q0?o000000<0
m;6108I=Q03d/H000P26CH@50:O0k0@0Q4V200@0000m08A9P@24BH40Q4V10`23BH400`3g/GD0n;5d
0?RaM0020?RaM0<0n;5c202V`^d40?RfN`H0RE:90`29DhT00`3i]7@0RE>90?VhO00J0:O1k080nJiW
0`3j/680103j/640S5F:0?Z`H@2<EX/208iHS080n[1Q00Oo00000:Vmj02Y_NSoZKgX0:Vmj?nY_NP0
i<bo00<0ZKgX00GoZKgX0:Vmj?nY_NP0ZKgXojVmj0070:Vmj003ojVmj02Y_NSo000001oooooo00?o
0000ooooooooool01_ooool00onW`N`0Yl7/ojO1k0040:O1k080ljE]00<0lZE]ooooooooool01?oo
ool01OnV`^d0Y/;]ojK2k@2V`^goY/;]00/0Y/;]1`2W`>/2o`000003ojO0j`2V`^d0Y/;]00/0Y/;]
00?oZKgX0:Vmj?nY_NP0102Y_NP204Q=]0@0ZKgX00?oZKgX0:Vmj00005L0202X_nX01P3g]7`0Z;oZ
08aFR`2<EX/0ReB9oh]DR@<0ReB90P3h/WD50?RbM0@0n;9c0P2Y_NP00onY_NP0ZKgXojVmj0090:Vm
j003ojVmj02Y_NP0ZKgX0080UV^O00D0Y/7]ojK1k@2V`NgoY/7]0:K1k@0;0:O1k004o`00002W`N`0
Yl7/0:O1k0<0WH>g00?oWH>g09f3]`2W`N`03_ooool00ol0003oooooooooo`0Cooooo`003?ooool0
0ol0003oooooooooo`0Kooooo`03ojVmj02Y_NP0ZKgX00H0ZKgX00?oZKgX0:Vmj03b/H@00P25C8@0
1@3c/H?o0000o`000?l00000lk620080QTf400<0m;6108I=Q03d/H000P26CH@00`0003/0Yl3/0:O0
k0020:O0k0@0Q4V200@0000m08A9P@24BH40Q4V10`23BH400`3g/GD0n;5d0?RaM0020?RaM0<0n;5c
0`2V`^d00onV`^d0Y/;]0:K2k@020:K2k@@0n;Ik00D0RE:90?RdN029DXT0RE:90?VdM`020?VdMP04
08UCR@3i]7@0nKAd08UCR@80nKQl302W`N`00onW`N`0Yl7/ojO1k00:0:O1k080nJiW0`3j/6830?Z`
H@0A08aFR`2>F8`0SUR<0?Z`H@2>F8d0n[1Qo`00002Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVmj02Y_NSo
ZKgX0:Vmj?nY_NP01`2Y_NP00onY_NP0ZKgXojVmj0030:Vmj003o`000?oooooooooo01cooooo00?o
0000ooooooooool00oooool:0:O1k080ljE]0P3bYFd2ooooo`80Y/;]00GoY/;]0:K2kOnV`^d0Y/;]
ojK2k@0;0:K2k@03ojK2k@2W`>/0Yl3[0080Yl3[0ol000000`2W`>/0000X0:Vmj0020:Vmj0P0Y/;]
00GoTVBI099TV@2BI9T0TVBIojVmj0040:Vmj00304Q=]02NPkL0ZKgX00<0ZKgX00CoZKgX0:Vmj02Y
_NP0001H2`2X_nX00`2<EX/0ReB9oh]DR@0308]DR@80n;9e1@3h/W@40?RbL`030:Vmj?nY_NP0ZKgX
00P0ZKgX00?oZKgX0:Vmj?nY_NP00P2Y_NP03`0L3H00FCR?09I[W`3e`ID0UV^O0?K2U@3f`Y@0UVbO
ojO1k02W`NcoYl7/0:O1k?nW`N`0Yl7/ojO1k0040:O1k00:o`00002W`N`0WH>g09f3]`1JFKL0WH>g
ojO1k02W`NcoYl7/0:O1k0oooooo00?o0000ooooooooool04_ooool000cooooo00?o0000oooooooo
ool07?ooool00`2Y_NSoZKgX0:Vmj0070:Vmj0080?:aQ?l0003o0000o`000026C8@0lk6208I<Q03c
/H8208I=Q0030?BaP@26CH@0m;600080QTf41@2W`>`408A9PP040000?@24BH40Q4V108A9P@<0PdV1
00<0mk5e0?RaM03h/G@00P3h/G@20?RaL`030?NjQ`2V`^d0Y/;]00@0Y/;]00?oY/;]0:K2k@2V`^d0
0`3h]W/20?RdN00308UBR@3i]7L0nKAg0080nKAf00@0RE>90?VdM03i]7@0RE>90`3i^7`00onW`N`0
Yl7/ojO1k0070:O1k005ojO1k02W`NcoYl7/0:O1k?nW`N`00P2W`N`00onW`N`0Yl7/ojO1k0020:O1
k00409f3]onMPkL0WH>g0?V^I`<0n[1R103j/64208iHS0050?Z`H@2>F8d0n[1Qo`000?nY_NP00`2Y
_NP0103Tbkl0ZKgX0:Vmj?nY_NP60:Vmj003ojVmj02Y_NSoZKgX00H0ZKgX00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0=0:O1k080ljE]00<0lZE]0:K2k@2V`^d00P2V`^d01OnV`^d0Y/;]
ojK2k@2V`^goY/;]00d0Y/;]00T0l[65o`000?l0003o000008UAR03b/XL0RE:80?:aQ@3a/HH01@2Y
_NP01OnY_NP0ZKgX099TVOnBI9T0TVBI00;oTVBI1@2BI9T0103_^YT0ZKgX0:Vmj018CK@50:Vmj004
ojVmj02Y_NSoZKgX0000F0/0Z;oZ00<0S5J;08]DROn;E8T00`2;E8T20?RbM@D0n;9d103h/W<00`2Y
_NSoZKgX0:Vmj0080:Vmj003ojVmj02Y_NSoZKgX0080ZKgX00h070f005ThS`2FJil0mL6E0:Vnj@3f
`YD0ZKkY09I/W`3f`Y@0T5^?0:O1k?nW`N`0Yl7/ojO1k080Yl7/00GoYl7/0:O1k?nW`NcoYl7/o`00
000209f3]`H0Yl7/00?oYl7/ooooooooool03?ooool00ol0003oooooooooo`0Booooo`003?ooool0
0ol0003oooooooooo`0Mooooo`P0ZKgX0_l0000208E<Q0050?>aP`26C8@0lk6208I<Q03c/H800P26
CH@00`3d/H40QTf40?BaP00208I=Q0030?>gS02W`>`0Yl3/0080Yl3/1024BH801@0003d0Q4V108A9
P@24BH40000o00D0YL;^00GoYL;^0?RaM02U`^h0n;5c0:G2kP070:K2k@03ojK2k@2V`^goY/;]0080
n;Ik0P3h]7P00`29DXT0nKAg0?VdM`020?VdMP0408UCR@3i]7@0nKAd08UCR@@0nKQl00OoYl7/0:O1
k?nW`N`0Yl7/ojO1k02W`NcoYl7/00P0Yl7/00GoYl7/0:O1k?nW`N`0Yl7/oif3]`0209f3]`04ojO1
k02W`N`0Yl7/0:O1k080n[1R103j/64208iHS0090?Z`H@2>F8d0n[1Q08iISOl00000ZKgXojVmj02Y
_NSoZKgX00L0ZKgX00?oZKgX0:Vmj?nY_NP01`2Y_NP00onY_NP0ZKgXo`00000Mooooo`03o`00002W
`N`0Yl7/00h0Yl7/1`2V`^d00onV`^d0Y/;]ojK2k@0<0:K2k@?o00000P28DHP208UAR0040?:bQ`29
DXP0l[650000:@@0ZKgX00KoTVBI099TV@2BI9T0TVBIoi9TV@2BI9T2oi9TV@D0TVBI00<0kkZI099T
VOm8CK@01@2Y_NP01?nY_NP0ZKgX0:Vmj?nY_NP80:RojP03ojRojP2X_n[oZ;oZ0080Z;oZ00<0ReB9
oh]DR@2;E8T00P2;E8T20?RbM@D0n;9d103h/W<00onY_NP0ZKgX0:Vmj0050:Vmj003ojVmj02Y_NSo
ZKgX00D0ZKgX00<070f00:Vnj@2Y_^T00P2Y_^T01_nY_^T0ZKkY0:VnjOnY_^T0UVbO091KS`80Se^?
102W`N`309f3]`05ojO1k?l0003oYl7/0:O1k?nW`N`01P2W`N`>ooooo`03o`000?oooooooooo017o
oooo000<ooooo`03o`000?oooooooooo01oooooo00<0ZKgXojVmj02Y_NP00ol000002@2Y_NP0l[64
08E<Q025C8@0lk6308I<Q03c/H80QTb40?>aPP0208I=Q0030?BaP@26CH@0m;600080QTf400<0lkN<
08]GSP2W`>`00_n<FI0408A9PP030000?@24BH40Q4V100X0YL;^00<0mkZ70:K2k@2V`^d01@2V`^d0
1_nV`^d0Y/;]ojK2k@2V`^goY/;]0?RfN`80n;Ah00<0RE:90?VdM`3i]7L00P3i]7H00`29DhT0nKAd
0?VdM0060?VhO00608aHSP2W`NcoYl7/0:O1k?nW`N`0n[Ie2`2W`N`0102MPkOoWH>g09f3]onW`N`2
0:O1k004ojO1k02W`NcoYl7/0?Z`HP@0n[1Q0P2>F8`01P3j/640SUR=0?Z`H@2>FHd0ZKgXo`0000L0
ZKgX00?oZKgX0:Vmj?nY_NP01`2Y_NP00onY_NP0ZKgXojVmj0030:Vmj003o`000?oooooooooo01Wo
oooo00?o0000ooooo`2W`N`0402W`N`B0:K2k@?o000000<0l[:70?:aQ@0001`00P28DHP208UAR007
0?:bQ`29DXP0l[650000:P0002`0ZKgX099TV@02oi9TV@<0TVBI00KoTVBI099TVOnBI9WoTVBI0>ji
V@3_^IT40>njV@03099TV@3]_9l0ZKgX00H0ZKgX00?oZKgX0:Vmj00005T0102X_nX01OnX_nX0Z;oZ
ojRojP2X_n[oZ;oZ0080Z;oZ00<0001/08]DROn;E8T00`2;E8T20?RbM@D0n;9d103h/W<00onY_NP0
ZKgX0:Vmj0050:Vmj003ojVmj02Y_NSoZKgX00H0ZKgX102Y_^T01_nY_^T0ZKkYojVnj@2Y_^T0UVbO
091KS`80Se^?00<0Yl7/01<1M_nMPkL00`2MPkL01OnW`N`0Yl7/o`00002W`NcoYl7/0080Yl7/00Go
Yl7/0:O1k?nW`N`0Yl7/ojO1k00?ooooo`03o`000?oooooooooo013ooooo000<ooooo`03o`000?oo
oooooooo01oooooo0ol000001OnY_NP0ZKgX0:Vmj02Y_NP0l[640080QDb41026C8@00`3c/H80QTf4
08I=Q00508I=Q0030?>gS02;Ehh0S5V@00;oS5V@1024BH800`0003d0YL;^0:G2kP0;0:G2kPX0Y/;]
00?oY/;]0:K2k@2V`^d00P3h]7P00`29DXT0nKAg0?VdM`020?VdMP0308UCR@3i]7@0nKAd00H0nKQl
0P2<F8h308eHSP80n[Ie00<0SER=ojO1k02W`N`0102W`N`0102MPkOoWH>g09f3]`1DE[L40:O1k007
ojO1k02W`NcoYl7/0:O1k?nW`N`0Yl7/ojO1k0020?Z`H@060?Z`H`2>F8`0n[1Q08iHS@3j/640SUV=
0P2Y_NP01Ol00000ZKgX0:Vmj02Y_NSoZKgX0080ZKgX00?oZKgX0:Vmj02Y_NP0102Y_NP00onY_NP0
ZKgXojVmj0060:Vmj003o`000?oooooooooo01Wooooo00?o0000ooooooooool0402W`N`00`0002h0
Y/;]0:K2k@0<0:K2k@?o00000`2V`^d00`3b/XL0l[650?o7K`0208QAR080RE6800L0l[:708UBR03b
/HD0000Z099TVOnBI9T0TVBI00;oTVBI0`2BI9T00onBI9T0TVBI0:Vnj0030:Vnj0@0kkZI00<0TVBI
0>flW`3]_9l01P2Y_NP00onY_NP0ZKgX0000F@030:RojP03ojRojP2X_n[oZ;oZ0080Z;oZ00KoZ;oZ
0:RojP2X_nX0001/08]DROn;E8T208]DR@03ojO0k03h/WD0n;9e00D0n;9d103h/W<50:Vmj0<0TV6D
00<0ZKgXojVmj02Y_NP01P2Y_NP0102Y_^WoZKkY0:VnjOnY_^T40:Vnj@0709I/W`2@Fhl0Se^?08mK
S`2Y_^P04`5f05QH]`060:O1k00:o`00002W`N`0Yl7/ojO1k02W`NcoYl7/0:O1k?nW`N`0Yl7/ojO1
k0kooooo00?o0000ooooooooool04?ooool000cooooo00?o0000ooooooooool07?ooool3o`000003
ooooo`2Y_NSoZKgX0080ZKgX00?oZKgX08E<P`25C8@00P25C8@408I<Q0030?>aPP26CH@0QTf400D0
QTf400<0lkN<08]GSP2<FI000_n<FI0408A9PP<0YL;^00?oYL;^0:G2kP2U`^h0202U`^h=0:K2k@80
n;Ah00<0RE:90?VdM`3i]7L00P3i]7H00`29DhT0nKAd0?VdM0060?VhO080S5R>0`2=F8h20?ZfM@08
08eHS@3j]WD0Yl7/ojO1k02W`NcoWH>g09f3]`1CEKL?0:O1k0070?Z`H@3j/6<0n[1R0?Z`H@2>F8d0
n[1Q08iIS@020:Vmj007o`00002Y_NSoZKgX0:Vmj?nY_NP0ZKgXojVmj0050:Vmj003ojVmj02Y_NSo
ZKgX00L0ZKgX00?oZKgX0:Vmj?l000006_ooool01?l0003oooooooooooooool:0:O1k006ojO1k02W
`NcoYl7/0:O1k?nW`N`0Yl7/2`2V`^d3o`0000H0Y/;]00D0000H0?:aQ@3a/XP0R5680?6bR00208UA
R0070?:bQ`29DXP0l[650000:`2BI9WoTVBI099TV@02oi9TV@80TVBI00CoZKkX0:Vnj02Y_^SoZKkX
1P2Y_^P01@3_^YT0kkZH0>flW`3]_9l0hMIO00L0ZKgX00@0Z;oZojRojP2X_n[oZ;oZ0P2X_nX02?nX
_nX0Z;oZojRojP2X_n[oZ;oZ0:RojP0006`0ReB91@2W`>`00onW`>`0n;9d0?RbM0030?RbM0@0n;9c
0P2Y_NP2099QU003oi9QU02BHI@0TV6D00H0TV6D0P2CHI@20:Vmj00401h>P@2Y_^T0ZKkYojVnj@D0
ZKkY00D0T5^?0:Vnj02?Fhl0ZKkX01<1MP080:O1k003o`00002W`N`0Yl7/00L0Yl7/3_ooool00ol0
003oooooooooo`0?ooooo`003?ooool00ol0003oooooooooo`0Iooooo`?o00001_ooool0102Y_NSo
ZKgX0:Vmj025C8<208E<Q0040?>aP`26C8@0lk6208I<Q080lk6200@0QTf40?BaP@26CH@0m;600P26
CH@20?>gS00508]GSP2<FI3oS5V@ohaIT02<FI001`2U`^h00onU`^h0YL;^0:G2kP060:G2kP030?Ji
R?nV`^d0Y/;]00L0Y/;]0`2=G9<0102V`^d0n;Ah0?RdN029DXT20?VdM`060:K2kP3i]7H0RE>90:K2
kP3i]7@0Y/;^1@3i^7`208aHSP<0SER>0P3j]WD00`2=F8d0n[Ie08iKT00208iKT005oif3]`2MPkOo
Yl7/0:O1k?nW`N`03P2W`N`00`3j/6<0n[1R0?Z`H@020?Z`H@0508iIS@2Y_NP0ZKgX0:Vmj?l00000
0P2Y_NP00onY_NP0ZKgX0:Vmj0020:Vmj003ojVmj02Y_NSoZKgX0080ZKgX00?oZKgX0:Vmj02Y_NP0
0P2Y_NP00onY_NP0ZKgXojVmj0030:Vmj003o`000?oooooooooo01Oooooo00?o0000ooooooooool0
0_ooool80:O1k00:ojO1k02W`NcoYl7/0:O1k?nW`N`0Yl7/ojO1k02W`N`0Y/;]ojK2k@D0Y/;]0ol0
00080:K2k@060?:bQ`3b/H@0l[650?6bR028DHP0lK:8103b/XL01`3b/HD0000[099TVOnBI9T0TVBI
oi9TV@0006X0102Y_^P00onY_^P0ZKkX0:Vnj0070:Vnj080kKbO00P0hMIO09j4]`2NQ;L0g/>n0>Vo
ZP2Y_NSoZKgX0:Vmj0<0Z;oZ00OoZ;oZ0:Roj_nX_nX0Z;oZojRojP2X_nX0SebB0080Z;oZ00<0001/
0:O0k02W`>`01P2W`>`40?RbM0@0n;9c0P2Y_NP2099QU003oi9QU02BHI@0TV6D00H0TV6D0P2CHI@0
0`2CHID0Tf:E09=RU@080:Vnj@0:091KS`2Y_^P0Se^?0:Vnj00C0GKoYl7/0:O1k?nW`N`0Yl7/ojO1
k080Yl7/00WoYl7/0:O1k?l00000Yl7/ojO1k02W`NcoYl7/0:O1k?nW`N`00`2W`N`<ooooo`?o0000
4?ooool000_ooooo00?o0000ooooooooool05oooool3o`0000[ooooo0P2Y_NP01`3b/H@0QDb408E<
Q03c/H<0QTb40?>aPP26C8@00P3c/H801026CH@0m;6108I=Q03d/H0208I=Q0<0lkN<00H0S5V@ohaI
T?n<FI00S5V@ohaIT03c^8d60:G2kP03ojG2kP2U`^h0YL;^00D0YL;^00GoY/;]0:K2kOnV`^d0Y/;]
ojK2k@020:K2k@80SEbC00CoSEbC08eLT`2=G9<0SEbC0P0:1H400onV`^h0Y/;^0:K2kP080:K2kP@0
nKQl0P2<F8h308eHSP80n[Ie00<0SER=0?ZfM@2>Fi000P2>Fi003`2?G9;oYl7/0:O1k02W`NcoYl7/
0:O1k?nW`N`0Yl7/ojO1k02W`NcoYl7/0:O1k?nW`N`0Yl7/ojO1k0030:O1k0030?Z`H@3j/6<0n[1R
00@0n[1Q00D0ZKgXojVmj02Y_NSoZKgXo`0000060:Vmj003ojVmj02Y_NSoZKgX00D0ZKgX00?oZKgX
0:Vmj?nY_NP01@2Y_NP00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo202W`N`0
1OnW`N`0Yl7/ojO1k02W`NcoYl7/00<0QTn700<0Y/;]ojK2k@2V`^d00ol0000;0:K2k@060?:bQ`3b
/HD0l[650?6bR028DHP0lK:8103b/XL01@3b/HD0000[099TVOnBI9T0TVBI00P0ZKkX00?oZKkX0:Vn
j02Y_^P01P2Y_^P00`3]_9ooZKgX0:Vmj0020=k3_P0:0>VoZP2Y_NP0ZKgX0:Vmj00W27<0Z;oZ08mL
T@2X_n[oSebA08mLT@@0SebB00<0SefB0:RojP0006`02P2W`>`20?RbM0@0n;9c0P2Y_NP2099QU003
oi9QU02BHI@0TV6D00H0TV6D0P2CHI@0102CHID0Tf:E09=RU@0P48850:Vnj@07ojVnj@2Y_^T0T5^?
0:Vnj02?Fhl0ZKkX01@1M`040:O1k00;ojO1k02W`NcoYl7/0:O1k?nW`Nco0000ojO1k02W`NcoYl7/
0:O1k?nW`N`00P2W`N`00onW`N`0Yl7/ooooo`08ooooo`?o00000_ooool00ol0003oooooooooo`0>
ooooo`002oooool00ol0003oooooooooo`0Dooooo`?o00003_ooool0202Y_NP0l[6408E<Q025C8@0
lk6308I<Q03c/H80QTb40P3c/H801026CH@0m;6108I=Q03d/H0208I=Q0<0lkN<00L0S5V@ohaIT?n<
FI00S5V@0:K1k@3c^8d0Y/7]00H0YL;^00?oYL;^0:G2k_nU`^h0102U`^h01@2V`^goY/;]0:K2k@2=
G9<0Y/;]00@0SEbC00GoSEbC08eLT`2=G9<0SEbC00X5P@020:K2kP03ojK2kP2V`^h0Y/;^00P0Y/;^
0P3i^7`00`3a[X<0S5R>0?VgNP020?VgN@0508eHSP3j]WD0n[Ie08eHS@3j]WD00`2>Fi00302?G980
SefB0?ZiNonW`N`0Yl7/ojO1k02W`NcoYl7/0:O1k?nW`N`0Yl7/ojO1k080Yl7/00OoYl7/0:O1k?nW
`N`0Yl7/0?Z`HP3j/6<0n[1R00@0n[1Q00H0ZKgXojVmj02Y_NSoZKgX0:Vmj?l000020:Vmj004ojVm
j02Y_NP0ZKgXojVmj0@0ZKgX00?oZKgX0:Vmj?nY_NP01`2Y_NP00ooooooo0000ooooo`0Hooooo`03
o`000?oooooooooo00Cooooo2`2W`N`00`26ChP0QTn708I?Q`0208I?Q`;o00003P2V`^d01P3b/XL0
l[650?:aQ@3a/XP0R5680?6bR0@0l[:700@0l[650?6aQ`2Y_^SoZKkX2@2Y_^P00onY_^P0ZKkXojVn
j0060:Vnj0030:Vmj?nY_NP0ZKgX0080ZKgX00D0jKnZ0000002Y_NP0ZKgX02L8L`0308mLT@03ohmL
T@2?G940SebB00<0SebB00<0SefB0:RojP0006`03@2W`>`30?RbL`80ZKgX0P2BHI@00onBHI@0TV6D
099QU0030?NgP@030?NgP02BHI@0n;N00080Tf6D00@0Tf6E09=RU@2CHYD0Tf:E1@2Y_^T01onY_^T0
ZKkY091KS`2Y_^P0Se^?0:Vnj00D0WL02P2W`N`00ol00000Yl7/0:O1k0070:O1k0Gooooo0ol00005
ooooo`03o`000?oooooooooo00kooooo000;ooooo`03o`000?oooooooooo017ooooo0ol0000Boooo
o`070?:aQ025C8@0QDb40?>aP`26C8@0lk6208I<Q0020?>aPP0408I=Q03d/H40QTf40?BaP080QTf4
0`3c]h`00`2<FI00Y/7]0:K1k@050:K1k@@0YL;^00GoYL;^0:G2k_nU`^h0YL;^ojG2kP020:G2kP03
0:K2k@2=G9<0SEbC00L0SEbC00GoSEbC08eLT`2=G9<0SEbC0?35YP040:K2kP05ojK2kP2V`^koY/;^
0:K2k_nV`^h0102V`^h20?VhO0030?6^P`3i]gX0nKMj0080nKMi00<0SER>0?ZfM@3j]WD00P3j]WD3
08iKT00508mLTP2?GI80n[Uk08mMTP3j^G/03P2W`N`00`3j/6<0n[1R0?Z`H@030?Z`H@03ojVmj02Y
_NP0ZKgX0080ZKgX00Co0000ojVmj02Y_NSoZKgX1`2Y_NP00onY_NP0ZKgXojVmj0040:Vmj0Cooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`T0Yl7/00<0QTn808I?Qol00000
0_l00000100?06<0Re^C08]KT`2;Fi<;0:K2k@80l[:70P3b/HD00`3a/XP0R5680?6bR0040?:bQ`05
0000:03a/HL0lK2708aDR_nY_^P02@2Y_^P00onY_^P0ZKkX0:Vnj0020:Vnj0<0ZKgX00[oZKgX0:Vm
j02Y_NSoZKgX0:Vmj03Y_jX0UV^O0:Vmj?nY_NP09`Qc0`2?G9400on?G940SebA08mLTP0308mLTP80
SefB00<0001]0:O0k02W`>`02`2W`>`30?RbL`050:Vmj00B0gX0TV6D099QU?nBHI@00P2BHI@30?Ng
P@040?NgP02BHI@0n;N00?RgO`80n;Qo00P0n;Qn09=RU@3h^7h08Q630:VnjOnY_^T0ZKkYojVnj@80
ZKkY00D0T5^?0:Vnj02?Fhl06PMj08mKS`030:O1k005ojO1k02W`NcoYl7/0:O1k?nW`N`00`2W`N`0
0ol00000Yl7/0:O1k0070:O1k0Co00002?ooool00ol0003oooooooooo`0>ooooo`002oooool00ol0
003oooooooooo`0?ooooo`;o00005Oooool03`3b/H@0QDb408E<Q03c/H?oY/7]0?>aP_nV`Nd0Y/7]
ojK1k@2V`NgoY/7]0:K1kOnV`Nd0Y/7]ojK1k@030:K1k@030>37_`2V`Nd0Y/7]00H0Y/7]102U`^h0
1_nU`^h0YL;^ojG2kP2U`^koYL;^0:G2kPX0SEbC00CoSEbC08eLT`2=G9<0SEbC0P3`aJH20:K2kP0=
ojK2kP2V`^koY/;^0:K2k_nV`^h0Y/;^ojK2kP2V`^koY/;^0:K2k_nV`^h0nKQl0?6^P`020?VgNP80
nKMi00<0SER>0?ZfM@3j]WD00`3j]WD02@3j^7X0SU^@08mLTP2?GI80n[Uk08mMTP3j^G/0T5fB0?Zi
N`090:O1k005ojO1k02W`N`0Yl7/ojO1k03j/680103j/6460:Vmj003o`00002Y_NSoZKgX00@0ZKgX
00CoZKgX0:Vmj02Y_NSoZKgX0P2Y_NP9ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool02?ooool60:O1k00408M@R?l0003o0000o`0000<0QTn700<03`1S08]KT`2;Fi<00P2;Fi<308aK
T`0308aLT`2V`^d0Y/;]00<0Y/;]00<0gYj=0?:bQ`3b/XL00P3b/HD03P3a/XP0R56808UAR029DHP0
l[:708UBR03b/XL0lK660?6aQ`3a/8L0S5B:0?6aQ`2<EH[oZKkX1`2Y_^P01?nY_^P0ZKkX0:Vmj?nY
_NP60:Vmj004ojVmj02Y_NP0ZKgX0:Vmj080UV^O00<0kKbO02L8L`2?G9400P2?G9400on?G940SebA
0?FhR00308mLTP80SefB2P2W`>`00onW`>`0Yl3/0:O0k0020:O0k004ojO0k03h/W?oTf6D01<4NP80
TV6D00?oTV6D099QU02BHI@00`3g]h40103g]h00TV6D0?RgP03h]gl20?RhO`080?RhOP2CHYD0n;Qn
0?RhO@2Y_^WoZKkY0:VnjOnY_^T20:Vnj@03091KS`0I1WX0Se^?00<0Se^?00@0Yl7/ojO1k02W`Nco
Yl7/0P2W`N`03_nW`N`0Yl7/ojO1k02W`NcoYl7/o`000?nW`N`0Yl7/ojO1k02W`NcoYl7/0:O1k02N
PkOoWX>g3?ooool00ol0003oooooooooo`0>ooooo`002oooool00ol0003oooooooooo`0<ooooo`?o
00005oooool30:K1k@09ojK1k@2V`NgoY/7]0:K1kOnV`Nd0Y/7]ojK1k@2V`NgoY/7]00L0Y/7]00D0
h<No0:K1k@2V`Nd0Y/7]ojK1k@050:K1k@D0YL;^00?oYL;^0:G2kP2U`^h02P2=G9<01?n=G9<0SEbC
08eLT`2U`^h30?35YPP0Y/;^00?oY/;^0:K2k_nV`^h00P2V`^h00`3a[X<0nKMj0?VgNP020?VgN@03
08eHSP3j]WD0n[Ie00<0n[Ie00/0n[Qj0?ZiO03j^G`0n[Ul0?ZiN`2?GI80n[Uk091MTP3j^G/0T5jC
0?ZiNP020:O1k003ojO1k02W`NcoYl7/0080Yl7/00KoYl7/0:O1k?nW`N`0Yl7/ojO1k02W`N`30?Z`
H@<0ZKgX00GoZKgX0:Vmj02Y_NSoZKgXo`0000030:Vmj003ojVmj02Y_NSoZKgX0080ZKgX3?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo0`2W`N`3o`0000030:O1k026ChP0
QTn700<0QTn700<03`1S08]KT`2;Fi<00P2;Fi<308aKT`80S5bC102<G9@01`3NWXd0l[:70?:bQ`3b
/HD0l[660?6bR028DHP00P29DHP02`3b/XL0RE:80?:bQ`0002T0gIf>0?6`Q`2<E8X0lK6708aERP3a
/HH0S5J;00H0ZKkX0P2Y_NP00onY_NP0ZKgX0:Vmj0050:Vmj004ojVmj02Y_NP0ZKgX0:Vmj0<0kKbO
00L09`Qc08mLT@2?G940SebAohmLT@2?G940mKR80080SebB00<0mKR708mMTP2?GI801@2W`>`00onW
`>`0Yl3/0:O0k0020:O0k009ojO0k02W`>coYl3/0:O0k?nW`>`0Yl3/ojO0k?nCHI@0ZKgX0080TV6D
00?oTV6D099QU02BHI@00`3g]h40103g]h00TV6D0?RgP03h]gl20?RhO`050?RhOP2CHYD0n;Qn0?Rh
OOnY_^T01@2Y_^T00`2FK9l0T5^?08mKS`0508mKS`040:O1k?nW`N`0Yl7/ojO1k0D0Yl7/00Co0000
0:O1k02W`N`0Yl7/102NPkL00onW`Ncoooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000;
ooooo`03o`000?oooooooooo00Wooooo0ol0000Jooooo`09ojK1k@2V`NgoY/7]0:K1kOnV`Nd0Y/7]
ojK1k@2V`NgoY/7]00@0Y/7]00SoY/7]0:K1kOnV`Nd0Y/7]ojK1k@2V`Nd0h<NoojK1k@T0Y/7]1@2U
`^h00onU`^koYl3[08eLT`0308eLT`030?FkS02=G9<0SEbC00<0SEbC1@2U`^h30?35YPT0Y/;^00Co
Y/;^0:K2kP2LPkL0lJj30P3i]gX20?VgN@0308eHSP3j]WD0n[Ie00<0n[Ie00@0n[Qj0?ZiO03j^G`0
n[Ul0`3j^G/0102@GI80n[Uk091NT`3j^GX40:O1k003ojO1k02W`N`0Yl7/00P0Yl7/00D0n[1Q0:Vm
j02Y_NP0ZKgXojVmj0030:Vmj006o`00002Y_NP0ZKgX0:Vmj?nY_NP0ZKgX3oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Wooooo0ol0000308M@R0030:O1k026ChP0QTn700<0QTn7
00<0k[VJ08]KT`3^^IX00P2;Fi<308aKT`80S5bC102<G9@01`3NWXd0l[:70?:bQ`3b/HD0YL;^0?6b
R028DHP00P29DHP03P3b/XL0RE:80?:bQ`0002X0gIf>0?6`Q`2<E8X0lK6708aERP3a/HH0S5J;0?6a
QP2=EX/0ZKkX1@2Y_NP00onY_NP0ZKgX0:Vmj0060:Vmj004ojVmj02NQ;OoC4nd0:Vnj080kKbO00L0
9`Qc08mLT@3d]hT0SebAohmLT@2?G940mKR80080SebB00H0mKR708mMTP2?GI80001]0:O0k?nW`>`4
0:O0k00<ojO0k02W`>coYl3/0:O0k?nW`>`0Yl3/ojO0k02W`>coTf6D09=QU?nCHI@0ZKgX0P2BHI@5
0:Vnj@05ojVnj@3g]h3oZKkY0?RgP03h]gl00P3h^7l01@3h^7h0Tf:E0?RhOP3h^7d0=1j700<0ZKkY
00@0TEjA0:Vnj@2AGI00T5^?102?Fhl01?nW`>/0Yl3[ojO0j`2W`>/60:O1k080WX>g00Wo0000oij3
]`2NPkL0WX>gojO1k02W`NcoYl7/0:O1k?nW`N`03?ooool00ol0003oooooooooo`0=ooooo`002ooo
ool00ol0003oooooooooo`06ooooo`?o00007Oooool01P0002[oY/7]0:K1kOnV`Nd0Y/7]ojK1k@@0
Y/7]00goY/7]0:K1kOnV`Nd0Y/7]ojK1k@2V`NgoY/7]0:K1kOnV`Nd0Y/7]0<:I[@2EKjD0jl6Y00L0
Y/7]00<0lkJ80:G2kP2U`^h00`2U`^h00`2W`>/0SEbC08eLT`0208eLT`040?FkS02=G9<0SEbCojG2
kPP0YL;^0`3`aJH70:K2kP80W8>g00SoBTneojG2kP2U`^koYL;^0:G2k_nU`^h0nKMiojG2kPD0n[Ie
00@0n[Qj0?ZiO03j^G`0n[Ul1@3j^G/00`2@GY<0n[Uj0:O1k00?0:O1k0040:Vmj?nY_NP0ZKgXojVm
j0@0ZKgX00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Kooooo0ol00002ooooo`@0Qe2800<0Yl7/08I?R026ChL00`26ChL0103^^IX0Re^C0>jiVP3^^IX2
0>jiV@0608aKT`3^^IT0S5bC08aLT`2<G9@0kkZI0P2<G9@30?:bQ`040?:aQ@3oafl0lK:808QAR080
RE6800l0l[:708UBR03b/HD0000Z0=fMSP3a/8L0S5B:0?6aQ`2<EHX0lK6608aFR`3a/HH0SEJ;0?6a
QP3a/8H01P2Y_NP00onY_NP0ZKgX0:Vmj0030:Vmj00404]?]02NQ;L0ZKkXojVnj0<0ZKkX00L09`Qc
08mLT@3d]hT0SebAohmLT@2?G940mKR80080SebB00<0Yl3/08mMTP2W`>`00P2W`>`02_nW`>`0Yl3/
ojO0k02W`>coYl3/0:O0k?nX_nX0Z;oZojRojP2X_nX309=QU005oi=QU02CHICoTf6D01<4N`0B0gX0
1P2Y_^T00onY_^T0ZKkYojVnj@070:Vnj@03ojVnj@3SbKh0WhFg00<0TEjA00<0ZKkY095MT02@Fhl0
0P2?Fhl00`0J1gX0Yl3[0:O0j`040:O0j`80Yl7/0P2NPkL01OnNPkL0WX>g09j3]`2NPkOo000000P0
Yl7/2oooool00ol0003oooooooooo`0=ooooo`002_ooool00ol0003oooooooooo`04ooooo`?o0000
8?ooool00`0002/0Y/7]ojK1k@060:K1k@07ojK1k@2V`NgoY/7]0:K1kOnV`Nd0Y/7]ojK1k@030:K1
k@0509^2]`32VJd0UFnU0>_1Z@2EKjD00`2V`Nd0103c]HP0SEV>08eISP3c]XP208eIS`<0YL;^00`0
Yl3[08eLT`2=G9?oYL;^0:G2k_nU`^h0YL;^ojG2kP2U`^koYL;^0:G2k_nU`^h60:G2kP<0l<FV102V
`^h01?nLPkL0W8>g09b3]`2LPkL20:G2kP05ojG2kP2U`^koYL;^0:G2k_nU`^h00P2U`^h40?ZfM@<0
Y/;]00<0n[Ul0?ZiN`3j^G/0103j^G/00`3j^GX0Yl7/0:O1k00:0:O1k003ojO1k02W`N`0ZKgX0080
ZKgX00?oZKgX0:Vmj02Y_NP00P2Y_NP3ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`03ooooo`?o00001Oooool408M@R0030:O1k0000240QTn700<0
QTn700CoYL;^0:G2k_nU`^h0k[VJ0P3^^IT0102<Fi<0k[VI0>jiV@3_^IT30>njV@0508aLU03b/XL0
l[:70000603b/HD00`3a/XP208UAR0040?:bQ`29DXP0l[650000:`80lK2700T0S5B:0?6aQ`2<EHX0
lK6608aFR`3a/HH0SEJ;0?6aQP3a/8H01@2>F8`30:Vmj005ojVmj02Y_NP0ZKgX04]?]02OQ;L00P2Y
_^P02?nY_^P0ZKkX0:Vnj02Y_^P09`Qc08mLT@2W`>`0SebA1`2W`>`02OnW`>`0Yl3/ojO0k03f^8H0
mKR80:Roj_nX_nX0Z;oZojRojP030:RojP@0Tf6D00GoTf6D09=QU?nCHI@04`Ak01<4NP050:Vnj@04
ojVnj@2Y_^T0ZKkYojVnj@H0ZKkY00CoZKkY0:Vnj@2Y_^WoZKkY0`2AGY40102Y_^T0TEf@091KS`0I
1WX90:O0j`03ojO0j`2NPkL0WX>g00@0Yl7/00?o00000:O1k02W`N`01P2W`N`;ooooo`03o`000?oo
oooooooo00gooooo000:ooooo`04o`000?ooooooooooooooo`?o00008oooool00`0002/0Y/7]0:K1
k@050:K1k@03ojK1k@2V`NgoY/7]00H0Y/7]0`2KP[L01@2V`Nd0jl6Y0>_1Z@2EKjD0jl6Y0080lkF7
00@0lkF808eISP2=FHh0lkJ80`2=FHl0103d]XP0SEZ?09=XW@0005d40:G2kP05ojG2kP2U`^koYL;^
0:G2k_nU`^h01`2U`^h30?35YP050:K2kP2LPkL0W8>goib3]`19C[D02@2U`^h01OnU`^h0YL;^ojG2
kP2U`^koYL;^0080n[Ie1@2V`^d50?ZiN`0>0?ZiNP2W`N`0Yl7/0:O1k?nW`N`0Yl7/ojO1k02W`Nco
Yl7/0:O1k?nW`N`0Yl7/ojO1k02W`N`20:Vmj004ojVmj02Y_NSoZKgX0:Vmj0Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooooooo`?o00002?ooool4
08M@R00:08I@R0000240QTn708I?Q`0002?oYL;^0:G2k_nU`^h0YL;^ojG2kP@0YL;^00<0k[VI0:G2
kP2U`^h00`3_^YT20?:bQ`030?:aQ03b/HD0lK:80080lK:8103b/XL0103b/HD0Y/7/0?6`Q`3a/8L2
0?6aQ`0708aERP3a/HH0S5J;0?6aQP2=EX/0lK660?6`QP0508iHS080SUR=0P2>FHd00`2Y_NP0WhBg
09n4]`050:Vnj003ojVnj02Y_^P0ZKkX00L0Yl3/00?oYl3/0:O0k?nW`>`00P2W`>`00onW`>`0m[R7
0?FhR0030?>hS@04099QU02X_nX0TV6D0?FgQ`<0Tf6D00D0mKN5oi=QU02CHICoTf6D01<4N`060:Vn
j@03ojVnj@2Y_^T0ZKkY00D0ZKkY00?oZKkY0:VnjOnY_^T00P2Y_^T01`2BGY40TEjA095NT@2AGY40
ZKkY095MT00N2W`00`2W`>/01OnW`>/0Yl3[ojO0j`2W`>_oYl3[0080Yl3[00GoYl3[0:O1k?nW`N`0
Yl7/ojO1k0020:O1k00:ojO1k?l0003oYl7/0:O1k?nW`N`0Yl7/ojO1k02W`NcoYl7/0:O1k0[ooooo
00?o0000ooooooooool03Oooool000[ooooo1?l0000Vooooo`030000;02V`Nd0Y/7]00@0Y/7]00?o
Y/7]0:K1k@2V`Nd01@2V`Nd01?nV`Nd0Vh:g09^2]`2KP[L20:K1k@07ojK1k@3[`JT0UFnU0>_1Z@3c
]HL0Y/7]0?>eR00208eISP060?>fR02=FHl0SEV?08eIS`3d]XP0SEZ?0P2CJ9d80:G2kP09ojG2kP2U
`^koYL;^0:G2k_nU`^h0YL;^ojG2kP2U`^koYL;^00<0l<FV0P2LPkLA0:G2kP070000:P2V`^goY/;]
0:K2kOnV`^d0Y/;]ojK2k@040?ZiN`080:O1k?nW`N`0Yl7/ojO1k02W`NcoYl7/0:O1k?nW`N`20:O1
k003ojO1k02W`N`0ZKgX00<0ZKgX2oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Cooooo1?l0000;ooooo`@0Qe2800L0QU2800008@26ChL0000RojG2kP2U`^koYL;^00h0YL;^00<0
l[:70?:aQ@3b/HD00`3a/XP40?:bQ`040?:aQ@2V`N`0lK270?6`Q`80lK670P3a/HH01@2<EX/0lK66
08eFR`3a/HH0lK2600D0SUR<0P2>F8d208iIS@0308mIS@2OQ;L0ZKkX00D0ZKkX00CoZKkX0:Vnj02Y
_^P0ZKkX202W`>`01_nW`>`0Yl3/ojO0k02W`>`0mKR70?FhR0<0lkR=0`2BHI@02@3e]hL0Tf6D09=Q
U02CHI@0mKN5oi=QU02CHICoTf6D01<4N`040:Vnj@03ojVnj@2Y_^WoZKkY00L0ZKkY00?oZKkY0:Vn
j@2BGi800P2BGi802P2BGY40TEjA095NT@2AGY40001a095MT00N2WcoYl3[0:O0jonW`>/20:O0j`03
ojO0j`2W`>_oYl3[00@0Yl3[00GoYl7/0:O1k?nW`N`0Yl7/ojO1k0020:O1k005o`00002W`N`0Yl7/
0:O1k?nW`N`0102W`N`9ooooo`03o`000?oooooooooo00gooooo000:ooooo`;o0000:Oooool<0:K1
k@<0Vh:g00<0=T:a0:K1k@2V`Nd01@2V`Nd0103d]HL0lkF70?>eR03c]HP208eISP060?>fR02=FHl0
SEV?08eIS`3d]XP0SEZ?0P2CJ9d00`0005l0YL;^0:G2kP020:G2kP0;ojG2kP2U`^koYL;^0:G2k_nU
`^h0YL;^ojG2kP2U`^koYL;^0:G2k_nU`^h00`2U`^h01`3`aJH0YL;^ojG2kP2U`^koYL;^0:G2k_nU
`^h0302U`^h01onV`^d0Y/;]ojK2k@2V`^goY/;]0:K2kOnV`^d00P2V`^d01?nV`^d0n[Uk0?ZiNonW
`N`20:O1k003ojO1k02W`NcoYl7/00D0Yl7/0P2Y_NP?ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04oooool2o`0000gooooo1027D8P00`26D8P0000Q0:G2kP0C0:G2kP80l[650P2V
`N`00`3a/XP0l[:70?:bQ`020?:bQ`040?:aQ@3a/HL0lK270?6`Q`80lK67103a/HH00`2=EX/0lK66
0?6`QP0508iHS080SUR=0P2>FHd00`2?FHd0l[65ojVnj0040:Vnj004ojVnj02Y_^P0ZKkXojVnj080
ZKkX1P2W`>`01onW`>`0Yl3/0:O0k?nW`>`0Yl3/0?FhQ`3e^8P00P2Y_^T01@3c^8d0TV6D099QU02B
HI@0mKN700<0Tf6D00<0mKN5oi=QU02CHI@01P2Y_^T00onY_^T0ZKkYojVnj@070:Vnj@D0TUnB00X0
TUjA0>?9_P2AGY40TEjA0?VbK`2Y_^T0TEf@ojO0j`2W`>_oYl3[2@2W`>/00`0[6XP0Yl7/0:O1k005
0:O1k003o`00002W`N`0Yl7/00D0Yl7/2Oooool00ol0003oooooooooo`0=ooooo`003?ooool00ol0
003oooooooooo`0Xooooo`P0Y/7]00CoY/7]09^2]`2KP[L0Vh:g2P2V`Nd0103c]HL0lkF80?>fR@3c
]XT20?>fR0<0SEV?00D0m;J808eJSonW`N`0Yl7/ojO1k00;0:G2kP0;ojG2kP2U`^h0YL;^ojG2kP2U
`^koYL;^0:G2kP3f/WX0mk9j0:G2k_nU`^h03P2U`^h50:K2k@08ojK2k@2V`^goY/;]0:K2kOnV`^d0
Y/;]ojK2k@3j^G/80:O1k080Yl3[00<0n[9/ooooooooool04?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool408M@R00308I@R02U`^h0YL;^
01<0YL;^0P3b/HD30:K1k008ojK1k02V`N`0l[:70:K1k00002P0lK670?6`Q`2<E8X20?6aQ`H0lK66
00<0lK2608iHS02>F8`00`2>F8`208iHS@80SUV=00<0SeV=0?:aQ@3b/HD01`2Y_^P00onY_^P0ZKkX
0:Vnj0060:O0k007ojO0k02W`>coYl3/0:O0k?nW`>`0Yl3/ojVnj@020:Vnj@0603<]V`2BHI@0TV6D
099QU03e]hL0Tf6D0`2Y_^T00onY_^T0ZKkY0:Vnj@050:Vnj@03ojVnj@2Y_^WoZKkY00@0ZKkY202B
Gi80202BGY40hlVn095NT@2AGY40nK9_0:Vnj@2AGI00ZKkY2P2W`>/00onW`>/0Yl3[0:O1k0040:O1
k003ojO1k02W`Nco00000080Yl7/00KoYl7/0:O1k?nW`N`0Yl7/ojO1k02W`N`8ooooo`03o`000?oo
oooooooo00gooooo000=ooooo`03o`000?oooooooooo02[ooooo0P2V`Nd209^2]`03oi^2]`2KP[L0
=46`00`0Y/7]00@0lkF70?>eR03c]XT0lkJ90`3c]XP30?BfR00708eJS`2W`NcoYl7/0:O1k?nW`N`0
Yl7/0?FbO@030?FbOP030?:_P02U`^h0YL;^0080YL;^00GoYL;^0:G2k_nU`^h0YL;^08iHS0020?Jb
N`0<0?JbNP3g/WX0mk9j08iIS@2U`^koYL;^0:G2k_nU`^h0YL;^ojG2kP2U`^koYL;^1@2U`^h>0:K2
k@P0Yl3[00?oYl3[0:O0j`3j/V`04oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool02?ooool00`0001/0Qe2808M@R00208M@R1H0YL;^0P3b/HD70:K1
k0060?6aQP3a/HL0lK2708aDRP3a/HL0S5F:1P3a/HH608iHS080SUR=0P2>FHd01@2?FHd0l[650?:a
Q@0004_oZKkX00D0ZKkX00?oZKkX0:Vnj02Y_^P01@2W`>`03?nW`>`0Yl3/0:O0k?nW`>`0Yl3/ojO0
k02W`>coZKkY0:VnjOnY_^T0ZKkYojVnj@L0ZKkY00?oZKkY0:Vnj@2Y_^T0102Y_^T01OnY_^T0ZKkY
0:VnjOnY_^T0ZKkY00/0TUnB00T0ZKkY01`9N`2AGY40TEjA0?VbK`2Y_^T0TEf@0:Vnj@0N2g`01`2W
`>/01onW`>/0Yl3[ojO0j`2W`>_oYl7/0:O1k?nW`N`00P2W`N`02OnW`N`0Yl7/ojO1k?l0003oYl7/
0:O1k?nW`N`0Yl7/ojO1k0020:O1k003ojO1k?oooooooooo00Kooooo00?o0000ooooooooool03?oo
ool000kooooo00?o0000ooooooooool0:_ooool00`0c?k00Vh:g09^2]`0@0:K1k@030?>eR03c]XT0
lkJ900<0lkJ80`3d]XP01`2fYAH0Yl7/ojO1k02W`NcoYl7/0:O1k?nW`N`00`3e/Wh0103b[h00SEN<
08eGS03f/Wd2ohiHS00408iHS03f/W/0SUR<08iHS080m[9k00@0m[9j0?NbNP3g/WX0SUV=0P2>F8`0
0onU`^h0YL;^ojG2kP020:G2kP04ojG2kP2U`^koYL;^0:G2kPh0Y/;]00<0nKMh0?NnS@3g_Xd0102W
`>/01_nW`>/0Yl3[ojO0j`2W`>_oYl3[0:O0ja?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00@0000K08M@R027D8P0000M5`2U`^h00`3b
/HD0l[660:K1k0060:K1k0080000:@3a/HL0lK2708aDRP3a/HL0S5F:0?6aQP2<EX/40?6aQP80SUR<
00@0lK6608iHS02>F8`0SUR<0P2>F8d208iIS@0508mIS@3b/HD0l[650?:aQOnY_^P00`2Y_^P00on@
G8l0T5b?oi1LS`02091LS`030:Vnj00I4HP0Yl3/0080Yl3/00GoYl3/0:O0k?nW`>`0Yl3/ojO0k002
0:O0k080ZKkY00?oZKkY0:VnjOnY_^T01`2Y_^T00onY_^T0ZKkY0:Vnj@040:Vnj@03ojVnj@2Y_^T0
TUnB00d0TUnB0100001V01`9N`2AGY40TEjA0?VbK`2Y_^T0TEf@0:Vnj@0N2g`07`an0:O0jonW`>/0
Yl3[ojO0j`2W`>_oYl3[0P2W`>/01onW`>/0Yl3[ojO0j`2W`NcoYl7/0:O1k?nW`N`0102W`N`00ol0
0000Yl7/0:O1k0050:O1k0Sooooo00?o0000ooooooooool03?ooool000oooooo0_l0000[ooooo`03
03<o/02V`Nd0Y/7]0100Y/7]00<0lkJ90:K1k@3c]XP00P3c]XP30?BfR0040:O1k?nW`N`0Yl7/ojO1
k080Yl7/00GoYl7/0?FbOP3e/Wh0mK9n0?:_P00208eGS0050?JbOOn>F8coSUR<08iHS03f/W/00P2>
F8`20?JbN`040?JbNP3g/WX0mk9j08iIS@D0SUR<00D0YL;^ojG2kP2U`^koYL;^0:G2kP0?0:K2k@03
0?VgN03g_Xd0mkj=00@0Yl3[00?oYl3[0:O0jonW`>/00`2W`>/Dooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool06?ooool2o`0000Oooooo00<0000K08M@R00001d03P2U`^h03?nU`^h0
YL;^ojG2kP2U`^koYL;^0:G2k_nU`^h0YL;^ojG2kP2U`^h0l[650:G2kPL0Y/7/00`0000Z0?6aQ`3a
/8L0S5B:0?6aQ`2<EHX0lK6608aFR`3a/HH0SEJ;0?6aQP3a/8H208iHS0040?6aQP2>F8`0SUR<08iH
S080SUR=0P2>FHd00`2?FHd0l[650?:aQ@020?:aQ@06oi1LS`2@G8ooT5b?oi1LS`2@G8ooT5b?0P2@
G8l00`23DXh06A680:Vnj@020:O0k0030:Vnj@2W`>coZKkY00H0ZKkY00?oZKkY0:VnjOnY_^T01`2Y
_^T00onY_^T0ZKkY0:Vnj@040:Vnj@03ojVnj@2BH9<0TUnB00d0TUnB00<0001V01`9N`2AGY400P2A
GY400`2Y_^T0TEf@0:Vnj@02095MT0090:O0jonW`>/0Yl3[ojO0j`2W`>_oYl3[0:O0j`2CHYD0Yl3[
0080Tf:E202W`N`01Ol00000Yl7/0:O1k02W`NcoYl7/0080Yl7/00?oYl7/0:O1k?ooool01_ooool0
0ol0003oooooooooo`0<ooooo`004Oooool00ol0003oooooooooo`0Yooooo`030000?`2>FXl0SUZ?
01<0Y/7]00@0lkJ80:K1k@3d]XP0m;J80`2W`N`00onW`N`0Yl7/ojO1k0020:O1k080mK9n00@0lZn0
08eGS02=Eh`0m[9m0_n>F8`0102>F8`0m[9k08iHS02>F8`20?JbN`040?JbNP3g/WX0mk9j08iIS@H0
SUR<0`2U`^h20:K2k@0509f3]`2V`^d0WH>g0:K2k@2MPkL00`2V`^d00onV`^d0Y/;]ojK2k@020:K2
k@80nKMh0P3g_Xd0202W`>_oYl3[0:O0j`2W`>_oYl3[0:O0jonW`>/0Yl3[5oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00`0001/0YL;^
0:G2kP090:G2kP09ojG2kP2U`^koYL;^0:G2k_nU`^h0YL;^ojG2kP2U`^koYL;^00L0YL;^202V`N`0
3P0002X0lK670?6`Q`2<E8X0lK6708aERP3a/HH0S5J;0?6aQP2=EX/0lK660?6`QP3a/HH0SUR<0P3a
/HH208iHS080SUR=0P2>FHd00`2?FHd0l[650?:aQ@020?:aQ@06oi1LS`2@G8ooT5b?oi1LS`2@G8oo
T5b?0P2@G8l00`23DXkoZKkY0:Vnj@040:Vnj@03ojVnj@2Y_^T0ZKkY00@0ZKkY00?oZKkY095MT?nY
_^T01`2Y_^T00onY_^T0ZKkY0:Vnj@050:Vnj@03099PT`2BGi80TUnB00d0TUnB00L070Uk095NT@2A
GY40TEjA0:Vnj@2AGI007PYl0080TEf@00?oYl3[0:O0j`2W`>/0202CHYD50:O1k00=ojO1k02W`N`0
Yl7/ojO1k?l0003oYl7/0:O1k?nW`N`0Yl7/ojO1k02W`NcoYl7/0:O1k006ooooo`03o`000?oooooo
oooo00cooooo000Booooo`03o`000?oooooooooo02Sooooo0`2>FXl00on>FXl0Yl3[ohiJS`02ohiJ
S`0308iJS`2V`Nd0Y/7]00h0Y/7]1P2W`N`01_nW`N`0Yl7/ojO1k02W`N`0mK9n0?:_P080SEN<00D0
m[9mohiHS?n>F8`0SUR<0?JbN`0208iHS080m[9k00@0m[9j0?NbNP3g/WX0SUV=1`2>F8`0102>Eh`0
YL;^09f3]`3Tbkl609f3]`03oif4]`2MQ;L0WHBg00@0WHBg0P3i]gP20?NnS@040?NnS_nW`>/0Yl3[
ojO0j`80Yl3[6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool00oooool70:G2kP0;ojG2kP2U`^koYL;^0:G2k_nU`^h0YL;^ojG2kP2U`^koYL;^0:G2
k_nU`^h02@2U`^h00`3b/HH0Y/7/ojK1k0060:K1k00>0000:`3a/HL0lK2708aDRP3a/HL0S5F:0?6a
QP2<EX/0lK6608eFR`3a/HH0lK260?6aQP2>F8`40?6aQP<0l[6500<0SUV=08mIS@3b/HD00`3b/HD0
1_n@G8l0T5b?oi1LSon@G8l0T5b?oi1LS`80T5b?00@0Pe:>095MT03c/XD0TEf@0`2Y_^T00onY_^T0
ZKkYojVnj@040:Vnj@80TEf@00<0REN?0:Vnj@2Y_^T01@2Y_^T00onY_^T0ZKkY0:Vnj@050:Vnj@03
099PT`2BGi80TUnB00d0TUnB00L0TUjA095NT@2AGY40TEjA0000L@2AGI007PYl0080TEf@00<0D2j8
09=RU@2CHYD02@2CHYD03?nW`N`0Yl7/ojO1k02W`NcoYl7/0:O1k?nW`N`0Yl7/ojO1k?l00000Yl7/
ojO1k0<0Yl7/0P2JM:L6ooooo`03o`000?oooooooooo00cooooo000Cooooo`03o`000?oooooooooo
02Oooooo0`2>FXl00on>FXl0Yl3[ohiJS`02ohiJS`80SUZ?00?oSUZ?0000C`2V`Nd0302V`Nd30:O1
k009ojO1k02W`N`0Yl7/ojO1k02W`NcoYl7/0:O1k?nW`N`0lZn00080SEN<00H0m[9mohiHS?n>F8`0
SUR<0?JbN`2>F8`20:O1k0050?JbN`3f/WX0mk9j0?NbNP2>FHd01`2>F8`01`2>Eh`0001Y0:K2kOnV
`^d0i<boojK2k@3Tc;l00P2V`^d0103Tc;l0Y/;]0>C<_onV`^d20>G=_`0509f4]`3i]gP0nKMh0?Vg
N?nW`>`00P3g_Xh00`2AGY40nK=aooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`03ooooo`/0YL;^00?oYL;^0:G2kP2U`^h03@2U`^h00onV
`N`0Y/7/ojK1k0020:K1k00AojK1k02V`NcoY/7/0:K1k03MWHh0lK2708aDRP3a/HL0S5F:0?6aQP2<
EX/0lK6608eFR`3a/HH0lK260?6aQP2>F8`0103a/HH40?:aQ@0308mIS@3b/HD0l[650080l[6500Ko
T5b?091LSon@G8ooT5b?091LSon@G8l2091LS`0608=BSP2AGI00lk:5095MT02AGI40lk:40`2Y_^T0
1OnY_^T0ZKkY095MT?nAGI00ZKkY0080TEf@00<0REN?095MT@2BGY40102BGY400`2Y_^WoZKkY0:Vn
j@020:Vnj@80TUjA0P2Y_^T00`2BH9<0TUnB099OTP0=099OTP07099NT@2AGY40TEjA095NT@000740
TEf@01h:O002095MT003050^R02CHYD0Tf:E00T0Tf:E00D0<1n;ojO1k02W`N`0Yl7/ojO1k0050:O1
k003o`00002JM:L0VWBW00D0VWBW1Oooool00ol0003oooooooooo`0<ooooo`005?ooool00ol0003o
ooooooooo`0Vooooo`<0SUZ?00?oSUZ?0:O0jon>FXl00_n>FXl208iJS`03ohiJS`000500Y/7]00/0
Y/7]1P2W`N`00onW`N`0Yl7/ojO1k0020:O1k00508iISP3b[h00SEN<ojO1k03f/Wd02@2W`N`00`3g
/WX0Yl7/08iIS@0708iHS00<08iGS00006T0Y/;]ojK2k@2V`^goY/;]0:K2kOnV`^d0Y/;]ojK2k@2V
`^goY/;]0P2V`^d00onV`^d0Y/;]ojK2k@020?VgN005ojO0k03g_Xh0mkj>095NT@3i/g407_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo0_l00004oooooaT0YL;^1@2V`N`0
0onV`N`0Y/7/ojK1k0020:K1k080lK2700/0S5B:0?6aQ`2<EHX0lK6608aFR`3a/HH0SEJ;0?6aQP3a
/8H0lK6608iHS0040?6aQPT0l[6500KoT5b?091LSon@G8ooT5b?091LSon@G8l2091LS`0:08=BSP2A
GI00lk:5095MT02AGI40lk:4095NT@3c/X@0ZKkYoi5MT080TEf@00KoTEf@0:Vnj@2AGI00TEf@08UG
S`2AGI48099NT@040:Vnj@2BGY40TUjA099NT@80ZKkY00<0TV2C099OTP2BGi803@2BGi801`2BGY40
TEjA095NT@2AGY40001a095MT00N2W`00P2AGI000`1@;XP0Tf:E09=RU@0509=RU@030?^hM02CHYD0
Tf:E0080Tf:E1P2W`N`309YdY`03o`00002JM:L0VWBW00@0VWBW00<0Y/7]ooooooooool00oooool0
0ol0003oooooooooo`0<ooooo`005Oooool2o`0002Kooooo0`2>FXl00on>FXl0SUZ?ohiJS`02ohiJ
S`80SUZ?00?oSUZ?08iJS`2V`Nd02P2V`Nd90:O1k0@0SUV>00<0BDne0:O1k02W`N`02P2W`N`00onW
`N`0Yl7/08iIS@0708iHS00508iGS00006WoY/;]0:K2kOnV`^d00P2V`^d02OnV`^d0Y/;]ojK2k@2V
`^goY/;]0:K2kOnV`^d0Y/;]ojK2k@020:K2k@060?VgN02AGY40Yl3/0:A/T@2AGY40nK=a7oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00ooooolD
0:G2kP03ojO1k02W`N`0;S^^00T0Y/7/00<0lK670?6`Q`3a/8L00P3a/HL02@2<EHX0lK6608aFR`3a
/HH0SEJ;0?6aQP3a/8H0lK6608iHS0040?6aQPT0l[6500KoT5b?091LSon@G8ooT5b?091LSon@G8l2
091LS`0:08=BSP2AGI00lk:5095MT02AGI40lk:4095NT@3c/X@0TUjAoi5MT080TEf@00KoTEf@0:Vn
j@2AGI00TEf@08UGS`2AGI48099NT@040:Vnj@2BGY40TUjA099NT@80ZKkY00<0TV2C01D4N@2BGi80
3@2BGi802P2BGY40hlVn095NT@2AGY40nK9_095MT00N2W`0TEf@0:Vnj@2AGI0709=RU@030?^hM02C
HYD0Tf:E0080Tf:E1@2JM:L02?nJM:L0VWBW09YdY`2JM:OoVWBWo`00002JM:OoY/7]1@2V`Nd4oooo
o`03o`000?oooooooooo00cooooo000Gooooo`03o`000?oooooooooo02?ooooo0`2>FXl00on>FXl0
SUZ?ohiJS`02ohiJS`80SUZ?0P2V`N`00`00057oY/7]0:K1k@070:K1k@030<ZAV02W`N`0Yl7/00<0
Yl7/00?oSUV>08iIS_n>FHh01@2>FHh00`3e/h7oYl7/0:O1k00<0:O1k00308iIS@2>F8`0SUR<00D0
SUR<00T0SUN<0000JOnV`^d0Y/;]ojK2k@2V`^goY/;]0:K2kOnV`^d0102V`^d00onV`^d0Y/;]0:K2
k@030:K2k@80TEjA00<0Y6bA095NT@3i/g408?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool01?ooool00`2U`^koooooooooo`09ooooo`D0Yl7/00Co
Yl7/0:O1k02W`N`0;S^^2@2V`N`00`3a/HL0lK270?6`Q`020?6aQ`80lK6600L0S5J;0?6aQP2=EX/0
lK660?6`QP3a/HH0SUR<00@0lK662@3b/HD01_n@G8l0T5b?oi1LSon@G8l0T5b?oi1LS`80T5b?00X0
Pe:>095MT03c/XD0TEf@095MT@3c/X@0TEjA0?>bQ02BGY7oTEf@0P2AGI001_nAGI00ZKkY095MT02A
GI00REN?095MT@P0TUjA00@0ZKkY099NT@2BGY40TUjA0P2Y_^T00`0D0gT0TV2C099OTP0=099OTP0:
099NT@0L2G/0TEjA095NT@3i/Vl0TEf@01h:O02Y_^T07P]l095MT0L0Tf:E00<0nkQd09=RU@2CHYD0
0P2CHYD01P2JM:L0mLVP0?G9X03ebJ00VWBWoiYdY`<0VWBW0P2V`Nd00ol00000Y/7]0:K1k@040:K1
k@Gooooo00?o0000ooooooooool02oooool001Sooooo00?o0000ooooooooool08_ooool308iJS`04
ohiJS`2>FXooSUZ?ohiJS`L0Y/7/00<0Y/7]ojK1k@2V`Nd0102V`Nd00`3`^YP0bY6H091NT`02091N
T`?oSUV>00<0SUV>ohiISP2>FHh0102>FHh20?FcP@`0Yl7/00?oTEjB08iIS@2>F8`01P2>F8`00`2>
Eh`0001Y0:K2k@030:K2k@03ojK2k@2V`^d0Y/;]00X0Y/;]0P2AGY400`2TK940nK=b0?VcL@0Poooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0@oooo
o`L0Yl7/00?o;S^^0:K1k02V`N`01`2V`N`00`3a/HL0lK270?6`Q`020?6aQ`@0lK6600D0SEJ;0?6a
QP3a/8H0lK6608iHS0040?6aQPT0l[6500KoT5b?091LSon@G8ooT5b?091LSon@G8l2091LS`0:08=B
SP2AGI00lk:5095MT02AGI40lk:4095NT@3c/X@0TUjAoi5MT080TEf@00KoTEf@0:Vnj@2AGI00TEf@
08UGS`2AGI48099NT@080:Vnj@2BGY40TUjA099NT@2Y_^T0GcR:01@3N@2BH9<;099OTP05ojO0j`2W
`>/0Yl3[0000IP0L2G/00P2AGY401P3i/Vl0ZKkY095MT02Y_^T07P]l095MT0L0Tf:E00<0nkQd09=R
U@2CHYD00P2CHYD01@2V`Nd0mLVP0?G9X03ebJ00VWBW00L0Y/7]00Oo00000:K1k@2V`NgoY/7]0:K1
kOnV`Nd0Y/7]00Cooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool08Ooo
ool308iJS`03ohiJS`000500Y/7/00`0Y/7/00D0Y/7]ojK1k@2V`Nd0l;ZH0<ZAV003091NT`?oSUV>
00<0SUV>ohiISP2>FHh0102>FHh30?FcP@03ojO1k02W`N`0Yl7/00L0Yl7/0_nAGY800`2>FHd0SUR<
08iHS00508iHS0030000J?nV`^d0Y/;]00`0Y/;]1P2AGY400`2TK940nK=b0?VcL@0Qooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool08Oooool2o`00017ooooo1P2W`N`01OnW`N`0Y/7/
ojK1k02V`NcoY/7/00H0Y/7/0P3a/8L20?6aQ`H0lK6600<0lK2608iHS03a/HH0103a/HH80?:aQ@03
0?g4H_n@G8l0T5b?00;oT5b?00h0T5b?oi1LS`2@G8l0T5b?08=BSP2AGI00lk:5095MT02AGI40lk:4
095NT@3c/X@0TUjAoi5MT080TEf@00KoTEf@0:Vnj@2AGI00TEf@08UGS`2AGI48099NT@080:Vnj@2B
GY40TUjA099NT@2Y_^T0TUj@01@3N@2BH9<:099OTP060:O0jonW`>/0Yl3[0:O0j`0006H070Uk0P2A
GY401P3i/Vl0ZKkY095MT00N2W`07P]l095MT0L0Tf:E00<0nkQdojK1k@2V`Nd02P2V`Nd02OnV`Nd0
Y/7]ojK1k@2V`Ngo00000:K1kOnV`Nd0Y/7]ojK1k@030:K1k@?ooooo00?o0000ooooooooool02ooo
ool001[ooooo0_l0000Qooooo`<0SUZ?00?oY/7/0:K1k02V`N`02`2V`N`01_nV`N`0Y/7/0:K1k?nV
`N`0l;ZH0<ZAV0<0T5jC0on>FHh00`2>FHkoSUV>08iISP0408iISP@0mK>100<0Se^?0:O1k02W`N`0
1P2W`N`2oi5NTP03091NTP2>F8`0SUR<00<0SUR<00<0001X0:K2k@2V`^d02`2V`^d3095MT@H0TEjA
00<0Y6bA0?VcLP3i/g408_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool03oooool60:O1k00302ll[P2V`N`0Y/7/0080Y/7/00GoY/7/0:K1k?nV`N`0
Y/7/0=fMSP020?6`Q`80lK671P3a/HH208iHS0040?6aQP2>F8`0SUR<08iHS080SUR=00<0SUV=0?:a
Q@3b/HD0103b/HD00`3ma6;oT5b?091LS`02oi1LS`0>0?:bQOn@G8l0T5b?0?>bQ023DXh0TEf@0?>b
Q@2AGI00TEfA0?>bQ02AGY40lk:4099NTOnAGI02095MT006oi5MT02Y_^T0TEf@095MT029Ehl0TEfA
202BGY40202Y_^T0TUjA099NT@2BGY403`1c099NT00D0gT0TV2C1P2BGi800onW`>/0Yl3[ojO0j`05
0:O0j`0:02XKRP0L2G/0TEjA0:O1k03i/Vl0001a095MT00N2W`07P]l095MT0<0Tf:E00?oY/7]0:K1
k@2V`Nd02@2V`Nd01OnV`Nd0Y/7]ojK1k@2V`NgoY/7]0080Y/7]00CoY/7]0:K1kOnV`Ngo00001`2V
`Nd2ooooo`03o`000?oooooooooo00_ooooo000Looooo`03o`000?oooooooooo01kooooo0`2V`N`0
0onV`N`0Y/7/ojK1k00=0:K1k007ojK1k02V`NcoU6VN0<ZAV02@GY<0l[N>091NT`03ohiISP0308iI
S_n>FHh0SUV>00@0SUV>103e/h400`2?Fhl0mK>10:O1k0030:O1k003095OT`2AGY80Yl7/00;oTEjB
00<0101a08iHS02>F8`00P2>F8`00`0006L0Y/;]0:K2k@080:K2k@L0TEfA1P2AGY400`2TK940nK=b
0?VcL@0Sooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0?ooooo`D0Yl7/00@0PU2<0:K1k02=FHl0Y/7/0P2=FXl208iJS`04ohiJS`3MWHh0lK270?6`
Q`80lK671P3a/HH208iHS0040?6aQP2>F8`0SUR<08iHS080SUR=0P2>FHd00`2?FHd0l[650?:aQ@02
0?:aQ@030?g4H_n@G8l0l[:600;oT5b?00h0l[:5oi1LS`2@G8l0lk:408=BSP2AGI00lk:5095MT02A
GI40lk:4095NT@3c/X@0TUjAoi5MT080TEf@00KoTEf@0:Vnj@2AGI00TEf@08UGS`2AGI48099NT@08
00`0LP2BGY40TUjA099NT@0?07<0TUj@01@3N@2BH9<2099OTP@0Yl3[00?oYl3[0:O0jonW`>/01@2W
`>/0300Z6hX0Yl7/0:O1k?nW`N`0Yl7/0000L@2AGI007PYl01h;O02AGI00Y/7]ojK1k@/0Y/7]00Oo
Y/7]0:K1kOnV`Nd0Y/7]ojK1k@2V`NgoY/7]00H0Y/7]00Oo00000:K1k@2V`NgoY/7]0:K1kOnV`Nd0
Y/7]00;ooooo00?o0000ooooooooool02oooool001gooooo00?o0000ooooooooool08?ooool40:K1
k003ojK1k02V`N`0Y/7/00L0Y/7/00D0U6VNoiAYWP2DJIh0U6VNoiAYWP040?:gSP?oSUV>00<0SUV>
ohiISP2>FHh0102>FHh40?FcP@0308mKS`3e/h40mK>100<0Yl7/00<0TEnC095NTP2W`N`00_nAGY80
1@040740SUR<08iHS02>F8`0001W00/0Y/;]0P2AGI401P3h]7T0n;Ah0?RdN02AGI40n;Ag0?VdM`D0
TEjA00<0Y6bA0?VcLP2AGY408oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool03oooool01@2=FHkoSEV>08eISP2W`N`0PU2<0080SEV?0`2=FXl208iJ
S`04ohiJS`3MWHh0lK270?6`Q`80lK671P3a/HH208iHS0040?6aQP2>F8`0SUR<08iHS080SUR=0P2>
FHd00`2?FHd0l[650?:aQ@020?:aQ@030?g4H_n@G8l0l[:600;oT5b?00@0l[:5oi1LS`2@G8l0lk:4
0`3c/XD30?>bQ004095NT@3c/X@0TUjAoi5MT080TEf@00?oTEf@0:Vnj@2AGI000P2AGI000`2AGI40
TUjA099NT@06099NT@0900`0LP2BGY40TUjA099NT@0?07<0TUj@01@3N@2BH9<05@Ai00D0Yl3[00Co
Yl3[0:O0j`2W`>_oYl3[102W`>/0100Z6hX0Yl7/0:O1k?nW`N`20:O1k003095MT00N2W`0Y/7]00T0
Y/7]00?oY/7]0:K1kOnV`Nd00P2V`Nd00onV`Nd0Y/7]ojK1k@0:0:K1k@0:o`000?nV`Nd0Y/7]ojK1
k@2V`NgoY/7]0:K1kOnV`Ngoooooo`0000gooooo000Nooooo`03o`000?oooooooooo027ooooo102V
`N`00onV`N`0Y/7/0:K1k0020:K1k00509AYW_nDJIkoU6VN09AYW_nDJIh00P2DJIh00onDJIh0l[N>
0?:gSP020?:gSP?oSUV>00<0SUV>ohiISP2>FHh0102>FHh40?FcP@0908mKS`3e/h40mK>10?FcP@2W
`NcoTEnC095OT`2AGY80Yl7/00;oTEjB00<0101a08iHS02>F8`03@2V`^d30?RdN@80n;Ah00@0TEfA
0?RdM`3i]7L0nKAg0P3i]7H01@2AGY40nKAe0?VdM03i/g80TEjA02Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00kooooo00D0SEV>oheISP2=FHh0
Yl7/089@S00208eIS`<0SEZ?0P2>FXl01?n>FXl0gIf>0?6`Q`3a/8L20?6aQ`H0lK660P2>F8`0103a
/HH0SUR<08iHS02>F8`208iHS@80SUV=00<0SeV=0?:aQ@3b/HD00P3b/HD00`3ma6;oT5b?0?:bQP02
oi1LS`040?:bQOn@G8l0T5b?0?>bQ0<0lk:50`3c/X@0102AGY40lk:4099NTOnAGI02095MT003oi5M
T02AGI00TEf@0080TEf@0P3e/Wl7099NT@0800`0LP2BGY40TUjA099NT@0?07<0TUj@01@3NOnW`>/6
0:O0j`04ojO0j`2W`>/0Yl3[ojO0j`D0Yl3[00GoYl7/0:O1k?nW`N`0Yl7/ojO1k00:0:K1k@05ojK1
k@2V`NgoY/7]0:K1kOnV`Nd02`2V`Nd02?nV`Nd0Y/7]0:K1kOnV`Nd0Y/7]o`00002V`NgoY/7]1@2V
`Nd00ol0003oooooooooo`0;ooooo`007oooool00ol0003oooooooooo`0Rooooo`@0Y/7/00CoY/7/
0:K1k?nDJIh0U6VN0_nDJIh01@2DJIkoU6VN09AYWP2DJIh0Y/7]00@0l[N>0on>FHh00`2>FHkoSUV>
08iISP0408iISP@0mK>100L0Se^?0?FcP@3e/h40mK>1095NT_nAGi<0TEnC0080TEjB0_nAGY800`04
0740T5jB0:K2k@0=0:K2k@<0n;Ai0P3h]7P0102AGI40n;Ag0?VdM`3i]7L20?VdMP05095NT@3i]7D0
nKAd0?VcLP2AGY409Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo0_l0
000>ooooo`0508eIS_n=FHh0SEV>0:O1k022D8`00P2=FHl208eJS`070>ndT02>FXl0SUZ?ohiJS`3M
WHh0lK2708aDRP020?6aQ`H0lK660P2>F8`0103a/HH0SUR<08iHS02>F8`208iHS@80SUV=00P0SeV=
0?:aQ@3b/HD0Y/;]0?:aQ@3ma6;oT5b?0?:bQP;oT5b?00@0l[:5oi1LS`2@G8l0lk:40`3c/XD50?>b
Q005099NTOnAGI00TEf@0000J_nAGI00102AGI030?FbO`D0TUjA00<0m[=m00`0LP2BGY400P2BGY40
100?07<0TUj@05lhRP2CH9<40:O0j`04ojO0j`2W`>/0Yl3[ojO0j`L0Yl3[00?oYl7/0:O1k?nW`N`0
1@2W`N`50:K1k@05ojK1k@2V`NgoY/7]0:K1kOnV`Nd02`2V`Nd01OnV`Nd0Y/7]ojK1k@2V`NgoY/7]
00<0Y/7]00?o00000:K1k@2V`Nd00`2V`Nd00onV`Ngo0000ooooo`0<ooooo`008?ooool2o`0002Co
oooo00H0U6VNoiAYWP2DJIh0U6VNoiAYWP2DJIh2oiAYWP0309AYWP2V`Nd0Y/7]00D0Y/7]00H0l[N>
ohiIS_n>FHkoSUV>08iIS_n>FHh408iISPD0mK>100T0Se^?0?FcP@3e/h40mK>1095NT_nAGi<0Yl7/
095OT`2AGY800_nAGY800`04077oY/;]0:K2k@0=0:K2k@<0n;Ai0P3h]7P0102AGI40n;Ag0?VdM`3i
]7L20?VdMP05095NT@3i]7D0nKAd0?VcLP2AGY409Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool02oooool01@2=FHkoSEV>08eISP2W`N`0k[>A0080
SEV?0P2=FXl02@3_]900SUZ?08iJSon>FXl0gIf>0?6`Q`2<E8X0lK6708aERP060?6aQP80SUR<00@0
lK6608iHS02>F8`0SUR<0P2>F8d208iIS@0308mIS@3b/HD0l[650080l[6500<0oLARoi1LS`3b/XH0
0_n@G8l0103b/XGoT5b?091LS`3c/X@30?>bQ@H0lk:400CoTEf@095MT00006[oTEf@102AGI030?Fb
O`030?FcOP3f/gh0m[=n00<0m[=m00<0301b099NT@2BGY400P2BGY401@2Y_^T0GcR:09=PT`2CH9<0
mkAm00<0Yl3[00?oYl3[0:O0jonW`>/01`2W`>/00onW`N`0Yl7/ojO1k0060:O1k0070:K1kOnV`Nd0
Y/7]0:K1kOnV`Nd0Y/7]ojK1k@090:K1k@07ojK1k@2V`NgoY/7]0:K1kOnV`Nd0Y/7]ojK1k@060:K1
k@05o`000?nV`Nd0Y/7]ojK1k@2V`Nd00_ooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0
003oooooooooo`0Qooooo`0609AYW_nDJIh0U6VN09AYW_nDJIh0U6VN2P2V`Nd01P3b]hkoSUV>ohiI
S_n>FHh0SUV>ohiISP@0SUV>1@3e/h402@2?Fhl0mK>10?FcP@3e/h40TEjBoi5OT`020700TEnC095N
TP02oi5NTP0300@0L@2V`^d0Y/;]00`0Y/;]00@0k:V50?RdN@3h]7T0n;Ai0P3h]7P0102AGI40n;Ag
0?VdM`3i]7L20?VdMP05095NT@3i]7D0nKAd0?VcLP2AGY409_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool01@2=FHkoSEV>08eISP2W`N`0
k[>A0080SEV?0P2=FXl0103_]900SUZ?0>ndSon>FXl20?6`Q`0508aDRP3a/HL0S5F:0?6aQP2<EX/0
103a/HH208iHS0040?6aQP2>F8`0SUR<08iHS080SUR=0P2>FHd00`2?FHd0l[650?:aQ@020?:aQ@03
0?g4H_n@G8l0l[:600;oT5b?00@0l[:5oi1LS`2@G8l0lk:40`3c/XD60?>bQ004oi5MT02AGI00001Z
oi5MT0@0TEf@0`3e/Wl00`3e/gh0m[=n0?JcOP030?JcO@0300`0LP2Y_^T0TUjA0080TUjA00D0ZKkY
05lhRP2CH9<0Tf2C0?NdO@0209=QT`040:O0jonW`>/0Yl3[ojO0j`L0Yl3[00<0;Af;0:O1k02W`N`0
1`2W`N`01_nW`N`0Y/7]0:K1kOnV`Nd0Y/7]ojK1k@H0Y/7]00KoY/7]0:K1k@2V`NgoY/7]0:K1kOnV
`Nd90:K1k@03ojK1kOl0003ooooo00Gooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000
ooooooooool08?ooool0102DJIkoU6VN09AYWP2DJIh20:K1k@03ojK1k@2V`Nd0Y/7]00L0Y/7]00H0
l[N>ohiIS_n>FHkoSUV>08iIS_n>FHh408iISPD0mK>100`0Se^?0?FcP@3e/h40mK>1095NT_nAGi<0
0P1`095OT`2AGY;oTEjB00<0LOnV`^d;0:K2k@0409UcYonILjL0VG>W09UcY`<0n;Ai0P3h]7P0102A
GI40n;Ag0?VdM`3i]7L20?VdMP03095NT@3i]7D0nKAd0080nK=b9oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02Oooool01`2=FHkoSEV>08eISP22
D8`0k[>A08eIS`3_]9000P2=FXl0103_]900SUZ?0>ndSon>FXl20?6`Q`80lK6700D0S5F:0?6aQP2<
EX/0lK6608eFR`030?6aQP0308iHS03a/HH0lK660080SUR<0P2>F8d208iIS@0308mIS@3b/HD0l[65
0080l[6500<0oLARoi1LS`3b/XH00_n@G8l0103b/XGoT5b?091LS`3c/X@30?>bQ@H0lk:400CoTEf@
095MT00006[oTEf@102AGI030?FbO`030?FcOP3f/gh0m[=n00@0m[=m00H0ZKkY099NT@2BGY40TUjA
0:Vnj@1O>8X209=PT`070?NdO@2CHI<0Tf6CooNdO02CHI<0Yl3[ojO0j`050:O0j`03ojO0j`2W`>/0
;Af;00L0Yl7/00?oYl7/0:O1k?nW`N`00P2W`N`00onV`Nd0Y/7]0:K1k@040:K1k@03ojK1k@2V`Ngo
Y/7]0080Y/7]00?oY/7]0:K1k@2V`Nd01`2V`Nd4ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02_ooool002Cooooo00?o0000ooooooooool07oooool00`2DJIh0Y/7]0:K1k@050:K1
k@03ojK1k@2V`Nd0Y/7]00D0Y/7]00H0l[N>ohiIS_n>FHkoSUV>08iIS_n>FHh408iISPD0mK>100`0
Se^?0?FcP@3e/h40mK>1095NT_nAGi<00P1`095OT`2AGY;oY/;]0:K2kOnV`^d:0:K2k@80VG>W00?o
VG>W09UcY`2ILjL00`3h]7T20?RdN004095MT@3h]7L0nKAg0?VdM`80nKAf00<0TEjA0?VdM@3i]7@0
0P3i/g8Xooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool2o`0000Wooooo
00L0SEV>oheISP2=FHh0PU2<0>jcT@2=FHl0kkB@0080SEZ?00@0kkB@08iJS`3_]8ooSUZ?0P3a/8L2
0?6aQ`80lK6600L0S5J;0?6aQP2=EX/0lK660?6`QP3a/HH0SUR<00@0lK660`3b/HD00`2>FHd0SeV=
0?:aQ@030?:aQ@030?g4H_n@G8l0l[:600;oT5b?00@0l[:5oi1LS`2@G8l0lk:40`3c/XD60?>bQ004
oi5MT02AGI00001Zoi5MT0@0TEf@0`3e/Wl00`3e/gh0m[=n0?JcOP040?JcO@060:Vnj@2BGY40TUjA
099NT@2Y_^T0GcR:0P2CH9<0203g]7d0Tf6C09=QToog]7`0Tf6C09AQU03g]7/0U6:D102W`>/01?nW
`>/0Yl3[0?>I@_nW`N`60:O1k003ojO1k02W`NcoYl7/00D0Yl7/0P2V`Nd00onV`Nd0Y/7]ojK1k@02
0:K1k@03ojK1k@2V`Nd0Y/7]00@0Y/7]00?oY/7]0:K1kOooool01oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00[ooooo000Uooooo`;o00007oooool00`0004L0Y/7]0:K1k@070:K1
k@03ojK1k@2V`Nd0Y/7]0080Y/7]00?ooooo0?:gS_n>FHh00_n>FHh00`2>FHkoSUV>08iISP0308iI
SPT0mK>100P0TEjBoi5OT`020700TEnC0:K2kOnV`^d0Y/;]ojK2k@X0Y/;]00<0=2jL09UcY`2U`^h0
0`2U`^h01_nU`^h0YL;^0:G2k_nU`^h0YL;^ojG2kP80nKAg0P3i]7H00`2AGY40nKAe0?VdM0020?Vc
LRSooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00Kooooo00P0SEV>oheISP2=FHh0PU2<0>jcT@2=FHl0kkB@08eJS`80kkB@00<0SUZ?0>ndSon>FXl0
0P3a/8L20?6aQ`@0lK6600<0SEJ;0?6aQP3a/8H01P3a/HH90?:aQ@060?g4H_n@G8l0l[:6oi1LS`2W
`>`0l[:50`2W`>`00onW`>`0Yl3/0?>bQ@060?>bQ004oi5MT02AGI00001Zoi5MT0@0TEf@0`3e/Wl0
0`3e/gh0m[=n0?JcOP040?JcO@060:Vnj@2BGY40TUjA099NT@2Y_^T0GcR:0P2CH9<01`3g]7d0Tf6C
09=QToog]7`0Tf6C09AQU03g]7/00`2DHY@01@3h]7/0Yl3[ooooooooool0liU300D0Yl7/00?oYl7/
0:O1k?nW`N`01@2W`N`3ooooo`040:K1kOnV`Nd0Y/7]ojK1k@L0Y/7]3Oooool01Ol0003ooooooooo
oooooooo000000cooooo000Wooooo`03o`000?oooooooooo01gooooo2@2V`Nd01?nV`Nd0Y/7]0:K1
kOnV`Nd3ooooo`?oSUV>00<0SUV>ohiISP2>FHh00`2>FHh90?FcP@03095NT_nAGi<00P1`0080Y/;]
00?oY/;]0:K2kOnV`^d02P2V`^d00`0d;i`0YL;^0:G2kP030:G2kP08ojG2kP2U`^h0YL;^ojG2kP2U
`^koYL;^0:G2k_nU`^h60:G2kP030?VcL_oooooooooo02Oooooo00Go0000ooooooooooooooooo`00
000_ooooo`03o`000?oooooooooo00Gooooo00<0SEV>oheISP2=FHh00P3^/i401`2=FHl0kkB@08eJ
S`2U`^koYL;^0:G2k_nU`^h00P2U`^h00`3a/8L0lK670?6aQ`060?6aQP030?6`QP3a/HH0lK6600@0
lK662@3b/HD00`2W`>coYl3/0:O0k0060:O0k004ojO0k02W`>coYl3/0:O0k0D0lk:400CoTEf@095M
T00006[oTEf@102AGI030?FbO`030?FcOP3f/gh0m[=n00@0m[=m00T0ZKkY099NT@2BGY40TUjA0:Vn
j@1O>8X0mkAm09=PT`3g]7d00P2CHI<01?og]7`0Tf6C09AQU03g]7/309ARU0050?RdNooooooooooo
ooooo`2W`>/01P2W`N`01?nW`N`0Yl7/ojO1k02W`N`8ooooo`80Y/7]00?oY/7]0:K1k@2V`Nd04Ooo
ool01Ol0003ooooooooooooooooo000000cooooo000Xooooo`03o`000?oooooooooo01oooooo2@2V
`Nd01?l0003oooooooooooooool3ohiISP0308iIS_n>FHh0SUV>00<0SUV>203e/h400`3d]HD0TEjB
0040L0030:K2k@03ojK2k@2V`^goY/;]00X0Y/;]00<0=2nL0:G2kP2U`^h00`2U`^h02?nU`^h0YL;^
0:G2k_nU`^h0YL;^ojG2kP2U`^koYL;^1`2U`^hZooooo`04o`000?ooooooooooo`00033ooooo00?o
0000ooooooooool01?ooool00`2=FHkoSEV>0:G2kP0:0:G2kP04ojG2kP2U`^koYL;^0?6aQ`H0lK66
00<0n;V00?6aQP3a/HH0103a/HH90?:aQ@@0Yl3/00?oYl3/0:O0k02W`>`0102W`>`00onW`>`0Yl3/
0:O0k0020:O0k080lk:400CoTEf@095MT00006[oTEf@102AGI030?FbO`030?FcOP3f/gh0m[=n00@0
m[=m00H0ZKkY099NT@2BGY40TUjA00l0L`2BGY030?NdO@80Tf6C00ComkAl09=QT`2DHI@0mkAk0`2D
HY@00`3h]7_oooooooooo`02ooooo`0302lOS02W`N`0Yl7/00<0Yl7/8oooool01?l0003ooooooooo
ool0000<ooooo`00:Oooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooooooo`?oSUV>
00L0SUV>ohiISP2>FHh0SUV>ojG3k`2U`nooYL?_00L0mK>100/0m;F5095NTP2ILjL0k<:X09UcY`2V
`^goY/;]0:K2kOnV`^d0Y/;]ojK2k@020:K2k@Kooooo00<0=BnL0:G2kP2U`^h00`2U`^h01_nU`^h0
YL;^0:G2k_nU`^h0YL;^ojG2kPP0YL;^;?ooool00ol0003oooooo`00000aooooo`;o00001?ooool0
0`2U`^koYL;^0:G2kP0<0:G2kP03ojG2kP2U`^koYL;^00D0lK6600<0n;V00?6aQP3a/HH0103a/HH9
0?:aQ@@0Yl3/00?oYl3/0:O0k02W`>`01@2W`>`00onW`>`0Yl3/ojO0k0020:O0k0050?>bQ?nAGI00
TEf@0000J_nAGI000`2AGI020:O1k080mK9o00<0mK=n0?JcOP3f/gh0103f/gd01P0<0780TUjA099N
T@2BGY403`1c099NT0@0mkAm00D0mkAlooNdO02CHI<0U66D0?NdN`0309ARU0030?RdNooooooooooo
00;ooooo00<0<22<0:O1k?ooool09oooool00ol0003oooooo`00000<ooooo`00:_ooool00ol0003o
ooooooooo`0Vooooo`04o`000?ooooooooooooooo`?oSUV>00P0SUV>ojG3k`2U`nl0YL?_ojG3k`2U
`nooYL?_0:G3k`H0mK>100@0m;F5095NTP2ILjL0k<:X0P2ILjL00`3]`jP0Y/;]ooooo`0;ooooo`D0
YL;^00KoYL;^0:G2kP2U`^koYL;^0:G2k_nU`^h40:G2kS3ooooo00?o0000ooooool00000<oooool0
0ol0003oooooooooo`03ooooo`030:G2k_nU`^h0YL;^0100YL;^0P3a/HH00`3h^H00Y/;]0:K2k@04
0?6aQPP0l[6500<0oLAR0:O0k02W`>`01@2W`>`00onW`>`0Yl3/0:O0k0040:O0k00:ojO0k02W`>`0
Yl3/0?>bQ?nAGI00TEf@0000J_nAGI00TEf@ojO1k0L0Yl7/00?oYl7/0:O1k02W`N`00P3f/gd01P0<
0780TUjA099NT@2BGY403`1c099NT0@0mkAm00D0mkAlooNdO03g]7`0U66D0?NdN`0309ARU0030?Rd
Nooooooooooo02cooooo00Co0000oooooooooooo00002oooool002_ooooo0_l0000Vooooo`04o`00
0?ooooooooooooooo`@0YL?_00SoYL?_0:G3k`2U`nooYL?_0:G3konU`nl0YL?_ojG3k`D0mK>10`2U
`^h01@3/`ZP0VG>W09UcY`3]`jP0mKB300gooooo0P2U`^h02?nU`^h0YL;^0:G2k_nU`^h0YL;^ojG2
kP2U`^koYL;^0P2U`^hcooooo`03o`000?oooooo000003?ooooo00?o0000ooooooooool00_ooool3
0:G2kP06ojG2kP2U`^h0YL;^ojG2kP2U`^koYL;^302U`^h00`3h^H00Y/;]0:K2k@050:K2k@030?:a
Q@2V`^d0l[6500@0l[6500<0oLAR0:O0k02W`>`01@2W`>`00onW`>`0Yl3/0:O0k0050:O0k009ojO0
k02W`>`0liaFoi5MT02AGI00001ZojO1k02W`NcoYl7/00L0Yl7/00KoYl7/0:O1k02W`N`0Yl7/0?Jc
O@0<0783099NT@0300l0L`2BGY00mkAm00<0mkAm00D0mkAlooNdO03g]7`0mkAl0?NdN`0309ARU003
0?RdNooooooooooo02gooooo00?o0000ooooool000002oooool002gooooo00?o0000ooooooooool0
8oooool01Ol0003oooooooooooooool0001Q00P0YL?_00CoYL?_0:G3konU`nl0YL?_103e/h460:G2
kP030>g3Z?oooooooooo00gooooo00P0YL;^ojG2kP2U`^h0YL;^ojG2kP2U`^koYL;^0:G2kSOooooo
0_l0000dooooo`03o`000?oooooooooo00?ooooo202U`^h00onU`^h0YL;^0:G2kP080:G2kP050?Ri
P02V`^goY/;]0:K2kOnV`^d0202V`^d20?:aQ@040:K2k@2W`>`0Yl3/ojO0k0L0Yl3/00?oYl3/0:O0
k02W`>`0102W`>/00`3cW5H0001Y0:O1k0040:O1k003ojO1k02W`N`0Yl7/00@0Yl7/00KoYl7/0:O1
k02W`N`0Yl7/0?JcO@0<0783099NT@0300l0L`2BGY00mkAm00<0mkAm00@0mkAlooNdO03g]7`0mkAl
0`3g]7/20?RdNc3ooooo0_l0000;ooooo`00;_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00;ooooo2P2U`nl01?nU`nl0YL?_ojG3k`2U`nl20?FcP@80YL;^00GoYL;^0:G2kP2U`^h0
YL;^0?FdPP0@ooooo`<0YL;^>_ooool3o`0003Gooooo0_l00004ooooo`T0YL;^00KoYL;^0:G2kP2U
`^koYL;^0:G2k_nU`^h30:G2kP@0Y/;]00?oY/;]0:K2kOnV`^d01P2V`^d20?:aQ@050>jgU`2W`>`0
Yl3/0:O0k?nW`>`01P2W`>`20:O0j`03ojO0j`2W`>/0Yl3[00<0Yl3[1P2W`N`00onW`N`0Yl7/0:O1
k0050:O1k005ojO1k02W`N`0Yl7/01X<P00<07800`2BGY400`0?07<0TUj@0?NdO@030?NdO@040?Nd
O?og]7`0mkAl0?NdO0<0mkAk0P3h]7/_ooooo`?o00002oooool002oooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`04ooooo`/0YL?_00OoYL?_0:G3konU`nl0mK>1ojG2kP2U`^koYL;^
00@0YL;^BOooool4o`0003[ooooo00?o0000ooooooooool00_ooool00`2U`^koYL;^0:G2kP0:0:G2
kP04ojG2kP2U`^koYL;^0:G2kPT0Y/;]00?oY/;]0:K2k@2V`^d00P2V`^d0103b/HD0k[NG0:]cU02B
GY430:O0k004ojO0k02W`>`0Yl3/ojO0j`@0Yl3[00?oYl3[0:O0j`2W`>/00P2W`>/60:O1k004ojO1
k02W`N`0Yl7/ojO1k0@0Yl7/00GoYl7/0:O1k02W`N`06Pb000`0LP03099NT@<0Y/;]0`3g]7d0103g
]7comkAl0?NdO03g]7`30?NdN`80n;Ak:oooool4o`0000kooooo000`ooooo`;o00008?ooool00ol0
003oooooooooo`06ooooo`T0YL?_00OoYL?_0:G3konU`nl0YL?_ojG2kP2U`^koYL;^00@0YL;^A_oo
ool3o`0003oooooo00?o0000ooooooooool00oooool00`2U`^koYL;^0:G2kP0:0:G2kP030:K2kOnV
`^d0Y/;]00P0Y/;]00?oY/;]0:K2kOnV`^d00`2V`^d00`3^]iL0Zg>D099NT@02099OT@<0lK:800<0
Yl3[ojO0j`2W`>/0102W`>/00onW`>/0Yl3[0:O0j`030:O0j`L0Yl7/00?oYl7/0:O1k02W`N`01@2W
`N`00`0J3800301bojK2k@070:K2k@03ojK2k@3g]7comkAl0080mkAl0`3g]7/20?RdNbSooooo0ol0
000Booooo`00<_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Wooooo202U`nl4
0:G2kP05ojG2kP2U`^h0YL;^ojG2kP2U`^h0@_ooool4o`0004?ooooo00?o0000ooooooooool00_oo
ool60:G2kP03ojG2kP2U`^h0YL;^00@0YL;^102V`^d00onV`^d0Y/;]0:K2k@070:K2k@06ojK2k@2V
`^goY/;]0>jgU`2[Li@0TUjA0P2BGi440?6bR0030:O0jonW`>/0Yl3[00H0Yl3[00?oYl3[0:O0j`2W
`>/00P2W`>/60:O1k003ojO1k02W`N`0Yl7/00@0Yl7/00@06Pb00:K2k@2V`^goY/;]1P2V`^d00onV
`^d0Y/;]ojK2k@020?NdO0<0mkAk0P3h]7/Tooooo`Co00005Oooool003?ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0;ooooo`030:G2kP2U`nl0YL;^00P0YL;^00?oYL;^0:G2k_nU
`^h0?oooool4o`0004Sooooo0_l00004ooooo`H0YL;^00GoYL;^0:G2kP2U`^h0Y/;]ojK2k@060:K2
k@04ojK2k@2V`^d0Y/;]ojK2k@H0Y/;]0P3^]iL0102[Li@0TUjA099OT@2BGi440?6bR0050000E`2W
`>/0Yl3[0:O0jonW`>/0102W`>/00onW`>/0Yl3[0:O0j`04ooooo`@0Yl7/00?oYl7/0:O1k02W`N`0
0`2W`N`01@0K3H406Pb0ojK2k@2V`^goY/;]00L0Y/;]00?oY/;]0:K2kOnV`^d00`2V`^d00`3g]7/0
n;Ak0?RdN`0Pooooo`Co00006Oooool003Cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0=ooooo`030:G2k_nU`^h0YL;^00L0YL;^?Oooool4o`0004kooooo00?o0000ooooooooool0
0_ooool70:G2kPCooooo0P2V`N`00onV`N`0Y/7/0:K1k0020:K1k0030:K2kOnV`^d0Y/;]00@0Y/;]
0P2V`N`00`3^]iL0Zg>D099NT@02099OT@D0lK:8102W`>/00onW`>/0Yl3[0:O0j`0;ooooo`80Yl7/
00?oYl7/0:O1k02W`N`00P2W`N`01@3eXed0Y/;]ojK2k@2V`^goY/;]00L0Y/;]00?oY/;]0:K2kOnV
`^d01P2V`^dMooooo`?o00007Oooool003Gooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0?ooooo`03ojG2kP2U`^koYL;^00<0YL;^??ooool3o`0005?ooooo00?o0000ooooooooool0
0oooool0102U`^koYL;^0:G2kP2U`^h6ooooo`@0Y/7/00?oY/7/0:K1k02V`N`0102V`N`01onV`N`0
Y/7/0:K1k02BGi;oTUnB0:]cU02BGY400P2BGi460?6bR0<0Yl3[3oooool20:O1k006ojO1k02W`Nco
ooooooooo`0L3X406`f10`2V`^d00onV`^d0Y/;]0:K2k@050:K2k@03ojK2k@2V`^goY/;]0080Y/;]
7?ooool4o`00023ooooo000fooooo`;o00006_ooool00ol0003oooooooooo`0Aooooo`03ojG2kP2U
`^kooooo03Wooooo1?l0001Gooooo`03o`000?oooooooooo00;ooooo0`2U`^h8ooooo`/0Y/7/0_nB
Gi80102BGi;oTUnB0:]cU02BGY42099OT@H0lK:86?ooool00`0L3X40Y/;]0:K2k@030:K2k@03ojK2
k@2V`^d0Y/;]00@0Y/;]00?oY/;]0:K2kOooool06_ooool4o`0002Cooooo000hooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0BOooool4o`0005cooooo0_l0000>ooooo`03ojK1k02V
`N`0Y/7/0080Y/7/00GoY/7/0:K1k?nBGi;oTUnB099OTP02oi9OTP04099OT_nBGi80Zg>D099NT@80
TUnA1P3a/XPHooooo`0301`>P@2V`^d0Y/;]00<0Y/;]00?oY/;]0:K2k@2V`^d00P2V`^dKooooo`Co
0000:?ooool003Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`Co0000
H_ooool00ol0003oooooooooo`0<ooooo`@0Y/7/00D0TV2Coi9PTonBGi;oTUnB099OTP02oi9OTP04
099OT_nBGi80Zg>D099NT@80TUnA1P3a/XPHooooo`0301`>P@2V`^d0Y/;]00@0Y/;]7?ooool3o`00
02cooooo000jooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool3o`0006Oo
oooo00?o0000ooooooooool03?ooool01@2V`NcoTV2C099PT`2BH9?oTV2C00;oTUnB00L0TUnBoi9O
T_nBGi80TUnBoi9OTP2[Li@0TUjA0080TUnA1P3a/XPHooooo`0401d>PP2V`^d0Y/;]0:K2kA_ooooo
1?l0000_ooooo`00>oooool2o`0001Gooooo00?o0000ooooooooool0?_ooool4o`0006_ooooo00?o
0000ooooooooool02oooool01@2CH9?oTV2C099PT`2BH9?oTV2C00;oTUnB00D0TUnBoi9OT_nBGi80
TUnBoi9OTP030?6bR@L0lK:8<oooool4o`0003?ooooo000mooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0>_ooool4o`00073ooooo0_l0000;ooooo`0509=PTonBH9<0TV2C099PTonB
H9<00_nBGi801@2BGi;oTUnBoi9OTP2BGi;oTUnB00<0lK:91`3a/XP_ooooo`Co0000=oooool003ko
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0fooooo`Co0000M_ooool00ol0003o
ooooooooo`08ooooo`0509=PTonBH9<0TV2C099PTonBH9<00_nBGi801@2BGi;oTUnBoi9OTP2BGi;o
TUnB00<0lK:91`3a/XP/ooooo`?o0000>oooool003oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0booooo`Co0000Noooool00ol0003oooooooooo`07ooooo`0509=PTonBH9<0TV2C
099PTonBH9<00_nBGi801@2BGi;oTUnBoi9OTP2BGi;oTUnB00<0lK:9103a/XP00`2U`nl0lK:80?6b
R00Xooooo`Co0000?_ooool0043ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0_
ooooo`?o0000P?ooool00ol0003oooooooooo`06ooooo`0509=PTonBH9<0TV2C099PTonBH9<00_nB
Gi801@2BGi;oTUnBoi9OTP2BGi;oTUnB00<0lK:91`3a/XPTooooo`Co0000@_ooool0047ooooo0_l0
000?ooooo`03o`000?oooooooooo02_ooooo1?l00024ooooo`03o`000?oooooooooo00Gooooo00D0
Tf2Coi9PT`2BH9<0TV2Coi9PT`02oi9OTP05099OT_nBGi;oTUnB099OT_nBGi800`3a/XT70?6bR27o
oooo0ol00016ooooo`00@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo
1?l00029ooooo`;o00001Oooool01@2CH9?oTV2C099PT`2BH9?oTV2C00;oTUnB00D0TUnBoi9OT_nB
Gi80TUnBoi9OTP030?6bR@L0lK:87Oooool4o`0004Wooooo0014ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool08oooool4o`0008oooooo00?o0000ooooooooool00_ooool01@2CH9?o
TV2C099PT`2BH9?oTV2C00;oTUnB00D0TUnBoi9OT_nBGi80TUnBojG3k`030?6bR@L0lK:86Oooool4
o`0004gooooo0015ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?ooool3o`00
09Cooooo00Ko0000oooooooooooooooo09=PTonBH9<2099PT`05oi9PTonBGi;oTUnB099OT_nBGi80
1@2U`nl00onU`nl0YL?_0?6bR0050?6bR1Gooooo1?l0001Aooooo`00A_ooool2o`0000Wooooo00?o
0000ooooooooool07Oooool4o`0009Sooooo00Go0000ooooooooool0Tf2Coi9PT`02099PT`04oi9P
T`0005h0YL?_ojG3k`T0YL?_1@3a/XPBooooo`?o0000EOooool004Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Iooooo`Co0000WOooool2o`00000409=PTonBH9<0TV2C099PT`H0
YL?_00?oYL?_0:G3k`2U`nl01@2U`nl40?6bR0kooooo1?l0001Hooooo`00BOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0002Sooooo`0309=PT`2U`nl0YL?_00<0YL?_
00?oYL?_0:G3k`2U`nl0102U`nl00onU`nl0YL?_0:G3k`030:G3k`<0lK:82_ooool4o`0005cooooo
001:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool3o`000:Sooooo00?o
YL?_0:G3k`2U`nl01@2U`nl00onU`nl0YL?_0:G3k`020:G3k`03ojG3k`2U`nooYL?_00<0YL?_0P3a
/XP6ooooo`Co0000H?ooool004_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>
ooooo`Co0000[?ooool00ol00000YL?_ojG3k`0=0:G3k`04ojG3k`2U`nl0YL?_0?6bR0?ooooo0ol0
001Tooooo`00C?ooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000;7ooooo00?o0000
0:G3k`2U`nl00P2U`nl00onU`nl0YL?_0:G3k`020:G3k`03ojG3k`2U`nl0YL?_00D0YL?_1?l0001W
ooooo`00C_ooool01?l0003oooooooooool00008ooooo`Co0000]oooool40:G3k`03ojG3k`2U`nl0
YL?_00D0YL?_1?l0001[ooooo`00Coooool00ol0003oooooo`000005ooooo`?o0000_?ooool60:G3
k`03ojG3k`2U`noo000000;o0000Koooool0053ooooo0_l000000ooooooo0000o`000002o`000<3o
oooo00<0YL?_ojG3k`2U`nl01?l0001booooo`00DOooool2o`000<Gooooo0_l0001fooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {153.5, 0}} -> {-0.0542361, -0.0193168, \
0.0052844, 0.0052844}, {{10.25, 190.438}, {149.812, 3.625}} -> {-0.0541935, \
0.0451583, 0.00528671, 0.00528671}, {{208.5, 388.688}, {149.812, 3.625}} -> \
{-1.10228, 0.0451583, 0.00528671, 0.00528671}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New classification of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gdnoFrame\  = \ 
        Show[gd, \ Frame \[Rule] False, \ nS];\)\), "\[IndentingNewLine]", 
    \(\(gclass\  = \ 
        DrawHistogramClass[{h1, h2}, \ {class1Color, class2Color}, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gdnoFrame, gclass}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.57086 .29556 Mdot
.50407 .34657 Mdot
.46655 .63873 Mdot
.37143 .78266 Mdot
.30469 .41219 Mdot
.21935 .61945 Mdot
.75874 .36291 Mdot
.21642 .68992 Mdot
.69121 .46804 Mdot
.17803 .44769 Mdot
.27721 .32934 Mdot
.5171 .25799 Mdot
.6538 .53375 Mdot
.30253 .31846 Mdot
.32082 .30112 Mdot
.25833 .52481 Mdot
.34273 .31876 Mdot
.49466 .69386 Mdot
.74595 .66885 Mdot
.37431 .52138 Mdot
.38571 .56772 Mdot
.56365 .83077 Mdot
.24005 .40612 Mdot
.3997 .68651 Mdot
.24221 .49985 Mdot
.29823 .31856 Mdot
.25867 .53652 Mdot
.33469 .41998 Mdot
.46083 .30594 Mdot
.24338 .6277 Mdot
.52287 .64008 Mdot
.80612 .62042 Mdot
.72077 .27744 Mdot
.61897 .58405 Mdot
.44114 .32093 Mdot
.16613 .5698 Mdot
.47896 .70156 Mdot
.80624 .54325 Mdot
.67606 .26478 Mdot
.27935 .6454 Mdot
.69425 .47291 Mdot
.50352 .21821 Mdot
.66794 .68084 Mdot
.25932 .35157 Mdot
.20998 .32747 Mdot
.62349 .49315 Mdot
.24687 .62735 Mdot
.66739 .43167 Mdot
.24675 .70452 Mdot
.29707 .69398 Mdot
.46387 .84092 Mdot
.47227 .17001 Mdot
.40149 .25737 Mdot
.36982 .66157 Mdot
.34838 .77304 Mdot
.58947 .32528 Mdot
.25837 .30254 Mdot
.16848 .44116 Mdot
.77388 .56986 Mdot
.20109 .38203 Mdot
.63367 .71902 Mdot
.58035 .38425 Mdot
.31826 .70587 Mdot
.33573 .28374 Mdot
.35898 .71902 Mdot
.4369 .82541 Mdot
.71737 .61014 Mdot
.67314 .38497 Mdot
.71562 .53653 Mdot
.55423 .6738 Mdot
.75706 .71697 Mdot
.60578 .6295 Mdot
.76971 .51999 Mdot
.40367 .75361 Mdot
.19758 .46869 Mdot
.32335 .70168 Mdot
.58812 .82239 Mdot
.56007 .23589 Mdot
.1813 .60863 Mdot
.21454 .68043 Mdot
.35286 .7518 Mdot
.59706 .3215 Mdot
.70265 .43509 Mdot
.45895 .80537 Mdot
.41223 .28418 Mdot
.5225 .75219 Mdot
.73602 .51697 Mdot
.46483 .22863 Mdot
.7109 .75027 Mdot
.6805 .33009 Mdot
.70196 .56489 Mdot
.37841 .36786 Mdot
.72691 .52811 Mdot
.65747 .25824 Mdot
.25786 .36035 Mdot
.48174 .27934 Mdot
.72361 .42195 Mdot
.62292 .55759 Mdot
.50206 .21096 Mdot
.55918 .17592 Mdot
.25895 .32899 Mdot
.55221 .73121 Mdot
.44012 .37346 Mdot
.22734 .60873 Mdot
.55964 .79464 Mdot
.44756 .20801 Mdot
.55154 .17853 Mdot
.70266 .51897 Mdot
.70157 .55033 Mdot
.53843 .35372 Mdot
.41832 .33373 Mdot
.70182 .38223 Mdot
.17726 .53698 Mdot
.64425 .48482 Mdot
.68263 .63686 Mdot
.38585 .42778 Mdot
.2784 .56756 Mdot
.69055 .23093 Mdot
.70322 .39069 Mdot
.37946 .48594 Mdot
.35906 .7921 Mdot
.35715 .52364 Mdot
.73334 .43365 Mdot
.51766 .72992 Mdot
.4137 .76408 Mdot
.53769 .61203 Mdot
.18472 .49316 Mdot
.41616 .20133 Mdot
.3373 .4191 Mdot
.55608 .65378 Mdot
.55468 .64531 Mdot
.59878 .82733 Mdot
.35439 .27853 Mdot
.70858 .55055 Mdot
.67987 .39175 Mdot
.45174 .6296 Mdot
.29904 .62286 Mdot
.42389 .2933 Mdot
.72602 .57839 Mdot
.24346 .71734 Mdot
.3268 .76775 Mdot
.61526 .2793 Mdot
.52997 .79999 Mdot
.66452 .4063 Mdot
.581 .60902 Mdot
.36964 .61984 Mdot
.43882 .8293 Mdot
.78889 .48339 Mdot
.70229 .60919 Mdot
.57354 .66814 Mdot
.61387 .36072 Mdot
.353 .35995 Mdot
.37905 .46185 Mdot
.61514 .59407 Mdot
.33318 .60791 Mdot
.22052 .35862 Mdot
.62038 .357 Mdot
.36137 .59257 Mdot
.39124 .71697 Mdot
.63096 .76756 Mdot
.6205 .51311 Mdot
.58739 .21313 Mdot
.42436 .31002 Mdot
.3652 .59441 Mdot
.65236 .55909 Mdot
.35579 .7524 Mdot
.47604 .79432 Mdot
.29213 .55064 Mdot
.6988 .59418 Mdot
.46442 .72035 Mdot
.68706 .3641 Mdot
.55555 .82051 Mdot
.41956 .21094 Mdot
.34721 .38296 Mdot
.83456 .4737 Mdot
.29115 .54381 Mdot
.69929 .7662 Mdot
.43549 .79277 Mdot
.62559 .77449 Mdot
.28401 .70832 Mdot
.70759 .65424 Mdot
.72283 .57102 Mdot
.25412 .31611 Mdot
.7314 .25418 Mdot
.8061 .61543 Mdot
.52748 .6658 Mdot
.26357 .36612 Mdot
.42927 .7282 Mdot
.56482 .23082 Mdot
.53139 .75292 Mdot
.46756 .75785 Mdot
.64313 .6556 Mdot
.5046 .29928 Mdot
.82026 .47662 Mdot
.50431 .27209 Mdot
.4207 .72637 Mdot
.61211 .35653 Mdot
.42662 .76735 Mdot
.23758 .44675 Mdot
.43759 .63428 Mdot
.45446 .71021 Mdot
.66971 .30979 Mdot
.2135 .50723 Mdot
.29907 .35725 Mdot
.22207 .50906 Mdot
.63859 .58485 Mdot
.67953 .57536 Mdot
.38194 .70828 Mdot
.34209 .6099 Mdot
.74773 .47468 Mdot
.17669 .5722 Mdot
.72076 .37182 Mdot
.6259 .45839 Mdot
.34752 .3711 Mdot
.74128 .66026 Mdot
.30778 .29818 Mdot
.72949 .74056 Mdot
.76897 .43303 Mdot
.54426 .28753 Mdot
.64681 .34351 Mdot
.45615 .81555 Mdot
.56008 .65898 Mdot
.55801 .31215 Mdot
.67166 .41473 Mdot
.48333 .2415 Mdot
.28426 .28406 Mdot
.46209 .28315 Mdot
.60297 .56874 Mdot
.28881 .29225 Mdot
.79929 .38209 Mdot
.58456 .60287 Mdot
.61532 .42623 Mdot
.27034 .6828 Mdot
.28886 .3416 Mdot
.82921 .55559 Mdot
.66991 .21532 Mdot
.53797 .76621 Mdot
.42695 .60477 Mdot
.77008 .35195 Mdot
.77206 .3763 Mdot
.71461 .41477 Mdot
.18161 .60847 Mdot
.72854 .70231 Mdot
.35483 .55002 Mdot
.5023 .71546 Mdot
.66001 .62695 Mdot
.7066 .46362 Mdot
.30527 .75874 Mdot
.32032 .66117 Mdot
.62094 .29411 Mdot
.39822 .8219 Mdot
.21801 .67178 Mdot
.58135 .35181 Mdot
.82894 .56109 Mdot
.71789 .73133 Mdot
.68053 .64548 Mdot
.78335 .64402 Mdot
.51707 .82745 Mdot
.31928 .50677 Mdot
.22509 .58104 Mdot
.56622 .82113 Mdot
.50479 .19381 Mdot
.44364 .36517 Mdot
.58665 .64743 Mdot
.45784 .64722 Mdot
.7119 .75923 Mdot
.60927 .60844 Mdot
.192 .43639 Mdot
.19991 .63045 Mdot
.71818 .63121 Mdot
.62888 .38705 Mdot
.41964 .22455 Mdot
.49109 .79561 Mdot
.7482 .36789 Mdot
.72496 .34404 Mdot
.68191 .55673 Mdot
.33957 .53206 Mdot
.25285 .49779 Mdot
.67533 .78487 Mdot
.46711 .2676 Mdot
.41256 .71718 Mdot
.45868 .72543 Mdot
.19651 .57753 Mdot
.68369 .5829 Mdot
.50099 .20769 Mdot
.39401 .25215 Mdot
.56182 .31042 Mdot
.78103 .4423 Mdot
.30613 .43637 Mdot
.34501 .78041 Mdot
.24191 .46271 Mdot
.58406 .41188 Mdot
.59326 .66432 Mdot
.33592 .70198 Mdot
.18831 .51076 Mdot
.39803 .41655 Mdot
.76196 .69968 Mdot
.30937 .62231 Mdot
.75131 .34821 Mdot
.3221 .70584 Mdot
.32411 .77947 Mdot
.57197 .19838 Mdot
.59015 .66094 Mdot
.65835 .45637 Mdot
.31769 .73993 Mdot
.67811 .3072 Mdot
.68622 .41178 Mdot
.6027 .17951 Mdot
.27111 .37026 Mdot
.61451 .7883 Mdot
.57372 .68264 Mdot
.75851 .38313 Mdot
.35302 .32296 Mdot
.51805 .17263 Mdot
.58937 .36872 Mdot
.59124 .21365 Mdot
.63204 .58667 Mdot
.37403 .24583 Mdot
.34967 .80475 Mdot
.29981 .5209 Mdot
.54527 .19142 Mdot
.4786 .62289 Mdot
.79904 .66584 Mdot
.7305 .5661 Mdot
.74196 .53197 Mdot
.42071 .2791 Mdot
.36239 .37507 Mdot
.33197 .48139 Mdot
.21944 .6973 Mdot
.33532 .68588 Mdot
.51731 .66275 Mdot
.8125 .49689 Mdot
.50865 .288 Mdot
.72555 .63384 Mdot
.37064 .19739 Mdot
.66297 .77967 Mdot
.19218 .35465 Mdot
.30253 .27379 Mdot
.33546 .29166 Mdot
.58426 .27688 Mdot
.3661 .63791 Mdot
.29556 .67299 Mdot
.59294 .30793 Mdot
.26212 .34614 Mdot
.37917 .2674 Mdot
.34385 .75588 Mdot
.29662 .29268 Mdot
.55549 .17266 Mdot
.47988 .18378 Mdot
.5036 .31018 Mdot
.49221 .2038 Mdot
.38695 .70079 Mdot
.53149 .73485 Mdot
.78781 .44805 Mdot
.64805 .31222 Mdot
.33611 .35788 Mdot
.24942 .29642 Mdot
.53695 .37471 Mdot
.61268 .26951 Mdot
.73352 .36491 Mdot
.59121 .32743 Mdot
.40357 .34847 Mdot
.29766 .60464 Mdot
.2051 .46508 Mdot
.53051 .61588 Mdot
.43556 .35244 Mdot
.31509 .28673 Mdot
.37446 .48907 Mdot
.42471 .76496 Mdot
.62639 .31851 Mdot
.479 .16182 Mdot
.37968 .81318 Mdot
.3382 .40032 Mdot
.62485 .36358 Mdot
.69754 .5828 Mdot
.28455 .65536 Mdot
.75323 .32315 Mdot
.27146 .53111 Mdot
.6356 .52615 Mdot
.45427 .2827 Mdot
.59181 .21201 Mdot
.32117 .34746 Mdot
.77059 .31174 Mdot
.65599 .62376 Mdot
.64547 .70841 Mdot
.74145 .6738 Mdot
.56612 .81491 Mdot
.3065 .61865 Mdot
.40181 .62431 Mdot
.33953 .77022 Mdot
.50026 .73401 Mdot
.57108 .17781 Mdot
.35161 .23787 Mdot
.76874 .31254 Mdot
.18416 .48188 Mdot
.7208 .70636 Mdot
.3633 .38732 Mdot
.53812 .77928 Mdot
.42825 .37082 Mdot
.46679 .18118 Mdot
.22591 .42818 Mdot
.54118 .71178 Mdot
.73782 .44478 Mdot
.28643 .43316 Mdot
.63623 .52354 Mdot
.25497 .5874 Mdot
.49489 .67503 Mdot
.21711 .54213 Mdot
.2311 .3227 Mdot
.20914 .64917 Mdot
.26738 .44974 Mdot
.74529 .73887 Mdot
.64719 .30833 Mdot
.56292 .29572 Mdot
.58694 .60934 Mdot
.48869 .81615 Mdot
.48349 .23535 Mdot
.78435 .44235 Mdot
.37298 .62875 Mdot
.40282 .17994 Mdot
.39204 .61217 Mdot
.50067 .28421 Mdot
.33423 .64143 Mdot
.26654 .36654 Mdot
.28263 .52956 Mdot
.27305 .27502 Mdot
.64227 .45107 Mdot
.33184 .67581 Mdot
.42615 .66546 Mdot
.77216 .65273 Mdot
.69988 .41187 Mdot
.4652 .33983 Mdot
.80281 .37973 Mdot
.34901 .22167 Mdot
.3174 .77179 Mdot
.73439 .26319 Mdot
.24501 .5794 Mdot
.65979 .21088 Mdot
.24178 .50451 Mdot
.61972 .32154 Mdot
.79842 .50901 Mdot
.42758 .25673 Mdot
.63788 .58035 Mdot
.41041 .71087 Mdot
.74663 .47402 Mdot
.32226 .28833 Mdot
.20322 .42099 Mdot
.50561 .23432 Mdot
.20282 .62296 Mdot
.28787 .73422 Mdot
.6441 .40827 Mdot
.33258 .38208 Mdot
.37339 .3084 Mdot
.53783 .64486 Mdot
.80612 .44067 Mdot
.63434 .3277 Mdot
.64072 .3092 Mdot
.58798 .74985 Mdot
.29197 .23174 Mdot
.54202 .28375 Mdot
.71442 .50193 Mdot
.41102 .39267 Mdot
.5406 .36573 Mdot
.73394 .50145 Mdot
.25009 .34912 Mdot
.31828 .28818 Mdot
.24369 .61545 Mdot
.36524 .61176 Mdot
.17338 .52179 Mdot
.2868 .60117 Mdot
.31959 .57967 Mdot
.58933 .3923 Mdot
.42879 .23508 Mdot
.68307 .35427 Mdot
.33556 .7291 Mdot
.52165 .22295 Mdot
.37745 .61172 Mdot
.2741 .47449 Mdot
.40708 .69187 Mdot
.66089 .45643 Mdot
.52572 .65974 Mdot
.34702 .77378 Mdot
.45617 .19294 Mdot
.55391 .81755 Mdot
.67896 .32264 Mdot
.17376 .52451 Mdot
.56172 .69129 Mdot
.60981 .67578 Mdot
.60721 .79647 Mdot
.79206 .3762 Mdot
.23835 .29359 Mdot
.73446 .36295 Mdot
.51493 .23797 Mdot
.2428 .72139 Mdot
.78726 .58218 Mdot
.52422 .18696 Mdot
.33431 .74954 Mdot
.38539 .5302 Mdot
.67866 .78318 Mdot
.41429 .41302 Mdot
.78734 .57709 Mdot
.74249 .33192 Mdot
.17931 .53306 Mdot
.77965 .65481 Mdot
.83736 .48619 Mdot
.4123 .62471 Mdot
.65991 .57978 Mdot
.43139 .20644 Mdot
.65977 .6079 Mdot
.27461 .46149 Mdot
.69312 .49776 Mdot
.33627 .39313 Mdot
.7566 .68609 Mdot
.34205 .75008 Mdot
.50116 .21824 Mdot
.52527 .32716 Mdot
.16274 .51344 Mdot
.25075 .27758 Mdot
.34611 .74868 Mdot
.23364 .48417 Mdot
.47368 .71786 Mdot
.6237 .37697 Mdot
.62277 .62955 Mdot
.71024 .53402 Mdot
.43758 .7226 Mdot
.36594 .47264 Mdot
.75545 .55231 Mdot
.36006 .80234 Mdot
.66157 .43159 Mdot
.58479 .79055 Mdot
.54028 .33579 Mdot
.62575 .76788 Mdot
.20634 .4248 Mdot
.6531 .70656 Mdot
.48034 .8361 Mdot
.83467 .43184 Mdot
.46638 .78244 Mdot
.76924 .60351 Mdot
.62413 .55968 Mdot
.62114 .42134 Mdot
.80319 .37675 Mdot
.27651 .42459 Mdot
.40264 .29905 Mdot
.63931 .43163 Mdot
.41111 .71035 Mdot
.32979 .49232 Mdot
.40369 .73195 Mdot
.38024 .66625 Mdot
.39416 .24412 Mdot
.60223 .40177 Mdot
.43411 .71051 Mdot
.31446 .44278 Mdot
.30072 .25397 Mdot
.51828 .16802 Mdot
.73274 .38675 Mdot
.34535 .51883 Mdot
.7848 .63002 Mdot
.505 .33771 Mdot
.27025 .67538 Mdot
.35628 .53978 Mdot
.79893 .38946 Mdot
.21242 .44268 Mdot
.43751 .37831 Mdot
.32282 .21279 Mdot
.24902 .70262 Mdot
.43758 .20882 Mdot
.30736 .22946 Mdot
.4896 .6976 Mdot
.67353 .39539 Mdot
.61797 .79585 Mdot
.45201 .73992 Mdot
.6968 .31147 Mdot
.25067 .62476 Mdot
.6042 .77031 Mdot
.37852 .64315 Mdot
.22725 .46217 Mdot
.6037 .69044 Mdot
.81722 .37549 Mdot
.29412 .26255 Mdot
.27313 .67996 Mdot
.41826 .28489 Mdot
.62482 .45029 Mdot
.34788 .66585 Mdot
.17799 .60298 Mdot
.3738 .44722 Mdot
.71258 .65247 Mdot
.2876 .61898 Mdot
.26514 .56379 Mdot
.51657 .32137 Mdot
.69001 .43576 Mdot
.73489 .71422 Mdot
.71376 .2681 Mdot
.28206 .3227 Mdot
.72133 .71004 Mdot
.42586 .75512 Mdot
.59059 .24792 Mdot
.74907 .49718 Mdot
.38936 .33267 Mdot
.63544 .24837 Mdot
.2933 .47846 Mdot
.62699 .35035 Mdot
.62581 .73473 Mdot
.2899 .44572 Mdot
.54245 .35466 Mdot
.217 .67052 Mdot
.21838 .30662 Mdot
.56391 .68817 Mdot
.28827 .25742 Mdot
.78006 .49468 Mdot
.31111 .60309 Mdot
.83026 .49907 Mdot
.79744 .62348 Mdot
.44467 .30127 Mdot
.50342 .29792 Mdot
.38454 .47388 Mdot
.4419 .83444 Mdot
.72113 .30313 Mdot
.67157 .63745 Mdot
.7842 .65159 Mdot
.5514 .69266 Mdot
.62995 .20537 Mdot
.56428 .35045 Mdot
.67565 .42502 Mdot
.32909 .28397 Mdot
.73506 .57531 Mdot
.73033 .29267 Mdot
.77523 .68044 Mdot
.225 .33795 Mdot
.55226 .35033 Mdot
.43819 .28944 Mdot
.60568 .70756 Mdot
.81959 .37538 Mdot
.20123 .53808 Mdot
.78384 .49509 Mdot
.46891 .27403 Mdot
.38845 .30162 Mdot
.40046 .30174 Mdot
.42504 .27703 Mdot
.53208 .35105 Mdot
.83473 .53971 Mdot
.55562 .81881 Mdot
.44534 .25192 Mdot
.75143 .63994 Mdot
.57056 .78564 Mdot
.33897 .64089 Mdot
.78165 .49601 Mdot
.82677 .41802 Mdot
.40643 .30182 Mdot
.69394 .32615 Mdot
.5467 .6264 Mdot
.33955 .73169 Mdot
.61213 .78919 Mdot
.35588 .46369 Mdot
.43002 .30516 Mdot
.49151 .65228 Mdot
.80671 .50749 Mdot
.24194 .50733 Mdot
.81468 .62918 Mdot
.39114 .33804 Mdot
.20845 .44948 Mdot
.48335 .62712 Mdot
.51977 .2765 Mdot
.43285 .19553 Mdot
.28025 .48768 Mdot
.55067 .74771 Mdot
.57991 .2916 Mdot
.59045 .80792 Mdot
.54873 .26416 Mdot
.38852 .19383 Mdot
.55861 .69929 Mdot
.73784 .56562 Mdot
.67458 .64689 Mdot
.25153 .51215 Mdot
.19139 .49704 Mdot
.69611 .43391 Mdot
.52262 .81553 Mdot
.30424 .32661 Mdot
.39626 .36981 Mdot
.27097 .27359 Mdot
.47014 .21077 Mdot
.67069 .71803 Mdot
.81772 .44099 Mdot
.75613 .58447 Mdot
.67034 .27125 Mdot
.62203 .64904 Mdot
.23844 .64393 Mdot
.38264 .4361 Mdot
.50075 .28192 Mdot
.66096 .71318 Mdot
.34768 .65927 Mdot
.55908 .2903 Mdot
.5845 .69245 Mdot
.84222 .51794 Mdot
.75729 .57807 Mdot
.37705 .71204 Mdot
.67572 .77727 Mdot
.33183 .65221 Mdot
.33345 .56276 Mdot
.78833 .64388 Mdot
.23056 .64421 Mdot
.64475 .66113 Mdot
.69757 .41423 Mdot
.72305 .49672 Mdot
.77786 .69598 Mdot
.54861 .3424 Mdot
.4671 .71412 Mdot
.74699 .52441 Mdot
.39248 .58785 Mdot
.17326 .44135 Mdot
.53804 .33049 Mdot
.67802 .34906 Mdot
.23846 .63884 Mdot
.30832 .77353 Mdot
.61066 .4152 Mdot
.59827 .60046 Mdot
.30042 .54422 Mdot
.69442 .23291 Mdot
.67802 .63469 Mdot
.36991 .62588 Mdot
.71651 .49913 Mdot
.63492 .70343 Mdot
.48804 .76057 Mdot
.61605 .24496 Mdot
.73291 .31698 Mdot
.36047 .44938 Mdot
.3515 .80476 Mdot
.48709 .79338 Mdot
.65961 .52793 Mdot
.69532 .24682 Mdot
.43291 .18149 Mdot
.36414 .32938 Mdot
.65999 .77967 Mdot
.47437 .16927 Mdot
.34436 .39266 Mdot
.43588 .77147 Mdot
.62296 .64829 Mdot
.23227 .47895 Mdot
.42832 .68667 Mdot
.61184 .3156 Mdot
.73613 .43875 Mdot
.3358 .29097 Mdot
.52886 .26623 Mdot
.51895 .35443 Mdot
.61862 .32549 Mdot
.55163 .31349 Mdot
.54321 .68968 Mdot
.28017 .46996 Mdot
.51146 .31122 Mdot
.65672 .66582 Mdot
.48213 .70404 Mdot
.70307 .34727 Mdot
.77365 .54741 Mdot
.31673 .50072 Mdot
.65034 .23432 Mdot
.36183 .33975 Mdot
.29574 .76624 Mdot
.29993 .46066 Mdot
.61002 .69094 Mdot
.3065 .23704 Mdot
.28834 .33191 Mdot
.6675 .37613 Mdot
.4284 .82778 Mdot
.73699 .67186 Mdot
.26854 .48392 Mdot
.24352 .5944 Mdot
.74985 .30103 Mdot
.79091 .6713 Mdot
.60678 .68351 Mdot
.67807 .68828 Mdot
.70842 .66066 Mdot
.16743 .46901 Mdot
.43688 .67602 Mdot
.27358 .64028 Mdot
.32521 .34896 Mdot
.4185 .20479 Mdot
.23915 .37458 Mdot
.65486 .36443 Mdot
.25458 .44927 Mdot
.6581 .37186 Mdot
.41965 .60413 Mdot
.79282 .55434 Mdot
.40909 .29198 Mdot
.5128 .72146 Mdot
.29237 .49484 Mdot
.34446 .52936 Mdot
.26231 .44895 Mdot
.76909 .48143 Mdot
.2711 .27387 Mdot
.76858 .62511 Mdot
.45614 .74514 Mdot
.50579 .17784 Mdot
.50646 .34767 Mdot
.25357 .729 Mdot
.83679 .46934 Mdot
.80433 .39102 Mdot
.6492 .78311 Mdot
.72324 .45854 Mdot
.67571 .71083 Mdot
.609 .34154 Mdot
.30973 .43953 Mdot
.40134 .22161 Mdot
.64641 .24873 Mdot
.30463 .33574 Mdot
.65275 .62253 Mdot
.34344 .78786 Mdot
.48769 .15951 Mdot
.28031 .38087 Mdot
.65512 .29182 Mdot
.51444 .19619 Mdot
.36158 .5998 Mdot
.50352 .82762 Mdot
.35575 .64874 Mdot
.74869 .72854 Mdot
.52462 .70137 Mdot
.62169 .66513 Mdot
.71264 .56642 Mdot
.26411 .6258 Mdot
.80779 .51719 Mdot
.34422 .51807 Mdot
.26225 .7271 Mdot
.43867 .63266 Mdot
.56845 .3217 Mdot
.69894 .59842 Mdot
.65088 .29574 Mdot
.74836 .26974 Mdot
.32463 .66457 Mdot
.23156 .64149 Mdot
.58565 .37547 Mdot
.67066 .45393 Mdot
.65044 .72137 Mdot
.75929 .64014 Mdot
.48613 .24848 Mdot
.31836 .42705 Mdot
.24367 .6287 Mdot
.68873 .26976 Mdot
.58056 .30891 Mdot
.77325 .43068 Mdot
.84143 .50077 Mdot
.72688 .45546 Mdot
.36634 .27186 Mdot
.74209 .51657 Mdot
.27953 .4863 Mdot
.21023 .40367 Mdot
.54211 .33425 Mdot
.19216 .58784 Mdot
.612 .74671 Mdot
.59803 .26991 Mdot
.31012 .63161 Mdot
.22706 .57099 Mdot
.70386 .456 Mdot
.58119 .81283 Mdot
.19594 .63544 Mdot
.42708 .73187 Mdot
.67219 .61882 Mdot
.64521 .39992 Mdot
.60199 .20469 Mdot
.66528 .6164 Mdot
.74127 .59183 Mdot
.31694 .62213 Mdot
.55668 .64301 Mdot
.69392 .25482 Mdot
.17859 .47914 Mdot
.29854 .47657 Mdot
.52161 .68262 Mdot
.55738 .81341 Mdot
.36154 .21735 Mdot
.43633 .64598 Mdot
.38976 .81897 Mdot
.67044 .30995 Mdot
.36803 .49669 Mdot
.42668 .38276 Mdot
.222 .32227 Mdot
.16372 .44288 Mdot
.57052 .64004 Mdot
.59169 .27264 Mdot
.74322 .48696 Mdot
.38052 .61908 Mdot
.19347 .42684 Mdot
.47168 .68643 Mdot
.46413 .23002 Mdot
.45727 .63027 Mdot
.36726 .64128 Mdot
.8298 .50327 Mdot
.54895 .29755 Mdot
.60854 .29201 Mdot
.64959 .37808 Mdot
.67022 .53948 Mdot
.349 .79169 Mdot
.39774 .40981 Mdot
.58359 .65655 Mdot
.6839 .72324 Mdot
.77714 .43533 Mdot
.49481 .69853 Mdot
.33013 .30442 Mdot
.43977 .34464 Mdot
.18465 .61799 Mdot
.63005 .36505 Mdot
.36868 .44645 Mdot
.78929 .48495 Mdot
.43468 .16798 Mdot
.77561 .30118 Mdot
.783 .31259 Mdot
.31944 .65212 Mdot
.59624 .80653 Mdot
.64396 .70353 Mdot
.50474 .66908 Mdot
.55859 .341 Mdot
.62612 .19668 Mdot
.31695 .23216 Mdot
.70434 .39093 Mdot
.56385 .26877 Mdot
.56954 .3568 Mdot
.76302 .40837 Mdot
.22166 .53086 Mdot
.48774 .83756 Mdot
.50621 .34672 Mdot
.72322 .30691 Mdot
.69945 .26386 Mdot
.27259 .42606 Mdot
.55187 .31415 Mdot
.63199 .74891 Mdot
.30111 .75449 Mdot
.6977 .63854 Mdot
.65397 .31976 Mdot
.81761 .48849 Mdot
.37816 .66154 Mdot
.27503 .3815 Mdot
.26244 .39235 Mdot
.27992 .50857 Mdot
.5537 .23506 Mdot
.76485 .32929 Mdot
.49358 .16405 Mdot
.6206 .41794 Mdot
.63902 .36865 Mdot
.66455 .72329 Mdot
.48289 .20116 Mdot
.42333 .83322 Mdot
.38688 .37573 Mdot
.43637 .6218 Mdot
.42026 .27754 Mdot
.61496 .74164 Mdot
.67493 .68404 Mdot
.22544 .39985 Mdot
.3489 .63974 Mdot
.64525 .40976 Mdot
.41971 .67365 Mdot
.23313 .41212 Mdot
.41222 .1937 Mdot
.56451 .64301 Mdot
.77329 .69954 Mdot
.72412 .50153 Mdot
.58126 .21666 Mdot
.31842 .38615 Mdot
.74933 .34931 Mdot
.72399 .53133 Mdot
.43721 .61495 Mdot
.48766 .71358 Mdot
.34561 .29136 Mdot
.60668 .36892 Mdot
.60749 .23156 Mdot
.52781 .27715 Mdot
.44594 .68855 Mdot
.52349 .18268 Mdot
.24314 .41087 Mdot
.53999 .81701 Mdot
.35124 .68251 Mdot
.58689 .60781 Mdot
.46412 .20808 Mdot
.29781 .7624 Mdot
.78205 .61057 Mdot
.6012 .42317 Mdot
.41542 .58475 Mdot
.78545 .4584 Mdot
.32914 .33074 Mdot
.57366 .63345 Mdot
.20795 .64516 Mdot
.4642 .1942 Mdot
.27447 .41073 Mdot
.32326 .27494 Mdot
.33555 .6433 Mdot
.56519 .69491 Mdot
.62287 .39337 Mdot
.59099 .72782 Mdot
.37741 .75197 Mdot
.32632 .26368 Mdot
.43559 .63242 Mdot
.70525 .22634 Mdot
.31799 .37854 Mdot
.53886 .79454 Mdot
.82558 .57838 Mdot
.21917 .51982 Mdot
.3508 .70627 Mdot
.47132 .63514 Mdot
.64707 .69061 Mdot
.78495 .62114 Mdot
.70041 .52981 Mdot
.40295 .66974 Mdot
.65567 .43162 Mdot
.23534 .70697 Mdot
.34121 .63962 Mdot
0 0 1 r
.15994 .86097 Mdot
.82907 .15102 Mdot
.44004 .09847 Mdot
.80278 .28193 Mdot
.52316 .41561 Mdot
.02628 .72954 Mdot
.1716 .66333 Mdot
.20509 .79892 Mdot
.76283 .07299 Mdot
.47291 .40641 Mdot
.20955 .69714 Mdot
.50058 .39673 Mdot
.07035 .30806 Mdot
.53738 .88264 Mdot
.54161 .54446 Mdot
.60295 .16594 Mdot
.86362 .33914 Mdot
.94244 .88863 Mdot
.45166 .5017 Mdot
.30299 .08606 Mdot
.73509 .79245 Mdot
.84393 .311 Mdot
.20328 .2578 Mdot
.47815 .09168 Mdot
.84715 .51225 Mdot
.86539 .91594 Mdot
.97373 .18292 Mdot
.91315 .03712 Mdot
.47129 .52561 Mdot
.02648 .46467 Mdot
.08997 .33197 Mdot
.23624 .03078 Mdot
.08811 .41443 Mdot
.74828 .92929 Mdot
.23115 .89237 Mdot
.87308 .02316 Mdot
.95013 .97623 Mdot
.91815 .18813 Mdot
.48864 .46042 Mdot
.90148 .71365 Mdot
.40847 .13825 Mdot
.6297 .06103 Mdot
.18204 .11728 Mdot
.09223 .02519 Mdot
.16427 .82726 Mdot
.10229 .70856 Mdot
.25299 .12341 Mdot
.61348 .07218 Mdot
.51178 .47264 Mdot
.07189 .42557 Mdot
.09763 .30427 Mdot
.54677 .14925 Mdot
.95584 .96065 Mdot
.86335 .2619 Mdot
.18914 .67198 Mdot
.57972 .89506 Mdot
.04276 .75562 Mdot
.18494 .87045 Mdot
.07712 .78516 Mdot
.68 .05156 Mdot
.02463 .85129 Mdot
.75774 .74709 Mdot
.40802 .88122 Mdot
.72478 .98166 Mdot
.23288 .02057 Mdot
.54308 .95921 Mdot
.11504 .64234 Mdot
.30588 .96837 Mdot
.11102 .16019 Mdot
.07311 .54115 Mdot
.94163 .21533 Mdot
.87934 .67034 Mdot
.48812 .54209 Mdot
.7741 .03781 Mdot
.04944 .72994 Mdot
.47802 .05964 Mdot
.92861 .57956 Mdot
.41472 .50869 Mdot
.74962 .84876 Mdot
.97623 .76443 Mdot
.04441 .55891 Mdot
.43807 .53906 Mdot
.54648 .02663 Mdot
.76143 .94273 Mdot
.96369 .52125 Mdot
.02161 .10377 Mdot
.97766 .74701 Mdot
.68459 .87476 Mdot
.94305 .19791 Mdot
.88973 .8844 Mdot
.3311 .1967 Mdot
.37014 .90883 Mdot
.93878 .44218 Mdot
.69226 .10647 Mdot
.02071 .54944 Mdot
.1097 .27201 Mdot
.12118 .65523 Mdot
.68368 .88896 Mdot
.0485 .47804 Mdot
.40552 .1611 Mdot
.07213 .87427 Mdot
.64505 .16335 Mdot
.52276 .93906 Mdot
.96148 .45148 Mdot
.92278 .96364 Mdot
.24768 .79375 Mdot
.07995 .11303 Mdot
.94889 .04591 Mdot
.6505 .15035 Mdot
.43593 .09704 Mdot
.39323 .91909 Mdot
.22936 .89347 Mdot
.15535 .13514 Mdot
.15922 .79024 Mdot
.55271 .48513 Mdot
.83414 .30926 Mdot
.59402 .44903 Mdot
.19344 .16872 Mdot
.16789 .36179 Mdot
.50442 .46986 Mdot
.74799 .74443 Mdot
.08122 .81637 Mdot
.91606 .69104 Mdot
.37901 .06072 Mdot
.76933 .75688 Mdot
.83721 .12269 Mdot
.1564 .64983 Mdot
.09902 .36846 Mdot
.08499 .82365 Mdot
.56079 .51749 Mdot
.15912 .14242 Mdot
.77617 .9169 Mdot
.01664 .16983 Mdot
.30508 .14217 Mdot
.45807 .02928 Mdot
.24899 .1151 Mdot
.1738 .28165 Mdot
.79826 .14333 Mdot
.02448 .14904 Mdot
.23851 .22233 Mdot
.95996 .94204 Mdot
.23168 .06231 Mdot
.66468 .80968 Mdot
.82628 .29738 Mdot
.21641 .7902 Mdot
.83776 .14899 Mdot
.42309 .90063 Mdot
.0493 .01546 Mdot
.93823 .49636 Mdot
.12175 .20878 Mdot
.52486 .02651 Mdot
.11157 .11607 Mdot
.80882 .89698 Mdot
.03986 .3394 Mdot
.46346 .10067 Mdot
.4579 .56223 Mdot
.9288 .08397 Mdot
.7235 .92423 Mdot
.82703 .95809 Mdot
.0482 .3115 Mdot
.14349 .62302 Mdot
.76652 .02767 Mdot
.61025 .82701 Mdot
.94789 .12089 Mdot
.04465 .53716 Mdot
.91783 .77168 Mdot
.57139 .44629 Mdot
.69803 .96392 Mdot
.92171 .94605 Mdot
.06182 .93459 Mdot
.96402 .83497 Mdot
.02697 .40723 Mdot
.05599 .07309 Mdot
.44578 .95113 Mdot
.57645 .84402 Mdot
.01704 .19439 Mdot
.14199 .59488 Mdot
.23666 .79426 Mdot
.2758 .07138 Mdot
.19047 .73097 Mdot
.82022 .11044 Mdot
.60421 .87715 Mdot
.02683 .51182 Mdot
.01959 .32723 Mdot
.66481 .90424 Mdot
.43133 .08443 Mdot
.20448 .28037 Mdot
.11565 .38367 Mdot
.02382 .53959 Mdot
.2686 .76141 Mdot
.0136 .62064 Mdot
.5842 .52994 Mdot
.57247 .54601 Mdot
.21236 .09451 Mdot
.10652 .70104 Mdot
.94417 .08322 Mdot
.31437 .11848 Mdot
.50672 .59796 Mdot
.41001 .88712 Mdot
.01014 .56115 Mdot
.58911 .46912 Mdot
.05616 .48774 Mdot
.04662 .80272 Mdot
.03405 .89764 Mdot
.68171 .08709 Mdot
.11732 .41255 Mdot
.5184 .93363 Mdot
.48159 .14071 Mdot
.54272 .97296 Mdot
.12891 .34282 Mdot
.1198 .47546 Mdot
.09876 .91132 Mdot
.78293 .25634 Mdot
.57055 .96789 Mdot
.51203 .51516 Mdot
.09877 .83699 Mdot
.95951 .5324 Mdot
.84041 .19939 Mdot
.41281 .92406 Mdot
.98824 .6869 Mdot
.03854 .1643 Mdot
.18833 .9551 Mdot
.76571 .04085 Mdot
.47269 .57264 Mdot
.92262 .86771 Mdot
.95281 .37059 Mdot
.95477 .67389 Mdot
.92604 .51939 Mdot
.4636 .91256 Mdot
.972 .52344 Mdot
.50911 .941 Mdot
.54649 .58021 Mdot
.10559 .32193 Mdot
.58192 .89652 Mdot
.60643 .47789 Mdot
.4483 .92121 Mdot
.88877 .82264 Mdot
.97489 .01845 Mdot
.90696 .309 Mdot
.85135 .76818 Mdot
.27923 .86186 Mdot
.81588 .82251 Mdot
.37738 .89149 Mdot
.39268 .88285 Mdot
.59769 .51103 Mdot
.41017 .98508 Mdot
.0796 .8789 Mdot
.81201 .74619 Mdot
.64643 .86052 Mdot
.44443 .84489 Mdot
.91185 .21804 Mdot
.06155 .95224 Mdot
.11364 .85515 Mdot
.45405 .45102 Mdot
.69367 .86026 Mdot
.15447 .64336 Mdot
.73676 .97401 Mdot
.86508 .29812 Mdot
.91495 .23763 Mdot
.42858 .42088 Mdot
.96472 .96006 Mdot
.49948 .48455 Mdot
.35481 .83139 Mdot
.8437 .42373 Mdot
.47993 .54307 Mdot
.91895 .19591 Mdot
.26128 .12508 Mdot
.94468 .8957 Mdot
.02966 .3921 Mdot
.05513 .42223 Mdot
.26186 .07615 Mdot
.45506 .02449 Mdot
.89724 .23495 Mdot
.21433 .20957 Mdot
.45983 .12021 Mdot
.169 .77753 Mdot
.20777 .05387 Mdot
.30073 .80911 Mdot
.11238 .18169 Mdot
.86381 .13683 Mdot
.20539 .18499 Mdot
.48662 .88912 Mdot
.98125 .96562 Mdot
.0366 .77871 Mdot
.82206 .19789 Mdot
.81902 .73465 Mdot
.12773 .42525 Mdot
.52809 .91573 Mdot
.02515 .25336 Mdot
.58558 .47651 Mdot
.9467 .23828 Mdot
.44308 .55084 Mdot
.56707 .13781 Mdot
.09596 .88086 Mdot
.4338 .45921 Mdot
.43168 .10196 Mdot
.83842 .9729 Mdot
.47518 .85387 Mdot
.01511 .52431 Mdot
.06911 .36528 Mdot
.56223 .96366 Mdot
.93817 .16707 Mdot
.05289 .52471 Mdot
.85201 .27641 Mdot
.60929 .07531 Mdot
.76106 .09261 Mdot
.94514 .32059 Mdot
.93983 .78647 Mdot
.25332 .04595 Mdot
.75128 .79887 Mdot
.10871 .21845 Mdot
.15731 .21467 Mdot
.33784 .13565 Mdot
.20236 .88428 Mdot
.03502 .72442 Mdot
.25272 .10761 Mdot
.85551 .28481 Mdot
.03042 .8796 Mdot
.83843 .23995 Mdot
.69093 .03509 Mdot
.86586 .27096 Mdot
.49837 .14101 Mdot
.25545 .0432 Mdot
.07856 .83866 Mdot
.05795 .94926 Mdot
.95447 .13912 Mdot
.12584 .88936 Mdot
.53201 .94701 Mdot
.4251 .86408 Mdot
.91693 .73287 Mdot
.80589 .15892 Mdot
.29095 .94108 Mdot
.32668 .81176 Mdot
.94347 .98797 Mdot
.21065 .9126 Mdot
.42126 .05076 Mdot
.77574 .05832 Mdot
.84901 .31565 Mdot
.93942 .20598 Mdot
.21208 .88573 Mdot
.88677 .65548 Mdot
.51328 .54414 Mdot
.56001 .54636 Mdot
.36904 .91151 Mdot
.14855 .5054 Mdot
.5835 .86299 Mdot
.38363 .16011 Mdot
.43441 .94432 Mdot
.54696 .94097 Mdot
.23213 .06839 Mdot
.0903 .45157 Mdot
.15885 .95828 Mdot
.0201 .46268 Mdot
.13776 .65746 Mdot
.40327 .11012 Mdot
.84651 .15934 Mdot
.96013 .29967 Mdot
.20592 .85424 Mdot
.26088 .77541 Mdot
.12542 .41247 Mdot
.11184 .80733 Mdot
.40416 .87241 Mdot
.10154 .35445 Mdot
.2762 .22475 Mdot
.46507 .05187 Mdot
.86312 .12444 Mdot
.02642 .9553 Mdot
.81069 .11086 Mdot
.0518 .60873 Mdot
.93016 .7916 Mdot
.30073 .80638 Mdot
.03433 .59142 Mdot
.12014 .71127 Mdot
.1448 .51168 Mdot
.80745 .32713 Mdot
.82549 .90718 Mdot
.32849 .89605 Mdot
.97726 .47003 Mdot
.60392 .07494 Mdot
.15236 .82784 Mdot
.01737 .32596 Mdot
.67633 .03654 Mdot
.68327 .90554 Mdot
.90108 .31815 Mdot
.07366 .20311 Mdot
.08539 .40116 Mdot
.09832 .92133 Mdot
.4412 .97303 Mdot
.4846 .8562 Mdot
.29864 .15499 Mdot
.98121 .51214 Mdot
.29108 .81922 Mdot
.59801 .90388 Mdot
.2397 .83495 Mdot
.7453 .96895 Mdot
.06876 .29511 Mdot
.4494 .97142 Mdot
.05539 .80417 Mdot
.63571 .83201 Mdot
.71737 .04788 Mdot
.83692 .41869 Mdot
.48913 .96859 Mdot
.73237 .22437 Mdot
.96829 .74795 Mdot
.48311 .95275 Mdot
.83712 .823 Mdot
.75594 .91467 Mdot
.01 .41412 Mdot
.51107 .43572 Mdot
.53609 .50678 Mdot
.0907 .74263 Mdot
.4284 .52542 Mdot
.0391 .9725 Mdot
.93596 .8508 Mdot
.54619 .02956 Mdot
.10865 .0376 Mdot
.78045 .10508 Mdot
.10845 .61368 Mdot
.96609 .85735 Mdot
.50668 .43533 Mdot
.4179 .11812 Mdot
.08808 .9001 Mdot
.3886 .13581 Mdot
.14231 .0591 Mdot
.8326 .11606 Mdot
.04347 .0313 Mdot
.06196 .02078 Mdot
.92522 .40781 Mdot
.83097 .78473 Mdot
.15618 .66158 Mdot
.75269 .87482 Mdot
.62018 .82553 Mdot
.91537 .42931 Mdot
.86322 .41834 Mdot
.31385 .18598 Mdot
.75878 .01141 Mdot
.47308 .39145 Mdot
.84482 .79465 Mdot
.1002 .67149 Mdot
.91964 .37514 Mdot
.50388 .85764 Mdot
.06623 .947 Mdot
.84258 .46142 Mdot
.72357 .18531 Mdot
.95499 .18371 Mdot
.07526 .88398 Mdot
.35239 .83388 Mdot
.49777 .04903 Mdot
.75079 .83823 Mdot
.89841 .38661 Mdot
.36968 .11118 Mdot
.81374 .35786 Mdot
.30422 .21739 Mdot
.47116 .51418 Mdot
.93954 .82062 Mdot
.96359 .47496 Mdot
.68486 .12475 Mdot
.92426 .27672 Mdot
.88336 .1036 Mdot
.03566 .88031 Mdot
.11464 .56203 Mdot
.29109 .21397 Mdot
.81013 .68998 Mdot
.83674 .22483 Mdot
.44148 .41396 Mdot
.11146 .6802 Mdot
.73989 .11866 Mdot
.34226 .84438 Mdot
.06404 .22519 Mdot
.50593 .89523 Mdot
.06816 .90416 Mdot
.07225 .1567 Mdot
.94689 .23376 Mdot
.90026 .60273 Mdot
.21681 .12491 Mdot
.86975 .74717 Mdot
.08189 .129 Mdot
.26986 .02482 Mdot
.02766 .894 Mdot
.51193 .98897 Mdot
.44948 .84207 Mdot
.42882 .49419 Mdot
.96181 .4908 Mdot
.88972 .37161 Mdot
.08219 .60709 Mdot
.87187 .4678 Mdot
.62852 .96518 Mdot
.25281 .25684 Mdot
.91047 .61715 Mdot
.81419 .75285 Mdot
.40924 .8772 Mdot
.50971 .5154 Mdot
.19735 .15437 Mdot
.62803 .0574 Mdot
.31601 .91275 Mdot
.34782 .95161 Mdot
.95716 .58361 Mdot
.88003 .77633 Mdot
.62009 .03448 Mdot
.05782 .191 Mdot
.43255 .87031 Mdot
.41999 .1434 Mdot
.86373 .70072 Mdot
.07531 .61827 Mdot
.83712 .01981 Mdot
.18547 .83214 Mdot
.24118 .1322 Mdot
.13283 .92735 Mdot
.81138 .97899 Mdot
.2593 .23643 Mdot
.84559 .83035 Mdot
.62647 .82037 Mdot
.01827 .82034 Mdot
.4508 .97843 Mdot
.88542 .18078 Mdot
.4879 .39435 Mdot
.76239 .24362 Mdot
.5129 .017 Mdot
.01703 .96198 Mdot
.16164 .14144 Mdot
.19446 .72858 Mdot
.15317 .31129 Mdot
.83863 .56937 Mdot
.92639 .40019 Mdot
.08604 .33555 Mdot
.26948 .98484 Mdot
.26225 .03266 Mdot
.74241 .7598 Mdot
.11042 .88142 Mdot
.55775 .04102 Mdot
.94744 .57994 Mdot
.81409 .29088 Mdot
.96566 .7117 Mdot
.88942 .38596 Mdot
.33588 .06741 Mdot
.08483 .37751 Mdot
.96461 .48629 Mdot
.03572 .26659 Mdot
.02698 .89655 Mdot
.21182 .9659 Mdot
.48402 .12095 Mdot
.23636 .26401 Mdot
.87725 .71614 Mdot
.33714 .86825 Mdot
.01106 .81064 Mdot
.47474 .93827 Mdot
.41758 .52264 Mdot
.50033 .46178 Mdot
.48315 .55543 Mdot
.18965 .29015 Mdot
.98933 .44428 Mdot
.94349 .03595 Mdot
.12188 .71833 Mdot
.61615 .1579 Mdot
.5623 .40256 Mdot
.09736 .45449 Mdot
.20712 .80501 Mdot
.58724 .9829 Mdot
.11389 .43728 Mdot
.11475 .98319 Mdot
.98306 .27466 Mdot
.06616 .09438 Mdot
.43056 .8623 Mdot
.24414 .93231 Mdot
.64188 .97783 Mdot
.79309 .13435 Mdot
.53693 .98483 Mdot
.13038 .88208 Mdot
.07403 .7975 Mdot
.12331 .84787 Mdot
.62277 .06018 Mdot
.38843 .11807 Mdot
.03435 .02496 Mdot
.94994 .71511 Mdot
.38267 .03734 Mdot
.16666 .59056 Mdot
.83593 .0427 Mdot
.04608 .69868 Mdot
.96224 .89138 Mdot
.34928 .841 Mdot
.40785 .02498 Mdot
.95104 .73273 Mdot
.38331 .00982 Mdot
.0109 .02743 Mdot
.01044 .96268 Mdot
.16471 .92979 Mdot
.79817 .71858 Mdot
.85324 .62667 Mdot
.82612 .8174 Mdot
.67488 .18123 Mdot
.48665 .9666 Mdot
.27684 .16605 Mdot
.88373 .16603 Mdot
.88309 .19354 Mdot
.87248 .08039 Mdot
.86514 .61748 Mdot
.05617 .25319 Mdot
.91342 .28981 Mdot
.04371 .04292 Mdot
.0395 .13358 Mdot
.1466 .93024 Mdot
.81894 .0277 Mdot
.93665 .9375 Mdot
.53367 .07842 Mdot
.89029 .69412 Mdot
.95872 .55925 Mdot
.83528 .58285 Mdot
.03187 .61195 Mdot
.13178 .90802 Mdot
.95819 .88187 Mdot
.5478 .54912 Mdot
.48492 .10647 Mdot
.1671 .34014 Mdot
.9036 .07121 Mdot
.71911 .95046 Mdot
.07812 .47855 Mdot
.75691 .95451 Mdot
.57507 .43049 Mdot
.78891 .08245 Mdot
.78368 .92999 Mdot
.30857 .83333 Mdot
.09362 .19319 Mdot
.18022 .13178 Mdot
.88221 .36335 Mdot
.11191 .64343 Mdot
.19496 .02484 Mdot
.54648 .60647 Mdot
.8166 .64476 Mdot
.30536 .09275 Mdot
.22154 .88976 Mdot
.89691 .48781 Mdot
.05113 .76778 Mdot
.0245 .13426 Mdot
.92942 .13416 Mdot
.81974 .11922 Mdot
.59403 .44524 Mdot
.05735 .82897 Mdot
.39305 .87031 Mdot
.74219 .74603 Mdot
.86541 .07849 Mdot
.53045 .84646 Mdot
.9587 .58087 Mdot
.48913 .08849 Mdot
.944 .45641 Mdot
.54991 .94453 Mdot
.13407 .347 Mdot
.94608 .50909 Mdot
.90481 .81232 Mdot
.89853 .67031 Mdot
.52156 .93221 Mdot
.16615 .91448 Mdot
.64635 .86353 Mdot
.62589 .07782 Mdot
.14657 .97953 Mdot
.72404 .82625 Mdot
.58686 .04481 Mdot
.59977 .48905 Mdot
.72265 .84579 Mdot
.1734 .72491 Mdot
.56631 .92151 Mdot
.51725 .85157 Mdot
.93061 .85349 Mdot
.79384 .86415 Mdot
.11537 .73287 Mdot
.21678 .82915 Mdot
.84354 .45745 Mdot
.64724 .84217 Mdot
.1398 .9808 Mdot
.19483 .67902 Mdot
.336 .94993 Mdot
.85859 .84852 Mdot
.89686 .19904 Mdot
.22115 .01615 Mdot
.09116 .02555 Mdot
.2828 .01007 Mdot
.73002 .21138 Mdot
.59594 .90524 Mdot
.90691 .47984 Mdot
.05813 .62152 Mdot
.82717 .61518 Mdot
.12733 .73301 Mdot
.83473 .73275 Mdot
.95506 .01518 Mdot
.11451 .53117 Mdot
.36892 .10013 Mdot
.06687 .68437 Mdot
.40388 .97917 Mdot
.81129 .76456 Mdot
.84643 .75918 Mdot
.54246 .98239 Mdot
.04491 .06817 Mdot
.63122 .0792 Mdot
.17528 .02937 Mdot
.07411 .6956 Mdot
.96309 .47412 Mdot
.25303 .92124 Mdot
.3968 .17186 Mdot
.89968 .4932 Mdot
.86458 .43484 Mdot
.34384 .09948 Mdot
.17836 .07991 Mdot
.17885 .66004 Mdot
.91602 .729 Mdot
.58062 .92475 Mdot
.52903 .56694 Mdot
.61954 .08354 Mdot
.38949 .15715 Mdot
.05545 .06748 Mdot
.86728 .97776 Mdot
.41693 .8746 Mdot
.1008 .45702 Mdot
.8781 .31747 Mdot
.87228 .90236 Mdot
.26836 .24374 Mdot
.51339 .59504 Mdot
.01139 .3216 Mdot
.88845 .328 Mdot
.2517 .81398 Mdot
.79745 .86117 Mdot
.91537 .94901 Mdot
.10525 .27238 Mdot
.97582 .49666 Mdot
.91184 .64755 Mdot
.51751 .45889 Mdot
.66994 .82377 Mdot
.2205 .06469 Mdot
.37668 .92864 Mdot
.05796 .04141 Mdot
.95111 .16136 Mdot
.13632 .38406 Mdot
.45658 .55049 Mdot
.72335 .11456 Mdot
.15044 .23303 Mdot
.92847 .47565 Mdot
.92014 .17815 Mdot
.57596 .05036 Mdot
.30131 .78099 Mdot
.20909 .11191 Mdot
.25315 .74938 Mdot
.24817 .94075 Mdot
.12663 .37513 Mdot
.79496 .25789 Mdot
.66025 .81484 Mdot
.08141 .15314 Mdot
.51962 .59161 Mdot
.14314 .66768 Mdot
.05483 .87329 Mdot
.11971 .57446 Mdot
.9184 .50797 Mdot
.24334 .18304 Mdot
.73853 .10151 Mdot
.11001 .50556 Mdot
.15865 .66844 Mdot
.54283 .86862 Mdot
.85068 .04576 Mdot
.80565 .16267 Mdot
.08464 .76915 Mdot
.87745 .6449 Mdot
.6193 .95177 Mdot
.87097 .86006 Mdot
.72212 .20143 Mdot
.8735 .88555 Mdot
.86164 .16547 Mdot
.06579 .0126 Mdot
.17854 .3579 Mdot
.84423 .32023 Mdot
.54944 .39632 Mdot
.32769 .05069 Mdot
.89174 .27691 Mdot
.93675 .33483 Mdot
.02804 .38155 Mdot
.08492 .17916 Mdot
.32948 .82979 Mdot
.02893 .17636 Mdot
.70576 .0766 Mdot
.84058 .80866 Mdot
.85172 .74657 Mdot
.62247 .88588 Mdot
.61405 .06683 Mdot
.57881 .16044 Mdot
.44015 .97453 Mdot
.19325 .68859 Mdot
.80787 .09845 Mdot
.14176 .52779 Mdot
.92729 .20279 Mdot
.53115 .14609 Mdot
.64272 .96575 Mdot
.93967 .91135 Mdot
.07371 .81512 Mdot
.16317 .72245 Mdot
.95056 .44171 Mdot
.60222 .47244 Mdot
.81861 .90412 Mdot
.0322 .3039 Mdot
.34779 .84667 Mdot
.94869 .47898 Mdot
.13941 .34179 Mdot
.61187 .06793 Mdot
.84648 .85343 Mdot
.57259 .45581 Mdot
.16877 .28969 Mdot
.92754 .82171 Mdot
.21028 .80091 Mdot
.1399 .41691 Mdot
.05516 .31837 Mdot
.47276 .85275 Mdot
.10225 .96008 Mdot
.19743 .18438 Mdot
.92368 .68019 Mdot
.72321 .86948 Mdot
.45236 .85335 Mdot
.14441 .1365 Mdot
.0158 .18486 Mdot
.01431 .70979 Mdot
.95084 .85669 Mdot
.72089 .16593 Mdot
.48788 .01374 Mdot
.30025 .81956 Mdot
.04996 .47649 Mdot
.96195 .62676 Mdot
.5818 .43828 Mdot
.82283 .78047 Mdot
.11174 .62434 Mdot
.14307 .56785 Mdot
.47349 .4381 Mdot
.83301 .73849 Mdot
.76873 .92225 Mdot
.79286 .2718 Mdot
.79698 .30529 Mdot
.95983 .79543 Mdot
.14681 .02476 Mdot
.01191 .6386 Mdot
.04487 .39062 Mdot
.85904 .08055 Mdot
.56158 .94271 Mdot
.03583 .33226 Mdot
.78304 .03026 Mdot
.23317 .07027 Mdot
.97626 .71516 Mdot
.02811 .4118 Mdot
.02623 .90993 Mdot
.86962 .89497 Mdot
.5241 .48228 Mdot
.48993 .54118 Mdot
.27471 .09935 Mdot
.48743 .89648 Mdot
.85156 .48612 Mdot
.60801 .01132 Mdot
.46843 .92329 Mdot
.93453 .45082 Mdot
.49069 .91591 Mdot
.01057 .38453 Mdot
.18135 .21126 Mdot
.4969 .55851 Mdot
.91514 .52371 Mdot
.01927 .65222 Mdot
.07338 .04739 Mdot
.59515 .11429 Mdot
.62799 .17316 Mdot
.14711 .24744 Mdot
.14635 .85311 Mdot
.04282 .16121 Mdot
.11788 .6277 Mdot
.0543 .59011 Mdot
.23852 .98186 Mdot
.44934 .48563 Mdot
.78872 .82216 Mdot
.46343 .58087 Mdot
.58416 .4693 Mdot
.05707 .77118 Mdot
.39856 .10009 Mdot
.80874 .77952 Mdot
.93942 .60465 Mdot
.21781 .95121 Mdot
.1605 .77269 Mdot
.02521 .98549 Mdot
.74026 .23883 Mdot
.18358 .22461 Mdot
.87445 .66852 Mdot
.08366 .82766 Mdot
.91206 .33717 Mdot
.50732 .52427 Mdot
.49192 .52898 Mdot
.90977 .22389 Mdot
.0611 .97832 Mdot
.736 .98948 Mdot
.17684 .3196 Mdot
.51144 .38913 Mdot
.5006 .60228 Mdot
.43758 .55167 Mdot
.92046 .0372 Mdot
.09418 .59012 Mdot
.43835 .49842 Mdot
.34009 .15396 Mdot
.28879 .16584 Mdot
.77297 .28505 Mdot
.12175 .83644 Mdot
.27133 .88611 Mdot
.82395 .34425 Mdot
.04242 .95924 Mdot
.89369 .31685 Mdot
.93843 .37892 Mdot
.93657 .53409 Mdot
.32917 .07873 Mdot
.1734 .25885 Mdot
.21722 .2325 Mdot
.89226 .36293 Mdot
.59606 .97873 Mdot
.07812 .02848 Mdot
.56345 .0293 Mdot
.17463 .70183 Mdot
.69968 .88341 Mdot
.01686 .4156 Mdot
.5897 .11008 Mdot
.47048 .12398 Mdot
.86461 .13544 Mdot
.31097 .11595 Mdot
.4545 .02664 Mdot
.74502 .13343 Mdot
.67889 .05978 Mdot
.98191 .7645 Mdot
.0108 .7033 Mdot
.53052 .58912 Mdot
.70457 .91708 Mdot
.09505 .20822 Mdot
.65919 .88196 Mdot
.87593 .06776 Mdot
.97049 .83199 Mdot
.88421 .29346 Mdot
.9695 .13849 Mdot
.44878 .53956 Mdot
.78287 .08588 Mdot
.07144 .31254 Mdot
.76873 .82698 Mdot
.18571 .25458 Mdot
.78843 .98519 Mdot
.2917 .95132 Mdot
.80913 .8565 Mdot
.02206 .63936 Mdot
.31987 .15504 Mdot
.14957 .52212 Mdot
.25823 .8327 Mdot
.08233 .58791 Mdot
.75387 .82404 Mdot
.98113 .29488 Mdot
.39351 .50711 Mdot
.96887 .64572 Mdot
.80622 .26625 Mdot
.30522 .0588 Mdot
.33785 .07987 Mdot
.54722 .44328 Mdot
.95895 .5248 Mdot
.55629 .1582 Mdot
.57524 .0275 Mdot
.57761 .50268 Mdot
.75922 .75145 Mdot
.90901 .012 Mdot
.10257 .02692 Mdot
.78754 .95832 Mdot
.18039 .27416 Mdot
.07473 .60948 Mdot
.62336 .82108 Mdot
.10598 .09448 Mdot
.07688 .67269 Mdot
.52094 .07678 Mdot
.07202 .82359 Mdot
.8618 .33029 Mdot
.88182 .55923 Mdot
.79687 .71101 Mdot
.20119 .06546 Mdot
.70192 .87584 Mdot
.14108 .70802 Mdot
.75889 .94541 Mdot
.07886 .87463 Mdot
.88728 .62492 Mdot
.18724 .3252 Mdot
.10021 .9041 Mdot
.90917 .58705 Mdot
.20995 .7184 Mdot
.02567 .64576 Mdot
.87479 .92793 Mdot
.02322 .51935 Mdot
.80573 .06311 Mdot
.12613 .88463 Mdot
.03572 .97072 Mdot
.70932 .15086 Mdot
.98173 .60966 Mdot
.43605 .96475 Mdot
.96587 .9541 Mdot
.10089 .03598 Mdot
.64054 .97083 Mdot
.28535 .96306 Mdot
.52421 .09601 Mdot
.4983 .11548 Mdot
.92812 .1037 Mdot
.85229 .41273 Mdot
.93658 .48424 Mdot
.42604 .43817 Mdot
.96091 .52033 Mdot
.76229 .92838 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00630716 0.0238095 0.00630716 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFFFFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF8080FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFFFFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF8080FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80
FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF8080FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF80FFFF80FFFF80FFFF80
FFFF80FFFF80FFFF80FFFF8080FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFFFFFF80FFFF8080FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF80FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00503oool30000ob@0oooo0`000?l?0?ooo`<0003o403oool30000oa<0oooo0`000?lH0?oo
o`<0003o603oool30000on40oooo000A0?ooo`H0003o6@3oool30000o`P0oooo0`000?l?0?ooo`<0
003o403oool30000o`80oooo0`000?l>0?ooo`<0003o603oool30000o`/0oooo0`000?l:0?ooo`<0
003o1P3oool60000omD0oooo000?0?ooo`P0003o0P3oool30000o`L0oooo0`000?l50?ooo`<0003o
0P3oool50000o`@0oooo1@000?l?0?ooo`<0003o0P3oool30000o`D0oooo0`000?l30?ooo`<0003o
0P3oool30000o`h0oooo0`000?lH0?ooo`<0003o2`3oool30000o`@0oooo0`000?l30?ooo`<0003o
1P3oool60000omD0oooo000:0?ooo`<0003o0P3oool?0000o`D0oooo0`000?l20?ooo`H0003o0P3o
ool60000o`<0oooo0`000?lF0?ooo`<0003o1@3oool40000o`L0oooo1@000?l00`3oool0003o0000
o`060000ob00oooo1P000?l30?ooo`H0003o103oool30000o``0oooo1P000?oE0?ooo`002P3oool3
0000o`80oooo3`000?l50?ooo`<0003o0P3oool60000o`@0oooo10000?l20?ooo`@0003o5P3oool3
0000o`D0oooo10000?l90?ooo`<0003o00<0oooo0000o`000?l01P000?l50?ooo`<0003o1`3oool6
0000o`/0oooo1P000?l30?ooo`<0003o1`3oool30000o`T0oooo0`000?lO0?oooj`0P?oo403oool0
00X0oooo0`000?l30?ooo`T0003o0P3oool40000o`T0oooo0`000?l80?ooo`<0003o0P3oool30000
oa80oooo0`000?l:0?ooo`@0003o2@3oool30000o`030?ooo`000?l0003o00H0003o1@3oool30000
o`L0oooo1P000?l:0?ooo`L0003o0`3oool30000o`h0oooo10000?l0103oool0003o0000o`000?lO
0?oooj`0P?oo403oool00100oooo2@000?l20?ooo`@0003o5`3oool50000oa80oooo0`000?lM0?oo
o`<0003o0P3oool30000o`<0oooo0`000?l70?ooo`H0003o2P3oool50000o`P0oooo1P000?l80?oo
o`@0003o00<0oooo0000o`000?l00P000?lN0?oooj`0P?oo403oool00100oooo2@000?l30?ooo`<0
003o5`3oool30000o`X0oooo0`000?l70?ooo`<0003o103oool30000o`D0oooo0`000?l30?ooo`<0
003o203oool80000o`h0oooo0`000?l40?ooo`<0003o1@3oool50000o`P0oooo1P000?l80?ooo`@0
003o0P3oool30000oah0oooo[020ool@0?ooo`00403oool30000o`<0oooo0`000?lE0?ooo`<0003o
1@3oool30000o`H0oooo0`000?l0103oool0003o0000o`000?l>0?ooo`<0003o1@3oool30000o`<0
oooo0`000?l;0?ooo`D0003o1@3oool30000o`H0oooo0`000?l40?ooo`<0003o1`3oool30000o`P0
oooo1P000?l>0?ooo`<0003o7P3ooon/083ooa00oooo000R0?ooo`<0003o2@3oool30000o`040?oo
o`000?l0003o0000o`X0oooo0`000?l0103oool0003o0000o`000?l70?ooo`<0003o103oool30000
o`D0oooo2@000?l;0?ooo`<0003o1P3oool40000o`H0oooo0`000?l40?ooo`<0003o1`3oool30000
o`<0oooo0`000?lg0?oooj`0P?oo403oool00100oooo1@000?l=0?ooo`<0003o203oool80000o`X0
oooo0`000?l30?ooo`<0003o1@3oool30000o`l0oooo0`000?lE0?ooo`H0003o1P3oool30000o`h0
oooo0`000?l30?ooo`<0003o2@3oool30000ob/0oooo[020ool@0?ooo`00403oool50000o`d0oooo
0`000?l80?ooo`P0003o1@3oool30000o`P0oooo0`000?l50?ooo`<0003o3`3oool30000oa<0oooo
20000?l60?ooo`<0003o303oool30000o`D0oooo0`000?l90?ooo`<0003o0P3oool30000obH0oooo
[020ool@0?ooo`00403oool50000oa<0oooo0`000?l20?ooo`P0003o0`3oool50000o`L0oooo1000
0?lN0?ooo`H0003o2@3oool80000o`/0oooo0`000?l70?ooo`<0003o3P3oool60000o`80oooo0`00
0?lV0?oooj`0P?oo403oool00180oooo0`000?lC0?ooo`<0003o1`3oool30000o`<0oooo1@000?l2
0?ooo`<0003o0P3oool40000o`h0oooo0`000?l=0?ooo`H0003o2@3oool80000o`/0oooo0`000?l7
0?ooo`<0003o00<0oooo0000o`000?l00P000?l90?ooo`H0003o0P3oool30000o`80oooo1P000?lN
0?oooj`0P?oo403oool002P0oooo0`000?l=0?ooo`<0003o103oool30000o`80oooo10000?l>0?oo
o`<0003o1P3oool50000o`80oooo1P000?l<0?ooo`D0003o1P3oool30000o`80oooo0`000?l;0?oo
o`@0003o2@3oool60000o`L0oooo1P000?lN0?oooj`0P?oo403oool001@0oooo0`000?l40?ooo`<0
003o4@3oool30000o`d0oooo0`000?lD0?ooo`@0003o1@3oool50000o`<0oooo0`000?l>0?ooo`<0
003o203oool30000o``0oooo0`000?l00`3oool0003o0000o`020000oaH0oooo1P000?lN0?oooj`0
P?oo403oool001@0oooo0`000?l40?ooo`<0003o4@3oool30000o`P0oooo0`000?l20?ooo`<0003o
103oool30000o`80oooo0`000?l20?ooo`<0003o0`3oool50000o`030?ooo`000?l0003o00H0003o
0`3oool30000oaT0oooo0`000?l80?ooo`<0003o00@0oooo0000o`000?l0003o1@3oool30000ocL0
oooo[020ool@0?ooo`00303oool30000o`D0oooo0`000?l40?ooo`<0003o4@3oool30000o`@0oooo
0`000?l0103oool0003o0000o`000?l20?ooo`<0003o103oool30000o`80oooo0`000?l20?ooo`<0
003o0`3oool50000o`050?ooo`000?l0003o0000o`3oool00`000?l40?ooo`<0003o6`3oool30000
o`H0oooo0`000?l00`3oool0003o0000o`040000o`80oooo0`000?l;0?ooo`<0003o1@3oool30000
ob40oooo[020ool@0?ooo`00303oool30000o`P0oooo0`000?lD0?ooo`<0003o1@3oool30000o`04
0?ooo`000?l0003o0000o`T0oooo0`000?l20?ooo`<0003o0P3oool40000o`80oooo1@000?l01@3o
ool0003o0000o`000?l0oooo00<0003o403oool40000o`h0oooo0`000?l60?ooo`<0003o103oool3
0000o`80oooo1@000?l90?ooo`<0003o1@3oool30000ob40oooo[020ool@0?ooo`00303oool30000
o`P0oooo0`000?l20?ooo`<0003o2P3oool30000o`80oooo0`000?l40?ooo`@0003o1`3oool40000
o`L0oooo30000?l90?ooo`D0003o3P3oool40000o`h0oooo0`000?l30?ooo`H0003o103oool30000
o`<0oooo1P000?l70?ooo`<0003o1@3oool30000ob40oooo[020ool@0?ooo`005`3oool30000o`80
oooo0`000?l:0?ooo`<0003o0P3oool40000o`<0oooo1@000?l60?ooo`@0003o1`3oool<0000o`@0
oooo2P000?l>0?ooo`@0003o3@3oool30000o`@0oooo1P000?l:0?ooo`L0003o0P3oool30000o``0
oooo0`000?lN0?oooj`0P?oo403oool001L0oooo0`000?l20?ooo`<0003o2P3oool30000o`<0oooo
0`000?l30?ooo`D0003o1P3oool40000o`X0oooo0`000?l30?ooo`<0003o103oool:0000oal0oooo
0`000?l40?ooo`H0003o2`3oool60000o`80oooo0`000?l<0?ooo`<0003o7P3ooon/083ooa00oooo
000=0?ooo`D0003o1@3oool30000o`P0oooo1@000?l20?ooo`<0003o0`3oool30000o`80oooo1P00
0?l;0?ooo`<0003o1P3oool30000o`X0oooo20000?lQ0?ooo`<0003o203oool30000o`D0oooo0`00
0?l50?ooo`<0003o0P3oool30000o`T0oooo1P000?lN0?oooj`0P?oo403oool000d0oooo1@000?l5
0?ooo`<0003o203oool60000o`040?ooo`000?l0003o0000o`P0oooo0`000?l>0?ooo`<0003o1P3o
ool30000o`040?ooo`000?l0003o0000o`X0oooo1P000?l:0?ooo`<0003o7@3oool30000o`D0oooo
0`000?l:0?ooo`<0003o2@3oool30000o`030?ooo`000?l0003o00@0003o6P3ooon/083ooa00oooo
000=0?ooo`D0003o403oool60000o`040?ooo`000?l0003o0000o`P0oooo0`000?l80?ooo`<0003o
0`3oool30000o`H0oooo0`000?l00`3oool0003o0000o`030000o`P0oooo1P000?l30?ooo`<0003o
103oool30000oad0oooo0`000?l50?ooo`@0003o2@3oool30000o`T0oooo0`000?l00`3oool0003o
0000o`040000oaX0oooo[020ool@0?ooo`003@3oool30000o`L0oooo0`000?l;0?ooo`<0003o5`3o
ool30000oa00oooo1@000?l80?ooo`H0003o0`3oool60000o`040?ooo`000?l0003o0000o``0oooo
0`000?l70?ooo`<0003o3@3oool30000o`<0oooo10000?l20?ooo`<0003o3@3oool60000oaX0oooo
[020ool@0?ooo`003@3oool30000o`D0oooo1@000?l;0?ooo`<0003o103oool30000o`l0oooo1`00
0?l0103oool0003o0000o`000?l60?ooo`<0003o0P3oool30000oa40oooo20000?l70?ooo`<0003o
103oool30000o`L0oooo0`000?l=0?ooo`<0003o0`3oool40000oc80ooooA@20ool30?ooP140P?oo
103ooh1?083ooa00oooo000=0?ooo`H0003o0P3oool50000o`80oooo0`000?l=0?ooo`<0003o3`3o
ool30000o`050?ooo`000?l0003o0000o`3oool00`000?l50?ooo`H0003o2`3oool50?l000L0oooo
1@000?l0103oool0003o0000o`000?l30?ooo`<0003o0`3oool40000o`L0oooo0`000?l?0?ooo`<0
003o00<0oooo0000o`000?l010000?l@0?ooo`<0003o7@3ooom4083oo`H0oon02@20ool<0?ooP4d0
P?oo403oool000l0oooo10000?l20?ooo`<0003o103oool30000o``0oooo10000?l;0?ooo`L0003o
00D0oooo0000o`000?l0003o0?ooo`030000o`D0oooo1P000?l30?ooo`<0o`00103oool60?l00080
oooo0`3o00040?ooo`<0003o00D0oooo0000o`000?l0003o0?ooo`050000o`<0oooo0`000?l:0?oo
o`<0003o3@3oool30000o`@0oooo1P000?l0103oool0003o0000o`000?l70?ooo`D0003o7@3ooom4
083ooa`0oon0C020ool@0?ooo`002`3oool30000o`030?ooo`000?l0003o0080003o2@3oool30000
o``0oooo0`000?l<0?ooo`D0003o3`3oool60000o`<0oooo0`3o00040?ooo`H0o`000P3oool30?l0
00@0oooo0`3o00001@3oool0003o0000o`000?l0oooo00<0003o0P3oool60000o`X0oooo0`000?l=
0?ooo`<0003o103oool60000o`040?ooo`000?l0003o0000o`L0oooo1@000?lM0?oood<0P?oo7P3o
oh1;083ooa00oooo000;0?ooo`L0003o1P3oool30000oa00oooo0`000?l<0?ooo`D0003o4@3oool3
0000o`040?l0003oool0oooo0?ooo`<0o`00103oool30?l000<0oooo1@3o00030?ooo`H0o`000`3o
ool30000o`80oooo0`000?l=0?ooo`<0003o5`3oool30000o`040?ooo`000?l0003o0000o`<0oooo
0`000?l0103oool0003o0000o`000?lO0?oood80P?oo803ooh0D083oo`@0oon0<P20ool@0?ooo`00
2`3oool60000o`L0oooo0`000?l20?ooo`<0003o303oool40000o`@0oooo0`000?l:0?ooo`<0003o
303oool30000o`030?l0003oool0oooo00<0o`00103oool50?l00080oooo1P3o00020?ooo`H0o`00
0`3oool30?l00080oooo0`000?l50?ooo`<0003o1P3oool30000oaX0oooo0`000?l30?ooo`<0003o
103oool60000oaT0oooo@P20oolQ0?ooP100P?oo203ooh0a083ooa00oooo000;0?ooo`H0003o0P3o
ool30000o`80oooo0`000?l20?ooo`<0003o303oool40000o`@0oooo0`000?l:0?ooo`<0003o3@3o
ool30?l00080oooo0`3o00040?ooo`D0o`000P3oool60?l000030?ooo`3o0000o`0000D0o`000`3o
ool30?l000X0oooo0`000?l60?ooo`<0003o6P3oool30000o`<0oooo0`000?l40?ooo`H0003o6@3o
oom1083oob<0oon03020ool=0?ooP2l0P?oo403oool000/0oooo0`000?l50?ooo`<0003o0`3oool3
0000o`040?ooo`000?l0003o0000o``0oooo10000?l40?ooo`<0003o2P3oool60000o`@0oooo1P3o
00020?ooo`H0o`000P3oool70?l000030?ooo`3o0000o`0000D0o`0000@0oooo0?l0003o0000o`00
2`3oool30?l000H0oooo0`000?l60?ooo`<0003o6P3oool30000o`<0oooo0`000?l40?ooo`H0003o
6@3ooom1083oob<0oon03020ool=0?ooP2l0P?oo403oool000/0oooo0`000?l50?ooo`<0003o0`3o
ool30000obP0oooo0`000?l40?ooo`H0o`000P3oool60?l00080oooo1`3o00000`3oool0o`000?l0
00050?l000050?ooo`3o0000o`000?l0003oool00`3o00070?ooo`<0o`003`3oool30000o`l0oooo
1P000?l50?ooo`D0003o00<0oooo0000o`000?l01@000?lO0?oood00P?oo:03ooh04083ooa80oon0
;P20ool@0?ooo`002`3oool30000o`P0oooo1P000?lX0?ooo`<0003o103oool60?l00080oooo5@3o
00070?ooo`<0o`000`3oool30?l000030?ooo`3o0000o`000080o`003P3oool30000o`l0oooo1P00
0?l50?ooo`D0003o00<0oooo0000o`000?l01@000?lO0?oood00P?oo@@3ooh0[083ooa00oooo000F
0?ooo`H0003o0P3oool30000o`P0oooo0`000?l30?ooo`<0003o2`3oool30000o`<0oooo0`3o000=
0?oooa<0o`002@3oool90?l00080oooo0`3o00020?ooo`<0o`002@3oool40000o`h0oooo1P000?l7
0?ooo`<0003o0`3oool50000oal0oooo9`20ool00`3ooh00P?oo083oo`0E083ood<0oon0:P20ool@
0?ooo`005P3oool;0000o`@0oooo0`000?l0103oool0003o0000o`000?l30?ooo`<0003o2`3oool5
0000o`040?ooo`3o0000o`000?l000@0oooo0`3o00070?ooo``0o`0000<0oooo0?l0003o00000`3o
000;0?ooo`L0o`000P3oool30?l00080oooo1@3o00080?ooo`<0003o7P3oool30000o`80oooo0`00
0?lO0?ooobH0P?oo1@3ooh0C083oodD0oon0:@20ool@0?ooo`00503oool30000o`D0oooo1@000?l4
0?ooo`<0003o00@0oooo0000o`000?l0003o0`3oool30000o`040?ooo`000?l0003o0000o`@0oooo
20000?l01@3oool0o`000?l0003o0000oooo00H0o`00103oool90?l000<0oooo0`3o00030?ooo`H0
o`00203oool50?l000T0oooo1@3o00080?ooo`<0003o403oool30000o`X0oooo10000?l20?ooo`<0
003o7`3ooolV083oo`P0oon04020oom50?ooP2T0P?oo403oool001@0oooo0`000?l50?ooo`<0003o
1P3oool30000o`040?ooo`000?l0003o0000o`L0oooo0`000?l40?ooo`<0003o0P3oool30000o`03
0?l0003oool0oooo0080oooo1P3o00040?ooo`H0o`001@3oool30?l000@0oooo1P3o00080?ooo`<0
o`003@3oool30?l000@0oooo0`3o0000103oool0003o0000o`000?l@0?ooo`<0003o2P3oool40000
o`80oooo0`000?lO0?ooob@0P?oo3@3ooh0;083oodL0oon0:@20ool@0?ooo`00503oool30000o``0
oooo0`000?l30?ooo`<0003o0`3oool30000o`040?ooo`000?l0003o0000o`@0oooo0`000?l70?l0
00<0oooo0`3o00070?ooo`P0o`000`3oool30?l000050?ooo`3o0000o`000?l0003oool01@3o0003
0?ooo`D0o`001@3oool30?l000D0oooo0`3o00040?ooo`H0o`0000@0oooo0000o`000?l0003o403o
ool30000o`P0oooo1@000?l40?ooo`<0003o7P3ooolT083ooa00oon01`20oom80?ooP2T0P?oo403o
ool002<0oooo0`000?l90?ooo`<0003o1@3oool30000o`<0oooo1`3o00040?ooo`<0o`002`3oool3
0?l000<0oooo1`3o00000`3oool0o`000?l000020?l000@0oooo1@3o00050?ooo`<0o`001@3oool3
0?l000@0oooo1P3o00030?ooo`<0003o3`3oool30000o`L0oooo1P000?l30?ooo`<0003o7P3ooolT
083ooa00oon01`20oom80?ooP2T0P?oo403oool002<0oooo0`000?l90?ooo`<0003o1@3oool50000
o`030?ooo`3o0000o`0000D0o`00103oool30?l000030?ooo`3o0000o`0000@0o`00103oool30?l0
00H0oooo103o00000`3oool0o`000?l000020?l000@0oooo1@3o00050?ooo`@0o`00103oool30?l0
00@0oooo103o00050?ooo`<0003o00@0oooo0000o`000?l0003o2`3oool30000o`L0oooo1P000?l3
0?ooo`<0003o7P3ooolS083ooa@0oon01020oom80?ooP2T0P?oo403oool002<0oooo0`000?lA0?oo
o`D0003o103oool30?l000D0oooo0`3o00000`3oool0o`000?l000040?l000L0oooo0`3o00030?oo
o`@0o`000P3oool30?l000/0oooo0`3o00001@3oool0o`000?l0003o0000oooo00D0o`001P3oool3
0?l000D0oooo0`000?l0103oool0003o0000o`000?l;0?ooo`<0003o2P3oool30000o`<0oooo0`00
0?lN0?ooob<0P?ooH03ooh0Y083ooa00oooo000=0?ooo`<0003o0P3oool30000o`h0oooo0`000?l4
0?ooo`H0003o1P3oool60000o`H0o`002P3oool80?l000050?ooo`3o0000o`000?l0003oool00`3o
00040?ooo`<0o`000`3oool30?l000X0oooo0`3o00001@3oool0o`000?l0003o0000oooo00L0o`00
0`3oool40?l000<0oooo0`3o00030?ooo`<0003o00<0oooo0000o`000?l00`000?li0?ooob80P?oo
H@3ooh0Y083ooa00oooo000=0?ooo`<0003o0P3oool30000o`h0oooo0`000?l20?ooo`P0003o0`3o
ool60000o`<0oooo1P3o0000103oool0o`000?l0003o00090?ooo`D0o`0000D0oooo0?l0003o0000
o`000?ooo`030?l000@0oooo0`3o00030?ooo`<0o`002P3oool30?l000D0oooo1`3o00030?ooo`@0
o`000`3oool40?l000H0oooo1@000?l90?ooo`<0003o;@3ooolQ083oof80oon0:@20ool@0?ooo`00
3@3oool80000oa<0oooo20000?l30?ooo`H0003o0`3oool60?l000040?ooo`3o0000o`000?l000L0
oooo0`3o00001@3oool0o`000?l0003o0000oooo00<0o`001@3oool30?l000H0oooo2`3o00060?oo
o`<0o`001@3ooolA0?l000H0oooo1`000?l70?ooo`<0003o;@3ooolQ083oof80oon0:@20ool@0?oo
o`003`3oool30000o`T0oooo10000?l90?ooo`@0003o1`3oool30000o`<0oooo2@3o0000103oool0
o`000?l0003o00040?ooo`H0o`003@3oool30?l000<0oooo0`3o00020?ooo`T0o`000P3oool70?l0
00L0oooo2`3o00000`3oool0o`000?l000030?l000D0oooo1P000?l70?ooo`<0003o4`3oool30000
oaL0oooo8020oomS0?ooP2T0P?oo403oool000l0oooo0`000?l90?ooo`@0003o2P3oool30000o`04
0?ooo`000?l0003o0000o`H0oooo1`3o00020?ooo`<0o`0000@0oooo0?l0003o0000o`000P3oool8
0?l000@0oooo103o00050?ooo`D0o`0000<0oooo0?l0003o0000303o00000`3oool0o`000?l00006
0?l000L0oooo1`3o00000`3oool0o`000?l000020?l00080oooo0`3o00050?ooo`H0003o1@3oool5
0000o`80oooo0`000?l30?ooo`<0003o203oool30000oaL0oooo8020oomT0?ooP2P0P?oo403oool0
01/0oooo10000?l90?ooo`@0003o00@0oooo0000o`000?l0003o1P3oool<0?l000030?ooo`3o0000
o`0000P0o`001P3oool50?l00080oooo203o00000`3oool0o`000?l000080?l000D0oooo203o0007
0?ooo`<0o`0000@0oooo0?l0003o0000o`000P3oool30?l00080oooo0`3o00020?ooo`P0003o1P3o
ool50000o`80oooo0`000?l30?ooo`<0003o203oool30000oaL0oooo8020oomT0?ooP2P0P?oo403o
ool002L0oooo2@000?l60?ooo`<0o`000`3oool30?l00080oooo2P3o00080?ooo`l0o`0000<0oooo
0?l0003o00002`3o00000`3oool0o`000?l000020?l00080oooo0`3o000@0?ooo`<0o`001`3oool3
0000o`80oooo1@000?l40?ooo`@0003o0`3oool30000o`030?ooo`000?l0003o00<0003o8P3ooolO
083oofH0oon09`20ool@0?ooo`005@3oool30000o`l0oooo1`000?l50?ooo`D0o`00103oool>0?l0
00P0oooo3@3o00040?ooo`@0o`000`3oool:0?l00080oooo1@3o00030?ooo`<0o`002`3oool30?l0
00D0oooo0`000?l20?ooo`D0003o1@3oool30000o`80oooo0`000?l20?ooo`<0003o2@3oool30000
oaP0oooo7`20oomW0?ooP2H0P?oo403oool001D0oooo0`000?l?0?ooo`<0003o00@0oooo0000o`00
0?l0003o1@3oool70?l00080oooo3P3o00040?ooo`h0o`001`3oool40?l000<0oooo2P3o00020?oo
o`D0o`000`3oool30?l000/0oooo0`3o00001@3oool0o`000?l0003o0000oooo00<0o`00103oool5
0000o`@0oooo0`000?l0103oool0003o0000o`000?l20?ooo`<0003o1@3oool30000o`040?ooo`00
0?l0003o0000oaP0oooo7`20oomY0?ooP2@0P?oo403oool000h0oooo0`000?l40?ooo`<0003o0P3o
ool30000oa<0oooo2P3o00020?ooo`/0o`001`3oool@0?l000D0oooo0`3o00050?ooo`L0o`0000<0
oooo0?l0003o00001P3o00020?ooo`@0o`000P3oool30?l000@0oooo1@3o00001@3oool0o`000?l0
003o0000oooo00<0o`0000@0oooo0000o`000?l0003o0P3oool30000o`@0oooo0`000?l0103oool0
003o0000o`000?l:0?ooo`<0003o00@0oooo0000o`000?l0003o603ooolP083oofP0oon09020ool@
0?ooo`003P3oool60000o`040?ooo`000?l0003o0000o`80oooo0`000?l70?ooo`<0003o2@3oool3
0?l000@0oooo0`3o00060?ooo`L0o`001@3ooolB0?l000D0oooo1@3o00030?ooo`/0o`001P3oool4
0?l000030?ooo`3o0000o`0000H0o`0000<0oooo0?l0003o00000P3o00020?ooo`P0o`000`000?l2
0?ooo`X0003o1@3oool30000o`H0oooo0`000?lL0?ooob00P?ooJ@3ooh0S083ooa00oooo000>0?oo
o`X0003o0P3oool30000o`L0oooo0`000?l90?ooo`<0o`000`3oool30?l000D0oooo103o00020?oo
o`D0o`000`3oool30?l000H0oooo103o00020?ooo`<0o`001@3oool50?l000@0oooo2P3o00000`3o
ool0o`000?l000070?l000030?ooo`3o0000o`0000H0o`0000<0oooo0?l0003o0000103o00030?oo
o`D0o`000`000?l40?ooo`D0003o0`3oool80000obD0oooo8@20oomY0?ooP280P?oo403oool000X0
oooo0`000?l40?ooo`L0003o0`3oool30000o`H0oooo0`000?l0103oool0003o0000o`000?l50?oo
o`D0o`0000@0oooo0?l0003o0000o`000P3oool70?l000@0oooo1@3o0000103oool0o`000?l0003o
00060?ooo`H0o`00203oool50?l000@0oooo7@3o00040?ooo``0o`001P3oool50000o`<0oooo2000
0?l40?ooo`<0003o7P3ooolR083oofT0oon08@20ool@0?ooo`002P3oool50000o`<0oooo0`000?l6
0?ooo`<0003o2P3oool50000o`030?ooo`3o0000o`0000D0o`0000<0oooo0?l0003o00002P3o0004
0?ooo`L0o`002`3oool30?l000X0oooo3@3o00000`3oool0o`000?l0000<0?l00080oooo1@3o0005
0?ooo`P0o`001@3oool30000o`@0oooo3@000?l50?ooo`<0003o7P3ooolR083oofT0oon08@20ool@
0?ooo`002P3oool80000o`H0oooo1P000?l:0?ooo`D0003o00<0oooo0?l0003o00001@3o00020?oo
o`/0o`000P3oool30?l000030?ooo`3o0000o`0000<0o`000P3oool30?l00080oooo0`3o0000103o
ool0o`000?l0003o000:0?ooo`P0o`000P3oool30?l000030?ooo`3o0000o`000080o`0000<0oooo
0?l0003o00001`3o00020?ooo`D0o`001P3oool70?l000D0oooo0`000?l40?ooo`H0003o0P3oool3
0000o`D0oooo1@000?lN0?ooob80P?ooJP3ooh0P083ooa00oooo000;0?ooo`P0003o1@3oool40000
o`X0oooo0`000?l01@3oool0003o0000o`000?l0oooo00H0o`000`3oool;0?l00080oooo0`3o0003
0?ooo`<0o`000P3oool30?l00080oooo0`3o00050?ooo`<0o`00103oool30?l000030?ooo`3o0000
o`0000L0o`000`3oool;0?l000D0oooo1@3o00060?ooo`<0o`0000@0oooo0?l0003o0000o`001@3o
ool30000o`L0oooo0`000?l20?ooo`<0003o00D0oooo0000o`000?l0003o0?ooo`030000ob00oooo
8`20oomY0?ooP200P?oo403oool000l0oooo10000?l50?ooo`@0003o103oool40000o`80oooo0`00
0?l80?ooo`<0o`00103oool30?l000030?ooo`3o0000o`0000@0o`000P3oool30?l000<0oooo0`3o
00020?ooo`<0o`000P3oool30?l000050?ooo`3o0000o`000?l0003oool00`3o00040?ooo`@0o`00
0`3oool60?l000H0oooo0`3o00040?ooo`<0o`002`3oool60?l000`0oooo0`000?l40?ooo`<0003o
1P3oool30000o`040?ooo`000?l0003o0000ob00oooo8`20oomY0?ooP200P?oo403oool00100oooo
0`000?l=0?ooo`@0003o0P3oool30000o`P0oooo0`3o00000`3oool0o`000?l000040?l000040?oo
o`3o0000o`000?l000<0oooo103o00040?ooo`<0o`000P3oool50?l000<0oooo103o0000103oool0
o`000?l0003o00040?ooo`@0o`0000<0oooo0?l0003o00002P3o00020?ooo`H0o`0000@0oooo0?l0
003o0000o`000`3oool30?l000050?ooo`3o0000o`000?l0003oool00`3o00000`3oool0o`000?l0
00050?l000L0oooo0`000?l40?ooo`<0003o1P3oool30000ob@0oooo8`20oomZ0?ooP1l0P?oo403o
ool001/0oooo0`000?l20?ooo`@0003o1@3oool30000o`80o`001`3oool60?l000<0oooo0`3o0000
0`3oool0o`000?l000040?l000T0oooo0`3o00030?ooo`@0o`00203ooolA0?l000<0oooo1@3o0000
103oool0o`000?l0003o00030?ooo`L0o`0000D0oooo0?l0003o0000o`000?ooo`070?l000D0oooo
1@000?ld0?ooob80P?ooJ`3ooh0O083ooa00oooo000K0?ooo`<0003o2@3oool50000o`80o`000P3o
ool30?l00080oooo1@3o00040?ooo`<0o`0000<0oooo0?l0003o00001`3o00060?ooo`<0o`000`3o
ool30?l000X0oooo403o00030?ooo`D0o`001`3oool70?l000<0oooo2@3o00050?ooo`<0003o2@3o
ool50000obP0oooo8P20ool_0?ooP003083oo`3ooh00oon003X0oon07P20ool@0?ooo`005@3oool3
0000o`80oooo10000?l90?ooo`D0003o0P3o00020?ooo`<0o`00103oool40?l000<0oooo0`3o0004
0?ooo`H0o`000P3oool30?l000P0oooo0`3o000;0?ooo`L0o`000P3oool30?l000030?ooo`3o0000
o`0000`0o`000`3oool30?l000H0oooo1`3o00070?ooo`<0003o2@3oool50000obP0oooo8@20ool_
0?ooP0<0P?oo>`3ooh0N083ooa00oooo000E0?ooo`<0003o0P3oool30000o`X0oooo0`000?l60?oo
o`H0o`0000<0oooo0?l0003o00000`3o000;0?ooo`@0o`000P3oool60?l000<0oooo1@3o000>0?oo
o`@0o`001P3oool?0?l00080oooo0`3o00030?ooo`X0o`004`3oool50000o`P0oooo0`000?lM0?oo
ob40P?oo;`3ooh03083ooc/0oon07P20ool@0?ooo`005@3oool80000o`80oooo0`000?lA0?ooo`<0
o`000P3oool40?l000H0oooo0`3o00020?ooo``0o`000`3oool50?l000h0oooo103o00050?oooaD0
o`000`3oool80?l00080oooo2`3o000:0?ooo`<0003o0P3oool30000o`030?ooo`000?l0003o00<0
003o7@3ooolP083ooc00oon01020ooll0?ooP1`0P?oo403oool000X0oooo1P000?l80?ooo`<0003o
0P3oool70000o`T0oooo0`3o00030?ooo`<0o`000`3oool50?l000@0oooo2`3o00000`3oool0o`00
0?l000030?l00080oooo1P3o000>0?ooo`<0o`001@3oool40?l000@0oooo0`3o00000`3oool0o`00
0?l000060?l00080oooo1P3o00040?ooo`h0o`002P3oool30000o`80oooo0`000?l00`3oool0003o
0000o`030000oad0oooo8020ool_0?ooP0P0P?oo>P3ooh0K083ooa00oooo000:0?ooo`T0003o1@3o
ool30000o`80oooo1`000?l90?ooo`<0o`002P3oool40?l000@0oooo2`3o0000103oool0o`000?l0
003o00040?ooo`D0o`00103oool30000o`@0oooo0`000?l90?ooo`@0o`00103oool70?l000030?oo
o`3o0000o`000080o`000P3oool30?l00080oooo0`3o00020?ooo`h0o`002P3oool40000o`050?oo
o`000?l0003o0000o`3oool00`000?lO0?oooal0P?oo<03ooh09083oocX0oon06P20ool@0?ooo`00
2P3oool90000o`X0oooo0`000?l0103oool0003o0000o`000?l90?ooo`<0o`00203oool60?l000@0
oooo2`3o00050?ooo`H0o`001P3oool:0000o`<0oooo0`000?l30?ooo`D0o`000`3oool40?l000D0
oooo103o0000103oool0o`000?l0003o00020?ooo`<0o`000P3oool30?l000@0oooo103o000=0?oo
o`@0003o9`3ooolN083oobl0oon03020ooli0?ooP1X0P?oo403oool000h0oooo1@000?l50?ooo`<0
003o5P3oool30?l000@0oooo0`3o00070?ooo`L0o`0000@0oooo0?l0003o0000o`001@3oool30?l0
00T0oooo2P000?l30?ooo`H0003o0P3oool50?l000030?ooo`3o0000o`0000D0o`000P3oool40?l0
00040?ooo`3o0000o`000?l00080oooo0`3o00090?ooo`@0o`003P3oool30000o`80oooo0`000?lR
0?oooah0P?oo;`3ooh0=083oocT0oon06@20ool@0?ooo`003@3oool40000o`L0oooo0`000?lC0?oo
o`T0o`0000@0oooo0?l0003o0000o`002P3oool40?l000T0oooo0`3o00090?ooo`P0003o1@3oool6
0000o`80oooo1@3o00001@3oool0o`000?l0003o0000oooo00T0o`00:@3oool30000ob80oooo7020
ool`0?ooP0l0P?oo>@3ooh0H083ooa00oooo000=0?ooo`<0003o203oool30000o`80oooo1@000?l<
0?ooo`T0o`000`3oool30?l00080oooo0`3o00030?ooo`<0o`00203oool60?l000P0oooo0`000?l=
0?ooo`<0003o00<0oooo0?l0003o0000103o00040?ooo`L0o`0000<0oooo0?l0003o0000103o0008
0?ooo`<0o`003@3oool30000o`X0oooo0`000?lR0?oooa`0P?oo<03ooh0@083oocP0oon06020ool@
0?ooo`002P3oool60000o`P0oooo0`000?l20?ooo`P0003o2@3oool30?l000030?ooo`3o0000o`00
00<0o`000`3oool30?l00080oooo0`3o00030?ooo`<0o`00203oool60?l00080oooo0`000?l30?oo
o`<0003o1P3oool30000o`P0oooo0`3o00000`3oool0o`000?l000030?l000030?ooo`3o0000o`00
00h0o`001P3oool30?l000P0oooo0P3o00080000o`P0oooo0`000?lR0?oooa/0P?oo<03ooh0L083o
obd0oon06020ool@0?ooo`002P3oool60000o`80oooo0`000?l30?ooo`<0003o0P3oool80000o`P0
oooo103o00000`3oool0o`000?l000030?l000<0oooo0`3o00020?ooo`<0o`000`3oool30?l000P0
oooo1P3o00050000o``0oooo0`000?l80?ooo`T0o`0000<0oooo0?l0003o00000P3o00000`3oool0
o`000?l0000;0?l000@0oooo0`3o00080?ooo`80o`0020000?l]0?oooa/0P?oo<03ooh0L083oobd0
oon06020ool@0?ooo`002P3oool40000o`@0oooo2@000?l40?ooo`H0003o1P3oool90?l000D0oooo
103o00050?ooo`H0o`001P3oool50?l000<0oooo1@000?l<0?ooo`<0003o2`3oool60?l000H0oooo
103o00000`3oool0o`000?l000060?l000l0oooo0P3o00040000o`040?ooo`000?l0003o0000o`H0
oooo0`000?lT0?oooaX0P?oo<@3ooh0L083oobd0oon06020ool@0?ooo`004P3oool60000o`L0oooo
0`000?l90?ooo`T0o`001@3oool60?l000<0oooo1P3o00060?ooo`<0o`001@3oool30000o`/0oooo
0`000?l90?ooo`<0003o0P3oool60?l000030?ooo`3o0000o`0000`0o`0000<0oooo0?l0003o0000
0`3o00030?ooo`@0o`00203oool01@3o0000003o0000o`000?l0oooo00<0003o1P3oool30000ob@0
oooo6P20ool`0?ooP1d0P?oo;03ooh0I083ooa00oooo000E0?ooo`<0003o1@3oool50000o`D0oooo
1`3o00030?ooo`<0o`001@3oool60?l000030?ooo`3o0000o`0000<0o`00203oool40?l000@0oooo
0`000?l60?ooo`<0003o0`3oool30000o`T0oooo10000?l30?ooo`<0o`000P3oool>0?l000<0oooo
0`3o00030?ooo`@0o`000`3oool80?l00080oooo0`000?l60?ooo`<0003o903ooolI083ooc00oon0
7`20ool[0?ooP1T0P?oo403oool001d0oooo0`000?l60?ooo`P0o`0000D0oooo0?l0003o0000o`00
0?ooo`030?l000H0oooo203o00070?ooo`D0o`001@3oool30000o`H0oooo0`000?l30?ooo`<0003o
103oool30000o`030?ooo`000?l0003o00D0003o1P3oool80?l000030?ooo`3o0000o`0000<0o`00
0`3oool30?l000<0oooo1P3o00000`3oool0o`000?l000060?l00080oooo0`000?l;0?ooo`D0003o
103oool30000oaH0oooo6020oola0?ooP1l0P?oo:`3ooh0I083ooa00oooo000I0?ooo`<0003o00@0
oooo0000o`000?l0003o1P3oool<0?l000030?ooo`3o0000o`0000L0o`0000<0oooo0?l0003o0000
1@3o00050?ooo`L0o`001@3oool30000o`80oooo0`000?l0103oool0003o0000o`000?l:0?ooo`<0
003o00<0oooo0000o`000?l01@000?l30?ooo`H0o`003P3oool30?l000D0oooo103o00000`3oool0
o`000?l000030?l00180oooo20000?l20?ooo`<0003o5P3ooolH083ooc00oon08020oolZ0?ooP1X0
P?oo403oool001T0oooo10000?l90?ooo`D0o`000`3oool40?l000030?ooo`3o0000o`0000L0o`00
00D0oooo0?l0003o0000o`000?ooo`030?l000D0oooo1P3o000;0?ooo`<0003o3P3oool30000o`03
0?ooo`000?l0003o00D0003o0`3oool;0?l000<0oooo0`3o00000`3oool0o`000?l000030?l000D0
oooo103o00070?ooo`<0003o3P3oool80000o`80oooo0`000?lF0?oooaL0P?oo<@3ooh0Q083oobT0
oon06P20ool@0?ooo`00303oool30000o`X0oooo10000?l;0?ooo`<0o`000`3oool?0?l000040?oo
o`3o0000o`000?l000P0oooo1`3o00070?ooo`H0003o0`3oool90000o`L0oooo1P000?l30?ooo`/0
o`000`3oool70?l000P0oooo0`3o00070?ooo`<0003o3P3oool80000oa/0oooo5`20ool`0?ooP280
P?oo:P3ooh0I083ooa00oooo000<0?ooo`@0003o2P3oool30000o`X0oooo0`3o00020?ooo`@0o`00
00<0oooo0?l0003o0000103o00030?ooo`<0o`0000@0oooo0?l0003o0000o`00203oool30?l00004
0?ooo`3o0000o`000?l000L0oooo0`000?l60?ooo`T0003o1`3oool60000o`<0oooo0`3o00030?oo
o`D0o`0000<0oooo0?l0003o00001`3o00080?ooo`<0o`001`3oool30000o`<0oooo0`000?l:0?oo
o`<0003o7P3ooolG083ooc00oon08P20oolZ0?ooP1T0P?oo403oool000`0oooo10000?lG0?ooo`<0
o`000P3oool40?l000030?ooo`3o0000o`0000@0o`000`3oool70?l000P0oooo203o00060?ooo`<0
003o1P3oool90000o`T0oooo1P000?l0103oool0o`000?l0003o00090?ooo`T0o`0000@0oooo0?l0
003o0000o`00103oool30?l000H0oooo00@0o`000000o`000?l0003o0`3oool30000o`d0oooo1P00
0?lH0?oooaH0P?oo<@3ooh0R083oobX0oon06@20ool@0?ooo`003@3oool30000o`040?ooo`000?l0
003o0000o`80oooo0`000?l50?ooo`<0003o1P3oool90?l00080oooo0`3o00050?ooo`L0o`00203o
ool40?l000040?ooo`3o0000o`000?l00180oooo1@000?l:0?ooo`L0003o303oool40?l000H0oooo
0`3o000:0?ooo`H0o`00103oool30000o`<0oooo0`000?l00`3oool0003o0000o`0:0000oaP0oooo
5@20ool`0?ooP2D0P?oo:@3ooh0I083ooa00oooo000A0?ooo`<0003o0P3oool30000o`D0oooo0`00
0?l80?ooo`@0o`001@3oool30?l000@0oooo203o00030?ooo`<0o`000`3oool30?l000040?ooo`3o
0000o`000?l000P0oooo0`000?l60?ooo`P0003o0P3oool30000o`<0oooo1`000?l40?ooo`<0o`00
1P3oool30?l000H0oooo0`3o00001@3oool0o`000?l0003o0000oooo00<0o`000P3oool60?l000X0
oooo0`000?l00`3oool0003o0000o`0:0000oaP0oooo5@20ool`0?ooP2D0P?oo:P3ooh0H083ooa00
oooo000A0?ooo`@0003o00@0oooo0000o`000?l0003o1@3oool30000o`P0oooo103o00050?ooo`<0
o`00103oool80?l000<0oooo0`3o00050?ooo`@0o`002@3oool30000o`H0oooo0`000?l20?ooo`<0
003o0P3oool30000o`<0oooo1`000?l40?ooo`<0o`003P3oool30?l00080oooo0`3o0000103oool0
o`000?l0003o00020?ooo`H0o`000`000?l50?ooo`D0003o00<0oooo0000o`000?l01`000?lK0?oo
oaD0P?oo<03ooh0V083oobT0oon06020ool@0?ooo`004P3oool30000oaD0oooo0`3o00050?ooo`<0
o`00103oool70?l000@0oooo0`3o00040?ooo`D0o`001P3oool60000o`H0oooo0`000?l20?ooo`<0
003o0P3oool30000o`D0oooo0`000?l20?ooo`<0o`0000@0oooo0?l0003o0000o`002`3oool60?l0
0080oooo1`3o00000`3oool0o`000?l000050?l000<0003o1@3oool40000o`<0oooo10000?l00`3o
ool0003o0000o`030000oaT0oooo5@20ool`0?ooP2H0P?oo:P3ooh0G083ooa00oooo000B0?ooo`<0
003o5@3oool40?l000H0oooo1@3o00020?ooo`D0o`0000<0oooo0?l0003o0000103o00040?ooo`D0
o`001P3oool70000oaL0oooo0`000?l20?ooo`<0o`002@3oool30?l000030?ooo`3o0000o`0000L0
o`000`3oool40?l00080oooo1`3o00030000o`D0oooo10000?l40?ooo`<0003o00<0oooo0000o`00
0?l00`000?lI0?oooaH0P?oo;`3ooh0V083oobX0oon05`20ool@0?ooo`00703oool30000o`@0oooo
0`000?l40?ooo`@0o`0000@0oooo0?l0003o0000o`000P3oool50?l000@0oooo0`3o00000`3oool0
o`000?l000040?l000@0oooo0`3o0000103oool0003o0000o`000?l40?ooo`L0003o303oool30000
o`D0oooo0`000?l50?ooo`<0o`002@3oool30?l000030?ooo`3o0000o`0000L0o`000`3oool40?l0
00030?ooo`3o0000o`0000L0o`00203oool60000o`040?ooo`000?l0003o0000o`<0oooo0`000?lI
0?oooaH0P?oo;`3ooh0W083oobX0oon05P20ool@0?ooo`003@3oool30000o``0oooo0`000?l30?oo
o`@0003o0`3o00000`3oool0o`000?l000020?l000030?ooo`3o0000o`000080o`0000<0oooo0?l0
003o00000`3o00020?ooo`<0o`000`3oool40?l000X0oooo0`000?l01@3oool0003o0000o`000?l0
oooo00H0003o303oool30000o`D0oooo1P000?l0103oool0o`000?l0003o000:0?ooo`<0o`0000<0
oooo0?l0003o00001`3o00060?ooo`D0o`0000@0oooo0?l0003o0000o`000`000?l:0?ooo`<0003o
0P3oool30000o`<0oooo0`000?lH0?oooaH0P?oo;`3ooh0W083oobX0oon05P20ool@0?ooo`003@3o
ool30000o``0oooo0`000?l30?ooo`@0003o0`3o0000103oool0o`000?l0003o00020?ooo`@0o`00
00<0oooo0?l0003o00000`3o00020?ooo`<0o`00103oool30?l000030?ooo`3o0000o`000080o`00
1@3oool30000o`040?ooo`000?l0003o0000o`L0oooo0`000?l40?ooo`@0003o00D0oooo0000o`00
0?l0003o0?ooo`030000o`030?ooo`000?l0003o00@0003o00@0oooo0?l0003o0000o`00303oool3
0?l000<0oooo103o00070?ooo`D0o`0000@0oooo0?l0003o0000o`000`000?l:0?ooo`<0003o0P3o
ool30000o`<0oooo0`000?lH0?oooaH0P?oo;`3ooh0W083oobX0oon05P20ool@0?ooo`002`3oool5
0000oa80oooo10000?l70?l000<0oooo0`3o00030?ooo`<0o`000P3oool60?l000D0oooo2@3o0004
0?ooo`@0003o1P3oool30000o`@0oooo10000?l50?ooo`<0003o103oool30000o`030?ooo`3o0000
o`0000@0o`002@3oool30?l000<0oooo1@3o0000103oool0o`000?l0003o00020?ooo`D0o`000`3o
ool0103o0000003o0000o`000?l90?ooo`D0003o00<0oooo0000o`000?l01`000?lH0?oooaL0P?oo
;P3ooh0W083oobX0oon05P20ool@0?ooo`002`3oool50000o`80oooo0`000?l=0?ooo`@0003o0P3o
ool30?l000D0oooo0`3o00040?ooo`<0o`0000<0oooo0?l0003o0000103o00050?ooo`T0o`001@3o
ool50000o`@0oooo0`000?l00`3oool0003o0000o`050000o`D0oooo0`000?l20?ooo`<0003o1P3o
ool30?l000040?ooo`3o0000o`000?l000D0oooo0`3o00000`3oool0o`000?l000050?l000040?oo
o`3o0000o`000?l000@0oooo0`3o00030?ooo`<0o`002P3oool50000o`<0oooo1P000?lI0?oooaL0
P?oo;@3ooh0X083oob/0oon05@20ool@0?ooo`002`3oool50000o`80oooo0`000?l80?ooo`<0003o
0P3oool40000o`80oooo103o00040?ooo`<0o`00103oool:0?l000D0oooo2`3o00030?ooo`D0003o
103oool30000o`030?ooo`000?l0003o00@0003o2`3oool30000o`H0oooo1`3o00050?ooo`/0o`00
00@0oooo0?l0003o0000o`005`3oool70000o`030?ooo`000?l0003o00@0003o6@3ooolG083oobd0
oon0:020ool[0?ooP1D0P?oo403oool000d0oooo20000?l0103oool0003o0000o`000?l40?ooo`<0
003o0P3oool30000o`<0oooo103o00000`3oool0o`000?l000040?l000@0oooo1`3o00080?ooo`H0
o`000P3oool30?l000D0oooo1P000?l01@3oool0003o0000o`000?l0oooo00<0003o3P3oool30000
o`H0oooo2@3o00030?ooo`X0o`003P3oool30?l000l0oooo0`000?l0103oool0003o0000o`000?lL
0?oooaP0P?oo;03ooh0X083oobX0oon05P20ool@0?ooo`003@3oool60000o`<0oooo0`000?l40?oo
o`<0003o203oool40?l000030?ooo`3o0000o`0000@0o`00103oool50?l000030?ooo`3o0000o`00
00<0o`00103oool60?l00080oooo0`3o00060?ooo`D0003o0`3oool50000o`040?ooo`000?l0003o
0000o`80oooo2@000?l;0?ooo`H0o`00103oool90?l000T0oooo0`3o00020?ooo`<0o`003`3oool3
0000o`040?ooo`000?l0003o0000oa`0oooo6020ool/0?ooP2L0P?oo:`3ooh0F083ooa00oooo000<
0?ooo`L0003o0`3oool30000o`l0oooo0`3o00020?ooo`D0o`001@3oool30?l000<0oooo1@3o0006
0?ooo`@0o`002`3oool70000o`030?ooo`000?l0003o00<0003o00@0oooo0000o`000?l0003o0P3o
ool90000o`h0oooo0`3o00030?ooo`D0o`001@3oool60?l000<0oooo0`3o00020?ooo`<0o`00<P3o
oolH083oob`0oon09P20ool[0?ooP1L0P?oo403oool000`0oooo0`000?lP0?ooo`<0o`002`3oool5
0?l000H0oooo0`3o000<0?ooo`L0003o00<0oooo0000o`000?l00P000?l20?ooo`<0003o0P3oool9
0000o`H0oooo0`3o00070?ooo`<0o`0000<0oooo0?l0003o00000P3o00060?ooo``0o`0000@0oooo
0?l0003o0000o`00<`3ooolH083oob`0oon09P20ool[0?ooP1L0P?oo403oool000X0oooo1@000?l0
103oool0003o0000o`000?l:0?ooo`<0003o7@3oool30?l000@0oooo0`3o0000103oool0o`000?l0
003o000<0?ooo`L0003o00<0oooo0000o`000?l010000?l60?ooo`<0003o2`3oool30?l00080oooo
0`3o00020?ooo`<0o`0000<0oooo0?l0003o00000P3o00060?ooo`T0o`00103oool30?l000H0oooo
0`000?l;0?ooo`<0003o703ooolI083oob/0oon09P20ool[0?ooP1L0P?oo403oool000X0oooo0`00
0?l30?ooo`<0003o2P3oool30000o`80oooo0`000?lC0?ooo`H0o`001P3oool30?l000L0oooo0`3o
000:0?ooo`<0003o00<0oooo0000o`000?l010000?l30?ooo`<0003o2P3oool30?l000040?ooo`3o
0000o`000?l00080oooo0`3o00020?ooo`<0o`0000<0oooo0?l0003o00001`3o00070?ooo`<0o`00
103oool30?l000H0oooo0`000?l;0?ooo`<0003o703ooolI083oob/0oon09P20oolZ0?ooP1P0P?oo
403oool000X0oooo0`000?l30?ooo`<0003o2P3oool40000o`050?ooo`000?l0003o0000o`3oool0
1@3o00060?ooo`<0o`00103oool60?l000H0oooo0`3o00070?ooo`<0o`002P3oool60000o`040?oo
o`000?l0003o0000o`<0oooo0`000?l:0?ooo`<0o`0000@0oooo0?l0003o0000o`000P3oool30?l0
00H0oooo2@3o00040?ooo`<0o`001`3oool20?l000<0003o103oool30000o`/0oooo0`000?lL0?oo
oaT0P?oo:`3ooh0U083oob/0oon06020ool@0?ooo`007P3oool30000o`050?ooo`000?l0003o0000
o`3oool01@3o0000103oool0o`000?l0003o00020?ooo`<0o`0000<0oooo0?l0003o00001`3o0004
0?ooo`<0o`002@3oool30?l000d0oooo0`000?l70?ooo`<0003o2P3oool30?l000L0oooo0`3o0000
1@3oool0o`000?l0003o0000oooo00T0o`0000<0oooo0?l0003o00001P3o00040?ooo`<0o`000`00
0?l=0?ooo`H0003o7P3ooolI083oob/0oon09@20oolZ0?ooP1T0P?oo403oool001h0oooo0`000?l5
0?ooo`D0o`0000@0oooo0?l0003o0000o`000P3oool30?l000040?ooo`3o0000o`000?l000X0oooo
0`3o000>0?ooo`<0o`001P3oool50000o`X0oooo0`000?l:0?ooo`H0o`0000D0oooo0?l0003o0000
o`000?ooo`060?l00080oooo1@3o00000`3oool0o`000?l000060?l000@0oooo0P3o00040000o`d0
oooo20000?lL0?oooaP0P?oo<03ooh0P083oob/0oon06@20ool@0?ooo`004P3oool30000o`80oooo
1@000?l:0?ooo`<0003o0P3oool40?l00080oooo0`3o00000`3oool0o`000?l000020?l000T0oooo
0`3o000:0?ooo`<0o`0000@0oooo0?l0003o0000o`001P3oool30000o`T0oooo1P000?l:0?ooo`H0
o`0000D0oooo0?l0003o0000o`000?ooo`060?l00080oooo1@3o0000103oool0o`000?l0003o0002
0?ooo`<0o`00103oool20?l000<0003o2P3oool30000o`030?ooo`000?l0003o00H0003o703ooolH
083oocD0oon06`20ool[0?ooP1T0P?oo403oool000l0oooo1P000?l20?ooo`D0003o1P3oool30000
o`040?ooo`000?l0003o0000o`80oooo0`3o00030?ooo`P0o`00403oool40?l00080oooo0`3o0000
103oool0o`000?l0003o00060?ooo`<0003o1P3oool90000o`T0oooo1`3o00060?ooo`D0o`001@3o
ool60?l00080oooo0`3o00060?ooo`<0003o2P3oool30000o`H0oooo0`000?lL0?oooaP0P?oo>P3o
oh0E083oobd0oon06020ool@0?ooo`003`3oool60000o`80oooo1@000?l60?ooo`<0003o00@0oooo
0000o`000?l0003o0P3oool30?l000H0oooo1@3o00030?ooo`<0o`002P3oool40?l00080oooo0`3o
000B0?ooo`L0003o2@3oool90?l000T0oooo0`3o00050?ooo`<0o`006`3oool30000obD0oooo6020
oolj0?ooP1D0P?oo;@3ooh0H083ooa00oooo000?0?ooo`<0003o1@3oool30000o`P0oooo0`000?l3
0?ooo`<0o`002@3oool30?l000D0oooo1`3o00060?ooo`@0o`001`3oool40?l000/0oooo1P000?l2
0?ooo`<0003o103oool80?l000`0oooo0`3o00050?ooo`<0o`000P3oool30?l001D0oooo0`000?l4
0?ooo`<0003o7`3ooolG083ooc/0oon04P20ool`0?ooP1P0P?oo403oool000h0oooo0`000?l01@3o
ool0003o0000o`000?l0oooo00@0003o3P3oool40?l000D0oooo0`3o00080?ooo`L0o`0000<0oooo
0?l0003o00000`3o00000`3oool0o`000?l000060?l00080oooo103o000;0?ooo`@0003o0P3oool2
0?l000<0003o0`3oool80?l000H0oooo0`3o00040?ooo`L0o`001P3oool50?l001<0oooo0`000?l4
0?ooo`<0003o103oool30000oaP0oooo6020oolk0?ooP0h0P?oo=03ooh0G083ooa00oooo000>0?oo
o`<0003o00D0oooo0000o`000?l0003o0?ooo`040000o`80oooo0`000?l90?ooo`D0o`00103oool6
0?l000L0oooo1@3o00000`3oool0o`000?l000030?l000030?ooo`3o0000o`0000H0o`000P3oool6
0?l000T0oooo0`000?l20?ooo`<0o`000`000?l30?ooo`@0o`0000@0oooo0?l0003o0000o`001P3o
ool60?l00080oooo1P3o00060?ooo`D0o`000P3oool30?l000040?ooo`000?l0003o0000o`<0oooo
0`000?l40?ooo`D0003o0P3oool30000o`@0oooo0`000?lH0?oooaT0P?oo>`3ooh0;083oocH0oon0
5`20ool@0?ooo`002`3oool60000o`030?ooo`000?l0003o00D0003o0`3oool30000o`<0oooo0`00
0?l40?ooo`h0o`001@3oool=0?l000030?ooo`3o0000o`0000P0o`000`3oool30?l000D0oooo0`3o
00060?ooo`@0o`001@3oool40?l000040?ooo`3o0000o`000?l000D0oooo1`3o00020?ooo`H0o`00
203oool80?l000040?ooo`000?l0003o0000o`<0oooo0`000?l60?ooo`<0003o2@3oool30000oaP0
oooo6P20oolj0?ooP0P0P?oo>@3ooh0G083ooa00oooo000;0?ooo`<0003o1@3oool60000o`<0oooo
1@000?l0103oool0003o0000o`000?l50?ooo`T0o`0000<0oooo0?l0003o00001@3o00000`3oool0
o`000?l000060?l000L0oooo1@3o00000`3oool0o`000?l000030?l000030?ooo`3o0000o`0000@0
o`000P3oool30?l000H0oooo1P3o00080?ooo`H0o`000P3oool70?l000h0oooo2`3o00030000o`03
0?ooo`000?l0003o00<0003o00@0oooo0000o`000?l0003o0P3oool30000o`H0oooo0`000?lK0?oo
oa/0P?oo>P3ooh05083ooc`0oon05P20ool@0?ooo`002`3oool30000o`D0oooo0`000?l60?ooo`D0
003o00@0oooo0000o`000?l0003o1`3oool70?l000030?ooo`3o0000o`0000D0o`0000<0oooo0?l0
003o00001P3o00070?ooo`D0o`0000<0oooo0?l0003o00000`3o00000`3oool0o`000?l000090?l0
00T0oooo0`3o00020?ooo`<0o`000`3oool60?l00080oooo103o0000103oool0o`000?l0003o0004
0?ooo`@0o`001@3oool;0?l000@0oooo0`000?l30?ooo`<0003o2`3oool30000oa/0oooo7020oomj
0?ooP1H0P?oo403oool000X0oooo1@000?l?0?ooo`<0003o2`3oool30?l000@0oooo2P3o00030?oo
o`<0o`000P3oool:0?l000@0oooo0`3o00000`3oool0o`000?l000090?l000D0oooo0`3o00001@3o
ool0o`000?l0003o0000oooo00@0o`000`3oool60?l000<0oooo2P3o00000`3oool0o`000?l00002
0?l00080oooo2@3o00020?ooo`<0o`00103oool30000o`<0oooo0`000?l;0?ooo`<0003o6`3ooolN
083oogP0oon05P20ool@0?ooo`002P3oool60000o`d0oooo0`000?l40?ooo`<0003o1@3oool50?l0
00030?ooo`3o0000o`000080o`00103oool40?l00080oooo0`3o00020?ooo`/0o`001`3oool30?l0
00030?ooo`3o0000o`0000<0o`001`3oool<0?l000h0oooo203o00000`3oool0o`000?l000020?l0
0080oooo103o00020?ooo`@0o`000P3oool30000o`P0oooo0`000?l=0?ooo`<0003o6P3ooolO083o
ogP0oon05@20ool@0?ooo`002P3oool60000o`d0oooo0`000?l40?ooo`@0003o1P3oool30?l00003
0?ooo`3o0000o`000080o`00103oool40?l000@0oooo3P3o00070?ooo`<0o`0000<0oooo0?l0003o
00000P3o00080?ooo`h0o`00103oool30?l000D0oooo203o00070?ooo`@0o`000P3oool40?l00080
oooo0`000?l80?ooo`<0003o0`3oool30000o`L0oooo0`000?lJ0?oooal0P?ooN03ooh0E083ooa00
oooo000<0?ooo`@0003o3@3oool;0000o`H0oooo0`3o00000`3oool0o`000?l000020?l000D0oooo
103o00030?ooo`h0o`001`3oool30?l000040?ooo`3o0000o`000?l000<0oooo0`3o00050?ooo`P0
o`0000@0oooo0?l0003o0000o`00103oool60?l000<0oooo103o00020?ooo`@0o`00203oool60?l0
0080oooo0`000?l80?ooo`@0003o0P3oool30000o`L0oooo0`000?lJ0?ooob00P?ooM`3ooh0E083o
oa00oooo000<0?ooo`<0003o3`3oool:0000o`040?ooo`000?l0003o0000o`80oooo0`3o000;0?oo
o`<0o`000`3oool>0?l000/0oooo0`3o00030?ooo`<0o`000P3oool40?l000<0oooo0`3o00020?oo
o`@0o`000`3oool70?l00080oooo0`3o00030?ooo`@0o`000P3oool30?l000<0oooo1@3o000?0?oo
o`<0003o0P3oool30000ob@0oooo8@20oomc0?ooP1P0P?oo403oool000`0oooo0`000?l?0?ooo`h0
003o403oool30?l000<0oooo203o00000`3oool0o`000?l000030?l000D0oooo0`3o00090?ooo`<0
o`000P3oool40?l000<0oooo2@3o00020?ooo`<0o`0000<0oooo0?l0003o0000103o00060?ooo`@0
o`000P3oool30?l000<0oooo1`3o000;0?ooo`D0003o:@3ooolR083oofh0oon07020ool@0?ooo`00
5P3oool30000o`040?ooo`000?l0003o0000o`D0oooo2`000?l20?ooo`@0o`002`3oool30?l00003
0?ooo`3o0000o`000080o`0000D0oooo0?l0003o0000o`000?ooo`050?l000030?ooo`3o0000o`00
00D0o`002`3oool70?l00080oooo2P3o00020?ooo`<0o`000P3oool50?l000H0oooo0`3o00020?oo
o`D0o`001@3oool40?l000/0oooo1`000?l80?ooo`<0003o703ooolR083oofX0oon08020ool@0?oo
o`005P3oool30000o`040?ooo`000?l0003o0000o`D0oooo30000?l00`3oool0o`000?l000020?l0
00H0oooo0`3o00020?ooo`<0o`000P3oool70?l000<0oooo0`3o00000`3oool0o`000?l000070?l0
00P0oooo103o0000103oool0o`000?l0003o00020?ooo`<0o`0000<0oooo0?l0003o00002@3o0004
0?ooo`<0o`002`3oool50?l000D0oooo103o000;0?ooo`L0003o203oool30000oa`0oooo8P20oomW
0?ooP2<0P?oo403oool001@0oooo1@000?l00`3oool0003o0000o`030000o`/0oooo10000?l00`3o
ool0o`000?l000020?l000H0oooo103o0000103oool0o`000?l0003o00030?ooo`<0o`0000@0oooo
0?l0003o0000o`001P3oool90?l000P0oooo1`3o00030?ooo`<0o`0000@0oooo0?l0003o0000o`00
0`3oool30?l000P0oooo103o00080?ooo`D0o`000P3oool60?l000d0oooo1P000?l20?ooo`<0003o
0`3oool30000oa`0oooo8P20oomT0?ooP2H0P?oo403oool001@0oooo0`000?l50?ooo`<0003o303o
ool30000o`040?ooo`3o0000o`000?l000L0oooo103o00070?ooo`L0o`001@3oool30?l000<0oooo
1P3o0000103oool0o`000?l0003o00020?ooo`<0o`0000D0oooo0?l0003o0000o`000?ooo`030?l0
00030?ooo`3o0000o`0000<0o`000P3oool40?l000@0oooo0`3o00000`3oool0o`000?l000030?l0
00/0oooo1P3o00030?ooo`<0003o4P3oool30000o`T0oooo0`000?lF0?ooob80P?ooI03ooh0V083o
oa00oooo000D0?ooo`D0003o0`3oool30000o``0oooo0`000?l0103oool0o`000?l0003o00070?oo
o`@0o`0000@0oooo0?l0003o0000o`00103oool60?l000D0oooo1@3o00000`3oool0o`000?l00004
0?l000040?ooo`3o0000o`000?l00080oooo0`3o00001@3oool0o`000?l0003o0000oooo00l0o`00
103oool30?l000030?ooo`3o0000o`0000<0o`002`3oool70?l00080oooo0`000?l<0?ooo`<0003o
0P3oool40000o`T0oooo0`000?lF0?ooob80P?ooI03ooh0V083ooa00oooo000A0?ooo`<0003o0P3o
ool30000o`<0oooo0`000?l90?ooo`T0003o0P3o000;0?ooo`<0o`000P3oool50?l000H0oooo1`3o
00000`3oool0o`000?l000040?l000030?ooo`3o0000o`0000H0o`000P3oool:0?l000030?ooo`3o
0000o`0000D0o`00103oool30?l000<0oooo0`3o000;0?ooo`L0o`000P3oool30000o`L0oooo0`00
0?l20?ooo`<0003o0P3oool30000o`X0oooo0`000?lF0?ooob80P?ooI03ooh0V083ooa00oooo000:
0?ooo`<0003o103oool30000o`80oooo0`000?l30?ooo`<0003o2@3oool30000o`<0oooo0`000?l7
0?l000H0oooo0`3o00000`3oool0o`000?l000070?l000<0oooo0`3o0000103oool0o`000?l0003o
000:0?ooo`H0o`000P3oool30?l00080oooo1@3o00001@3oool0o`000?l0003o0000oooo00<0o`00
0P3oool60?l000T0oooo1@3o00030?ooo`H0o`00303oool30000o`80oooo0`000?l20?ooo`<0003o
8`3ooolR083oof@0oon09P20ool@0?ooo`002P3oool40000o`<0oooo0`000?l70?ooo`H0003o00@0
oooo0000o`000?l0003o0`3oool30000o`<0oooo0`000?l70?l000@0oooo0`3o00030?ooo`T0o`00
00<0oooo0?l0003o00000`3o0000103oool0o`000?l0003o00020?ooo`H0o`000P3oool60?l00080
oooo2@3o00060?ooo`<0o`000P3oool60?l000040?ooo`3o0000o`000?l000D0oooo1@3o00030?oo
o`D0o`0000@0oooo0000o`000?l0003o2@3oool30000o`l0oooo0`000?lK0?ooob40P?ooI@3ooh0V
083ooa00oooo000:0?ooo`@0003o3@3oool60000o`040?ooo`000?l0003o0000o`T0oooo0`000?l2
0?ooo`D0o`00103oool30?l000<0oooo0`3o00030?ooo`<0o`0000<0oooo0?l0003o0000203o0000
0`3oool0o`000?l0000=0?l000@0oooo0`3o00090?ooo`<0o`000P3oool:0?l000D0oooo1P3o0000
103oool0o`000?l0003o00040?ooo`<0003o303oool30000o`040?ooo`000?l0003o0000o`H0oooo
1`000?lI0?ooob40P?ooI03ooh0W083ooa00oooo000;0?ooo`<0003o3@3oool60000o`050?ooo`00
0?l0003o0000o`3oool00`000?l50?ooo`<0003o0`3oool30?l000D0oooo0`3o000:0?ooo`d0o`00
00<0oooo0?l0003o00003`3o00020?ooo`<0o`003P3oool<0?l000<0oooo1P3o0000103oool0o`00
0?l0003o00040?ooo`<0003o303oool30000o`040?ooo`000?l0003o0000o`H0oooo1`000?lI0?oo
ob40P?ooI03ooh0W083ooa00oooo000=0?ooo`D0003o303oool30000o`D0oooo2`000?l30?ooo`L0
o`002P3oool30?l000040?ooo`3o0000o`000?l000<0oooo0`3o00000`3oool0o`000?l000050?l0
00030?ooo`3o0000o`0000/0o`002`3oool30?l000D0oooo303o00060?ooo`L0o`00103oool30000
o``0oooo0`000?l00`3oool0003o0000o`040000o`<0oooo0`000?l0103oool0003o0000o`000?lI
0?ooob40P?ooI03ooh0W083ooa00oooo000=0?ooo`L0003o2@3oool50000o`@0oooo20000?l60?oo
o`L0o`0000@0oooo0?l0003o0000o`001P3oool70?l000D0oooo2@3o00000`3oool0o`000?l00002
0?l000@0oooo203o0000103oool0o`000?l0003o00040?ooo`<0o`000`3oool:0?l000040?ooo`3o
0000o`000?l000<0oooo0`3o00020?ooo`<0o`002P3oool60000o``0oooo0`000?l30?ooo`<0003o
7@3ooolQ083oof@0oon09`20ool@0?ooo`003@3oool70000o`T0oooo1@000?l60?ooo`H0003o203o
ool50?l000040?ooo`3o0000o`000?l000<0oooo1`3o00080?ooo`P0o`0000<0oooo0?l0003o0000
0P3o00050?ooo`P0o`0000@0oooo0?l0003o0000o`00103oool30?l000<0oooo0`3o000>0?ooo`P0
o`002P3oool60000o``0oooo0`000?l30?ooo`<0003o7@3ooolQ083oof@0oon09`20ool@0?ooo`00
4@3oool30000o`D0oooo0`000?l00`3oool0003o0000o`030000o`T0oooo0`000?l>0?ooo`<0o`00
0`3oool30?l000040?ooo`3o0000o`000?l000P0oooo0`3o0000103oool0o`000?l0003o00020?oo
o`@0o`001@3oool80?l000040?ooo`3o0000o`000?l000P0oooo1@3o000>0?ooo`@0o`0010000?l9
0?ooo`L0003o303oool30000o`<0oooo0`000?lM0?ooob@0P?ooH@3ooh0W083ooa00oooo000I0?oo
o`<0003o6P3oool30000o`T0oooo2@3o000?0?ooo`@0o`003P3oool30?l000<0oooo0`3o00020?oo
o`H0o`00303oool50?l000H0003o1`3oool30000o`030?ooo`000?l0003o00L0003o3`3oool50000
oaP0oooo:@20oomL0?ooP2L0P?oo403oool00100oooo0`000?l60?ooo`<0003o6P3oool30000o`H0
oooo0`3o00030?ooo`H0o`0000@0oooo0?l0003o0000o`000P3oool30?l000040?ooo`3o0000o`00
0?l000<0oooo0`3o00090?ooo`@0o`0000@0oooo0?l0003o0000o`000`3oool30?l00080oooo1P3o
000<0?ooo`<0o`000P3oool80000o`D0oooo0`000?l40?ooo`H0003o3`3oool50000oaP0oooo;P20
oomG0?ooP2L0P?oo403oool00100oooo0`000?lS0?ooo`H0003o0P3oool40?l000<0oooo1P3o0000
103oool0o`000?l0003o00020?ooo`<0o`0000@0oooo0?l0003o0000o`001@3oool60?l000@0oooo
103o0000103oool0o`000?l0003o00030?ooo`<0o`000P3oool60?l000`0oooo0`3o00020?ooo`P0
003o1@3oool30000o`<0oooo1`000?l?0?ooo`D0003o603oool_083ooeH0oon09`20ool@0?ooo`00
403oool50000ob@0oooo0`000?l20?ooo`@0o`0000<0oooo0?l0003o00001P3o0000103oool0o`00
0?l0003o00020?ooo`L0o`001@3oool60?l000@0oooo1@3o000=0?ooo`@0o`002@3oool60?l00080
oooo0`000?l20?ooo`<0003o1@3oool30000o`<0oooo10000?lC0?ooo`@0003o603oool`083ooe@0
oon0:020ool@0?ooo`004P3oool40000o`80oooo0`000?l:0?ooo`<0003o4@3oool30000o`80oooo
303o00090?ooo`L0o`000`3oool60?l000H0oooo0`3o00090?ooo`<0o`0000<0oooo0?l0003o0000
0P3o00090?ooo`H0o`000P3oool30000o`X0oooo0`000?l30?ooo`@0003o2@3oool30000o`L0oooo
10000?lH0?oooc00P?ooE03ooh0X083ooa00oooo000?0?ooo`L0003o0P3oool30000o`X0oooo1@00
0?l=0?ooo`<0003o103oool<0?l000T0oooo1`3o000?0?ooo`<0o`002@3oool30?l000030?ooo`3o
0000o`000080o`001@3oool30?l000040?ooo`3o0000o`000?l00140oooo10000?l40?ooo`<0003o
0P3oool30000o`@0oooo0`000?l70?ooo`@0003o603ooola083ooe<0oon0:020ool@0?ooo`003`3o
ool30000o`030?ooo`000?l0003o00H0003o2P3oool50000o`d0oooo0`000?l50?ooo`<0003o203o
0000103oool0o`000?l0003o00090?ooo`<0o`000P3oool30?l000X0oooo0`3o00090?ooo`<0o`00
00D0oooo0?l0003o0000o`000?ooo`090?l001@0oooo1`000?l60?ooo`<0003o103oool30000ob<0
oooo<@20oomC0?ooP2P0P?oo403oool000l0oooo0`000?l40?ooo`<0003o303oool50000o`D0oooo
0`000?l50?ooo`<0003o1@3oool30000o`030?ooo`3o0000o`0000D0o`0000@0oooo0?l0003o0000
o`003P3oool30?l000X0oooo0`3o00030?ooo`H0o`000P3oool50?l000030?ooo`3o0000o`0000L0
o`00503oool70000o`H0oooo0`000?l80?ooo`<0003o7`3ooola083ooe<0oon0:020ool@0?ooo`00
5P3oool30000o``0oooo0`000?l70?ooo`<0003o00<0oooo0000o`000?l00`000?l70?ooo`<0003o
103oool80?l000T0oooo0`3o00020?ooo`P0o`001P3oool;0?l00080oooo103o00020?ooo`T0o`00
1`3oool30000o`d0oooo1`000?l<0?ooo`P0003o703ooola083ooe<0oon0:020ool@0?ooo`005P3o
ool30000o``0oooo0`000?l50?ooo`D0003o00<0oooo0000o`000?l00`000?l>0?ooo`H0o`002`3o
ool30?l000@0oooo1P3o00040?ooo`d0o`0000<0oooo0?l0003o00000`3o000B0?ooo`H0003o3P3o
ool30000o``0oooo20000?lL0?oooc80P?ooDP3ooh0X083ooa00oooo000A0?ooo`@0003o00@0oooo
0000o`000?l0003o0`3oool30000o`h0oooo10000?l20?ooo`D0003o1`3oool30000o`D0oooo1@3o
000;0?ooo`<0o`0000<0oooo0?l0003o00001`3o00040?ooo`P0o`00103oool70?l00180oooo1P00
0?l>0?ooo`<0003o303oool30000o`80oooo0`000?lL0?oooc80P?ooD03ooh0Z083ooa00oooo000:
0?ooo`<0003o103oool40000o`040?ooo`000?l0003o0000o`<0oooo0`000?l>0?ooo`@0003o3P3o
ool30000o`050?ooo`000?l0003o0000o`3oool01@3o000?0?ooo`<0o`002P3oool30?l000H0oooo
203o00070?ooo`<0003o3@3oool30000o`d0oooo0`000?l90?ooo`<0003o9@3ooolc083oo`l0oon0
0P20ooll0?ooP2`0P?oo403oool000X0oooo0`000?l40?ooo`@0003o00<0oooo0000o`000?l00P00
0?l20?ooo`<0003o3`3oool30000o`D0oooo0`000?l60?ooo`<0003o00D0oooo0000o`000?l0003o
0?ooo`050?l000040?ooo`3o0000o`000?l000/0oooo0`3o00020?ooo`<0o`00103oool@0?l000P0
oooo10000?lJ0?ooo`H0003o2@3oool30000obD0oooo<`20ool<0?ooP0H0P?oo<@3ooh05083oo`03
0?ooP020ool0P?oo02h0P?oo403oool000X0oooo1@000?l60?ooo`H0003o6`3oool30000o`@0oooo
1@000?l0103oool0003o0000o`000?l70?ooo`H0o`00203oool30?l00080oooo0`3o00040?ooo`l0
o`000`3oool30000o`<0oooo1@000?lC0?ooo`<0003o00<0oooo0000o`000?l01P000?l60?ooo`H0
003o00<0oooo0000o`000?l00`000?lO0?oooc<0P?oo1`3ooh0;083oobl0oon0>020ool@0?ooo`00
303oool30000o`@0oooo20000?l90?ooo`D0003o1P3oool30000o`@0oooo0`000?l40?ooo`@0003o
303oool60?l000<0oooo103o0000103oool0o`000?l0003o00020?oooa40o`0000<0oooo0?l0003o
00000P3o00060000o`<0oooo1@000?l70?ooo`<0003o0P3oool60000o`050?ooo`000?l0003o0000
o`3oool01`000?l70?ooo`<0003o103oool50000oal0oooo<`20ool70?ooP0/0P?oo;`3ooh0h083o
oa00oooo000<0?ooo`<0003o103oool80000o`T0oooo1@000?l0103oool0003o0000o`000?l20?oo
o`<0003o0P3oool60000o`<0oooo1P000?l01@3oool0003o0000o`000?l0oooo00<0003o103oool4
0?l00080oooo1P3o00080?ooo`H0o`00103oool40?l000030?ooo`3o0000o`000080o`0020000?l3
0?ooo`<0003o1`3oool30000o`80oooo1P000?l01@3oool0003o0000o`000?l0oooo00<0003o00<0
oooo0000o`000?l00`000?l50?ooo`<0003o103oool50000o`030?ooo`000?l0003o0080003o6P3o
oold083oo`80oon04@20oolV0?ooP3l0P?oo403oool001<0oooo2P000?l0103oool0003o0000o`00
0?l30?ooo`D0003o00@0oooo0000o`000?l0003o0P3oool30000o`80oooo1P000?l60?ooo`<0003o
00D0oooo0000o`000?l0003o0?ooo`030000o`X0oooo1P3o00040?ooo`X0o`001@3oool30?l000<0
oooo0P3o00080000o`d0oooo0`000?l20?ooo`H0003o2`3oool30000oa80oooo10000?lJ0?ooodP0
P?oo5@3ooh1?083ooa00oooo000F0?ooo`<0003o00D0oooo0000o`000?l0003o0?ooo`030000o`T0
oooo0`000?l70?ooo`H0003o1P3oool30000o`030?ooo`000?l0003o00D0003o2P3oool30?l000@0
003o1`3o000;0?ooo`80o`000`000?l80?ooo`D0003o2`3oool30000o`80oooo0`000?l>0?ooo`<0
003o4P3oool40000oaX0ooooB@20oolB0?ooP540P?oo403oool000d0oooo0`000?l60?ooo`<0003o
00D0oooo0000o`000?l0003o0?ooo`040000ob@0oooo10000?l>0?ooo`@0003o1`3o00030?ooo`D0
003o1@3oool30000o`X0oooo0`000?l;0?ooo`<0003o0P3oool30000oa00oooo0`000?l;0?ooo`<0
003o803ooom:083ooa00oon0DP20ool@0?ooo`003@3oool30000o`d0oooo1@000?l0103oool0003o
0000o`000?l70?ooo`<0003o5P3oool40000o`h0oooo1@000?l00`3o0000003o0000o`030000o`<0
oooo1@000?l50?ooo`<0003o2P3oool30000o`/0oooo0`000?l20?ooo`<0003o1`3oool30000o`@0
oooo1@000?l:0?ooo`L0003o7@3ooom;083oo`h0oon0D`20ool@0?ooo`003@3oool30000o`d0oooo
1@000?l00`3oool0003o0000o`030000o`D0oooo0`000?l;0?ooo`<0003o2@3oool30000o``0oooo
0`000?l01@3oool0003o0000o`000?l0oooo00d0003o4P3oool30000o`D0oooo0`000?l80?ooo`<0
003o1@3oool50000o`@0oooo1`000?l80?ooo`X0003o6P3ooom<083oo`/0oon0E@20ool@0?ooo`00
7@3oool30000o`<0oooo1@000?l50?ooo`<0003o2`3oool30000o`L0oooo0`000?l=0?ooo`@0003o
00D0oooo0000o`000?l0003o0?ooo`080000o``0oooo0`000?l80?ooo`<0003o1@3oool30000oa00
oooo1@000?l40?ooo`<0003o00@0oooo0000o`000?l0003o1`3oool40000o`030?ooo`000?l0003o
00@0003o6P3ooom=083oo`<0oon0G020ool@0?ooo`004P3oool30000oa00oooo0`000?l20?ooo`<0
003o3P3oool30000o`L0oooo0`000?l70?ooo`D0003o00<0oooo0000o`000?l00P000?l:0?ooo`<0
003o103oool30000o`D0oooo0`000?l80?ooo`<0003o1@3oool30000o`<0oooo0`000?l:0?ooo`<0
003o2P3oool30000o`L0oooo0`000?l50?ooo`<0003o6P3ooon/083ooa00oooo000B0?ooo`P0003o
403oool30000oaP0oooo0`000?l70?ooo`X0003o4@3oool30000o`D0oooo1P000?l50?ooo`<0003o
103oool60000o`040?ooo`000?l0003o0000o`80oooo0`000?l50?ooo`<0003o503oool30000ob80
oooo[020ool@0?ooo`003P3ooolE0000o`L0oooo1P000?lO0?ooo`X0003o403oool40000o`P0oooo
0`000?l70?ooo`<0003o0P3oool60000o`040?ooo`000?l0003o0000o`80oooo0`000?lF0?ooo`<0
003o2@3oool30000oa`0oooo[020ool@0?ooo`003P3oool40000o`<0oooo3P000?l:0?ooo`H0003o
1P3oool30000oa<0oooo20000?l90?ooo`<0003o1P3oool30000o`T0oooo0`000?l0103oool0003o
0000o`000?l30?ooo`<0003o0P3oool60000o`H0oooo0`000?lC0?ooo`H0003o1P3oool60000oa`0
oooo[020ool@0?ooo`003@3oool50000o`@0oooo0`000?l00`3oool0003o0000o`070000o`X0oooo
20000?l40?ooo`<0003o203oool30000o`D0oooo2@000?l;0?ooo`<0003o00@0oooo0000o`000?l0
003o0P3oool30000o`D0oooo0`000?l50?ooo`<0003o0`3oool30000o`80oooo1P000?lK0?ooo`L0
003o1P3oool70000oa/0oooo[020ool@0?ooo`003@3oool40000o`L0oooo0`000?l40?ooo`<0003o
3@3oool60000o`@0oooo0`000?l80?ooo`<0003o1@3oool30000o`<0oooo1P000?l80?ooo`<0003o
00@0oooo0000o`000?l0003o2P3oool30000o`D0oooo0`000?l80?ooo`<0003o4`3oool30000o`P0
oooo10000?l90?ooo`L0003o6`3ooon/083ooa00oooo000=0?ooo`@0003o103oool80000oaD0oooo
0`000?l?0?ooo`<0003o1@3oool30000o`H0oooo0`000?l80?ooo`<0003o00@0oooo0000o`000?l0
003o2P3oool60000o`T0oooo0`000?l0103oool0003o0000o`000?lC0?ooo`D0003o1P3oool40000
o`X0oooo1P000?lK0?oooj`0P?oo403oool000d0oooo10000?l40?ooo`P0003o0`3oool30000o`/0
oooo0`000?lJ0?ooo`<0003o1`3oool30000o`@0oooo0`000?l0103oool0003o0000o`000?l>0?oo
o`H0003o2@3oool30000o`040?ooo`000?l0003o0000oa<0oooo1P000?l60?ooo`<0003o2@3oool3
0000oal0oooo[020ool@0?ooo`003@3oool30000o`D0oooo0`000?l20?ooo`<0003o0`3oool30000
o`<0oooo0`000?l50?ooo`<0003o403oool30000o`L0oooo0`000?l>0?ooo`<0003o0P3oool30000
o`@0oooo0`000?l90?ooo`<0003o2@3oool30000o`030?ooo`000?l0003o00@0003o1`3oool60000
o`D0oooo10000?l40?ooo`D0003o2@3oool30000oal0oooo[020ool@0?ooo`003@3oool30000o`X0
oooo0`000?l30?ooo`<0003o0`3oool30000o`D0oooo0`000?l50?ooo`<0003o203oool30000o`L0
oooo0`000?l0103oool0003o0000o`000?l70?ooo`L0003o00@0oooo0000o`000?l0003o103oool3
0000o`<0oooo0`000?lF0?ooo`<0003o1`3oool60000o`H0oooo0`000?l40?ooo`<0003o2`3oool3
0000oal0oooo[020ool@0?ooo`006P3oool30000o`<0oooo0`000?l30?ooo`<0003o3@3oool30000
o`P0oooo0`000?l80?ooo`H0003o00@0oooo0000o`000?l0003o0`3oool30000o`050?ooo`000?l0
003o0000o`3oool00`000?l40?ooo`<0003o0`3oool60000oa<0oooo0`000?l01@3oool0003o0000
o`000?l0oooo00P0003o3@3oool50000ob/0oooo[020ool@0?ooo`004`3oool30000o`@0oooo0`00
0?l30?ooo`T0003o2`3oool50000oa<0oooo1P000?l0103oool0003o0000o`000?l30?ooo`<0003o
00@0oooo0000o`000?l0003o1P3oool30000o`D0oooo1P000?lG0?ooo`<0003o00<0oooo0000o`00
0?l020000?l=0?ooo`<0003o:`3ooon/083ooa00oooo000C0?ooo`<0003o2P3oool90000o`/0oooo
0`000?lE0?ooo`<0003o103oool30000o`P0oooo0`000?l50?ooo`@0003o1`3oool30000oaL0oooo
0`000?l00`3oool0003o0000o`040000o`040?ooo`000?l0003o0000o`d0oooo0`000?l80?ooo`<0
003o803ooon/083ooa00oooo000C0?ooo`<0003o3@3oool60000o`/0oooo10000?l50?ooo`<0003o
5`3oool30000o`@0oooo0`000?l30?ooo`H0003o00<0oooo0000o`000?l010000?lP0?ooo`@0003o
00@0oooo0000o`000?l0003o603oool30000o`040?ooo`000?l0003o0000oa`0oooo[020ool@0?oo
o`004`3oool40000oaT0oooo0`000?l20?ooo`<0003o1@3oool30000o`D0oooo0`000?l?0?ooo`D0
003o0P3oool30000o`<0oooo3@000?lI0?ooo`<0003o103oool40000oaP0oooo1`000?l0103oool0
003o0000o`000?lL0?oooj`0P?oo403oool000d0oooo0`000?l30?ooo`@0003o4`3oool30000o`<0
oooo0`000?l20?ooo`<0003o1@3oool30000o`D0oooo1@000?l=0?ooo`D0003o0`3oool30000o`80
oooo0`000?l00`3oool0003o0000o`070000o`L0oooo0`000?l?0?ooo`<0003o103oool40000oaP0
oooo1@000?l30?ooo`D0003o6P3ooon/083ooa00oooo000;0?ooo``0003o103oool30000o`L0oooo
0`000?l20?ooo`<0003o0`3oool30000o`X0oooo0`000?l50?ooo`D0003o3`3oool30000o`<0oooo
0`000?l60?ooo`D0003o2`3oool30000o`l0oooo0`000?l40?ooo`<0003o0P3oool30000o`@0oooo
0`000?l=0?ooo`D0003o0`3oool50000oaX0oooo[020ool@0?ooo`002P3oool<0000o`D0oooo0`00
0?l70?ooo`<0003o0P3oool30000o`80oooo0`000?l:0?ooo`<0003o203oool30000o`d0oooo0`00
0?l50?ooo`@0003o1`3oool30000o`030?ooo`000?l0003o0080003o1P3oool70000o`L0oooo0`00
0?l80?ooo`<0003o0P3oool30000o`@0oooo0`000?l?0?ooo`<0003o0`3oool70000oaP0oooo[020
ool@0?ooo`002P3oool40000o`030?ooo`000?l0003o0080003o203oool30000o`L0oooo0`000?l7
0?ooo`<0003o2P3oool60000oaD0oooo1@000?l40?ooo`@0003o1P3oool30000o`030?ooo`000?l0
003o0080003o203oool50000o`L0oooo0`000?l60?ooo`<0003o103oool30000o`@0oooo1P000?l<
0?ooo`<0003o0`3oool70000oaP0oooo[020ool@0?ooo`002P3oool30000o`80oooo0`000?l0103o
ool0003o0000o`000?lI0?ooo`<0003o2P3oool60000o`l0oooo0`000?l30?ooo`H0003o0`3oool4
0000o`H0oooo0`000?l00`3oool0003o0000o`020000o`80oooo0`000?l30?ooo`D0003o1`3oool3
0000o`@0oooo1@000?l90?ooo`<0003o0P3oool30000o`80oooo0`000?l70?ooo`<0003o0P3oool3
0000o`80oooo0`000?lH0?oooj`0P?oo403oool000l0oooo0`000?l0103oool0003o0000o`000?l7
0?ooo`<0003o0P3oool40000o`d0oooo0`000?l90?ooo`<0003o3`3oool30000o`@0oooo1@000?l4
0?ooo`<0003o1P3oool30000o`D0oooo1@000?l50?ooo`<0003o303oool70000o`T0oooo0`000?l2
0?ooo`<0003o0P3oool30000o``0oooo0`000?lM0?oooj`0P?oo403oool000d0oooo0`000?l30?oo
o`<0003o1`3oool30000o`80oooo10000?l=0?ooo`<0003o0`3oool30000oaD0oooo10000?l30?oo
o`D0003o203oool30000o`030?ooo`000?l0003o0080003o1@3oool50000o`D0oooo0`000?l<0?oo
o`D0003o1`3oool30000o`040?ooo`000?l0003o0000o`L0oooo0`000?l:0?ooo`D0003of@3oool0
00d0oooo0`000?l=0?ooo`<0003o0P3oool40000o`d0oooo0`000?l30?ooo`<0003o5P3oool30000
oa00oooo0`000?l00`3oool0003o0000o`020000o`D0oooo0`000?lF0?ooo`D0003o1`3oool30000
oaP0oooo0`000?oK0?ooo`003@3oool30000obT0oooo0`000?lF0?ooo`<0003o403oool30000o`04
0?ooo`000?l0003o0000ob40oooo0`000?l70?ooo`<0003o603oool30000om/0oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.066908, \
-0.0358058, 0.00565494, 0.00565494}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-187.077, -7.78627, 0.879011, 0.879011}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 828}},
WindowSize->{675, 713},
WindowMargins->{{0, Automatic}, {Automatic, 1}},
CellLabelAutoDelete->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 51, 0, 62, "Title"],
Cell[1808, 53, 275, 6, 46, "Text"],

Cell[CellGroupData[{
Cell[2108, 63, 42, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2175, 67, 53, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2253, 71, 36, 0, 43, "Subsubsection"],
Cell[2292, 73, 232, 5, 79, "Input"],
Cell[2527, 80, 276, 5, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2840, 90, 53, 0, 43, "Subsubsection"],
Cell[2896, 92, 207, 4, 63, "Input"],
Cell[3106, 98, 84, 1, 47, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3239, 105, 40, 0, 49, "Subsection"],
Cell[3282, 107, 63, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3382, 113, 36, 0, 49, "Subsection"],
Cell[3421, 115, 130, 2, 63, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3600, 123, 36, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3661, 127, 77, 0, 49, "Subsection"],
Cell[3741, 129, 893, 17, 255, "Input"],
Cell[4637, 148, 857, 17, 255, "Input"],

Cell[CellGroupData[{
Cell[5519, 169, 43, 0, 43, "Subsubsection"],
Cell[5565, 171, 299, 6, 79, "Input"],
Cell[5867, 179, 628, 10, 175, "Input"],
Cell[6498, 191, 296, 5, 95, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6843, 202, 52, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[6920, 206, 50, 0, 43, "Subsubsection"],
Cell[6973, 208, 613, 9, 175, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7623, 222, 65, 0, 43, "Subsubsection"],
Cell[7691, 224, 1145, 19, 223, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8897, 250, 52, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[8974, 254, 44, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[9043, 258, 70, 1, 47, "Input"],
Cell[9116, 261, 21390, 327, 296, 893, 69, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30555, 594, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[30640, 598, 55, 0, 43, "Subsubsection"],
Cell[30698, 600, 159, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30894, 609, 39, 0, 43, "Subsubsection"],
Cell[30936, 611, 160, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31133, 618, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[31197, 622, 251, 5, 79, "Input"],
Cell[31451, 629, 130597, 3202, 296, 38326, 2058, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[162121, 3839, 37, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[162183, 3843, 132, 5, 49, "Subsection"],
Cell[162318, 3850, 101, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[162456, 3858, 54, 0, 49, "Subsection"],
Cell[162513, 3860, 190, 3, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[162740, 3868, 36, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[162801, 3872, 144, 3, 63, "Input"],
Cell[162948, 3877, 19651, 344, 296, 1940, 121, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[182648, 4227, 69, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[182742, 4231, 193, 3, 63, "Input"],
Cell[182938, 4236, 88576, 1767, 296, 11885, 816, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[271563, 6009, 48, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[271636, 6013, 77, 0, 43, "Subsubsection"],
Cell[271716, 6015, 152, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[271905, 6022, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[271979, 6026, 313, 7, 79, "Input"],
Cell[272295, 6035, 2970079, 51271, 163, 2876612, 50114, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3242435, 57313, 55, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3242515, 57317, 329, 6, 95, "Input"],
Cell[3242847, 57325, 231190, 4728, 199, 178034, 4069, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

