(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3142365,      56157]*)
(*NotebookOutlinePosition[   3143085,      56182]*)
(*  CellTagsIndexPosition[   3143041,      56178]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Simple histogram modeling examples", "Title"],

Cell[CellGroupData[{

Cell["Foreword", "Section"],

Cell[TextData[{
  "This notebook gives examples of histogram-based statistical modeling and \
classification, and assumes that the definitions in the notebook \"",
  StyleBox["statistical_modeling.nb",
    FontColor->RGBColor[1, 0, 0]],
  "\" have already been evaluated. All user input sections have been \
highlighted as cell boxes."
}], "Text"],

Cell["\<\
Histogram modeling is a form of non-parametric modeling. Histogram \
models are very simple.They first quantize the space of possible data vectors \
into different regions (bins) and then simply compute the frequency of \
occurrence in the training data for each region.Vector-quantization,a \
data-based method of quantizing a real space into discrete regions,often \
accompanies histogram-based statistical models,although other quantization \
schemes are also possible.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Global user definitions", "Section"],

Cell["Display colors", "Subsection"],

Cell[CellGroupData[{

Cell["Colors representing two classes", "Subsection"],

Cell[BoxData[{
    \(\(class1Color = Red;\)\), "\[IndentingNewLine]", 
    \(\(class2Color = Blue;\)\), "\[IndentingNewLine]", 
    \(\(centroidColor\  = \ Magenta;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Default point style definitions", "Subsection"],

Cell[BoxData[{
    \(\(style1\  = \ {class1Color, 
          PointSize[ .02]};\)\), "\[IndentingNewLine]", 
    \(\(style2\  = \ {class2Color, 
          PointSize[ .02]};\)\), "\[IndentingNewLine]", 
    \(\(centroidStyle\  = \ {centroidColor, PointSize[ .02]};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Default plot range", "Subsection"],

Cell[BoxData[
    \(\(pr\  = \ {{\(-1\), 1}, {\(-1\), 1}};\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example A: Uniform distributions", "Section"],

Cell[CellGroupData[{

Cell["Generate data from two uniform classes", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[{
    \(\(n1\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(n2\  = \ 100;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = \ 
        Table[{ru2[{pr[\([1, 1]\)], 0}], 
            ru2[pr[\([2]\)]]}, {n1}];\)\), "\n", 
    \(\(data2\  = \ 
        Table[{ru2[{0, pr[\([1, 2]\)]}], 
            ru2[pr[\([2]\)]]}, {n2}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[data2, pr, style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ 
        Show[gd1, gd2, \ yS, \ FrameTicks \[Rule] None];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.32705 .5164 Mdot
.29668 .60644 Mdot
.15864 .36367 Mdot
.27753 .96099 Mdot
.05386 .03889 Mdot
.29317 .47122 Mdot
.24512 .97593 Mdot
.28241 .9681 Mdot
.06004 .57488 Mdot
.4336 .22093 Mdot
.39592 .0594 Mdot
.44328 .68243 Mdot
.07382 .53805 Mdot
.15156 .08094 Mdot
.41518 .17934 Mdot
.37402 .115 Mdot
.36627 .1454 Mdot
.0858 .63883 Mdot
.1261 .16452 Mdot
.30339 .66578 Mdot
.07101 .58469 Mdot
.36979 .4498 Mdot
.17509 .53024 Mdot
.42651 .76242 Mdot
.10622 .98723 Mdot
.2799 .68643 Mdot
.19105 .81285 Mdot
.40588 .57638 Mdot
.32478 .6724 Mdot
.32503 .9326 Mdot
.20362 .51284 Mdot
.02659 .27178 Mdot
.13756 .9232 Mdot
.15679 .81703 Mdot
.46247 .39791 Mdot
.23028 .05956 Mdot
.36119 .40572 Mdot
.45038 .36818 Mdot
.1751 .58793 Mdot
.04944 .78685 Mdot
.35032 .91058 Mdot
.22441 .84929 Mdot
.15165 .40269 Mdot
.20278 .58247 Mdot
.01904 .47454 Mdot
.05094 .76049 Mdot
.05657 .08159 Mdot
.32066 .70588 Mdot
.19538 .67091 Mdot
.37028 .34265 Mdot
.02523 .08794 Mdot
.32579 .55085 Mdot
.17491 .17241 Mdot
.10633 .69661 Mdot
.02821 .76477 Mdot
.40355 .11909 Mdot
.01413 .29518 Mdot
.35756 .35366 Mdot
.45756 .21854 Mdot
.04185 .64283 Mdot
.26713 .54268 Mdot
.17157 .30513 Mdot
.24685 .45969 Mdot
.34577 .74933 Mdot
.07689 .29222 Mdot
.2444 .05767 Mdot
.05363 .5225 Mdot
.34085 .93363 Mdot
.04445 .23227 Mdot
.48329 .58492 Mdot
.08689 .01868 Mdot
.4464 .93715 Mdot
.31976 .47106 Mdot
.27978 .63697 Mdot
.07786 .01632 Mdot
.43401 .88269 Mdot
.00592 .71915 Mdot
.19456 .82997 Mdot
.45229 .2016 Mdot
.3537 .89139 Mdot
.41279 .96437 Mdot
.37041 .31142 Mdot
.33084 .95064 Mdot
.42402 .36932 Mdot
.01603 .48453 Mdot
.14919 .7274 Mdot
.43817 .47316 Mdot
.21518 .83977 Mdot
.43721 .74907 Mdot
.02557 .01475 Mdot
.48492 .55242 Mdot
.17187 .11841 Mdot
.07709 .5831 Mdot
.30146 .80205 Mdot
.24624 .62751 Mdot
.37744 .43768 Mdot
.23516 .14793 Mdot
.23321 .70532 Mdot
.29699 .66981 Mdot
.02298 .86061 Mdot
0 0 1 r
.64022 .9158 Mdot
.5026 .85081 Mdot
.62514 .36833 Mdot
.66952 .73735 Mdot
.69727 .78027 Mdot
.96602 .93035 Mdot
.93857 .15771 Mdot
.84347 .49762 Mdot
.67373 .01473 Mdot
.57668 .78735 Mdot
.96577 .33997 Mdot
.59471 .9218 Mdot
.82555 .41922 Mdot
.59211 .07594 Mdot
.70041 .05585 Mdot
.91765 .33364 Mdot
.50313 .27062 Mdot
.94667 .39834 Mdot
.55962 .11786 Mdot
.6032 .89577 Mdot
.88094 .10808 Mdot
.52652 .11337 Mdot
.91022 .76316 Mdot
.92686 .18662 Mdot
.58468 .34889 Mdot
.83475 .11563 Mdot
.87932 .29799 Mdot
.91215 .77704 Mdot
.87618 .03232 Mdot
.96053 .38364 Mdot
.81657 .90951 Mdot
.85733 .48293 Mdot
.93068 .80638 Mdot
.83081 .37451 Mdot
.52045 .04817 Mdot
.89899 .19284 Mdot
.93082 .69434 Mdot
.56424 .08217 Mdot
.55151 .4013 Mdot
.64714 .30018 Mdot
.67037 .37393 Mdot
.68166 .91158 Mdot
.84886 .45948 Mdot
.81938 .43361 Mdot
.91323 .64815 Mdot
.98362 .06405 Mdot
.89278 .60492 Mdot
.58462 .86625 Mdot
.957 .90563 Mdot
.52038 .78904 Mdot
.9055 .50928 Mdot
.86829 .49381 Mdot
.73512 .1403 Mdot
.68663 .57727 Mdot
.88132 .67587 Mdot
.86231 .14862 Mdot
.96313 .03268 Mdot
.87374 .08952 Mdot
.57035 .4228 Mdot
.78911 .21832 Mdot
.6084 .51222 Mdot
.76873 .42433 Mdot
.69795 .00789 Mdot
.89549 .92557 Mdot
.95787 .86264 Mdot
.70886 .35325 Mdot
.57656 .19171 Mdot
.8416 .20958 Mdot
.60848 .16399 Mdot
.96291 .12501 Mdot
.53812 .73623 Mdot
.6738 .90174 Mdot
.92478 .22896 Mdot
.90012 .48236 Mdot
.72683 .22603 Mdot
.50463 .55184 Mdot
.764 .35844 Mdot
.79082 .20354 Mdot
.68744 .17168 Mdot
.94427 .98901 Mdot
.57897 .01264 Mdot
.97641 .86896 Mdot
.54084 .27145 Mdot
.80261 .96226 Mdot
.61112 .04744 Mdot
.89754 .48485 Mdot
.87934 .81646 Mdot
.89291 .92807 Mdot
.61534 .46297 Mdot
.60209 .72947 Mdot
.92294 .29624 Mdot
.65286 .73551 Mdot
.84397 .28856 Mdot
.6715 .8616 Mdot
.80313 .02205 Mdot
.86394 .89439 Mdot
.69201 .96967 Mdot
.96145 .41448 Mdot
.80772 .15815 Mdot
.56855 .48147 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`32ooooo`Go003oE?ooool1o`00007o
oooo00000ol0003oooooooooo`03ooooo`?oo`00Voooool3o`00oaWooooo0ol00?l2ooooo`Go003o
E?ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`Goo`002oooool5ool008Wooooo1Ol0
0?lGooooo`Go003o00?oooooo`00ool00?l00ol00?mDooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo1Ooo000:ooooo`Ooo`00R?ooool5o`00oaOooooo1Ol00?l2ooooo`?o003o7?ooool3
o`00ocKooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool5ool000[ooooo1ooo0028oooo
o`Go003o5oooool5o`00ob3ooooo1Ol00?leooooo`7o00000Oooool00003o`000?oooooooooo00?o
oooo0ooo000;ooooo`Ooo`00ROooool3o`00oaWooooo0ol00?lQooooo`Go003o=Oooool1o`00007o
oooo00000ol0003oooooooooo`0Booooo`Goo`00b_ooool5o`00oa7ooooo0ol00?lEooooo`?o003o
2Oooool1o`00007ooooo00000ol0003oooooooooo`3Rooooo`?o003o4Oooool5o`00oa?ooooo1Ol0
0?l8ooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo0ooo003Xooooo`Go003o4oooool5
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool5ool00>Oooooo1Ol00?lCoooo
o`Go003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0:ooooo`Goo`00j?ooool3o`00oaGo
oooo0ol00?l9ooooo`7o00000Oooool00003o`000?oooooooooo00[ooooo1Ooo0022ooooo`?o003o
5oooool3o`00ofgooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool3ool008;ooooo1Ol0
0?lEooooo`Go003oK?ooool1o`00007ooooo00000ol0003oooooooooo`11ooooo`?oo`00C?ooool5
o`00oaGooooo1Ol00?lEooooo`?o003oE?ooool1o`00007ooooo00000ol0003oooooooooo`0moooo
o`Soo`00:?ooool3ool0023ooooo1Ol00?lEooooo`Go003o5?ooool5o`00oe?ooooo0Ol00001oooo
o`0000?o0000ooooooooool0??ooool9ool002Oooooo1Ooo000Pooooo`?o003o5oooool3o`00oaGo
oooo1Ol00?m=ooooo`?o003o0oooool1o`00007ooooo00000ol0003oooooooooo`0looooo`Woo`00
9oooool5ool005;ooooo1Ol00?m<ooooo`Go003o0_ooool1o`00007ooooo00000ol0003ooooooooo
o`0looooo`Soo`00:?ooool5ool005?ooooo0ol00?m=ooooo`Go003o0_ooool1o`00007ooooo0000
0ol0003oooooooooo`0mooooo`?oo`00;Oooool3ool00:Cooooo1Ol00?l2ooooo`7o00000Oooool0
0003o`000?oooooooooo0:Gooooo0ol00?m]ooooo`?o003o0oooool1o`00007ooooo00000ol0003o
ooooooooo`0<ooooo`?oo`006?ooool3ool007?ooooo0ol00?l4ooooo`Go003oL_ooool1o`00007o
oooo00000ol0003oooooooooo`0;ooooo`Goo`005_ooool5ool0077ooooo1Ol00?l3ooooo`Go003o
L_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`?oo`001Oooool5ool001Kooooo1Ooo
001aooooo`Go003o0oooool5o`00og;ooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool5
ool000Cooooo1Ooo000Fooooo`Goo`00LOooool5o`00o`Cooooo0ol00?m>ooooo`?o003o8_ooool1
o`00007ooooo00000ol0003oooooooooo`02ooooo`Goo`001Oooool3ool001Sooooo0ooo001coooo
o`?o003oEOooool5o`00ob7ooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool5ool00>ko
oooo1Ol00?lQooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo0ooo003_ooooo`Go003o
8Oooool1o`00007ooooo00000ol0003oooooooooo`3fooooo`?o003o8_ooool1o`00007ooooo0000
0ol0003oooooooooo`3hooooo`?o003o8?ooool1o`00007ooooo00000ol0003oooooooooo`2Boooo
o`?o003oH_ooool5o`00oaoooooo0Ol00001ooooo`0000?o0000ooooooooool0Ioooool3ool002Oo
oooo1Ol00?mEooooo`?o003o2Oooool5o`00oaoooooo0Ol00001ooooo`0000?o0000ooooooooool0
;Oooool3ool003Kooooo1Ooo0004ooooo`?oo`007oooool5o`00o`Kooooo0ol00?m;ooooo`Go003o
2?ooool5o`00oaoooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool5ool003Gooooo1Ooo
0003ooooo`Goo`007_ooool5o`00o`Gooooo1Ol00?m:ooooo`Go003o2Oooool3o`00ob3ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0;?ooool5ool003Gooooo1Ooo0003ooooo`Goo`007oooool3
o`00o`Kooooo1Ol00?m:ooooo`Go003o8?ooool3o`00o`Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0;?ooool5ool003Kooooo0ooo0004ooooo`Goo`00:?ooool5o`00od_ooooo0ol00?lPoooo
o`Go003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`?oo`00?oooool3ool002[o
oooo0ol00?m_ooooo`Go003o2?ooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`oooooo
1Ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo0<kooooo0ol00?lnooooo`?o003o2Ooo
ool1o`00007ooooo00000ol0003oooooooooo`3=ooooo`Go003oBOooool1o`00007ooooo00000ol0
003oooooooooo`0oooooo`?oo`008_ooool3ool006Kooooo1Ol00?m9ooooo`7o00000Oooool00003
o`000?oooooooooo03kooooo1Ooo000Pooooo`Goo`00IOooool5o`00ob7ooooo0ol00?lUooooo`7o
00000Oooool00003o`000?oooooooooo03kooooo1Ooo000Pooooo`Goo`00I_ooool3o`00ob7ooooo
1Ol00?lTooooo`7o00000Oooool00003o`000?oooooooooo03kooooo1Ooo000Pooooo`Goo`00Nooo
ool3o`00o`cooooo1Ol00?lAooooo`?o003o4?ooool1o`00007ooooo00000ol0003oooooooooo`0o
ooooo`?oo`008_ooool3ool007_ooooo1Ol00?l;ooooo`Go003o4?ooool5o`00o`oooooo0Ol00001
ooooo`0000?o0000ooooooooool07oooool3ool008Sooooo0ol00?leooooo`Go003o3?ooool3o`00
oa7ooooo1Ol00?l?ooooo`7o00000Oooool00003o`000?oooooooooo01kooooo1Ooo0026ooooo`Go
003o=?ooool5o`00ob3ooooo1Ol00?l?ooooo`7o00000Oooool00003o`000?oooooooooo01kooooo
1Ooo000:ooooo`?oo`00NOooool5o`00oa;ooooo0ol00?lPooooo`?o003o8_ooool3o`00oa3ooooo
0Ol00001ooooo`0000?o0000ooooooooool07_ooool5ool000Wooooo1Ooo001hooooo`Go003o4Ooo
ool5o`00oeOooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool3ool000[ooooo1Ooo0011
ooooo`?oo`00=Oooool3o`00oa;ooooo1Ol00?mGooooo`7o00000Oooool00003o`000?oooooooooo
02cooooo1Ooo0010ooooo`Goo`00BOooool5o`00oeOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0;Oooool3ool0047ooooo1Ooo001:ooooo`?o003o@_ooool3o`00oa?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0LOooool5ool008kooooo1Ol00?lBooooo`7o00000Oooool00003o`000?oo
oooooooo07;ooooo0ooo000/ooooo`?o003oFOooool3o`00o`Cooooo1Ol00?lBooooo`7o00000Ooo
ool00003o`000?oooooooooo0:3ooooo1Ol00?mGooooo`Go003o0oooool5o`00oa;ooooo0Ol00001
ooooo`0000?o0000ooooooooool0X?ooool5o`00oeOooooo1Ol00?l4ooooo`?o003o4oooool1o`00
007ooooo00000ol0003oooooooooo`1mooooo`?oo`008?ooool5o`00ocWooooo0ol00?lKooooo`Go
003o6_ooool1o`00007ooooo00000ol0003oooooooooo`1looooo`Goo`008?ooool3o`00ocWooooo
1Ol00?lKooooo`?o003o6oooool1o`00007ooooo00000ol0003oooooooooo`1looooo`Goo`00G?oo
ool5o`00o`_ooooo0ol00?l[ooooo`7o00000Oooool00003o`000?oooooooooo07cooooo1Ooo001L
ooooo`Go003o2_ooool5o`00ob[ooooo0Ol00001ooooo`0000?o0000ooooooooool0OOooool3ool0
05kooooo0ol00?l;ooooo`Go003o:_ooool1o`00007ooooo00000ol0003oooooooooo`1hooooo`?o
o`001?ooool3ool005cooooo0ol00?l;ooooo`Go003o:_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1gooooo`Goo`000_ooool5ool005[ooooo1Ol00?l;ooooo`?o003o:oooool1o`00007ooooo
00000ol0003oooooooooo`1gooooo`Goo`000_ooool5ool004Wooooo0ol00?l>ooooo`Go003o>Ooo
ool1o`00007ooooo00000ol0003oooooooooo`1gooooo`Goo`000_ooool5ool004Sooooo1Ol00?l=
ooooo`Go003o8_ooool3o`00oaCooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool3ool0
06gooooo0ooo0004ooooo`?oo`00BOooool5o`00o`kooooo0ol00?lRooooo`Go003o4oooool1o`00
007ooooo00000ol0003oooooooooo`07ooooo`Goo`00_oooool5o`00oc?ooooo1Ol00?lCooooo`7o
00000Oooool00003o`000?oooooooooo00Oooooo1Ooo0030ooooo`?o003o=?ooool5o`00oa?ooooo
0Ol00001ooooo`0000?o0000ooooooooool01oooool5ool00?Sooooo0ol00?lDooooo`7o00000Ooo
ool00003o`000?oooooooooo00Sooooo0ooo003ooooooa7ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool3ool008Ko
oooo0ol00?l7ooooo`?o003oP_ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`Goo`00
Q?ooool5o`00o`Gooooo1Ol00?n1ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo1Ooo
0024ooooo`Go003o1Oooool5o`00oh7ooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool5
ool008Cooooo1Ol00?l5ooooo`Go003oPOooool1o`00007ooooo00000ol0003oooooooooo`03oooo
o`?oo`00Q_ooool3o`00o`Oooooo0ol00?n2ooooo`7o00000Oooool00003o`000?oooooooooo0>go
oooo0ol00?l[ooooo`7o00000Oooool00003o`000?oooooooooo017ooooo0ooo003Hooooo`Go003o
:_ooool1o`00007ooooo00000ol0003oooooool00002ool000kooooo1Ooo003Gooooo`Go003o1_oo
ool3o`00o`[ooooo0ol00?lDooooo`7o00000Oooool00003o`000?oo003oo`0000?oo`003Oooool5
ool00:3ooooo0ol00?ldooooo`Go003o1Oooool5o`00o`Sooooo1Ol00?lCooooo`7o00000Oooool0
0003o`000?oo003oo`0000?oo`003Oooool5ool001Sooooo0ooo0024ooooo`Go003o=?ooool3o`00
o`Kooooo1Ol00?l8ooooo`Go003o4oooool1o`00007ooooo00000ol0003oo`00ool00003ool000ko
oooo0ooo000Hooooo`Goo`00Poooool5o`00ocgooooo1Ol00?l8ooooo`Go003o4oooool1o`00007o
oooo00000ol0003oooooool00002ool002[ooooo1Ooo000eooooo`?oo`00Boooool5o`00ockooooo
0ol00?l:ooooo`?o003o5?ooool1o`00007ooooo00000ol0003oooooooooo`0/ooooo`Goo`00=?oo
ool5ool004_ooooo0ol00?mSooooo`7o00000Oooool00003o`000?oooooooooo02gooooo0ooo000e
ooooo`Goo`00/Oooool1o`00007ooooo00000ol0003oooooooooo`1Uooooo`Goo`00/Oooool1o`00
007ooooo00000ol0003oooooooooo`1Vooooo`?oo`00/_ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo0oooool3o`00oaKooooo0Ol00001ooooo`0000?o0000oooo
ooooool0ooooool2ooooo`Go003o2_ooool3o`00o`Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0IOooool3ool009Wooooo1Ol00?l9ooooo`Go003o1oooool1o`00007ooooo00000ol0003ooooo
ooooo`1Tooooo`Goo`00V?ooool5o`00o`Wooooo1Ol00?l7ooooo`7o00000Oooool00003o`000?oo
oooooooo06Cooooo1Ooo000jooooo`?o003oG?ooool3o`00o`[ooooo1Ol00?l7ooooo`7o00000Ooo
ool00003o`000?oooooooooo06;ooooo1ooo000iooooo`Go003o8?ooool3o`00odKooooo0ol00?l8
ooooo`7o00000Oooool00003o`000?oooooooooo067ooooo1ooo000jooooo`Go003o7oooool5o`00
oe3ooooo0Ol00001ooooo`0000?o0000ooooooooool0HOooool5ool003cooooo1Ol00?lOooooo`Go
003o2oooool3o`00od;ooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool3ool003Gooooo
1Ooo000mooooo`?o003o8?ooool5o`00o`[ooooo1Ol00?m1ooooo`7o00000Oooool00003o`000?oo
oooooooo02Sooooo1Ooo000eooooo`?oo`00H_ooool3o`00o`_ooooo1Ol00?m1ooooo`7o00000Ooo
ool00003o`000?oooooooooo02Sooooo1Ooo0018ooooo`?oo`001?ooool3ool0033ooooo0ol00?lS
ooooo`Go003o@Oooool1o`00007ooooo00000ol0003oooooooooo`0Xooooo`Goo`00Aoooool5ool0
00;ooooo1Ooo000^ooooo`Go003o2Oooool3o`00oaOooooo0ol00?lAooooo`?o003o;_ooool1o`00
007ooooo00000ol0003oooooooooo`0Yooooo`?oo`00B?ooool5ool000;ooooo1Ooo000^ooooo`Go
003o2?ooool5o`00obWooooo1Ol00?l]ooooo`7o00000Oooool00003o`000?oooooooooo07Cooooo
1Ooo0002ooooo`Goo`00;_ooool5o`00o`Sooooo1Ol00?lYooooo`Go003o;Oooool1o`00007ooooo
00000ol0003oooooooooo`1eooooo`?oo`001?ooool3ool0033ooooo0ol00?l9ooooo`Go003o:Ooo
ool5o`00ob7ooooo0ol00?l9ooooo`7o00000Oooool00003o`000?oooooooooo0;cooooo0ol00?l[
ooooo`?o003o8Oooool5o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool?oooo
o`Go003o2?ooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`oooooo1Ol00?l8ooooo`7o
00000Oooool00003o`000?oooooooooo083ooooo0ooo0028ooooo`?o003o00Coooooo`00ool00?oo
003o2Oooool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`?oo`00EOooool5ool001Gooooo
0ol00?m^ooooo`Go003o3?ooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`Goo`00>?oo
ool3ool001Wooooo1Ooo000Dooooo`Go003oKOooool5o`00o`cooooo0Ol00001ooooo`0000?o0000
ooooooooool09_ooool5ool003Oooooo1Ooo000Hooooo`Goo`005?ooool5o`00ofgooooo1Ol00?l<
ooooo`7o00000Oooool00003o`000?oooooooooo02Kooooo1Ooo000gooooo`Goo`006Oooool3ool0
01Gooooo1Ol00?m^ooooo`?o003o3Oooool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`?o
o`00>?ooool5ool003;ooooo0ol00?mcooooo`?o003o2Oooool1o`00007ooooo00000ol0003ooooo
ooooo`1Sooooo`?oo`00P_ooool3o`00ob?ooooo1Ol00?l8ooooo`7o00000Oooool00003o`000?oo
oooooooo09oooooo0ol00?m5ooooo`Go003o8_ooool5o`00o`Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0W_ooool5o`00ocGooooo0ol00?l<ooooo`Go003o8_ooool5o`00o`Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0W_ooool5o`00ocCooooo1Ol00?l;ooooo`Go003o8oooool3o`00
o`Wooooo0Ol00001ooooo`0000?o0000ooooooooool0W_ooool5o`00ocCooooo1Ol00?l:ooooo`Go
003o<?ooool1o`00007ooooo00000ol0003oooooooooo`1Xooooo`?oo`00=?ooool3o`00ocGooooo
1Ol00?l9ooooo`Go003o<Oooool1o`00007ooooo00000ol0003oooooooooo`1Wooooo`Goo`00K?oo
ool3o`00o`[ooooo1Ol00?laooooo`7o00000Oooool00003o`000?oooooooooo06Oooooo1Ooo001i
ooooo`Go003o<Oooool1o`00007ooooo00000ol0003oooooooooo`1Wooooo`Goo`00N_ooool3o`00
oc;ooooo0Ol00001ooooo`0000?o0000ooooooooool0IOooool6ool00;3ooooo0Ol00001ooooo`00
00?o0000ooooooooool0I?ooool5ool00;;ooooo0Ol00001ooooo`0000?o0000ooooooooool0I?oo
ool5ool00;;ooooo0Ol00001ooooo`0000?o0000ooooooooool0@_ooool3ool001oooooo1Ooo0026
ooooo`?o003o:Oooool1o`00007ooooo00000ol0003oooooooooo`11ooooo`Goo`007oooool3ool0
04Cooooo0ol00?loooooo`Go003o:?ooool1o`00007ooooo00000ol0003oooooooooo`11ooooo`Go
o`00IOooool5o`00ockooooo1Ol00?lXooooo`7o00000Oooool00003o`000?oooooooooo047ooooo
1Ooo0009ooooo`?oo`001Oooool3ool0057ooooo1Ol00?lnooooo`Go003o:?ooool1o`00007ooooo
00001?l0003oooooooooooooool3ool003kooooo0ooo0009ooooo`Goo`000oooool5ool001kooooo
0ooo000_ooooo`Go003o?oooool3o`00obWooooo0Ol00001ooooo`0000?o0000ooooooooool01Ooo
0019ooooo`Goo`000oooool5ool001gooooo1Ooo000_ooooo`?o003oK?ooool1o`00007ooooo0000
0ol0003oooooooooo`05ool004Wooooo1Ooo0003ooooo`Goo`007Oooool5ool0027ooooo0ol00?m@
ooooo`?o003o2Oooool3o`00oa_ooooo0Ol00001ooooo`0000?o0000ooooooooool01Ooo001:oooo
o`?oo`001Oooool3ool001kooooo1Ooo000Pooooo`Go003oC_ooool5o`00o`Oooooo1Ol00?lJoooo
o`7o00000Oooool00003o`000?ooooooo`0000Coo`00MOooool3ool0027ooooo1Ol00?m>ooooo`Go
003o1oooool5o`00oa[ooooo0Ol00001ooooo`0000?o0000oooooooo00001?oo002Iooooo`Go003o
C_ooool5o`00o`Oooooo1Ol00?lJooooo`7o00000Oooool00003o`000?ooooooo`0000Coo`00V_oo
ool3o`00oe3ooooo1_l00?l5ooooo`Go003o6_ooool1o`00007ooooo00000ol0003oooooooooo`03
ool00>[ooooo0ol00?l3ooooo`Go003o1Oooool3o`00oa_ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0k?ooool5o`00o`;ooooo1Ol00?lSooooo`7o00000Oooool00003o`000?oooooooooo0>co
oooo1Ol00?l2ooooo`Go003o8oooool1o`00007ooooo00000ol0003oooooooooo`3/ooooo`Go003o
0oooool3o`00o`Sooooo0ol00?lIooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo0ooo
001aooooo`?o003o@?ooool3o`00o`kooooo1Ol00?lHooooo`7o00000Oooool00003o`000?oooooo
oooo03Gooooo1Ooo000Oooooo`?oo`00COooool5o`00oe3ooooo1Ol00?lHooooo`7o00000Oooool0
0003o`000?oooooooooo03Gooooo1Ooo000Nooooo`Goo`00C?ooool5o`00oe3ooooo1Ol00?lHoooo
o`7o00000Oooool00003o`000?oooooooooo00_ooooo0ooo000Wooooo`Goo`007_ooool5ool004co
oooo1Ol00?mAooooo`?o003o6Oooool1o`00007ooooo00000ol0003oooooooooo`0:ooooo`Goo`00
9oooool3ool001oooooo1Ooo001=ooooo`?o003oK_ooool1o`00007ooooo00000ol0003ooooooooo
o`0:ooooo`Goo`007oooool3ool002Sooooo0ooo002oooooo`7o00000Oooool00003o`000?oooooo
oooo00[ooooo1Ooo000Nooooo`Goo`00jOooool1o`00007ooooo00000ol0003oooooooooo`0;oooo
o`?oo`000_ooool3ool001[ooooo1Ooo003Yooooo`7o00000Oooool00003o`000?oooooooooo00oo
oooo1Ooo000Iooooo`Goo`00jOooool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`Goo`00
6_ooool3ool001Oooooo0ooo003@ooooo`7o00000Oooool00003o`000?oooooooooo00oooooo1Ooo
000cooooo`Goo`00coooool1o`00007ooooo00000ol0003oooooooooo`0@ooooo`?oo`00=?ooool5
ool000gooooo0ooo000Zooooo`?oo`000oooool3o`00ohcooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Aoooool5ool000cooooo1Ooo000Xooooo`Goo`0000?oooooo`00ool00?l00ol00?n;oooo
o`7o00000Oooool00003o`000?oooooooooo04Sooooo0ooo000=ooooo`Goo`00:?ooool5ool00003
ooooool00?oo003o00?o003oRoooool1o`00007ooooo00000ol0003oooooooooo`1Hooooo`Goo`00
:?ooool5ool00003ooooool00?oo003o00?o003oRoooool1o`00007ooooo00000ol0003ooooooooo
o`1Iooooo`?oo`00:_ooool3ool000?ooooo0ol00?n<ooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool03Oooool3ool0063ooooo0ooo001=ooooo`?o003oF?ooool1o`00007o
oooo00000ol0003oooooooooo`0<ooooo`Goo`00G_ooool5ool004_ooooo1Ol00?mGooooo`7o0000
0Oooool00003o`000?oooooooooo00cooooo2?oo000Qooooo`?oo`00=oooool5ool004_ooooo1Ol0
0?mGooooo`7o00000Oooool00003o`000?oooooooooo00cooooo2Ooo000Oooooo`Goo`00=_ooool5
ool001;ooooo0ooo000fooooo`Go003oEoooool1o`00007ooooo00000ol0003oooooooooo`0=oooo
o`Soo`006Oooool3ool000?ooooo1Ooo000gooooo`?oo`004_ooool5ool003Kooooo0ol00?mHoooo
o`7o00000Oooool00003o`000?oooooooooo00oooooo1_oo000Hooooo`Goo`000_ooool5ool004co
oooo1Ooo002Aooooo`7o00000Oooool00003o`000?oooooooooo00oooooo1Ooo000Iooooo`Goo`00
0oooool3ool004gooooo1Ooo002Aooooo`7o00000Oooool00003o`000?oooooooooo013ooooo0ooo
000Jooooo`Goo`00E?ooool3ool009;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;_ooool3
ool00<[ooooo0ol00?lMooooo`7o00000Oooool00003o`000?oooooooooo053ooooo0ooo002Woooo
o`Go003o7?ooool1o`00007ooooo00000ol0003oooooooooo`1?ooooo`Goo`00Y_ooool5o`00oaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0Coooool5ool00:Kooooo1Ol00?lLooooo`7o0000
0Oooool00003o`000?oooooooooo04oooooo1Ooo002Wooooo`?o003o7Oooool1o`00007ooooo0000
0ol0003oooooooooo`1@ooooo`?oo`00b?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0@_ooool3ool00=Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0@Oooool5ool00=Gooooo0Ol00001ooooo`0000?o0000ooooooooool0@Ooo
ool5ool00=Gooooo0Ol00001ooooo`0000?o0000ooooooooool05?ooool3ool002[ooooo1Ooo0006
ooooo`?oo`00c?ooool1o`00007ooooo00000ol0003oooooooooo`07ooooo`?oo`002Oooool5ool0
02[ooooo0ooo0006ooooo`Goo`00boooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`Go
o`002?ooool5ool003?ooooo1Ooo003;ooooo`7o00000Oooool00003o`000?oooooooooo00Kooooo
1Ooo0008ooooo`Goo`00<oooool5ool00;7ooooo0ol00?lGooooo`7o00000Oooool00003o`000?oo
oooooooo00Kooooo1Ooo0009ooooo`?oo`00=Oooool3ool00;7ooooo1Ol00?lFooooo`7o00000Ooo
ool00003o`000?oooooooooo00Oooooo0ooo003fooooo`Go003o5_ooool1o`00007ooooo00000ol0
003oooooooooo`3oooooo`7ooooo1Ol00?lFooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo0_ooool3o`00oaOooooo0Ol00001ooooo`0000?o0000ooooooooool0D_ooool3ool00<Kooooo
0Ol00001ooooo`0000?o0000ooooooooool0<oooool3ool001[ooooo1_oo0035ooooo`7o00000Ooo
ool00003o`000?oooooooooo03;ooooo1Ooo000Hooooo`Ooo`000_ooool3ool00<3ooooo0Ol00001
ooooo`0000?o0000ooooooooool0<_ooool5ool001Sooooo1ooo00000oooooooo`00ool00003ool0
09cooooo0ol00?lPooooo`7o00000Oooool00003o`000?oooooooooo03;ooooo1Ooo000Hooooo`Ko
o`000_ooool5ool009_ooooo1Ol00?lOooooo`7o00000Oooool00003o`000?oooooooooo03?ooooo
0ooo000Jooooo`?oo`001?ooool5ool001kooooo0ooo001jooooo`Go003o7oooool1o`00007ooooo
00000ol0003oooooooooo`1<ooooo`?oo`002Oooool3ool001kooooo1Ooo001iooooo`Go003o7ooo
ool1o`00007ooooo00000ol0003oooooooooo`1;ooooo`Goo`00:Oooool5ool007[ooooo0ol00?lP
ooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo1Ooo000Yooooo`Goo`00R?ooool3o`00
oa;ooooo0Ol00001ooooo`0000?o0000ooooooooool06_ooool3ool002kooooo1Ooo000Zooooo`?o
o`00R?ooool5o`00oa7ooooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool5ool002kooooo
0ooo002fooooo`Go003o4Oooool1o`00007ooooo00000ol0003oooooooooo`0Iooooo`Goo`008?oo
ool3ool001Kooooo0ooo002[ooooo`Go003o4Oooool1o`00007ooooo00000ol0003oooooooooo`0I
ooooo`Goo`007oooool5ool001Cooooo1Ooo002[ooooo`?o003o4_ooool1o`00007ooooo00000ol0
003oooooooooo`0Jooooo`?oo`008?ooool5ool001Cooooo1Ooo0030ooooo`7o00000Oooool00003
o`000?oooooooooo03gooooo1Ooo000Dooooo`Goo`00`?ooool1o`00007ooooo0002ool003oooooo
0ooo000Fooooo`?oo`00`Oooool1o`00007ooooo0003ool00?oooooo7?ooool1o`00007ooooo0003
ool00?oooooo7?ooool1o`00007ooooo0003ool002Kooooo0ooo001oooooo`?o003oL?ooool1o`00
007ooooo0002ool002Kooooo1Ooo001mooooo`Go003oKoooool1o`00007ooooo00000ol0003ooooo
ooooo`0Uooooo`Goo`00K?ooool3o`00o`kooooo1Ol00?l;ooooo`?o003o00Coooooo`00ool00?oo
003oGOooool1o`00007ooooo00000ol0003oooooooooo`0Uooooo`Goo`00Joooool5o`00o`gooooo
1Ol00?l:ooooo`Wo003oG?ooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`?oo`00K?oo
ool5o`00o`kooooo0ol00?l;ooooo`Wo003oG?ooool1o`00007ooooo00000ol0003oooooooooo`2E
ooooo`Go003o7?ooool9o`00oecooooo0Ol00001ooooo`0000?o0000ooooooooool0G_ooool3ool0
01Sooooo0ooo000Jooooo`?o003o7_ooool3o`00o`04ooooool00?oo003oo`00oegooooo0Ol00001
ooooo`0000?o0000ooooooooool0GOooool5ool001Kooooo1Ooo002Nooooo`7o00000Oooool00003
o`000?oooooooooo05gooooo1Ooo000Fooooo`Goo`00W_ooool1o`00007ooooo00000ol0003ooooo
ooooo`0:ooooo`?oo`00D?ooool5ool001Kooooo1Ooo002Nooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo0ooo0003ooooo`Goo`00D?ooool3ool001Gooooo1_oo0024ooooo`?o003o6?oo
ool1o`00007ooooo00000ol0003oooooooooo`02ooooo`Goo`000_ooool5ool006Oooooo1Ooo0025
ooooo`Go003o5oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`Goo`000_ooool5ool0
06Oooooo1Ooo0025ooooo`Go003o5oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`Go
o`000oooool3ool006Sooooo1Ooo0025ooooo`Go003o5oooool1o`00007ooooo00000ol0003ooooo
ooooo`03ooooo`?oo`00L?ooool3ool008Oooooo1?l00?lGooooo`7o00000Oooool00003o`000?oo
oooooooo0<?ooooo0ol00?ljooooo`Go003o5_ooool1o`00007ooooo00000ol0003oooooooooo`32
ooooo`Go003o>Oooool5o`00oaKooooo0Ol00001ooooo`0000?o0000ooooooooool02Oooool3ool0
08Gooooo0ol00?l=ooooo`?o003o7_ooool5o`00ocWooooo1Ol00?lFooooo`7o00000Oooool00003
o`000?oooooooooo00Sooooo1Ooo0023ooooo`Go003o2oooool5o`00oagooooo1Ol00?ljooooo`?o
003o5oooool1o`00007ooooo00000ol0003oooooooooo`08ooooo`Goo`00Poooool5o`00o`_ooooo
1Ol00?lNooooo`?o003oEOooool1o`00007ooooo00000ol0003oooooooooo`08ooooo`Goo`00Pooo
ool5o`00o`_ooooo1Ol00?mfooooo`7o00000Oooool00003o`000?oooooooooo00Wooooo0ooo0016
ooooo`?oo`00??ooool3o`00o`gooooo0ol00?mgooooo`7o00000Oooool00003o`000?oooooooooo
057ooooo1Ooo002`ooooo`?o003o4_ooool1o`00007ooooo00000ol0003oooooooooo`1Aooooo`Go
o`00[oooool5o`00oa7ooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool3ool001cooooo
1Ooo002_ooooo`Go003o4Oooool1o`00007ooooo00000ol0003oooooooooo`0Xooooo`?oo`001_oo
ool5ool001cooooo0ooo002Rooooo`?o003o2oooool5o`00oa7ooooo0Ol00001ooooo`0000?o0000
ooooooooool09oooool5ool000Gooooo1Ooo0030ooooo`Go003o2oooool3o`00oa;ooooo0Ol00001
ooooo`0000?o0000ooooooooool09oooool5ool000Gooooo1Ooo0030ooooo`Go003o8?ooool1o`00
007ooooo00000ol0003oooooooooo`0Wooooo`Goo`001_ooool3ool00<7ooooo1Ol00?lPooooo`7o
00000Oooool00003o`000?oooooooooo02Sooooo0ooo0008ooooo`?oo`00`Oooool3o`00ob7ooooo
0Ol00001ooooo`0000?o0000ooooooooool0<_ooool5ool00>Cooooo0Ol00001ooooo`0000?o0000
ooooooooool0<_ooool5ool00>Cooooo0Ol00001ooooo`0000?o0000ooooooooool0<_ooool5ool0
00;ooooo0ooo003Oooooo`7o00000Oooool00003o`000?oooooooooo03?ooooo0ooo0002ooooo`Go
o`00g_ooool1o`00007ooooo00000ol0003oooooooooo`0hooooo`Ooo`00g?ooool1o`00007ooooo
00000ol0003oooooooooo`0hooooo`Soo`00Boooool3o`00ohgooooo0Ol00001ooooo`0000?o0000
ooooooooool0>Oooool7ool004[ooooo1Ol00?n<ooooo`7o00000Oooool00003o`000?oooooooooo
03_ooooo1Ooo001:ooooo`Go003oS?ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`?o
o`00=oooool3ool004_ooooo1Ol00?l]ooooo`?o003oCoooool3o`00o`[ooooo0Ol00001ooooo`00
00Co0000oooooooooooooooo1Ooo0025ooooo`?o003o5Oooool3o`00oaGooooo1Ol00?m=ooooo`Go
003o2Oooool1o`00007ooooo00001?l0003oooooooooooooool5ool009cooooo1Ol00?lDooooo`Go
003oCOooool5o`00o`04ooooool00?oo003oo`00o`Gooooo0Ol00001ooooo`0000Co0000oooooooo
oooooooo1Ooo002Looooo`Go003o5?ooool5o`00odgooooo2_l00?l4ooooo`7o00000Oooool00003
o`000?oooooooooo00;ooooo0ooo002Mooooo`Go003o5Oooool3o`00odoooooo0ol00?l00ooooooo
003oo`00o`03o`00o`Cooooo0Ol00001ooooo`0000?o0000ooooooooool0Xoooool3o`00ofcooooo
1Ol00?l4ooooo`7o00000Oooool00003o`000?oooooooooo07Sooooo0ooo002Hooooo`?o003o1Ooo
ool1o`00007ooooo00000ol0003oooooooooo`1gooooo`Goo`00Woooool1o`00007ooooo00000ol0
003oooooooooo`1gooooo`Goo`00Woooool1o`00007ooooo00000ol0003oooooooooo`1Qooooo`?o
o`004oooool5ool007Oooooo0ol00?lUooooo`7o00000Oooool00003o`000?oooooooooo063ooooo
1Ooo000Cooooo`?oo`00;Oooool3o`00odOooooo1Ol00?lTooooo`7o00000Oooool00003o`000?oo
oooooooo063ooooo1Ooo0012ooooo`Go003oA_ooool5o`00obCooooo0Ol00001ooooo`0000?o0000
ooooooooool0H?ooool5ool004;ooooo1Ol00?lAooooo`?o003o<_ooool5o`00obCooooo0Ol00001
ooooo`0000?o0000ooooooooool0HOooool3ool004?ooooo1Ol00?l@ooooo`Go003o<_ooool3o`00
oaSooooo0ol00?l:ooooo`7o00000Oooool00003o`000?oooooooooo063ooooo0ooo0015ooooo`?o
003o4Oooool6o`00ob?ooooo0ol00?lUooooo`Go003o2Oooool1o`00007ooooo00000ol0003ooooo
ooooo`1Oooooo`Goo`00F?ooool7o`00ob7ooooo1Ol00?lTooooo`Go003o2Oooool1o`00007ooooo
00000ol0003oooooooooo`1Oooooo`Goo`00Coooool3o`00o`Oooooo1_l00?lQooooo`Go003o9?oo
ool5o`00o`Wooooo0Ol00001ooooo`0000?o0000ooooooooool0Goooool5ool004;ooooo0ol00?l9
ooooo`Go003o1oooool5o`00ob7ooooo1Ol00?lUooooo`?o003o2_ooool1o`00007ooooo00000ol0
003oooooooooo`0Sooooo`?oo`00>_ooool3ool004;ooooo1Ol00?l8ooooo`Go003o2?ooool3o`00
ob?ooooo0ol00?lDooooo`?o003o7?ooool1o`00007ooooo00000ol0003oooooooooo`0Rooooo`Go
o`00O_ooool5o`00o`Sooooo1Ol00?m4ooooo`Go003o6oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Rooooo`Goo`00<_ooool3ool004Wooooo1Ol00?l9ooooo`?o003oA?ooool6o`00oa3ooooo
0ol00?l8ooooo`7o00000Oooool00003o`000?oooooooooo02;ooooo1Ooo000aooooo`Soo`00A_oo
ool3o`00oe7ooooo1_l00?l?ooooo`Go003o1oooool1o`00007ooooo00000ol0003oooooooooo`0S
ooooo`?oo`00<_ooool9ool001[ooooo0ooo001looooo`Go003o4?ooool5o`00o`Oooooo0Ol00001
ooooo`0000?o0000ooooooooool0F?ooool9ool001Wooooo1Ooo001looooo`?o003o4Oooool5o`00
o`Oooooo0Ol00001ooooo`0000?o0000ooooooooool0FOooool8ool001Wooooo1Ooo002Aooooo`?o
003o2?ooool1o`00007ooooo00000ol0003oooooooooo`1Mooooo`?oo`006_ooool5ool009cooooo
0Ol00001ooooo`0000?o0000ooooooooool0F_ooool3ool001kooooo0ooo002Mooooo`7o00000Ooo
ool00003o`000?oooooooooo05Wooooo1Ooo002mooooo`7o00000Oooool00003o`000?oooooooooo
04_ooooo0ooo000;ooooo`Goo`00_Oooool1o`00007ooooo00000ol0003oooooooooo`1:ooooo`Go
o`002_ooool5ool001Cooooo0ooo001/ooooo`?o003o=oooool1o`00007ooooo00000ol0003ooooo
ooooo`1:ooooo`Goo`002oooool3ool001Cooooo1Ooo001Zooooo`Go003o=_ooool1o`00007ooooo
00000ol0003oooooooooo`1:ooooo`Goo`008_ooool5ool004cooooo0ol00?lKooooo`Go003o=_oo
ool1o`00007ooooo00000ol0003oooooooooo`1;ooooo`Goo`008Oooool5ool004_ooooo1Ol00?lJ
ooooo`Go003o=_ooool1o`00007ooooo00000ol0003oooooooooo`12ooooo`?oo`001_ooool5ool0
02;ooooo0ooo001<ooooo`Go003o6oooool3o`00ocOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0@Oooool5ool000Gooooo1Ooo001aooooo`Go003oEOooool1o`00007ooooo00000ol0003ooooo
ooooo`11ooooo`Goo`001_ooool3ool007?ooooo0ol00?mFooooo`7o00000Oooool00003o`000?oo
oooooooo01[ooooo0ooo000Tooooo`Goo`00eOooool1o`00007ooooo00000ol0003oooooooooo`0I
ooooo`Goo`009?ooool3ool00<Gooooo0ol00?l>ooooo`7o00000Oooool00003o`000?oooooooooo
01Wooooo1Ooo003[ooooo`Go003o3Oooool1o`00007ooooo00000ol0003oooooooooo`0Iooooo`Go
o`00joooool5o`00o`gooooo0Ol00001ooooo`0000?o0000ooooooooool06_ooool3ool00>cooooo
1Ol00?l=ooooo`7o00000Oooool00?oo00003_l00003o`00o`oo00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Uniform quantization", "Subsection"],

Cell[CellGroupData[{

Cell["Number of centroids in each direction", "Subsubsection"],

Cell[BoxData[
    \(\(nCentroids\  = \ 4;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute uniformly distributed centroids", "Subsubsection"],

Cell[BoxData[
    \(\(uniformCentroids\  = \ 
        UniformQuantization[pr[\([1]\)], pr[\([2]\)], 
          nCentroids];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gCentroids = \ 
        PlotData2D[uniformCentroids, pr, \ centroidStyle, \ 
          FrameTicks \[Rule] None];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 1 r
.02 w
.12871 .12871 Mdot
.12871 .37624 Mdot
.12871 .62377 Mdot
.12871 .8713 Mdot
.37624 .12871 Mdot
.37624 .37624 Mdot
.37624 .62377 Mdot
.37624 .8713 Mdot
.62377 .12871 Mdot
.62377 .37624 Mdot
.62377 .62377 Mdot
.62377 .8713 Mdot
.8713 .12871 Mdot
.8713 .37624 Mdot
.8713 .62377 Mdot
.8713 .8713 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool08?ooool3ool0odCooooo0ooo0?m4oooo
o`?oo`3oA?ooool3ool0ob?ooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool5ool0od;o
oooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
7oooool5ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol00001ooooo`0000?o
0000ooooooooool07oooool5ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol0
0001ooooo`0000?o0000ooooooooool08?ooool3ool0odCooooo0ooo0?m4ooooo`?oo`3oA?ooool3
ool0ob?ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool08?ooool3ool0odCooooo0ooo0?m4ooooo`?oo`3oA?ooool3ool0ob?o
oooo0Ol00001ooooo`0000?o0000ooooooooool07oooool5ool0od;ooooo1Ooo0?m2ooooo`Goo`3o
@_ooool5ool0ob;ooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool5ool0od;ooooo1Ooo
0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool5
ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol00001ooooo`0000?o0000oooo
ooooool08?ooool3ool0odCooooo0ooo0?m4ooooo`?oo`3oA?ooool3ool0ob?ooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
8?ooool3ool0odCooooo0ooo0?m4ooooo`?oo`3oA?ooool3ool0ob?ooooo0Ol00001ooooo`0000?o
0000ooooooooool07oooool5ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol0
0001ooooo`0000?o0000ooooooooool07oooool5ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5
ool0ob;ooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool5ool0od;ooooo1Ooo0?m2oooo
o`Goo`3o@_ooool5ool0ob;ooooo0Ol00001ooooo`0000?o0000ooooooooool08?ooool3ool0odCo
oooo0ooo0?m4ooooo`?oo`3oA?ooool3ool0ob?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool08?ooool3ool0odCooooo0ooo
0?m4ooooo`?oo`3oA?ooool3ool0ob?ooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool5
ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol00001ooooo`0000?o0000oooo
ooooool07oooool5ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol00001oooo
o`0000?o0000ooooooooool07oooool5ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;o
oooo0Ol00001ooooo`0000?o0000ooooooooool08?ooool3ool0odCooooo0ooo0?m4ooooo`?oo`3o
A?ooool3ool0ob?ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Histograms for two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Compute histograms based on uniform centroids", "Subsubsection"],

Cell[BoxData[{
    \(\(h1\  = Histogram[data1, uniformCentroids, pr, 50];\)\), "\n", 
    \(\(h2\  = Histogram[data2, uniformCentroids, pr, 50];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize two histograms", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gh1\  = 
        DrawHistogram[h1, pr, \ nS, \ 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(gh2\  = 
        DrawHistogram[h2, pr, \ nS, \ 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gh1, gh2}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
%%ImageSize: 400 154.502 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.652 .756 .926 r
.39385 .73851 .40022 .74392 .41088 .74099 .40453 .73557 Mtetra
.40453 .73557 .41088 .74099 .42157 .73806 .41525 .73262 Mtetra
.41525 .73262 .42157 .73806 .43231 .73512 .42602 .72965 Mtetra
.42602 .72965 .43231 .73512 .44309 .73216 .43683 .72667 Mtetra
.43683 .72667 .44309 .73216 .45392 .72919 .44768 .72368 Mtetra
.44768 .72368 .45392 .72919 .46479 .72621 .45858 .72068 Mtetra
.45858 .72068 .46479 .72621 .4757 .72322 .46952 .71766 Mtetra
.46952 .71766 .4757 .72322 .48666 .72022 .4805 .71464 Mtetra
.4805 .71464 .48666 .72022 .49766 .7172 .49153 .7116 Mtetra
.49153 .7116 .49766 .7172 .5087 .71417 .5026 .70855 Mtetra
.5026 .70855 .5087 .71417 .51979 .71113 .51372 .70549 Mtetra
.51372 .70549 .51979 .71113 .53092 .70808 .52489 .70241 Mtetra
.863 .419 .033 r
.52489 .70241 .53092 .70808 .54222 .72988 .53618 .72424 Mtetra
.65 .758 .929 r
.53618 .72424 .54222 .72988 .55353 .72683 .54751 .72117 Mtetra
.54751 .72117 .55353 .72683 .56488 .72377 .55889 .71809 Mtetra
.55889 .71809 .56488 .72377 .57628 .7207 .57032 .71499 Mtetra
.57032 .71499 .57628 .7207 .58772 .71761 .5818 .71188 Mtetra
.5818 .71188 .58772 .71761 .59921 .71451 .59332 .70876 Mtetra
.59332 .70876 .59921 .71451 .61075 .7114 .60489 .70562 Mtetra
.60489 .70562 .61075 .7114 .62234 .70828 .61651 .70247 Mtetra
.61651 .70247 .62234 .70828 .63398 .70514 .62818 .69931 Mtetra
.62818 .69931 .63398 .70514 .64566 .70199 .6399 .69613 Mtetra
.6399 .69613 .64566 .70199 .65739 .69882 .65166 .69295 Mtetra
.65166 .69295 .65739 .69882 .66917 .69565 .66348 .68974 Mtetra
.66348 .68974 .66917 .69565 .681 .69245 .67534 .68653 Mtetra
.964 .709 .499 r
.67534 .68653 .681 .69245 .68478 .51982 .67939 .51353 Mtetra
.664 .741 .908 r
.67939 .51353 .68478 .51982 .69612 .51641 .69076 .5101 Mtetra
.69076 .5101 .69612 .51641 .7075 .513 .70218 .50666 Mtetra
.70218 .50666 .7075 .513 .71893 .50957 .71364 .5032 Mtetra
.71364 .5032 .71893 .50957 .73041 .50613 .72515 .49974 Mtetra
.72515 .49974 .73041 .50613 .74193 .50267 .7367 .49625 Mtetra
.7367 .49625 .74193 .50267 .7535 .4992 .7483 .49276 Mtetra
.7483 .49276 .7535 .4992 .76511 .49572 .75995 .48925 Mtetra
.75995 .48925 .76511 .49572 .77677 .49222 .77165 .48572 Mtetra
.77165 .48572 .77677 .49222 .78848 .48871 .78339 .48218 Mtetra
.78339 .48218 .78848 .48871 .80024 .48518 .79518 .47863 Mtetra
.79518 .47863 .80024 .48518 .81205 .48164 .80702 .47506 Mtetra
.80702 .47506 .81205 .48164 .8239 .47808 .81891 .47148 Mtetra
.81891 .47148 .8239 .47808 .8358 .47451 .83085 .46788 Mtetra
.83085 .46788 .8358 .47451 .84775 .47092 .84283 .46427 Mtetra
.84283 .46427 .84775 .47092 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .45699 Mtetra
.86696 .45699 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.652 .756 .926 r
.38743 .73307 .39385 .73851 .40453 .73557 .39814 .73011 Mtetra
.39814 .73011 .40453 .73557 .41525 .73262 .40889 .72713 Mtetra
.40889 .72713 .41525 .73262 .42602 .72965 .41968 .72414 Mtetra
.41968 .72414 .42602 .72965 .43683 .72667 .43052 .72114 Mtetra
.43052 .72114 .43683 .72667 .44768 .72368 .4414 .71813 Mtetra
.4414 .71813 .44768 .72368 .45858 .72068 .45232 .7151 Mtetra
.45232 .7151 .45858 .72068 .46952 .71766 .46329 .71207 Mtetra
.46329 .71207 .46952 .71766 .4805 .71464 .4743 .70902 Mtetra
.4743 .70902 .4805 .71464 .49153 .7116 .48536 .70596 Mtetra
.48536 .70596 .49153 .7116 .5026 .70855 .49646 .70288 Mtetra
.49646 .70288 .5026 .70855 .51372 .70549 .50761 .6998 Mtetra
.50761 .6998 .51372 .70549 .52489 .70241 .5188 .6967 Mtetra
.863 .419 .033 r
.5188 .6967 .52489 .70241 .53618 .72424 .53008 .71856 Mtetra
.65 .758 .929 r
.53008 .71856 .53618 .72424 .54751 .72117 .54145 .71547 Mtetra
.54145 .71547 .54751 .72117 .55889 .71809 .55286 .71236 Mtetra
.55286 .71236 .55889 .71809 .57032 .71499 .56432 .70924 Mtetra
.56432 .70924 .57032 .71499 .5818 .71188 .57583 .7061 Mtetra
.57583 .7061 .5818 .71188 .59332 .70876 .58738 .70296 Mtetra
.58738 .70296 .59332 .70876 .60489 .70562 .59898 .6998 Mtetra
.59898 .6998 .60489 .70562 .61651 .70247 .61064 .69662 Mtetra
.61064 .69662 .61651 .70247 .62818 .69931 .62234 .69344 Mtetra
.62234 .69344 .62818 .69931 .6399 .69613 .63409 .69024 Mtetra
.63409 .69024 .6399 .69613 .65166 .69295 .64589 .68702 Mtetra
.64589 .68702 .65166 .69295 .66348 .68974 .65774 .6838 Mtetra
.65774 .6838 .66348 .68974 .67534 .68653 .66964 .68056 Mtetra
.964 .709 .499 r
.66964 .68056 .67534 .68653 .67939 .51353 .67397 .50719 Mtetra
.664 .741 .908 r
.67397 .50719 .67939 .51353 .69076 .5101 .68537 .50374 Mtetra
.68537 .50374 .69076 .5101 .70218 .50666 .69682 .50027 Mtetra
.69682 .50027 .70218 .50666 .71364 .5032 .70831 .49679 Mtetra
.70831 .49679 .71364 .5032 .72515 .49974 .71985 .4933 Mtetra
.71985 .4933 .72515 .49974 .7367 .49625 .73144 .48979 Mtetra
.73144 .48979 .7367 .49625 .7483 .49276 .74307 .48626 Mtetra
.74307 .48626 .7483 .49276 .75995 .48925 .75475 .48273 Mtetra
.75475 .48273 .75995 .48925 .77165 .48572 .76648 .47918 Mtetra
.76648 .47918 .77165 .48572 .78339 .48218 .77826 .47561 Mtetra
.77826 .47561 .78339 .48218 .79518 .47863 .79008 .47203 Mtetra
.79008 .47203 .79518 .47863 .80702 .47506 .80196 .46843 Mtetra
.80196 .46843 .80702 .47506 .81891 .47148 .81388 .46482 Mtetra
.81388 .46482 .81891 .47148 .83085 .46788 .82585 .4612 Mtetra
.82585 .4612 .83085 .46788 .84283 .46427 .83788 .45756 Mtetra
.83788 .45756 .84283 .46427 .85487 .46064 .84995 .4539 Mtetra
.84995 .4539 .85487 .46064 .86696 .45699 .86207 .45023 Mtetra
.86207 .45023 .86696 .45699 .87909 .45334 .87424 .44654 Mtetra
.87424 .44654 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.652 .756 .926 r
.38096 .72759 .38743 .73307 .39814 .73011 .3917 .7246 Mtetra
.3917 .7246 .39814 .73011 .40889 .72713 .40248 .7216 Mtetra
.40248 .7216 .40889 .72713 .41968 .72414 .4133 .71859 Mtetra
.4133 .71859 .41968 .72414 .43052 .72114 .42416 .71557 Mtetra
.42416 .71557 .43052 .72114 .4414 .71813 .43507 .71254 Mtetra
.43507 .71254 .4414 .71813 .45232 .7151 .44602 .70949 Mtetra
.44602 .70949 .45232 .7151 .46329 .71207 .45702 .70643 Mtetra
.45702 .70643 .46329 .71207 .4743 .70902 .46806 .70336 Mtetra
.46806 .70336 .4743 .70902 .48536 .70596 .47915 .70027 Mtetra
.47915 .70027 .48536 .70596 .49646 .70288 .49028 .69718 Mtetra
.49028 .69718 .49646 .70288 .50761 .6998 .50145 .69407 Mtetra
.50145 .69407 .50761 .6998 .5188 .6967 .51268 .69094 Mtetra
.863 .419 .033 r
.51268 .69094 .5188 .6967 .53008 .71856 .52394 .71284 Mtetra
.65 .758 .929 r
.52394 .71284 .53008 .71856 .54145 .71547 .53534 .70972 Mtetra
.53534 .70972 .54145 .71547 .55286 .71236 .54678 .70659 Mtetra
.54678 .70659 .55286 .71236 .56432 .70924 .55827 .70344 Mtetra
.55827 .70344 .56432 .70924 .57583 .7061 .56981 .70028 Mtetra
.56981 .70028 .57583 .7061 .58738 .70296 .5814 .69711 Mtetra
.5814 .69711 .58738 .70296 .59898 .6998 .59303 .69393 Mtetra
.59303 .69393 .59898 .6998 .61064 .69662 .60472 .69073 Mtetra
.60472 .69073 .61064 .69662 .62234 .69344 .61645 .68752 Mtetra
.61645 .68752 .62234 .69344 .63409 .69024 .62823 .6843 Mtetra
.62823 .6843 .63409 .69024 .64589 .68702 .64007 .68106 Mtetra
.64007 .68106 .64589 .68702 .65774 .6838 .65195 .6778 Mtetra
.65195 .6778 .65774 .6838 .66964 .68056 .66388 .67454 Mtetra
.964 .709 .499 r
.66388 .67454 .66964 .68056 .67397 .50719 .6685 .5008 Mtetra
.664 .741 .908 r
.6685 .5008 .67397 .50719 .68537 .50374 .67993 .49733 Mtetra
.67993 .49733 .68537 .50374 .69682 .50027 .69141 .49383 Mtetra
.69141 .49383 .69682 .50027 .70831 .49679 .70294 .49033 Mtetra
.70294 .49033 .70831 .49679 .71985 .4933 .71451 .48681 Mtetra
.71451 .48681 .71985 .4933 .73144 .48979 .72613 .48327 Mtetra
.72613 .48327 .73144 .48979 .74307 .48626 .7378 .47972 Mtetra
.7378 .47972 .74307 .48626 .75475 .48273 .74951 .47616 Mtetra
.74951 .47616 .75475 .48273 .76648 .47918 .76127 .47258 Mtetra
.76127 .47258 .76648 .47918 .77826 .47561 .77309 .46899 Mtetra
.77309 .46899 .77826 .47561 .79008 .47203 .78495 .46538 Mtetra
.78495 .46538 .79008 .47203 .80196 .46843 .79686 .46176 Mtetra
.79686 .46176 .80196 .46843 .81388 .46482 .80881 .45812 Mtetra
.80881 .45812 .81388 .46482 .82585 .4612 .82082 .45446 Mtetra
.82082 .45446 .82585 .4612 .83788 .45756 .83288 .4508 Mtetra
.83288 .4508 .83788 .45756 .84995 .4539 .84499 .44711 Mtetra
.84499 .44711 .84995 .4539 .86207 .45023 .85715 .44341 Mtetra
.85715 .44341 .86207 .45023 .87424 .44654 .86936 .4397 Mtetra
.86936 .4397 .87424 .44654 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.652 .756 .926 r
.37445 .72207 .38096 .72759 .3917 .7246 .38521 .71906 Mtetra
.38521 .71906 .3917 .7246 .40248 .7216 .39602 .71604 Mtetra
.39602 .71604 .40248 .7216 .4133 .71859 .40686 .713 Mtetra
.40686 .713 .4133 .71859 .42416 .71557 .41775 .70996 Mtetra
.41775 .70996 .42416 .71557 .43507 .71254 .42869 .7069 Mtetra
.42869 .7069 .43507 .71254 .44602 .70949 .43967 .70383 Mtetra
.43967 .70383 .44602 .70949 .45702 .70643 .4507 .70075 Mtetra
.4507 .70075 .45702 .70643 .46806 .70336 .46177 .69765 Mtetra
.46177 .69765 .46806 .70336 .47915 .70027 .47288 .69455 Mtetra
.47288 .69455 .47915 .70027 .49028 .69718 .48404 .69142 Mtetra
.48404 .69142 .49028 .69718 .50145 .69407 .49525 .68829 Mtetra
.49525 .68829 .50145 .69407 .51268 .69094 .5065 .68515 Mtetra
.863 .419 .033 r
.5065 .68515 .51268 .69094 .52394 .71284 .51775 .70707 Mtetra
.65 .758 .929 r
.51775 .70707 .52394 .71284 .53534 .70972 .52918 .70393 Mtetra
.52918 .70393 .53534 .70972 .54678 .70659 .54065 .70077 Mtetra
.54065 .70077 .54678 .70659 .55827 .70344 .55218 .6976 Mtetra
.55218 .6976 .55827 .70344 .56981 .70028 .56375 .69442 Mtetra
.56375 .69442 .56981 .70028 .5814 .69711 .57537 .69122 Mtetra
.57537 .69122 .5814 .69711 .59303 .69393 .58703 .68801 Mtetra
.58703 .68801 .59303 .69393 .60472 .69073 .59875 .68479 Mtetra
.59875 .68479 .60472 .69073 .61645 .68752 .61052 .68156 Mtetra
.61052 .68156 .61645 .68752 .62823 .6843 .62234 .67831 Mtetra
.62234 .67831 .62823 .6843 .64007 .68106 .6342 .67504 Mtetra
.6342 .67504 .64007 .68106 .65195 .6778 .64612 .67176 Mtetra
.64612 .67176 .65195 .6778 .66388 .67454 .65809 .66847 Mtetra
.964 .709 .499 r
.65809 .66847 .66388 .67454 .6685 .5008 .663 .49437 Mtetra
.664 .741 .908 r
.663 .49437 .6685 .5008 .67993 .49733 .67446 .49087 Mtetra
.67446 .49087 .67993 .49733 .69141 .49383 .68597 .48735 Mtetra
.68597 .48735 .69141 .49383 .70294 .49033 .69753 .48382 Mtetra
.69753 .48382 .70294 .49033 .71451 .48681 .70913 .48027 Mtetra
.70913 .48027 .71451 .48681 .72613 .48327 .72078 .47671 Mtetra
.72078 .47671 .72613 .48327 .7378 .47972 .73248 .47313 Mtetra
.73248 .47313 .7378 .47972 .74951 .47616 .74423 .46954 Mtetra
.74423 .46954 .74951 .47616 .76127 .47258 .75603 .46593 Mtetra
.75603 .46593 .76127 .47258 .77309 .46899 .76788 .46231 Mtetra
.76788 .46231 .77309 .46899 .78495 .46538 .77977 .45868 Mtetra
.77977 .45868 .78495 .46538 .79686 .46176 .79171 .45503 Mtetra
.79171 .45503 .79686 .46176 .80881 .45812 .80371 .45136 Mtetra
.80371 .45136 .80881 .45812 .82082 .45446 .81575 .44768 Mtetra
.81575 .44768 .82082 .45446 .83288 .4508 .82785 .44398 Mtetra
.82785 .44398 .83288 .4508 .84499 .44711 .83999 .44027 Mtetra
.83999 .44027 .84499 .44711 .85715 .44341 .85219 .43654 Mtetra
.85219 .43654 .85715 .44341 .86936 .4397 .86443 .4328 Mtetra
.86443 .4328 .86936 .4397 .88162 .43597 .87673 .42904 Mtetra
.87673 .42904 .88162 .43597 .89393 .43222 .88908 .42526 Mtetra
.88908 .42526 .89393 .43222 .9063 .42846 .90148 .42147 Mtetra
.90148 .42147 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.652 .756 .926 r
.36789 .7165 .37445 .72207 .38521 .71906 .37868 .71347 Mtetra
.37868 .71347 .38521 .71906 .39602 .71604 .38951 .71043 Mtetra
.38951 .71043 .39602 .71604 .40686 .713 .40038 .70737 Mtetra
.40038 .70737 .40686 .713 .41775 .70996 .4113 .7043 Mtetra
.4113 .7043 .41775 .70996 .42869 .7069 .42227 .70122 Mtetra
.42227 .70122 .42869 .7069 .43967 .70383 .43327 .69813 Mtetra
.43327 .69813 .43967 .70383 .4507 .70075 .44433 .69502 Mtetra
.44433 .69502 .4507 .70075 .46177 .69765 .45543 .69191 Mtetra
.45543 .69191 .46177 .69765 .47288 .69455 .46657 .68877 Mtetra
.46657 .68877 .47288 .69455 .48404 .69142 .47776 .68563 Mtetra
.47776 .68563 .48404 .69142 .49525 .68829 .489 .68247 Mtetra
.489 .68247 .49525 .68829 .5065 .68515 .50028 .6793 Mtetra
.863 .419 .033 r
.50028 .6793 .5065 .68515 .51775 .70707 .51151 .70126 Mtetra
.65 .758 .929 r
.51151 .70126 .51775 .70707 .52918 .70393 .52297 .69809 Mtetra
.52297 .69809 .52918 .70393 .54065 .70077 .53448 .69491 Mtetra
.53448 .69491 .54065 .70077 .55218 .6976 .54603 .69172 Mtetra
.54603 .69172 .55218 .6976 .56375 .69442 .55764 .68851 Mtetra
.55764 .68851 .56375 .69442 .57537 .69122 .56929 .68529 Mtetra
.56929 .68529 .57537 .69122 .58703 .68801 .58099 .68205 Mtetra
.58099 .68205 .58703 .68801 .59875 .68479 .59274 .67881 Mtetra
.59274 .67881 .59875 .68479 .61052 .68156 .60454 .67555 Mtetra
.60454 .67555 .61052 .68156 .62234 .67831 .61639 .67227 Mtetra
.61639 .67227 .62234 .67831 .6342 .67504 .62829 .66898 Mtetra
.62829 .66898 .6342 .67504 .64612 .67176 .64024 .66568 Mtetra
.64024 .66568 .64612 .67176 .65809 .66847 .65225 .66236 Mtetra
.964 .709 .499 r
.65225 .66236 .65809 .66847 .663 .49437 .65745 .48789 Mtetra
.664 .741 .908 r
.65745 .48789 .663 .49437 .67446 .49087 .66894 .48436 Mtetra
.66894 .48436 .67446 .49087 .68597 .48735 .68049 .48082 Mtetra
.68049 .48082 .68597 .48735 .69753 .48382 .69208 .47726 Mtetra
.69208 .47726 .69753 .48382 .70913 .48027 .70371 .47368 Mtetra
.70371 .47368 .70913 .48027 .72078 .47671 .7154 .47009 Mtetra
.7154 .47009 .72078 .47671 .73248 .47313 .72713 .46649 Mtetra
.72713 .46649 .73248 .47313 .74423 .46954 .73891 .46287 Mtetra
.73891 .46287 .74423 .46954 .75603 .46593 .75075 .45924 Mtetra
.75075 .45924 .75603 .46593 .76788 .46231 .76263 .45559 Mtetra
.76263 .45559 .76788 .46231 .77977 .45868 .77455 .45193 Mtetra
.77455 .45193 .77977 .45868 .79171 .45503 .78653 .44825 Mtetra
.78653 .44825 .79171 .45503 .80371 .45136 .79856 .44455 Mtetra
.79856 .44455 .80371 .45136 .81575 .44768 .81064 .44084 Mtetra
.81064 .44084 .81575 .44768 .82785 .44398 .82277 .43712 Mtetra
.82277 .43712 .82785 .44398 .83999 .44027 .83495 .43338 Mtetra
.83495 .43338 .83999 .44027 .85219 .43654 .84719 .42962 Mtetra
.84719 .42962 .85219 .43654 .86443 .4328 .85947 .42585 Mtetra
.85947 .42585 .86443 .4328 .87673 .42904 .87181 .42206 Mtetra
.87181 .42206 .87673 .42904 .88908 .42526 .88419 .41825 Mtetra
.88419 .41825 .88908 .42526 .90148 .42147 .89664 .41443 Mtetra
.89664 .41443 .90148 .42147 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.652 .756 .926 r
.36128 .7109 .36789 .7165 .37868 .71347 .37209 .70784 Mtetra
.37209 .70784 .37868 .71347 .38951 .71043 .38295 .70478 Mtetra
.38295 .70478 .38951 .71043 .40038 .70737 .39385 .7017 Mtetra
.39385 .7017 .40038 .70737 .4113 .7043 .4048 .69861 Mtetra
.4048 .69861 .4113 .7043 .42227 .70122 .41579 .6955 Mtetra
.41579 .6955 .42227 .70122 .43327 .69813 .42683 .69239 Mtetra
.42683 .69239 .43327 .69813 .44433 .69502 .43791 .68926 Mtetra
.43791 .68926 .44433 .69502 .45543 .69191 .44904 .68611 Mtetra
.44904 .68611 .45543 .69191 .46657 .68877 .46021 .68296 Mtetra
.46021 .68296 .46657 .68877 .47776 .68563 .47143 .67979 Mtetra
.47143 .67979 .47776 .68563 .489 .68247 .4827 .67661 Mtetra
.4827 .67661 .489 .68247 .50028 .6793 .49401 .67342 Mtetra
.863 .419 .033 r
.49401 .67342 .50028 .6793 .51151 .70126 .50523 .6954 Mtetra
.65 .758 .929 r
.50523 .6954 .51151 .70126 .52297 .69809 .51672 .69221 Mtetra
.51672 .69221 .52297 .69809 .53448 .69491 .52826 .689 Mtetra
.52826 .689 .53448 .69491 .54603 .69172 .53984 .68579 Mtetra
.53984 .68579 .54603 .69172 .55764 .68851 .55148 .68255 Mtetra
.55148 .68255 .55764 .68851 .56929 .68529 .56316 .67931 Mtetra
.56316 .67931 .56929 .68529 .58099 .68205 .5749 .67605 Mtetra
.5749 .67605 .58099 .68205 .59274 .67881 .58668 .67277 Mtetra
.58668 .67277 .59274 .67881 .60454 .67555 .59851 .66949 Mtetra
.59851 .66949 .60454 .67555 .61639 .67227 .6104 .66619 Mtetra
.6104 .66619 .61639 .67227 .62829 .66898 .62233 .66287 Mtetra
.62233 .66287 .62829 .66898 .64024 .66568 .63432 .65954 Mtetra
.63432 .65954 .64024 .66568 .65225 .66236 .64636 .6562 Mtetra
.964 .709 .499 r
.64636 .6562 .65225 .66236 .65745 .48789 .65186 .48136 Mtetra
.664 .741 .908 r
.65186 .48136 .65745 .48789 .66894 .48436 .66338 .47781 Mtetra
.66338 .47781 .66894 .48436 .68049 .48082 .67496 .47423 Mtetra
.67496 .47423 .68049 .48082 .69208 .47726 .68658 .47065 Mtetra
.68658 .47065 .69208 .47726 .70371 .47368 .69825 .46705 Mtetra
.69825 .46705 .70371 .47368 .7154 .47009 .70997 .46343 Mtetra
.70997 .46343 .7154 .47009 .72713 .46649 .72174 .4598 Mtetra
.72174 .4598 .72713 .46649 .73891 .46287 .73355 .45615 Mtetra
.73355 .45615 .73891 .46287 .75075 .45924 .74542 .45249 Mtetra
.74542 .45249 .75075 .45924 .76263 .45559 .75733 .44881 Mtetra
.75733 .44881 .76263 .45559 .77455 .45193 .7693 .44512 Mtetra
.7693 .44512 .77455 .45193 .78653 .44825 .78131 .44141 Mtetra
.78131 .44141 .78653 .44825 .79856 .44455 .79338 .43769 Mtetra
.79338 .43769 .79856 .44455 .81064 .44084 .80549 .43395 Mtetra
.80549 .43395 .81064 .44084 .82277 .43712 .81766 .4302 Mtetra
.81766 .4302 .82277 .43712 .83495 .43338 .82988 .42643 Mtetra
.82988 .42643 .83495 .43338 .84719 .42962 .84215 .42264 Mtetra
.84215 .42264 .84719 .42962 .85947 .42585 .85447 .41884 Mtetra
.85447 .41884 .85947 .42585 .87181 .42206 .86684 .41502 Mtetra
.86684 .41502 .87181 .42206 .88419 .41825 .87927 .41119 Mtetra
.87927 .41119 .88419 .41825 .89664 .41443 .89175 .40734 Mtetra
.89175 .40734 .89664 .41443 .90913 .4106 .90428 .40347 Mtetra
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39958 Mtetra
.91687 .39958 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.652 .756 .926 r
.35462 .70525 .36128 .7109 .37209 .70784 .36546 .70217 Mtetra
.36546 .70217 .37209 .70784 .38295 .70478 .37634 .69908 Mtetra
.37634 .69908 .38295 .70478 .39385 .7017 .38727 .69598 Mtetra
.38727 .69598 .39385 .7017 .4048 .69861 .39825 .69287 Mtetra
.39825 .69287 .4048 .69861 .41579 .6955 .40927 .68974 Mtetra
.40927 .68974 .41579 .6955 .42683 .69239 .42033 .6866 Mtetra
.42033 .6866 .42683 .69239 .43791 .68926 .43144 .68345 Mtetra
.43144 .68345 .43791 .68926 .44904 .68611 .4426 .68028 Mtetra
.4426 .68028 .44904 .68611 .46021 .68296 .4538 .6771 Mtetra
.4538 .6771 .46021 .68296 .47143 .67979 .46505 .67391 Mtetra
.46505 .67391 .47143 .67979 .4827 .67661 .47635 .6707 Mtetra
.47635 .6707 .4827 .67661 .49401 .67342 .48769 .66748 Mtetra
.863 .419 .033 r
.48769 .66748 .49401 .67342 .50523 .6954 .4989 .6895 Mtetra
.65 .758 .929 r
.4989 .6895 .50523 .6954 .51672 .69221 .51042 .68628 Mtetra
.51042 .68628 .51672 .69221 .52826 .689 .52199 .68305 Mtetra
.52199 .68305 .52826 .689 .53984 .68579 .53361 .67981 Mtetra
.53361 .67981 .53984 .68579 .55148 .68255 .54527 .67655 Mtetra
.54527 .67655 .55148 .68255 .56316 .67931 .55699 .67328 Mtetra
.55699 .67328 .56316 .67931 .5749 .67605 .56876 .66999 Mtetra
.56876 .66999 .5749 .67605 .58668 .67277 .58057 .66669 Mtetra
.58057 .66669 .58668 .67277 .59851 .66949 .59244 .66338 Mtetra
.59244 .66338 .59851 .66949 .6104 .66619 .60436 .66005 Mtetra
.60436 .66005 .6104 .66619 .62233 .66287 .61633 .65671 Mtetra
.61633 .65671 .62233 .66287 .63432 .65954 .62835 .65336 Mtetra
.62835 .65336 .63432 .65954 .64636 .6562 .64042 .64999 Mtetra
.964 .709 .499 r
.64042 .64999 .64636 .6562 .65186 .48136 .64622 .47478 Mtetra
.664 .741 .908 r
.64622 .47478 .65186 .48136 .66338 .47781 .65778 .4712 Mtetra
.65778 .4712 .66338 .47781 .67496 .47423 .66939 .4676 Mtetra
.66939 .4676 .67496 .47423 .68658 .47065 .68105 .46399 Mtetra
.68105 .46399 .68658 .47065 .69825 .46705 .69275 .46036 Mtetra
.69275 .46036 .69825 .46705 .70997 .46343 .7045 .45671 Mtetra
.7045 .45671 .70997 .46343 .72174 .4598 .7163 .45306 Mtetra
.7163 .45306 .72174 .4598 .73355 .45615 .72815 .44938 Mtetra
.72815 .44938 .73355 .45615 .74542 .45249 .74005 .44569 Mtetra
.74005 .44569 .74542 .45249 .75733 .44881 .752 .44199 Mtetra
.752 .44199 .75733 .44881 .7693 .44512 .764 .43827 Mtetra
.764 .43827 .7693 .44512 .78131 .44141 .77605 .43453 Mtetra
.77605 .43453 .78131 .44141 .79338 .43769 .78815 .43078 Mtetra
.78815 .43078 .79338 .43769 .80549 .43395 .8003 .42701 Mtetra
.8003 .42701 .80549 .43395 .81766 .4302 .81251 .42323 Mtetra
.81251 .42323 .81766 .4302 .82988 .42643 .82476 .41943 Mtetra
.82476 .41943 .82988 .42643 .84215 .42264 .83707 .41561 Mtetra
.83707 .41561 .84215 .42264 .85447 .41884 .84943 .41178 Mtetra
.84943 .41178 .85447 .41884 .86684 .41502 .86184 .40793 Mtetra
.86184 .40793 .86684 .41502 .87927 .41119 .8743 .40406 Mtetra
.8743 .40406 .87927 .41119 .89175 .40734 .88682 .40018 Mtetra
.88682 .40018 .89175 .40734 .90428 .40347 .89939 .39628 Mtetra
.89939 .39628 .90428 .40347 .91687 .39958 .91202 .39237 Mtetra
.91202 .39237 .91687 .39958 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.652 .756 .926 r
.3479 .69956 .35462 .70525 .36546 .70217 .35877 .69646 Mtetra
.35877 .69646 .36546 .70217 .37634 .69908 .36969 .69335 Mtetra
.36969 .69335 .37634 .69908 .38727 .69598 .38064 .69022 Mtetra
.38064 .69022 .38727 .69598 .39825 .69287 .39165 .68708 Mtetra
.39165 .68708 .39825 .69287 .40927 .68974 .4027 .68393 Mtetra
.4027 .68393 .40927 .68974 .42033 .6866 .41379 .68077 Mtetra
.41379 .68077 .42033 .6866 .43144 .68345 .42493 .67759 Mtetra
.42493 .67759 .43144 .68345 .4426 .68028 .43612 .6744 Mtetra
.43612 .6744 .4426 .68028 .4538 .6771 .44735 .6712 Mtetra
.44735 .6712 .4538 .6771 .46505 .67391 .45863 .66798 Mtetra
.45863 .66798 .46505 .67391 .47635 .6707 .46995 .66475 Mtetra
.46995 .66475 .47635 .6707 .48769 .66748 .48133 .6615 Mtetra
.863 .419 .033 r
.48133 .6615 .48769 .66748 .4989 .6895 .49251 .68355 Mtetra
.65 .758 .929 r
.49251 .68355 .4989 .6895 .51042 .68628 .50407 .68031 Mtetra
.50407 .68031 .51042 .68628 .52199 .68305 .51567 .67705 Mtetra
.51567 .67705 .52199 .68305 .53361 .67981 .52732 .67378 Mtetra
.52732 .67378 .53361 .67981 .54527 .67655 .53902 .6705 Mtetra
.53902 .6705 .54527 .67655 .55699 .67328 .55077 .6672 Mtetra
.55077 .6672 .55699 .67328 .56876 .66999 .56257 .66389 Mtetra
.56257 .66389 .56876 .66999 .58057 .66669 .57442 .66057 Mtetra
.57442 .66057 .58057 .66669 .59244 .66338 .58632 .65723 Mtetra
.58632 .65723 .59244 .66338 .60436 .66005 .59827 .65387 Mtetra
.59827 .65387 .60436 .66005 .61633 .65671 .61028 .65051 Mtetra
.61028 .65051 .61633 .65671 .62835 .65336 .62233 .64712 Mtetra
.62233 .64712 .62835 .65336 .64042 .64999 .63444 .64372 Mtetra
.964 .709 .499 r
.63444 .64372 .64042 .64999 .64622 .47478 .64055 .46816 Mtetra
.664 .741 .908 r
.64055 .46816 .64622 .47478 .65778 .4712 .65214 .46454 Mtetra
.65214 .46454 .65778 .4712 .66939 .4676 .66378 .46092 Mtetra
.66378 .46092 .66939 .4676 .68105 .46399 .67547 .45728 Mtetra
.67547 .45728 .68105 .46399 .69275 .46036 .68721 .45362 Mtetra
.68721 .45362 .69275 .46036 .7045 .45671 .69899 .44995 Mtetra
.69899 .44995 .7045 .45671 .7163 .45306 .71083 .44626 Mtetra
.71083 .44626 .7163 .45306 .72815 .44938 .72271 .44256 Mtetra
.72271 .44256 .72815 .44938 .74005 .44569 .73465 .43884 Mtetra
.73465 .43884 .74005 .44569 .752 .44199 .74663 .4351 Mtetra
.74663 .4351 .752 .44199 .764 .43827 .75866 .43136 Mtetra
.75866 .43136 .764 .43827 .77605 .43453 .77075 .42759 Mtetra
.77075 .42759 .77605 .43453 .78815 .43078 .78289 .42381 Mtetra
.78289 .42381 .78815 .43078 .8003 .42701 .79507 .42001 Mtetra
.79507 .42001 .8003 .42701 .81251 .42323 .80731 .4162 Mtetra
.80731 .4162 .81251 .42323 .82476 .41943 .81961 .41237 Mtetra
.81961 .41237 .82476 .41943 .83707 .41561 .83195 .40852 Mtetra
.83195 .40852 .83707 .41561 .84943 .41178 .84435 .40466 Mtetra
.84435 .40466 .84943 .41178 .86184 .40793 .8568 .40078 Mtetra
.8568 .40078 .86184 .40793 .8743 .40406 .8693 .39689 Mtetra
.8693 .39689 .8743 .40406 .88682 .40018 .88186 .39297 Mtetra
.88186 .39297 .88682 .40018 .89939 .39628 .89447 .38904 Mtetra
.89447 .38904 .89939 .39628 .91202 .39237 .90713 .3851 Mtetra
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37715 Mtetra
.652 .756 .926 r
.34114 .69383 .3479 .69956 .35877 .69646 .35204 .6907 Mtetra
.35204 .6907 .35877 .69646 .36969 .69335 .36298 .68757 Mtetra
.36298 .68757 .36969 .69335 .38064 .69022 .37397 .68442 Mtetra
.37397 .68442 .38064 .69022 .39165 .68708 .385 .68126 Mtetra
.385 .68126 .39165 .68708 .4027 .68393 .39607 .67808 Mtetra
.39607 .67808 .4027 .68393 .41379 .68077 .4072 .67489 Mtetra
.4072 .67489 .41379 .68077 .42493 .67759 .41836 .67169 Mtetra
.41836 .67169 .42493 .67759 .43612 .6744 .42958 .66848 Mtetra
.42958 .66848 .43612 .6744 .44735 .6712 .44084 .66525 Mtetra
.44084 .66525 .44735 .6712 .45863 .66798 .45215 .662 Mtetra
.45215 .662 .45863 .66798 .46995 .66475 .46351 .65875 Mtetra
.46351 .65875 .46995 .66475 .48133 .6615 .47491 .65548 Mtetra
.863 .419 .033 r
.47491 .65548 .48133 .6615 .49251 .68355 .48608 .67755 Mtetra
.65 .758 .929 r
.48608 .67755 .49251 .68355 .50407 .68031 .49767 .67429 Mtetra
.49767 .67429 .50407 .68031 .51567 .67705 .5093 .67101 Mtetra
.5093 .67101 .51567 .67705 .52732 .67378 .52098 .66771 Mtetra
.52098 .66771 .52732 .67378 .53902 .6705 .53271 .6644 Mtetra
.53271 .6644 .53902 .6705 .55077 .6672 .5445 .66108 Mtetra
.5445 .66108 .55077 .6672 .56257 .66389 .55633 .65774 Mtetra
.55633 .65774 .56257 .66389 .57442 .66057 .56821 .65439 Mtetra
.56821 .65439 .57442 .66057 .58632 .65723 .58015 .65102 Mtetra
.58015 .65102 .58632 .65723 .59827 .65387 .59214 .64764 Mtetra
.59214 .64764 .59827 .65387 .61028 .65051 .60417 .64425 Mtetra
.60417 .64425 .61028 .65051 .62233 .64712 .61626 .64084 Mtetra
.61626 .64084 .62233 .64712 .63444 .64372 .62841 .63741 Mtetra
.964 .709 .499 r
.62841 .63741 .63444 .64372 .64055 .46816 .63483 .46148 Mtetra
.664 .741 .908 r
.63483 .46148 .64055 .46816 .65214 .46454 .64645 .45784 Mtetra
.64645 .45784 .65214 .46454 .66378 .46092 .65813 .45418 Mtetra
.65813 .45418 .66378 .46092 .67547 .45728 .66985 .45051 Mtetra
.66985 .45051 .67547 .45728 .68721 .45362 .68162 .44683 Mtetra
.68162 .44683 .68721 .45362 .69899 .44995 .69344 .44313 Mtetra
.69344 .44313 .69899 .44995 .71083 .44626 .70531 .43941 Mtetra
.70531 .43941 .71083 .44626 .72271 .44256 .71723 .43568 Mtetra
.71723 .43568 .72271 .44256 .73465 .43884 .7292 .43193 Mtetra
.7292 .43193 .73465 .43884 .74663 .4351 .74122 .42817 Mtetra
.74122 .42817 .74663 .4351 .75866 .43136 .75329 .42439 Mtetra
.75329 .42439 .75866 .43136 .77075 .42759 .76541 .4206 Mtetra
.76541 .4206 .77075 .42759 .78289 .42381 .77758 .41679 Mtetra
.77758 .41679 .78289 .42381 .79507 .42001 .7898 .41296 Mtetra
.7898 .41296 .79507 .42001 .80731 .4162 .80208 .40912 Mtetra
.80208 .40912 .80731 .4162 .81961 .41237 .81441 .40526 Mtetra
.81441 .40526 .81961 .41237 .83195 .40852 .82679 .40138 Mtetra
.82679 .40138 .83195 .40852 .84435 .40466 .83923 .39749 Mtetra
.83923 .39749 .84435 .40466 .8568 .40078 .85171 .39358 Mtetra
.85171 .39358 .8568 .40078 .8693 .39689 .86426 .38965 Mtetra
.86426 .38965 .8693 .39689 .88186 .39297 .87685 .38571 Mtetra
.87685 .38571 .88186 .39297 .89447 .38904 .8895 .38175 Mtetra
.8895 .38175 .89447 .38904 .90713 .3851 .90221 .37777 Mtetra
.90221 .37777 .90713 .3851 .91985 .38114 .91497 .37377 Mtetra
.91497 .37377 .91985 .38114 .93263 .37715 .92778 .36976 Mtetra
.652 .756 .926 r
.33433 .68805 .34114 .69383 .35204 .6907 .34525 .6849 Mtetra
.34525 .6849 .35204 .6907 .36298 .68757 .35622 .68174 Mtetra
.35622 .68174 .36298 .68757 .37397 .68442 .36723 .67857 Mtetra
.36723 .67857 .37397 .68442 .385 .68126 .37829 .67538 Mtetra
.37829 .67538 .385 .68126 .39607 .67808 .3894 .67218 Mtetra
.3894 .67218 .39607 .67808 .4072 .67489 .40055 .66897 Mtetra
.40055 .66897 .4072 .67489 .41836 .67169 .41175 .66574 Mtetra
.41175 .66574 .41836 .67169 .42958 .66848 .42299 .6625 Mtetra
.42299 .6625 .42958 .66848 .44084 .66525 .43429 .65925 Mtetra
.43429 .65925 .44084 .66525 .45215 .662 .44562 .65598 Mtetra
.44562 .65598 .45215 .662 .46351 .65875 .45701 .6527 Mtetra
.45701 .6527 .46351 .65875 .47491 .65548 .46845 .64941 Mtetra
.863 .419 .033 r
.46845 .64941 .47491 .65548 .48608 .67755 .4796 .67151 Mtetra
.65 .758 .929 r
.4796 .67151 .48608 .67755 .49767 .67429 .49122 .66822 Mtetra
.49122 .66822 .49767 .67429 .5093 .67101 .50288 .66491 Mtetra
.50288 .66491 .5093 .67101 .52098 .66771 .5146 .66159 Mtetra
.5146 .66159 .52098 .66771 .53271 .6644 .52636 .65826 Mtetra
.52636 .65826 .53271 .6644 .5445 .66108 .53818 .65491 Mtetra
.53818 .65491 .5445 .66108 .55633 .65774 .55004 .65154 Mtetra
.55004 .65154 .55633 .65774 .56821 .65439 .56196 .64816 Mtetra
.56196 .64816 .56821 .65439 .58015 .65102 .57393 .64477 Mtetra
.57393 .64477 .58015 .65102 .59214 .64764 .58595 .64136 Mtetra
.58595 .64136 .59214 .64764 .60417 .64425 .59802 .63794 Mtetra
.59802 .63794 .60417 .64425 .61626 .64084 .61015 .6345 Mtetra
.61015 .6345 .61626 .64084 .62841 .63741 .62233 .63105 Mtetra
.964 .709 .499 r
.62233 .63105 .62841 .63741 .63483 .46148 .62907 .45475 Mtetra
.664 .741 .908 r
.62907 .45475 .63483 .46148 .64645 .45784 .64072 .45108 Mtetra
.64072 .45108 .64645 .45784 .65813 .45418 .65243 .4474 Mtetra
.65243 .4474 .65813 .45418 .66985 .45051 .66418 .4437 Mtetra
.66418 .4437 .66985 .45051 .68162 .44683 .67599 .43998 Mtetra
.67599 .43998 .68162 .44683 .69344 .44313 .68784 .43626 Mtetra
.68784 .43626 .69344 .44313 .70531 .43941 .69975 .43251 Mtetra
.69975 .43251 .70531 .43941 .71723 .43568 .7117 .42875 Mtetra
.7117 .42875 .71723 .43568 .7292 .43193 .7237 .42497 Mtetra
.7237 .42497 .7292 .43193 .74122 .42817 .73576 .42118 Mtetra
.73576 .42118 .74122 .42817 .75329 .42439 .74786 .41737 Mtetra
.74786 .41737 .75329 .42439 .76541 .4206 .76002 .41355 Mtetra
.76002 .41355 .76541 .4206 .77758 .41679 .77223 .40971 Mtetra
.77223 .40971 .77758 .41679 .7898 .41296 .78449 .40585 Mtetra
.78449 .40585 .7898 .41296 .80208 .40912 .79681 .40198 Mtetra
.79681 .40198 .80208 .40912 .81441 .40526 .80917 .39809 Mtetra
.80917 .39809 .81441 .40526 .82679 .40138 .82159 .39418 Mtetra
.82159 .39418 .82679 .40138 .83923 .39749 .83406 .39025 Mtetra
.83406 .39025 .83923 .39749 .85171 .39358 .84659 .38631 Mtetra
.84659 .38631 .85171 .39358 .86426 .38965 .85917 .38236 Mtetra
.85917 .38236 .86426 .38965 .87685 .38571 .87181 .37838 Mtetra
.87181 .37838 .87685 .38571 .8895 .38175 .8845 .37439 Mtetra
.8845 .37439 .8895 .38175 .90221 .37777 .89724 .37038 Mtetra
.89724 .37038 .90221 .37777 .91497 .37377 .91004 .36635 Mtetra
.91004 .36635 .91497 .37377 .92778 .36976 .9229 .36231 Mtetra
.652 .756 .926 r
.32746 .68223 .33433 .68805 .34525 .6849 .33841 .67906 Mtetra
.33841 .67906 .34525 .6849 .35622 .68174 .34941 .67587 Mtetra
.34941 .67587 .35622 .68174 .36723 .67857 .36045 .67268 Mtetra
.36045 .67268 .36723 .67857 .37829 .67538 .37154 .66947 Mtetra
.37154 .66947 .37829 .67538 .3894 .67218 .38267 .66624 Mtetra
.38267 .66624 .3894 .67218 .40055 .66897 .39386 .663 Mtetra
.39386 .663 .40055 .66897 .41175 .66574 .40508 .65975 Mtetra
.40508 .65975 .41175 .66574 .42299 .6625 .41636 .65649 Mtetra
.41636 .65649 .42299 .6625 .43429 .65925 .42768 .65321 Mtetra
.42768 .65321 .43429 .65925 .44562 .65598 .43905 .64992 Mtetra
.43905 .64992 .44562 .65598 .45701 .6527 .45046 .64661 Mtetra
.45046 .64661 .45701 .6527 .46845 .64941 .46193 .64329 Mtetra
.863 .419 .033 r
.46193 .64329 .46845 .64941 .4796 .67151 .47307 .66542 Mtetra
.65 .758 .929 r
.47307 .66542 .4796 .67151 .49122 .66822 .48471 .6621 Mtetra
.48471 .6621 .49122 .66822 .50288 .66491 .49641 .65877 Mtetra
.49641 .65877 .50288 .66491 .5146 .66159 .50816 .65542 Mtetra
.50816 .65542 .5146 .66159 .52636 .65826 .51996 .65206 Mtetra
.51996 .65206 .52636 .65826 .53818 .65491 .5318 .64869 Mtetra
.5318 .64869 .53818 .65491 .55004 .65154 .54371 .64529 Mtetra
.54371 .64529 .55004 .65154 .56196 .64816 .55566 .64189 Mtetra
.55566 .64189 .56196 .64816 .57393 .64477 .56766 .63847 Mtetra
.56766 .63847 .57393 .64477 .58595 .64136 .57972 .63503 Mtetra
.57972 .63503 .58595 .64136 .59802 .63794 .59182 .63158 Mtetra
.59182 .63158 .59802 .63794 .61015 .6345 .60399 .62812 Mtetra
.60399 .62812 .61015 .6345 .62233 .63105 .6162 .62464 Mtetra
.964 .709 .499 r
.6162 .62464 .62233 .63105 .62907 .45475 .62326 .44796 Mtetra
.664 .741 .908 r
.62326 .44796 .62907 .45475 .64072 .45108 .63495 .44427 Mtetra
.63495 .44427 .64072 .45108 .65243 .4474 .64669 .44056 Mtetra
.64669 .44056 .65243 .4474 .66418 .4437 .65848 .43683 Mtetra
.65848 .43683 .66418 .4437 .67599 .43998 .67031 .43309 Mtetra
.67031 .43309 .67599 .43998 .68784 .43626 .6822 .42933 Mtetra
.6822 .42933 .68784 .43626 .69975 .43251 .69414 .42556 Mtetra
.69414 .42556 .69975 .43251 .7117 .42875 .70613 .42177 Mtetra
.70613 .42177 .7117 .42875 .7237 .42497 .71817 .41796 Mtetra
.71817 .41796 .7237 .42497 .73576 .42118 .73026 .41414 Mtetra
.73026 .41414 .73576 .42118 .74786 .41737 .7424 .4103 Mtetra
.7424 .4103 .74786 .41737 .76002 .41355 .75459 .40644 Mtetra
.75459 .40644 .76002 .41355 .77223 .40971 .76684 .40257 Mtetra
.76684 .40257 .77223 .40971 .78449 .40585 .77914 .39869 Mtetra
.77914 .39869 .78449 .40585 .79681 .40198 .79149 .39478 Mtetra
.79149 .39478 .79681 .40198 .80917 .39809 .80389 .39086 Mtetra
.80389 .39086 .80917 .39809 .82159 .39418 .81635 .38692 Mtetra
.81635 .38692 .82159 .39418 .83406 .39025 .82886 .38297 Mtetra
.82886 .38297 .83406 .39025 .84659 .38631 .84143 .37899 Mtetra
.84143 .37899 .84659 .38631 .85917 .38236 .85405 .375 Mtetra
.85405 .375 .85917 .38236 .87181 .37838 .86672 .371 Mtetra
.86672 .371 .87181 .37838 .8845 .37439 .87945 .36697 Mtetra
.87945 .36697 .8845 .37439 .89724 .37038 .89224 .36293 Mtetra
.89224 .36293 .89724 .37038 .91004 .36635 .90508 .35887 Mtetra
.90508 .35887 .91004 .36635 .9229 .36231 .91798 .35479 Mtetra
.652 .756 .926 r
.32055 .67636 .32746 .68223 .33841 .67906 .33153 .67317 Mtetra
.33153 .67317 .33841 .67906 .34941 .67587 .34255 .66996 Mtetra
.34255 .66996 .34941 .67587 .36045 .67268 .35362 .66674 Mtetra
.35362 .66674 .36045 .67268 .37154 .66947 .36474 .6635 Mtetra
.36474 .6635 .37154 .66947 .38267 .66624 .3759 .66025 Mtetra
.3759 .66025 .38267 .66624 .39386 .663 .38711 .65699 Mtetra
.38711 .65699 .39386 .663 .40508 .65975 .39836 .65371 Mtetra
.39836 .65371 .40508 .65975 .41636 .65649 .40967 .65042 Mtetra
.40967 .65042 .41636 .65649 .42768 .65321 .42102 .64712 Mtetra
.42102 .64712 .42768 .65321 .43905 .64992 .43242 .6438 Mtetra
.43242 .6438 .43905 .64992 .45046 .64661 .44387 .64047 Mtetra
.44387 .64047 .45046 .64661 .46193 .64329 .45536 .63712 Mtetra
.863 .419 .033 r
.45536 .63712 .46193 .64329 .47307 .66542 .46648 .65928 Mtetra
.65 .758 .929 r
.46648 .65928 .47307 .66542 .48471 .6621 .47816 .65594 Mtetra
.47816 .65594 .48471 .6621 .49641 .65877 .48989 .65258 Mtetra
.48989 .65258 .49641 .65877 .50816 .65542 .50167 .64921 Mtetra
.50167 .64921 .50816 .65542 .51996 .65206 .5135 .64582 Mtetra
.5135 .64582 .51996 .65206 .5318 .64869 .52538 .64241 Mtetra
.52538 .64241 .5318 .64869 .54371 .64529 .53732 .639 Mtetra
.53732 .639 .54371 .64529 .55566 .64189 .5493 .63556 Mtetra
.5493 .63556 .55566 .64189 .56766 .63847 .56134 .63212 Mtetra
.56134 .63212 .56766 .63847 .57972 .63503 .57343 .62865 Mtetra
.57343 .62865 .57972 .63503 .59182 .63158 .58557 .62518 Mtetra
.58557 .62518 .59182 .63158 .60399 .62812 .59777 .62168 Mtetra
.59777 .62168 .60399 .62812 .6162 .62464 .61002 .61817 Mtetra
.964 .709 .499 r
.61002 .61817 .6162 .62464 .62326 .44796 .61741 .44113 Mtetra
.664 .741 .908 r
.61741 .44113 .62326 .44796 .63495 .44427 .62913 .4374 Mtetra
.62913 .4374 .63495 .44427 .64669 .44056 .6409 .43366 Mtetra
.6409 .43366 .64669 .44056 .65848 .43683 .65272 .42991 Mtetra
.65272 .42991 .65848 .43683 .67031 .43309 .6646 .42614 Mtetra
.6646 .42614 .67031 .43309 .6822 .42933 .67652 .42235 Mtetra
.67652 .42235 .6822 .42933 .69414 .42556 .68849 .41855 Mtetra
.68849 .41855 .69414 .42556 .70613 .42177 .70051 .41473 Mtetra
.70051 .41473 .70613 .42177 .71817 .41796 .71259 .41089 Mtetra
.71259 .41089 .71817 .41796 .73026 .41414 .72471 .40704 Mtetra
.72471 .40704 .73026 .41414 .7424 .4103 .73689 .40317 Mtetra
.73689 .40317 .7424 .4103 .75459 .40644 .74912 .39928 Mtetra
.74912 .39928 .75459 .40644 .76684 .40257 .76141 .39538 Mtetra
.76141 .39538 .76684 .40257 .77914 .39869 .77374 .39146 Mtetra
.77374 .39146 .77914 .39869 .79149 .39478 .78613 .38753 Mtetra
.78613 .38753 .79149 .39478 .80389 .39086 .79857 .38358 Mtetra
.79857 .38358 .80389 .39086 .81635 .38692 .81107 .37961 Mtetra
.81107 .37961 .81635 .38692 .82886 .38297 .82362 .37562 Mtetra
.82362 .37562 .82886 .38297 .84143 .37899 .83622 .37161 Mtetra
.83622 .37161 .84143 .37899 .85405 .375 .84888 .36759 Mtetra
.84888 .36759 .85405 .375 .86672 .371 .8616 .36355 Mtetra
.8616 .36355 .86672 .371 .87945 .36697 .87437 .3595 Mtetra
.87437 .3595 .87945 .36697 .89224 .36293 .88719 .35542 Mtetra
.88719 .35542 .89224 .36293 .90508 .35887 .90008 .35133 Mtetra
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.53 .277 .476 r
.30972 .73412 .32055 .67636 .33153 .67317 .32092 .73097 Mtetra
.32092 .73097 .33153 .67317 .34255 .66996 .33217 .72782 Mtetra
.33217 .72782 .34255 .66996 .35362 .66674 .34346 .72465 Mtetra
.34346 .72465 .35362 .66674 .36474 .6635 .35481 .72146 Mtetra
.35481 .72146 .36474 .6635 .3759 .66025 .3662 .71826 Mtetra
.3662 .71826 .3759 .66025 .38711 .65699 .37764 .71505 Mtetra
.37764 .71505 .38711 .65699 .39836 .65371 .38913 .71183 Mtetra
.38913 .71183 .39836 .65371 .40967 .65042 .40067 .70859 Mtetra
.40067 .70859 .40967 .65042 .42102 .64712 .41225 .70533 Mtetra
.41225 .70533 .42102 .64712 .43242 .6438 .42389 .70207 Mtetra
.42389 .70207 .43242 .6438 .44387 .64047 .43558 .69879 Mtetra
.43558 .69879 .44387 .64047 .45536 .63712 .44732 .69549 Mtetra
.15 0 .353 r
.44732 .69549 .45536 .63712 .46648 .65928 .45984 .6531 Mtetra
.65 .758 .929 r
.45984 .6531 .46648 .65928 .47816 .65594 .47155 .64973 Mtetra
.47155 .64973 .47816 .65594 .48989 .65258 .48332 .64634 Mtetra
.48332 .64634 .48989 .65258 .50167 .64921 .49513 .64294 Mtetra
.49513 .64294 .50167 .64921 .5135 .64582 .50699 .63952 Mtetra
.50699 .63952 .5135 .64582 .52538 .64241 .51891 .63609 Mtetra
.51891 .63609 .52538 .64241 .53732 .639 .53088 .63265 Mtetra
.53088 .63265 .53732 .639 .5493 .63556 .5429 .62919 Mtetra
.5429 .62919 .5493 .63556 .56134 .63212 .55497 .62571 Mtetra
.55497 .62571 .56134 .63212 .57343 .62865 .5671 .62222 Mtetra
.5671 .62222 .57343 .62865 .58557 .62518 .57927 .61871 Mtetra
.57927 .61871 .58557 .62518 .59777 .62168 .59151 .61519 Mtetra
.59151 .61519 .59777 .62168 .61002 .61817 .60379 .61166 Mtetra
.964 .709 .499 r
.60379 .61166 .61002 .61817 .61741 .44113 .61151 .43424 Mtetra
.664 .741 .908 r
.61151 .43424 .61741 .44113 .62913 .4374 .62327 .43049 Mtetra
.62327 .43049 .62913 .4374 .6409 .43366 .63507 .42672 Mtetra
.63507 .42672 .6409 .43366 .65272 .42991 .64693 .42293 Mtetra
.64693 .42293 .65272 .42991 .6646 .42614 .65883 .41913 Mtetra
.65883 .41913 .6646 .42614 .67652 .42235 .67079 .41532 Mtetra
.67079 .41532 .67652 .42235 .68849 .41855 .6828 .41148 Mtetra
.6828 .41148 .68849 .41855 .70051 .41473 .69486 .40763 Mtetra
.69486 .40763 .70051 .41473 .71259 .41089 .70697 .40377 Mtetra
.70697 .40377 .71259 .41089 .72471 .40704 .71913 .39988 Mtetra
.71913 .39988 .72471 .40704 .73689 .40317 .73134 .39598 Mtetra
.73134 .39598 .73689 .40317 .74912 .39928 .74361 .39207 Mtetra
.74361 .39207 .74912 .39928 .76141 .39538 .75593 .38814 Mtetra
.75593 .38814 .76141 .39538 .77374 .39146 .7683 .38419 Mtetra
.7683 .38419 .77374 .39146 .78613 .38753 .78073 .38022 Mtetra
.78073 .38022 .78613 .38753 .79857 .38358 .79321 .37623 Mtetra
.79321 .37623 .79857 .38358 .81107 .37961 .80574 .37223 Mtetra
.80574 .37223 .81107 .37961 .82362 .37562 .81833 .36821 Mtetra
.81833 .36821 .82362 .37562 .83622 .37161 .83097 .36418 Mtetra
.83097 .36418 .83622 .37161 .84888 .36759 .84367 .36012 Mtetra
.84367 .36012 .84888 .36759 .8616 .36355 .85643 .35605 Mtetra
.85643 .35605 .8616 .36355 .87437 .3595 .86924 .35196 Mtetra
.86924 .35196 .87437 .3595 .88719 .35542 .88211 .34785 Mtetra
.88211 .34785 .88719 .35542 .90008 .35133 .89503 .34373 Mtetra
.89503 .34373 .90008 .35133 .91302 .34722 .90801 .33958 Mtetra
.646 .762 .934 r
.30256 .7283 .30972 .73412 .32092 .73097 .31378 .72514 Mtetra
.31378 .72514 .32092 .73097 .33217 .72782 .32506 .72195 Mtetra
.32506 .72195 .33217 .72782 .34346 .72465 .33638 .71876 Mtetra
.33638 .71876 .34346 .72465 .35481 .72146 .34776 .71555 Mtetra
.34776 .71555 .35481 .72146 .3662 .71826 .35918 .71232 Mtetra
.35918 .71232 .3662 .71826 .37764 .71505 .37065 .70909 Mtetra
.37065 .70909 .37764 .71505 .38913 .71183 .38217 .70584 Mtetra
.38217 .70584 .38913 .71183 .40067 .70859 .39374 .70257 Mtetra
.39374 .70257 .40067 .70859 .41225 .70533 .40536 .69929 Mtetra
.40536 .69929 .41225 .70533 .42389 .70207 .41703 .696 Mtetra
.41703 .696 .42389 .70207 .43558 .69879 .42875 .69269 Mtetra
.42875 .69269 .43558 .69879 .44732 .69549 .44052 .68937 Mtetra
.925 .745 .639 r
.44052 .68937 .44732 .69549 .45984 .6531 .45315 .64686 Mtetra
.65 .758 .929 r
.45315 .64686 .45984 .6531 .47155 .64973 .4649 .64346 Mtetra
.4649 .64346 .47155 .64973 .48332 .64634 .47669 .64005 Mtetra
.47669 .64005 .48332 .64634 .49513 .64294 .48854 .63662 Mtetra
.48854 .63662 .49513 .64294 .50699 .63952 .50043 .63318 Mtetra
.50043 .63318 .50699 .63952 .51891 .63609 .51238 .62972 Mtetra
.51238 .62972 .51891 .63609 .53088 .63265 .52439 .62625 Mtetra
.52439 .62625 .53088 .63265 .5429 .62919 .53644 .62276 Mtetra
.53644 .62276 .5429 .62919 .55497 .62571 .54855 .61925 Mtetra
.54855 .61925 .55497 .62571 .5671 .62222 .56071 .61574 Mtetra
.56071 .61574 .5671 .62222 .57927 .61871 .57292 .6122 Mtetra
.57292 .6122 .57927 .61871 .59151 .61519 .58519 .60865 Mtetra
.58519 .60865 .59151 .61519 .60379 .61166 .59751 .60508 Mtetra
.964 .709 .499 r
.59751 .60508 .60379 .61166 .61151 .43424 .60557 .4273 Mtetra
.664 .741 .908 r
.60557 .4273 .61151 .43424 .62327 .43049 .61736 .42352 Mtetra
.61736 .42352 .62327 .43049 .63507 .42672 .6292 .41972 Mtetra
.6292 .41972 .63507 .42672 .64693 .42293 .64109 .4159 Mtetra
.64109 .4159 .64693 .42293 .65883 .41913 .65303 .41207 Mtetra
.65303 .41207 .65883 .41913 .67079 .41532 .66502 .40823 Mtetra
.66502 .40823 .67079 .41532 .6828 .41148 .67706 .40436 Mtetra
.67706 .40436 .6828 .41148 .69486 .40763 .68915 .40048 Mtetra
.68915 .40048 .69486 .40763 .70697 .40377 .7013 .39659 Mtetra
.7013 .39659 .70697 .40377 .71913 .39988 .7135 .39267 Mtetra
.7135 .39267 .71913 .39988 .73134 .39598 .72575 .38874 Mtetra
.72575 .38874 .73134 .39598 .74361 .39207 .73805 .38479 Mtetra
.73805 .38479 .74361 .39207 .75593 .38814 .75041 .38083 Mtetra
.75041 .38083 .75593 .38814 .7683 .38419 .76282 .37685 Mtetra
.76282 .37685 .7683 .38419 .78073 .38022 .77528 .37285 Mtetra
.77528 .37285 .78073 .38022 .79321 .37623 .7878 .36883 Mtetra
.7878 .36883 .79321 .37623 .80574 .37223 .80037 .3648 Mtetra
.80037 .3648 .80574 .37223 .81833 .36821 .813 .36075 Mtetra
.813 .36075 .81833 .36821 .83097 .36418 .82568 .35668 Mtetra
.82568 .35668 .83097 .36418 .84367 .36012 .83842 .35259 Mtetra
.83842 .35259 .84367 .36012 .85643 .35605 .85122 .34849 Mtetra
.85122 .34849 .85643 .35605 .86924 .35196 .86407 .34436 Mtetra
.86407 .34436 .86924 .35196 .88211 .34785 .87698 .34022 Mtetra
.87698 .34022 .88211 .34785 .89503 .34373 .88994 .33606 Mtetra
.88994 .33606 .89503 .34373 .90801 .33958 .90297 .33188 Mtetra
.646 .762 .934 r
.29533 .72244 .30256 .7283 .31378 .72514 .30659 .71925 Mtetra
.30659 .71925 .31378 .72514 .32506 .72195 .31789 .71604 Mtetra
.31789 .71604 .32506 .72195 .33638 .71876 .32925 .71282 Mtetra
.32925 .71282 .33638 .71876 .34776 .71555 .34065 .70959 Mtetra
.34065 .70959 .34776 .71555 .35918 .71232 .3521 .70634 Mtetra
.3521 .70634 .35918 .71232 .37065 .70909 .3636 .70307 Mtetra
.3636 .70307 .37065 .70909 .38217 .70584 .37515 .6998 Mtetra
.37515 .6998 .38217 .70584 .39374 .70257 .38675 .69651 Mtetra
.38675 .69651 .39374 .70257 .40536 .69929 .3984 .6932 Mtetra
.3984 .6932 .40536 .69929 .41703 .696 .41011 .68988 Mtetra
.41011 .68988 .41703 .696 .42875 .69269 .42186 .68655 Mtetra
.42186 .68655 .42875 .69269 .44052 .68937 .43366 .6832 Mtetra
.925 .745 .639 r
.43366 .6832 .44052 .68937 .45315 .64686 .44641 .64058 Mtetra
.65 .758 .929 r
.44641 .64058 .45315 .64686 .4649 .64346 .45818 .63715 Mtetra
.45818 .63715 .4649 .64346 .47669 .64005 .47001 .63371 Mtetra
.47001 .63371 .47669 .64005 .48854 .63662 .48189 .63025 Mtetra
.48189 .63025 .48854 .63662 .50043 .63318 .49382 .62678 Mtetra
.49382 .62678 .50043 .63318 .51238 .62972 .50581 .6233 Mtetra
.50581 .6233 .51238 .62972 .52439 .62625 .51784 .61979 Mtetra
.51784 .61979 .52439 .62625 .53644 .62276 .52993 .61628 Mtetra
.52993 .61628 .53644 .62276 .54855 .61925 .54207 .61275 Mtetra
.54207 .61275 .54855 .61925 .56071 .61574 .55427 .6092 Mtetra
.55427 .6092 .56071 .61574 .57292 .6122 .56652 .60563 Mtetra
.56652 .60563 .57292 .6122 .58519 .60865 .57882 .60205 Mtetra
.57882 .60205 .58519 .60865 .59751 .60508 .59118 .59846 Mtetra
.964 .709 .499 r
.59118 .59846 .59751 .60508 .60557 .4273 .59958 .4203 Mtetra
.664 .741 .908 r
.59958 .4203 .60557 .4273 .61736 .42352 .6114 .41649 Mtetra
.6114 .41649 .61736 .42352 .6292 .41972 .62327 .41266 Mtetra
.62327 .41266 .6292 .41972 .64109 .4159 .6352 .40882 Mtetra
.6352 .40882 .64109 .4159 .65303 .41207 .64717 .40496 Mtetra
.64717 .40496 .65303 .41207 .66502 .40823 .6592 .40108 Mtetra
.6592 .40108 .66502 .40823 .67706 .40436 .67128 .39719 Mtetra
.67128 .39719 .67706 .40436 .68915 .40048 .6834 .39327 Mtetra
.6834 .39327 .68915 .40048 .7013 .39659 .69559 .38935 Mtetra
.69559 .38935 .7013 .39659 .7135 .39267 .70782 .3854 Mtetra
.70782 .3854 .7135 .39267 .72575 .38874 .72011 .38144 Mtetra
.72011 .38144 .72575 .38874 .73805 .38479 .73245 .37746 Mtetra
.73245 .37746 .73805 .38479 .75041 .38083 .74484 .37347 Mtetra
.74484 .37347 .75041 .38083 .76282 .37685 .75729 .36945 Mtetra
.75729 .36945 .76282 .37685 .77528 .37285 .76979 .36542 Mtetra
.76979 .36542 .77528 .37285 .7878 .36883 .78235 .36137 Mtetra
.78235 .36137 .7878 .36883 .80037 .3648 .79496 .35731 Mtetra
.79496 .35731 .80037 .3648 .813 .36075 .80763 .35322 Mtetra
.80763 .35322 .813 .36075 .82568 .35668 .82035 .34912 Mtetra
.82035 .34912 .82568 .35668 .83842 .35259 .83313 .345 Mtetra
.83313 .345 .83842 .35259 .85122 .34849 .84597 .34086 Mtetra
.84597 .34086 .85122 .34849 .86407 .34436 .85886 .3367 Mtetra
.85886 .3367 .86407 .34436 .87698 .34022 .87181 .33253 Mtetra
.87181 .33253 .87698 .34022 .88994 .33606 .88482 .32833 Mtetra
.88482 .32833 .88994 .33606 .90297 .33188 .89788 .32412 Mtetra
.646 .762 .934 r
.28805 .71654 .29533 .72244 .30659 .71925 .29934 .71332 Mtetra
.29934 .71332 .30659 .71925 .31789 .71604 .31067 .71009 Mtetra
.31067 .71009 .31789 .71604 .32925 .71282 .32205 .70684 Mtetra
.32205 .70684 .32925 .71282 .34065 .70959 .33349 .70358 Mtetra
.33349 .70358 .34065 .70959 .3521 .70634 .34497 .7003 Mtetra
.34497 .7003 .3521 .70634 .3636 .70307 .3565 .69701 Mtetra
.3565 .69701 .3636 .70307 .37515 .6998 .36808 .69371 Mtetra
.36808 .69371 .37515 .6998 .38675 .69651 .37971 .69039 Mtetra
.37971 .69039 .38675 .69651 .3984 .6932 .39139 .68706 Mtetra
.39139 .68706 .3984 .6932 .41011 .68988 .40313 .68371 Mtetra
.40313 .68371 .41011 .68988 .42186 .68655 .41491 .68035 Mtetra
.41491 .68035 .42186 .68655 .43366 .6832 .42675 .67698 Mtetra
.925 .745 .639 r
.42675 .67698 .43366 .6832 .44641 .64058 .43961 .63424 Mtetra
.65 .758 .929 r
.43961 .63424 .44641 .64058 .45818 .63715 .45142 .63079 Mtetra
.45142 .63079 .45818 .63715 .47001 .63371 .46328 .62732 Mtetra
.46328 .62732 .47001 .63371 .48189 .63025 .47519 .62383 Mtetra
.47519 .62383 .48189 .63025 .49382 .62678 .48716 .62033 Mtetra
.48716 .62033 .49382 .62678 .50581 .6233 .49917 .61682 Mtetra
.49917 .61682 .50581 .6233 .51784 .61979 .51124 .61329 Mtetra
.51124 .61329 .51784 .61979 .52993 .61628 .52337 .60974 Mtetra
.52337 .60974 .52993 .61628 .54207 .61275 .53555 .60618 Mtetra
.53555 .60618 .54207 .61275 .55427 .6092 .54778 .60261 Mtetra
.54778 .60261 .55427 .6092 .56652 .60563 .56006 .59901 Mtetra
.56006 .59901 .56652 .60563 .57882 .60205 .5724 .5954 Mtetra
.5724 .5954 .57882 .60205 .59118 .59846 .5848 .59178 Mtetra
.964 .709 .499 r
.5848 .59178 .59118 .59846 .59958 .4203 .59354 .41325 Mtetra
.664 .741 .908 r
.59354 .41325 .59958 .4203 .6114 .41649 .6054 .40941 Mtetra
.6054 .40941 .6114 .41649 .62327 .41266 .6173 .40555 Mtetra
.6173 .40555 .62327 .41266 .6352 .40882 .62926 .40168 Mtetra
.62926 .40168 .6352 .40882 .64717 .40496 .64127 .39779 Mtetra
.64127 .39779 .64717 .40496 .6592 .40108 .65333 .39388 Mtetra
.65333 .39388 .6592 .40108 .67128 .39719 .66545 .38995 Mtetra
.66545 .38995 .67128 .39719 .6834 .39327 .67761 .38601 Mtetra
.67761 .38601 .6834 .39327 .69559 .38935 .68983 .38205 Mtetra
.68983 .38205 .69559 .38935 .70782 .3854 .7021 .37807 Mtetra
.7021 .37807 .70782 .3854 .72011 .38144 .71442 .37408 Mtetra
.71442 .37408 .72011 .38144 .73245 .37746 .7268 .37007 Mtetra
.7268 .37007 .73245 .37746 .74484 .37347 .73923 .36604 Mtetra
.73923 .36604 .74484 .37347 .75729 .36945 .75172 .362 Mtetra
.75172 .362 .75729 .36945 .76979 .36542 .76426 .35793 Mtetra
.76426 .35793 .76979 .36542 .78235 .36137 .77685 .35385 Mtetra
.77685 .35385 .78235 .36137 .79496 .35731 .78951 .34975 Mtetra
.78951 .34975 .79496 .35731 .80763 .35322 .80221 .34563 Mtetra
.80221 .34563 .80763 .35322 .82035 .34912 .81498 .3415 Mtetra
.81498 .3415 .82035 .34912 .83313 .345 .82779 .33734 Mtetra
.82779 .33734 .83313 .345 .84597 .34086 .84067 .33317 Mtetra
.84067 .33317 .84597 .34086 .85886 .3367 .8536 .32898 Mtetra
.8536 .32898 .85886 .3367 .87181 .33253 .8666 .32477 Mtetra
.8666 .32477 .87181 .33253 .88482 .32833 .87965 .32054 Mtetra
.87965 .32054 .88482 .32833 .89788 .32412 .89275 .31629 Mtetra
.646 .762 .934 r
.28071 .71058 .28805 .71654 .29934 .71332 .29203 .70734 Mtetra
.29203 .70734 .29934 .71332 .31067 .71009 .30339 .70408 Mtetra
.30339 .70408 .31067 .71009 .32205 .70684 .3148 .70081 Mtetra
.3148 .70081 .32205 .70684 .33349 .70358 .32627 .69752 Mtetra
.32627 .69752 .33349 .70358 .34497 .7003 .33778 .69422 Mtetra
.33778 .69422 .34497 .7003 .3565 .69701 .34934 .6909 Mtetra
.34934 .6909 .3565 .69701 .36808 .69371 .36095 .68757 Mtetra
.36095 .68757 .36808 .69371 .37971 .69039 .37261 .68423 Mtetra
.37261 .68423 .37971 .69039 .39139 .68706 .38433 .68087 Mtetra
.38433 .68087 .39139 .68706 .40313 .68371 .39609 .6775 Mtetra
.39609 .6775 .40313 .68371 .41491 .68035 .40791 .67411 Mtetra
.40791 .67411 .41491 .68035 .42675 .67698 .41978 .6707 Mtetra
.925 .745 .639 r
.41978 .6707 .42675 .67698 .43961 .63424 .43276 .62785 Mtetra
.65 .758 .929 r
.43276 .62785 .43961 .63424 .45142 .63079 .4446 .62437 Mtetra
.4446 .62437 .45142 .63079 .46328 .62732 .45649 .62087 Mtetra
.45649 .62087 .46328 .62732 .47519 .62383 .46844 .61736 Mtetra
.46844 .61736 .47519 .62383 .48716 .62033 .48044 .61383 Mtetra
.48044 .61383 .48716 .62033 .49917 .61682 .49249 .61029 Mtetra
.49249 .61029 .49917 .61682 .51124 .61329 .50459 .60673 Mtetra
.50459 .60673 .51124 .61329 .52337 .60974 .51675 .60316 Mtetra
.51675 .60316 .52337 .60974 .53555 .60618 .52896 .59957 Mtetra
.52896 .59957 .53555 .60618 .54778 .60261 .54123 .59596 Mtetra
.54123 .59596 .54778 .60261 .56006 .59901 .55355 .59234 Mtetra
.55355 .59234 .56006 .59901 .5724 .5954 .56593 .5887 Mtetra
.56593 .5887 .5724 .5954 .5848 .59178 .57836 .58504 Mtetra
.964 .709 .499 r
.57836 .58504 .5848 .59178 .59354 .41325 .58746 .40615 Mtetra
.664 .741 .908 r
.58746 .40615 .59354 .41325 .6054 .40941 .59935 .40227 Mtetra
.59935 .40227 .6054 .40941 .6173 .40555 .61129 .39839 Mtetra
.61129 .39839 .6173 .40555 .62926 .40168 .62328 .39448 Mtetra
.62328 .39448 .62926 .40168 .64127 .39779 .63532 .39056 Mtetra
.63532 .39056 .64127 .39779 .65333 .39388 .64742 .38662 Mtetra
.64742 .38662 .65333 .39388 .66545 .38995 .65957 .38266 Mtetra
.65957 .38266 .66545 .38995 .67761 .38601 .67177 .37869 Mtetra
.67177 .37869 .67761 .38601 .68983 .38205 .68402 .3747 Mtetra
.68402 .3747 .68983 .38205 .7021 .37807 .69633 .37069 Mtetra
.69633 .37069 .7021 .37807 .71442 .37408 .70869 .36666 Mtetra
.70869 .36666 .71442 .37408 .7268 .37007 .72111 .36262 Mtetra
.72111 .36262 .7268 .37007 .73923 .36604 .73358 .35856 Mtetra
.73358 .35856 .73923 .36604 .75172 .362 .7461 .35448 Mtetra
.7461 .35448 .75172 .362 .76426 .35793 .75868 .35038 Mtetra
.75868 .35038 .76426 .35793 .77685 .35385 .77131 .34627 Mtetra
.77131 .34627 .77685 .35385 .78951 .34975 .78401 .34213 Mtetra
.78401 .34213 .78951 .34975 .80221 .34563 .79675 .33798 Mtetra
.79675 .33798 .80221 .34563 .81498 .3415 .80955 .33381 Mtetra
.80955 .33381 .81498 .3415 .82779 .33734 .82241 .32963 Mtetra
.82241 .32963 .82779 .33734 .84067 .33317 .83533 .32542 Mtetra
.83533 .32542 .84067 .33317 .8536 .32898 .84831 .32119 Mtetra
.84831 .32119 .8536 .32898 .8666 .32477 .86134 .31695 Mtetra
.86134 .31695 .8666 .32477 .87965 .32054 .87443 .31268 Mtetra
.87443 .31268 .87965 .32054 .89275 .31629 .88758 .3084 Mtetra
.646 .762 .934 r
.27331 .70458 .28071 .71058 .29203 .70734 .28466 .70131 Mtetra
.28466 .70131 .29203 .70734 .30339 .70408 .29605 .69803 Mtetra
.29605 .69803 .30339 .70408 .3148 .70081 .30749 .69473 Mtetra
.30749 .69473 .3148 .70081 .32627 .69752 .31899 .69141 Mtetra
.31899 .69141 .32627 .69752 .33778 .69422 .33053 .68809 Mtetra
.33053 .68809 .33778 .69422 .34934 .6909 .34212 .68474 Mtetra
.34212 .68474 .34934 .6909 .36095 .68757 .35377 .68139 Mtetra
.35377 .68139 .36095 .68757 .37261 .68423 .36546 .67802 Mtetra
.36546 .67802 .37261 .68423 .38433 .68087 .37721 .67463 Mtetra
.37721 .67463 .38433 .68087 .39609 .6775 .389 .67123 Mtetra
.389 .67123 .39609 .6775 .40791 .67411 .40085 .66781 Mtetra
.40085 .66781 .40791 .67411 .41978 .6707 .41276 .66438 Mtetra
.925 .745 .639 r
.41276 .66438 .41978 .6707 .43276 .62785 .42585 .62141 Mtetra
.65 .758 .929 r
.42585 .62141 .43276 .62785 .4446 .62437 .43772 .6179 Mtetra
.43772 .6179 .4446 .62437 .45649 .62087 .44965 .61438 Mtetra
.44965 .61438 .45649 .62087 .46844 .61736 .46163 .61084 Mtetra
.46163 .61084 .46844 .61736 .48044 .61383 .47366 .60728 Mtetra
.47366 .60728 .48044 .61383 .49249 .61029 .48575 .60371 Mtetra
.48575 .60371 .49249 .61029 .50459 .60673 .49789 .60012 Mtetra
.49789 .60012 .50459 .60673 .51675 .60316 .51008 .59652 Mtetra
.51008 .59652 .51675 .60316 .52896 .59957 .52233 .5929 Mtetra
.52233 .5929 .52896 .59957 .54123 .59596 .53463 .58926 Mtetra
.53463 .58926 .54123 .59596 .55355 .59234 .54699 .58561 Mtetra
.54699 .58561 .55355 .59234 .56593 .5887 .5594 .58194 Mtetra
.5594 .58194 .56593 .5887 .57836 .58504 .57187 .57825 Mtetra
.964 .709 .499 r
.57187 .57825 .57836 .58504 .58746 .40615 .58132 .39899 Mtetra
.664 .741 .908 r
.58132 .39899 .58746 .40615 .59935 .40227 .59325 .39508 Mtetra
.59325 .39508 .59935 .40227 .61129 .39839 .60522 .39116 Mtetra
.60522 .39116 .61129 .39839 .62328 .39448 .61725 .38723 Mtetra
.61725 .38723 .62328 .39448 .63532 .39056 .62933 .38327 Mtetra
.62933 .38327 .63532 .39056 .64742 .38662 .64146 .3793 Mtetra
.64146 .3793 .64742 .38662 .65957 .38266 .65365 .37531 Mtetra
.65365 .37531 .65957 .38266 .67177 .37869 .66588 .37131 Mtetra
.66588 .37131 .67177 .37869 .68402 .3747 .67817 .36728 Mtetra
.67817 .36728 .68402 .3747 .69633 .37069 .69052 .36324 Mtetra
.69052 .36324 .69633 .37069 .70869 .36666 .70292 .35918 Mtetra
.70292 .35918 .70869 .36666 .72111 .36262 .71537 .35511 Mtetra
.71537 .35511 .72111 .36262 .73358 .35856 .72788 .35101 Mtetra
.72788 .35101 .73358 .35856 .7461 .35448 .74044 .3469 Mtetra
.74044 .3469 .7461 .35448 .75868 .35038 .75306 .34277 Mtetra
.75306 .34277 .75868 .35038 .77131 .34627 .76573 .33862 Mtetra
.76573 .33862 .77131 .34627 .78401 .34213 .77846 .33446 Mtetra
.77846 .33446 .78401 .34213 .79675 .33798 .79125 .33027 Mtetra
.79125 .33027 .79675 .33798 .80955 .33381 .80409 .32607 Mtetra
.80409 .32607 .80955 .33381 .82241 .32963 .81699 .32184 Mtetra
.81699 .32184 .82241 .32963 .83533 .32542 .82995 .3176 Mtetra
.82995 .3176 .83533 .32542 .84831 .32119 .84297 .31334 Mtetra
.84297 .31334 .84831 .32119 .86134 .31695 .85604 .30906 Mtetra
.85604 .30906 .86134 .31695 .87443 .31268 .86918 .30476 Mtetra
.86918 .30476 .87443 .31268 .88758 .3084 .88237 .30044 Mtetra
.646 .762 .934 r
.26586 .69853 .27331 .70458 .28466 .70131 .27723 .69524 Mtetra
.27723 .69524 .28466 .70131 .29605 .69803 .28865 .69193 Mtetra
.28865 .69193 .29605 .69803 .30749 .69473 .30013 .6886 Mtetra
.30013 .6886 .30749 .69473 .31899 .69141 .31165 .68526 Mtetra
.31165 .68526 .31899 .69141 .33053 .68809 .32322 .6819 Mtetra
.32322 .6819 .33053 .68809 .34212 .68474 .33485 .67854 Mtetra
.33485 .67854 .34212 .68474 .35377 .68139 .34652 .67515 Mtetra
.34652 .67515 .35377 .68139 .36546 .67802 .35825 .67175 Mtetra
.35825 .67175 .36546 .67802 .37721 .67463 .37002 .66834 Mtetra
.37002 .66834 .37721 .67463 .389 .67123 .38185 .66491 Mtetra
.38185 .66491 .389 .67123 .40085 .66781 .39374 .66146 Mtetra
.39374 .66146 .40085 .66781 .41276 .66438 .40567 .658 Mtetra
.925 .745 .639 r
.40567 .658 .41276 .66438 .42585 .62141 .41888 .61492 Mtetra
.65 .758 .929 r
.41888 .61492 .42585 .62141 .43772 .6179 .43079 .61138 Mtetra
.43079 .61138 .43772 .6179 .44965 .61438 .44275 .60783 Mtetra
.44275 .60783 .44965 .61438 .46163 .61084 .45476 .60426 Mtetra
.45476 .60426 .46163 .61084 .47366 .60728 .46683 .60067 Mtetra
.46683 .60067 .47366 .60728 .48575 .60371 .47895 .59707 Mtetra
.47895 .59707 .48575 .60371 .49789 .60012 .49113 .59345 Mtetra
.49113 .59345 .49789 .60012 .51008 .59652 .50335 .58982 Mtetra
.50335 .58982 .51008 .59652 .52233 .5929 .51564 .58617 Mtetra
.51564 .58617 .52233 .5929 .53463 .58926 .52798 .5825 Mtetra
.52798 .5825 .53463 .58926 .54699 .58561 .54037 .57882 Mtetra
.54037 .57882 .54699 .58561 .5594 .58194 .55282 .57512 Mtetra
.55282 .57512 .5594 .58194 .57187 .57825 .56533 .5714 Mtetra
.964 .709 .499 r
.56533 .5714 .57187 .57825 .58132 .39899 .57514 .39177 Mtetra
.664 .741 .908 r
.57514 .39177 .58132 .39899 .59325 .39508 .5871 .38783 Mtetra
.5871 .38783 .59325 .39508 .60522 .39116 .59911 .38388 Mtetra
.59911 .38388 .60522 .39116 .61725 .38723 .61117 .37991 Mtetra
.61117 .37991 .61725 .38723 .62933 .38327 .62329 .37593 Mtetra
.62329 .37593 .62933 .38327 .64146 .3793 .63545 .37192 Mtetra
.63545 .37192 .64146 .3793 .65365 .37531 .64767 .3679 Mtetra
.64767 .3679 .65365 .37531 .66588 .37131 .65995 .36387 Mtetra
.65995 .36387 .66588 .37131 .67817 .36728 .67228 .35981 Mtetra
.67228 .35981 .67817 .36728 .69052 .36324 .68466 .35574 Mtetra
.68466 .35574 .69052 .36324 .70292 .35918 .69709 .35165 Mtetra
.69709 .35165 .70292 .35918 .71537 .35511 .70958 .34754 Mtetra
.70958 .34754 .71537 .35511 .72788 .35101 .72213 .34341 Mtetra
.72213 .34341 .72788 .35101 .74044 .3469 .73473 .33926 Mtetra
.73473 .33926 .74044 .3469 .75306 .34277 .74739 .3351 Mtetra
.74739 .3351 .75306 .34277 .76573 .33862 .7601 .33092 Mtetra
.7601 .33092 .76573 .33862 .77846 .33446 .77287 .32671 Mtetra
.77287 .32671 .77846 .33446 .79125 .33027 .7857 .32249 Mtetra
.7857 .32249 .79125 .33027 .80409 .32607 .79858 .31826 Mtetra
.79858 .31826 .80409 .32607 .81699 .32184 .81152 .314 Mtetra
.81152 .314 .81699 .32184 .82995 .3176 .82452 .30972 Mtetra
.82452 .30972 .82995 .3176 .84297 .31334 .83758 .30543 Mtetra
.83758 .30543 .84297 .31334 .85604 .30906 .8507 .30111 Mtetra
.8507 .30111 .85604 .30906 .86918 .30476 .86387 .29677 Mtetra
.86387 .29677 .86918 .30476 .88237 .30044 .87711 .29242 Mtetra
.646 .762 .934 r
.25834 .69244 .26586 .69853 .27723 .69524 .26974 .68911 Mtetra
.26974 .68911 .27723 .69524 .28865 .69193 .2812 .68577 Mtetra
.2812 .68577 .28865 .69193 .30013 .6886 .2927 .68242 Mtetra
.2927 .68242 .30013 .6886 .31165 .68526 .30425 .67905 Mtetra
.30425 .67905 .31165 .68526 .32322 .6819 .31586 .67567 Mtetra
.31586 .67567 .32322 .6819 .33485 .67854 .32751 .67228 Mtetra
.32751 .67228 .33485 .67854 .34652 .67515 .33922 .66886 Mtetra
.33922 .66886 .34652 .67515 .35825 .67175 .35097 .66544 Mtetra
.35097 .66544 .35825 .67175 .37002 .66834 .36278 .66199 Mtetra
.36278 .66199 .37002 .66834 .38185 .66491 .37465 .65854 Mtetra
.37465 .65854 .38185 .66491 .39374 .66146 .38656 .65506 Mtetra
.38656 .65506 .39374 .66146 .40567 .658 .39853 .65158 Mtetra
.925 .745 .639 r
.39853 .65158 .40567 .658 .41888 .61492 .41186 .60838 Mtetra
.65 .758 .929 r
.41186 .60838 .41888 .61492 .43079 .61138 .4238 .60481 Mtetra
.4238 .60481 .43079 .61138 .44275 .60783 .4358 .60123 Mtetra
.4358 .60123 .44275 .60783 .45476 .60426 .44784 .59763 Mtetra
.44784 .59763 .45476 .60426 .46683 .60067 .45994 .59401 Mtetra
.45994 .59401 .46683 .60067 .47895 .59707 .4721 .59038 Mtetra
.4721 .59038 .47895 .59707 .49113 .59345 .48431 .58673 Mtetra
.48431 .58673 .49113 .59345 .50335 .58982 .49657 .58307 Mtetra
.49657 .58307 .50335 .58982 .51564 .58617 .50889 .57939 Mtetra
.50889 .57939 .51564 .58617 .52798 .5825 .52127 .57569 Mtetra
.52127 .57569 .52798 .5825 .54037 .57882 .5337 .57198 Mtetra
.5337 .57198 .54037 .57882 .55282 .57512 .54619 .56825 Mtetra
.54619 .56825 .55282 .57512 .56533 .5714 .55873 .5645 Mtetra
.964 .709 .499 r
.55873 .5645 .56533 .5714 .57514 .39177 .56891 .38449 Mtetra
.664 .741 .908 r
.56891 .38449 .57514 .39177 .5871 .38783 .5809 .38052 Mtetra
.5809 .38052 .5871 .38783 .59911 .38388 .59295 .37654 Mtetra
.59295 .37654 .59911 .38388 .61117 .37991 .60505 .37254 Mtetra
.60505 .37254 .61117 .37991 .62329 .37593 .6172 .36852 Mtetra
.6172 .36852 .62329 .37593 .63545 .37192 .6294 .36449 Mtetra
.6294 .36449 .63545 .37192 .64767 .3679 .64166 .36043 Mtetra
.64166 .36043 .64767 .3679 .65995 .36387 .65397 .35636 Mtetra
.65397 .35636 .65995 .36387 .67228 .35981 .66633 .35228 Mtetra
.66633 .35228 .67228 .35981 .68466 .35574 .67875 .34817 Mtetra
.67875 .34817 .68466 .35574 .69709 .35165 .69122 .34404 Mtetra
.69122 .34404 .69709 .35165 .70958 .34754 .70375 .3399 Mtetra
.70375 .3399 .70958 .34754 .72213 .34341 .71633 .33574 Mtetra
.71633 .33574 .72213 .34341 .73473 .33926 .72897 .33156 Mtetra
.72897 .33156 .73473 .33926 .74739 .3351 .74167 .32736 Mtetra
.74167 .32736 .74739 .3351 .7601 .33092 .75442 .32315 Mtetra
.75442 .32315 .7601 .33092 .77287 .32671 .76723 .31891 Mtetra
.76723 .31891 .77287 .32671 .7857 .32249 .7801 .31465 Mtetra
.7801 .31465 .7857 .32249 .79858 .31826 .79302 .31038 Mtetra
.79302 .31038 .79858 .31826 .81152 .314 .80601 .30609 Mtetra
.80601 .30609 .81152 .314 .82452 .30972 .81905 .30177 Mtetra
.81905 .30177 .82452 .30972 .83758 .30543 .83215 .29744 Mtetra
.83215 .29744 .83758 .30543 .8507 .30111 .84531 .29309 Mtetra
.84531 .29309 .8507 .30111 .86387 .29677 .85853 .28872 Mtetra
.85853 .28872 .86387 .29677 .87711 .29242 .87181 .28433 Mtetra
.646 .762 .934 r
.25076 .68629 .25834 .69244 .26974 .68911 .2622 .68294 Mtetra
.2622 .68294 .26974 .68911 .2812 .68577 .27368 .67957 Mtetra
.27368 .67957 .2812 .68577 .2927 .68242 .28521 .67619 Mtetra
.28521 .67619 .2927 .68242 .30425 .67905 .29679 .6728 Mtetra
.29679 .6728 .30425 .67905 .31586 .67567 .30843 .66939 Mtetra
.30843 .66939 .31586 .67567 .32751 .67228 .32012 .66597 Mtetra
.32012 .66597 .32751 .67228 .33922 .66886 .33185 .66253 Mtetra
.33185 .66253 .33922 .66886 .35097 .66544 .34364 .65907 Mtetra
.34364 .65907 .35097 .66544 .36278 .66199 .35548 .6556 Mtetra
.35548 .6556 .36278 .66199 .37465 .65854 .36738 .65211 Mtetra
.36738 .65211 .37465 .65854 .38656 .65506 .37933 .64861 Mtetra
.37933 .64861 .38656 .65506 .39853 .65158 .39133 .64509 Mtetra
.925 .745 .639 r
.39133 .64509 .39853 .65158 .41186 .60838 .40478 .60178 Mtetra
.65 .758 .929 r
.40478 .60178 .41186 .60838 .4238 .60481 .41676 .59818 Mtetra
.41676 .59818 .4238 .60481 .4358 .60123 .42878 .59457 Mtetra
.42878 .59457 .4358 .60123 .44784 .59763 .44086 .59094 Mtetra
.44086 .59094 .44784 .59763 .45994 .59401 .453 .58729 Mtetra
.453 .58729 .45994 .59401 .4721 .59038 .46519 .58363 Mtetra
.46519 .58363 .4721 .59038 .48431 .58673 .47743 .57996 Mtetra
.47743 .57996 .48431 .58673 .49657 .58307 .48973 .57626 Mtetra
.48973 .57626 .49657 .58307 .50889 .57939 .50209 .57255 Mtetra
.50209 .57255 .50889 .57939 .52127 .57569 .5145 .56882 Mtetra
.5145 .56882 .52127 .57569 .5337 .57198 .52697 .56508 Mtetra
.52697 .56508 .5337 .57198 .54619 .56825 .53949 .56131 Mtetra
.53949 .56131 .54619 .56825 .55873 .5645 .55208 .55753 Mtetra
.964 .709 .499 r
.55208 .55753 .55873 .5645 .56891 .38449 .56263 .37715 Mtetra
.664 .741 .908 r
.56263 .37715 .56891 .38449 .5809 .38052 .57466 .37316 Mtetra
.57466 .37316 .5809 .38052 .59295 .37654 .58674 .36914 Mtetra
.58674 .36914 .59295 .37654 .60505 .37254 .59887 .36511 Mtetra
.59887 .36511 .60505 .37254 .6172 .36852 .61106 .36106 Mtetra
.61106 .36106 .6172 .36852 .6294 .36449 .62329 .35699 Mtetra
.62329 .35699 .6294 .36449 .64166 .36043 .63559 .35291 Mtetra
.63559 .35291 .64166 .36043 .65397 .35636 .64793 .3488 Mtetra
.64793 .3488 .65397 .35636 .66633 .35228 .66033 .34468 Mtetra
.66033 .34468 .66633 .35228 .67875 .34817 .67279 .34054 Mtetra
.67279 .34054 .67875 .34817 .69122 .34404 .6853 .33638 Mtetra
.6853 .33638 .69122 .34404 .70375 .3399 .69787 .3322 Mtetra
.69787 .3322 .70375 .3399 .71633 .33574 .71049 .32801 Mtetra
.71049 .32801 .71633 .33574 .72897 .33156 .72317 .3238 Mtetra
.72317 .3238 .72897 .33156 .74167 .32736 .73591 .31956 Mtetra
.73591 .31956 .74167 .32736 .75442 .32315 .7487 .31531 Mtetra
.7487 .31531 .75442 .32315 .76723 .31891 .76155 .31104 Mtetra
.76155 .31104 .76723 .31891 .7801 .31465 .77446 .30675 Mtetra
.77446 .30675 .7801 .31465 .79302 .31038 .78742 .30244 Mtetra
.78742 .30244 .79302 .31038 .80601 .30609 .80045 .29811 Mtetra
.80045 .29811 .80601 .30609 .81905 .30177 .81353 .29376 Mtetra
.81353 .29376 .81905 .30177 .83215 .29744 .82667 .28939 Mtetra
.82667 .28939 .83215 .29744 .84531 .29309 .83988 .285 Mtetra
.83988 .285 .84531 .29309 .85853 .28872 .85314 .2806 Mtetra
.85314 .2806 .85853 .28872 .87181 .28433 .86646 .27617 Mtetra
.646 .762 .934 r
.24313 .68009 .25076 .68629 .2622 .68294 .25459 .67671 Mtetra
.25459 .67671 .2622 .68294 .27368 .67957 .2661 .67332 Mtetra
.2661 .67332 .27368 .67957 .28521 .67619 .27766 .66992 Mtetra
.27766 .66992 .28521 .67619 .29679 .6728 .28928 .66649 Mtetra
.28928 .66649 .29679 .6728 .30843 .66939 .30094 .66306 Mtetra
.30094 .66306 .30843 .66939 .32012 .66597 .31266 .6596 Mtetra
.31266 .6596 .32012 .66597 .33185 .66253 .32443 .65613 Mtetra
.32443 .65613 .33185 .66253 .34364 .65907 .33625 .65265 Mtetra
.33625 .65265 .34364 .65907 .35548 .6556 .34813 .64915 Mtetra
.34813 .64915 .35548 .6556 .36738 .65211 .36005 .64564 Mtetra
.36005 .64564 .36738 .65211 .37933 .64861 .37203 .64211 Mtetra
.37203 .64211 .37933 .64861 .39133 .64509 .38407 .63856 Mtetra
.925 .745 .639 r
.38407 .63856 .39133 .64509 .40478 .60178 .39764 .59513 Mtetra
.65 .758 .929 r
.39764 .59513 .40478 .60178 .41676 .59818 .40965 .5915 Mtetra
.40965 .5915 .41676 .59818 .42878 .59457 .42171 .58786 Mtetra
.42171 .58786 .42878 .59457 .44086 .59094 .43383 .5842 Mtetra
.43383 .5842 .44086 .59094 .453 .58729 .446 .58052 Mtetra
.446 .58052 .453 .58729 .46519 .58363 .45822 .57683 Mtetra
.45822 .57683 .46519 .58363 .47743 .57996 .4705 .57312 Mtetra
.4705 .57312 .47743 .57996 .48973 .57626 .48284 .5694 Mtetra
.48284 .5694 .48973 .57626 .50209 .57255 .49523 .56565 Mtetra
.49523 .56565 .50209 .57255 .5145 .56882 .50768 .56189 Mtetra
.50768 .56189 .5145 .56882 .52697 .56508 .52018 .55812 Mtetra
.52018 .55812 .52697 .56508 .53949 .56131 .53274 .55432 Mtetra
.53274 .55432 .53949 .56131 .55208 .55753 .54536 .55051 Mtetra
.964 .709 .499 r
.54536 .55051 .55208 .55753 .56263 .37715 .5563 .36976 Mtetra
.664 .741 .908 r
.5563 .36976 .56263 .37715 .57466 .37316 .56836 .36573 Mtetra
.56836 .36573 .57466 .37316 .58674 .36914 .58048 .36168 Mtetra
.58048 .36168 .58674 .36914 .59887 .36511 .59265 .35762 Mtetra
.59265 .35762 .59887 .36511 .61106 .36106 .60487 .35354 Mtetra
.60487 .35354 .61106 .36106 .62329 .35699 .61714 .34943 Mtetra
.61714 .34943 .62329 .35699 .63559 .35291 .62947 .34532 Mtetra
.62947 .34532 .63559 .35291 .64793 .3488 .64185 .34118 Mtetra
.64185 .34118 .64793 .3488 .66033 .34468 .65429 .33702 Mtetra
.65429 .33702 .66033 .34468 .67279 .34054 .66679 .33285 Mtetra
.66679 .33285 .67279 .34054 .6853 .33638 .67933 .32866 Mtetra
.67933 .32866 .6853 .33638 .69787 .3322 .69194 .32444 Mtetra
.69194 .32444 .69787 .3322 .71049 .32801 .7046 .32021 Mtetra
.7046 .32021 .71049 .32801 .72317 .3238 .71732 .31597 Mtetra
.71732 .31597 .72317 .3238 .73591 .31956 .73009 .3117 Mtetra
.73009 .3117 .73591 .31956 .7487 .31531 .74293 .30741 Mtetra
.74293 .30741 .7487 .31531 .76155 .31104 .75582 .3031 Mtetra
.75582 .3031 .76155 .31104 .77446 .30675 .76877 .29878 Mtetra
.76877 .29878 .77446 .30675 .78742 .30244 .78177 .29443 Mtetra
.78177 .29443 .78742 .30244 .80045 .29811 .79484 .29007 Mtetra
.79484 .29007 .80045 .29811 .81353 .29376 .80797 .28568 Mtetra
.80797 .28568 .81353 .29376 .82667 .28939 .82115 .28128 Mtetra
.82115 .28128 .82667 .28939 .83988 .285 .8344 .27685 Mtetra
.8344 .27685 .83988 .285 .85314 .2806 .8477 .2724 Mtetra
.8477 .2724 .85314 .2806 .86646 .27617 .86107 .26794 Mtetra
.646 .762 .934 r
.23543 .67385 .24313 .68009 .25459 .67671 .24692 .67044 Mtetra
.24692 .67044 .25459 .67671 .2661 .67332 .25846 .66702 Mtetra
.25846 .66702 .2661 .67332 .27766 .66992 .27005 .66359 Mtetra
.27005 .66359 .27766 .66992 .28928 .66649 .2817 .66014 Mtetra
.2817 .66014 .28928 .66649 .30094 .66306 .29339 .65667 Mtetra
.29339 .65667 .30094 .66306 .31266 .6596 .30514 .65319 Mtetra
.30514 .65319 .31266 .6596 .32443 .65613 .31694 .64969 Mtetra
.31694 .64969 .32443 .65613 .33625 .65265 .3288 .64618 Mtetra
.3288 .64618 .33625 .65265 .34813 .64915 .3407 .64265 Mtetra
.3407 .64265 .34813 .64915 .36005 .64564 .35267 .63911 Mtetra
.35267 .63911 .36005 .64564 .37203 .64211 .36468 .63555 Mtetra
.36468 .63555 .37203 .64211 .38407 .63856 .37675 .63197 Mtetra
.925 .745 .639 r
.37675 .63197 .38407 .63856 .39764 .59513 .39045 .58842 Mtetra
.65 .758 .929 r
.39045 .58842 .39764 .59513 .40965 .5915 .40249 .58476 Mtetra
.40249 .58476 .40965 .5915 .42171 .58786 .41458 .58109 Mtetra
.41458 .58109 .42171 .58786 .43383 .5842 .42673 .5774 Mtetra
.42673 .5774 .43383 .5842 .446 .58052 .43894 .57369 Mtetra
.43894 .57369 .446 .58052 .45822 .57683 .4512 .56997 Mtetra
.4512 .56997 .45822 .57683 .4705 .57312 .46351 .56623 Mtetra
.46351 .56623 .4705 .57312 .48284 .5694 .47588 .56247 Mtetra
.47588 .56247 .48284 .5694 .49523 .56565 .48831 .5587 Mtetra
.48831 .5587 .49523 .56565 .50768 .56189 .5008 .55491 Mtetra
.5008 .55491 .50768 .56189 .52018 .55812 .51334 .5511 Mtetra
.51334 .5511 .52018 .55812 .53274 .55432 .52594 .54727 Mtetra
.52594 .54727 .53274 .55432 .54536 .55051 .5386 .54343 Mtetra
.964 .709 .499 r
.5386 .54343 .54536 .55051 .5563 .36976 .54992 .36231 Mtetra
.664 .741 .908 r
.54992 .36231 .5563 .36976 .56836 .36573 .56202 .35825 Mtetra
.56202 .35825 .56836 .36573 .58048 .36168 .57417 .35416 Mtetra
.57417 .35416 .58048 .36168 .59265 .35762 .58637 .35007 Mtetra
.58637 .35007 .59265 .35762 .60487 .35354 .59863 .34595 Mtetra
.59863 .34595 .60487 .35354 .61714 .34943 .61094 .34182 Mtetra
.61094 .34182 .61714 .34943 .62947 .34532 .6233 .33766 Mtetra
.6233 .33766 .62947 .34532 .64185 .34118 .63572 .33349 Mtetra
.63572 .33349 .64185 .34118 .65429 .33702 .6482 .3293 Mtetra
.6482 .3293 .65429 .33702 .66679 .33285 .66073 .32509 Mtetra
.66073 .32509 .66679 .33285 .67933 .32866 .67332 .32087 Mtetra
.67332 .32087 .67933 .32866 .69194 .32444 .68596 .31662 Mtetra
.68596 .31662 .69194 .32444 .7046 .32021 .69866 .31236 Mtetra
.69866 .31236 .7046 .32021 .71732 .31597 .71142 .30807 Mtetra
.71142 .30807 .71732 .31597 .73009 .3117 .72423 .30377 Mtetra
.72423 .30377 .73009 .3117 .74293 .30741 .73711 .29944 Mtetra
.73711 .29944 .74293 .30741 .75582 .3031 .75004 .2951 Mtetra
.75004 .2951 .75582 .3031 .76877 .29878 .76303 .29074 Mtetra
.76303 .29074 .76877 .29878 .78177 .29443 .77608 .28636 Mtetra
.77608 .28636 .78177 .29443 .79484 .29007 .78919 .28195 Mtetra
.78919 .28195 .79484 .29007 .80797 .28568 .80235 .27753 Mtetra
.80235 .27753 .80797 .28568 .82115 .28128 .81558 .27309 Mtetra
.81558 .27309 .82115 .28128 .8344 .27685 .82887 .26863 Mtetra
.82887 .26863 .8344 .27685 .8477 .2724 .84222 .26414 Mtetra
.84222 .26414 .8477 .2724 .86107 .26794 .85563 .25964 Mtetra
.646 .762 .934 r
.22766 .66755 .23543 .67385 .24692 .67044 .23918 .66411 Mtetra
.23918 .66411 .24692 .67044 .25846 .66702 .25076 .66067 Mtetra
.25076 .66067 .25846 .66702 .27005 .66359 .26238 .6572 Mtetra
.26238 .6572 .27005 .66359 .2817 .66014 .27406 .65372 Mtetra
.27406 .65372 .2817 .66014 .29339 .65667 .28578 .65023 Mtetra
.28578 .65023 .29339 .65667 .30514 .65319 .29756 .64672 Mtetra
.29756 .64672 .30514 .65319 .31694 .64969 .3094 .64319 Mtetra
.3094 .64319 .31694 .64969 .3288 .64618 .32128 .63965 Mtetra
.32128 .63965 .3288 .64618 .3407 .64265 .33322 .6361 Mtetra
.33322 .6361 .3407 .64265 .35267 .63911 .34522 .63252 Mtetra
.34522 .63252 .35267 .63911 .36468 .63555 .35726 .62893 Mtetra
.35726 .62893 .36468 .63555 .37675 .63197 .36937 .62533 Mtetra
.925 .745 .639 r
.36937 .62533 .37675 .63197 .39045 .58842 .38319 .58166 Mtetra
.65 .758 .929 r
.38319 .58166 .39045 .58842 .40249 .58476 .39527 .57797 Mtetra
.39527 .57797 .40249 .58476 .41458 .58109 .4074 .57426 Mtetra
.4074 .57426 .41458 .58109 .42673 .5774 .41958 .57054 Mtetra
.41958 .57054 .42673 .5774 .43894 .57369 .43182 .56681 Mtetra
.43182 .56681 .43894 .57369 .4512 .56997 .44411 .56305 Mtetra
.44411 .56305 .4512 .56997 .46351 .56623 .45647 .55928 Mtetra
.45647 .55928 .46351 .56623 .47588 .56247 .46887 .55549 Mtetra
.46887 .55549 .47588 .56247 .48831 .5587 .48134 .55169 Mtetra
.48134 .55169 .48831 .5587 .5008 .55491 .49386 .54786 Mtetra
.49386 .54786 .5008 .55491 .51334 .5511 .50644 .54402 Mtetra
.50644 .54402 .51334 .5511 .52594 .54727 .51908 .54016 Mtetra
.51908 .54016 .52594 .54727 .5386 .54343 .53177 .53629 Mtetra
.964 .709 .499 r
.53177 .53629 .5386 .54343 .54992 .36231 .54349 .35479 Mtetra
.664 .741 .908 r
.54349 .35479 .54992 .36231 .56202 .35825 .55562 .3507 Mtetra
.55562 .3507 .56202 .35825 .57417 .35416 .5678 .34658 Mtetra
.5678 .34658 .57417 .35416 .58637 .35007 .58004 .34245 Mtetra
.58004 .34245 .58637 .35007 .59863 .34595 .59233 .3383 Mtetra
.59233 .3383 .59863 .34595 .61094 .34182 .60468 .33414 Mtetra
.60468 .33414 .61094 .34182 .6233 .33766 .61708 .32995 Mtetra
.61708 .32995 .6233 .33766 .63572 .33349 .62954 .32574 Mtetra
.62954 .32574 .63572 .33349 .6482 .3293 .64206 .32152 Mtetra
.64206 .32152 .6482 .3293 .66073 .32509 .65462 .31728 Mtetra
.65462 .31728 .66073 .32509 .67332 .32087 .66725 .31301 Mtetra
.66725 .31301 .67332 .32087 .68596 .31662 .67993 .30873 Mtetra
.67993 .30873 .68596 .31662 .69866 .31236 .69267 .30443 Mtetra
.69267 .30443 .69866 .31236 .71142 .30807 .70547 .30011 Mtetra
.70547 .30011 .71142 .30807 .72423 .30377 .71832 .29577 Mtetra
.71832 .29577 .72423 .30377 .73711 .29944 .73124 .29141 Mtetra
.73124 .29141 .73711 .29944 .75004 .2951 .74421 .28703 Mtetra
.74421 .28703 .75004 .2951 .76303 .29074 .75724 .28263 Mtetra
.75724 .28263 .76303 .29074 .77608 .28636 .77033 .27821 Mtetra
.77033 .27821 .77608 .28636 .78919 .28195 .78348 .27377 Mtetra
.78348 .27377 .78919 .28195 .80235 .27753 .79669 .26932 Mtetra
.79669 .26932 .80235 .27753 .81558 .27309 .80997 .26483 Mtetra
.80997 .26483 .81558 .27309 .82887 .26863 .8233 .26033 Mtetra
.8233 .26033 .82887 .26863 .84222 .26414 .83669 .25581 Mtetra
.83669 .25581 .84222 .26414 .85563 .25964 .85015 .25127 Mtetra
.562 .367 .574 r
.22889 .55778 .22766 .66755 .23918 .66411 .24012 .5542 Mtetra
.24012 .5542 .23918 .66411 .25076 .66067 .25139 .5506 Mtetra
.25139 .5506 .25076 .66067 .26238 .6572 .26272 .54699 Mtetra
.26272 .54699 .26238 .6572 .27406 .65372 .27409 .54336 Mtetra
.27409 .54336 .27406 .65372 .28578 .65023 .28551 .53972 Mtetra
.28551 .53972 .28578 .65023 .29756 .64672 .29699 .53606 Mtetra
.29699 .53606 .29756 .64672 .3094 .64319 .30851 .53238 Mtetra
.30851 .53238 .3094 .64319 .32128 .63965 .32008 .52869 Mtetra
.32008 .52869 .32128 .63965 .33322 .6361 .33171 .52498 Mtetra
.33171 .52498 .33322 .6361 .34522 .63252 .34338 .52126 Mtetra
.34338 .52126 .34522 .63252 .35726 .62893 .35511 .51752 Mtetra
.35511 .51752 .35726 .62893 .36937 .62533 .36689 .51376 Mtetra
.393 .236 .547 r
.36689 .51376 .36937 .62533 .38319 .58166 .37703 .54859 Mtetra
.597 .459 .665 r
.37703 .54859 .38319 .58166 .39527 .57797 .38904 .54485 Mtetra
.38904 .54485 .39527 .57797 .4074 .57426 .40111 .54108 Mtetra
.40111 .54108 .4074 .57426 .41958 .57054 .41324 .5373 Mtetra
.41324 .5373 .41958 .57054 .43182 .56681 .42542 .5335 Mtetra
.42542 .5335 .43182 .56681 .44411 .56305 .43766 .52969 Mtetra
.43766 .52969 .44411 .56305 .45647 .55928 .44995 .52585 Mtetra
.44995 .52585 .45647 .55928 .46887 .55549 .4623 .522 Mtetra
.4623 .522 .46887 .55549 .48134 .55169 .4747 .51813 Mtetra
.4747 .51813 .48134 .55169 .49386 .54786 .48716 .51425 Mtetra
.48716 .51425 .49386 .54786 .50644 .54402 .49968 .51034 Mtetra
.49968 .51034 .50644 .54402 .51908 .54016 .51225 .50642 Mtetra
.51225 .50642 .51908 .54016 .53177 .53629 .52489 .50248 Mtetra
.919 .663 .534 r
.52489 .50248 .53177 .53629 .54349 .35479 .537 .34722 Mtetra
.664 .741 .908 r
.537 .34722 .54349 .35479 .55562 .3507 .54917 .34309 Mtetra
.54917 .34309 .55562 .3507 .5678 .34658 .56139 .33894 Mtetra
.56139 .33894 .5678 .34658 .58004 .34245 .57366 .33478 Mtetra
.57366 .33478 .58004 .34245 .59233 .3383 .58599 .33059 Mtetra
.58599 .33059 .59233 .3383 .60468 .33414 .59838 .32639 Mtetra
.59838 .32639 .60468 .33414 .61708 .32995 .61082 .32217 Mtetra
.61082 .32217 .61708 .32995 .62954 .32574 .62331 .31793 Mtetra
.62331 .31793 .62954 .32574 .64206 .32152 .63586 .31367 Mtetra
.63586 .31367 .64206 .32152 .65462 .31728 .64847 .30939 Mtetra
.64847 .30939 .65462 .31728 .66725 .31301 .66113 .30509 Mtetra
.66113 .30509 .66725 .31301 .67993 .30873 .67385 .30078 Mtetra
.67385 .30078 .67993 .30873 .69267 .30443 .68663 .29644 Mtetra
.68663 .29644 .69267 .30443 .70547 .30011 .69947 .29208 Mtetra
.69947 .29208 .70547 .30011 .71832 .29577 .71237 .28771 Mtetra
.71237 .28771 .71832 .29577 .73124 .29141 .72532 .28331 Mtetra
.72532 .28331 .73124 .29141 .74421 .28703 .73833 .2789 Mtetra
.73833 .2789 .74421 .28703 .75724 .28263 .75141 .27446 Mtetra
.75141 .27446 .75724 .28263 .77033 .27821 .76454 .27 Mtetra
.76454 .27 .77033 .27821 .78348 .27377 .77773 .26553 Mtetra
.77773 .26553 .78348 .27377 .79669 .26932 .79099 .26103 Mtetra
.79099 .26103 .79669 .26932 .80997 .26483 .8043 .25651 Mtetra
.8043 .25651 .80997 .26483 .8233 .26033 .81768 .25197 Mtetra
.81768 .25197 .8233 .26033 .83669 .25581 .83112 .24741 Mtetra
.83112 .24741 .83669 .25581 .85015 .25127 .84462 .24283 Mtetra
.655 .752 .921 r
.22127 .55115 .22889 .55778 .24012 .5542 .23253 .54754 Mtetra
.23253 .54754 .24012 .5542 .25139 .5506 .24383 .54392 Mtetra
.24383 .54392 .25139 .5506 .26272 .54699 .25518 .54028 Mtetra
.25518 .54028 .26272 .54699 .27409 .54336 .26659 .53662 Mtetra
.26659 .53662 .27409 .54336 .28551 .53972 .27804 .53295 Mtetra
.27804 .53295 .28551 .53972 .29699 .53606 .28954 .52926 Mtetra
.28954 .52926 .29699 .53606 .30851 .53238 .3011 .52555 Mtetra
.3011 .52555 .30851 .53238 .32008 .52869 .3127 .52183 Mtetra
.3127 .52183 .32008 .52869 .33171 .52498 .32435 .51809 Mtetra
.32435 .51809 .33171 .52498 .34338 .52126 .33606 .51434 Mtetra
.33606 .51434 .34338 .52126 .35511 .51752 .34782 .51057 Mtetra
.34782 .51057 .35511 .51752 .36689 .51376 .35963 .50678 Mtetra
.928 .544 .224 r
.35963 .50678 .36689 .51376 .37703 .54859 .36971 .54166 Mtetra
.652 .756 .926 r
.36971 .54166 .37703 .54859 .38904 .54485 .38176 .53788 Mtetra
.38176 .53788 .38904 .54485 .40111 .54108 .39387 .53409 Mtetra
.39387 .53409 .40111 .54108 .41324 .5373 .40603 .53027 Mtetra
.40603 .53027 .41324 .5373 .42542 .5335 .41824 .52644 Mtetra
.41824 .52644 .42542 .5335 .43766 .52969 .43051 .52259 Mtetra
.43051 .52259 .43766 .52969 .44995 .52585 .44284 .51873 Mtetra
.44284 .51873 .44995 .52585 .4623 .522 .45522 .51485 Mtetra
.45522 .51485 .4623 .522 .4747 .51813 .46766 .51094 Mtetra
.46766 .51094 .4747 .51813 .48716 .51425 .48016 .50703 Mtetra
.48016 .50703 .48716 .51425 .49968 .51034 .49272 .50309 Mtetra
.49272 .50309 .49968 .51034 .51225 .50642 .50533 .49913 Mtetra
.50533 .49913 .51225 .50642 .52489 .50248 .518 .49516 Mtetra
.964 .712 .507 r
.518 .49516 .52489 .50248 .537 .34722 .53046 .33958 Mtetra
.664 .741 .908 r
.53046 .33958 .537 .34722 .54917 .34309 .54266 .33542 Mtetra
.54266 .33542 .54917 .34309 .56139 .33894 .55492 .33124 Mtetra
.55492 .33124 .56139 .33894 .57366 .33478 .56723 .32704 Mtetra
.56723 .32704 .57366 .33478 .58599 .33059 .5796 .32282 Mtetra
.5796 .32282 .58599 .33059 .59838 .32639 .59202 .31858 Mtetra
.59202 .31858 .59838 .32639 .61082 .32217 .60449 .31433 Mtetra
.60449 .31433 .61082 .32217 .62331 .31793 .61703 .31005 Mtetra
.61703 .31005 .62331 .31793 .63586 .31367 .62962 .30576 Mtetra
.62962 .30576 .63586 .31367 .64847 .30939 .64226 .30144 Mtetra
.64226 .30144 .64847 .30939 .66113 .30509 .65497 .29711 Mtetra
.65497 .29711 .66113 .30509 .67385 .30078 .66773 .29276 Mtetra
.66773 .29276 .67385 .30078 .68663 .29644 .68054 .28838 Mtetra
.68054 .28838 .68663 .29644 .69947 .29208 .69342 .28399 Mtetra
.69342 .28399 .69947 .29208 .71237 .28771 .70636 .27958 Mtetra
.70636 .27958 .71237 .28771 .72532 .28331 .71935 .27514 Mtetra
.71935 .27514 .72532 .28331 .73833 .2789 .73241 .27069 Mtetra
.73241 .27069 .73833 .2789 .75141 .27446 .74552 .26622 Mtetra
.74552 .26622 .75141 .27446 .76454 .27 .7587 .26172 Mtetra
.7587 .26172 .76454 .27 .77773 .26553 .77193 .25721 Mtetra
.77193 .25721 .77773 .26553 .79099 .26103 .78523 .25267 Mtetra
.78523 .25267 .79099 .26103 .8043 .25651 .79859 .24811 Mtetra
.79859 .24811 .8043 .25651 .81768 .25197 .81201 .24353 Mtetra
.81201 .24353 .81768 .25197 .83112 .24741 .82549 .23893 Mtetra
.82549 .23893 .83112 .24741 .84462 .24283 .83904 .23431 Mtetra
.655 .752 .921 r
.21359 .54448 .22127 .55115 .23253 .54754 .22487 .54084 Mtetra
.22487 .54084 .23253 .54754 .24383 .54392 .23621 .53718 Mtetra
.23621 .53718 .24383 .54392 .25518 .54028 .24759 .53351 Mtetra
.24759 .53351 .25518 .54028 .26659 .53662 .25902 .52983 Mtetra
.25902 .52983 .26659 .53662 .27804 .53295 .2705 .52612 Mtetra
.2705 .52612 .27804 .53295 .28954 .52926 .28204 .5224 Mtetra
.28204 .5224 .28954 .52926 .3011 .52555 .29362 .51867 Mtetra
.29362 .51867 .3011 .52555 .3127 .52183 .30526 .51492 Mtetra
.30526 .51492 .3127 .52183 .32435 .51809 .31694 .51115 Mtetra
.31694 .51115 .32435 .51809 .33606 .51434 .32868 .50736 Mtetra
.32868 .50736 .33606 .51434 .34782 .51057 .34047 .50356 Mtetra
.34047 .50356 .34782 .51057 .35963 .50678 .35231 .49974 Mtetra
.928 .544 .224 r
.35231 .49974 .35963 .50678 .36971 .54166 .36233 .53467 Mtetra
.652 .756 .926 r
.36233 .53467 .36971 .54166 .38176 .53788 .37442 .53086 Mtetra
.37442 .53086 .38176 .53788 .39387 .53409 .38656 .52703 Mtetra
.38656 .52703 .39387 .53409 .40603 .53027 .39875 .52319 Mtetra
.39875 .52319 .40603 .53027 .41824 .52644 .411 .51932 Mtetra
.411 .51932 .41824 .52644 .43051 .52259 .42331 .51544 Mtetra
.42331 .51544 .43051 .52259 .44284 .51873 .43567 .51155 Mtetra
.43567 .51155 .44284 .51873 .45522 .51485 .44809 .50763 Mtetra
.44809 .50763 .45522 .51485 .46766 .51094 .46057 .50369 Mtetra
.46057 .50369 .46766 .51094 .48016 .50703 .4731 .49974 Mtetra
.4731 .49974 .48016 .50703 .49272 .50309 .48569 .49577 Mtetra
.48569 .49577 .49272 .50309 .50533 .49913 .49834 .49178 Mtetra
.49834 .49178 .50533 .49913 .518 .49516 .51105 .48777 Mtetra
.964 .712 .507 r
.51105 .48777 .518 .49516 .53046 .33958 .52387 .33188 Mtetra
.664 .741 .908 r
.52387 .33188 .53046 .33958 .54266 .33542 .53611 .32769 Mtetra
.53611 .32769 .54266 .33542 .55492 .33124 .5484 .32347 Mtetra
.5484 .32347 .55492 .33124 .56723 .32704 .56075 .31924 Mtetra
.56075 .31924 .56723 .32704 .5796 .32282 .57315 .31498 Mtetra
.57315 .31498 .5796 .32282 .59202 .31858 .58561 .31071 Mtetra
.58561 .31071 .59202 .31858 .60449 .31433 .59812 .30642 Mtetra
.59812 .30642 .60449 .31433 .61703 .31005 .61069 .30211 Mtetra
.61069 .30211 .61703 .31005 .62962 .30576 .62332 .29778 Mtetra
.62332 .29778 .62962 .30576 .64226 .30144 .636 .29343 Mtetra
.636 .29343 .64226 .30144 .65497 .29711 .64874 .28906 Mtetra
.64874 .28906 .65497 .29711 .66773 .29276 .66155 .28467 Mtetra
.66155 .28467 .66773 .29276 .68054 .28838 .6744 .28026 Mtetra
.6744 .28026 .68054 .28838 .69342 .28399 .68732 .27583 Mtetra
.68732 .27583 .69342 .28399 .70636 .27958 .7003 .27138 Mtetra
.7003 .27138 .70636 .27958 .71935 .27514 .71333 .26691 Mtetra
.71333 .26691 .71935 .27514 .73241 .27069 .72643 .26241 Mtetra
.72643 .26241 .73241 .27069 .74552 .26622 .73959 .2579 Mtetra
.73959 .2579 .74552 .26622 .7587 .26172 .7528 .25337 Mtetra
.7528 .25337 .7587 .26172 .77193 .25721 .76608 .24881 Mtetra
.76608 .24881 .77193 .25721 .78523 .25267 .77942 .24424 Mtetra
.77942 .24424 .78523 .25267 .79859 .24811 .79283 .23964 Mtetra
.79283 .23964 .79859 .24811 .81201 .24353 .80629 .23502 Mtetra
.80629 .23502 .81201 .24353 .82549 .23893 .81982 .23039 Mtetra
.81982 .23039 .82549 .23893 .83904 .23431 .83341 .22572 Mtetra
.655 .752 .921 r
.20585 .53775 .21359 .54448 .22487 .54084 .21716 .53408 Mtetra
.21716 .53408 .22487 .54084 .23621 .53718 .22852 .53039 Mtetra
.22852 .53039 .23621 .53718 .24759 .53351 .23993 .52669 Mtetra
.23993 .52669 .24759 .53351 .25902 .52983 .2514 .52298 Mtetra
.2514 .52298 .25902 .52983 .2705 .52612 .26291 .51924 Mtetra
.26291 .51924 .2705 .52612 .28204 .5224 .27447 .51549 Mtetra
.27447 .51549 .28204 .5224 .29362 .51867 .28609 .51173 Mtetra
.28609 .51173 .29362 .51867 .30526 .51492 .29775 .50795 Mtetra
.29775 .50795 .30526 .51492 .31694 .51115 .30947 .50415 Mtetra
.30947 .50415 .31694 .51115 .32868 .50736 .32124 .50033 Mtetra
.32124 .50033 .32868 .50736 .34047 .50356 .33306 .4965 Mtetra
.33306 .4965 .34047 .50356 .35231 .49974 .34494 .49264 Mtetra
.928 .544 .224 r
.34494 .49264 .35231 .49974 .36233 .53467 .35489 .52762 Mtetra
.652 .756 .926 r
.35489 .52762 .36233 .53467 .37442 .53086 .36701 .52378 Mtetra
.36701 .52378 .37442 .53086 .38656 .52703 .37919 .51992 Mtetra
.37919 .51992 .38656 .52703 .39875 .52319 .39141 .51604 Mtetra
.39141 .51604 .39875 .52319 .411 .51932 .4037 .51215 Mtetra
.4037 .51215 .411 .51932 .42331 .51544 .41604 .50823 Mtetra
.41604 .50823 .42331 .51544 .43567 .51155 .42844 .5043 Mtetra
.42844 .5043 .43567 .51155 .44809 .50763 .4409 .50035 Mtetra
.4409 .50035 .44809 .50763 .46057 .50369 .45341 .49638 Mtetra
.45341 .49638 .46057 .50369 .4731 .49974 .46598 .4924 Mtetra
.46598 .4924 .4731 .49974 .48569 .49577 .47861 .48839 Mtetra
.47861 .48839 .48569 .49577 .49834 .49178 .4913 .48437 Mtetra
.4913 .48437 .49834 .49178 .51105 .48777 .50405 .48033 Mtetra
.964 .712 .507 r
.50405 .48033 .51105 .48777 .52387 .33188 .51722 .32412 Mtetra
.664 .741 .908 r
.51722 .32412 .52387 .33188 .53611 .32769 .5295 .31989 Mtetra
.5295 .31989 .53611 .32769 .5484 .32347 .54182 .31564 Mtetra
.54182 .31564 .5484 .32347 .56075 .31924 .55421 .31137 Mtetra
.55421 .31137 .56075 .31924 .57315 .31498 .56665 .30708 Mtetra
.56665 .30708 .57315 .31498 .58561 .31071 .57914 .30277 Mtetra
.57914 .30277 .58561 .31071 .59812 .30642 .59169 .29844 Mtetra
.59169 .29844 .59812 .30642 .61069 .30211 .6043 .2941 Mtetra
.6043 .2941 .61069 .30211 .62332 .29778 .61697 .28973 Mtetra
.61697 .28973 .62332 .29778 .636 .29343 .62969 .28534 Mtetra
.62969 .28534 .636 .29343 .64874 .28906 .64247 .28094 Mtetra
.64247 .28094 .64874 .28906 .66155 .28467 .65531 .27651 Mtetra
.65531 .27651 .66155 .28467 .6744 .28026 .66821 .27206 Mtetra
.66821 .27206 .6744 .28026 .68732 .27583 .68117 .26759 Mtetra
.68117 .26759 .68732 .27583 .7003 .27138 .69419 .26311 Mtetra
.69419 .26311 .7003 .27138 .71333 .26691 .70726 .2586 Mtetra
.70726 .2586 .71333 .26691 .72643 .26241 .7204 .25407 Mtetra
.7204 .25407 .72643 .26241 .73959 .2579 .7336 .24952 Mtetra
.7336 .24952 .73959 .2579 .7528 .25337 .74686 .24494 Mtetra
.74686 .24494 .7528 .25337 .76608 .24881 .76018 .24035 Mtetra
.76018 .24035 .76608 .24881 .77942 .24424 .77357 .23574 Mtetra
.77357 .23574 .77942 .24424 .79283 .23964 .78702 .2311 Mtetra
.78702 .2311 .79283 .23964 .80629 .23502 .80053 .22644 Mtetra
.80053 .22644 .80629 .23502 .81982 .23039 .8141 .22176 Mtetra
.8141 .22176 .81982 .23039 .83341 .22572 .82774 .21706 Mtetra
.655 .752 .921 r
.19804 .53096 .20585 .53775 .21716 .53408 .20938 .52726 Mtetra
.20938 .52726 .21716 .53408 .22852 .53039 .22077 .52355 Mtetra
.22077 .52355 .22852 .53039 .23993 .52669 .23222 .51982 Mtetra
.23222 .51982 .23993 .52669 .2514 .52298 .24371 .51607 Mtetra
.24371 .51607 .2514 .52298 .26291 .51924 .25525 .51231 Mtetra
.25525 .51231 .26291 .51924 .27447 .51549 .26684 .50853 Mtetra
.26684 .50853 .27447 .51549 .28609 .51173 .27849 .50473 Mtetra
.27849 .50473 .28609 .51173 .29775 .50795 .29018 .50092 Mtetra
.29018 .50092 .29775 .50795 .30947 .50415 .30193 .49709 Mtetra
.30193 .49709 .30947 .50415 .32124 .50033 .31373 .49324 Mtetra
.31373 .49324 .32124 .50033 .33306 .4965 .32559 .48937 Mtetra
.32559 .48937 .33306 .4965 .34494 .49264 .3375 .48549 Mtetra
.928 .544 .224 r
.3375 .48549 .34494 .49264 .35489 .52762 .34739 .52052 Mtetra
.652 .756 .926 r
.34739 .52052 .35489 .52762 .36701 .52378 .35954 .51664 Mtetra
.35954 .51664 .36701 .52378 .37919 .51992 .37175 .51275 Mtetra
.37175 .51275 .37919 .51992 .39141 .51604 .38402 .50884 Mtetra
.38402 .50884 .39141 .51604 .4037 .51215 .39634 .50491 Mtetra
.39634 .50491 .4037 .51215 .41604 .50823 .40871 .50096 Mtetra
.40871 .50096 .41604 .50823 .42844 .5043 .42115 .497 Mtetra
.42115 .497 .42844 .5043 .4409 .50035 .43364 .49301 Mtetra
.43364 .49301 .4409 .50035 .45341 .49638 .44619 .48901 Mtetra
.44619 .48901 .45341 .49638 .46598 .4924 .4588 .48499 Mtetra
.4588 .48499 .46598 .4924 .47861 .48839 .47147 .48095 Mtetra
.47147 .48095 .47861 .48839 .4913 .48437 .48419 .47689 Mtetra
.48419 .47689 .4913 .48437 .50405 .48033 .49698 .47281 Mtetra
.964 .712 .507 r
.49698 .47281 .50405 .48033 .51722 .32412 .51052 .31629 Mtetra
.664 .741 .908 r
.51052 .31629 .51722 .32412 .5295 .31989 .52283 .31203 Mtetra
.52283 .31203 .5295 .31989 .54182 .31564 .53519 .30774 Mtetra
.53519 .30774 .54182 .31564 .55421 .31137 .54761 .30344 Mtetra
.54761 .30344 .55421 .31137 .56665 .30708 .56009 .29911 Mtetra
.56009 .29911 .56665 .30708 .57914 .30277 .57262 .29477 Mtetra
.57262 .29477 .57914 .30277 .59169 .29844 .58521 .2904 Mtetra
.58521 .2904 .59169 .29844 .6043 .2941 .59786 .28602 Mtetra
.59786 .28602 .6043 .2941 .61697 .28973 .61056 .28162 Mtetra
.61056 .28162 .61697 .28973 .62969 .28534 .62333 .27719 Mtetra
.62333 .27719 .62969 .28534 .64247 .28094 .63615 .27275 Mtetra
.63615 .27275 .64247 .28094 .65531 .27651 .64903 .26828 Mtetra
.64903 .26828 .65531 .27651 .66821 .27206 .66197 .2638 Mtetra
.66197 .2638 .66821 .27206 .68117 .26759 .67496 .25929 Mtetra
.67496 .25929 .68117 .26759 .69419 .26311 .68802 .25477 Mtetra
.68802 .25477 .69419 .26311 .70726 .2586 .70114 .25022 Mtetra
.70114 .25022 .70726 .2586 .7204 .25407 .71432 .24565 Mtetra
.71432 .24565 .7204 .25407 .7336 .24952 .72756 .24106 Mtetra
.72756 .24106 .7336 .24952 .74686 .24494 .74087 .23645 Mtetra
.74087 .23645 .74686 .24494 .76018 .24035 .75423 .23182 Mtetra
.75423 .23182 .76018 .24035 .77357 .23574 .76766 .22716 Mtetra
.76766 .22716 .77357 .23574 .78702 .2311 .78115 .22248 Mtetra
.78115 .22248 .78702 .2311 .80053 .22644 .79471 .21779 Mtetra
.79471 .21779 .80053 .22644 .8141 .22176 .80833 .21306 Mtetra
.80833 .21306 .8141 .22176 .82774 .21706 .82201 .20832 Mtetra
.655 .752 .921 r
.19017 .52412 .19804 .53096 .20938 .52726 .20154 .52039 Mtetra
.20154 .52039 .20938 .52726 .22077 .52355 .21296 .51665 Mtetra
.21296 .51665 .22077 .52355 .23222 .51982 .22443 .51289 Mtetra
.22443 .51289 .23222 .51982 .24371 .51607 .23596 .50911 Mtetra
.23596 .50911 .24371 .51607 .25525 .51231 .24753 .50532 Mtetra
.24753 .50532 .25525 .51231 .26684 .50853 .25915 .50151 Mtetra
.25915 .50151 .26684 .50853 .27849 .50473 .27083 .49768 Mtetra
.27083 .49768 .27849 .50473 .29018 .50092 .28256 .49383 Mtetra
.28256 .49383 .29018 .50092 .30193 .49709 .29434 .48997 Mtetra
.29434 .48997 .30193 .49709 .31373 .49324 .30617 .48609 Mtetra
.30617 .48609 .31373 .49324 .32559 .48937 .31806 .48219 Mtetra
.31806 .48219 .32559 .48937 .3375 .48549 .33 .47828 Mtetra
.928 .544 .224 r
.33 .47828 .3375 .48549 .34739 .52052 .33983 .51335 Mtetra
.652 .756 .926 r
.33983 .51335 .34739 .52052 .35954 .51664 .35201 .50944 Mtetra
.35201 .50944 .35954 .51664 .37175 .51275 .36426 .50551 Mtetra
.36426 .50551 .37175 .51275 .38402 .50884 .37655 .50157 Mtetra
.37655 .50157 .38402 .50884 .39634 .50491 .38891 .49761 Mtetra
.38891 .49761 .39634 .50491 .40871 .50096 .40132 .49363 Mtetra
.40132 .49363 .40871 .50096 .42115 .497 .41379 .48963 Mtetra
.41379 .48963 .42115 .497 .43364 .49301 .42632 .48561 Mtetra
.42632 .48561 .43364 .49301 .44619 .48901 .43891 .48157 Mtetra
.43891 .48157 .44619 .48901 .4588 .48499 .45155 .47752 Mtetra
.45155 .47752 .4588 .48499 .47147 .48095 .46426 .47344 Mtetra
.46426 .47344 .47147 .48095 .48419 .47689 .47702 .46935 Mtetra
.47702 .46935 .48419 .47689 .49698 .47281 .48985 .46524 Mtetra
.964 .712 .507 r
.48985 .46524 .49698 .47281 .51052 .31629 .50376 .3084 Mtetra
.664 .741 .908 r
.50376 .3084 .51052 .31629 .52283 .31203 .51611 .3041 Mtetra
.51611 .3041 .52283 .31203 .53519 .30774 .52851 .29978 Mtetra
.52851 .29978 .53519 .30774 .54761 .30344 .54097 .29544 Mtetra
.54097 .29544 .54761 .30344 .56009 .29911 .55348 .29108 Mtetra
.55348 .29108 .56009 .29911 .57262 .29477 .56605 .28669 Mtetra
.56605 .28669 .57262 .29477 .58521 .2904 .57868 .28229 Mtetra
.57868 .28229 .58521 .2904 .59786 .28602 .59136 .27787 Mtetra
.59136 .27787 .59786 .28602 .61056 .28162 .60411 .27343 Mtetra
.60411 .27343 .61056 .28162 .62333 .27719 .61691 .26897 Mtetra
.61691 .26897 .62333 .27719 .63615 .27275 .62977 .26449 Mtetra
.62977 .26449 .63615 .27275 .64903 .26828 .64269 .25999 Mtetra
.64269 .25999 .64903 .26828 .66197 .2638 .65567 .25546 Mtetra
.65567 .25546 .66197 .2638 .67496 .25929 .66871 .25092 Mtetra
.66871 .25092 .67496 .25929 .68802 .25477 .68181 .24635 Mtetra
.68181 .24635 .68802 .25477 .70114 .25022 .69497 .24177 Mtetra
.69497 .24177 .70114 .25022 .71432 .24565 .70819 .23716 Mtetra
.70819 .23716 .71432 .24565 .72756 .24106 .72148 .23253 Mtetra
.72148 .23253 .72756 .24106 .74087 .23645 .73482 .22788 Mtetra
.73482 .22788 .74087 .23645 .75423 .23182 .74823 .2232 Mtetra
.74823 .2232 .75423 .23182 .76766 .22716 .7617 .21851 Mtetra
.7617 .21851 .76766 .22716 .78115 .22248 .77524 .21379 Mtetra
.77524 .21379 .78115 .22248 .79471 .21779 .78884 .20905 Mtetra
.78884 .20905 .79471 .21779 .80833 .21306 .80251 .20429 Mtetra
.80251 .20429 .80833 .21306 .82201 .20832 .81623 .19951 Mtetra
.655 .752 .921 r
.18224 .51723 .19017 .52412 .20154 .52039 .19364 .51347 Mtetra
.19364 .51347 .20154 .52039 .21296 .51665 .20509 .50969 Mtetra
.20509 .50969 .21296 .51665 .22443 .51289 .21659 .5059 Mtetra
.21659 .5059 .22443 .51289 .23596 .50911 .22814 .50209 Mtetra
.22814 .50209 .23596 .50911 .24753 .50532 .23974 .49827 Mtetra
.23974 .49827 .24753 .50532 .25915 .50151 .2514 .49442 Mtetra
.2514 .49442 .25915 .50151 .27083 .49768 .2631 .49056 Mtetra
.2631 .49056 .27083 .49768 .28256 .49383 .27486 .48669 Mtetra
.27486 .48669 .28256 .49383 .29434 .48997 .28668 .48279 Mtetra
.28668 .48279 .29434 .48997 .30617 .48609 .29854 .47888 Mtetra
.29854 .47888 .30617 .48609 .31806 .48219 .31046 .47495 Mtetra
.31046 .47495 .31806 .48219 .33 .47828 .32243 .471 Mtetra
.928 .544 .224 r
.32243 .471 .33 .47828 .33983 .51335 .3322 .50612 Mtetra
.652 .756 .926 r
.3322 .50612 .33983 .51335 .35201 .50944 .34442 .50218 Mtetra
.34442 .50218 .35201 .50944 .36426 .50551 .3567 .49822 Mtetra
.3567 .49822 .36426 .50551 .37655 .50157 .36903 .49424 Mtetra
.36903 .49424 .37655 .50157 .38891 .49761 .38142 .49024 Mtetra
.38142 .49024 .38891 .49761 .40132 .49363 .39387 .48623 Mtetra
.39387 .48623 .40132 .49363 .41379 .48963 .40638 .48219 Mtetra
.40638 .48219 .41379 .48963 .42632 .48561 .41894 .47814 Mtetra
.41894 .47814 .42632 .48561 .43891 .48157 .43157 .47407 Mtetra
.43157 .47407 .43891 .48157 .45155 .47752 .44425 .46998 Mtetra
.44425 .46998 .45155 .47752 .46426 .47344 .45699 .46587 Mtetra
.45699 .46587 .46426 .47344 .47702 .46935 .46979 .46174 Mtetra
.46979 .46174 .47702 .46935 .48985 .46524 .48266 .45759 Mtetra
.964 .712 .507 r
.48266 .45759 .48985 .46524 .50376 .3084 .49695 .30044 Mtetra
.664 .741 .908 r
.49695 .30044 .50376 .3084 .51611 .3041 .50933 .29611 Mtetra
.50933 .29611 .51611 .3041 .52851 .29978 .52177 .29175 Mtetra
.52177 .29175 .52851 .29978 .54097 .29544 .53426 .28737 Mtetra
.53426 .28737 .54097 .29544 .55348 .29108 .54681 .28297 Mtetra
.54681 .28297 .55348 .29108 .56605 .28669 .55942 .27855 Mtetra
.55942 .27855 .56605 .28669 .57868 .28229 .57209 .27412 Mtetra
.57209 .27412 .57868 .28229 .59136 .27787 .58481 .26966 Mtetra
.58481 .26966 .59136 .27787 .60411 .27343 .59759 .26518 Mtetra
.59759 .26518 .60411 .27343 .61691 .26897 .61043 .26068 Mtetra
.61043 .26068 .61691 .26897 .62977 .26449 .62333 .25616 Mtetra
.62333 .25616 .62977 .26449 .64269 .25999 .63629 .25162 Mtetra
.63629 .25162 .64269 .25999 .65567 .25546 .64932 .24706 Mtetra
.64932 .24706 .65567 .25546 .66871 .25092 .6624 .24247 Mtetra
.6624 .24247 .66871 .25092 .68181 .24635 .67554 .23787 Mtetra
.67554 .23787 .68181 .24635 .69497 .24177 .68874 .23324 Mtetra
.68874 .23324 .69497 .24177 .70819 .23716 .70201 .22859 Mtetra
.70201 .22859 .70819 .23716 .72148 .23253 .71533 .22393 Mtetra
.71533 .22393 .72148 .23253 .73482 .22788 .72872 .21923 Mtetra
.72872 .21923 .73482 .22788 .74823 .2232 .74218 .21452 Mtetra
.74218 .21452 .74823 .2232 .7617 .21851 .75569 .20978 Mtetra
.75569 .20978 .7617 .21851 .77524 .21379 .76928 .20502 Mtetra
.76928 .20502 .77524 .21379 .78884 .20905 .78292 .20024 Mtetra
.78292 .20024 .78884 .20905 .80251 .20429 .79663 .19544 Mtetra
.79663 .19544 .80251 .20429 .81623 .19951 .81041 .19061 Mtetra
.655 .752 .921 r
.17424 .51028 .18224 .51723 .19364 .51347 .18567 .50649 Mtetra
.18567 .50649 .19364 .51347 .20509 .50969 .19715 .50268 Mtetra
.19715 .50268 .20509 .50969 .21659 .5059 .20868 .49886 Mtetra
.20868 .49886 .21659 .5059 .22814 .50209 .22026 .49502 Mtetra
.22026 .49502 .22814 .50209 .23974 .49827 .23189 .49116 Mtetra
.23189 .49116 .23974 .49827 .2514 .49442 .24358 .48728 Mtetra
.24358 .48728 .2514 .49442 .2631 .49056 .25532 .48339 Mtetra
.25532 .48339 .2631 .49056 .27486 .48669 .26711 .47948 Mtetra
.26711 .47948 .27486 .48669 .28668 .48279 .27895 .47556 Mtetra
.27895 .47556 .28668 .48279 .29854 .47888 .29085 .47161 Mtetra
.29085 .47161 .29854 .47888 .31046 .47495 .3028 .46765 Mtetra
.3028 .46765 .31046 .47495 .32243 .471 .31481 .46367 Mtetra
.928 .544 .224 r
.31481 .46367 .32243 .471 .3322 .50612 .3245 .49883 Mtetra
.652 .756 .926 r
.3245 .49883 .3322 .50612 .34442 .50218 .33676 .49485 Mtetra
.33676 .49485 .34442 .50218 .3567 .49822 .34907 .49086 Mtetra
.34907 .49086 .3567 .49822 .36903 .49424 .36144 .48685 Mtetra
.36144 .48685 .36903 .49424 .38142 .49024 .37387 .48282 Mtetra
.37387 .48282 .38142 .49024 .39387 .48623 .38635 .47877 Mtetra
.38635 .47877 .39387 .48623 .40638 .48219 .39889 .4747 Mtetra
.39889 .4747 .40638 .48219 .41894 .47814 .4115 .47061 Mtetra
.4115 .47061 .41894 .47814 .43157 .47407 .42416 .4665 Mtetra
.42416 .4665 .43157 .47407 .44425 .46998 .43688 .46238 Mtetra
.43688 .46238 .44425 .46998 .45699 .46587 .44966 .45823 Mtetra
.44966 .45823 .45699 .46587 .46979 .46174 .4625 .45407 Mtetra
.4625 .45407 .46979 .46174 .48266 .45759 .4754 .44988 Mtetra
.964 .712 .507 r
.4754 .44988 .48266 .45759 .49695 .30044 .49008 .29242 Mtetra
.664 .741 .908 r
.49008 .29242 .49695 .30044 .50933 .29611 .5025 .28804 Mtetra
.5025 .28804 .50933 .29611 .52177 .29175 .51497 .28365 Mtetra
.51497 .28365 .52177 .29175 .53426 .28737 .5275 .27924 Mtetra
.5275 .27924 .53426 .28737 .54681 .28297 .54009 .2748 Mtetra
.54009 .2748 .54681 .28297 .55942 .27855 .55274 .27035 Mtetra
.55274 .27035 .55942 .27855 .57209 .27412 .56544 .26587 Mtetra
.56544 .26587 .57209 .27412 .58481 .26966 .5782 .26137 Mtetra
.5782 .26137 .58481 .26966 .59759 .26518 .59102 .25686 Mtetra
.59102 .25686 .59759 .26518 .61043 .26068 .60391 .25232 Mtetra
.60391 .25232 .61043 .26068 .62333 .25616 .61685 .24776 Mtetra
.61685 .24776 .62333 .25616 .63629 .25162 .62985 .24318 Mtetra
.62985 .24318 .63629 .25162 .64932 .24706 .64291 .23858 Mtetra
.64291 .23858 .64932 .24706 .6624 .24247 .65603 .23396 Mtetra
.65603 .23396 .6624 .24247 .67554 .23787 .66921 .22931 Mtetra
.66921 .22931 .67554 .23787 .68874 .23324 .68246 .22464 Mtetra
.68246 .22464 .68874 .23324 .70201 .22859 .69577 .21996 Mtetra
.69577 .21996 .70201 .22859 .71533 .22393 .70914 .21525 Mtetra
.70914 .21525 .71533 .22393 .72872 .21923 .72257 .21051 Mtetra
.72257 .21051 .72872 .21923 .74218 .21452 .73607 .20576 Mtetra
.73607 .20576 .74218 .21452 .75569 .20978 .74963 .20098 Mtetra
.74963 .20098 .75569 .20978 .76928 .20502 .76326 .19618 Mtetra
.76326 .19618 .76928 .20502 .78292 .20024 .77695 .19136 Mtetra
.77695 .19136 .78292 .20024 .79663 .19544 .79071 .18651 Mtetra
.79071 .18651 .79663 .19544 .81041 .19061 .80453 .18164 Mtetra
.655 .752 .921 r
.16618 .50327 .17424 .51028 .18567 .50649 .17764 .49945 Mtetra
.17764 .49945 .18567 .50649 .19715 .50268 .18915 .49561 Mtetra
.18915 .49561 .19715 .50268 .20868 .49886 .2007 .49175 Mtetra
.2007 .49175 .20868 .49886 .22026 .49502 .21232 .48788 Mtetra
.21232 .48788 .22026 .49502 .23189 .49116 .22398 .48399 Mtetra
.22398 .48399 .23189 .49116 .24358 .48728 .23569 .48009 Mtetra
.23569 .48009 .24358 .48728 .25532 .48339 .24746 .47616 Mtetra
.24746 .47616 .25532 .48339 .26711 .47948 .25929 .47222 Mtetra
.25929 .47222 .26711 .47948 .27895 .47556 .27116 .46826 Mtetra
.27116 .46826 .27895 .47556 .29085 .47161 .28309 .46428 Mtetra
.28309 .46428 .29085 .47161 .3028 .46765 .29508 .46028 Mtetra
.29508 .46028 .3028 .46765 .31481 .46367 .30711 .45627 Mtetra
.928 .544 .224 r
.30711 .45627 .31481 .46367 .3245 .49883 .31674 .49147 Mtetra
.652 .756 .926 r
.31674 .49147 .3245 .49883 .33676 .49485 .32903 .48747 Mtetra
.32903 .48747 .33676 .49485 .34907 .49086 .34138 .48344 Mtetra
.34138 .48344 .34907 .49086 .36144 .48685 .35378 .47939 Mtetra
.35378 .47939 .36144 .48685 .37387 .48282 .36625 .47533 Mtetra
.36625 .47533 .37387 .48282 .38635 .47877 .37877 .47124 Mtetra
.37877 .47124 .38635 .47877 .39889 .4747 .39135 .46714 Mtetra
.39135 .46714 .39889 .4747 .4115 .47061 .40399 .46301 Mtetra
.40399 .46301 .4115 .47061 .42416 .4665 .41669 .45887 Mtetra
.41669 .45887 .42416 .4665 .43688 .46238 .42944 .45471 Mtetra
.42944 .45471 .43688 .46238 .44966 .45823 .44226 .45053 Mtetra
.44226 .45053 .44966 .45823 .4625 .45407 .45514 .44633 Mtetra
.45514 .44633 .4625 .45407 .4754 .44988 .46809 .4421 Mtetra
.964 .712 .507 r
.46809 .4421 .4754 .44988 .49008 .29242 .48315 .28433 Mtetra
.664 .741 .908 r
.48315 .28433 .49008 .29242 .5025 .28804 .49561 .27992 Mtetra
.49561 .27992 .5025 .28804 .51497 .28365 .50812 .27548 Mtetra
.50812 .27548 .51497 .28365 .5275 .27924 .52068 .27103 Mtetra
.52068 .27103 .5275 .27924 .54009 .2748 .53331 .26656 Mtetra
.53331 .26656 .54009 .2748 .55274 .27035 .54599 .26207 Mtetra
.54599 .26207 .55274 .27035 .56544 .26587 .55874 .25755 Mtetra
.55874 .25755 .56544 .26587 .5782 .26137 .57154 .25302 Mtetra
.57154 .25302 .5782 .26137 .59102 .25686 .5844 .24846 Mtetra
.5844 .24846 .59102 .25686 .60391 .25232 .59732 .24389 Mtetra
.59732 .24389 .60391 .25232 .61685 .24776 .6103 .23929 Mtetra
.6103 .23929 .61685 .24776 .62985 .24318 .62334 .23467 Mtetra
.62334 .23467 .62985 .24318 .64291 .23858 .63645 .23003 Mtetra
.63645 .23003 .64291 .23858 .65603 .23396 .64961 .22536 Mtetra
.64961 .22536 .65603 .23396 .66921 .22931 .66284 .22068 Mtetra
.66284 .22068 .66921 .22931 .68246 .22464 .67612 .21597 Mtetra
.67612 .21597 .68246 .22464 .69577 .21996 .68948 .21124 Mtetra
.68948 .21124 .69577 .21996 .70914 .21525 .70289 .20649 Mtetra
.70289 .20649 .70914 .21525 .72257 .21051 .71637 .20172 Mtetra
.71637 .20172 .72257 .21051 .73607 .20576 .72991 .19692 Mtetra
.72991 .19692 .73607 .20576 .74963 .20098 .74352 .1921 Mtetra
.74352 .1921 .74963 .20098 .76326 .19618 .75719 .18726 Mtetra
.75719 .18726 .76326 .19618 .77695 .19136 .77093 .18239 Mtetra
.77093 .18239 .77695 .19136 .79071 .18651 .78473 .1775 Mtetra
.78473 .1775 .79071 .18651 .80453 .18164 .7986 .17259 Mtetra
.655 .752 .921 r
.15805 .4962 .16618 .50327 .17764 .49945 .16954 .49235 Mtetra
.16954 .49235 .17764 .49945 .18915 .49561 .18107 .48848 Mtetra
.18107 .48848 .18915 .49561 .2007 .49175 .19266 .48459 Mtetra
.19266 .48459 .2007 .49175 .21232 .48788 .2043 .48069 Mtetra
.2043 .48069 .21232 .48788 .22398 .48399 .216 .47677 Mtetra
.216 .47677 .22398 .48399 .23569 .48009 .22775 .47283 Mtetra
.22775 .47283 .23569 .48009 .24746 .47616 .23955 .46887 Mtetra
.23955 .46887 .24746 .47616 .25929 .47222 .2514 .46489 Mtetra
.2514 .46489 .25929 .47222 .27116 .46826 .26331 .4609 Mtetra
.26331 .4609 .27116 .46826 .28309 .46428 .27527 .45689 Mtetra
.27527 .45689 .28309 .46428 .29508 .46028 .28729 .45286 Mtetra
.28729 .45286 .29508 .46028 .30711 .45627 .29936 .44881 Mtetra
.928 .544 .224 r
.29936 .44881 .30711 .45627 .31674 .49147 .30892 .48406 Mtetra
.652 .756 .926 r
.30892 .48406 .31674 .49147 .32903 .48747 .32124 .48002 Mtetra
.32124 .48002 .32903 .48747 .34138 .48344 .33362 .47595 Mtetra
.33362 .47595 .34138 .48344 .35378 .47939 .34606 .47187 Mtetra
.34606 .47187 .35378 .47939 .36625 .47533 .35856 .46777 Mtetra
.35856 .46777 .36625 .47533 .37877 .47124 .37112 .46365 Mtetra
.37112 .46365 .37877 .47124 .39135 .46714 .38374 .45951 Mtetra
.38374 .45951 .39135 .46714 .40399 .46301 .39641 .45535 Mtetra
.39641 .45535 .40399 .46301 .41669 .45887 .40915 .45117 Mtetra
.40915 .45117 .41669 .45887 .42944 .45471 .42195 .44697 Mtetra
.42195 .44697 .42944 .45471 .44226 .45053 .4348 .44275 Mtetra
.4348 .44275 .44226 .45053 .45514 .44633 .44772 .43852 Mtetra
.44772 .43852 .45514 .44633 .46809 .4421 .4607 .43426 Mtetra
.964 .712 .507 r
.4607 .43426 .46809 .4421 .48315 .28433 .47617 .27617 Mtetra
.664 .741 .908 r
.47617 .27617 .48315 .28433 .49561 .27992 .48866 .27172 Mtetra
.48866 .27172 .49561 .27992 .50812 .27548 .5012 .26725 Mtetra
.5012 .26725 .50812 .27548 .52068 .27103 .51381 .26276 Mtetra
.51381 .26276 .52068 .27103 .53331 .26656 .52647 .25825 Mtetra
.52647 .25825 .53331 .26656 .54599 .26207 .5392 .25372 Mtetra
.5392 .25372 .54599 .26207 .55874 .25755 .55198 .24917 Mtetra
.55198 .24917 .55874 .25755 .57154 .25302 .56482 .24459 Mtetra
.56482 .24459 .57154 .25302 .5844 .24846 .57772 .24 Mtetra
.57772 .24 .5844 .24846 .59732 .24389 .59068 .23538 Mtetra
.59068 .23538 .59732 .24389 .6103 .23929 .6037 .23074 Mtetra
.6037 .23074 .6103 .23929 .62334 .23467 .61678 .22608 Mtetra
.61678 .22608 .62334 .23467 .63645 .23003 .62993 .2214 Mtetra
.62993 .2214 .63645 .23003 .64961 .22536 .64313 .2167 Mtetra
.64313 .2167 .64961 .22536 .66284 .22068 .6564 .21197 Mtetra
.6564 .21197 .66284 .22068 .67612 .21597 .66973 .20722 Mtetra
.66973 .20722 .67612 .21597 .68948 .21124 .68313 .20245 Mtetra
.68313 .20245 .68948 .21124 .70289 .20649 .69659 .19766 Mtetra
.69659 .19766 .70289 .20649 .71637 .20172 .71011 .19284 Mtetra
.71011 .19284 .71637 .20172 .72991 .19692 .72369 .188 Mtetra
.72369 .188 .72991 .19692 .74352 .1921 .73735 .18314 Mtetra
.73735 .18314 .74352 .1921 .75719 .18726 .75106 .17826 Mtetra
.75106 .17826 .75719 .18726 .77093 .18239 .76485 .17335 Mtetra
.76485 .17335 .77093 .18239 .78473 .1775 .7787 .16841 Mtetra
.7787 .16841 .78473 .1775 .7986 .17259 .79262 .16346 Mtetra
.655 .752 .921 r
.14985 .48908 .15805 .4962 .16954 .49235 .16137 .48519 Mtetra
.16137 .48519 .16954 .49235 .18107 .48848 .17294 .48129 Mtetra
.17294 .48129 .18107 .48848 .19266 .48459 .18456 .47737 Mtetra
.18456 .47737 .19266 .48459 .2043 .48069 .19623 .47343 Mtetra
.19623 .47343 .2043 .48069 .216 .47677 .20795 .46948 Mtetra
.20795 .46948 .216 .47677 .22775 .47283 .21973 .46551 Mtetra
.21973 .46551 .22775 .47283 .23955 .46887 .23156 .46151 Mtetra
.23156 .46151 .23955 .46887 .2514 .46489 .24345 .45751 Mtetra
.24345 .45751 .2514 .46489 .26331 .4609 .25539 .45348 Mtetra
.25539 .45348 .26331 .4609 .27527 .45689 .26738 .44943 Mtetra
.26738 .44943 .27527 .45689 .28729 .45286 .27943 .44537 Mtetra
.27943 .44537 .28729 .45286 .29936 .44881 .29154 .44128 Mtetra
.928 .544 .224 r
.29154 .44128 .29936 .44881 .30892 .48406 .30102 .47658 Mtetra
.652 .756 .926 r
.30102 .47658 .30892 .48406 .32124 .48002 .31338 .4725 Mtetra
.31338 .4725 .32124 .48002 .33362 .47595 .3258 .4684 Mtetra
.3258 .4684 .33362 .47595 .34606 .47187 .33827 .46429 Mtetra
.33827 .46429 .34606 .47187 .35856 .46777 .35081 .46015 Mtetra
.35081 .46015 .35856 .46777 .37112 .46365 .3634 .45599 Mtetra
.3634 .45599 .37112 .46365 .38374 .45951 .37606 .45182 Mtetra
.37606 .45182 .38374 .45951 .39641 .45535 .38877 .44762 Mtetra
.38877 .44762 .39641 .45535 .40915 .45117 .40154 .44341 Mtetra
.40154 .44341 .40915 .45117 .42195 .44697 .41438 .43917 Mtetra
.41438 .43917 .42195 .44697 .4348 .44275 .42728 .43491 Mtetra
.42728 .43491 .4348 .44275 .44772 .43852 .44023 .43064 Mtetra
.44023 .43064 .44772 .43852 .4607 .43426 .45326 .42634 Mtetra
.964 .712 .507 r
.45326 .42634 .4607 .43426 .47617 .27617 .46912 .26794 Mtetra
.664 .741 .908 r
.46912 .26794 .47617 .27617 .48866 .27172 .48165 .26345 Mtetra
.48165 .26345 .48866 .27172 .5012 .26725 .49423 .25894 Mtetra
.49423 .25894 .5012 .26725 .51381 .26276 .50688 .25442 Mtetra
.50688 .25442 .51381 .26276 .52647 .25825 .51958 .24987 Mtetra
.51958 .24987 .52647 .25825 .5392 .25372 .53234 .2453 Mtetra
.53234 .2453 .5392 .25372 .55198 .24917 .54516 .24071 Mtetra
.54516 .24071 .55198 .24917 .56482 .24459 .55804 .23609 Mtetra
.55804 .23609 .56482 .24459 .57772 .24 .57098 .23146 Mtetra
.57098 .23146 .57772 .24 .59068 .23538 .58398 .2268 Mtetra
.58398 .2268 .59068 .23538 .6037 .23074 .59704 .22212 Mtetra
.59704 .22212 .6037 .23074 .61678 .22608 .61017 .21742 Mtetra
.61017 .21742 .61678 .22608 .62993 .2214 .62335 .2127 Mtetra
.62335 .2127 .62993 .2214 .64313 .2167 .6366 .20796 Mtetra
.6366 .20796 .64313 .2167 .6564 .21197 .64991 .20319 Mtetra
.64991 .20319 .6564 .21197 .66973 .20722 .66328 .1984 Mtetra
.66328 .1984 .66973 .20722 .68313 .20245 .67672 .19359 Mtetra
.67672 .19359 .68313 .20245 .69659 .19766 .69023 .18875 Mtetra
.69023 .18875 .69659 .19766 .71011 .19284 .70379 .18389 Mtetra
.70379 .18389 .71011 .19284 .72369 .188 .71742 .17901 Mtetra
.71742 .17901 .72369 .188 .73735 .18314 .73112 .1741 Mtetra
.73112 .1741 .73735 .18314 .75106 .17826 .74489 .16917 Mtetra
.74489 .16917 .75106 .17826 .76485 .17335 .75872 .16422 Mtetra
.75872 .16422 .76485 .17335 .7787 .16841 .77261 .15924 Mtetra
.77261 .15924 .7787 .16841 .79262 .16346 .78658 .15424 Mtetra
.655 .752 .921 r
.14159 .48189 .14985 .48908 .16137 .48519 .15313 .47797 Mtetra
.15313 .47797 .16137 .48519 .17294 .48129 .16473 .47404 Mtetra
.16473 .47404 .17294 .48129 .18456 .47737 .17638 .47009 Mtetra
.17638 .47009 .18456 .47737 .19623 .47343 .18808 .46612 Mtetra
.18808 .46612 .19623 .47343 .20795 .46948 .19984 .46213 Mtetra
.19984 .46213 .20795 .46948 .21973 .46551 .21165 .45812 Mtetra
.21165 .45812 .21973 .46551 .23156 .46151 .22351 .4541 Mtetra
.22351 .4541 .23156 .46151 .24345 .45751 .23543 .45006 Mtetra
.23543 .45006 .24345 .45751 .25539 .45348 .2474 .44599 Mtetra
.2474 .44599 .25539 .45348 .26738 .44943 .25942 .44191 Mtetra
.25942 .44191 .26738 .44943 .27943 .44537 .27151 .43782 Mtetra
.27151 .43782 .27943 .44537 .29154 .44128 .28365 .4337 Mtetra
.928 .544 .224 r
.28365 .4337 .29154 .44128 .30102 .47658 .29306 .46903 Mtetra
.652 .756 .926 r
.29306 .46903 .30102 .47658 .31338 .4725 .30545 .46492 Mtetra
.30545 .46492 .31338 .4725 .3258 .4684 .31791 .46079 Mtetra
.31791 .46079 .3258 .4684 .33827 .46429 .33042 .45663 Mtetra
.33042 .45663 .33827 .46429 .35081 .46015 .34299 .45246 Mtetra
.34299 .45246 .35081 .46015 .3634 .45599 .35562 .44827 Mtetra
.35562 .44827 .3634 .45599 .37606 .45182 .36831 .44406 Mtetra
.36831 .44406 .37606 .45182 .38877 .44762 .38106 .43982 Mtetra
.38106 .43982 .38877 .44762 .40154 .44341 .39387 .43557 Mtetra
.39387 .43557 .40154 .44341 .41438 .43917 .40675 .4313 Mtetra
.40675 .4313 .41438 .43917 .42728 .43491 .41968 .427 Mtetra
.41968 .427 .42728 .43491 .44023 .43064 .43268 .42269 Mtetra
.43268 .42269 .44023 .43064 .45326 .42634 .44574 .41835 Mtetra
.964 .712 .507 r
.44574 .41835 .45326 .42634 .46912 .26794 .46201 .25964 Mtetra
.664 .741 .908 r
.46201 .25964 .46912 .26794 .48165 .26345 .47458 .25511 Mtetra
.47458 .25511 .48165 .26345 .49423 .25894 .4872 .25057 Mtetra
.4872 .25057 .49423 .25894 .50688 .25442 .49988 .246 Mtetra
.49988 .246 .50688 .25442 .51958 .24987 .51262 .24141 Mtetra
.51262 .24141 .51958 .24987 .53234 .2453 .52542 .2368 Mtetra
.52542 .2368 .53234 .2453 .54516 .24071 .53828 .23217 Mtetra
.53828 .23217 .54516 .24071 .55804 .23609 .5512 .22752 Mtetra
.5512 .22752 .55804 .23609 .57098 .23146 .56418 .22284 Mtetra
.56418 .22284 .57098 .23146 .58398 .2268 .57722 .21815 Mtetra
.57722 .21815 .58398 .2268 .59704 .22212 .59033 .21343 Mtetra
.59033 .21343 .59704 .22212 .61017 .21742 .60349 .20869 Mtetra
.60349 .20869 .61017 .21742 .62335 .2127 .61672 .20392 Mtetra
.61672 .20392 .62335 .2127 .6366 .20796 .63001 .19914 Mtetra
.63001 .19914 .6366 .20796 .64991 .20319 .64336 .19433 Mtetra
.64336 .19433 .64991 .20319 .66328 .1984 .65678 .1895 Mtetra
.65678 .1895 .66328 .1984 .67672 .19359 .67026 .18464 Mtetra
.67026 .18464 .67672 .19359 .69023 .18875 .68381 .17976 Mtetra
.68381 .17976 .69023 .18875 .70379 .18389 .69742 .17486 Mtetra
.69742 .17486 .70379 .18389 .71742 .17901 .7111 .16993 Mtetra
.7111 .16993 .71742 .17901 .73112 .1741 .72484 .16498 Mtetra
.72484 .16498 .73112 .1741 .74489 .16917 .73865 .16001 Mtetra
.73865 .16001 .74489 .16917 .75872 .16422 .75253 .15501 Mtetra
.75253 .15501 .75872 .16422 .77261 .15924 .76647 .14999 Mtetra
.76647 .14999 .77261 .15924 .78658 .15424 .78049 .14494 Mtetra
.655 .752 .921 r
.13326 .47465 .14159 .48189 .15313 .47797 .14483 .4707 Mtetra
.14483 .4707 .15313 .47797 .16473 .47404 .15646 .46673 Mtetra
.15646 .46673 .16473 .47404 .17638 .47009 .16813 .46274 Mtetra
.16813 .46274 .17638 .47009 .18808 .46612 .17987 .45874 Mtetra
.17987 .45874 .18808 .46612 .19984 .46213 .19165 .45472 Mtetra
.19165 .45472 .19984 .46213 .21165 .45812 .20349 .45068 Mtetra
.20349 .45068 .21165 .45812 .22351 .4541 .21539 .44662 Mtetra
.21539 .44662 .22351 .4541 .23543 .45006 .22734 .44254 Mtetra
.22734 .44254 .23543 .45006 .2474 .44599 .23934 .43845 Mtetra
.23934 .43845 .2474 .44599 .25942 .44191 .2514 .43433 Mtetra
.2514 .43433 .25942 .44191 .27151 .43782 .26352 .4302 Mtetra
.26352 .4302 .27151 .43782 .28365 .4337 .27569 .42604 Mtetra
.928 .544 .224 r
.27569 .42604 .28365 .4337 .29306 .46903 .28503 .46142 Mtetra
.652 .756 .926 r
.28503 .46142 .29306 .46903 .30545 .46492 .29746 .45727 Mtetra
.29746 .45727 .30545 .46492 .31791 .46079 .30995 .4531 Mtetra
.30995 .4531 .31791 .46079 .33042 .45663 .32249 .44891 Mtetra
.32249 .44891 .33042 .45663 .34299 .45246 .3351 .4447 Mtetra
.3351 .4447 .34299 .45246 .35562 .44827 .34777 .44047 Mtetra
.34777 .44047 .35562 .44827 .36831 .44406 .3605 .43623 Mtetra
.3605 .43623 .36831 .44406 .38106 .43982 .37328 .43195 Mtetra
.37328 .43195 .38106 .43982 .39387 .43557 .38613 .42766 Mtetra
.38613 .42766 .39387 .43557 .40675 .4313 .39905 .42335 Mtetra
.39905 .42335 .40675 .4313 .41968 .427 .41202 .41902 Mtetra
.41202 .41902 .41968 .427 .43268 .42269 .42506 .41467 Mtetra
.42506 .41467 .43268 .42269 .44574 .41835 .43816 .41029 Mtetra
.964 .712 .507 r
.43816 .41029 .44574 .41835 .46201 .25964 .45485 .25127 Mtetra
.664 .741 .908 r
.45485 .25127 .46201 .25964 .47458 .25511 .46745 .24671 Mtetra
.46745 .24671 .47458 .25511 .4872 .25057 .48011 .24212 Mtetra
.48011 .24212 .4872 .25057 .49988 .246 .49283 .23751 Mtetra
.49283 .23751 .49988 .246 .51262 .24141 .50561 .23289 Mtetra
.50561 .23289 .51262 .24141 .52542 .2368 .51844 .22824 Mtetra
.51844 .22824 .52542 .2368 .53828 .23217 .53134 .22356 Mtetra
.53134 .22356 .53828 .23217 .5512 .22752 .5443 .21887 Mtetra
.5443 .21887 .5512 .22752 .56418 .22284 .55732 .21416 Mtetra
.55732 .21416 .56418 .22284 .57722 .21815 .57041 .20942 Mtetra
.57041 .20942 .57722 .21815 .59033 .21343 .58355 .20466 Mtetra
.58355 .20466 .59033 .21343 .60349 .20869 .59676 .19987 Mtetra
.59676 .19987 .60349 .20869 .61672 .20392 .61003 .19507 Mtetra
.61003 .19507 .61672 .20392 .63001 .19914 .62336 .19024 Mtetra
.62336 .19024 .63001 .19914 .64336 .19433 .63676 .18539 Mtetra
.63676 .18539 .64336 .19433 .65678 .1895 .65022 .18051 Mtetra
.65022 .18051 .65678 .1895 .67026 .18464 .66374 .17561 Mtetra
.66374 .17561 .67026 .18464 .68381 .17976 .67734 .17069 Mtetra
.67734 .17069 .68381 .17976 .69742 .17486 .69099 .16575 Mtetra
.69099 .16575 .69742 .17486 .7111 .16993 .70472 .16078 Mtetra
.70472 .16078 .7111 .16993 .72484 .16498 .7185 .15578 Mtetra
.7185 .15578 .72484 .16498 .73865 .16001 .73236 .15076 Mtetra
.73236 .15076 .73865 .16001 .75253 .15501 .74629 .14572 Mtetra
.74629 .14572 .75253 .15501 .76647 .14999 .76028 .14065 Mtetra
.76028 .14065 .76647 .14999 .78049 .14494 .77434 .13556 Mtetra
.474 .194 .407 r
.11687 .53299 .13326 .47465 .14483 .4707 .12869 .52908 Mtetra
.12869 .52908 .14483 .4707 .15646 .46673 .14056 .52516 Mtetra
.14056 .52516 .15646 .46673 .16813 .46274 .15248 .52121 Mtetra
.15248 .52121 .16813 .46274 .17987 .45874 .16447 .51724 Mtetra
.16447 .51724 .17987 .45874 .19165 .45472 .17651 .51326 Mtetra
.17651 .51326 .19165 .45472 .20349 .45068 .1886 .50926 Mtetra
.1886 .50926 .20349 .45068 .21539 .44662 .20075 .50524 Mtetra
.20075 .50524 .21539 .44662 .22734 .44254 .21296 .5012 Mtetra
.21296 .5012 .22734 .44254 .23934 .43845 .22523 .49714 Mtetra
.22523 .49714 .23934 .43845 .2514 .43433 .23756 .49306 Mtetra
.23756 .49306 .2514 .43433 .26352 .4302 .24994 .48896 Mtetra
.24994 .48896 .26352 .4302 .27569 .42604 .26238 .48485 Mtetra
.721 .709 .177 r
.26238 .48485 .27569 .42604 .28503 .46142 .28091 .40112 Mtetra
.563 .386 .599 r
.28091 .40112 .28503 .46142 .29746 .45727 .29318 .39688 Mtetra
.29318 .39688 .29746 .45727 .30995 .4531 .30551 .39261 Mtetra
.30551 .39261 .30995 .4531 .32249 .44891 .3179 .38833 Mtetra
.3179 .38833 .32249 .44891 .3351 .4447 .33035 .38403 Mtetra
.33035 .38403 .3351 .4447 .34777 .44047 .34285 .37971 Mtetra
.34285 .37971 .34777 .44047 .3605 .43623 .35542 .37537 Mtetra
.35542 .37537 .3605 .43623 .37328 .43195 .36804 .371 Mtetra
.36804 .371 .37328 .43195 .38613 .42766 .38073 .36662 Mtetra
.38073 .36662 .38613 .42766 .39905 .42335 .39347 .36221 Mtetra
.39347 .36221 .39905 .42335 .41202 .41902 .40627 .35779 Mtetra
.40627 .35779 .41202 .41902 .42506 .41467 .41914 .35334 Mtetra
.41914 .35334 .42506 .41467 .43816 .41029 .43207 .34887 Mtetra
.844 .593 .559 r
.43207 .34887 .43816 .41029 .45485 .25127 .44762 .24283 Mtetra
.664 .741 .908 r
.44762 .24283 .45485 .25127 .46745 .24671 .46026 .23822 Mtetra
.46026 .23822 .46745 .24671 .48011 .24212 .47296 .2336 Mtetra
.47296 .2336 .48011 .24212 .49283 .23751 .48571 .22895 Mtetra
.48571 .22895 .49283 .23751 .50561 .23289 .49853 .22429 Mtetra
.49853 .22429 .50561 .23289 .51844 .22824 .51141 .2196 Mtetra
.51141 .2196 .51844 .22824 .53134 .22356 .52435 .21488 Mtetra
.52435 .21488 .53134 .22356 .5443 .21887 .53735 .21015 Mtetra
.53735 .21015 .5443 .21887 .55732 .21416 .55041 .20539 Mtetra
.55041 .20539 .55732 .21416 .57041 .20942 .56353 .20061 Mtetra
.56353 .20061 .57041 .20942 .58355 .20466 .57672 .19581 Mtetra
.57672 .19581 .58355 .20466 .59676 .19987 .58996 .19098 Mtetra
.58996 .19098 .59676 .19987 .61003 .19507 .60328 .18614 Mtetra
.60328 .18614 .61003 .19507 .62336 .19024 .61665 .18126 Mtetra
.61665 .18126 .62336 .19024 .63676 .18539 .63009 .17637 Mtetra
.63009 .17637 .63676 .18539 .65022 .18051 .6436 .17145 Mtetra
.6436 .17145 .65022 .18051 .66374 .17561 .65717 .16651 Mtetra
.65717 .16651 .66374 .17561 .67734 .17069 .6708 .16154 Mtetra
.6708 .16154 .67734 .17069 .69099 .16575 .68451 .15655 Mtetra
.68451 .15655 .69099 .16575 .70472 .16078 .69828 .15154 Mtetra
.69828 .15154 .70472 .16078 .7185 .15578 .71211 .1465 Mtetra
.71211 .1465 .7185 .15578 .73236 .15076 .72601 .14144 Mtetra
.72601 .14144 .73236 .15076 .74629 .14572 .73999 .13635 Mtetra
.73999 .13635 .74629 .14572 .76028 .14065 .75403 .13123 Mtetra
.75403 .13123 .76028 .14065 .77434 .13556 .76814 .12609 Mtetra
.65 .758 .929 r
.10819 .52576 .11687 .53299 .12869 .52908 .12004 .52182 Mtetra
.12004 .52182 .12869 .52908 .14056 .52516 .13194 .51786 Mtetra
.13194 .51786 .14056 .52516 .15248 .52121 .1439 .51388 Mtetra
.1439 .51388 .15248 .52121 .16447 .51724 .15591 .50988 Mtetra
.15591 .50988 .16447 .51724 .17651 .51326 .16798 .50586 Mtetra
.16798 .50586 .17651 .51326 .1886 .50926 .18011 .50182 Mtetra
.18011 .50182 .1886 .50926 .20075 .50524 .1923 .49777 Mtetra
.1923 .49777 .20075 .50524 .21296 .5012 .20454 .49369 Mtetra
.20454 .49369 .21296 .5012 .22523 .49714 .21684 .4896 Mtetra
.21684 .4896 .22523 .49714 .23756 .49306 .2292 .48548 Mtetra
.2292 .48548 .23756 .49306 .24994 .48896 .24162 .48135 Mtetra
.24162 .48135 .24994 .48896 .26238 .48485 .2541 .47719 Mtetra
.94 .722 .58 r
.2541 .47719 .26238 .48485 .28091 .40112 .27289 .39327 Mtetra
.656 .751 .92 r
.27289 .39327 .28091 .40112 .29318 .39688 .28519 .38899 Mtetra
.28519 .38899 .29318 .39688 .30551 .39261 .29756 .38469 Mtetra
.29756 .38469 .30551 .39261 .3179 .38833 .30998 .38037 Mtetra
.30998 .38037 .3179 .38833 .33035 .38403 .32246 .37604 Mtetra
.32246 .37604 .33035 .38403 .34285 .37971 .335 .37168 Mtetra
.335 .37168 .34285 .37971 .35542 .37537 .34761 .36729 Mtetra
.34761 .36729 .35542 .37537 .36804 .371 .36027 .36289 Mtetra
.36027 .36289 .36804 .371 .38073 .36662 .37299 .35847 Mtetra
.37299 .35847 .38073 .36662 .39347 .36221 .38577 .35403 Mtetra
.38577 .35403 .39347 .36221 .40627 .35779 .39861 .34956 Mtetra
.39861 .34956 .40627 .35779 .41914 .35334 .41152 .34507 Mtetra
.41152 .34507 .41914 .35334 .43207 .34887 .42448 .34057 Mtetra
.96 .721 .532 r
.42448 .34057 .43207 .34887 .44762 .24283 .44033 .23431 Mtetra
.664 .741 .908 r
.44033 .23431 .44762 .24283 .46026 .23822 .453 .22967 Mtetra
.453 .22967 .46026 .23822 .47296 .2336 .46574 .225 Mtetra
.46574 .225 .47296 .2336 .48571 .22895 .47854 .22032 Mtetra
.47854 .22032 .48571 .22895 .49853 .22429 .49139 .21561 Mtetra
.49139 .21561 .49853 .22429 .51141 .2196 .50431 .21088 Mtetra
.50431 .21088 .51141 .2196 .52435 .21488 .51729 .20612 Mtetra
.51729 .20612 .52435 .21488 .53735 .21015 .53033 .20135 Mtetra
.53033 .20135 .53735 .21015 .55041 .20539 .54343 .19655 Mtetra
.54343 .19655 .55041 .20539 .56353 .20061 .55659 .19173 Mtetra
.55659 .19173 .56353 .20061 .57672 .19581 .56982 .18688 Mtetra
.56982 .18688 .57672 .19581 .58996 .19098 .58311 .18202 Mtetra
.58311 .18202 .58996 .19098 .60328 .18614 .59647 .17712 Mtetra
.59647 .17712 .60328 .18614 .61665 .18126 .60989 .17221 Mtetra
.60989 .17221 .61665 .18126 .63009 .17637 .62337 .16727 Mtetra
.62337 .16727 .63009 .17637 .6436 .17145 .63692 .16231 Mtetra
.63692 .16231 .6436 .17145 .65717 .16651 .65053 .15732 Mtetra
.65053 .15732 .65717 .16651 .6708 .16154 .66421 .15231 Mtetra
.66421 .15231 .6708 .16154 .68451 .15655 .67796 .14728 Mtetra
.67796 .14728 .68451 .15655 .69828 .15154 .69178 .14222 Mtetra
.69178 .14222 .69828 .15154 .71211 .1465 .70566 .13713 Mtetra
.70566 .13713 .71211 .1465 .72601 .14144 .71961 .13202 Mtetra
.71961 .13202 .72601 .14144 .73999 .13635 .73363 .12689 Mtetra
.73363 .12689 .73999 .13635 .75403 .13123 .74772 .12173 Mtetra
.74772 .12173 .75403 .13123 .76814 .12609 .76188 .11654 Mtetra
.65 .758 .929 r
.09944 .51847 .10819 .52576 .12004 .52182 .11131 .51449 Mtetra
.11131 .51449 .12004 .52182 .13194 .51786 .12325 .51049 Mtetra
.12325 .51049 .13194 .51786 .1439 .51388 .13524 .50648 Mtetra
.13524 .50648 .1439 .51388 .15591 .50988 .14728 .50244 Mtetra
.14728 .50244 .15591 .50988 .16798 .50586 .15939 .49839 Mtetra
.15939 .49839 .16798 .50586 .18011 .50182 .17155 .49432 Mtetra
.17155 .49432 .18011 .50182 .1923 .49777 .18377 .49023 Mtetra
.18377 .49023 .1923 .49777 .20454 .49369 .19604 .48612 Mtetra
.19604 .48612 .20454 .49369 .21684 .4896 .20838 .48198 Mtetra
.20838 .48198 .21684 .4896 .2292 .48548 .22077 .47783 Mtetra
.22077 .47783 .2292 .48548 .24162 .48135 .23323 .47366 Mtetra
.23323 .47366 .24162 .48135 .2541 .47719 .24574 .46947 Mtetra
.94 .722 .58 r
.24574 .46947 .2541 .47719 .27289 .39327 .26479 .38536 Mtetra
.656 .751 .92 r
.26479 .38536 .27289 .39327 .28519 .38899 .27713 .38104 Mtetra
.27713 .38104 .28519 .38899 .29756 .38469 .28953 .3767 Mtetra
.28953 .3767 .29756 .38469 .30998 .38037 .30199 .37235 Mtetra
.30199 .37235 .30998 .38037 .32246 .37604 .31451 .36797 Mtetra
.31451 .36797 .32246 .37604 .335 .37168 .32709 .36357 Mtetra
.32709 .36357 .335 .37168 .34761 .36729 .33973 .35915 Mtetra
.33973 .35915 .34761 .36729 .36027 .36289 .35242 .35471 Mtetra
.35242 .35471 .36027 .36289 .37299 .35847 .36518 .35025 Mtetra
.36518 .35025 .37299 .35847 .38577 .35403 .378 .34577 Mtetra
.378 .34577 .38577 .35403 .39861 .34956 .39088 .34126 Mtetra
.39088 .34126 .39861 .34956 .41152 .34507 .40383 .33674 Mtetra
.40383 .33674 .41152 .34507 .42448 .34057 .41683 .33219 Mtetra
.96 .721 .532 r
.41683 .33219 .42448 .34057 .44033 .23431 .43297 .22572 Mtetra
.664 .741 .908 r
.43297 .22572 .44033 .23431 .453 .22967 .44569 .22104 Mtetra
.44569 .22104 .453 .22967 .46574 .225 .45846 .21634 Mtetra
.45846 .21634 .46574 .225 .47854 .22032 .4713 .21161 Mtetra
.4713 .21161 .47854 .22032 .49139 .21561 .48419 .20686 Mtetra
.48419 .20686 .49139 .21561 .50431 .21088 .49715 .20209 Mtetra
.49715 .20209 .50431 .21088 .51729 .20612 .51017 .19729 Mtetra
.51017 .19729 .51729 .20612 .53033 .20135 .52325 .19247 Mtetra
.52325 .19247 .53033 .20135 .54343 .19655 .53639 .18763 Mtetra
.53639 .18763 .54343 .19655 .55659 .19173 .5496 .18277 Mtetra
.5496 .18277 .55659 .19173 .56982 .18688 .56287 .17788 Mtetra
.56287 .17788 .56982 .18688 .58311 .18202 .5762 .17297 Mtetra
.5762 .17297 .58311 .18202 .59647 .17712 .5896 .16803 Mtetra
.5896 .16803 .59647 .17712 .60989 .17221 .60306 .16307 Mtetra
.60306 .16307 .60989 .17221 .62337 .16727 .61659 .15809 Mtetra
.61659 .15809 .62337 .16727 .63692 .16231 .63018 .15308 Mtetra
.63018 .15308 .63692 .16231 .65053 .15732 .64384 .14805 Mtetra
.64384 .14805 .65053 .15732 .66421 .15231 .65757 .143 Mtetra
.65757 .143 .66421 .15231 .67796 .14728 .67136 .13792 Mtetra
.67136 .13792 .67796 .14728 .69178 .14222 .68522 .13281 Mtetra
.68522 .13281 .69178 .14222 .70566 .13713 .69915 .12768 Mtetra
.69915 .12768 .70566 .13713 .71961 .13202 .71315 .12252 Mtetra
.71315 .12252 .71961 .13202 .73363 .12689 .72722 .11734 Mtetra
.72722 .11734 .73363 .12689 .74772 .12173 .74135 .11213 Mtetra
.74135 .11213 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.65 .758 .929 r
.09061 .51111 .09944 .51847 .11131 .51449 .10252 .5071 Mtetra
.10252 .5071 .11131 .51449 .12325 .51049 .11448 .50307 Mtetra
.11448 .50307 .12325 .51049 .13524 .50648 .1265 .49902 Mtetra
.1265 .49902 .13524 .50648 .14728 .50244 .13858 .49495 Mtetra
.13858 .49495 .14728 .50244 .15939 .49839 .15072 .49086 Mtetra
.15072 .49086 .15939 .49839 .17155 .49432 .16291 .48675 Mtetra
.16291 .48675 .17155 .49432 .18377 .49023 .17516 .48262 Mtetra
.17516 .48262 .18377 .49023 .19604 .48612 .18747 .47847 Mtetra
.18747 .47847 .19604 .48612 .20838 .48198 .19984 .47431 Mtetra
.19984 .47431 .20838 .48198 .22077 .47783 .21227 .47012 Mtetra
.21227 .47012 .22077 .47783 .23323 .47366 .22476 .46591 Mtetra
.22476 .46591 .23323 .47366 .24574 .46947 .23731 .46168 Mtetra
.94 .722 .58 r
.23731 .46168 .24574 .46947 .26479 .38536 .25663 .37737 Mtetra
.656 .751 .92 r
.25663 .37737 .26479 .38536 .27713 .38104 .269 .37302 Mtetra
.269 .37302 .27713 .38104 .28953 .3767 .28144 .36864 Mtetra
.28144 .36864 .28953 .3767 .30199 .37235 .29393 .36425 Mtetra
.29393 .36425 .30199 .37235 .31451 .36797 .30649 .35983 Mtetra
.30649 .35983 .31451 .36797 .32709 .36357 .3191 .3554 Mtetra
.3191 .3554 .32709 .36357 .33973 .35915 .33177 .35094 Mtetra
.33177 .35094 .33973 .35915 .35242 .35471 .34451 .34646 Mtetra
.34451 .34646 .35242 .35471 .36518 .35025 .35731 .34196 Mtetra
.35731 .34196 .36518 .35025 .378 .34577 .37016 .33743 Mtetra
.37016 .33743 .378 .34577 .39088 .34126 .38308 .33289 Mtetra
.38308 .33289 .39088 .34126 .40383 .33674 .39607 .32832 Mtetra
.39607 .32832 .40383 .33674 .41683 .33219 .40911 .32373 Mtetra
.96 .721 .532 r
.40911 .32373 .41683 .33219 .43297 .22572 .42556 .21706 Mtetra
.664 .741 .908 r
.42556 .21706 .43297 .22572 .44569 .22104 .43831 .21234 Mtetra
.43831 .21234 .44569 .22104 .45846 .21634 .45112 .20759 Mtetra
.45112 .20759 .45846 .21634 .4713 .21161 .46399 .20282 Mtetra
.46399 .20282 .4713 .21161 .48419 .20686 .47693 .19803 Mtetra
.47693 .19803 .48419 .20686 .49715 .20209 .48993 .19321 Mtetra
.48993 .19321 .49715 .20209 .51017 .19729 .50298 .18838 Mtetra
.50298 .18838 .51017 .19729 .52325 .19247 .5161 .18352 Mtetra
.5161 .18352 .52325 .19247 .53639 .18763 .52929 .17863 Mtetra
.52929 .17863 .53639 .18763 .5496 .18277 .54254 .17372 Mtetra
.54254 .17372 .5496 .18277 .56287 .17788 .55585 .16879 Mtetra
.55585 .16879 .56287 .17788 .5762 .17297 .56922 .16384 Mtetra
.56922 .16384 .5762 .17297 .5896 .16803 .58266 .15886 Mtetra
.58266 .15886 .5896 .16803 .60306 .16307 .59617 .15386 Mtetra
.59617 .15386 .60306 .16307 .61659 .15809 .60974 .14883 Mtetra
.60974 .14883 .61659 .15809 .63018 .15308 .62338 .14378 Mtetra
.62338 .14378 .63018 .15308 .64384 .14805 .63708 .1387 Mtetra
.63708 .1387 .64384 .14805 .65757 .143 .65086 .1336 Mtetra
.65086 .1336 .65757 .143 .67136 .13792 .6647 .12847 Mtetra
.6647 .12847 .67136 .13792 .68522 .13281 .6786 .12332 Mtetra
.6786 .12332 .68522 .13281 .69915 .12768 .69258 .11814 Mtetra
.69258 .11814 .69915 .12768 .71315 .12252 .70663 .11294 Mtetra
.70663 .11294 .71315 .12252 .72722 .11734 .72074 .10771 Mtetra
.72074 .10771 .72722 .11734 .74135 .11213 .73493 .10245 Mtetra
.73493 .10245 .74135 .11213 .75556 .1069 .74918 .09717 Mtetra
.65 .758 .929 r
.0817 .50369 .09061 .51111 .10252 .5071 .09364 .49964 Mtetra
.09364 .49964 .10252 .5071 .11448 .50307 .10564 .49557 Mtetra
.10564 .49557 .11448 .50307 .1265 .49902 .11769 .49149 Mtetra
.11769 .49149 .1265 .49902 .13858 .49495 .1298 .48738 Mtetra
.1298 .48738 .13858 .49495 .15072 .49086 .14197 .48326 Mtetra
.14197 .48326 .15072 .49086 .16291 .48675 .15419 .47911 Mtetra
.15419 .47911 .16291 .48675 .17516 .48262 .16648 .47495 Mtetra
.16648 .47495 .17516 .48262 .18747 .47847 .17882 .47077 Mtetra
.17882 .47077 .18747 .47847 .19984 .47431 .19123 .46656 Mtetra
.19123 .46656 .19984 .47431 .21227 .47012 .20369 .46234 Mtetra
.20369 .46234 .21227 .47012 .22476 .46591 .21621 .45809 Mtetra
.21621 .45809 .22476 .46591 .23731 .46168 .2288 .45383 Mtetra
.94 .722 .58 r
.2288 .45383 .23731 .46168 .25663 .37737 .24839 .36932 Mtetra
.656 .751 .92 r
.24839 .36932 .25663 .37737 .269 .37302 .2608 .36493 Mtetra
.2608 .36493 .269 .37302 .28144 .36864 .27327 .36051 Mtetra
.27327 .36051 .28144 .36864 .29393 .36425 .2858 .35608 Mtetra
.2858 .35608 .29393 .36425 .30649 .35983 .29839 .35162 Mtetra
.29839 .35162 .30649 .35983 .3191 .3554 .31104 .34715 Mtetra
.31104 .34715 .3191 .3554 .33177 .35094 .32375 .34265 Mtetra
.32375 .34265 .33177 .35094 .34451 .34646 .33653 .33813 Mtetra
.33653 .33813 .34451 .34646 .35731 .34196 .34936 .33359 Mtetra
.34936 .33359 .35731 .34196 .37016 .33743 .36226 .32903 Mtetra
.36226 .32903 .37016 .33743 .38308 .33289 .37521 .32444 Mtetra
.37521 .32444 .38308 .33289 .39607 .32832 .38824 .31983 Mtetra
.38824 .31983 .39607 .32832 .40911 .32373 .40132 .3152 Mtetra
.96 .721 .532 r
.40132 .3152 .40911 .32373 .42556 .21706 .41807 .20832 Mtetra
.664 .741 .908 r
.41807 .20832 .42556 .21706 .43831 .21234 .43086 .20356 Mtetra
.43086 .20356 .43831 .21234 .45112 .20759 .44372 .19877 Mtetra
.44372 .19877 .45112 .20759 .46399 .20282 .45663 .19396 Mtetra
.45663 .19396 .46399 .20282 .47693 .19803 .4696 .18912 Mtetra
.4696 .18912 .47693 .19803 .48993 .19321 .48264 .18427 Mtetra
.48264 .18427 .48993 .19321 .50298 .18838 .49574 .17939 Mtetra
.49574 .17939 .50298 .18838 .5161 .18352 .5089 .17448 Mtetra
.5089 .17448 .5161 .18352 .52929 .17863 .52212 .16955 Mtetra
.52212 .16955 .52929 .17863 .54254 .17372 .53541 .1646 Mtetra
.53541 .1646 .54254 .17372 .55585 .16879 .54877 .15963 Mtetra
.54877 .15963 .55585 .16879 .56922 .16384 .56218 .15463 Mtetra
.56218 .15463 .56922 .16384 .58266 .15886 .57567 .1496 Mtetra
.57567 .1496 .58266 .15886 .59617 .15386 .58922 .14455 Mtetra
.58922 .14455 .59617 .15386 .60974 .14883 .60283 .13948 Mtetra
.60283 .13948 .60974 .14883 .62338 .14378 .61652 .13438 Mtetra
.61652 .13438 .62338 .14378 .63708 .1387 .63027 .12926 Mtetra
.63027 .12926 .63708 .1387 .65086 .1336 .64408 .12411 Mtetra
.64408 .12411 .65086 .1336 .6647 .12847 .65797 .11894 Mtetra
.65797 .11894 .6647 .12847 .6786 .12332 .67193 .11374 Mtetra
.67193 .11374 .6786 .12332 .69258 .11814 .68595 .10851 Mtetra
.68595 .10851 .69258 .11814 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.65 .758 .929 r
.07272 .4962 .0817 .50369 .09364 .49964 .08469 .49212 Mtetra
.08469 .49212 .09364 .49964 .10564 .49557 .09672 .48802 Mtetra
.09672 .48802 .10564 .49557 .11769 .49149 .1088 .48389 Mtetra
.1088 .48389 .11769 .49149 .1298 .48738 .12094 .47975 Mtetra
.12094 .47975 .1298 .48738 .14197 .48326 .13314 .47559 Mtetra
.13314 .47559 .14197 .48326 .15419 .47911 .1454 .47141 Mtetra
.1454 .47141 .15419 .47911 .16648 .47495 .15772 .46721 Mtetra
.15772 .46721 .16648 .47495 .17882 .47077 .1701 .46299 Mtetra
.1701 .46299 .17882 .47077 .19123 .46656 .18254 .45875 Mtetra
.18254 .45875 .19123 .46656 .20369 .46234 .19503 .45448 Mtetra
.19503 .45448 .20369 .46234 .21621 .45809 .20759 .4502 Mtetra
.20759 .4502 .21621 .45809 .2288 .45383 .22021 .4459 Mtetra
.94 .722 .58 r
.22021 .4459 .2288 .45383 .24839 .36932 .24008 .36119 Mtetra
.656 .751 .92 r
.24008 .36119 .24839 .36932 .2608 .36493 .25253 .35676 Mtetra
.25253 .35676 .2608 .36493 .27327 .36051 .26504 .35231 Mtetra
.26504 .35231 .27327 .36051 .2858 .35608 .2776 .34784 Mtetra
.2776 .34784 .2858 .35608 .29839 .35162 .29023 .34334 Mtetra
.29023 .34334 .29839 .35162 .31104 .34715 .30291 .33883 Mtetra
.30291 .33883 .31104 .34715 .32375 .34265 .31566 .33429 Mtetra
.31566 .33429 .32375 .34265 .33653 .33813 .32847 .32973 Mtetra
.32847 .32973 .33653 .33813 .34936 .33359 .34134 .32515 Mtetra
.34134 .32515 .34936 .33359 .36226 .32903 .35428 .32054 Mtetra
.35428 .32054 .36226 .32903 .37521 .32444 .36728 .31591 Mtetra
.36728 .31591 .37521 .32444 .38824 .31983 .38034 .31126 Mtetra
.38034 .31126 .38824 .31983 .40132 .3152 .39346 .30659 Mtetra
.96 .721 .532 r
.39346 .30659 .40132 .3152 .41807 .20832 .41053 .19951 Mtetra
.664 .741 .908 r
.41053 .19951 .41807 .20832 .43086 .20356 .42335 .1947 Mtetra
.42335 .1947 .43086 .20356 .44372 .19877 .43624 .18987 Mtetra
.43624 .18987 .44372 .19877 .45663 .19396 .4492 .18501 Mtetra
.4492 .18501 .45663 .19396 .4696 .18912 .46221 .18014 Mtetra
.46221 .18014 .4696 .18912 .48264 .18427 .47529 .17524 Mtetra
.47529 .17524 .48264 .18427 .49574 .17939 .48843 .17031 Mtetra
.48843 .17031 .49574 .17939 .5089 .17448 .50163 .16537 Mtetra
.50163 .16537 .5089 .17448 .52212 .16955 .51489 .16039 Mtetra
.51489 .16039 .52212 .16955 .53541 .1646 .52823 .1554 Mtetra
.52823 .1554 .53541 .1646 .54877 .15963 .54162 .15038 Mtetra
.54162 .15038 .54877 .15963 .56218 .15463 .55508 .14533 Mtetra
.55508 .14533 .56218 .15463 .57567 .1496 .56861 .14026 Mtetra
.56861 .14026 .57567 .1496 .58922 .14455 .5822 .13517 Mtetra
.5822 .13517 .58922 .14455 .60283 .13948 .59586 .13005 Mtetra
.59586 .13005 .60283 .13948 .61652 .13438 .60959 .12491 Mtetra
.60959 .12491 .61652 .13438 .63027 .12926 .62339 .11974 Mtetra
.62339 .11974 .63027 .12926 .64408 .12411 .63725 .11454 Mtetra
.63725 .11454 .64408 .12411 .65797 .11894 .65119 .10932 Mtetra
.65119 .10932 .65797 .11894 .67193 .11374 .66519 .10407 Mtetra
.66519 .10407 .67193 .11374 .68595 .10851 .67926 .0988 Mtetra
.67926 .0988 .68595 .10851 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.65 .758 .929 r
.06365 .48865 .07272 .4962 .08469 .49212 .07566 .48453 Mtetra
.07566 .48453 .08469 .49212 .09672 .48802 .08772 .48039 Mtetra
.08772 .48039 .09672 .48802 .1088 .48389 .09983 .47623 Mtetra
.09983 .47623 .1088 .48389 .12094 .47975 .11201 .47205 Mtetra
.11201 .47205 .12094 .47975 .13314 .47559 .12424 .46786 Mtetra
.12424 .46786 .13314 .47559 .1454 .47141 .13653 .46364 Mtetra
.13653 .46364 .1454 .47141 .15772 .46721 .14888 .4594 Mtetra
.14888 .4594 .15772 .46721 .1701 .46299 .1613 .45514 Mtetra
.1613 .45514 .1701 .46299 .18254 .45875 .17377 .45086 Mtetra
.17377 .45086 .18254 .45875 .19503 .45448 .1863 .44656 Mtetra
.1863 .44656 .19503 .45448 .20759 .4502 .19889 .44224 Mtetra
.19889 .44224 .20759 .4502 .22021 .4459 .21155 .4379 Mtetra
.94 .722 .58 r
.21155 .4379 .22021 .4459 .24008 .36119 .2317 .353 Mtetra
.656 .751 .92 r
.2317 .353 .24008 .36119 .25253 .35676 .24418 .34853 Mtetra
.24418 .34853 .25253 .35676 .26504 .35231 .25672 .34404 Mtetra
.25672 .34404 .26504 .35231 .2776 .34784 .26933 .33952 Mtetra
.26933 .33952 .2776 .34784 .29023 .34334 .28199 .33499 Mtetra
.28199 .33499 .29023 .34334 .30291 .33883 .29471 .33043 Mtetra
.29471 .33043 .30291 .33883 .31566 .33429 .3075 .32585 Mtetra
.3075 .32585 .31566 .33429 .32847 .32973 .32034 .32125 Mtetra
.32034 .32125 .32847 .32973 .34134 .32515 .33325 .31663 Mtetra
.33325 .31663 .34134 .32515 .35428 .32054 .34623 .31198 Mtetra
.34623 .31198 .35428 .32054 .36728 .31591 .35926 .30731 Mtetra
.35926 .30731 .36728 .31591 .38034 .31126 .37236 .30262 Mtetra
.37236 .30262 .38034 .31126 .39346 .30659 .38553 .29791 Mtetra
.96 .721 .532 r
.38553 .29791 .39346 .30659 .41053 .19951 .40291 .19061 Mtetra
.664 .741 .908 r
.40291 .19061 .41053 .19951 .42335 .1947 .41578 .18576 Mtetra
.41578 .18576 .42335 .1947 .43624 .18987 .42871 .18089 Mtetra
.42871 .18089 .43624 .18987 .4492 .18501 .4417 .17599 Mtetra
.4417 .17599 .4492 .18501 .46221 .18014 .45475 .17107 Mtetra
.45475 .17107 .46221 .18014 .47529 .17524 .46787 .16613 Mtetra
.46787 .16613 .47529 .17524 .48843 .17031 .48105 .16116 Mtetra
.48105 .16116 .48843 .17031 .50163 .16537 .49429 .15617 Mtetra
.49429 .15617 .50163 .16537 .51489 .16039 .5076 .15115 Mtetra
.5076 .15115 .51489 .16039 .52823 .1554 .52097 .14611 Mtetra
.52097 .14611 .52823 .1554 .54162 .15038 .53441 .14104 Mtetra
.53441 .14104 .54162 .15038 .55508 .14533 .54792 .13595 Mtetra
.54792 .13595 .55508 .14533 .56861 .14026 .56149 .13084 Mtetra
.56149 .13084 .56861 .14026 .5822 .13517 .57513 .1257 Mtetra
.57513 .1257 .5822 .13517 .59586 .13005 .58883 .12053 Mtetra
.58883 .12053 .59586 .13005 .60959 .12491 .60261 .11534 Mtetra
.60261 .11534 .60959 .12491 .62339 .11974 .61645 .11012 Mtetra
.61645 .11012 .62339 .11974 .63725 .11454 .63036 .10488 Mtetra
.63036 .10488 .63725 .11454 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09431 Mtetra
.65839 .09431 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.65 .758 .929 r
.05451 .48103 .06365 .48865 .07566 .48453 .06654 .47687 Mtetra
.06654 .47687 .07566 .48453 .08772 .48039 .07864 .4727 Mtetra
.07864 .4727 .08772 .48039 .09983 .47623 .09078 .4685 Mtetra
.09078 .4685 .09983 .47623 .11201 .47205 .10299 .46429 Mtetra
.10299 .46429 .11201 .47205 .12424 .46786 .11526 .46005 Mtetra
.11526 .46005 .12424 .46786 .13653 .46364 .12758 .4558 Mtetra
.12758 .4558 .13653 .46364 .14888 .4594 .13997 .45152 Mtetra
.13997 .45152 .14888 .4594 .1613 .45514 .15241 .44722 Mtetra
.15241 .44722 .1613 .45514 .17377 .45086 .16492 .4429 Mtetra
.16492 .4429 .17377 .45086 .1863 .44656 .17749 .43856 Mtetra
.17749 .43856 .1863 .44656 .19889 .44224 .19012 .4342 Mtetra
.19012 .4342 .19889 .44224 .21155 .4379 .20281 .42982 Mtetra
.94 .722 .58 r
.20281 .42982 .21155 .4379 .2317 .353 .22325 .34473 Mtetra
.656 .751 .92 r
.22325 .34473 .2317 .353 .24418 .34853 .23576 .34022 Mtetra
.23576 .34022 .24418 .34853 .25672 .34404 .24834 .33569 Mtetra
.24834 .33569 .25672 .34404 .26933 .33952 .26098 .33113 Mtetra
.26098 .33113 .26933 .33952 .28199 .33499 .27367 .32656 Mtetra
.27367 .32656 .28199 .33499 .29471 .33043 .28644 .32196 Mtetra
.28644 .32196 .29471 .33043 .3075 .32585 .29926 .31734 Mtetra
.29926 .31734 .3075 .32585 .32034 .32125 .31214 .3127 Mtetra
.31214 .3127 .32034 .32125 .33325 .31663 .32509 .30803 Mtetra
.32509 .30803 .33325 .31663 .34623 .31198 .3381 .30334 Mtetra
.3381 .30334 .34623 .31198 .35926 .30731 .35118 .29863 Mtetra
.35118 .29863 .35926 .30731 .37236 .30262 .36432 .2939 Mtetra
.36432 .2939 .37236 .30262 .38553 .29791 .37753 .28914 Mtetra
.96 .721 .532 r
.37753 .28914 .38553 .29791 .40291 .19061 .39523 .18164 Mtetra
.664 .741 .908 r
.39523 .18164 .40291 .19061 .41578 .18576 .40813 .17675 Mtetra
.40813 .17675 .41578 .18576 .42871 .18089 .4211 .17183 Mtetra
.4211 .17183 .42871 .18089 .4417 .17599 .43413 .16689 Mtetra
.43413 .16689 .4417 .17599 .45475 .17107 .44723 .16193 Mtetra
.44723 .16193 .45475 .17107 .46787 .16613 .46038 .15694 Mtetra
.46038 .15694 .46787 .16613 .48105 .16116 .4736 .15192 Mtetra
.4736 .15192 .48105 .16116 .49429 .15617 .48689 .14689 Mtetra
.48689 .14689 .49429 .15617 .5076 .15115 .50024 .14183 Mtetra
.50024 .14183 .5076 .15115 .52097 .14611 .51366 .13674 Mtetra
.51366 .13674 .52097 .14611 .53441 .14104 .52714 .13163 Mtetra
.52714 .13163 .53441 .14104 .54792 .13595 .54069 .12649 Mtetra
.54069 .12649 .54792 .13595 .56149 .13084 .5543 .12133 Mtetra
.5543 .12133 .56149 .13084 .57513 .1257 .56798 .11614 Mtetra
.56798 .11614 .57513 .1257 .58883 .12053 .58173 .11093 Mtetra
.58173 .11093 .58883 .12053 .60261 .11534 .59555 .10569 Mtetra
.59555 .10569 .60261 .11534 .61645 .11012 .60944 .10042 Mtetra
.60944 .10042 .61645 .11012 .63036 .10488 .6234 .09513 Mtetra
.6234 .09513 .63036 .10488 .64434 .09961 .63742 .08981 Mtetra
.63742 .08981 .64434 .09961 .65839 .09431 .65152 .08447 Mtetra
.65152 .08447 .65839 .09431 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.65 .758 .929 r
.04529 .47334 .05451 .48103 .06654 .47687 .05735 .46915 Mtetra
.05735 .46915 .06654 .47687 .07864 .4727 .06947 .46494 Mtetra
.06947 .46494 .07864 .4727 .09078 .4685 .08166 .46071 Mtetra
.08166 .46071 .09078 .4685 .10299 .46429 .09389 .45645 Mtetra
.09389 .45645 .10299 .46429 .11526 .46005 .10619 .45218 Mtetra
.10619 .45218 .11526 .46005 .12758 .4558 .11855 .44789 Mtetra
.11855 .44789 .12758 .4558 .13997 .45152 .13097 .44357 Mtetra
.13097 .44357 .13997 .45152 .15241 .44722 .14345 .43923 Mtetra
.14345 .43923 .15241 .44722 .16492 .4429 .15599 .43488 Mtetra
.15599 .43488 .16492 .4429 .17749 .43856 .1686 .4305 Mtetra
.1686 .4305 .17749 .43856 .19012 .4342 .18126 .4261 Mtetra
.18126 .4261 .19012 .4342 .20281 .42982 .19399 .42167 Mtetra
.94 .722 .58 r
.19399 .42167 .20281 .42982 .22325 .34473 .21472 .33639 Mtetra
.656 .751 .92 r
.21472 .33639 .22325 .34473 .23576 .34022 .22727 .33184 Mtetra
.22727 .33184 .23576 .34022 .24834 .33569 .23988 .32726 Mtetra
.23988 .32726 .24834 .33569 .26098 .33113 .25255 .32267 Mtetra
.25255 .32267 .26098 .33113 .27367 .32656 .26529 .31805 Mtetra
.26529 .31805 .27367 .32656 .28644 .32196 .27808 .31341 Mtetra
.27808 .31341 .28644 .32196 .29926 .31734 .29094 .30875 Mtetra
.29094 .30875 .29926 .31734 .31214 .3127 .30387 .30407 Mtetra
.30387 .30407 .31214 .3127 .32509 .30803 .31685 .29936 Mtetra
.31685 .29936 .32509 .30803 .3381 .30334 .32991 .29463 Mtetra
.32991 .29463 .3381 .30334 .35118 .29863 .34302 .28987 Mtetra
.34302 .28987 .35118 .29863 .36432 .2939 .3562 .2851 Mtetra
.3562 .2851 .36432 .2939 .37753 .28914 .36945 .28029 Mtetra
.96 .721 .532 r
.36945 .28029 .37753 .28914 .39523 .18164 .38748 .17259 Mtetra
.664 .741 .908 r
.38748 .17259 .39523 .18164 .40813 .17675 .40042 .16765 Mtetra
.40042 .16765 .40813 .17675 .4211 .17183 .41343 .16269 Mtetra
.41343 .16269 .4211 .17183 .43413 .16689 .4265 .15771 Mtetra
.4265 .15771 .43413 .16689 .44723 .16193 .43963 .1527 Mtetra
.43963 .1527 .44723 .16193 .46038 .15694 .45283 .14766 Mtetra
.45283 .14766 .46038 .15694 .4736 .15192 .46609 .14261 Mtetra
.46609 .14261 .4736 .15192 .48689 .14689 .47942 .13752 Mtetra
.47942 .13752 .48689 .14689 .50024 .14183 .49281 .13242 Mtetra
.49281 .13242 .50024 .14183 .51366 .13674 .50627 .12728 Mtetra
.50627 .12728 .51366 .13674 .52714 .13163 .5198 .12212 Mtetra
.5198 .12212 .52714 .13163 .54069 .12649 .53339 .11694 Mtetra
.53339 .11694 .54069 .12649 .5543 .12133 .54705 .11173 Mtetra
.54705 .11173 .5543 .12133 .56798 .11614 .56078 .1065 Mtetra
.56078 .1065 .56798 .11614 .58173 .11093 .57457 .10123 Mtetra
.57457 .10123 .58173 .11093 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10042 .60237 .09063 Mtetra
.60237 .09063 .60944 .10042 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63742 .08981 .63045 .07992 Mtetra
.63045 .07992 .63742 .08981 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.65 .758 .929 r
.03598 .46559 .04529 .47334 .05735 .46915 .04808 .46136 Mtetra
.04808 .46136 .05735 .46915 .06947 .46494 .06023 .45711 Mtetra
.06023 .45711 .06947 .46494 .08166 .46071 .07244 .45284 Mtetra
.07244 .45284 .08166 .46071 .09389 .45645 .08472 .44855 Mtetra
.08472 .44855 .09389 .45645 .10619 .45218 .09705 .44424 Mtetra
.09705 .44424 .10619 .45218 .11855 .44789 .10944 .4399 Mtetra
.10944 .4399 .11855 .44789 .13097 .44357 .12189 .43555 Mtetra
.12189 .43555 .13097 .44357 .14345 .43923 .13441 .43117 Mtetra
.13441 .43117 .14345 .43923 .15599 .43488 .14698 .42678 Mtetra
.14698 .42678 .15599 .43488 .1686 .4305 .15962 .42236 Mtetra
.15962 .42236 .1686 .4305 .18126 .4261 .17232 .41792 Mtetra
.17232 .41792 .18126 .4261 .19399 .42167 .18509 .41345 Mtetra
.94 .722 .58 r
.18509 .41345 .19399 .42167 .21472 .33639 .20611 .32797 Mtetra
.656 .751 .92 r
.20611 .32797 .21472 .33639 .22727 .33184 .21869 .32338 Mtetra
.21869 .32338 .22727 .33184 .23988 .32726 .23134 .31876 Mtetra
.23134 .31876 .23988 .32726 .25255 .32267 .24405 .31413 Mtetra
.24405 .31413 .25255 .32267 .26529 .31805 .25682 .30947 Mtetra
.25682 .30947 .26529 .31805 .27808 .31341 .26966 .30479 Mtetra
.26966 .30479 .27808 .31341 .29094 .30875 .28256 .30008 Mtetra
.28256 .30008 .29094 .30875 .30387 .30407 .29552 .29536 Mtetra
.29552 .29536 .30387 .30407 .31685 .29936 .30854 .29061 Mtetra
.30854 .29061 .31685 .29936 .32991 .29463 .32163 .28583 Mtetra
.32163 .28583 .32991 .29463 .34302 .28987 .33479 .28103 Mtetra
.33479 .28103 .34302 .28987 .3562 .2851 .34801 .27621 Mtetra
.34801 .27621 .3562 .2851 .36945 .28029 .3613 .27137 Mtetra
.96 .721 .532 r
.3613 .27137 .36945 .28029 .38748 .17259 .37966 .16346 Mtetra
.664 .741 .908 r
.37966 .16346 .38748 .17259 .40042 .16765 .39264 .15847 Mtetra
.39264 .15847 .40042 .16765 .41343 .16269 .40569 .15347 Mtetra
.40569 .15347 .41343 .16269 .4265 .15771 .4188 .14844 Mtetra
.4188 .14844 .4265 .15771 .43963 .1527 .43197 .14339 Mtetra
.43197 .14339 .43963 .1527 .45283 .14766 .44521 .13831 Mtetra
.44521 .13831 .45283 .14766 .46609 .14261 .45852 .1332 Mtetra
.45852 .1332 .46609 .14261 .47942 .13752 .47188 .12807 Mtetra
.47188 .12807 .47942 .13752 .49281 .13242 .48532 .12292 Mtetra
.48532 .12292 .49281 .13242 .50627 .12728 .49882 .11774 Mtetra
.49882 .11774 .50627 .12728 .5198 .12212 .51239 .11253 Mtetra
.51239 .11253 .5198 .12212 .53339 .11694 .52603 .1073 Mtetra
.52603 .1073 .53339 .11694 .54705 .11173 .53973 .10205 Mtetra
.53973 .10205 .54705 .11173 .56078 .1065 .5535 .09676 Mtetra
.5535 .09676 .56078 .1065 .57457 .10123 .56734 .09145 Mtetra
.56734 .09145 .57457 .10123 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09063 .59523 .08075 Mtetra
.59523 .08075 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.65 .758 .929 r
.02659 .45776 .03598 .46559 .04808 .46136 .03872 .4535 Mtetra
.03872 .4535 .04808 .46136 .06023 .45711 .05091 .44921 Mtetra
.05091 .44921 .06023 .45711 .07244 .45284 .06315 .4449 Mtetra
.06315 .4449 .07244 .45284 .08472 .44855 .07546 .44057 Mtetra
.07546 .44057 .08472 .44855 .09705 .44424 .08782 .43622 Mtetra
.08782 .43622 .09705 .44424 .10944 .4399 .10025 .43185 Mtetra
.10025 .43185 .10944 .4399 .12189 .43555 .11273 .42745 Mtetra
.11273 .42745 .12189 .43555 .13441 .43117 .12528 .42304 Mtetra
.12528 .42304 .13441 .43117 .14698 .42678 .13789 .4186 Mtetra
.13789 .4186 .14698 .42678 .15962 .42236 .15057 .41414 Mtetra
.15057 .41414 .15962 .42236 .17232 .41792 .1633 .40966 Mtetra
.1633 .40966 .17232 .41792 .18509 .41345 .1761 .40515 Mtetra
.94 .722 .58 r
.1761 .40515 .18509 .41345 .20611 .32797 .19742 .31948 Mtetra
.656 .751 .92 r
.19742 .31948 .20611 .32797 .21869 .32338 .21005 .31484 Mtetra
.21005 .31484 .21869 .32338 .23134 .31876 .22273 .31019 Mtetra
.22273 .31019 .23134 .31876 .24405 .31413 .23548 .30551 Mtetra
.23548 .30551 .24405 .31413 .25682 .30947 .24828 .30081 Mtetra
.24828 .30081 .25682 .30947 .26966 .30479 .26116 .29609 Mtetra
.26116 .29609 .26966 .30479 .28256 .30008 .27409 .29134 Mtetra
.27409 .29134 .28256 .30008 .29552 .29536 .28709 .28657 Mtetra
.28709 .28657 .29552 .29536 .30854 .29061 .30016 .28177 Mtetra
.30016 .28177 .30854 .29061 .32163 .28583 .31328 .27696 Mtetra
.31328 .27696 .32163 .28583 .33479 .28103 .32648 .27211 Mtetra
.32648 .27211 .33479 .28103 .34801 .27621 .33974 .26725 Mtetra
.33974 .26725 .34801 .27621 .3613 .27137 .35307 .26235 Mtetra
.96 .721 .532 r
.35307 .26235 .3613 .27137 .37966 .16346 .37177 .15424 Mtetra
.664 .741 .908 r
.37177 .15424 .37966 .16346 .39264 .15847 .38479 .14922 Mtetra
.38479 .14922 .39264 .15847 .40569 .15347 .39788 .14417 Mtetra
.39788 .14417 .40569 .15347 .4188 .14844 .41103 .13909 Mtetra
.41103 .13909 .4188 .14844 .43197 .14339 .42424 .13399 Mtetra
.42424 .13399 .43197 .14339 .44521 .13831 .43752 .12886 Mtetra
.43752 .12886 .44521 .13831 .45852 .1332 .45087 .12371 Mtetra
.45087 .12371 .45852 .1332 .47188 .12807 .46428 .11854 Mtetra
.46428 .11854 .47188 .12807 .48532 .12292 .47776 .11334 Mtetra
.47776 .11334 .48532 .12292 .49882 .11774 .4913 .10811 Mtetra
.4913 .10811 .49882 .11774 .51239 .11253 .50491 .10286 Mtetra
.50491 .10286 .51239 .11253 .52603 .1073 .51859 .09758 Mtetra
.51859 .09758 .52603 .1073 .53973 .10205 .53234 .09227 Mtetra
.53234 .09227 .53973 .10205 .5535 .09676 .54616 .08694 Mtetra
.54616 .08694 .5535 .09676 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.65 .758 .929 r
.01712 .44987 .02659 .45776 .03872 .4535 .02928 .44556 Mtetra
.02928 .44556 .03872 .4535 .05091 .44921 .0415 .44124 Mtetra
.0415 .44124 .05091 .44921 .06315 .4449 .05377 .43689 Mtetra
.05377 .43689 .06315 .4449 .07546 .44057 .06611 .43252 Mtetra
.06611 .43252 .07546 .44057 .08782 .43622 .07851 .42813 Mtetra
.07851 .42813 .08782 .43622 .10025 .43185 .09097 .42372 Mtetra
.09097 .42372 .10025 .43185 .11273 .42745 .10349 .41928 Mtetra
.10349 .41928 .11273 .42745 .12528 .42304 .11607 .41483 Mtetra
.11607 .41483 .12528 .42304 .13789 .4186 .12872 .41035 Mtetra
.12872 .41035 .13789 .4186 .15057 .41414 .14143 .40585 Mtetra
.14143 .40585 .15057 .41414 .1633 .40966 .1542 .40133 Mtetra
.1542 .40133 .1633 .40966 .1761 .40515 .16704 .39678 Mtetra
.94 .722 .58 r
.16704 .39678 .1761 .40515 .19742 .31948 .18866 .31091 Mtetra
.656 .751 .92 r
.18866 .31091 .19742 .31948 .21005 .31484 .20132 .30623 Mtetra
.20132 .30623 .21005 .31484 .22273 .31019 .21404 .30153 Mtetra
.21404 .30153 .22273 .31019 .23548 .30551 .22682 .29681 Mtetra
.22682 .29681 .23548 .30551 .24828 .30081 .23967 .29207 Mtetra
.23967 .29207 .24828 .30081 .26116 .29609 .25258 .2873 Mtetra
.25258 .2873 .26116 .29609 .27409 .29134 .26555 .28251 Mtetra
.26555 .28251 .27409 .29134 .28709 .28657 .27859 .2777 Mtetra
.27859 .2777 .28709 .28657 .30016 .28177 .29169 .27286 Mtetra
.29169 .27286 .30016 .28177 .31328 .27696 .30486 .268 Mtetra
.30486 .268 .31328 .27696 .32648 .27211 .31809 .26311 Mtetra
.31809 .26311 .32648 .27211 .33974 .26725 .33139 .2582 Mtetra
.33139 .2582 .33974 .26725 .35307 .26235 .34476 .25326 Mtetra
.96 .721 .532 r
.34476 .25326 .35307 .26235 .37177 .15424 .36381 .14494 Mtetra
.664 .741 .908 r
.36381 .14494 .37177 .15424 .38479 .14922 .37687 .13987 Mtetra
.37687 .13987 .38479 .14922 .39788 .14417 .39 .13478 Mtetra
.39 .13478 .39788 .14417 .41103 .13909 .40319 .12965 Mtetra
.40319 .12965 .41103 .13909 .42424 .13399 .41644 .12451 Mtetra
.41644 .12451 .42424 .13399 .43752 .12886 .42976 .11934 Mtetra
.42976 .11934 .43752 .12886 .45087 .12371 .44315 .11414 Mtetra
.44315 .11414 .45087 .12371 .46428 .11854 .4566 .10892 Mtetra
.4566 .10892 .46428 .11854 .47776 .11334 .47013 .10367 Mtetra
.47013 .10367 .47776 .11334 .4913 .10811 .48371 .09839 Mtetra
.48371 .09839 .4913 .10811 .50491 .10286 .49737 .09309 Mtetra
.49737 .09309 .50491 .10286 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09227 .52489 .0824 Mtetra
.52489 .0824 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.65 .758 .929 r
.00756 .4419 .01712 .44987 .02928 .44556 .01975 .43756 Mtetra
.01975 .43756 .02928 .44556 .0415 .44124 .032 .43319 Mtetra
.032 .43319 .0415 .44124 .05377 .43689 .04431 .42881 Mtetra
.04431 .42881 .05377 .43689 .06611 .43252 .05668 .4244 Mtetra
.05668 .4244 .06611 .43252 .07851 .42813 .06911 .41997 Mtetra
.06911 .41997 .07851 .42813 .09097 .42372 .08161 .41551 Mtetra
.08161 .41551 .09097 .42372 .10349 .41928 .09416 .41104 Mtetra
.09416 .41104 .10349 .41928 .11607 .41483 .10678 .40654 Mtetra
.10678 .40654 .11607 .41483 .12872 .41035 .11946 .40202 Mtetra
.11946 .40202 .12872 .41035 .14143 .40585 .1322 .39748 Mtetra
.1322 .39748 .14143 .40585 .1542 .40133 .14501 .39292 Mtetra
.14501 .39292 .1542 .40133 .16704 .39678 .15788 .38833 Mtetra
.94 .722 .58 r
.15788 .38833 .16704 .39678 .18866 .31091 .17982 .30226 Mtetra
.656 .751 .92 r
.17982 .30226 .18866 .31091 .20132 .30623 .19251 .29754 Mtetra
.19251 .29754 .20132 .30623 .21404 .30153 .20527 .2928 Mtetra
.20527 .2928 .21404 .30153 .22682 .29681 .21809 .28804 Mtetra
.21809 .28804 .22682 .29681 .23967 .29207 .23097 .28325 Mtetra
.23097 .28325 .23967 .29207 .25258 .2873 .24392 .27844 Mtetra
.24392 .27844 .25258 .2873 .26555 .28251 .25693 .27361 Mtetra
.25693 .27361 .26555 .28251 .27859 .2777 .27 .26875 Mtetra
.27 .26875 .27859 .2777 .29169 .27286 .28315 .26386 Mtetra
.28315 .26386 .29169 .27286 .30486 .268 .29636 .25895 Mtetra
.29636 .25895 .30486 .268 .31809 .26311 .30963 .25402 Mtetra
.30963 .25402 .31809 .26311 .33139 .2582 .32297 .24906 Mtetra
.32297 .24906 .33139 .2582 .34476 .25326 .33638 .24408 Mtetra
.96 .721 .532 r
.33638 .24408 .34476 .25326 .36381 .14494 .35578 .13556 Mtetra
.664 .741 .908 r
.35578 .13556 .36381 .14494 .37687 .13987 .36888 .13044 Mtetra
.36888 .13044 .37687 .13987 .39 .13478 .38204 .1253 Mtetra
.38204 .1253 .39 .13478 .40319 .12965 .39527 .12013 Mtetra
.39527 .12013 .40319 .12965 .41644 .12451 .40857 .11494 Mtetra
.40857 .11494 .41644 .12451 .42976 .11934 .42193 .10972 Mtetra
.42193 .10972 .42976 .11934 .44315 .11414 .43536 .10448 Mtetra
.43536 .10448 .44315 .11414 .4566 .10892 .44886 .0992 Mtetra
.44886 .0992 .4566 .10892 .47013 .10367 .46242 .09391 Mtetra
.46242 .09391 .47013 .10367 .48371 .09839 .47605 .08858 Mtetra
.47605 .08858 .48371 .09839 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .0824 .51736 .07245 Mtetra
.51736 .07245 .52489 .0824 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .57879 .48228 .57294 Mtetra
.48228 .57294 .48818 .57879 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57244 .5035 .56654 Mtetra
.5035 .56654 .50935 .57244 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .56009 Mtetra
.52489 .56009 .53068 .56605 .54141 .56283 .53564 .55685 Mtetra
.53564 .55685 .54141 .56283 .55218 .5596 .54644 .5536 Mtetra
.54644 .5536 .55218 .5596 .56299 .55635 .55728 .55033 Mtetra
.55728 .55033 .56299 .55635 .57385 .5531 .56816 .54705 Mtetra
.56816 .54705 .57385 .5531 .58474 .54983 .57909 .54376 Mtetra
.57909 .54376 .58474 .54983 .59568 .54654 .59006 .54045 Mtetra
.59006 .54045 .59568 .54654 .60667 .54325 .60107 .53713 Mtetra
.60107 .53713 .60667 .54325 .61769 .53994 .61213 .5338 Mtetra
.61213 .5338 .61769 .53994 .62876 .53662 .62323 .53045 Mtetra
.62323 .53045 .62876 .53662 .63988 .53329 .63437 .5271 Mtetra
.63437 .5271 .63988 .53329 .65104 .52994 .64556 .52372 Mtetra
.64556 .52372 .65104 .52994 .66224 .52658 .65679 .52034 Mtetra
.65679 .52034 .66224 .52658 .67349 .5232 .66807 .51694 Mtetra
.964 .65 .372 r
.66807 .51694 .67349 .5232 .69092 .64824 .68535 .6422 Mtetra
.653 .754 .924 r
.68535 .6422 .69092 .64824 .70271 .64498 .69717 .63891 Mtetra
.69717 .63891 .70271 .64498 .71455 .6417 .70905 .63561 Mtetra
.70905 .63561 .71455 .6417 .72643 .6384 .72097 .63229 Mtetra
.72097 .63229 .72643 .6384 .73837 .6351 .73294 .62896 Mtetra
.73294 .62896 .73837 .6351 .75035 .63178 .74496 .62561 Mtetra
.74496 .62561 .75035 .63178 .76239 .62844 .75703 .62225 Mtetra
.75703 .62225 .76239 .62844 .77448 .6251 .76915 .61888 Mtetra
.76915 .61888 .77448 .6251 .78661 .62173 .78132 .61549 Mtetra
.78132 .61549 .78661 .62173 .7988 .61836 .79355 .61209 Mtetra
.79355 .61209 .7988 .61836 .81104 .61497 .80583 .60867 Mtetra
.80583 .60867 .81104 .61497 .82334 .61156 .81816 .60524 Mtetra
.612 .146 0 r
.81816 .60524 .82334 .61156 .83774 .63082 .83257 .62452 Mtetra
.651 .756 .927 r
.83257 .62452 .83774 .63082 .85022 .62741 .84509 .62108 Mtetra
.84509 .62108 .85022 .62741 .86276 .62399 .85767 .61763 Mtetra
.85767 .61763 .86276 .62399 .87535 .62055 .8703 .61417 Mtetra
.8703 .61417 .87535 .62055 .888 .6171 .88299 .61069 Mtetra
.88299 .61069 .888 .6171 .9007 .61363 .89573 .60719 Mtetra
.89573 .60719 .9007 .61363 .91346 .61015 .90853 .60368 Mtetra
.90853 .60368 .91346 .61015 .92627 .60665 .92138 .60015 Mtetra
.92138 .60015 .92627 .60665 .93914 .60314 .93429 .59661 Mtetra
.93429 .59661 .93914 .60314 .95206 .59961 .94725 .59306 Mtetra
.94725 .59306 .95206 .59961 .96504 .59607 .96028 .58948 Mtetra
.96028 .58948 .96504 .59607 .97808 .59251 .97336 .58589 Mtetra
.97336 .58589 .97808 .59251 .99117 .58893 .9865 .58229 Mtetra
.664 .741 .908 r
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57342 Mtetra
.45523 .57342 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55735 Mtetra
.50831 .55735 .51417 .56332 .52489 .56009 .51905 .5541 Mtetra
.51905 .5541 .52489 .56009 .53564 .55685 .52983 .55083 Mtetra
.52983 .55083 .53564 .55685 .54644 .5536 .54066 .54756 Mtetra
.54066 .54756 .54644 .5536 .55728 .55033 .55153 .54426 Mtetra
.55153 .54426 .55728 .55033 .56816 .54705 .56244 .54096 Mtetra
.56244 .54096 .56816 .54705 .57909 .54376 .57339 .53764 Mtetra
.57339 .53764 .57909 .54376 .59006 .54045 .58439 .53431 Mtetra
.58439 .53431 .59006 .54045 .60107 .53713 .59543 .53097 Mtetra
.59543 .53097 .60107 .53713 .61213 .5338 .60652 .52761 Mtetra
.60652 .52761 .61213 .5338 .62323 .53045 .61765 .52424 Mtetra
.61765 .52424 .62323 .53045 .63437 .5271 .62882 .52086 Mtetra
.62882 .52086 .63437 .5271 .64556 .52372 .64004 .51746 Mtetra
.64004 .51746 .64556 .52372 .65679 .52034 .6513 .51405 Mtetra
.6513 .51405 .65679 .52034 .66807 .51694 .66261 .51063 Mtetra
.964 .65 .372 r
.66261 .51063 .66807 .51694 .68535 .6422 .67974 .63612 Mtetra
.653 .754 .924 r
.67974 .63612 .68535 .6422 .69717 .63891 .6916 .6328 Mtetra
.6916 .6328 .69717 .63891 .70905 .63561 .7035 .62947 Mtetra
.7035 .62947 .70905 .63561 .72097 .63229 .71546 .62613 Mtetra
.71546 .62613 .72097 .63229 .73294 .62896 .72746 .62277 Mtetra
.72746 .62277 .73294 .62896 .74496 .62561 .73952 .6194 Mtetra
.73952 .6194 .74496 .62561 .75703 .62225 .75162 .61601 Mtetra
.75162 .61601 .75703 .62225 .76915 .61888 .76378 .61261 Mtetra
.76378 .61261 .76915 .61888 .78132 .61549 .77599 .6092 Mtetra
.77599 .6092 .78132 .61549 .79355 .61209 .78826 .60577 Mtetra
.78826 .60577 .79355 .61209 .80583 .60867 .80057 .60232 Mtetra
.80057 .60232 .80583 .60867 .81816 .60524 .81294 .59886 Mtetra
.612 .146 0 r
.81294 .59886 .81816 .60524 .83257 .62452 .82736 .61816 Mtetra
.651 .756 .927 r
.82736 .61816 .83257 .62452 .84509 .62108 .83992 .6147 Mtetra
.83992 .6147 .84509 .62108 .85767 .61763 .85254 .61122 Mtetra
.85254 .61122 .85767 .61763 .8703 .61417 .86521 .60773 Mtetra
.86521 .60773 .8703 .61417 .88299 .61069 .87794 .60422 Mtetra
.87794 .60422 .88299 .61069 .89573 .60719 .89072 .6007 Mtetra
.89072 .6007 .89573 .60719 .90853 .60368 .90356 .59716 Mtetra
.90356 .59716 .90853 .60368 .92138 .60015 .91645 .5936 Mtetra
.91645 .5936 .92138 .60015 .93429 .59661 .9294 .59003 Mtetra
.9294 .59003 .93429 .59661 .94725 .59306 .94241 .58645 Mtetra
.94241 .58645 .94725 .59306 .96028 .58948 .95547 .58285 Mtetra
.95547 .58285 .96028 .58948 .97336 .58589 .9686 .57923 Mtetra
.9686 .57923 .97336 .58589 .9865 .58229 .98178 .57559 Mtetra
.664 .741 .908 r
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57342 .44919 .56753 Mtetra
.44919 .56753 .45523 .57342 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .5546 Mtetra
.49168 .5546 .49761 .56059 .50831 .55735 .5024 .55134 Mtetra
.5024 .55134 .50831 .55735 .51905 .5541 .51317 .54806 Mtetra
.51317 .54806 .51905 .5541 .52983 .55083 .52398 .54477 Mtetra
.52398 .54477 .52983 .55083 .54066 .54756 .53484 .54147 Mtetra
.53484 .54147 .54066 .54756 .55153 .54426 .54573 .53815 Mtetra
.54573 .53815 .55153 .54426 .56244 .54096 .55667 .53483 Mtetra
.55667 .53483 .56244 .54096 .57339 .53764 .56766 .53149 Mtetra
.56766 .53149 .57339 .53764 .58439 .53431 .57868 .52813 Mtetra
.57868 .52813 .58439 .53431 .59543 .53097 .58975 .52476 Mtetra
.58975 .52476 .59543 .53097 .60652 .52761 .60087 .52138 Mtetra
.60087 .52138 .60652 .52761 .61765 .52424 .61203 .51799 Mtetra
.61203 .51799 .61765 .52424 .62882 .52086 .62323 .51458 Mtetra
.62323 .51458 .62882 .52086 .64004 .51746 .63448 .51115 Mtetra
.63448 .51115 .64004 .51746 .6513 .51405 .64578 .50772 Mtetra
.64578 .50772 .6513 .51405 .66261 .51063 .65712 .50427 Mtetra
.964 .65 .372 r
.65712 .50427 .66261 .51063 .67974 .63612 .67408 .62998 Mtetra
.653 .754 .924 r
.67408 .62998 .67974 .63612 .6916 .6328 .68597 .62664 Mtetra
.68597 .62664 .6916 .6328 .7035 .62947 .69791 .62329 Mtetra
.69791 .62329 .7035 .62947 .71546 .62613 .7099 .61992 Mtetra
.7099 .61992 .71546 .62613 .72746 .62277 .72194 .61653 Mtetra
.72194 .61653 .72746 .62277 .73952 .6194 .73404 .61313 Mtetra
.73404 .61313 .73952 .6194 .75162 .61601 .74618 .60972 Mtetra
.74618 .60972 .75162 .61601 .76378 .61261 .75837 .60629 Mtetra
.75837 .60629 .76378 .61261 .77599 .6092 .77062 .60285 Mtetra
.77062 .60285 .77599 .6092 .78826 .60577 .78292 .5994 Mtetra
.78292 .5994 .78826 .60577 .80057 .60232 .79527 .59592 Mtetra
.79527 .59592 .80057 .60232 .81294 .59886 .80768 .59244 Mtetra
.612 .146 0 r
.80768 .59244 .81294 .59886 .82736 .61816 .82211 .61176 Mtetra
.651 .756 .927 r
.82211 .61176 .82736 .61816 .83992 .6147 .83471 .60827 Mtetra
.83471 .60827 .83992 .6147 .85254 .61122 .84737 .60476 Mtetra
.84737 .60476 .85254 .61122 .86521 .60773 .86008 .60124 Mtetra
.86008 .60124 .86521 .60773 .87794 .60422 .87284 .5977 Mtetra
.87284 .5977 .87794 .60422 .89072 .6007 .88567 .59415 Mtetra
.88567 .59415 .89072 .6007 .90356 .59716 .89855 .59058 Mtetra
.89855 .59058 .90356 .59716 .91645 .5936 .91148 .587 Mtetra
.91148 .587 .91645 .5936 .9294 .59003 .92447 .5834 Mtetra
.92447 .5834 .9294 .59003 .94241 .58645 .93752 .57979 Mtetra
.93752 .57979 .94241 .58645 .95547 .58285 .95063 .57615 Mtetra
.95063 .57615 .95547 .58285 .9686 .57923 .9638 .57251 Mtetra
.9638 .57251 .9686 .57923 .98178 .57559 .97702 .56884 Mtetra
.664 .741 .908 r
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .5551 Mtetra
.46432 .5551 .47035 .56109 .48099 .55785 .47499 .55184 Mtetra
.47499 .55184 .48099 .55785 .49168 .5546 .4857 .54857 Mtetra
.4857 .54857 .49168 .5546 .5024 .55134 .49646 .54528 Mtetra
.49646 .54528 .5024 .55134 .51317 .54806 .50725 .54198 Mtetra
.50725 .54198 .51317 .54806 .52398 .54477 .51809 .53867 Mtetra
.51809 .53867 .52398 .54477 .53484 .54147 .52897 .53534 Mtetra
.52897 .53534 .53484 .54147 .54573 .53815 .5399 .532 Mtetra
.5399 .532 .54573 .53815 .55667 .53483 .55087 .52865 Mtetra
.55087 .52865 .55667 .53483 .56766 .53149 .56188 .52528 Mtetra
.56188 .52528 .56766 .53149 .57868 .52813 .57293 .5219 Mtetra
.57293 .5219 .57868 .52813 .58975 .52476 .58403 .51851 Mtetra
.58403 .51851 .58975 .52476 .60087 .52138 .59518 .5151 Mtetra
.59518 .5151 .60087 .52138 .61203 .51799 .60637 .51168 Mtetra
.60637 .51168 .61203 .51799 .62323 .51458 .6176 .50825 Mtetra
.6176 .50825 .62323 .51458 .63448 .51115 .62888 .5048 Mtetra
.62888 .5048 .63448 .51115 .64578 .50772 .64021 .50134 Mtetra
.64021 .50134 .64578 .50772 .65712 .50427 .65158 .49786 Mtetra
.964 .65 .372 r
.65158 .49786 .65712 .50427 .67408 .62998 .66838 .6238 Mtetra
.653 .754 .924 r
.66838 .6238 .67408 .62998 .68597 .62664 .68031 .62044 Mtetra
.68031 .62044 .68597 .62664 .69791 .62329 .69228 .61705 Mtetra
.69228 .61705 .69791 .62329 .7099 .61992 .70431 .61366 Mtetra
.70431 .61366 .7099 .61992 .72194 .61653 .71638 .61025 Mtetra
.71638 .61025 .72194 .61653 .73404 .61313 .72851 .60682 Mtetra
.72851 .60682 .73404 .61313 .74618 .60972 .74069 .60338 Mtetra
.74069 .60338 .74618 .60972 .75837 .60629 .75292 .59993 Mtetra
.75292 .59993 .75837 .60629 .77062 .60285 .7652 .59646 Mtetra
.7652 .59646 .77062 .60285 .78292 .5994 .77754 .59297 Mtetra
.77754 .59297 .78292 .5994 .79527 .59592 .78993 .58947 Mtetra
.78993 .58947 .79527 .59592 .80768 .59244 .80237 .58596 Mtetra
.612 .146 0 r
.80237 .58596 .80768 .59244 .82211 .61176 .81682 .6053 Mtetra
.651 .756 .927 r
.81682 .6053 .82211 .61176 .83471 .60827 .82946 .60178 Mtetra
.82946 .60178 .83471 .60827 .84737 .60476 .84215 .59825 Mtetra
.84215 .59825 .84737 .60476 .86008 .60124 .8549 .5947 Mtetra
.8549 .5947 .86008 .60124 .87284 .5977 .86771 .59113 Mtetra
.86771 .59113 .87284 .5977 .88567 .59415 .88057 .58755 Mtetra
.88057 .58755 .88567 .59415 .89855 .59058 .89349 .58396 Mtetra
.89349 .58396 .89855 .59058 .91148 .587 .90647 .58034 Mtetra
.90647 .58034 .91148 .587 .92447 .5834 .91951 .57671 Mtetra
.91951 .57671 .92447 .5834 .93752 .57979 .9326 .57307 Mtetra
.9326 .57307 .93752 .57979 .95063 .57615 .94575 .56941 Mtetra
.94575 .56941 .95063 .57615 .9638 .57251 .95896 .56573 Mtetra
.95896 .56573 .9638 .57251 .97702 .56884 .97223 .56204 Mtetra
.664 .741 .908 r
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .5556 Mtetra
.43698 .5556 .44311 .56159 .45369 .55835 .4476 .55234 Mtetra
.4476 .55234 .45369 .55835 .46432 .5551 .45825 .54907 Mtetra
.45825 .54907 .46432 .5551 .47499 .55184 .46895 .54579 Mtetra
.46895 .54579 .47499 .55184 .4857 .54857 .47968 .54249 Mtetra
.47968 .54249 .4857 .54857 .49646 .54528 .49046 .53918 Mtetra
.49046 .53918 .49646 .54528 .50725 .54198 .50129 .53585 Mtetra
.50129 .53585 .50725 .54198 .51809 .53867 .51215 .53251 Mtetra
.51215 .53251 .51809 .53867 .52897 .53534 .52306 .52916 Mtetra
.52306 .52916 .52897 .53534 .5399 .532 .53402 .5258 Mtetra
.53402 .5258 .5399 .532 .55087 .52865 .54501 .52242 Mtetra
.54501 .52242 .55087 .52865 .56188 .52528 .55606 .51903 Mtetra
.55606 .51903 .56188 .52528 .57293 .5219 .56714 .51563 Mtetra
.56714 .51563 .57293 .5219 .58403 .51851 .57827 .51221 Mtetra
.57827 .51221 .58403 .51851 .59518 .5151 .58944 .50878 Mtetra
.58944 .50878 .59518 .5151 .60637 .51168 .60066 .50533 Mtetra
.60066 .50533 .60637 .51168 .6176 .50825 .61193 .50187 Mtetra
.61193 .50187 .6176 .50825 .62888 .5048 .62324 .4984 Mtetra
.62324 .4984 .62888 .5048 .64021 .50134 .6346 .49491 Mtetra
.6346 .49491 .64021 .50134 .65158 .49786 .646 .49141 Mtetra
.964 .65 .372 r
.646 .49141 .65158 .49786 .66838 .6238 .66264 .61758 Mtetra
.653 .754 .924 r
.66264 .61758 .66838 .6238 .68031 .62044 .6746 .61418 Mtetra
.6746 .61418 .68031 .62044 .69228 .61705 .68661 .61077 Mtetra
.68661 .61077 .69228 .61705 .70431 .61366 .69867 .60735 Mtetra
.69867 .60735 .70431 .61366 .71638 .61025 .71078 .60391 Mtetra
.71078 .60391 .71638 .61025 .72851 .60682 .72294 .60046 Mtetra
.72294 .60046 .72851 .60682 .74069 .60338 .73516 .59699 Mtetra
.73516 .59699 .74069 .60338 .75292 .59993 .74742 .59351 Mtetra
.74742 .59351 .75292 .59993 .7652 .59646 .75975 .59001 Mtetra
.75975 .59001 .7652 .59646 .77754 .59297 .77212 .5865 Mtetra
.77212 .5865 .77754 .59297 .78993 .58947 .78455 .58297 Mtetra
.78455 .58297 .78993 .58947 .80237 .58596 .79703 .57943 Mtetra
.612 .146 0 r
.79703 .57943 .80237 .58596 .81682 .6053 .81148 .59879 Mtetra
.651 .756 .927 r
.81148 .59879 .81682 .6053 .82946 .60178 .82416 .59525 Mtetra
.82416 .59525 .82946 .60178 .84215 .59825 .8369 .59168 Mtetra
.8369 .59168 .84215 .59825 .8549 .5947 .84969 .58811 Mtetra
.84969 .58811 .8549 .5947 .86771 .59113 .86254 .58451 Mtetra
.86254 .58451 .86771 .59113 .88057 .58755 .87544 .5809 Mtetra
.87544 .5809 .88057 .58755 .89349 .58396 .8884 .57727 Mtetra
.8884 .57727 .89349 .58396 .90647 .58034 .90142 .57363 Mtetra
.90142 .57363 .90647 .58034 .91951 .57671 .9145 .56997 Mtetra
.9145 .56997 .91951 .57671 .9326 .57307 .92763 .5663 Mtetra
.92763 .5663 .9326 .57307 .94575 .56941 .94083 .56261 Mtetra
.94083 .56261 .94575 .56941 .95896 .56573 .95408 .5589 Mtetra
.95408 .5589 .95896 .56573 .97223 .56204 .96739 .55517 Mtetra
.664 .741 .908 r
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55284 Mtetra
.42022 .55284 .42641 .55885 .43698 .5556 .43081 .54957 Mtetra
.43081 .54957 .43698 .5556 .4476 .55234 .44145 .54629 Mtetra
.44145 .54629 .4476 .55234 .45825 .54907 .45213 .543 Mtetra
.45213 .543 .45825 .54907 .46895 .54579 .46286 .53969 Mtetra
.46286 .53969 .46895 .54579 .47968 .54249 .47362 .53636 Mtetra
.47362 .53636 .47968 .54249 .49046 .53918 .48443 .53303 Mtetra
.48443 .53303 .49046 .53918 .50129 .53585 .49528 .52968 Mtetra
.49528 .52968 .50129 .53585 .51215 .53251 .50617 .52632 Mtetra
.50617 .52632 .51215 .53251 .52306 .52916 .51711 .52294 Mtetra
.51711 .52294 .52306 .52916 .53402 .5258 .52809 .51955 Mtetra
.52809 .51955 .53402 .5258 .54501 .52242 .53912 .51615 Mtetra
.53912 .51615 .54501 .52242 .55606 .51903 .55019 .51274 Mtetra
.55019 .51274 .55606 .51903 .56714 .51563 .5613 .50931 Mtetra
.5613 .50931 .56714 .51563 .57827 .51221 .57246 .50586 Mtetra
.57246 .50586 .57827 .51221 .58944 .50878 .58367 .50241 Mtetra
.58367 .50241 .58944 .50878 .60066 .50533 .59492 .49893 Mtetra
.59492 .49893 .60066 .50533 .61193 .50187 .60621 .49545 Mtetra
.60621 .49545 .61193 .50187 .62324 .4984 .61755 .49195 Mtetra
.61755 .49195 .62324 .4984 .6346 .49491 .62894 .48843 Mtetra
.62894 .48843 .6346 .49491 .646 .49141 .64038 .48491 Mtetra
.964 .65 .372 r
.64038 .48491 .646 .49141 .66264 .61758 .65685 .6113 Mtetra
.653 .754 .924 r
.65685 .6113 .66264 .61758 .6746 .61418 .66884 .60788 Mtetra
.66884 .60788 .6746 .61418 .68661 .61077 .68089 .60444 Mtetra
.68089 .60444 .68661 .61077 .69867 .60735 .69298 .60099 Mtetra
.69298 .60099 .69867 .60735 .71078 .60391 .70513 .59753 Mtetra
.70513 .59753 .71078 .60391 .72294 .60046 .71733 .59405 Mtetra
.71733 .59405 .72294 .60046 .73516 .59699 .72958 .59055 Mtetra
.72958 .59055 .73516 .59699 .74742 .59351 .74188 .58704 Mtetra
.74188 .58704 .74742 .59351 .75975 .59001 .75424 .58352 Mtetra
.75424 .58352 .75975 .59001 .77212 .5865 .76665 .57998 Mtetra
.76665 .57998 .77212 .5865 .78455 .58297 .77912 .57642 Mtetra
.77912 .57642 .78455 .58297 .79703 .57943 .79164 .57285 Mtetra
.612 .146 0 r
.79164 .57285 .79703 .57943 .81148 .59879 .8061 .59223 Mtetra
.651 .756 .927 r
.8061 .59223 .81148 .59879 .82416 .59525 .81882 .58866 Mtetra
.81882 .58866 .82416 .59525 .8369 .59168 .8316 .58506 Mtetra
.8316 .58506 .8369 .59168 .84969 .58811 .84443 .58146 Mtetra
.84443 .58146 .84969 .58811 .86254 .58451 .85732 .57783 Mtetra
.85732 .57783 .86254 .58451 .87544 .5809 .87026 .57419 Mtetra
.87026 .57419 .87544 .5809 .8884 .57727 .88327 .57054 Mtetra
.88327 .57054 .8884 .57727 .90142 .57363 .89633 .56686 Mtetra
.89633 .56686 .90142 .57363 .9145 .56997 .90945 .56318 Mtetra
.90945 .56318 .9145 .56997 .92763 .5663 .92263 .55947 Mtetra
.92263 .55947 .92763 .5663 .94083 .56261 .93586 .55575 Mtetra
.93586 .55575 .94083 .56261 .95408 .5589 .94916 .55201 Mtetra
.94916 .55201 .95408 .5589 .96739 .55517 .96252 .54825 Mtetra
.664 .741 .908 r
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55984 Mtetra
.37189 .55984 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55284 .41397 .5468 Mtetra
.41397 .5468 .42022 .55284 .43081 .54957 .4246 .5435 Mtetra
.4246 .5435 .43081 .54957 .44145 .54629 .43526 .5402 Mtetra
.43526 .5402 .44145 .54629 .45213 .543 .44597 .53688 Mtetra
.44597 .53688 .45213 .543 .46286 .53969 .45672 .53354 Mtetra
.45672 .53354 .46286 .53969 .47362 .53636 .46751 .5302 Mtetra
.46751 .5302 .47362 .53636 .48443 .53303 .47835 .52684 Mtetra
.47835 .52684 .48443 .53303 .49528 .52968 .48923 .52346 Mtetra
.48923 .52346 .49528 .52968 .50617 .52632 .50015 .52008 Mtetra
.50015 .52008 .50617 .52632 .51711 .52294 .51112 .51668 Mtetra
.51112 .51668 .51711 .52294 .52809 .51955 .52213 .51326 Mtetra
.52213 .51326 .52809 .51955 .53912 .51615 .53318 .50983 Mtetra
.53318 .50983 .53912 .51615 .55019 .51274 .54428 .50639 Mtetra
.54428 .50639 .55019 .51274 .5613 .50931 .55543 .50294 Mtetra
.55543 .50294 .5613 .50931 .57246 .50586 .56661 .49947 Mtetra
.56661 .49947 .57246 .50586 .58367 .50241 .57785 .49599 Mtetra
.57785 .49599 .58367 .50241 .59492 .49893 .58913 .49249 Mtetra
.58913 .49249 .59492 .49893 .60621 .49545 .60045 .48898 Mtetra
.60045 .48898 .60621 .49545 .61755 .49195 .61183 .48545 Mtetra
.61183 .48545 .61755 .49195 .62894 .48843 .62325 .48191 Mtetra
.62325 .48191 .62894 .48843 .64038 .48491 .63471 .47835 Mtetra
.964 .65 .372 r
.63471 .47835 .64038 .48491 .65685 .6113 .65101 .60497 Mtetra
.653 .754 .924 r
.65101 .60497 .65685 .6113 .66884 .60788 .66304 .60152 Mtetra
.66304 .60152 .66884 .60788 .68089 .60444 .67512 .59806 Mtetra
.67512 .59806 .68089 .60444 .69298 .60099 .68725 .59458 Mtetra
.68725 .59458 .69298 .60099 .70513 .59753 .69943 .59109 Mtetra
.69943 .59109 .70513 .59753 .71733 .59405 .71167 .58758 Mtetra
.71167 .58758 .71733 .59405 .72958 .59055 .72396 .58406 Mtetra
.72396 .58406 .72958 .59055 .74188 .58704 .7363 .58052 Mtetra
.7363 .58052 .74188 .58704 .75424 .58352 .7487 .57697 Mtetra
.7487 .57697 .75424 .58352 .76665 .57998 .76115 .5734 Mtetra
.76115 .5734 .76665 .57998 .77912 .57642 .77365 .56982 Mtetra
.77365 .56982 .77912 .57642 .79164 .57285 .78621 .56622 Mtetra
.612 .146 0 r
.78621 .56622 .79164 .57285 .8061 .59223 .80068 .58562 Mtetra
.651 .756 .927 r
.80068 .58562 .8061 .59223 .81882 .58866 .81344 .58201 Mtetra
.81344 .58201 .81882 .58866 .8316 .58506 .82626 .57839 Mtetra
.82626 .57839 .8316 .58506 .84443 .58146 .83913 .57475 Mtetra
.83913 .57475 .84443 .58146 .85732 .57783 .85206 .5711 Mtetra
.85206 .5711 .85732 .57783 .87026 .57419 .86505 .56743 Mtetra
.86505 .56743 .87026 .57419 .88327 .57054 .87809 .56374 Mtetra
.87809 .56374 .88327 .57054 .89633 .56686 .89119 .56004 Mtetra
.89119 .56004 .89633 .56686 .90945 .56318 .90436 .55632 Mtetra
.90436 .55632 .90945 .56318 .92263 .55947 .91758 .55259 Mtetra
.91758 .55259 .92263 .55947 .93586 .55575 .93086 .54883 Mtetra
.93086 .54883 .93586 .55575 .94916 .55201 .9442 .54506 Mtetra
.9442 .54506 .94916 .55201 .96252 .54825 .9576 .54127 Mtetra
.664 .741 .908 r
.35506 .5571 .36148 .56307 .37189 .55984 .3655 .55385 Mtetra
.3655 .55385 .37189 .55984 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .5435 .41834 .53739 Mtetra
.41834 .53739 .4246 .5435 .43526 .5402 .42903 .53406 Mtetra
.42903 .53406 .43526 .5402 .44597 .53688 .43976 .53071 Mtetra
.43976 .53071 .44597 .53688 .45672 .53354 .45054 .52735 Mtetra
.45054 .52735 .45672 .53354 .46751 .5302 .46136 .52398 Mtetra
.46136 .52398 .46751 .5302 .47835 .52684 .47222 .5206 Mtetra
.47222 .5206 .47835 .52684 .48923 .52346 .48313 .5172 Mtetra
.48313 .5172 .48923 .52346 .50015 .52008 .49408 .51379 Mtetra
.49408 .51379 .50015 .52008 .51112 .51668 .50508 .51036 Mtetra
.50508 .51036 .51112 .51668 .52213 .51326 .51612 .50692 Mtetra
.51612 .50692 .52213 .51326 .53318 .50983 .5272 .50347 Mtetra
.5272 .50347 .53318 .50983 .54428 .50639 .53833 .5 Mtetra
.53833 .5 .54428 .50639 .55543 .50294 .5495 .49652 Mtetra
.5495 .49652 .55543 .50294 .56661 .49947 .56072 .49303 Mtetra
.56072 .49303 .56661 .49947 .57785 .49599 .57199 .48952 Mtetra
.57199 .48952 .57785 .49599 .58913 .49249 .5833 .48599 Mtetra
.5833 .48599 .58913 .49249 .60045 .48898 .59465 .48245 Mtetra
.59465 .48245 .60045 .48898 .61183 .48545 .60606 .4789 Mtetra
.60606 .4789 .61183 .48545 .62325 .48191 .61751 .47533 Mtetra
.61751 .47533 .62325 .48191 .63471 .47835 .629 .47175 Mtetra
.964 .65 .372 r
.629 .47175 .63471 .47835 .65101 .60497 .64513 .5986 Mtetra
.653 .754 .924 r
.64513 .5986 .65101 .60497 .66304 .60152 .6572 .59512 Mtetra
.6572 .59512 .66304 .60152 .67512 .59806 .66931 .59163 Mtetra
.66931 .59163 .67512 .59806 .68725 .59458 .68148 .58812 Mtetra
.68148 .58812 .68725 .59458 .69943 .59109 .6937 .5846 Mtetra
.6937 .5846 .69943 .59109 .71167 .58758 .70597 .58107 Mtetra
.70597 .58107 .71167 .58758 .72396 .58406 .71829 .57752 Mtetra
.71829 .57752 .72396 .58406 .7363 .58052 .73067 .57395 Mtetra
.73067 .57395 .7363 .58052 .7487 .57697 .7431 .57037 Mtetra
.7431 .57037 .7487 .57697 .76115 .5734 .75559 .56677 Mtetra
.75559 .56677 .76115 .5734 .77365 .56982 .76813 .56316 Mtetra
.76813 .56316 .77365 .56982 .78621 .56622 .78073 .55953 Mtetra
.612 .146 0 r
.78073 .55953 .78621 .56622 .80068 .58562 .79522 .57895 Mtetra
.651 .756 .927 r
.79522 .57895 .80068 .58562 .81344 .58201 .80802 .57531 Mtetra
.80802 .57531 .81344 .58201 .82626 .57839 .82087 .57166 Mtetra
.82087 .57166 .82626 .57839 .83913 .57475 .83378 .568 Mtetra
.83378 .568 .83913 .57475 .85206 .5711 .84676 .56431 Mtetra
.84676 .56431 .85206 .5711 .86505 .56743 .85978 .56061 Mtetra
.85978 .56061 .86505 .56743 .87809 .56374 .87287 .55689 Mtetra
.87287 .55689 .87809 .56374 .89119 .56004 .88602 .55316 Mtetra
.88602 .55316 .89119 .56004 .90436 .55632 .89922 .54941 Mtetra
.89922 .54941 .90436 .55632 .91758 .55259 .91249 .54564 Mtetra
.91249 .54564 .91758 .55259 .93086 .54883 .92581 .54186 Mtetra
.92581 .54186 .93086 .54883 .9442 .54506 .9392 .53806 Mtetra
.9392 .53806 .9442 .54506 .9576 .54127 .95265 .53424 Mtetra
.664 .741 .908 r
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53457 Mtetra
.40135 .53457 .40769 .54071 .41834 .53739 .41203 .53123 Mtetra
.41203 .53123 .41834 .53739 .42903 .53406 .42275 .52787 Mtetra
.42275 .52787 .42903 .53406 .43976 .53071 .43351 .5245 Mtetra
.43351 .5245 .43976 .53071 .45054 .52735 .44432 .52112 Mtetra
.44432 .52112 .45054 .52735 .46136 .52398 .45516 .51772 Mtetra
.45516 .51772 .46136 .52398 .47222 .5206 .46605 .51431 Mtetra
.46605 .51431 .47222 .5206 .48313 .5172 .47699 .51089 Mtetra
.47699 .51089 .48313 .5172 .49408 .51379 .48797 .50745 Mtetra
.48797 .50745 .49408 .51379 .50508 .51036 .49899 .504 Mtetra
.49899 .504 .50508 .51036 .51612 .50692 .51006 .50054 Mtetra
.51006 .50054 .51612 .50692 .5272 .50347 .52117 .49706 Mtetra
.52117 .49706 .5272 .50347 .53833 .5 .53233 .49357 Mtetra
.53233 .49357 .53833 .5 .5495 .49652 .54353 .49006 Mtetra
.54353 .49006 .5495 .49652 .56072 .49303 .55478 .48654 Mtetra
.55478 .48654 .56072 .49303 .57199 .48952 .56608 .483 Mtetra
.56608 .483 .57199 .48952 .5833 .48599 .57742 .47945 Mtetra
.57742 .47945 .5833 .48599 .59465 .48245 .58881 .47588 Mtetra
.58881 .47588 .59465 .48245 .60606 .4789 .60024 .4723 Mtetra
.60024 .4723 .60606 .4789 .61751 .47533 .61172 .46871 Mtetra
.61172 .46871 .61751 .47533 .629 .47175 .62325 .4651 Mtetra
.964 .65 .372 r
.62325 .4651 .629 .47175 .64513 .5986 .6392 .59217 Mtetra
.653 .754 .924 r
.6392 .59217 .64513 .5986 .6572 .59512 .6513 .58867 Mtetra
.6513 .58867 .6572 .59512 .66931 .59163 .66345 .58515 Mtetra
.66345 .58515 .66931 .59163 .68148 .58812 .67565 .58161 Mtetra
.67565 .58161 .68148 .58812 .6937 .5846 .68791 .57807 Mtetra
.68791 .57807 .6937 .5846 .70597 .58107 .70022 .5745 Mtetra
.70022 .5745 .70597 .58107 .71829 .57752 .71258 .57092 Mtetra
.71258 .57092 .71829 .57752 .73067 .57395 .725 .56733 Mtetra
.725 .56733 .73067 .57395 .7431 .57037 .73747 .56372 Mtetra
.73747 .56372 .7431 .57037 .75559 .56677 .74999 .56009 Mtetra
.74999 .56009 .75559 .56677 .76813 .56316 .76257 .55645 Mtetra
.76257 .55645 .76813 .56316 .78073 .55953 .77521 .55279 Mtetra
.612 .146 0 r
.77521 .55279 .78073 .55953 .79522 .57895 .7897 .57223 Mtetra
.651 .756 .927 r
.7897 .57223 .79522 .57895 .80802 .57531 .80254 .56856 Mtetra
.80254 .56856 .80802 .57531 .82087 .57166 .81544 .56488 Mtetra
.81544 .56488 .82087 .57166 .83378 .568 .8284 .56118 Mtetra
.8284 .56118 .83378 .568 .84676 .56431 .84141 .55747 Mtetra
.84141 .55747 .84676 .56431 .85978 .56061 .85448 .55374 Mtetra
.85448 .55374 .85978 .56061 .87287 .55689 .86761 .54999 Mtetra
.86761 .54999 .87287 .55689 .88602 .55316 .8808 .54622 Mtetra
.8808 .54622 .88602 .55316 .89922 .54941 .89405 .54244 Mtetra
.89405 .54244 .89922 .54941 .91249 .54564 .90736 .53864 Mtetra
.90736 .53864 .91249 .54564 .92581 .54186 .92073 .53483 Mtetra
.92073 .53483 .92581 .54186 .9392 .53806 .93416 .53099 Mtetra
.93416 .53099 .9392 .53806 .95265 .53424 .94765 .52714 Mtetra
.664 .741 .908 r
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53508 Mtetra
.3737 .53508 .38013 .54122 .39072 .5379 .38431 .53174 Mtetra
.38431 .53174 .39072 .5379 .40135 .53457 .39497 .52839 Mtetra
.39497 .52839 .40135 .53457 .41203 .53123 .40568 .52502 Mtetra
.40568 .52502 .41203 .53123 .42275 .52787 .41642 .52164 Mtetra
.41642 .52164 .42275 .52787 .43351 .5245 .42721 .51825 Mtetra
.42721 .51825 .43351 .5245 .44432 .52112 .43804 .51484 Mtetra
.43804 .51484 .44432 .52112 .45516 .51772 .44892 .51142 Mtetra
.44892 .51142 .45516 .51772 .46605 .51431 .45984 .50798 Mtetra
.45984 .50798 .46605 .51431 .47699 .51089 .4708 .50453 Mtetra
.4708 .50453 .47699 .51089 .48797 .50745 .48181 .50107 Mtetra
.48181 .50107 .48797 .50745 .49899 .504 .49286 .49759 Mtetra
.49286 .49759 .49899 .504 .51006 .50054 .50396 .4941 Mtetra
.50396 .4941 .51006 .50054 .52117 .49706 .5151 .4906 Mtetra
.5151 .4906 .52117 .49706 .53233 .49357 .52629 .48708 Mtetra
.52629 .48708 .53233 .49357 .54353 .49006 .53752 .48355 Mtetra
.53752 .48355 .54353 .49006 .55478 .48654 .5488 .48 Mtetra
.5488 .48 .55478 .48654 .56608 .483 .56013 .47643 Mtetra
.56013 .47643 .56608 .483 .57742 .47945 .5715 .47286 Mtetra
.5715 .47286 .57742 .47945 .58881 .47588 .58292 .46926 Mtetra
.58292 .46926 .58881 .47588 .60024 .4723 .59438 .46566 Mtetra
.59438 .46566 .60024 .4723 .61172 .46871 .6059 .46203 Mtetra
.6059 .46203 .61172 .46871 .62325 .4651 .61746 .4584 Mtetra
.964 .65 .372 r
.61746 .4584 .62325 .4651 .6392 .59217 .63323 .58569 Mtetra
.653 .754 .924 r
.63323 .58569 .6392 .59217 .6513 .58867 .64536 .58216 Mtetra
.64536 .58216 .6513 .58867 .66345 .58515 .65755 .57861 Mtetra
.65755 .57861 .66345 .58515 .67565 .58161 .66979 .57505 Mtetra
.66979 .57505 .67565 .58161 .68791 .57807 .68208 .57147 Mtetra
.68208 .57147 .68791 .57807 .70022 .5745 .69442 .56788 Mtetra
.69442 .56788 .70022 .5745 .71258 .57092 .70682 .56427 Mtetra
.70682 .56427 .71258 .57092 .725 .56733 .71928 .56065 Mtetra
.71928 .56065 .725 .56733 .73747 .56372 .73179 .55701 Mtetra
.73179 .55701 .73747 .56372 .74999 .56009 .74435 .55335 Mtetra
.74435 .55335 .74999 .56009 .76257 .55645 .75697 .54968 Mtetra
.75697 .54968 .76257 .55645 .77521 .55279 .76964 .54599 Mtetra
.612 .146 0 r
.76964 .54599 .77521 .55279 .7897 .57223 .78415 .56545 Mtetra
.651 .756 .927 r
.78415 .56545 .7897 .57223 .80254 .56856 .79703 .56175 Mtetra
.79703 .56175 .80254 .56856 .81544 .56488 .80997 .55804 Mtetra
.80997 .55804 .81544 .56488 .8284 .56118 .82296 .55431 Mtetra
.82296 .55431 .8284 .56118 .84141 .55747 .83602 .55057 Mtetra
.83602 .55057 .84141 .55747 .85448 .55374 .84913 .5468 Mtetra
.84913 .5468 .85448 .55374 .86761 .54999 .8623 .54302 Mtetra
.8623 .54302 .86761 .54999 .8808 .54622 .87553 .53923 Mtetra
.87553 .53923 .8808 .54622 .89405 .54244 .88883 .53541 Mtetra
.88883 .53541 .89405 .54244 .90736 .53864 .90218 .53158 Mtetra
.90218 .53158 .90736 .53864 .92073 .53483 .91559 .52774 Mtetra
.91559 .52774 .92073 .53483 .93416 .53099 .92907 .52387 Mtetra
.92907 .52387 .93416 .53099 .94765 .52714 .94261 .51999 Mtetra
.664 .741 .908 r
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53508 .36722 .52891 Mtetra
.36722 .52891 .3737 .53508 .38431 .53174 .37786 .52554 Mtetra
.37786 .52554 .38431 .53174 .39497 .52839 .38855 .52216 Mtetra
.38855 .52216 .39497 .52839 .40568 .52502 .39928 .51877 Mtetra
.39928 .51877 .40568 .52502 .41642 .52164 .41005 .51537 Mtetra
.41005 .51537 .41642 .52164 .42721 .51825 .42087 .51195 Mtetra
.42087 .51195 .42721 .51825 .43804 .51484 .43173 .50851 Mtetra
.43173 .50851 .43804 .51484 .44892 .51142 .44263 .50507 Mtetra
.44263 .50507 .44892 .51142 .45984 .50798 .45358 .50161 Mtetra
.45358 .50161 .45984 .50798 .4708 .50453 .46457 .49813 Mtetra
.46457 .49813 .4708 .50453 .48181 .50107 .4756 .49464 Mtetra
.4756 .49464 .48181 .50107 .49286 .49759 .48668 .49114 Mtetra
.48668 .49114 .49286 .49759 .50396 .4941 .49781 .48762 Mtetra
.49781 .48762 .50396 .4941 .5151 .4906 .50898 .48409 Mtetra
.50898 .48409 .5151 .4906 .52629 .48708 .5202 .48054 Mtetra
.5202 .48054 .52629 .48708 .53752 .48355 .53146 .47698 Mtetra
.53146 .47698 .53752 .48355 .5488 .48 .54277 .47341 Mtetra
.54277 .47341 .5488 .48 .56013 .47643 .55413 .46982 Mtetra
.55413 .46982 .56013 .47643 .5715 .47286 .56553 .46621 Mtetra
.56553 .46621 .5715 .47286 .58292 .46926 .57698 .46259 Mtetra
.57698 .46259 .58292 .46926 .59438 .46566 .58848 .45896 Mtetra
.58848 .45896 .59438 .46566 .6059 .46203 .60002 .45531 Mtetra
.60002 .45531 .6059 .46203 .61746 .4584 .61162 .45164 Mtetra
.964 .65 .372 r
.61162 .45164 .61746 .4584 .63323 .58569 .62721 .57916 Mtetra
.653 .754 .924 r
.62721 .57916 .63323 .58569 .64536 .58216 .63937 .5756 Mtetra
.63937 .5756 .64536 .58216 .65755 .57861 .6516 .57202 Mtetra
.6516 .57202 .65755 .57861 .66979 .57505 .66387 .56843 Mtetra
.66387 .56843 .66979 .57505 .68208 .57147 .6762 .56483 Mtetra
.6762 .56483 .68208 .57147 .69442 .56788 .68858 .56121 Mtetra
.68858 .56121 .69442 .56788 .70682 .56427 .70102 .55757 Mtetra
.70102 .55757 .70682 .56427 .71928 .56065 .71351 .55392 Mtetra
.71351 .55392 .71928 .56065 .73179 .55701 .72606 .55025 Mtetra
.72606 .55025 .73179 .55701 .74435 .55335 .73866 .54656 Mtetra
.73866 .54656 .74435 .55335 .75697 .54968 .75132 .54286 Mtetra
.75132 .54286 .75697 .54968 .76964 .54599 .76403 .53914 Mtetra
.612 .146 0 r
.76403 .53914 .76964 .54599 .78415 .56545 .77855 .55861 Mtetra
.651 .756 .927 r
.77855 .55861 .78415 .56545 .79703 .56175 .79147 .55489 Mtetra
.79147 .55489 .79703 .56175 .80997 .55804 .80445 .55114 Mtetra
.80445 .55114 .80997 .55804 .82296 .55431 .81748 .54738 Mtetra
.81748 .54738 .82296 .55431 .83602 .55057 .83058 .54361 Mtetra
.83058 .54361 .83602 .55057 .84913 .5468 .84374 .53981 Mtetra
.84374 .53981 .84913 .5468 .8623 .54302 .85695 .536 Mtetra
.85695 .536 .8623 .54302 .87553 .53923 .87023 .53217 Mtetra
.87023 .53217 .87553 .53923 .88883 .53541 .88356 .52833 Mtetra
.88356 .52833 .88883 .53541 .90218 .53158 .89696 .52447 Mtetra
.89696 .52447 .90218 .53158 .91559 .52774 .91042 .52058 Mtetra
.91042 .52058 .91559 .52774 .92907 .52387 .92394 .51669 Mtetra
.92394 .51669 .92907 .52387 .94261 .51999 .93752 .51277 Mtetra
.664 .741 .908 r
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52268 Mtetra
.36069 .52268 .36722 .52891 .37786 .52554 .37136 .51929 Mtetra
.37136 .51929 .37786 .52554 .38855 .52216 .38207 .51589 Mtetra
.38207 .51589 .38855 .52216 .39928 .51877 .39283 .51247 Mtetra
.39283 .51247 .39928 .51877 .41005 .51537 .40363 .50904 Mtetra
.40363 .50904 .41005 .51537 .42087 .51195 .41447 .5056 Mtetra
.41447 .5056 .42087 .51195 .43173 .50851 .42536 .50214 Mtetra
.42536 .50214 .43173 .50851 .44263 .50507 .43629 .49867 Mtetra
.43629 .49867 .44263 .50507 .45358 .50161 .44727 .49518 Mtetra
.44727 .49518 .45358 .50161 .46457 .49813 .45829 .49168 Mtetra
.45829 .49168 .46457 .49813 .4756 .49464 .46935 .48816 Mtetra
.46935 .48816 .4756 .49464 .48668 .49114 .48046 .48463 Mtetra
.48046 .48463 .48668 .49114 .49781 .48762 .49162 .48109 Mtetra
.49162 .48109 .49781 .48762 .50898 .48409 .50282 .47753 Mtetra
.50282 .47753 .50898 .48409 .5202 .48054 .51406 .47396 Mtetra
.51406 .47396 .5202 .48054 .53146 .47698 .52536 .47037 Mtetra
.52536 .47037 .53146 .47698 .54277 .47341 .5367 .46677 Mtetra
.5367 .46677 .54277 .47341 .55413 .46982 .54809 .46315 Mtetra
.54809 .46315 .55413 .46982 .56553 .46621 .55952 .45952 Mtetra
.55952 .45952 .56553 .46621 .57698 .46259 .571 .45587 Mtetra
.571 .45587 .57698 .46259 .58848 .45896 .58253 .45221 Mtetra
.58253 .45221 .58848 .45896 .60002 .45531 .59411 .44853 Mtetra
.59411 .44853 .60002 .45531 .61162 .45164 .60573 .44484 Mtetra
.964 .65 .372 r
.60573 .44484 .61162 .45164 .62721 .57916 .62113 .57258 Mtetra
.653 .754 .924 r
.62113 .57258 .62721 .57916 .63937 .5756 .63334 .56899 Mtetra
.63334 .56899 .63937 .5756 .6516 .57202 .6456 .56538 Mtetra
.6456 .56538 .6516 .57202 .66387 .56843 .65791 .56177 Mtetra
.65791 .56177 .66387 .56843 .6762 .56483 .67027 .55813 Mtetra
.67027 .55813 .6762 .56483 .68858 .56121 .68269 .55448 Mtetra
.68269 .55448 .68858 .56121 .70102 .55757 .69517 .55081 Mtetra
.69517 .55081 .70102 .55757 .71351 .55392 .7077 .54713 Mtetra
.7077 .54713 .71351 .55392 .72606 .55025 .72028 .54343 Mtetra
.72028 .54343 .72606 .55025 .73866 .54656 .73292 .53971 Mtetra
.73292 .53971 .73866 .54656 .75132 .54286 .74562 .53598 Mtetra
.74562 .53598 .75132 .54286 .76403 .53914 .75838 .53223 Mtetra
.612 .146 0 r
.75838 .53223 .76403 .53914 .77855 .55861 .7729 .55172 Mtetra
.651 .756 .927 r
.7729 .55172 .77855 .55861 .79147 .55489 .78586 .54796 Mtetra
.78586 .54796 .79147 .55489 .80445 .55114 .79888 .54419 Mtetra
.79888 .54419 .80445 .55114 .81748 .54738 .81196 .5404 Mtetra
.81196 .5404 .81748 .54738 .83058 .54361 .8251 .53659 Mtetra
.8251 .53659 .83058 .54361 .84374 .53981 .8383 .53276 Mtetra
.8383 .53276 .84374 .53981 .85695 .536 .85155 .52892 Mtetra
.85155 .52892 .85695 .536 .87023 .53217 .86487 .52506 Mtetra
.86487 .52506 .87023 .53217 .88356 .52833 .87825 .52118 Mtetra
.87825 .52118 .88356 .52833 .89696 .52447 .8917 .51729 Mtetra
.8917 .51729 .89696 .52447 .91042 .52058 .9052 .51337 Mtetra
.9052 .51337 .91042 .52058 .92394 .51669 .91877 .50944 Mtetra
.91877 .50944 .92394 .51669 .93752 .51277 .93239 .50549 Mtetra
.664 .741 .908 r
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .5232 Mtetra
.33285 .5232 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52268 .35411 .51641 Mtetra
.35411 .51641 .36069 .52268 .37136 .51929 .36481 .513 Mtetra
.36481 .513 .37136 .51929 .38207 .51589 .37555 .50957 Mtetra
.37555 .50957 .38207 .51589 .39283 .51247 .38633 .50613 Mtetra
.38633 .50613 .39283 .51247 .40363 .50904 .39716 .50267 Mtetra
.39716 .50267 .40363 .50904 .41447 .5056 .40803 .4992 Mtetra
.40803 .4992 .41447 .5056 .42536 .50214 .41895 .49572 Mtetra
.41895 .49572 .42536 .50214 .43629 .49867 .42991 .49222 Mtetra
.42991 .49222 .43629 .49867 .44727 .49518 .44091 .48871 Mtetra
.44091 .48871 .44727 .49518 .45829 .49168 .45196 .48518 Mtetra
.45196 .48518 .45829 .49168 .46935 .48816 .46305 .48164 Mtetra
.46305 .48164 .46935 .48816 .48046 .48463 .47419 .47808 Mtetra
.47419 .47808 .48046 .48463 .49162 .48109 .48538 .47451 Mtetra
.48538 .47451 .49162 .48109 .50282 .47753 .49661 .47092 Mtetra
.49661 .47092 .50282 .47753 .51406 .47396 .50788 .46732 Mtetra
.50788 .46732 .51406 .47396 .52536 .47037 .51921 .46371 Mtetra
.51921 .46371 .52536 .47037 .5367 .46677 .53058 .46008 Mtetra
.53058 .46008 .5367 .46677 .54809 .46315 .542 .45643 Mtetra
.542 .45643 .54809 .46315 .55952 .45952 .55346 .45277 Mtetra
.55346 .45277 .55952 .45952 .571 .45587 .56497 .4491 Mtetra
.56497 .4491 .571 .45587 .58253 .45221 .57654 .44541 Mtetra
.57654 .44541 .58253 .45221 .59411 .44853 .58814 .4417 Mtetra
.58814 .4417 .59411 .44853 .60573 .44484 .5998 .43798 Mtetra
.956 .615 .303 r
.5998 .43798 .60573 .44484 .62113 .57258 .61352 .50979 Mtetra
.586 .411 .612 r
.61352 .50979 .62113 .57258 .63334 .56899 .62555 .50611 Mtetra
.62555 .50611 .63334 .56899 .6456 .56538 .63764 .50242 Mtetra
.63764 .50242 .6456 .56538 .65791 .56177 .64978 .49871 Mtetra
.64978 .49871 .65791 .56177 .67027 .55813 .66197 .49499 Mtetra
.66197 .49499 .67027 .55813 .68269 .55448 .67421 .49124 Mtetra
.67421 .49124 .68269 .55448 .69517 .55081 .68651 .48749 Mtetra
.68651 .48749 .69517 .55081 .7077 .54713 .69886 .48371 Mtetra
.69886 .48371 .7077 .54713 .72028 .54343 .71126 .47992 Mtetra
.71126 .47992 .72028 .54343 .73292 .53971 .72372 .47611 Mtetra
.72372 .47611 .73292 .53971 .74562 .53598 .73624 .47229 Mtetra
.73624 .47229 .74562 .53598 .75838 .53223 .74881 .46845 Mtetra
.675 .474 .605 r
.74881 .46845 .75838 .53223 .7729 .55172 .75983 .44238 Mtetra
.576 .386 .587 r
.75983 .44238 .7729 .55172 .78586 .54796 .77242 .43848 Mtetra
.77242 .43848 .78586 .54796 .79888 .54419 .78507 .43456 Mtetra
.78507 .43456 .79888 .54419 .81196 .5404 .79777 .43063 Mtetra
.79777 .43063 .81196 .5404 .8251 .53659 .81053 .42668 Mtetra
.81053 .42668 .8251 .53659 .8383 .53276 .82334 .42271 Mtetra
.82334 .42271 .8383 .53276 .85155 .52892 .83621 .41873 Mtetra
.83621 .41873 .85155 .52892 .86487 .52506 .84914 .41473 Mtetra
.84914 .41473 .86487 .52506 .87825 .52118 .86213 .41071 Mtetra
.86213 .41071 .87825 .52118 .8917 .51729 .87517 .40667 Mtetra
.87517 .40667 .8917 .51729 .9052 .51337 .88828 .40261 Mtetra
.88828 .40261 .9052 .51337 .91877 .50944 .90144 .39854 Mtetra
.90144 .39854 .91877 .50944 .93239 .50549 .91466 .39444 Mtetra
.664 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .34346 .51982 .33681 .51353 Mtetra
.33681 .51353 .34346 .51982 .35411 .51641 .34749 .5101 Mtetra
.34749 .5101 .35411 .51641 .36481 .513 .35821 .50666 Mtetra
.35821 .50666 .36481 .513 .37555 .50957 .36898 .5032 Mtetra
.36898 .5032 .37555 .50957 .38633 .50613 .37979 .49974 Mtetra
.37979 .49974 .38633 .50613 .39716 .50267 .39065 .49625 Mtetra
.39065 .49625 .39716 .50267 .40803 .4992 .40154 .49276 Mtetra
.40154 .49276 .40803 .4992 .41895 .49572 .41249 .48925 Mtetra
.41249 .48925 .41895 .49572 .42991 .49222 .42347 .48572 Mtetra
.42347 .48572 .42991 .49222 .44091 .48871 .4345 .48218 Mtetra
.4345 .48218 .44091 .48871 .45196 .48518 .44558 .47863 Mtetra
.44558 .47863 .45196 .48518 .46305 .48164 .4567 .47506 Mtetra
.4567 .47506 .46305 .48164 .47419 .47808 .46787 .47148 Mtetra
.46787 .47148 .47419 .47808 .48538 .47451 .47909 .46788 Mtetra
.47909 .46788 .48538 .47451 .49661 .47092 .49035 .46427 Mtetra
.49035 .46427 .49661 .47092 .50788 .46732 .50166 .46064 Mtetra
.50166 .46064 .50788 .46732 .51921 .46371 .51301 .45699 Mtetra
.51301 .45699 .51921 .46371 .53058 .46008 .52441 .45334 Mtetra
.52441 .45334 .53058 .46008 .542 .45643 .53586 .44966 Mtetra
.53586 .44966 .542 .45643 .55346 .45277 .54736 .44598 Mtetra
.54736 .44598 .55346 .45277 .56497 .4491 .5589 .44227 Mtetra
.5589 .44227 .56497 .4491 .57654 .44541 .57049 .43855 Mtetra
.57049 .43855 .57654 .44541 .58814 .4417 .58214 .43482 Mtetra
.58214 .43482 .58814 .4417 .5998 .43798 .59383 .43107 Mtetra
.956 .615 .303 r
.59383 .43107 .5998 .43798 .61352 .50979 .60745 .50299 Mtetra
.658 .749 .917 r
.60745 .50299 .61352 .50979 .62555 .50611 .61951 .49928 Mtetra
.61951 .49928 .62555 .50611 .63764 .50242 .63164 .49556 Mtetra
.63164 .49556 .63764 .50242 .64978 .49871 .64381 .49182 Mtetra
.64381 .49182 .64978 .49871 .66197 .49499 .65604 .48806 Mtetra
.65604 .48806 .66197 .49499 .67421 .49124 .66832 .48429 Mtetra
.66832 .48429 .67421 .49124 .68651 .48749 .68065 .4805 Mtetra
.68065 .4805 .68651 .48749 .69886 .48371 .69304 .4767 Mtetra
.69304 .4767 .69886 .48371 .71126 .47992 .70548 .47288 Mtetra
.70548 .47288 .71126 .47992 .72372 .47611 .71798 .46904 Mtetra
.71798 .46904 .72372 .47611 .73624 .47229 .73053 .46518 Mtetra
.73053 .46518 .73624 .47229 .74881 .46845 .74314 .46131 Mtetra
.925 .786 .688 r
.74314 .46131 .74881 .46845 .75983 .44238 .75423 .43517 Mtetra
.66 .746 .914 r
.75423 .43517 .75983 .44238 .77242 .43848 .76686 .43124 Mtetra
.76686 .43124 .77242 .43848 .78507 .43456 .77955 .42729 Mtetra
.77955 .42729 .78507 .43456 .79777 .43063 .79229 .42333 Mtetra
.79229 .42333 .79777 .43063 .81053 .42668 .80509 .41934 Mtetra
.80509 .41934 .81053 .42668 .82334 .42271 .81794 .41534 Mtetra
.81794 .41534 .82334 .42271 .83621 .41873 .83085 .41133 Mtetra
.83085 .41133 .83621 .41873 .84914 .41473 .84382 .40729 Mtetra
.84382 .40729 .84914 .41473 .86213 .41071 .85685 .40324 Mtetra
.85685 .40324 .86213 .41071 .87517 .40667 .86994 .39917 Mtetra
.86994 .39917 .87517 .40667 .88828 .40261 .88308 .39508 Mtetra
.88308 .39508 .88828 .40261 .90144 .39854 .89629 .39097 Mtetra
.89629 .39097 .90144 .39854 .91466 .39444 .90955 .38684 Mtetra
.664 .741 .908 r
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.34082 .50374 .34749 .5101 .35821 .50666 .35157 .50027 Mtetra
.35157 .50027 .35821 .50666 .36898 .5032 .36236 .49679 Mtetra
.36236 .49679 .36898 .5032 .37979 .49974 .3732 .4933 Mtetra
.3732 .4933 .37979 .49974 .39065 .49625 .38408 .48979 Mtetra
.38408 .48979 .39065 .49625 .40154 .49276 .39501 .48626 Mtetra
.39501 .48626 .40154 .49276 .41249 .48925 .40598 .48273 Mtetra
.40598 .48273 .41249 .48925 .42347 .48572 .41699 .47918 Mtetra
.41699 .47918 .42347 .48572 .4345 .48218 .42805 .47561 Mtetra
.42805 .47561 .4345 .48218 .44558 .47863 .43916 .47203 Mtetra
.43916 .47203 .44558 .47863 .4567 .47506 .45031 .46843 Mtetra
.45031 .46843 .4567 .47506 .46787 .47148 .46151 .46482 Mtetra
.46151 .46482 .46787 .47148 .47909 .46788 .47275 .4612 Mtetra
.47275 .4612 .47909 .46788 .49035 .46427 .48404 .45756 Mtetra
.48404 .45756 .49035 .46427 .50166 .46064 .49538 .4539 Mtetra
.49538 .4539 .50166 .46064 .51301 .45699 .50676 .45023 Mtetra
.50676 .45023 .51301 .45699 .52441 .45334 .5182 .44654 Mtetra
.5182 .44654 .52441 .45334 .53586 .44966 .52968 .44284 Mtetra
.52968 .44284 .53586 .44966 .54736 .44598 .5412 .43913 Mtetra
.5412 .43913 .54736 .44598 .5589 .44227 .55278 .43539 Mtetra
.55278 .43539 .5589 .44227 .57049 .43855 .56441 .43164 Mtetra
.56441 .43164 .57049 .43855 .58214 .43482 .57608 .42788 Mtetra
.57608 .42788 .58214 .43482 .59383 .43107 .5878 .4241 Mtetra
.956 .615 .303 r
.5878 .4241 .59383 .43107 .60745 .50299 .60132 .49613 Mtetra
.658 .749 .917 r
.60132 .49613 .60745 .50299 .61951 .49928 .61343 .4924 Mtetra
.61343 .4924 .61951 .49928 .63164 .49556 .62558 .48864 Mtetra
.62558 .48864 .63164 .49556 .64381 .49182 .63779 .48487 Mtetra
.63779 .48487 .64381 .49182 .65604 .48806 .65006 .48109 Mtetra
.65006 .48109 .65604 .48806 .66832 .48429 .66237 .47729 Mtetra
.66237 .47729 .66832 .48429 .68065 .4805 .67474 .47347 Mtetra
.67474 .47347 .68065 .4805 .69304 .4767 .68717 .46963 Mtetra
.68717 .46963 .69304 .4767 .70548 .47288 .69965 .46578 Mtetra
.69965 .46578 .70548 .47288 .71798 .46904 .71218 .46191 Mtetra
.71218 .46191 .71798 .46904 .73053 .46518 .72477 .45802 Mtetra
.72477 .45802 .73053 .46518 .74314 .46131 .73742 .45412 Mtetra
.925 .786 .688 r
.73742 .45412 .74314 .46131 .75423 .43517 .74859 .4279 Mtetra
.66 .746 .914 r
.74859 .4279 .75423 .43517 .76686 .43124 .76126 .42394 Mtetra
.76126 .42394 .76686 .43124 .77955 .42729 .77398 .41996 Mtetra
.77398 .41996 .77955 .42729 .79229 .42333 .78676 .41596 Mtetra
.78676 .41596 .79229 .42333 .80509 .41934 .7996 .41195 Mtetra
.7996 .41195 .80509 .41934 .81794 .41534 .8125 .40791 Mtetra
.8125 .40791 .81794 .41534 .83085 .41133 .82545 .40386 Mtetra
.82545 .40386 .83085 .41133 .84382 .40729 .83846 .39979 Mtetra
.83846 .39979 .84382 .40729 .85685 .40324 .85153 .39571 Mtetra
.85153 .39571 .85685 .40324 .86994 .39917 .86466 .3916 Mtetra
.86466 .3916 .86994 .39917 .88308 .39508 .87785 .38748 Mtetra
.87785 .38748 .88308 .39508 .89629 .39097 .8911 .38333 Mtetra
.8911 .38333 .89629 .39097 .90955 .38684 .90441 .37917 Mtetra
.664 .741 .908 r
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .5008 Mtetra
.32336 .5008 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49383 Mtetra
.34487 .49383 .35157 .50027 .36236 .49679 .35569 .49033 Mtetra
.35569 .49033 .36236 .49679 .3732 .4933 .36656 .48681 Mtetra
.36656 .48681 .3732 .4933 .38408 .48979 .37746 .48327 Mtetra
.37746 .48327 .38408 .48979 .39501 .48626 .38842 .47972 Mtetra
.38842 .47972 .39501 .48626 .40598 .48273 .39942 .47616 Mtetra
.39942 .47616 .40598 .48273 .41699 .47918 .41046 .47258 Mtetra
.41046 .47258 .41699 .47918 .42805 .47561 .42155 .46899 Mtetra
.42155 .46899 .42805 .47561 .43916 .47203 .43268 .46538 Mtetra
.43268 .46538 .43916 .47203 .45031 .46843 .44386 .46176 Mtetra
.44386 .46176 .45031 .46843 .46151 .46482 .45509 .45812 Mtetra
.45509 .45812 .46151 .46482 .47275 .4612 .46637 .45446 Mtetra
.46637 .45446 .47275 .4612 .48404 .45756 .47769 .4508 Mtetra
.47769 .4508 .48404 .45756 .49538 .4539 .48905 .44711 Mtetra
.48905 .44711 .49538 .4539 .50676 .45023 .50047 .44341 Mtetra
.50047 .44341 .50676 .45023 .5182 .44654 .51193 .4397 Mtetra
.51193 .4397 .5182 .44654 .52968 .44284 .52344 .43597 Mtetra
.52344 .43597 .52968 .44284 .5412 .43913 .535 .43222 Mtetra
.535 .43222 .5412 .43913 .55278 .43539 .54661 .42846 Mtetra
.54661 .42846 .55278 .43539 .56441 .43164 .55827 .42468 Mtetra
.55827 .42468 .56441 .43164 .57608 .42788 .56998 .42089 Mtetra
.56998 .42089 .57608 .42788 .5878 .4241 .58173 .41708 Mtetra
.956 .615 .303 r
.58173 .41708 .5878 .4241 .60132 .49613 .59515 .48922 Mtetra
.658 .749 .917 r
.59515 .48922 .60132 .49613 .61343 .4924 .60729 .48546 Mtetra
.60729 .48546 .61343 .4924 .62558 .48864 .61948 .48167 Mtetra
.61948 .48167 .62558 .48864 .63779 .48487 .63173 .47787 Mtetra
.63173 .47787 .63779 .48487 .65006 .48109 .64403 .47405 Mtetra
.64403 .47405 .65006 .48109 .66237 .47729 .65638 .47022 Mtetra
.65638 .47022 .66237 .47729 .67474 .47347 .66879 .46637 Mtetra
.66879 .46637 .67474 .47347 .68717 .46963 .68125 .4625 Mtetra
.68125 .4625 .68717 .46963 .69965 .46578 .69377 .45862 Mtetra
.69377 .45862 .69965 .46578 .71218 .46191 .70634 .45472 Mtetra
.70634 .45472 .71218 .46191 .72477 .45802 .71897 .4508 Mtetra
.71897 .4508 .72477 .45802 .73742 .45412 .73166 .44686 Mtetra
.925 .786 .688 r
.73166 .44686 .73742 .45412 .74859 .4279 .7429 .42057 Mtetra
.66 .746 .914 r
.7429 .42057 .74859 .4279 .76126 .42394 .75561 .41658 Mtetra
.75561 .41658 .76126 .42394 .77398 .41996 .76837 .41256 Mtetra
.76837 .41256 .77398 .41996 .78676 .41596 .78119 .40853 Mtetra
.78119 .40853 .78676 .41596 .7996 .41195 .79407 .40449 Mtetra
.79407 .40449 .7996 .41195 .8125 .40791 .80701 .40042 Mtetra
.80701 .40042 .8125 .40791 .82545 .40386 .82 .39634 Mtetra
.82 .39634 .82545 .40386 .83846 .39979 .83306 .39223 Mtetra
.83306 .39223 .83846 .39979 .85153 .39571 .84617 .38811 Mtetra
.84617 .38811 .85153 .39571 .86466 .3916 .85934 .38397 Mtetra
.85934 .38397 .86466 .3916 .87785 .38748 .87257 .37981 Mtetra
.87257 .37981 .87785 .38748 .8911 .38333 .88586 .37564 Mtetra
.88586 .37564 .8911 .38333 .90441 .37917 .89922 .37144 Mtetra
.664 .741 .908 r
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49786 Mtetra
.30585 .49786 .31267 .50427 .32336 .5008 .31656 .49437 Mtetra
.31656 .49437 .32336 .5008 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49383 .33812 .48735 Mtetra
.33812 .48735 .34487 .49383 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36656 .48681 .35986 .48027 Mtetra
.35986 .48027 .36656 .48681 .37746 .48327 .3708 .47671 Mtetra
.3708 .47671 .37746 .48327 .38842 .47972 .38178 .47313 Mtetra
.38178 .47313 .38842 .47972 .39942 .47616 .39281 .46954 Mtetra
.39281 .46954 .39942 .47616 .41046 .47258 .40388 .46593 Mtetra
.40388 .46593 .41046 .47258 .42155 .46899 .415 .46231 Mtetra
.415 .46231 .42155 .46899 .43268 .46538 .42616 .45868 Mtetra
.42616 .45868 .43268 .46538 .44386 .46176 .43737 .45503 Mtetra
.43737 .45503 .44386 .46176 .45509 .45812 .44863 .45136 Mtetra
.44863 .45136 .45509 .45812 .46637 .45446 .45993 .44768 Mtetra
.45993 .44768 .46637 .45446 .47769 .4508 .47128 .44398 Mtetra
.47128 .44398 .47769 .4508 .48905 .44711 .48268 .44027 Mtetra
.48268 .44027 .48905 .44711 .50047 .44341 .49413 .43654 Mtetra
.49413 .43654 .50047 .44341 .51193 .4397 .50562 .4328 Mtetra
.50562 .4328 .51193 .4397 .52344 .43597 .51716 .42904 Mtetra
.51716 .42904 .52344 .43597 .535 .43222 .52876 .42526 Mtetra
.52876 .42526 .535 .43222 .54661 .42846 .5404 .42147 Mtetra
.5404 .42147 .54661 .42846 .55827 .42468 .55209 .41767 Mtetra
.55209 .41767 .55827 .42468 .56998 .42089 .56383 .41384 Mtetra
.56383 .41384 .56998 .42089 .58173 .41708 .57562 .41 Mtetra
.956 .615 .303 r
.57562 .41 .58173 .41708 .59515 .48922 .58893 .48225 Mtetra
.658 .749 .917 r
.58893 .48225 .59515 .48922 .60729 .48546 .6011 .47846 Mtetra
.6011 .47846 .60729 .48546 .61948 .48167 .61333 .47464 Mtetra
.61333 .47464 .61948 .48167 .63173 .47787 .62561 .47081 Mtetra
.62561 .47081 .63173 .47787 .64403 .47405 .63795 .46696 Mtetra
.63795 .46696 .64403 .47405 .65638 .47022 .65034 .4631 Mtetra
.65034 .4631 .65638 .47022 .66879 .46637 .66279 .45922 Mtetra
.66279 .45922 .66879 .46637 .68125 .4625 .67529 .45532 Mtetra
.67529 .45532 .68125 .4625 .69377 .45862 .68784 .4514 Mtetra
.68784 .4514 .69377 .45862 .70634 .45472 .70045 .44747 Mtetra
.70045 .44747 .70634 .45472 .71897 .4508 .71312 .44352 Mtetra
.71312 .44352 .71897 .4508 .73166 .44686 .72585 .43955 Mtetra
.925 .786 .688 r
.72585 .43955 .73166 .44686 .7429 .42057 .73716 .41318 Mtetra
.66 .746 .914 r
.73716 .41318 .7429 .42057 .75561 .41658 .74991 .40916 Mtetra
.74991 .40916 .75561 .41658 .76837 .41256 .76271 .40511 Mtetra
.76271 .40511 .76837 .41256 .78119 .40853 .77557 .40105 Mtetra
.77557 .40105 .78119 .40853 .79407 .40449 .78849 .39697 Mtetra
.78849 .39697 .79407 .40449 .80701 .40042 .80147 .39287 Mtetra
.80147 .39287 .80701 .40042 .82 .39634 .81451 .38875 Mtetra
.81451 .38875 .82 .39634 .83306 .39223 .8276 .38461 Mtetra
.8276 .38461 .83306 .39223 .84617 .38811 .84076 .38045 Mtetra
.84076 .38045 .84617 .38811 .85934 .38397 .85397 .37628 Mtetra
.85397 .37628 .85934 .38397 .87257 .37981 .86725 .37209 Mtetra
.86725 .37209 .87257 .37981 .88586 .37564 .88058 .36787 Mtetra
.88058 .36787 .88586 .37564 .89922 .37144 .89398 .36364 Mtetra
.664 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .3708 .47671 .36408 .47009 Mtetra
.36408 .47009 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.37509 .46649 .38178 .47313 .39281 .46954 .38615 .46287 Mtetra
.38615 .46287 .39281 .46954 .40388 .46593 .39725 .45924 Mtetra
.39725 .45924 .40388 .46593 .415 .46231 .4084 .45559 Mtetra
.4084 .45559 .415 .46231 .42616 .45868 .41959 .45193 Mtetra
.41959 .45193 .42616 .45868 .43737 .45503 .43083 .44825 Mtetra
.43083 .44825 .43737 .45503 .44863 .45136 .44211 .44455 Mtetra
.44211 .44455 .44863 .45136 .45993 .44768 .45345 .44084 Mtetra
.45345 .44084 .45993 .44768 .47128 .44398 .46483 .43712 Mtetra
.46483 .43712 .47128 .44398 .48268 .44027 .47626 .43338 Mtetra
.47626 .43338 .48268 .44027 .49413 .43654 .48774 .42962 Mtetra
.48774 .42962 .49413 .43654 .50562 .4328 .49926 .42585 Mtetra
.49926 .42585 .50562 .4328 .51716 .42904 .51084 .42206 Mtetra
.51084 .42206 .51716 .42904 .52876 .42526 .52246 .41825 Mtetra
.52246 .41825 .52876 .42526 .5404 .42147 .53413 .41443 Mtetra
.53413 .41443 .5404 .42147 .55209 .41767 .54585 .4106 Mtetra
.54585 .4106 .55209 .41767 .56383 .41384 .55763 .40674 Mtetra
.55763 .40674 .56383 .41384 .57562 .41 .56945 .40287 Mtetra
.956 .615 .303 r
.56945 .40287 .57562 .41 .58893 .48225 .58266 .47523 Mtetra
.658 .749 .917 r
.58266 .47523 .58893 .48225 .6011 .47846 .59487 .4714 Mtetra
.59487 .4714 .6011 .47846 .61333 .47464 .60713 .46756 Mtetra
.60713 .46756 .61333 .47464 .62561 .47081 .61945 .4637 Mtetra
.61945 .4637 .62561 .47081 .63795 .46696 .63182 .45982 Mtetra
.63182 .45982 .63795 .46696 .65034 .4631 .64425 .45592 Mtetra
.64425 .45592 .65034 .4631 .66279 .45922 .65673 .45201 Mtetra
.65673 .45201 .66279 .45922 .67529 .45532 .66927 .44808 Mtetra
.66927 .44808 .67529 .45532 .68784 .4514 .68187 .44413 Mtetra
.68187 .44413 .68784 .4514 .70045 .44747 .69452 .44016 Mtetra
.69452 .44016 .70045 .44747 .71312 .44352 .70722 .43618 Mtetra
.70722 .43618 .71312 .44352 .72585 .43955 .71999 .43217 Mtetra
.925 .786 .688 r
.71999 .43217 .72585 .43955 .73716 .41318 .73138 .40573 Mtetra
.66 .746 .914 r
.73138 .40573 .73716 .41318 .74991 .40916 .74416 .40167 Mtetra
.74416 .40167 .74991 .40916 .76271 .40511 .75701 .39759 Mtetra
.75701 .39759 .76271 .40511 .77557 .40105 .76991 .3935 Mtetra
.76991 .3935 .77557 .40105 .78849 .39697 .78287 .38938 Mtetra
.78287 .38938 .78849 .39697 .80147 .39287 .79589 .38525 Mtetra
.79589 .38525 .80147 .39287 .81451 .38875 .80897 .38109 Mtetra
.80897 .38109 .81451 .38875 .8276 .38461 .82211 .37692 Mtetra
.82211 .37692 .8276 .38461 .84076 .38045 .8353 .37273 Mtetra
.8353 .37273 .84076 .38045 .85397 .37628 .84856 .36852 Mtetra
.84856 .36852 .85397 .37628 .86725 .37209 .86188 .36429 Mtetra
.86188 .36429 .86725 .37209 .88058 .36787 .87526 .36004 Mtetra
.87526 .36004 .88058 .36787 .89398 .36364 .8887 .35578 Mtetra
.664 .741 .908 r
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.34633 .46705 .35312 .47368 .36408 .47009 .35732 .46343 Mtetra
.35732 .46343 .36408 .47009 .37509 .46649 .36835 .4598 Mtetra
.36835 .4598 .37509 .46649 .38615 .46287 .37944 .45615 Mtetra
.37944 .45615 .38615 .46287 .39725 .45924 .39057 .45249 Mtetra
.39057 .45249 .39725 .45924 .4084 .45559 .40174 .44881 Mtetra
.40174 .44881 .4084 .45559 .41959 .45193 .41296 .44512 Mtetra
.41296 .44512 .41959 .45193 .43083 .44825 .42423 .44141 Mtetra
.42423 .44141 .43083 .44825 .44211 .44455 .43555 .43769 Mtetra
.43555 .43769 .44211 .44455 .45345 .44084 .44691 .43395 Mtetra
.44691 .43395 .45345 .44084 .46483 .43712 .45833 .4302 Mtetra
.45833 .4302 .46483 .43712 .47626 .43338 .46979 .42643 Mtetra
.46979 .42643 .47626 .43338 .48774 .42962 .48129 .42264 Mtetra
.48129 .42264 .48774 .42962 .49926 .42585 .49285 .41884 Mtetra
.49285 .41884 .49926 .42585 .51084 .42206 .50446 .41502 Mtetra
.50446 .41502 .51084 .42206 .52246 .41825 .51611 .41119 Mtetra
.51611 .41119 .52246 .41825 .53413 .41443 .52782 .40734 Mtetra
.52782 .40734 .53413 .41443 .54585 .4106 .53957 .40347 Mtetra
.53957 .40347 .54585 .4106 .55763 .40674 .55138 .39958 Mtetra
.55138 .39958 .55763 .40674 .56945 .40287 .56323 .39568 Mtetra
.956 .615 .303 r
.56323 .39568 .56945 .40287 .58266 .47523 .57634 .46815 Mtetra
.658 .749 .917 r
.57634 .46815 .58266 .47523 .59487 .4714 .58858 .46429 Mtetra
.58858 .46429 .59487 .4714 .60713 .46756 .60088 .46041 Mtetra
.60088 .46041 .60713 .46756 .61945 .4637 .61324 .45652 Mtetra
.61324 .45652 .61945 .4637 .63182 .45982 .62565 .45261 Mtetra
.62565 .45261 .63182 .45982 .64425 .45592 .63811 .44868 Mtetra
.63811 .44868 .64425 .45592 .65673 .45201 .65063 .44473 Mtetra
.65063 .44473 .65673 .45201 .66927 .44808 .66321 .44077 Mtetra
.66321 .44077 .66927 .44808 .68187 .44413 .67584 .43679 Mtetra
.67584 .43679 .68187 .44413 .69452 .44016 .68853 .43279 Mtetra
.68853 .43279 .69452 .44016 .70722 .43618 .70128 .42877 Mtetra
.70128 .42877 .70722 .43618 .71999 .43217 .71408 .42474 Mtetra
.925 .786 .688 r
.71408 .42474 .71999 .43217 .73138 .40573 .72554 .39822 Mtetra
.66 .746 .914 r
.72554 .39822 .73138 .40573 .74416 .40167 .73837 .39413 Mtetra
.73837 .39413 .74416 .40167 .75701 .39759 .75126 .39002 Mtetra
.75126 .39002 .75701 .39759 .76991 .3935 .7642 .38588 Mtetra
.7642 .38588 .76991 .3935 .78287 .38938 .7772 .38173 Mtetra
.7772 .38173 .78287 .38938 .79589 .38525 .79026 .37757 Mtetra
.79026 .37757 .79589 .38525 .80897 .38109 .80338 .37338 Mtetra
.80338 .37338 .80897 .38109 .82211 .37692 .81656 .36917 Mtetra
.81656 .36917 .82211 .37692 .8353 .37273 .8298 .36494 Mtetra
.8298 .36494 .8353 .37273 .84856 .36852 .84311 .3607 Mtetra
.84311 .3607 .84856 .36852 .86188 .36429 .85647 .35643 Mtetra
.85647 .35643 .86188 .36429 .87526 .36004 .86989 .35215 Mtetra
.86989 .35215 .87526 .36004 .8887 .35578 .88338 .34784 Mtetra
.664 .741 .908 r
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.3285 .46399 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45671 Mtetra
.3505 .45671 .35732 .46343 .36835 .4598 .36156 .45306 Mtetra
.36156 .45306 .36835 .4598 .37944 .45615 .37268 .44938 Mtetra
.37268 .44938 .37944 .45615 .39057 .45249 .38383 .44569 Mtetra
.38383 .44569 .39057 .45249 .40174 .44881 .39504 .44199 Mtetra
.39504 .44199 .40174 .44881 .41296 .44512 .40629 .43827 Mtetra
.40629 .43827 .41296 .44512 .42423 .44141 .41759 .43453 Mtetra
.41759 .43453 .42423 .44141 .43555 .43769 .42893 .43078 Mtetra
.42893 .43078 .43555 .43769 .44691 .43395 .44033 .42701 Mtetra
.44033 .42701 .44691 .43395 .45833 .4302 .45177 .42323 Mtetra
.45177 .42323 .45833 .4302 .46979 .42643 .46326 .41943 Mtetra
.46326 .41943 .46979 .42643 .48129 .42264 .4748 .41561 Mtetra
.4748 .41561 .48129 .42264 .49285 .41884 .48639 .41178 Mtetra
.48639 .41178 .49285 .41884 .50446 .41502 .49803 .40793 Mtetra
.49803 .40793 .50446 .41502 .51611 .41119 .50972 .40406 Mtetra
.50972 .40406 .51611 .41119 .52782 .40734 .52145 .40018 Mtetra
.52145 .40018 .52782 .40734 .53957 .40347 .53324 .39628 Mtetra
.53324 .39628 .53957 .40347 .55138 .39958 .54508 .39237 Mtetra
.54508 .39237 .55138 .39958 .56323 .39568 .55697 .38844 Mtetra
.956 .615 .303 r
.55697 .38844 .56323 .39568 .57634 .46815 .56996 .46101 Mtetra
.658 .749 .917 r
.56996 .46101 .57634 .46815 .58858 .46429 .58224 .45712 Mtetra
.58224 .45712 .58858 .46429 .60088 .46041 .59458 .45321 Mtetra
.59458 .45321 .60088 .46041 .61324 .45652 .60697 .44929 Mtetra
.60697 .44929 .61324 .45652 .62565 .45261 .61942 .44534 Mtetra
.61942 .44534 .62565 .45261 .63811 .44868 .63192 .44138 Mtetra
.63192 .44138 .63811 .44868 .65063 .44473 .64448 .4374 Mtetra
.64448 .4374 .65063 .44473 .66321 .44077 .65709 .43341 Mtetra
.65709 .43341 .66321 .44077 .67584 .43679 .66976 .42939 Mtetra
.66976 .42939 .67584 .43679 .68853 .43279 .68249 .42536 Mtetra
.68249 .42536 .68853 .43279 .70128 .42877 .69528 .42131 Mtetra
.69528 .42131 .70128 .42877 .71408 .42474 .70812 .41724 Mtetra
.925 .786 .688 r
.70812 .41724 .71408 .42474 .72554 .39822 .71966 .39065 Mtetra
.66 .746 .914 r
.71966 .39065 .72554 .39822 .73837 .39413 .73253 .38652 Mtetra
.73253 .38652 .73837 .39413 .75126 .39002 .74546 .38237 Mtetra
.74546 .38237 .75126 .39002 .7642 .38588 .75844 .37821 Mtetra
.75844 .37821 .7642 .38588 .7772 .38173 .77148 .37402 Mtetra
.77148 .37402 .7772 .38173 .79026 .37757 .78459 .36982 Mtetra
.78459 .36982 .79026 .37757 .80338 .37338 .79775 .3656 Mtetra
.79775 .3656 .80338 .37338 .81656 .36917 .81097 .36135 Mtetra
.81097 .36135 .81656 .36917 .8298 .36494 .82426 .35709 Mtetra
.82426 .35709 .8298 .36494 .84311 .3607 .8376 .35281 Mtetra
.8376 .35281 .84311 .3607 .85647 .35643 .85101 .34851 Mtetra
.85101 .34851 .85647 .35643 .86989 .35215 .86448 .34419 Mtetra
.86448 .34419 .86989 .35215 .88338 .34784 .87801 .33985 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.33258 .45362 .33948 .46036 .3505 .45671 .34363 .44995 Mtetra
.34363 .44995 .3505 .45671 .36156 .45306 .35472 .44626 Mtetra
.35472 .44626 .36156 .45306 .37268 .44938 .36586 .44256 Mtetra
.36586 .44256 .37268 .44938 .38383 .44569 .37705 .43884 Mtetra
.37705 .43884 .38383 .44569 .39504 .44199 .38828 .4351 Mtetra
.38828 .4351 .39504 .44199 .40629 .43827 .39956 .43136 Mtetra
.39956 .43136 .40629 .43827 .41759 .43453 .41089 .42759 Mtetra
.41089 .42759 .41759 .43453 .42893 .43078 .42227 .42381 Mtetra
.42227 .42381 .42893 .43078 .44033 .42701 .43369 .42001 Mtetra
.43369 .42001 .44033 .42701 .45177 .42323 .44517 .4162 Mtetra
.44517 .4162 .45177 .42323 .46326 .41943 .45669 .41237 Mtetra
.45669 .41237 .46326 .41943 .4748 .41561 .46826 .40852 Mtetra
.46826 .40852 .4748 .41561 .48639 .41178 .47988 .40466 Mtetra
.47988 .40466 .48639 .41178 .49803 .40793 .49155 .40078 Mtetra
.49155 .40078 .49803 .40793 .50972 .40406 .50327 .39689 Mtetra
.50327 .39689 .50972 .40406 .52145 .40018 .51504 .39297 Mtetra
.51504 .39297 .52145 .40018 .53324 .39628 .52686 .38904 Mtetra
.52686 .38904 .53324 .39628 .54508 .39237 .53873 .3851 Mtetra
.53873 .3851 .54508 .39237 .55697 .38844 .55066 .38114 Mtetra
.956 .615 .303 r
.55066 .38114 .55697 .38844 .56996 .46101 .56354 .45381 Mtetra
.658 .749 .917 r
.56354 .45381 .56996 .46101 .58224 .45712 .57585 .44989 Mtetra
.57585 .44989 .58224 .45712 .59458 .45321 .58823 .44595 Mtetra
.58823 .44595 .59458 .45321 .60697 .44929 .60066 .44199 Mtetra
.60066 .44199 .60697 .44929 .61942 .44534 .61314 .43802 Mtetra
.61314 .43802 .61942 .44534 .63192 .44138 .62568 .43402 Mtetra
.62568 .43402 .63192 .44138 .64448 .4374 .63828 .43001 Mtetra
.63828 .43001 .64448 .4374 .65709 .43341 .65093 .42598 Mtetra
.65093 .42598 .65709 .43341 .66976 .42939 .66364 .42193 Mtetra
.66364 .42193 .66976 .42939 .68249 .42536 .67641 .41787 Mtetra
.67641 .41787 .68249 .42536 .69528 .42131 .68923 .41378 Mtetra
.68923 .41378 .69528 .42131 .70812 .41724 .70212 .40968 Mtetra
.925 .786 .688 r
.70212 .40968 .70812 .41724 .71966 .39065 .71373 .38301 Mtetra
.66 .746 .914 r
.71373 .38301 .71966 .39065 .73253 .38652 .72664 .37885 Mtetra
.72664 .37885 .73253 .38652 .74546 .38237 .73961 .37467 Mtetra
.73961 .37467 .74546 .38237 .75844 .37821 .75263 .37047 Mtetra
.75263 .37047 .75844 .37821 .77148 .37402 .76572 .36625 Mtetra
.76572 .36625 .77148 .37402 .78459 .36982 .77886 .36201 Mtetra
.77886 .36201 .78459 .36982 .79775 .3656 .79207 .35775 Mtetra
.79207 .35775 .79775 .3656 .81097 .36135 .80533 .35347 Mtetra
.80533 .35347 .81097 .36135 .82426 .35709 .81866 .34917 Mtetra
.81866 .34917 .82426 .35709 .8376 .35281 .83205 .34485 Mtetra
.83205 .34485 .8376 .35281 .85101 .34851 .8455 .34051 Mtetra
.8455 .34051 .85101 .34851 .86448 .34419 .85902 .33616 Mtetra
.85902 .33616 .86448 .34419 .87801 .33985 .87259 .33178 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
.3146 .45051 .32158 .45728 .33258 .45362 .32563 .44683 Mtetra
.32563 .44683 .33258 .45362 .34363 .44995 .3367 .44313 Mtetra
.3367 .44313 .34363 .44995 .35472 .44626 .34783 .43941 Mtetra
.34783 .43941 .35472 .44626 .36586 .44256 .35899 .43568 Mtetra
.35899 .43568 .36586 .44256 .37705 .43884 .37021 .43193 Mtetra
.37021 .43193 .37705 .43884 .38828 .4351 .38147 .42817 Mtetra
.38147 .42817 .38828 .4351 .39956 .43136 .39278 .42439 Mtetra
.39278 .42439 .39956 .43136 .41089 .42759 .40414 .4206 Mtetra
.40414 .4206 .41089 .42759 .42227 .42381 .41555 .41679 Mtetra
.41555 .41679 .42227 .42381 .43369 .42001 .427 .41296 Mtetra
.427 .41296 .43369 .42001 .44517 .4162 .43851 .40912 Mtetra
.43851 .40912 .44517 .4162 .45669 .41237 .45006 .40526 Mtetra
.45006 .40526 .45669 .41237 .46826 .40852 .46166 .40138 Mtetra
.46166 .40138 .46826 .40852 .47988 .40466 .47332 .39749 Mtetra
.47332 .39749 .47988 .40466 .49155 .40078 .48502 .39358 Mtetra
.48502 .39358 .49155 .40078 .50327 .39689 .49677 .38965 Mtetra
.49677 .38965 .50327 .39689 .51504 .39297 .50857 .38571 Mtetra
.50857 .38571 .51504 .39297 .52686 .38904 .52043 .38175 Mtetra
.52043 .38175 .52686 .38904 .53873 .3851 .53233 .37777 Mtetra
.53233 .37777 .53873 .3851 .55066 .38114 .54429 .37377 Mtetra
.956 .615 .303 r
.54429 .37377 .55066 .38114 .56354 .45381 .55706 .44656 Mtetra
.658 .749 .917 r
.55706 .44656 .56354 .45381 .57585 .44989 .56941 .4426 Mtetra
.56941 .4426 .57585 .44989 .58823 .44595 .58182 .43863 Mtetra
.58182 .43863 .58823 .44595 .60066 .44199 .59429 .43464 Mtetra
.59429 .43464 .60066 .44199 .61314 .43802 .60681 .43063 Mtetra
.60681 .43063 .61314 .43802 .62568 .43402 .61939 .4266 Mtetra
.61939 .4266 .62568 .43402 .63828 .43001 .63202 .42256 Mtetra
.63202 .42256 .63828 .43001 .65093 .42598 .64471 .41849 Mtetra
.64471 .41849 .65093 .42598 .66364 .42193 .65746 .41441 Mtetra
.65746 .41441 .66364 .42193 .67641 .41787 .67027 .41031 Mtetra
.67027 .41031 .67641 .41787 .68923 .41378 .68313 .40619 Mtetra
.68313 .40619 .68923 .41378 .70212 .40968 .69606 .40205 Mtetra
.925 .786 .688 r
.69606 .40205 .70212 .40968 .71373 .38301 .70775 .37531 Mtetra
.66 .746 .914 r
.70775 .37531 .71373 .38301 .72664 .37885 .7207 .37112 Mtetra
.7207 .37112 .72664 .37885 .73961 .37467 .73371 .3669 Mtetra
.73371 .3669 .73961 .37467 .75263 .37047 .74678 .36266 Mtetra
.74678 .36266 .75263 .37047 .76572 .36625 .7599 .35841 Mtetra
.7599 .35841 .76572 .36625 .77886 .36201 .77309 .35413 Mtetra
.77309 .35413 .77886 .36201 .79207 .35775 .78634 .34983 Mtetra
.78634 .34983 .79207 .35775 .80533 .35347 .79965 .34552 Mtetra
.79965 .34552 .80533 .35347 .81866 .34917 .81302 .34118 Mtetra
.81302 .34118 .81866 .34917 .83205 .34485 .82645 .33683 Mtetra
.82645 .33683 .83205 .34485 .8455 .34051 .83995 .33245 Mtetra
.83995 .33245 .8455 .34051 .85902 .33616 .85351 .32806 Mtetra
.85351 .32806 .85902 .33616 .87259 .33178 .86713 .32364 Mtetra
.664 .741 .908 r
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.28559 .45108 .29268 .45784 .30361 .45418 .29655 .4474 Mtetra
.29655 .4474 .30361 .45418 .3146 .45051 .30756 .4437 Mtetra
.30756 .4437 .3146 .45051 .32563 .44683 .31862 .43998 Mtetra
.31862 .43998 .32563 .44683 .3367 .44313 .32973 .43626 Mtetra
.32973 .43626 .3367 .44313 .34783 .43941 .34088 .43251 Mtetra
.34088 .43251 .34783 .43941 .35899 .43568 .35207 .42875 Mtetra
.35207 .42875 .35899 .43568 .37021 .43193 .36332 .42497 Mtetra
.36332 .42497 .37021 .43193 .38147 .42817 .37461 .42118 Mtetra
.37461 .42118 .38147 .42817 .39278 .42439 .38595 .41737 Mtetra
.38595 .41737 .39278 .42439 .40414 .4206 .39734 .41355 Mtetra
.39734 .41355 .40414 .4206 .41555 .41679 .40878 .40971 Mtetra
.40878 .40971 .41555 .41679 .427 .41296 .42026 .40585 Mtetra
.42026 .40585 .427 .41296 .43851 .40912 .4318 .40198 Mtetra
.4318 .40198 .43851 .40912 .45006 .40526 .44338 .39809 Mtetra
.44338 .39809 .45006 .40526 .46166 .40138 .45502 .39418 Mtetra
.45502 .39418 .46166 .40138 .47332 .39749 .4667 .39025 Mtetra
.4667 .39025 .47332 .39749 .48502 .39358 .47843 .38631 Mtetra
.47843 .38631 .48502 .39358 .49677 .38965 .49022 .38236 Mtetra
.49022 .38236 .49677 .38965 .50857 .38571 .50206 .37838 Mtetra
.50206 .37838 .50857 .38571 .52043 .38175 .51394 .37439 Mtetra
.51394 .37439 .52043 .38175 .53233 .37777 .52588 .37038 Mtetra
.52588 .37038 .53233 .37777 .54429 .37377 .53788 .36635 Mtetra
.956 .615 .303 r
.53788 .36635 .54429 .37377 .55706 .44656 .55052 .43924 Mtetra
.658 .749 .917 r
.55052 .43924 .55706 .44656 .56941 .4426 .56291 .43525 Mtetra
.56291 .43525 .56941 .4426 .58182 .43863 .57536 .43125 Mtetra
.57536 .43125 .58182 .43863 .59429 .43464 .58786 .42722 Mtetra
.58786 .42722 .59429 .43464 .60681 .43063 .60042 .42318 Mtetra
.60042 .42318 .60681 .43063 .61939 .4266 .61304 .41912 Mtetra
.61304 .41912 .61939 .4266 .63202 .42256 .62571 .41504 Mtetra
.62571 .41504 .63202 .42256 .64471 .41849 .63844 .41094 Mtetra
.63844 .41094 .64471 .41849 .65746 .41441 .65123 .40683 Mtetra
.65123 .40683 .65746 .41441 .67027 .41031 .66408 .40269 Mtetra
.66408 .40269 .67027 .41031 .68313 .40619 .67698 .39854 Mtetra
.67698 .39854 .68313 .40619 .69606 .40205 .68995 .39437 Mtetra
.925 .786 .688 r
.68995 .39437 .69606 .40205 .70775 .37531 .70172 .36755 Mtetra
.66 .746 .914 r
.70172 .36755 .70775 .37531 .7207 .37112 .71471 .36331 Mtetra
.71471 .36331 .7207 .37112 .73371 .3669 .72776 .35906 Mtetra
.72776 .35906 .73371 .3669 .74678 .36266 .74087 .35479 Mtetra
.74087 .35479 .74678 .36266 .7599 .35841 .75404 .3505 Mtetra
.75404 .3505 .7599 .35841 .77309 .35413 .76727 .34618 Mtetra
.76727 .34618 .77309 .35413 .78634 .34983 .78056 .34185 Mtetra
.78056 .34185 .78634 .34983 .79965 .34552 .79391 .3375 Mtetra
.79391 .3375 .79965 .34552 .81302 .34118 .80733 .33313 Mtetra
.80733 .33313 .81302 .34118 .82645 .33683 .82081 .32873 Mtetra
.82081 .32873 .82645 .33683 .83995 .33245 .83435 .32432 Mtetra
.83435 .32432 .83995 .33245 .85351 .32806 .84795 .31989 Mtetra
.84795 .31989 .85351 .32806 .86713 .32364 .86162 .31543 Mtetra
.664 .741 .908 r
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .4437 .30048 .43683 Mtetra
.30048 .43683 .30756 .4437 .31862 .43998 .31156 .43309 Mtetra
.31156 .43309 .31862 .43998 .32973 .43626 .32269 .42933 Mtetra
.32269 .42933 .32973 .43626 .34088 .43251 .33387 .42556 Mtetra
.33387 .42556 .34088 .43251 .35207 .42875 .3451 .42177 Mtetra
.3451 .42177 .35207 .42875 .36332 .42497 .35637 .41796 Mtetra
.35637 .41796 .36332 .42497 .37461 .42118 .3677 .41414 Mtetra
.3677 .41414 .37461 .42118 .38595 .41737 .37907 .4103 Mtetra
.37907 .4103 .38595 .41737 .39734 .41355 .39048 .40644 Mtetra
.39048 .40644 .39734 .41355 .40878 .40971 .40195 .40257 Mtetra
.40195 .40257 .40878 .40971 .42026 .40585 .41347 .39869 Mtetra
.41347 .39869 .42026 .40585 .4318 .40198 .42503 .39478 Mtetra
.42503 .39478 .4318 .40198 .44338 .39809 .43665 .39086 Mtetra
.43665 .39086 .44338 .39809 .45502 .39418 .44832 .38692 Mtetra
.44832 .38692 .45502 .39418 .4667 .39025 .46003 .38297 Mtetra
.46003 .38297 .4667 .39025 .47843 .38631 .4718 .37899 Mtetra
.4718 .37899 .47843 .38631 .49022 .38236 .48362 .375 Mtetra
.48362 .375 .49022 .38236 .50206 .37838 .49549 .371 Mtetra
.49549 .371 .50206 .37838 .51394 .37439 .50741 .36697 Mtetra
.50741 .36697 .51394 .37439 .52588 .37038 .51938 .36293 Mtetra
.51938 .36293 .52588 .37038 .53788 .36635 .53141 .35887 Mtetra
.956 .615 .303 r
.53141 .35887 .53788 .36635 .55052 .43924 .54394 .43187 Mtetra
.658 .749 .917 r
.54394 .43187 .55052 .43924 .56291 .43525 .55636 .42784 Mtetra
.55636 .42784 .56291 .43525 .57536 .43125 .56885 .4238 Mtetra
.56885 .4238 .57536 .43125 .58786 .42722 .58139 .41975 Mtetra
.58139 .41975 .58786 .42722 .60042 .42318 .59399 .41567 Mtetra
.59399 .41567 .60042 .42318 .61304 .41912 .60664 .41158 Mtetra
.60664 .41158 .61304 .41912 .62571 .41504 .61935 .40746 Mtetra
.61935 .40746 .62571 .41504 .63844 .41094 .63212 .40333 Mtetra
.63212 .40333 .63844 .41094 .65123 .40683 .64495 .39918 Mtetra
.64495 .39918 .65123 .40683 .66408 .40269 .65784 .39501 Mtetra
.65784 .39501 .66408 .40269 .67698 .39854 .67078 .39082 Mtetra
.67078 .39082 .67698 .39854 .68995 .39437 .68379 .38661 Mtetra
.925 .786 .688 r
.68379 .38661 .68995 .39437 .70172 .36755 .69564 .35972 Mtetra
.66 .746 .914 r
.69564 .35972 .70172 .36755 .71471 .36331 .70867 .35545 Mtetra
.70867 .35545 .71471 .36331 .72776 .35906 .72176 .35116 Mtetra
.72176 .35116 .72776 .35906 .74087 .35479 .73491 .34685 Mtetra
.73491 .34685 .74087 .35479 .75404 .3505 .74812 .34252 Mtetra
.74812 .34252 .75404 .3505 .76727 .34618 .7614 .33817 Mtetra
.7614 .33817 .76727 .34618 .78056 .34185 .77473 .3338 Mtetra
.77473 .3338 .78056 .34185 .79391 .3375 .78813 .32941 Mtetra
.78813 .32941 .79391 .3375 .80733 .33313 .80159 .325 Mtetra
.80159 .325 .80733 .33313 .82081 .32873 .81511 .32057 Mtetra
.81511 .32057 .82081 .32873 .83435 .32432 .8287 .31612 Mtetra
.8287 .31612 .83435 .32432 .84795 .31989 .84235 .31165 Mtetra
.84235 .31165 .84795 .31989 .86162 .31543 .85606 .30715 Mtetra
.664 .741 .908 r
.23846 .44853 .24574 .45531 .25659 .45164 .24934 .44484 Mtetra
.24934 .44484 .25659 .45164 .2675 .44796 .26027 .44113 Mtetra
.26027 .44113 .2675 .44796 .27844 .44427 .27124 .4374 Mtetra
.27124 .4374 .27844 .44427 .28944 .44056 .28226 .43366 Mtetra
.28226 .43366 .28944 .44056 .30048 .43683 .29333 .42991 Mtetra
.29333 .42991 .30048 .43683 .31156 .43309 .30445 .42614 Mtetra
.30445 .42614 .31156 .43309 .32269 .42933 .31561 .42235 Mtetra
.31561 .42235 .32269 .42933 .33387 .42556 .32681 .41855 Mtetra
.32681 .41855 .33387 .42556 .3451 .42177 .33807 .41473 Mtetra
.33807 .41473 .3451 .42177 .35637 .41796 .34937 .41089 Mtetra
.34937 .41089 .35637 .41796 .3677 .41414 .36072 .40704 Mtetra
.36072 .40704 .3677 .41414 .37907 .4103 .37213 .40317 Mtetra
.37213 .40317 .37907 .4103 .39048 .40644 .38357 .39928 Mtetra
.38357 .39928 .39048 .40644 .40195 .40257 .39507 .39538 Mtetra
.39507 .39538 .40195 .40257 .41347 .39869 .40662 .39146 Mtetra
.40662 .39146 .41347 .39869 .42503 .39478 .41822 .38753 Mtetra
.41822 .38753 .42503 .39478 .43665 .39086 .42986 .38358 Mtetra
.42986 .38358 .43665 .39086 .44832 .38692 .44156 .37961 Mtetra
.44156 .37961 .44832 .38692 .46003 .38297 .45331 .37562 Mtetra
.45331 .37562 .46003 .38297 .4718 .37899 .46511 .37161 Mtetra
.46511 .37161 .4718 .37899 .48362 .375 .47696 .36759 Mtetra
.47696 .36759 .48362 .375 .49549 .371 .48886 .36355 Mtetra
.48886 .36355 .49549 .371 .50741 .36697 .50082 .3595 Mtetra
.50082 .3595 .50741 .36697 .51938 .36293 .51283 .35542 Mtetra
.51283 .35542 .51938 .36293 .53141 .35887 .52489 .35133 Mtetra
.964 .646 .363 r
.52489 .35133 .53141 .35887 .54394 .43187 .53747 .47026 Mtetra
.483 .196 .401 r
.53747 .47026 .54394 .43187 .55636 .42784 .55011 .46625 Mtetra
.55011 .46625 .55636 .42784 .56885 .4238 .56281 .46223 Mtetra
.56281 .46223 .56885 .4238 .58139 .41975 .57557 .45818 Mtetra
.57557 .45818 .58139 .41975 .59399 .41567 .58839 .45412 Mtetra
.58839 .45412 .59399 .41567 .60664 .41158 .60126 .45004 Mtetra
.60126 .45004 .60664 .41158 .61935 .40746 .6142 .44594 Mtetra
.6142 .44594 .61935 .40746 .63212 .40333 .62719 .44182 Mtetra
.62719 .44182 .63212 .40333 .64495 .39918 .64025 .43768 Mtetra
.64025 .43768 .64495 .39918 .65784 .39501 .65337 .43352 Mtetra
.65337 .43352 .65784 .39501 .67078 .39082 .66655 .42934 Mtetra
.66655 .42934 .67078 .39082 .68379 .38661 .67979 .42514 Mtetra
.85 .526 .439 r
.67979 .42514 .68379 .38661 .69564 .35972 .69812 .51789 Mtetra
.531 .294 .501 r
.69812 .51789 .69564 .35972 .70867 .35545 .7119 .51376 Mtetra
.7119 .51376 .70867 .35545 .72176 .35116 .72574 .50961 Mtetra
.72574 .50961 .72176 .35116 .73491 .34685 .73966 .50544 Mtetra
.73966 .50544 .73491 .34685 .74812 .34252 .75364 .50125 Mtetra
.75364 .50125 .74812 .34252 .7614 .33817 .76769 .49704 Mtetra
.76769 .49704 .7614 .33817 .77473 .3338 .78181 .49281 Mtetra
.78181 .49281 .77473 .3338 .78813 .32941 .79599 .48856 Mtetra
.79599 .48856 .78813 .32941 .80159 .325 .81025 .48429 Mtetra
.81025 .48429 .80159 .325 .81511 .32057 .82458 .48 Mtetra
.82458 .48 .81511 .32057 .8287 .31612 .83898 .47568 Mtetra
.83898 .47568 .8287 .31612 .84235 .31165 .85345 .47135 Mtetra
.85345 .47135 .84235 .31165 .85606 .30715 .868 .46699 Mtetra
.664 .741 .908 r
.23112 .4417 .23846 .44853 .24934 .44484 .24203 .43798 Mtetra
.24203 .43798 .24934 .44484 .26027 .44113 .25299 .43424 Mtetra
.25299 .43424 .26027 .44113 .27124 .4374 .26399 .43049 Mtetra
.26399 .43049 .27124 .4374 .28226 .43366 .27504 .42672 Mtetra
.27504 .42672 .28226 .43366 .29333 .42991 .28613 .42293 Mtetra
.28613 .42293 .29333 .42991 .30445 .42614 .29727 .41913 Mtetra
.29727 .41913 .30445 .42614 .31561 .42235 .30846 .41532 Mtetra
.30846 .41532 .31561 .42235 .32681 .41855 .3197 .41148 Mtetra
.3197 .41148 .32681 .41855 .33807 .41473 .33099 .40763 Mtetra
.33099 .40763 .33807 .41473 .34937 .41089 .34232 .40377 Mtetra
.34232 .40377 .34937 .41089 .36072 .40704 .3537 .39988 Mtetra
.3537 .39988 .36072 .40704 .37213 .40317 .36513 .39598 Mtetra
.36513 .39598 .37213 .40317 .38357 .39928 .37661 .39207 Mtetra
.37661 .39207 .38357 .39928 .39507 .39538 .38814 .38814 Mtetra
.38814 .38814 .39507 .39538 .40662 .39146 .39972 .38419 Mtetra
.39972 .38419 .40662 .39146 .41822 .38753 .41135 .38022 Mtetra
.41135 .38022 .41822 .38753 .42986 .38358 .42302 .37623 Mtetra
.42302 .37623 .42986 .38358 .44156 .37961 .43475 .37223 Mtetra
.43475 .37223 .44156 .37961 .45331 .37562 .44654 .36821 Mtetra
.44654 .36821 .45331 .37562 .46511 .37161 .45837 .36418 Mtetra
.45837 .36418 .46511 .37161 .47696 .36759 .47025 .36012 Mtetra
.47025 .36012 .47696 .36759 .48886 .36355 .48219 .35605 Mtetra
.48219 .35605 .48886 .36355 .50082 .3595 .49418 .35196 Mtetra
.49418 .35196 .50082 .3595 .51283 .35542 .50622 .34785 Mtetra
.50622 .34785 .51283 .35542 .52489 .35133 .51831 .34373 Mtetra
.964 .646 .363 r
.51831 .34373 .52489 .35133 .53747 .47026 .53068 .46285 Mtetra
.654 .753 .922 r
.53068 .46285 .53747 .47026 .55011 .46625 .54336 .4588 Mtetra
.54336 .4588 .55011 .46625 .56281 .46223 .5561 .45474 Mtetra
.5561 .45474 .56281 .46223 .57557 .45818 .56889 .45067 Mtetra
.56889 .45067 .57557 .45818 .58839 .45412 .58175 .44657 Mtetra
.58175 .44657 .58839 .45412 .60126 .45004 .59466 .44245 Mtetra
.59466 .44245 .60126 .45004 .6142 .44594 .60764 .43831 Mtetra
.60764 .43831 .6142 .44594 .62719 .44182 .62068 .43416 Mtetra
.62068 .43416 .62719 .44182 .64025 .43768 .63377 .42998 Mtetra
.63377 .42998 .64025 .43768 .65337 .43352 .64693 .42579 Mtetra
.64693 .42579 .65337 .43352 .66655 .42934 .66015 .42158 Mtetra
.66015 .42158 .66655 .42934 .67979 .42514 .67344 .41734 Mtetra
.952 .602 .243 r
.67344 .41734 .67979 .42514 .69812 .51789 .69165 .51025 Mtetra
.646 .762 .934 r
.69165 .51025 .69812 .51789 .7119 .51376 .70547 .50609 Mtetra
.70547 .50609 .7119 .51376 .72574 .50961 .71936 .5019 Mtetra
.71936 .5019 .72574 .50961 .73966 .50544 .73332 .49769 Mtetra
.73332 .49769 .73966 .50544 .75364 .50125 .74735 .49347 Mtetra
.74735 .49347 .75364 .50125 .76769 .49704 .76145 .48922 Mtetra
.76145 .48922 .76769 .49704 .78181 .49281 .77562 .48495 Mtetra
.77562 .48495 .78181 .49281 .79599 .48856 .78986 .48066 Mtetra
.78986 .48066 .79599 .48856 .81025 .48429 .80417 .47635 Mtetra
.80417 .47635 .81025 .48429 .82458 .48 .81855 .47201 Mtetra
.81855 .47201 .82458 .48 .83898 .47568 .833 .46766 Mtetra
.833 .46766 .83898 .47568 .85345 .47135 .84752 .46328 Mtetra
.84752 .46328 .85345 .47135 .868 .46699 .86212 .45888 Mtetra
.664 .741 .908 r
.22373 .43482 .23112 .4417 .24203 .43798 .23467 .43107 Mtetra
.23467 .43107 .24203 .43798 .25299 .43424 .24565 .4273 Mtetra
.24565 .4273 .25299 .43424 .26399 .43049 .25668 .42352 Mtetra
.25668 .42352 .26399 .43049 .27504 .42672 .26775 .41972 Mtetra
.26775 .41972 .27504 .42672 .28613 .42293 .27888 .4159 Mtetra
.27888 .4159 .28613 .42293 .29727 .41913 .29005 .41207 Mtetra
.29005 .41207 .29727 .41913 .30846 .41532 .30127 .40823 Mtetra
.30127 .40823 .30846 .41532 .3197 .41148 .31253 .40436 Mtetra
.31253 .40436 .3197 .41148 .33099 .40763 .32384 .40048 Mtetra
.32384 .40048 .33099 .40763 .34232 .40377 .33521 .39659 Mtetra
.33521 .39659 .34232 .40377 .3537 .39988 .34662 .39267 Mtetra
.34662 .39267 .3537 .39988 .36513 .39598 .35808 .38874 Mtetra
.35808 .38874 .36513 .39598 .37661 .39207 .36959 .38479 Mtetra
.36959 .38479 .37661 .39207 .38814 .38814 .38115 .38083 Mtetra
.38115 .38083 .38814 .38814 .39972 .38419 .39276 .37685 Mtetra
.39276 .37685 .39972 .38419 .41135 .38022 .40442 .37285 Mtetra
.40442 .37285 .41135 .38022 .42302 .37623 .41613 .36883 Mtetra
.41613 .36883 .42302 .37623 .43475 .37223 .42789 .3648 Mtetra
.42789 .3648 .43475 .37223 .44654 .36821 .43971 .36075 Mtetra
.43971 .36075 .44654 .36821 .45837 .36418 .45157 .35668 Mtetra
.45157 .35668 .45837 .36418 .47025 .36012 .46349 .35259 Mtetra
.46349 .35259 .47025 .36012 .48219 .35605 .47546 .34849 Mtetra
.47546 .34849 .48219 .35605 .49418 .35196 .48748 .34436 Mtetra
.48748 .34436 .49418 .35196 .50622 .34785 .49956 .34022 Mtetra
.49956 .34022 .50622 .34785 .51831 .34373 .51169 .33606 Mtetra
.964 .646 .363 r
.51169 .33606 .51831 .34373 .53068 .46285 .52383 .45537 Mtetra
.654 .753 .922 r
.52383 .45537 .53068 .46285 .54336 .4588 .53655 .45129 Mtetra
.53655 .45129 .54336 .4588 .5561 .45474 .54932 .4472 Mtetra
.54932 .4472 .5561 .45474 .56889 .45067 .56216 .44309 Mtetra
.56216 .44309 .56889 .45067 .58175 .44657 .57505 .43895 Mtetra
.57505 .43895 .58175 .44657 .59466 .44245 .58801 .4348 Mtetra
.58801 .4348 .59466 .44245 .60764 .43831 .60103 .43063 Mtetra
.60103 .43063 .60764 .43831 .62068 .43416 .6141 .42644 Mtetra
.6141 .42644 .62068 .43416 .63377 .42998 .62724 .42223 Mtetra
.62724 .42223 .63377 .42998 .64693 .42579 .64044 .41799 Mtetra
.64044 .41799 .64693 .42579 .66015 .42158 .65371 .41374 Mtetra
.65371 .41374 .66015 .42158 .67344 .41734 .66703 .40947 Mtetra
.952 .602 .243 r
.66703 .40947 .67344 .41734 .69165 .51025 .68512 .50255 Mtetra
.646 .762 .934 r
.68512 .50255 .69165 .51025 .70547 .50609 .69899 .49834 Mtetra
.69899 .49834 .70547 .50609 .71936 .5019 .71293 .49412 Mtetra
.71293 .49412 .71936 .5019 .73332 .49769 .72693 .48987 Mtetra
.72693 .48987 .73332 .49769 .74735 .49347 .74101 .48561 Mtetra
.74101 .48561 .74735 .49347 .76145 .48922 .75516 .48132 Mtetra
.75516 .48132 .76145 .48922 .77562 .48495 .76938 .47701 Mtetra
.76938 .47701 .77562 .48495 .78986 .48066 .78366 .47268 Mtetra
.78366 .47268 .78986 .48066 .80417 .47635 .79802 .46833 Mtetra
.79802 .46833 .80417 .47635 .81855 .47201 .81245 .46396 Mtetra
.81245 .46396 .81855 .47201 .833 .46766 .82696 .45956 Mtetra
.82696 .45956 .833 .46766 .84752 .46328 .84153 .45515 Mtetra
.84153 .45515 .84752 .46328 .86212 .45888 .85618 .45071 Mtetra
.664 .741 .908 r
.21628 .42788 .22373 .43482 .23467 .43107 .22724 .4241 Mtetra
.22724 .4241 .23467 .43107 .24565 .4273 .23825 .4203 Mtetra
.23825 .4203 .24565 .4273 .25668 .42352 .24931 .41649 Mtetra
.24931 .41649 .25668 .42352 .26775 .41972 .26041 .41266 Mtetra
.26041 .41266 .26775 .41972 .27888 .4159 .27156 .40882 Mtetra
.27156 .40882 .27888 .4159 .29005 .41207 .28276 .40496 Mtetra
.28276 .40496 .29005 .41207 .30127 .40823 .29401 .40108 Mtetra
.29401 .40108 .30127 .40823 .31253 .40436 .3053 .39719 Mtetra
.3053 .39719 .31253 .40436 .32384 .40048 .31665 .39327 Mtetra
.31665 .39327 .32384 .40048 .33521 .39659 .32804 .38935 Mtetra
.32804 .38935 .33521 .39659 .34662 .39267 .33948 .3854 Mtetra
.33948 .3854 .34662 .39267 .35808 .38874 .35097 .38144 Mtetra
.35097 .38144 .35808 .38874 .36959 .38479 .36251 .37746 Mtetra
.36251 .37746 .36959 .38479 .38115 .38083 .3741 .37347 Mtetra
.3741 .37347 .38115 .38083 .39276 .37685 .38574 .36945 Mtetra
.38574 .36945 .39276 .37685 .40442 .37285 .39744 .36542 Mtetra
.39744 .36542 .40442 .37285 .41613 .36883 .40918 .36137 Mtetra
.40918 .36137 .41613 .36883 .42789 .3648 .42097 .35731 Mtetra
.42097 .35731 .42789 .3648 .43971 .36075 .43282 .35322 Mtetra
.43282 .35322 .43971 .36075 .45157 .35668 .44472 .34912 Mtetra
.44472 .34912 .45157 .35668 .46349 .35259 .45667 .345 Mtetra
.45667 .345 .46349 .35259 .47546 .34849 .46867 .34086 Mtetra
.46867 .34086 .47546 .34849 .48748 .34436 .48073 .3367 Mtetra
.48073 .3367 .48748 .34436 .49956 .34022 .49284 .33253 Mtetra
.49284 .33253 .49956 .34022 .51169 .33606 .505 .32833 Mtetra
.964 .646 .363 r
.505 .32833 .51169 .33606 .52383 .45537 .51692 .44783 Mtetra
.654 .753 .922 r
.51692 .44783 .52383 .45537 .53655 .45129 .52968 .44372 Mtetra
.52968 .44372 .53655 .45129 .54932 .4472 .54249 .43959 Mtetra
.54249 .43959 .54932 .4472 .56216 .44309 .55537 .43544 Mtetra
.55537 .43544 .56216 .44309 .57505 .43895 .5683 .43127 Mtetra
.5683 .43127 .57505 .43895 .58801 .4348 .5813 .42708 Mtetra
.5813 .42708 .58801 .4348 .60103 .43063 .59436 .42288 Mtetra
.59436 .42288 .60103 .43063 .6141 .42644 .60748 .41865 Mtetra
.60748 .41865 .6141 .42644 .62724 .42223 .62066 .4144 Mtetra
.62066 .4144 .62724 .42223 .64044 .41799 .6339 .41013 Mtetra
.6339 .41013 .64044 .41799 .65371 .41374 .64721 .40584 Mtetra
.64721 .40584 .65371 .41374 .66703 .40947 .66057 .40153 Mtetra
.952 .602 .243 r
.66057 .40153 .66703 .40947 .68512 .50255 .67853 .49477 Mtetra
.646 .762 .934 r
.67853 .49477 .68512 .50255 .69899 .49834 .69244 .49053 Mtetra
.69244 .49053 .69899 .49834 .71293 .49412 .70643 .48626 Mtetra
.70643 .48626 .71293 .49412 .72693 .48987 .72049 .48198 Mtetra
.72049 .48198 .72693 .48987 .74101 .48561 .73461 .47768 Mtetra
.73461 .47768 .74101 .48561 .75516 .48132 .74881 .47335 Mtetra
.74881 .47335 .75516 .48132 .76938 .47701 .76308 .469 Mtetra
.76308 .469 .76938 .47701 .78366 .47268 .77741 .46463 Mtetra
.77741 .46463 .78366 .47268 .79802 .46833 .79182 .46024 Mtetra
.79182 .46024 .79802 .46833 .81245 .46396 .80631 .45583 Mtetra
.80631 .45583 .81245 .46396 .82696 .45956 .82086 .45139 Mtetra
.82086 .45139 .82696 .45956 .84153 .45515 .83549 .44693 Mtetra
.83549 .44693 .84153 .45515 .85618 .45071 .85019 .44245 Mtetra
.664 .741 .908 r
.20877 .42089 .21628 .42788 .22724 .4241 .21976 .41708 Mtetra
.21976 .41708 .22724 .4241 .23825 .4203 .2308 .41325 Mtetra
.2308 .41325 .23825 .4203 .24931 .41649 .24188 .40941 Mtetra
.24188 .40941 .24931 .41649 .26041 .41266 .25302 .40555 Mtetra
.25302 .40555 .26041 .41266 .27156 .40882 .26419 .40168 Mtetra
.26419 .40168 .27156 .40882 .28276 .40496 .27542 .39779 Mtetra
.27542 .39779 .28276 .40496 .29401 .40108 .2867 .39388 Mtetra
.2867 .39388 .29401 .40108 .3053 .39719 .29802 .38995 Mtetra
.29802 .38995 .3053 .39719 .31665 .39327 .30939 .38601 Mtetra
.30939 .38601 .31665 .39327 .32804 .38935 .32082 .38205 Mtetra
.32082 .38205 .32804 .38935 .33948 .3854 .33229 .37807 Mtetra
.33229 .37807 .33948 .3854 .35097 .38144 .34381 .37408 Mtetra
.34381 .37408 .35097 .38144 .36251 .37746 .35538 .37007 Mtetra
.35538 .37007 .36251 .37746 .3741 .37347 .367 .36604 Mtetra
.367 .36604 .3741 .37347 .38574 .36945 .37867 .362 Mtetra
.37867 .362 .38574 .36945 .39744 .36542 .3904 .35793 Mtetra
.3904 .35793 .39744 .36542 .40918 .36137 .40217 .35385 Mtetra
.40217 .35385 .40918 .36137 .42097 .35731 .414 .34975 Mtetra
.414 .34975 .42097 .35731 .43282 .35322 .42588 .34563 Mtetra
.42588 .34563 .43282 .35322 .44472 .34912 .43781 .3415 Mtetra
.43781 .3415 .44472 .34912 .45667 .345 .44979 .33734 Mtetra
.44979 .33734 .45667 .345 .46867 .34086 .46183 .33317 Mtetra
.46183 .33317 .46867 .34086 .48073 .3367 .47392 .32898 Mtetra
.47392 .32898 .48073 .3367 .49284 .33253 .48607 .32477 Mtetra
.48607 .32477 .49284 .33253 .505 .32833 .49827 .32054 Mtetra
.964 .646 .363 r
.49827 .32054 .505 .32833 .51692 .44783 .50995 .44023 Mtetra
.654 .753 .922 r
.50995 .44023 .51692 .44783 .52968 .44372 .52275 .43608 Mtetra
.52275 .43608 .52968 .44372 .54249 .43959 .5356 .43191 Mtetra
.5356 .43191 .54249 .43959 .55537 .43544 .54852 .42773 Mtetra
.54852 .42773 .55537 .43544 .5683 .43127 .56149 .42352 Mtetra
.56149 .42352 .5683 .43127 .5813 .42708 .57453 .4193 Mtetra
.57453 .4193 .5813 .42708 .59436 .42288 .58763 .41505 Mtetra
.58763 .41505 .59436 .42288 .60748 .41865 .60079 .41079 Mtetra
.60079 .41079 .60748 .41865 .62066 .4144 .61401 .4065 Mtetra
.61401 .4065 .62066 .4144 .6339 .41013 .6273 .4022 Mtetra
.6273 .4022 .6339 .41013 .64721 .40584 .64064 .39787 Mtetra
.64064 .39787 .64721 .40584 .66057 .40153 .65406 .39353 Mtetra
.952 .602 .243 r
.65406 .39353 .66057 .40153 .67853 .49477 .67188 .48692 Mtetra
.646 .762 .934 r
.67188 .48692 .67853 .49477 .69244 .49053 .68584 .48264 Mtetra
.68584 .48264 .69244 .49053 .70643 .48626 .69988 .47834 Mtetra
.69988 .47834 .70643 .48626 .72049 .48198 .71398 .47402 Mtetra
.71398 .47402 .72049 .48198 .73461 .47768 .72815 .46967 Mtetra
.72815 .46967 .73461 .47768 .74881 .47335 .7424 .46531 Mtetra
.7424 .46531 .74881 .47335 .76308 .469 .75672 .46092 Mtetra
.75672 .46092 .76308 .469 .77741 .46463 .77111 .45651 Mtetra
.77111 .45651 .77741 .46463 .79182 .46024 .78557 .45207 Mtetra
.78557 .45207 .79182 .46024 .80631 .45583 .8001 .44762 Mtetra
.8001 .44762 .80631 .45583 .82086 .45139 .81471 .44314 Mtetra
.81471 .44314 .82086 .45139 .83549 .44693 .82939 .43864 Mtetra
.82939 .43864 .83549 .44693 .85019 .44245 .84415 .43412 Mtetra
.664 .741 .908 r
.2012 .41384 .20877 .42089 .21976 .41708 .21222 .41 Mtetra
.21222 .41 .21976 .41708 .2308 .41325 .22329 .40615 Mtetra
.22329 .40615 .2308 .41325 .24188 .40941 .2344 .40227 Mtetra
.2344 .40227 .24188 .40941 .25302 .40555 .24556 .39839 Mtetra
.24556 .39839 .25302 .40555 .26419 .40168 .25677 .39448 Mtetra
.25677 .39448 .26419 .40168 .27542 .39779 .26802 .39056 Mtetra
.26802 .39056 .27542 .39779 .2867 .39388 .27933 .38662 Mtetra
.27933 .38662 .2867 .39388 .29802 .38995 .29068 .38266 Mtetra
.29068 .38266 .29802 .38995 .30939 .38601 .30208 .37869 Mtetra
.30208 .37869 .30939 .38601 .32082 .38205 .31353 .3747 Mtetra
.31353 .3747 .32082 .38205 .33229 .37807 .32503 .37069 Mtetra
.32503 .37069 .33229 .37807 .34381 .37408 .33659 .36666 Mtetra
.33659 .36666 .34381 .37408 .35538 .37007 .34819 .36262 Mtetra
.34819 .36262 .35538 .37007 .367 .36604 .35984 .35856 Mtetra
.35984 .35856 .367 .36604 .37867 .362 .37155 .35448 Mtetra
.37155 .35448 .37867 .362 .3904 .35793 .3833 .35038 Mtetra
.3833 .35038 .3904 .35793 .40217 .35385 .39511 .34627 Mtetra
.39511 .34627 .40217 .35385 .414 .34975 .40697 .34213 Mtetra
.40697 .34213 .414 .34975 .42588 .34563 .41888 .33798 Mtetra
.41888 .33798 .42588 .34563 .43781 .3415 .43084 .33381 Mtetra
.43084 .33381 .43781 .3415 .44979 .33734 .44286 .32963 Mtetra
.44286 .32963 .44979 .33734 .46183 .33317 .45493 .32542 Mtetra
.45493 .32542 .46183 .33317 .47392 .32898 .46706 .32119 Mtetra
.46706 .32119 .47392 .32898 .48607 .32477 .47924 .31695 Mtetra
.47924 .31695 .48607 .32477 .49827 .32054 .49147 .31268 Mtetra
.964 .646 .363 r
.49147 .31268 .49827 .32054 .50995 .44023 .50293 .43256 Mtetra
.654 .753 .922 r
.50293 .43256 .50995 .44023 .52275 .43608 .51576 .42837 Mtetra
.51576 .42837 .52275 .43608 .5356 .43191 .52865 .42417 Mtetra
.52865 .42417 .5356 .43191 .54852 .42773 .54161 .41995 Mtetra
.54161 .41995 .54852 .42773 .56149 .42352 .55462 .41571 Mtetra
.55462 .41571 .56149 .42352 .57453 .4193 .5677 .41145 Mtetra
.5677 .41145 .57453 .4193 .58763 .41505 .58084 .40716 Mtetra
.58084 .40716 .58763 .41505 .60079 .41079 .59404 .40286 Mtetra
.59404 .40286 .60079 .41079 .61401 .4065 .60731 .39854 Mtetra
.60731 .39854 .61401 .4065 .6273 .4022 .62063 .3942 Mtetra
.62063 .3942 .6273 .4022 .64064 .39787 .63403 .38983 Mtetra
.63403 .38983 .64064 .39787 .65406 .39353 .64748 .38545 Mtetra
.952 .602 .243 r
.64748 .38545 .65406 .39353 .67188 .48692 .66517 .479 Mtetra
.646 .762 .934 r
.66517 .479 .67188 .48692 .68584 .48264 .67918 .47468 Mtetra
.67918 .47468 .68584 .48264 .69988 .47834 .69326 .47034 Mtetra
.69326 .47034 .69988 .47834 .71398 .47402 .70741 .46598 Mtetra
.70741 .46598 .71398 .47402 .72815 .46967 .72164 .46159 Mtetra
.72164 .46159 .72815 .46967 .7424 .46531 .73593 .45719 Mtetra
.73593 .45719 .7424 .46531 .75672 .46092 .7503 .45276 Mtetra
.7503 .45276 .75672 .46092 .77111 .45651 .76474 .44831 Mtetra
.76474 .44831 .77111 .45651 .78557 .45207 .77925 .44383 Mtetra
.77925 .44383 .78557 .45207 .8001 .44762 .79384 .43934 Mtetra
.79384 .43934 .8001 .44762 .81471 .44314 .8085 .43482 Mtetra
.8085 .43482 .81471 .44314 .82939 .43864 .82323 .43027 Mtetra
.82323 .43027 .82939 .43864 .84415 .43412 .83804 .42571 Mtetra
.664 .741 .908 r
.19358 .40674 .2012 .41384 .21222 .41 .20462 .40287 Mtetra
.20462 .40287 .21222 .41 .22329 .40615 .21571 .39899 Mtetra
.21571 .39899 .22329 .40615 .2344 .40227 .22685 .39508 Mtetra
.22685 .39508 .2344 .40227 .24556 .39839 .23804 .39116 Mtetra
.23804 .39116 .24556 .39839 .25677 .39448 .24928 .38723 Mtetra
.24928 .38723 .25677 .39448 .26802 .39056 .26056 .38327 Mtetra
.26056 .38327 .26802 .39056 .27933 .38662 .2719 .3793 Mtetra
.2719 .3793 .27933 .38662 .29068 .38266 .28328 .37531 Mtetra
.28328 .37531 .29068 .38266 .30208 .37869 .29471 .37131 Mtetra
.29471 .37131 .30208 .37869 .31353 .3747 .30619 .36728 Mtetra
.30619 .36728 .31353 .3747 .32503 .37069 .31772 .36324 Mtetra
.31772 .36324 .32503 .37069 .33659 .36666 .32931 .35918 Mtetra
.32931 .35918 .33659 .36666 .34819 .36262 .34094 .35511 Mtetra
.34094 .35511 .34819 .36262 .35984 .35856 .35262 .35101 Mtetra
.35262 .35101 .35984 .35856 .37155 .35448 .36436 .3469 Mtetra
.36436 .3469 .37155 .35448 .3833 .35038 .37615 .34277 Mtetra
.37615 .34277 .3833 .35038 .39511 .34627 .38799 .33862 Mtetra
.38799 .33862 .39511 .34627 .40697 .34213 .39988 .33446 Mtetra
.39988 .33446 .40697 .34213 .41888 .33798 .41182 .33027 Mtetra
.41182 .33027 .41888 .33798 .43084 .33381 .42382 .32607 Mtetra
.42382 .32607 .43084 .33381 .44286 .32963 .43587 .32184 Mtetra
.43587 .32184 .44286 .32963 .45493 .32542 .44798 .3176 Mtetra
.44798 .3176 .45493 .32542 .46706 .32119 .46014 .31334 Mtetra
.46014 .31334 .46706 .32119 .47924 .31695 .47236 .30906 Mtetra
.47236 .30906 .47924 .31695 .49147 .31268 .48463 .30476 Mtetra
.964 .646 .363 r
.48463 .30476 .49147 .31268 .50293 .43256 .49584 .42482 Mtetra
.654 .753 .922 r
.49584 .42482 .50293 .43256 .51576 .42837 .50871 .4206 Mtetra
.50871 .4206 .51576 .42837 .52865 .42417 .52164 .41636 Mtetra
.52164 .41636 .52865 .42417 .54161 .41995 .53464 .4121 Mtetra
.53464 .4121 .54161 .41995 .55462 .41571 .54769 .40782 Mtetra
.54769 .40782 .55462 .41571 .5677 .41145 .56081 .40353 Mtetra
.56081 .40353 .5677 .41145 .58084 .40716 .57399 .39921 Mtetra
.57399 .39921 .58084 .40716 .59404 .40286 .58724 .39487 Mtetra
.58724 .39487 .59404 .40286 .60731 .39854 .60054 .39051 Mtetra
.60054 .39051 .60731 .39854 .62063 .3942 .61391 .38612 Mtetra
.61391 .38612 .62063 .3942 .63403 .38983 .62735 .38172 Mtetra
.62735 .38172 .63403 .38983 .64748 .38545 .64085 .3773 Mtetra
.952 .602 .243 r
.64085 .3773 .64748 .38545 .66517 .479 .65839 .47101 Mtetra
.646 .762 .934 r
.65839 .47101 .66517 .479 .67918 .47468 .67245 .46665 Mtetra
.67245 .46665 .67918 .47468 .69326 .47034 .68658 .46227 Mtetra
.68658 .46227 .69326 .47034 .70741 .46598 .70079 .45787 Mtetra
.70079 .45787 .70741 .46598 .72164 .46159 .71506 .45344 Mtetra
.71506 .45344 .72164 .46159 .73593 .45719 .7294 .44899 Mtetra
.7294 .44899 .73593 .45719 .7503 .45276 .74382 .44452 Mtetra
.74382 .44452 .7503 .45276 .76474 .44831 .75831 .44003 Mtetra
.75831 .44003 .76474 .44831 .77925 .44383 .77288 .43551 Mtetra
.77288 .43551 .77925 .44383 .79384 .43934 .78751 .43097 Mtetra
.78751 .43097 .79384 .43934 .8085 .43482 .80223 .42641 Mtetra
.80223 .42641 .8085 .43482 .82323 .43027 .81702 .42183 Mtetra
.81702 .42183 .82323 .43027 .83804 .42571 .83188 .41722 Mtetra
.664 .741 .908 r
.18589 .39958 .19358 .40674 .20462 .40287 .19696 .39568 Mtetra
.19696 .39568 .20462 .40287 .21571 .39899 .20808 .39177 Mtetra
.20808 .39177 .21571 .39899 .22685 .39508 .21925 .38783 Mtetra
.21925 .38783 .22685 .39508 .23804 .39116 .23047 .38388 Mtetra
.23047 .38388 .23804 .39116 .24928 .38723 .24173 .37991 Mtetra
.24173 .37991 .24928 .38723 .26056 .38327 .25304 .37593 Mtetra
.25304 .37593 .26056 .38327 .2719 .3793 .26441 .37192 Mtetra
.26441 .37192 .2719 .3793 .28328 .37531 .27582 .3679 Mtetra
.27582 .3679 .28328 .37531 .29471 .37131 .28728 .36387 Mtetra
.28728 .36387 .29471 .37131 .30619 .36728 .29879 .35981 Mtetra
.29879 .35981 .30619 .36728 .31772 .36324 .31035 .35574 Mtetra
.31035 .35574 .31772 .36324 .32931 .35918 .32197 .35165 Mtetra
.32197 .35165 .32931 .35918 .34094 .35511 .33363 .34754 Mtetra
.33363 .34754 .34094 .35511 .35262 .35101 .34535 .34341 Mtetra
.34535 .34341 .35262 .35101 .36436 .3469 .35711 .33926 Mtetra
.35711 .33926 .36436 .3469 .37615 .34277 .36893 .3351 Mtetra
.36893 .3351 .37615 .34277 .38799 .33862 .38081 .33092 Mtetra
.38081 .33092 .38799 .33862 .39988 .33446 .39273 .32671 Mtetra
.39273 .32671 .39988 .33446 .41182 .33027 .40471 .32249 Mtetra
.40471 .32249 .41182 .33027 .42382 .32607 .41674 .31826 Mtetra
.41674 .31826 .42382 .32607 .43587 .32184 .42883 .314 Mtetra
.42883 .314 .43587 .32184 .44798 .3176 .44097 .30972 Mtetra
.44097 .30972 .44798 .3176 .46014 .31334 .45316 .30543 Mtetra
.45316 .30543 .46014 .31334 .47236 .30906 .46541 .30111 Mtetra
.46541 .30111 .47236 .30906 .48463 .30476 .47772 .29677 Mtetra
.964 .646 .363 r
.47772 .29677 .48463 .30476 .49584 .42482 .48869 .41702 Mtetra
.654 .753 .922 r
.48869 .41702 .49584 .42482 .50871 .4206 .5016 .41276 Mtetra
.5016 .41276 .50871 .4206 .52164 .41636 .51457 .40848 Mtetra
.51457 .40848 .52164 .41636 .53464 .4121 .52761 .40419 Mtetra
.52761 .40419 .53464 .4121 .54769 .40782 .5407 .39987 Mtetra
.5407 .39987 .54769 .40782 .56081 .40353 .55386 .39554 Mtetra
.55386 .39554 .56081 .40353 .57399 .39921 .56709 .39118 Mtetra
.56709 .39118 .57399 .39921 .58724 .39487 .58037 .3868 Mtetra
.58037 .3868 .58724 .39487 .60054 .39051 .59372 .3824 Mtetra
.59372 .3824 .60054 .39051 .61391 .38612 .60713 .37798 Mtetra
.60713 .37798 .61391 .38612 .62735 .38172 .62061 .37354 Mtetra
.62061 .37354 .62735 .38172 .64085 .3773 .63416 .36907 Mtetra
.952 .602 .243 r
.63416 .36907 .64085 .3773 .65839 .47101 .65156 .46295 Mtetra
.646 .762 .934 r
.65156 .46295 .65839 .47101 .67245 .46665 .66567 .45855 Mtetra
.66567 .45855 .67245 .46665 .68658 .46227 .67985 .45412 Mtetra
.67985 .45412 .68658 .46227 .70079 .45787 .6941 .44968 Mtetra
.6941 .44968 .70079 .45787 .71506 .45344 .70842 .44521 Mtetra
.70842 .44521 .71506 .45344 .7294 .44899 .72281 .44072 Mtetra
.72281 .44072 .7294 .44899 .74382 .44452 .73728 .43621 Mtetra
.73728 .43621 .74382 .44452 .75831 .44003 .75183 .43167 Mtetra
.75183 .43167 .75831 .44003 .77288 .43551 .76644 .42712 Mtetra
.76644 .42712 .77288 .43551 .78751 .43097 .78113 .42253 Mtetra
.78113 .42253 .78751 .43097 .80223 .42641 .7959 .41793 Mtetra
.7959 .41793 .80223 .42641 .81702 .42183 .81074 .4133 Mtetra
.81074 .4133 .81702 .42183 .83188 .41722 .82566 .40865 Mtetra
.664 .741 .908 r
.17814 .39237 .18589 .39958 .19696 .39568 .18924 .38844 Mtetra
.18924 .38844 .19696 .39568 .20808 .39177 .20039 .38449 Mtetra
.20039 .38449 .20808 .39177 .21925 .38783 .21158 .38052 Mtetra
.21158 .38052 .21925 .38783 .23047 .38388 .22283 .37654 Mtetra
.22283 .37654 .23047 .38388 .24173 .37991 .23412 .37254 Mtetra
.23412 .37254 .24173 .37991 .25304 .37593 .24546 .36852 Mtetra
.24546 .36852 .25304 .37593 .26441 .37192 .25686 .36449 Mtetra
.25686 .36449 .26441 .37192 .27582 .3679 .2683 .36043 Mtetra
.2683 .36043 .27582 .3679 .28728 .36387 .27979 .35636 Mtetra
.27979 .35636 .28728 .36387 .29879 .35981 .29133 .35228 Mtetra
.29133 .35228 .29879 .35981 .31035 .35574 .30292 .34817 Mtetra
.30292 .34817 .31035 .35574 .32197 .35165 .31457 .34404 Mtetra
.31457 .34404 .32197 .35165 .33363 .34754 .32626 .3399 Mtetra
.32626 .3399 .33363 .34754 .34535 .34341 .33801 .33574 Mtetra
.33801 .33574 .34535 .34341 .35711 .33926 .34981 .33156 Mtetra
.34981 .33156 .35711 .33926 .36893 .3351 .36166 .32736 Mtetra
.36166 .32736 .36893 .3351 .38081 .33092 .37357 .32315 Mtetra
.37357 .32315 .38081 .33092 .39273 .32671 .38553 .31891 Mtetra
.38553 .31891 .39273 .32671 .40471 .32249 .39754 .31465 Mtetra
.39754 .31465 .40471 .32249 .41674 .31826 .4096 .31038 Mtetra
.4096 .31038 .41674 .31826 .42883 .314 .42172 .30609 Mtetra
.42172 .30609 .42883 .314 .44097 .30972 .4339 .30177 Mtetra
.4339 .30177 .44097 .30972 .45316 .30543 .44613 .29744 Mtetra
.44613 .29744 .45316 .30543 .46541 .30111 .45841 .29309 Mtetra
.45841 .29309 .46541 .30111 .47772 .29677 .47075 .28872 Mtetra
.964 .646 .363 r
.47075 .28872 .47772 .29677 .48869 .41702 .48148 .40914 Mtetra
.654 .753 .922 r
.48148 .40914 .48869 .41702 .5016 .41276 .49443 .40485 Mtetra
.49443 .40485 .5016 .41276 .51457 .40848 .50744 .40054 Mtetra
.50744 .40054 .51457 .40848 .52761 .40419 .52051 .3962 Mtetra
.52051 .3962 .52761 .40419 .5407 .39987 .53365 .39185 Mtetra
.53365 .39185 .5407 .39987 .55386 .39554 .54685 .38747 Mtetra
.54685 .38747 .55386 .39554 .56709 .39118 .56012 .38308 Mtetra
.56012 .38308 .56709 .39118 .58037 .3868 .57344 .37866 Mtetra
.57344 .37866 .58037 .3868 .59372 .3824 .58684 .37422 Mtetra
.58684 .37422 .59372 .3824 .60713 .37798 .60029 .36976 Mtetra
.60029 .36976 .60713 .37798 .62061 .37354 .61382 .36528 Mtetra
.61382 .36528 .62061 .37354 .63416 .36907 .6274 .36077 Mtetra
.952 .602 .243 r
.6274 .36077 .63416 .36907 .65156 .46295 .64466 .45481 Mtetra
.646 .762 .934 r
.64466 .45481 .65156 .46295 .66567 .45855 .65882 .45036 Mtetra
.65882 .45036 .66567 .45855 .67985 .45412 .67304 .4459 Mtetra
.67304 .4459 .67985 .45412 .6941 .44968 .68734 .44141 Mtetra
.68734 .44141 .6941 .44968 .70842 .44521 .70172 .43691 Mtetra
.70172 .43691 .70842 .44521 .72281 .44072 .71616 .43237 Mtetra
.71616 .43237 .72281 .44072 .73728 .43621 .73068 .42782 Mtetra
.73068 .42782 .73728 .43621 .75183 .43167 .74528 .42324 Mtetra
.74528 .42324 .75183 .43167 .76644 .42712 .75995 .41864 Mtetra
.75995 .41864 .76644 .42712 .78113 .42253 .77469 .41401 Mtetra
.77469 .41401 .78113 .42253 .7959 .41793 .78951 .40936 Mtetra
.78951 .40936 .7959 .41793 .81074 .4133 .80441 .40469 Mtetra
.80441 .40469 .81074 .4133 .82566 .40865 .81938 .39999 Mtetra
.664 .741 .908 r
.17033 .3851 .17814 .39237 .18924 .38844 .18146 .38114 Mtetra
.18146 .38114 .18924 .38844 .20039 .38449 .19263 .37715 Mtetra
.19263 .37715 .20039 .38449 .21158 .38052 .20386 .37316 Mtetra
.20386 .37316 .21158 .38052 .22283 .37654 .21513 .36914 Mtetra
.21513 .36914 .22283 .37654 .23412 .37254 .22645 .36511 Mtetra
.22645 .36511 .23412 .37254 .24546 .36852 .23782 .36106 Mtetra
.23782 .36106 .24546 .36852 .25686 .36449 .24924 .35699 Mtetra
.24924 .35699 .25686 .36449 .2683 .36043 .26072 .35291 Mtetra
.26072 .35291 .2683 .36043 .27979 .35636 .27224 .3488 Mtetra
.27224 .3488 .27979 .35636 .29133 .35228 .28381 .34468 Mtetra
.28381 .34468 .29133 .35228 .30292 .34817 .29543 .34054 Mtetra
.29543 .34054 .30292 .34817 .31457 .34404 .30711 .33638 Mtetra
.30711 .33638 .31457 .34404 .32626 .3399 .31884 .3322 Mtetra
.31884 .3322 .32626 .3399 .33801 .33574 .33061 .32801 Mtetra
.33061 .32801 .33801 .33574 .34981 .33156 .34245 .3238 Mtetra
.34245 .3238 .34981 .33156 .36166 .32736 .35433 .31956 Mtetra
.35433 .31956 .36166 .32736 .37357 .32315 .36627 .31531 Mtetra
.36627 .31531 .37357 .32315 .38553 .31891 .37826 .31104 Mtetra
.37826 .31104 .38553 .31891 .39754 .31465 .39031 .30675 Mtetra
.39031 .30675 .39754 .31465 .4096 .31038 .40241 .30244 Mtetra
.40241 .30244 .4096 .31038 .42172 .30609 .41456 .29811 Mtetra
.41456 .29811 .42172 .30609 .4339 .30177 .42677 .29376 Mtetra
.42677 .29376 .4339 .30177 .44613 .29744 .43903 .28939 Mtetra
.43903 .28939 .44613 .29744 .45841 .29309 .45135 .285 Mtetra
.45135 .285 .45841 .29309 .47075 .28872 .46373 .2806 Mtetra
.964 .646 .363 r
.46373 .2806 .47075 .28872 .48148 .40914 .4742 .4012 Mtetra
.654 .753 .922 r
.4742 .4012 .48148 .40914 .49443 .40485 .48719 .39687 Mtetra
.48719 .39687 .49443 .40485 .50744 .40054 .50024 .39252 Mtetra
.50024 .39252 .50744 .40054 .52051 .3962 .51336 .38815 Mtetra
.51336 .38815 .52051 .3962 .53365 .39185 .52654 .38375 Mtetra
.52654 .38375 .53365 .39185 .54685 .38747 .53978 .37934 Mtetra
.53978 .37934 .54685 .38747 .56012 .38308 .55309 .3749 Mtetra
.55309 .3749 .56012 .38308 .57344 .37866 .56646 .37045 Mtetra
.56646 .37045 .57344 .37866 .58684 .37422 .57989 .36597 Mtetra
.57989 .36597 .58684 .37422 .60029 .36976 .59339 .36147 Mtetra
.59339 .36147 .60029 .36976 .61382 .36528 .60696 .35695 Mtetra
.60696 .35695 .61382 .36528 .6274 .36077 .62059 .3524 Mtetra
.952 .602 .243 r
.62059 .3524 .6274 .36077 .64466 .45481 .6377 .44659 Mtetra
.646 .762 .934 r
.6377 .44659 .64466 .45481 .65882 .45036 .6519 .44211 Mtetra
.6519 .44211 .65882 .45036 .67304 .4459 .66618 .4376 Mtetra
.66618 .4376 .67304 .4459 .68734 .44141 .68053 .43307 Mtetra
.68053 .43307 .68734 .44141 .70172 .43691 .69495 .42852 Mtetra
.69495 .42852 .70172 .43691 .71616 .43237 .70945 .42395 Mtetra
.70945 .42395 .71616 .43237 .73068 .42782 .72402 .41935 Mtetra
.72402 .41935 .73068 .42782 .74528 .42324 .73867 .41473 Mtetra
.73867 .41473 .74528 .42324 .75995 .41864 .75339 .41008 Mtetra
.75339 .41008 .75995 .41864 .77469 .41401 .76819 .40541 Mtetra
.76819 .40541 .77469 .41401 .78951 .40936 .78306 .40072 Mtetra
.78306 .40072 .78951 .40936 .80441 .40469 .79801 .396 Mtetra
.79801 .396 .80441 .40469 .81938 .39999 .81304 .39126 Mtetra
.664 .741 .908 r
.16246 .37777 .17033 .3851 .18146 .38114 .17361 .37377 Mtetra
.17361 .37377 .18146 .38114 .19263 .37715 .18482 .36976 Mtetra
.18482 .36976 .19263 .37715 .20386 .37316 .19607 .36573 Mtetra
.19607 .36573 .20386 .37316 .21513 .36914 .20737 .36168 Mtetra
.20737 .36168 .21513 .36914 .22645 .36511 .21872 .35762 Mtetra
.21872 .35762 .22645 .36511 .23782 .36106 .23012 .35354 Mtetra
.23012 .35354 .23782 .36106 .24924 .35699 .24157 .34943 Mtetra
.24157 .34943 .24924 .35699 .26072 .35291 .25307 .34532 Mtetra
.25307 .34532 .26072 .35291 .27224 .3488 .26462 .34118 Mtetra
.26462 .34118 .27224 .3488 .28381 .34468 .27623 .33702 Mtetra
.27623 .33702 .28381 .34468 .29543 .34054 .28788 .33285 Mtetra
.28788 .33285 .29543 .34054 .30711 .33638 .29959 .32866 Mtetra
.29959 .32866 .30711 .33638 .31884 .3322 .31135 .32444 Mtetra
.31135 .32444 .31884 .3322 .33061 .32801 .32316 .32021 Mtetra
.32316 .32021 .33061 .32801 .34245 .3238 .33502 .31597 Mtetra
.33502 .31597 .34245 .3238 .35433 .31956 .34694 .3117 Mtetra
.34694 .3117 .35433 .31956 .36627 .31531 .35891 .30741 Mtetra
.35891 .30741 .36627 .31531 .37826 .31104 .37093 .3031 Mtetra
.37093 .3031 .37826 .31104 .39031 .30675 .38301 .29878 Mtetra
.38301 .29878 .39031 .30675 .40241 .30244 .39515 .29443 Mtetra
.39515 .29443 .40241 .30244 .41456 .29811 .40734 .29007 Mtetra
.40734 .29007 .41456 .29811 .42677 .29376 .41958 .28568 Mtetra
.41958 .28568 .42677 .29376 .43903 .28939 .43188 .28128 Mtetra
.43188 .28128 .43903 .28939 .45135 .285 .44424 .27685 Mtetra
.44424 .27685 .45135 .285 .46373 .2806 .45665 .2724 Mtetra
.964 .646 .363 r
.45665 .2724 .46373 .2806 .4742 .4012 .46686 .39319 Mtetra
.654 .753 .922 r
.46686 .39319 .4742 .4012 .48719 .39687 .47989 .38882 Mtetra
.47989 .38882 .48719 .39687 .50024 .39252 .49298 .38443 Mtetra
.49298 .38443 .50024 .39252 .51336 .38815 .50614 .38002 Mtetra
.50614 .38002 .51336 .38815 .52654 .38375 .51936 .37559 Mtetra
.51936 .37559 .52654 .38375 .53978 .37934 .53264 .37113 Mtetra
.53264 .37113 .53978 .37934 .55309 .3749 .54599 .36666 Mtetra
.54599 .36666 .55309 .3749 .56646 .37045 .5594 .36216 Mtetra
.5594 .36216 .56646 .37045 .57989 .36597 .57288 .35764 Mtetra
.57288 .35764 .57989 .36597 .59339 .36147 .58643 .3531 Mtetra
.58643 .3531 .59339 .36147 .60696 .35695 .60004 .34854 Mtetra
.60004 .34854 .60696 .35695 .62059 .3524 .61372 .34395 Mtetra
.952 .602 .243 r
.61372 .34395 .62059 .3524 .6377 .44659 .63067 .4383 Mtetra
.646 .762 .934 r
.63067 .4383 .6377 .44659 .6519 .44211 .64492 .43377 Mtetra
.64492 .43377 .6519 .44211 .66618 .4376 .65925 .42922 Mtetra
.65925 .42922 .66618 .4376 .68053 .43307 .67365 .42465 Mtetra
.67365 .42465 .68053 .43307 .69495 .42852 .68812 .42006 Mtetra
.68812 .42006 .69495 .42852 .70945 .42395 .70267 .41544 Mtetra
.70267 .41544 .70945 .42395 .72402 .41935 .71729 .4108 Mtetra
.71729 .4108 .72402 .41935 .73867 .41473 .73199 .40613 Mtetra
.73199 .40613 .73867 .41473 .75339 .41008 .74677 .40144 Mtetra
.74677 .40144 .75339 .41008 .76819 .40541 .76162 .39673 Mtetra
.76162 .39673 .76819 .40541 .78306 .40072 .77655 .39199 Mtetra
.77655 .39199 .78306 .40072 .79801 .396 .79155 .38723 Mtetra
.79155 .38723 .79801 .396 .81304 .39126 .80664 .38244 Mtetra
.664 .741 .908 r
.15452 .37038 .16246 .37777 .17361 .37377 .16571 .36635 Mtetra
.16571 .36635 .17361 .37377 .18482 .36976 .17694 .36231 Mtetra
.17694 .36231 .18482 .36976 .19607 .36573 .18822 .35825 Mtetra
.18822 .35825 .19607 .36573 .20737 .36168 .19955 .35416 Mtetra
.19955 .35416 .20737 .36168 .21872 .35762 .21093 .35007 Mtetra
.21093 .35007 .21872 .35762 .23012 .35354 .22236 .34595 Mtetra
.22236 .34595 .23012 .35354 .24157 .34943 .23384 .34182 Mtetra
.23384 .34182 .24157 .34943 .25307 .34532 .24537 .33766 Mtetra
.24537 .33766 .25307 .34532 .26462 .34118 .25695 .33349 Mtetra
.25695 .33349 .26462 .34118 .27623 .33702 .26858 .3293 Mtetra
.26858 .3293 .27623 .33702 .28788 .33285 .28027 .32509 Mtetra
.28027 .32509 .28788 .33285 .29959 .32866 .292 .32087 Mtetra
.292 .32087 .29959 .32866 .31135 .32444 .30379 .31662 Mtetra
.30379 .31662 .31135 .32444 .32316 .32021 .31564 .31236 Mtetra
.31564 .31236 .32316 .32021 .33502 .31597 .32753 .30807 Mtetra
.32753 .30807 .33502 .31597 .34694 .3117 .33948 .30377 Mtetra
.33948 .30377 .34694 .3117 .35891 .30741 .35149 .29944 Mtetra
.35149 .29944 .35891 .30741 .37093 .3031 .36355 .2951 Mtetra
.36355 .2951 .37093 .3031 .38301 .29878 .37566 .29074 Mtetra
.37566 .29074 .38301 .29878 .39515 .29443 .38783 .28636 Mtetra
.38783 .28636 .39515 .29443 .40734 .29007 .40005 .28195 Mtetra
.40005 .28195 .40734 .29007 .41958 .28568 .41233 .27753 Mtetra
.41233 .27753 .41958 .28568 .43188 .28128 .42467 .27309 Mtetra
.42467 .27309 .43188 .28128 .44424 .27685 .43706 .26863 Mtetra
.43706 .26863 .44424 .27685 .45665 .2724 .44951 .26414 Mtetra
.964 .646 .363 r
.44951 .26414 .45665 .2724 .46686 .39319 .45945 .38511 Mtetra
.654 .753 .922 r
.45945 .38511 .46686 .39319 .47989 .38882 .47252 .3807 Mtetra
.47252 .3807 .47989 .38882 .49298 .38443 .48566 .37627 Mtetra
.48566 .37627 .49298 .38443 .50614 .38002 .49886 .37182 Mtetra
.49886 .37182 .50614 .38002 .51936 .37559 .51212 .36735 Mtetra
.51212 .36735 .51936 .37559 .53264 .37113 .52544 .36286 Mtetra
.52544 .36286 .53264 .37113 .54599 .36666 .53883 .35834 Mtetra
.53883 .35834 .54599 .36666 .5594 .36216 .55229 .3538 Mtetra
.55229 .3538 .5594 .36216 .57288 .35764 .56581 .34924 Mtetra
.56581 .34924 .57288 .35764 .58643 .3531 .5794 .34466 Mtetra
.5794 .34466 .58643 .3531 .60004 .34854 .59306 .34006 Mtetra
.59306 .34006 .60004 .34854 .61372 .34395 .60678 .33543 Mtetra
.952 .602 .243 r
.60678 .33543 .61372 .34395 .63067 .4383 .62358 .42992 Mtetra
.646 .762 .934 r
.62358 .42992 .63067 .4383 .64492 .43377 .63788 .42536 Mtetra
.63788 .42536 .64492 .43377 .65925 .42922 .65226 .42077 Mtetra
.65226 .42077 .65925 .42922 .67365 .42465 .66671 .41615 Mtetra
.66671 .41615 .67365 .42465 .68812 .42006 .68123 .41151 Mtetra
.68123 .41151 .68812 .42006 .70267 .41544 .69583 .40685 Mtetra
.69583 .40685 .70267 .41544 .71729 .4108 .7105 .40216 Mtetra
.7105 .40216 .71729 .4108 .73199 .40613 .72526 .39745 Mtetra
.72526 .39745 .73199 .40613 .74677 .40144 .74008 .39272 Mtetra
.74008 .39272 .74677 .40144 .76162 .39673 .75499 .38796 Mtetra
.75499 .38796 .76162 .39673 .77655 .39199 .76997 .38317 Mtetra
.76997 .38317 .77655 .39199 .79155 .38723 .78503 .37837 Mtetra
.78503 .37837 .79155 .38723 .80664 .38244 .80017 .37353 Mtetra
.664 .741 .908 r
.14652 .36293 .15452 .37038 .16571 .36635 .15773 .35887 Mtetra
.15773 .35887 .16571 .36635 .17694 .36231 .16899 .35479 Mtetra
.16899 .35479 .17694 .36231 .18822 .35825 .1803 .3507 Mtetra
.1803 .3507 .18822 .35825 .19955 .35416 .19166 .34658 Mtetra
.19166 .34658 .19955 .35416 .21093 .35007 .20307 .34245 Mtetra
.20307 .34245 .21093 .35007 .22236 .34595 .21453 .3383 Mtetra
.21453 .3383 .22236 .34595 .23384 .34182 .22604 .33414 Mtetra
.22604 .33414 .23384 .34182 .24537 .33766 .2376 .32995 Mtetra
.2376 .32995 .24537 .33766 .25695 .33349 .24921 .32574 Mtetra
.24921 .32574 .25695 .33349 .26858 .3293 .26087 .32152 Mtetra
.26087 .32152 .26858 .3293 .28027 .32509 .27259 .31728 Mtetra
.27259 .31728 .28027 .32509 .292 .32087 .28436 .31301 Mtetra
.28436 .31301 .292 .32087 .30379 .31662 .29618 .30873 Mtetra
.29618 .30873 .30379 .31662 .31564 .31236 .30806 .30443 Mtetra
.30806 .30443 .31564 .31236 .32753 .30807 .31998 .30011 Mtetra
.31998 .30011 .32753 .30807 .33948 .30377 .33197 .29577 Mtetra
.33197 .29577 .33948 .30377 .35149 .29944 .344 .29141 Mtetra
.344 .29141 .35149 .29944 .36355 .2951 .3561 .28703 Mtetra
.3561 .28703 .36355 .2951 .37566 .29074 .36824 .28263 Mtetra
.36824 .28263 .37566 .29074 .38783 .28636 .38045 .27821 Mtetra
.38045 .27821 .38783 .28636 .40005 .28195 .3927 .27377 Mtetra
.3927 .27377 .40005 .28195 .41233 .27753 .40502 .26932 Mtetra
.40502 .26932 .41233 .27753 .42467 .27309 .41739 .26483 Mtetra
.41739 .26483 .42467 .27309 .43706 .26863 .42982 .26033 Mtetra
.42982 .26033 .43706 .26863 .44951 .26414 .4423 .25581 Mtetra
.964 .646 .363 r
.4423 .25581 .44951 .26414 .45945 .38511 .45198 .37695 Mtetra
.654 .753 .922 r
.45198 .37695 .45945 .38511 .47252 .3807 .46509 .37251 Mtetra
.46509 .37251 .47252 .3807 .48566 .37627 .47827 .36804 Mtetra
.47827 .36804 .48566 .37627 .49886 .37182 .49151 .36355 Mtetra
.49151 .36355 .49886 .37182 .51212 .36735 .50481 .35904 Mtetra
.50481 .35904 .51212 .36735 .52544 .36286 .51818 .3545 Mtetra
.51818 .3545 .52544 .36286 .53883 .35834 .53161 .34995 Mtetra
.53161 .34995 .53883 .35834 .55229 .3538 .54511 .34537 Mtetra
.54511 .34537 .55229 .3538 .56581 .34924 .55868 .34077 Mtetra
.55868 .34077 .56581 .34924 .5794 .34466 .57231 .33614 Mtetra
.57231 .33614 .5794 .34466 .59306 .34006 .58601 .33149 Mtetra
.58601 .33149 .59306 .34006 .60678 .33543 .59978 .32682 Mtetra
.952 .602 .243 r
.59978 .32682 .60678 .33543 .62358 .42992 .61642 .42147 Mtetra
.646 .762 .934 r
.61642 .42147 .62358 .42992 .63788 .42536 .63077 .41686 Mtetra
.63077 .41686 .63788 .42536 .65226 .42077 .64519 .41223 Mtetra
.64519 .41223 .65226 .42077 .66671 .41615 .65969 .40757 Mtetra
.65969 .40757 .66671 .41615 .68123 .41151 .67427 .40289 Mtetra
.67427 .40289 .68123 .41151 .69583 .40685 .68892 .39818 Mtetra
.68892 .39818 .69583 .40685 .7105 .40216 .70365 .39345 Mtetra
.70365 .39345 .7105 .40216 .72526 .39745 .71845 .38869 Mtetra
.71845 .38869 .72526 .39745 .74008 .39272 .73334 .38391 Mtetra
.73334 .38391 .74008 .39272 .75499 .38796 .74829 .37911 Mtetra
.74829 .37911 .75499 .38796 .76997 .38317 .76333 .37428 Mtetra
.76333 .37428 .76997 .38317 .78503 .37837 .77845 .36942 Mtetra
.77845 .36942 .78503 .37837 .80017 .37353 .79365 .36454 Mtetra
.664 .741 .908 r
.13846 .35542 .14652 .36293 .15773 .35887 .1497 .35133 Mtetra
.1497 .35133 .15773 .35887 .16899 .35479 .16098 .34722 Mtetra
.16098 .34722 .16899 .35479 .1803 .3507 .17232 .34309 Mtetra
.17232 .34309 .1803 .3507 .19166 .34658 .18371 .33894 Mtetra
.18371 .33894 .19166 .34658 .20307 .34245 .19515 .33478 Mtetra
.19515 .33478 .20307 .34245 .21453 .3383 .20663 .33059 Mtetra
.20663 .33059 .21453 .3383 .22604 .33414 .21817 .32639 Mtetra
.21817 .32639 .22604 .33414 .2376 .32995 .22976 .32217 Mtetra
.22976 .32217 .2376 .32995 .24921 .32574 .24141 .31793 Mtetra
.24141 .31793 .24921 .32574 .26087 .32152 .2531 .31367 Mtetra
.2531 .31367 .26087 .32152 .27259 .31728 .26485 .30939 Mtetra
.26485 .30939 .27259 .31728 .28436 .31301 .27665 .30509 Mtetra
.27665 .30509 .28436 .31301 .29618 .30873 .2885 .30078 Mtetra
.2885 .30078 .29618 .30873 .30806 .30443 .30041 .29644 Mtetra
.30041 .29644 .30806 .30443 .31998 .30011 .31237 .29208 Mtetra
.31237 .29208 .31998 .30011 .33197 .29577 .32439 .28771 Mtetra
.32439 .28771 .33197 .29577 .344 .29141 .33646 .28331 Mtetra
.33646 .28331 .344 .29141 .3561 .28703 .34858 .2789 Mtetra
.34858 .2789 .3561 .28703 .36824 .28263 .36077 .27446 Mtetra
.36077 .27446 .36824 .28263 .38045 .27821 .373 .27 Mtetra
.373 .27 .38045 .27821 .3927 .27377 .3853 .26553 Mtetra
.3853 .26553 .3927 .27377 .40502 .26932 .39764 .26103 Mtetra
.39764 .26103 .40502 .26932 .41739 .26483 .41005 .25651 Mtetra
.41005 .25651 .41739 .26483 .42982 .26033 .42252 .25197 Mtetra
.42252 .25197 .42982 .26033 .4423 .25581 .43504 .24741 Mtetra
.966 .658 .389 r
.43504 .24741 .4423 .25581 .45198 .37695 .44323 .41711 Mtetra
.449 .145 .357 r
.44323 .41711 .45198 .37695 .46509 .37251 .45657 .41268 Mtetra
.45657 .41268 .46509 .37251 .47827 .36804 .46999 .40822 Mtetra
.46999 .40822 .47827 .36804 .49151 .36355 .48347 .40374 Mtetra
.48347 .40374 .49151 .36355 .50481 .35904 .49702 .39924 Mtetra
.49702 .39924 .50481 .35904 .51818 .3545 .51063 .39471 Mtetra
.51063 .39471 .51818 .3545 .53161 .34995 .52432 .39016 Mtetra
.52432 .39016 .53161 .34995 .54511 .34537 .53807 .38559 Mtetra
.53807 .38559 .54511 .34537 .55868 .34077 .55189 .381 Mtetra
.55189 .381 .55868 .34077 .57231 .33614 .56578 .37639 Mtetra
.56578 .37639 .57231 .33614 .58601 .33149 .57974 .37175 Mtetra
.57974 .37175 .58601 .33149 .59978 .32682 .59377 .36708 Mtetra
.647 .318 .4 r
.59377 .36708 .59978 .32682 .61642 .42147 .60852 .38747 Mtetra
.59 .46 .671 r
.60852 .38747 .61642 .42147 .63077 .41686 .62281 .38279 Mtetra
.62281 .38279 .63077 .41686 .64519 .41223 .63717 .37808 Mtetra
.63717 .37808 .64519 .41223 .65969 .40757 .6516 .37335 Mtetra
.6516 .37335 .65969 .40757 .67427 .40289 .66611 .36859 Mtetra
.66611 .36859 .67427 .40289 .68892 .39818 .68069 .36381 Mtetra
.68069 .36381 .68892 .39818 .70365 .39345 .69535 .35901 Mtetra
.69535 .35901 .70365 .39345 .71845 .38869 .71009 .35418 Mtetra
.71009 .35418 .71845 .38869 .73334 .38391 .7249 .34932 Mtetra
.7249 .34932 .73334 .38391 .74829 .37911 .73979 .34444 Mtetra
.73979 .34444 .74829 .37911 .76333 .37428 .75476 .33954 Mtetra
.75476 .33954 .76333 .37428 .77845 .36942 .7698 .3346 Mtetra
.7698 .3346 .77845 .36942 .79365 .36454 .78493 .32965 Mtetra
.664 .741 .908 r
.13033 .34785 .13846 .35542 .1497 .35133 .1416 .34373 Mtetra
.1416 .34373 .1497 .35133 .16098 .34722 .15291 .33958 Mtetra
.15291 .33958 .16098 .34722 .17232 .34309 .16428 .33542 Mtetra
.16428 .33542 .17232 .34309 .18371 .33894 .17569 .33124 Mtetra
.17569 .33124 .18371 .33894 .19515 .33478 .18716 .32704 Mtetra
.18716 .32704 .19515 .33478 .20663 .33059 .19868 .32282 Mtetra
.19868 .32282 .20663 .33059 .21817 .32639 .21025 .31858 Mtetra
.21025 .31858 .21817 .32639 .22976 .32217 .22187 .31433 Mtetra
.22187 .31433 .22976 .32217 .24141 .31793 .23354 .31005 Mtetra
.23354 .31005 .24141 .31793 .2531 .31367 .24527 .30576 Mtetra
.24527 .30576 .2531 .31367 .26485 .30939 .25704 .30144 Mtetra
.25704 .30144 .26485 .30939 .27665 .30509 .26888 .29711 Mtetra
.26888 .29711 .27665 .30509 .2885 .30078 .28076 .29276 Mtetra
.28076 .29276 .2885 .30078 .30041 .29644 .2927 .28838 Mtetra
.2927 .28838 .30041 .29644 .31237 .29208 .3047 .28399 Mtetra
.3047 .28399 .31237 .29208 .32439 .28771 .31674 .27958 Mtetra
.31674 .27958 .32439 .28771 .33646 .28331 .32885 .27514 Mtetra
.32885 .27514 .33646 .28331 .34858 .2789 .34101 .27069 Mtetra
.34101 .27069 .34858 .2789 .36077 .27446 .35322 .26622 Mtetra
.35322 .26622 .36077 .27446 .373 .27 .36549 .26172 Mtetra
.36549 .26172 .373 .27 .3853 .26553 .37782 .25721 Mtetra
.37782 .25721 .3853 .26553 .39764 .26103 .39021 .25267 Mtetra
.39021 .25267 .39764 .26103 .41005 .25651 .40265 .24811 Mtetra
.40265 .24811 .41005 .25651 .42252 .25197 .41515 .24353 Mtetra
.41515 .24353 .42252 .25197 .43504 .24741 .42771 .23893 Mtetra
.966 .658 .389 r
.42771 .23893 .43504 .24741 .44323 .41711 .4355 .40891 Mtetra
.65 .758 .928 r
.4355 .40891 .44323 .41711 .45657 .41268 .44889 .40443 Mtetra
.44889 .40443 .45657 .41268 .46999 .40822 .46235 .39993 Mtetra
.46235 .39993 .46999 .40822 .48347 .40374 .47587 .39541 Mtetra
.47587 .39541 .48347 .40374 .49702 .39924 .48946 .39087 Mtetra
.48946 .39087 .49702 .39924 .51063 .39471 .50312 .3863 Mtetra
.50312 .3863 .51063 .39471 .52432 .39016 .51685 .38171 Mtetra
.51685 .38171 .52432 .39016 .53807 .38559 .53064 .3771 Mtetra
.53064 .3771 .53807 .38559 .55189 .381 .54451 .37246 Mtetra
.54451 .37246 .55189 .381 .56578 .37639 .55845 .3678 Mtetra
.55845 .3678 .56578 .37639 .57974 .37175 .57245 .36312 Mtetra
.57245 .36312 .57974 .37175 .59377 .36708 .58653 .35841 Mtetra
.629 .161 0 r
.58653 .35841 .59377 .36708 .60852 .38747 .60128 .37881 Mtetra
.648 .76 .931 r
.60128 .37881 .60852 .38747 .62281 .38279 .61562 .37408 Mtetra
.61562 .37408 .62281 .38279 .63717 .37808 .63003 .36933 Mtetra
.63003 .36933 .63717 .37808 .6516 .37335 .64451 .36455 Mtetra
.64451 .36455 .6516 .37335 .66611 .36859 .65907 .35975 Mtetra
.65907 .35975 .66611 .36859 .68069 .36381 .6737 .35492 Mtetra
.6737 .35492 .68069 .36381 .69535 .35901 .68841 .35007 Mtetra
.68841 .35007 .69535 .35901 .71009 .35418 .7032 .34519 Mtetra
.7032 .34519 .71009 .35418 .7249 .34932 .71807 .34029 Mtetra
.71807 .34029 .7249 .34932 .73979 .34444 .73301 .33536 Mtetra
.73301 .33536 .73979 .34444 .75476 .33954 .74803 .33041 Mtetra
.74803 .33041 .75476 .33954 .7698 .3346 .76314 .32543 Mtetra
.76314 .32543 .7698 .3346 .78493 .32965 .77832 .32042 Mtetra
.664 .741 .908 r
.12213 .34022 .13033 .34785 .1416 .34373 .13343 .33606 Mtetra
.13343 .33606 .1416 .34373 .15291 .33958 .14477 .33188 Mtetra
.14477 .33188 .15291 .33958 .16428 .33542 .15616 .32769 Mtetra
.15616 .32769 .16428 .33542 .17569 .33124 .16761 .32347 Mtetra
.16761 .32347 .17569 .33124 .18716 .32704 .17911 .31924 Mtetra
.17911 .31924 .18716 .32704 .19868 .32282 .19065 .31498 Mtetra
.19065 .31498 .19868 .32282 .21025 .31858 .20225 .31071 Mtetra
.20225 .31071 .21025 .31858 .22187 .31433 .2139 .30642 Mtetra
.2139 .30642 .22187 .31433 .23354 .31005 .22561 .30211 Mtetra
.22561 .30211 .23354 .31005 .24527 .30576 .23736 .29778 Mtetra
.23736 .29778 .24527 .30576 .25704 .30144 .24917 .29343 Mtetra
.24917 .29343 .25704 .30144 .26888 .29711 .26104 .28906 Mtetra
.26104 .28906 .26888 .29711 .28076 .29276 .27296 .28467 Mtetra
.27296 .28467 .28076 .29276 .2927 .28838 .28493 .28026 Mtetra
.28493 .28026 .2927 .28838 .3047 .28399 .29695 .27583 Mtetra
.29695 .27583 .3047 .28399 .31674 .27958 .30904 .27138 Mtetra
.30904 .27138 .31674 .27958 .32885 .27514 .32117 .26691 Mtetra
.32117 .26691 .32885 .27514 .34101 .27069 .33337 .26241 Mtetra
.33337 .26241 .34101 .27069 .35322 .26622 .34562 .2579 Mtetra
.34562 .2579 .35322 .26622 .36549 .26172 .35792 .25337 Mtetra
.35792 .25337 .36549 .26172 .37782 .25721 .37029 .24881 Mtetra
.37029 .24881 .37782 .25721 .39021 .25267 .38271 .24424 Mtetra
.38271 .24424 .39021 .25267 .40265 .24811 .39519 .23964 Mtetra
.39519 .23964 .40265 .24811 .41515 .24353 .40772 .23502 Mtetra
.40772 .23502 .41515 .24353 .42771 .23893 .42032 .23039 Mtetra
.966 .658 .389 r
.42032 .23039 .42771 .23893 .4355 .40891 .4277 .40062 Mtetra
.65 .758 .928 r
.4277 .40062 .4355 .40891 .44889 .40443 .44113 .39611 Mtetra
.44113 .39611 .44889 .40443 .46235 .39993 .45463 .39157 Mtetra
.45463 .39157 .46235 .39993 .47587 .39541 .4682 .387 Mtetra
.4682 .387 .47587 .39541 .48946 .39087 .48183 .38242 Mtetra
.48183 .38242 .48946 .39087 .50312 .3863 .49554 .37781 Mtetra
.49554 .37781 .50312 .3863 .51685 .38171 .50931 .37318 Mtetra
.50931 .37318 .51685 .38171 .53064 .3771 .52315 .36852 Mtetra
.52315 .36852 .53064 .3771 .54451 .37246 .53706 .36384 Mtetra
.53706 .36384 .54451 .37246 .55845 .3678 .55105 .35914 Mtetra
.55105 .35914 .55845 .3678 .57245 .36312 .5651 .35441 Mtetra
.5651 .35441 .57245 .36312 .58653 .35841 .57923 .34966 Mtetra
.629 .161 0 r
.57923 .34966 .58653 .35841 .60128 .37881 .59397 .37006 Mtetra
.648 .76 .931 r
.59397 .37006 .60128 .37881 .61562 .37408 .60835 .36529 Mtetra
.60835 .36529 .61562 .37408 .63003 .36933 .62281 .36049 Mtetra
.62281 .36049 .63003 .36933 .64451 .36455 .63735 .35567 Mtetra
.63735 .35567 .64451 .36455 .65907 .35975 .65196 .35082 Mtetra
.65196 .35082 .65907 .35975 .6737 .35492 .66664 .34595 Mtetra
.66664 .34595 .6737 .35492 .68841 .35007 .68141 .34105 Mtetra
.68141 .34105 .68841 .35007 .7032 .34519 .69625 .33612 Mtetra
.69625 .33612 .7032 .34519 .71807 .34029 .71117 .33117 Mtetra
.71117 .33117 .71807 .34029 .73301 .33536 .72617 .3262 Mtetra
.72617 .3262 .73301 .33536 .74803 .33041 .74124 .3212 Mtetra
.74124 .3212 .74803 .33041 .76314 .32543 .7564 .31617 Mtetra
.7564 .31617 .76314 .32543 .77832 .32042 .77164 .31111 Mtetra
.664 .741 .908 r
.11387 .33253 .12213 .34022 .13343 .33606 .12519 .32833 Mtetra
.12519 .32833 .13343 .33606 .14477 .33188 .13656 .32412 Mtetra
.13656 .32412 .14477 .33188 .15616 .32769 .14799 .31989 Mtetra
.14799 .31989 .15616 .32769 .16761 .32347 .15946 .31564 Mtetra
.15946 .31564 .16761 .32347 .17911 .31924 .17099 .31137 Mtetra
.17099 .31137 .17911 .31924 .19065 .31498 .18256 .30708 Mtetra
.18256 .30708 .19065 .31498 .20225 .31071 .19419 .30277 Mtetra
.19419 .30277 .20225 .31071 .2139 .30642 .20587 .29844 Mtetra
.20587 .29844 .2139 .30642 .22561 .30211 .21761 .2941 Mtetra
.21761 .2941 .22561 .30211 .23736 .29778 .2294 .28973 Mtetra
.2294 .28973 .23736 .29778 .24917 .29343 .24124 .28534 Mtetra
.24124 .28534 .24917 .29343 .26104 .28906 .25313 .28094 Mtetra
.25313 .28094 .26104 .28906 .27296 .28467 .26508 .27651 Mtetra
.26508 .27651 .27296 .28467 .28493 .28026 .27709 .27206 Mtetra
.27709 .27206 .28493 .28026 .29695 .27583 .28915 .26759 Mtetra
.28915 .26759 .29695 .27583 .30904 .27138 .30126 .26311 Mtetra
.30126 .26311 .30904 .27138 .32117 .26691 .31343 .2586 Mtetra
.31343 .2586 .32117 .26691 .33337 .26241 .32566 .25407 Mtetra
.32566 .25407 .33337 .26241 .34562 .2579 .33795 .24952 Mtetra
.33795 .24952 .34562 .2579 .35792 .25337 .35029 .24494 Mtetra
.35029 .24494 .35792 .25337 .37029 .24881 .36269 .24035 Mtetra
.36269 .24035 .37029 .24881 .38271 .24424 .37514 .23574 Mtetra
.37514 .23574 .38271 .24424 .39519 .23964 .38766 .2311 Mtetra
.38766 .2311 .39519 .23964 .40772 .23502 .40023 .22644 Mtetra
.40023 .22644 .40772 .23502 .42032 .23039 .41286 .22176 Mtetra
.966 .658 .389 r
.41286 .22176 .42032 .23039 .4277 .40062 .41983 .39227 Mtetra
.65 .758 .928 r
.41983 .39227 .4277 .40062 .44113 .39611 .43331 .38771 Mtetra
.43331 .38771 .44113 .39611 .45463 .39157 .44685 .38312 Mtetra
.44685 .38312 .45463 .39157 .4682 .387 .46046 .37852 Mtetra
.46046 .37852 .4682 .387 .48183 .38242 .47414 .37389 Mtetra
.47414 .37389 .48183 .38242 .49554 .37781 .48788 .36924 Mtetra
.48788 .36924 .49554 .37781 .50931 .37318 .5017 .36456 Mtetra
.5017 .36456 .50931 .37318 .52315 .36852 .51559 .35986 Mtetra
.51559 .35986 .52315 .36852 .53706 .36384 .52955 .35514 Mtetra
.52955 .35514 .53706 .36384 .55105 .35914 .54358 .35039 Mtetra
.54358 .35039 .55105 .35914 .5651 .35441 .55768 .34562 Mtetra
.55768 .34562 .5651 .35441 .57923 .34966 .57185 .34083 Mtetra
.629 .161 0 r
.57185 .34083 .57923 .34966 .59397 .37006 .58659 .36123 Mtetra
.648 .76 .931 r
.58659 .36123 .59397 .37006 .60835 .36529 .60102 .35641 Mtetra
.60102 .35641 .60835 .36529 .62281 .36049 .61553 .35157 Mtetra
.61553 .35157 .62281 .36049 .63735 .35567 .63012 .3467 Mtetra
.63012 .3467 .63735 .35567 .65196 .35082 .64478 .3418 Mtetra
.64478 .3418 .65196 .35082 .66664 .34595 .65952 .33688 Mtetra
.65952 .33688 .66664 .34595 .68141 .34105 .67433 .33194 Mtetra
.67433 .33194 .68141 .34105 .69625 .33612 .68923 .32696 Mtetra
.68923 .32696 .69625 .33612 .71117 .33117 .7042 .32197 Mtetra
.7042 .32197 .71117 .33117 .72617 .3262 .71926 .31694 Mtetra
.71926 .31694 .72617 .3262 .74124 .3212 .73439 .31189 Mtetra
.73439 .31189 .74124 .3212 .7564 .31617 .7496 .30681 Mtetra
.7496 .30681 .7564 .31617 .77164 .31111 .7649 .30171 Mtetra
.664 .741 .908 r
.10554 .32477 .11387 .33253 .12519 .32833 .11689 .32054 Mtetra
.11689 .32054 .12519 .32833 .13656 .32412 .12829 .31629 Mtetra
.12829 .31629 .13656 .32412 .14799 .31989 .13974 .31203 Mtetra
.13974 .31203 .14799 .31989 .15946 .31564 .15124 .30774 Mtetra
.15124 .30774 .15946 .31564 .17099 .31137 .1628 .30344 Mtetra
.1628 .30344 .17099 .31137 .18256 .30708 .1744 .29911 Mtetra
.1744 .29911 .18256 .30708 .19419 .30277 .18606 .29477 Mtetra
.18606 .29477 .19419 .30277 .20587 .29844 .19778 .2904 Mtetra
.19778 .2904 .20587 .29844 .21761 .2941 .20954 .28602 Mtetra
.20954 .28602 .21761 .2941 .2294 .28973 .22136 .28162 Mtetra
.22136 .28162 .2294 .28973 .24124 .28534 .23323 .27719 Mtetra
.23323 .27719 .24124 .28534 .25313 .28094 .24516 .27275 Mtetra
.24516 .27275 .25313 .28094 .26508 .27651 .25714 .26828 Mtetra
.25714 .26828 .26508 .27651 .27709 .27206 .26918 .2638 Mtetra
.26918 .2638 .27709 .27206 .28915 .26759 .28127 .25929 Mtetra
.28127 .25929 .28915 .26759 .30126 .26311 .29342 .25477 Mtetra
.29342 .25477 .30126 .26311 .31343 .2586 .30563 .25022 Mtetra
.30563 .25022 .31343 .2586 .32566 .25407 .31789 .24565 Mtetra
.31789 .24565 .32566 .25407 .33795 .24952 .33021 .24106 Mtetra
.33021 .24106 .33795 .24952 .35029 .24494 .34259 .23645 Mtetra
.34259 .23645 .35029 .24494 .36269 .24035 .35502 .23182 Mtetra
.35502 .23182 .36269 .24035 .37514 .23574 .36751 .22716 Mtetra
.36751 .22716 .37514 .23574 .38766 .2311 .38006 .22248 Mtetra
.38006 .22248 .38766 .2311 .40023 .22644 .39267 .21779 Mtetra
.39267 .21779 .40023 .22644 .41286 .22176 .40534 .21306 Mtetra
.966 .658 .389 r
.40534 .21306 .41286 .22176 .41983 .39227 .41189 .38383 Mtetra
.65 .758 .928 r
.41189 .38383 .41983 .39227 .43331 .38771 .42541 .37923 Mtetra
.42541 .37923 .43331 .38771 .44685 .38312 .43899 .3746 Mtetra
.43899 .3746 .44685 .38312 .46046 .37852 .45265 .36996 Mtetra
.45265 .36996 .46046 .37852 .47414 .37389 .46637 .36528 Mtetra
.46637 .36528 .47414 .37389 .48788 .36924 .48016 .36059 Mtetra
.48016 .36059 .48788 .36924 .5017 .36456 .49402 .35587 Mtetra
.49402 .35587 .5017 .36456 .51559 .35986 .50796 .35113 Mtetra
.50796 .35113 .51559 .35986 .52955 .35514 .52196 .34636 Mtetra
.52196 .34636 .52955 .35514 .54358 .35039 .53604 .34157 Mtetra
.53604 .34157 .54358 .35039 .55768 .34562 .55018 .33675 Mtetra
.55018 .33675 .55768 .34562 .57185 .34083 .56441 .33191 Mtetra
.629 .161 0 r
.56441 .33191 .57185 .34083 .58659 .36123 .57913 .35231 Mtetra
.648 .76 .931 r
.57913 .35231 .58659 .36123 .60102 .35641 .59362 .34745 Mtetra
.59362 .34745 .60102 .35641 .61553 .35157 .60818 .34256 Mtetra
.60818 .34256 .61553 .35157 .63012 .3467 .62282 .33764 Mtetra
.62282 .33764 .63012 .3467 .64478 .3418 .63753 .3327 Mtetra
.63753 .3327 .64478 .3418 .65952 .33688 .65232 .32773 Mtetra
.65232 .32773 .65952 .33688 .67433 .33194 .66719 .32274 Mtetra
.66719 .32274 .67433 .33194 .68923 .32696 .68214 .31772 Mtetra
.68214 .31772 .68923 .32696 .7042 .32197 .69717 .31267 Mtetra
.69717 .31267 .7042 .32197 .71926 .31694 .71228 .30759 Mtetra
.71228 .30759 .71926 .31694 .73439 .31189 .72747 .30249 Mtetra
.72747 .30249 .73439 .31189 .7496 .30681 .74274 .29736 Mtetra
.74274 .29736 .7496 .30681 .7649 .30171 .75809 .29221 Mtetra
.664 .741 .908 r
.09714 .31695 .10554 .32477 .11689 .32054 .10852 .31268 Mtetra
.10852 .31268 .11689 .32054 .12829 .31629 .11995 .3084 Mtetra
.11995 .3084 .12829 .31629 .13974 .31203 .13143 .3041 Mtetra
.13143 .3041 .13974 .31203 .15124 .30774 .14296 .29978 Mtetra
.14296 .29978 .15124 .30774 .1628 .30344 .15454 .29544 Mtetra
.15454 .29544 .1628 .30344 .1744 .29911 .16618 .29108 Mtetra
.16618 .29108 .1744 .29911 .18606 .29477 .17787 .28669 Mtetra
.17787 .28669 .18606 .29477 .19778 .2904 .18961 .28229 Mtetra
.18961 .28229 .19778 .2904 .20954 .28602 .20141 .27787 Mtetra
.20141 .27787 .20954 .28602 .22136 .28162 .21326 .27343 Mtetra
.21326 .27343 .22136 .28162 .23323 .27719 .22516 .26897 Mtetra
.22516 .26897 .23323 .27719 .24516 .27275 .23712 .26449 Mtetra
.23712 .26449 .24516 .27275 .25714 .26828 .24914 .25999 Mtetra
.24914 .25999 .25714 .26828 .26918 .2638 .26121 .25546 Mtetra
.26121 .25546 .26918 .2638 .28127 .25929 .27333 .25092 Mtetra
.27333 .25092 .28127 .25929 .29342 .25477 .28552 .24635 Mtetra
.28552 .24635 .29342 .25477 .30563 .25022 .29776 .24177 Mtetra
.29776 .24177 .30563 .25022 .31789 .24565 .31005 .23716 Mtetra
.31005 .23716 .31789 .24565 .33021 .24106 .32241 .23253 Mtetra
.32241 .23253 .33021 .24106 .34259 .23645 .33482 .22788 Mtetra
.33482 .22788 .34259 .23645 .35502 .23182 .34729 .2232 Mtetra
.34729 .2232 .35502 .23182 .36751 .22716 .35982 .21851 Mtetra
.35982 .21851 .36751 .22716 .38006 .22248 .3724 .21379 Mtetra
.3724 .21379 .38006 .22248 .39267 .21779 .38505 .20905 Mtetra
.38505 .20905 .39267 .21779 .40534 .21306 .39776 .20429 Mtetra
.966 .658 .389 r
.39776 .20429 .40534 .21306 .41189 .38383 .40387 .37532 Mtetra
.65 .758 .928 r
.40387 .37532 .41189 .38383 .42541 .37923 .41743 .37067 Mtetra
.41743 .37067 .42541 .37923 .43899 .3746 .43106 .366 Mtetra
.43106 .366 .43899 .3746 .45265 .36996 .44476 .36131 Mtetra
.44476 .36131 .45265 .36996 .46637 .36528 .45853 .3566 Mtetra
.45853 .3566 .46637 .36528 .48016 .36059 .47236 .35186 Mtetra
.47236 .35186 .48016 .36059 .49402 .35587 .48627 .34709 Mtetra
.48627 .34709 .49402 .35587 .50796 .35113 .50025 .3423 Mtetra
.50025 .3423 .50796 .35113 .52196 .34636 .5143 .33749 Mtetra
.5143 .33749 .52196 .34636 .53604 .34157 .52842 .33265 Mtetra
.52842 .33265 .53604 .34157 .55018 .33675 .54262 .32779 Mtetra
.54262 .32779 .55018 .33675 .56441 .33191 .55689 .3229 Mtetra
.629 .161 0 r
.55689 .3229 .56441 .33191 .57913 .35231 .57161 .34331 Mtetra
.648 .76 .931 r
.57161 .34331 .57913 .35231 .59362 .34745 .58614 .3384 Mtetra
.58614 .3384 .59362 .34745 .60818 .34256 .60075 .33346 Mtetra
.60075 .33346 .60818 .34256 .62282 .33764 .61544 .3285 Mtetra
.61544 .3285 .62282 .33764 .63753 .3327 .63021 .32351 Mtetra
.63021 .32351 .63753 .3327 .65232 .32773 .64505 .31849 Mtetra
.64505 .31849 .65232 .32773 .66719 .32274 .65998 .31345 Mtetra
.65998 .31345 .66719 .32274 .68214 .31772 .67498 .30838 Mtetra
.67498 .30838 .68214 .31772 .69717 .31267 .69006 .30328 Mtetra
.69006 .30328 .69717 .31267 .71228 .30759 .70523 .29816 Mtetra
.70523 .29816 .71228 .30759 .72747 .30249 .72047 .293 Mtetra
.72047 .293 .72747 .30249 .74274 .29736 .7358 .28782 Mtetra
.7358 .28782 .74274 .29736 .75809 .29221 .75121 .28262 Mtetra
.664 .741 .908 r
.08867 .30906 .09714 .31695 .10852 .31268 .10008 .30476 Mtetra
.10008 .30476 .10852 .31268 .11995 .3084 .11153 .30044 Mtetra
.11153 .30044 .11995 .3084 .13143 .3041 .12304 .29611 Mtetra
.12304 .29611 .13143 .3041 .14296 .29978 .1346 .29175 Mtetra
.1346 .29175 .14296 .29978 .15454 .29544 .14622 .28737 Mtetra
.14622 .28737 .15454 .29544 .16618 .29108 .15788 .28297 Mtetra
.15788 .28297 .16618 .29108 .17787 .28669 .1696 .27855 Mtetra
.1696 .27855 .17787 .28669 .18961 .28229 .18138 .27412 Mtetra
.18138 .27412 .18961 .28229 .20141 .27787 .1932 .26966 Mtetra
.1932 .26966 .20141 .27787 .21326 .27343 .20509 .26518 Mtetra
.20509 .26518 .21326 .27343 .22516 .26897 .21702 .26068 Mtetra
.21702 .26068 .22516 .26897 .23712 .26449 .22901 .25616 Mtetra
.22901 .25616 .23712 .26449 .24914 .25999 .24106 .25162 Mtetra
.24106 .25162 .24914 .25999 .26121 .25546 .25317 .24706 Mtetra
.25317 .24706 .26121 .25546 .27333 .25092 .26532 .24247 Mtetra
.26532 .24247 .27333 .25092 .28552 .24635 .27754 .23787 Mtetra
.27754 .23787 .28552 .24635 .29776 .24177 .28981 .23324 Mtetra
.28981 .23324 .29776 .24177 .31005 .23716 .30215 .22859 Mtetra
.30215 .22859 .31005 .23716 .32241 .23253 .31453 .22393 Mtetra
.31453 .22393 .32241 .23253 .33482 .22788 .32698 .21923 Mtetra
.32698 .21923 .33482 .22788 .34729 .2232 .33949 .21452 Mtetra
.33949 .21452 .34729 .2232 .35982 .21851 .35205 .20978 Mtetra
.35205 .20978 .35982 .21851 .3724 .21379 .36468 .20502 Mtetra
.36468 .20502 .3724 .21379 .38505 .20905 .37736 .20024 Mtetra
.37736 .20024 .38505 .20905 .39776 .20429 .39011 .19544 Mtetra
.966 .658 .389 r
.39011 .19544 .39776 .20429 .40387 .37532 .39578 .36672 Mtetra
.65 .758 .928 r
.39578 .36672 .40387 .37532 .41743 .37067 .40939 .36204 Mtetra
.40939 .36204 .41743 .37067 .43106 .366 .42306 .35732 Mtetra
.42306 .35732 .43106 .366 .44476 .36131 .4368 .35259 Mtetra
.4368 .35259 .44476 .36131 .45853 .3566 .45061 .34783 Mtetra
.45061 .34783 .45853 .3566 .47236 .35186 .46449 .34304 Mtetra
.46449 .34304 .47236 .35186 .48627 .34709 .47845 .33823 Mtetra
.47845 .33823 .48627 .34709 .50025 .3423 .49247 .3334 Mtetra
.49247 .3334 .50025 .3423 .5143 .33749 .50657 .32854 Mtetra
.50657 .32854 .5143 .33749 .52842 .33265 .52074 .32366 Mtetra
.52074 .32366 .52842 .33265 .54262 .32779 .53498 .31875 Mtetra
.53498 .31875 .54262 .32779 .55689 .3229 .5493 .31381 Mtetra
.629 .161 0 r
.5493 .31381 .55689 .3229 .57161 .34331 .56401 .33422 Mtetra
.648 .76 .931 r
.56401 .33422 .57161 .34331 .58614 .3384 .5786 .32926 Mtetra
.5786 .32926 .58614 .3384 .60075 .33346 .59326 .32428 Mtetra
.59326 .32428 .60075 .33346 .61544 .3285 .608 .31926 Mtetra
.608 .31926 .61544 .3285 .63021 .32351 .62282 .31423 Mtetra
.62282 .31423 .63021 .32351 .64505 .31849 .63772 .30916 Mtetra
.63772 .30916 .64505 .31849 .65998 .31345 .65269 .30407 Mtetra
.65269 .30407 .65998 .31345 .67498 .30838 .66775 .29895 Mtetra
.66775 .29895 .67498 .30838 .69006 .30328 .68289 .2938 Mtetra
.68289 .2938 .69006 .30328 .70523 .29816 .69811 .28862 Mtetra
.69811 .28862 .70523 .29816 .72047 .293 .71341 .28342 Mtetra
.71341 .28342 .72047 .293 .7358 .28782 .7288 .27819 Mtetra
.7288 .27819 .7358 .28782 .75121 .28262 .74427 .27293 Mtetra
.664 .741 .908 r
.08013 .30111 .08867 .30906 .10008 .30476 .09156 .29677 Mtetra
.09156 .29677 .10008 .30476 .11153 .30044 .10305 .29242 Mtetra
.10305 .29242 .11153 .30044 .12304 .29611 .11459 .28804 Mtetra
.11459 .28804 .12304 .29611 .1346 .29175 .12618 .28365 Mtetra
.12618 .28365 .1346 .29175 .14622 .28737 .13782 .27924 Mtetra
.13782 .27924 .14622 .28737 .15788 .28297 .14952 .2748 Mtetra
.14952 .2748 .15788 .28297 .1696 .27855 .16127 .27035 Mtetra
.16127 .27035 .1696 .27855 .18138 .27412 .17307 .26587 Mtetra
.17307 .26587 .18138 .27412 .1932 .26966 .18493 .26137 Mtetra
.18493 .26137 .1932 .26966 .20509 .26518 .19684 .25686 Mtetra
.19684 .25686 .20509 .26518 .21702 .26068 .20881 .25232 Mtetra
.20881 .25232 .21702 .26068 .22901 .25616 .22084 .24776 Mtetra
.22084 .24776 .22901 .25616 .24106 .25162 .23292 .24318 Mtetra
.23292 .24318 .24106 .25162 .25317 .24706 .24505 .23858 Mtetra
.24505 .23858 .25317 .24706 .26532 .24247 .25725 .23396 Mtetra
.25725 .23396 .26532 .24247 .27754 .23787 .2695 .22931 Mtetra
.2695 .22931 .27754 .23787 .28981 .23324 .2818 .22464 Mtetra
.2818 .22464 .28981 .23324 .30215 .22859 .29417 .21996 Mtetra
.29417 .21996 .30215 .22859 .31453 .22393 .30659 .21525 Mtetra
.30659 .21525 .31453 .22393 .32698 .21923 .31908 .21051 Mtetra
.31908 .21051 .32698 .21923 .33949 .21452 .33162 .20576 Mtetra
.33162 .20576 .33949 .21452 .35205 .20978 .34422 .20098 Mtetra
.34422 .20098 .35205 .20978 .36468 .20502 .35688 .19618 Mtetra
.35688 .19618 .36468 .20502 .37736 .20024 .3696 .19136 Mtetra
.3696 .19136 .37736 .20024 .39011 .19544 .38239 .18651 Mtetra
.966 .658 .389 r
.38239 .18651 .39011 .19544 .39578 .36672 .38762 .35805 Mtetra
.65 .758 .928 r
.38762 .35805 .39578 .36672 .40939 .36204 .40126 .35332 Mtetra
.40126 .35332 .40939 .36204 .42306 .35732 .41498 .34856 Mtetra
.41498 .34856 .42306 .35732 .4368 .35259 .42876 .34378 Mtetra
.42876 .34378 .4368 .35259 .45061 .34783 .44262 .33898 Mtetra
.44262 .33898 .45061 .34783 .46449 .34304 .45655 .33415 Mtetra
.45655 .33415 .46449 .34304 .47845 .33823 .47055 .32929 Mtetra
.47055 .32929 .47845 .33823 .49247 .3334 .48462 .32441 Mtetra
.48462 .32441 .49247 .3334 .50657 .32854 .49876 .31951 Mtetra
.49876 .31951 .50657 .32854 .52074 .32366 .51298 .31457 Mtetra
.51298 .31457 .52074 .32366 .53498 .31875 .52727 .30962 Mtetra
.52727 .30962 .53498 .31875 .5493 .31381 .54164 .30464 Mtetra
.629 .161 0 r
.54164 .30464 .5493 .31381 .56401 .33422 .55634 .32505 Mtetra
.648 .76 .931 r
.55634 .32505 .56401 .33422 .5786 .32926 .57097 .32004 Mtetra
.57097 .32004 .5786 .32926 .59326 .32428 .58569 .315 Mtetra
.58569 .315 .59326 .32428 .608 .31926 .60048 .30994 Mtetra
.60048 .30994 .608 .31926 .62282 .31423 .61535 .30485 Mtetra
.61535 .30485 .62282 .31423 .63772 .30916 .63031 .29974 Mtetra
.63031 .29974 .63772 .30916 .65269 .30407 .64534 .29459 Mtetra
.64534 .29459 .65269 .30407 .66775 .29895 .66045 .28942 Mtetra
.66045 .28942 .66775 .29895 .68289 .2938 .67564 .28422 Mtetra
.67564 .28422 .68289 .2938 .69811 .28862 .69092 .27899 Mtetra
.69092 .27899 .69811 .28862 .71341 .28342 .70628 .27374 Mtetra
.70628 .27374 .71341 .28342 .7288 .27819 .72172 .26845 Mtetra
.72172 .26845 .7288 .27819 .74427 .27293 .73725 .26314 Mtetra
.664 .741 .908 r
.07152 .29309 .08013 .30111 .09156 .29677 .08298 .28872 Mtetra
.08298 .28872 .09156 .29677 .10305 .29242 .09449 .28433 Mtetra
.09449 .28433 .10305 .29242 .11459 .28804 .10606 .27992 Mtetra
.10606 .27992 .11459 .28804 .12618 .28365 .11768 .27548 Mtetra
.11768 .27548 .12618 .28365 .13782 .27924 .12935 .27103 Mtetra
.12935 .27103 .13782 .27924 .14952 .2748 .14108 .26656 Mtetra
.14108 .26656 .14952 .2748 .16127 .27035 .15286 .26207 Mtetra
.15286 .26207 .16127 .27035 .17307 .26587 .1647 .25755 Mtetra
.1647 .25755 .17307 .26587 .18493 .26137 .17659 .25302 Mtetra
.17659 .25302 .18493 .26137 .19684 .25686 .18853 .24846 Mtetra
.18853 .24846 .19684 .25686 .20881 .25232 .20053 .24389 Mtetra
.20053 .24389 .20881 .25232 .22084 .24776 .21259 .23929 Mtetra
.21259 .23929 .22084 .24776 .23292 .24318 .2247 .23467 Mtetra
.2247 .23467 .23292 .24318 .24505 .23858 .23687 .23003 Mtetra
.23687 .23003 .24505 .23858 .25725 .23396 .2491 .22536 Mtetra
.2491 .22536 .25725 .23396 .2695 .22931 .26138 .22068 Mtetra
.26138 .22068 .2695 .22931 .2818 .22464 .27373 .21597 Mtetra
.27373 .21597 .2818 .22464 .29417 .21996 .28613 .21124 Mtetra
.28613 .21124 .29417 .21996 .30659 .21525 .29858 .20649 Mtetra
.29858 .20649 .30659 .21525 .31908 .21051 .3111 .20172 Mtetra
.3111 .20172 .31908 .21051 .33162 .20576 .32368 .19692 Mtetra
.32368 .19692 .33162 .20576 .34422 .20098 .33632 .1921 Mtetra
.33632 .1921 .34422 .20098 .35688 .19618 .34902 .18726 Mtetra
.34902 .18726 .35688 .19618 .3696 .19136 .36178 .18239 Mtetra
.36178 .18239 .3696 .19136 .38239 .18651 .3746 .1775 Mtetra
.966 .658 .389 r
.3746 .1775 .38239 .18651 .38762 .35805 .37937 .34929 Mtetra
.65 .758 .928 r
.37937 .34929 .38762 .35805 .40126 .35332 .39306 .34452 Mtetra
.39306 .34452 .40126 .35332 .41498 .34856 .40682 .33972 Mtetra
.40682 .33972 .41498 .34856 .42876 .34378 .42065 .33489 Mtetra
.42065 .33489 .42876 .34378 .44262 .33898 .43455 .33004 Mtetra
.43455 .33004 .44262 .33898 .45655 .33415 .44853 .32516 Mtetra
.44853 .32516 .45655 .33415 .47055 .32929 .46257 .32026 Mtetra
.46257 .32026 .47055 .32929 .48462 .32441 .47669 .31533 Mtetra
.47669 .31533 .48462 .32441 .49876 .31951 .49088 .31038 Mtetra
.49088 .31038 .49876 .31951 .51298 .31457 .50515 .3054 Mtetra
.50515 .3054 .51298 .31457 .52727 .30962 .51949 .3004 Mtetra
.51949 .3004 .52727 .30962 .54164 .30464 .53391 .29537 Mtetra
.629 .161 0 r
.53391 .29537 .54164 .30464 .55634 .32505 .54859 .31578 Mtetra
.648 .76 .931 r
.54859 .31578 .55634 .32505 .57097 .32004 .56328 .31072 Mtetra
.56328 .31072 .57097 .32004 .58569 .315 .57805 .30564 Mtetra
.57805 .30564 .58569 .315 .60048 .30994 .59289 .30052 Mtetra
.59289 .30052 .60048 .30994 .61535 .30485 .60782 .29538 Mtetra
.60782 .29538 .61535 .30485 .63031 .29974 .62282 .29022 Mtetra
.62282 .29022 .63031 .29974 .64534 .29459 .63791 .28502 Mtetra
.63791 .28502 .64534 .29459 .66045 .28942 .65308 .2798 Mtetra
.65308 .2798 .66045 .28942 .67564 .28422 .66833 .27455 Mtetra
.66833 .27455 .67564 .28422 .69092 .27899 .68366 .26927 Mtetra
.68366 .26927 .69092 .27899 .70628 .27374 .69908 .26396 Mtetra
.69908 .26396 .70628 .27374 .72172 .26845 .71458 .25862 Mtetra
.71458 .25862 .72172 .26845 .73725 .26314 .73016 .25326 Mtetra
.664 .741 .908 r
.06283 .285 .07152 .29309 .08298 .28872 .07432 .2806 Mtetra
.07432 .2806 .08298 .28872 .09449 .28433 .08587 .27617 Mtetra
.08587 .27617 .09449 .28433 .10606 .27992 .09746 .27172 Mtetra
.09746 .27172 .10606 .27992 .11768 .27548 .10911 .26725 Mtetra
.10911 .26725 .11768 .27548 .12935 .27103 .12082 .26276 Mtetra
.12082 .26276 .12935 .27103 .14108 .26656 .13257 .25825 Mtetra
.13257 .25825 .14108 .26656 .15286 .26207 .14438 .25372 Mtetra
.14438 .25372 .15286 .26207 .1647 .25755 .15625 .24917 Mtetra
.15625 .24917 .1647 .25755 .17659 .25302 .16817 .24459 Mtetra
.16817 .24459 .17659 .25302 .18853 .24846 .18015 .24 Mtetra
.18015 .24 .18853 .24846 .20053 .24389 .19218 .23538 Mtetra
.19218 .23538 .20053 .24389 .21259 .23929 .20427 .23074 Mtetra
.20427 .23074 .21259 .23929 .2247 .23467 .21642 .22608 Mtetra
.21642 .22608 .2247 .23467 .23687 .23003 .22862 .2214 Mtetra
.22862 .2214 .23687 .23003 .2491 .22536 .24088 .2167 Mtetra
.24088 .2167 .2491 .22536 .26138 .22068 .2532 .21197 Mtetra
.2532 .21197 .26138 .22068 .27373 .21597 .26558 .20722 Mtetra
.26558 .20722 .27373 .21597 .28613 .21124 .27801 .20245 Mtetra
.27801 .20245 .28613 .21124 .29858 .20649 .29051 .19766 Mtetra
.29051 .19766 .29858 .20649 .3111 .20172 .30306 .19284 Mtetra
.30306 .19284 .3111 .20172 .32368 .19692 .31567 .188 Mtetra
.31567 .188 .32368 .19692 .33632 .1921 .32835 .18314 Mtetra
.32835 .18314 .33632 .1921 .34902 .18726 .34108 .17826 Mtetra
.34108 .17826 .34902 .18726 .36178 .18239 .35388 .17335 Mtetra
.35388 .17335 .36178 .18239 .3746 .1775 .36674 .16841 Mtetra
.966 .658 .389 r
.36674 .16841 .3746 .1775 .37937 .34929 .37105 .34046 Mtetra
.65 .758 .928 r
.37105 .34046 .37937 .34929 .39306 .34452 .38478 .33563 Mtetra
.38478 .33563 .39306 .34452 .40682 .33972 .39859 .33079 Mtetra
.39859 .33079 .40682 .33972 .42065 .33489 .41246 .32591 Mtetra
.41246 .32591 .42065 .33489 .43455 .33004 .42641 .32102 Mtetra
.42641 .32102 .43455 .33004 .44853 .32516 .44043 .31609 Mtetra
.44043 .31609 .44853 .32516 .46257 .32026 .45452 .31115 Mtetra
.45452 .31115 .46257 .32026 .47669 .31533 .46869 .30617 Mtetra
.46869 .30617 .47669 .31533 .49088 .31038 .48293 .30117 Mtetra
.48293 .30117 .49088 .31038 .50515 .3054 .49724 .29614 Mtetra
.49724 .29614 .50515 .3054 .51949 .3004 .51163 .29109 Mtetra
.51163 .29109 .51949 .3004 .53391 .29537 .5261 .28601 Mtetra
.629 .161 0 r
.5261 .28601 .53391 .29537 .54859 .31578 .54077 .30642 Mtetra
.648 .76 .931 r
.54077 .30642 .54859 .31578 .56328 .31072 .55551 .30131 Mtetra
.55551 .30131 .56328 .31072 .57805 .30564 .57033 .29618 Mtetra
.57033 .29618 .57805 .30564 .59289 .30052 .58522 .29101 Mtetra
.58522 .29101 .59289 .30052 .60782 .29538 .6002 .28582 Mtetra
.6002 .28582 .60782 .29538 .62282 .29022 .61526 .28061 Mtetra
.61526 .28061 .62282 .29022 .63791 .28502 .6304 .27536 Mtetra
.6304 .27536 .63791 .28502 .65308 .2798 .64563 .27008 Mtetra
.64563 .27008 .65308 .2798 .66833 .27455 .66093 .26478 Mtetra
.66093 .26478 .66833 .27455 .68366 .26927 .67632 .25945 Mtetra
.67632 .25945 .68366 .26927 .69908 .26396 .6918 .25408 Mtetra
.6918 .25408 .69908 .26396 .71458 .25862 .70736 .24869 Mtetra
.70736 .24869 .71458 .25862 .73016 .25326 .723 .24327 Mtetra
.664 .741 .908 r
.05408 .27685 .06283 .285 .07432 .2806 .06559 .2724 Mtetra
.06559 .2724 .07432 .2806 .08587 .27617 .07717 .26794 Mtetra
.07717 .26794 .08587 .27617 .09746 .27172 .08879 .26345 Mtetra
.08879 .26345 .09746 .27172 .10911 .26725 .10047 .25894 Mtetra
.10047 .25894 .10911 .26725 .12082 .26276 .1122 .25442 Mtetra
.1122 .25442 .12082 .26276 .13257 .25825 .12399 .24987 Mtetra
.12399 .24987 .13257 .25825 .14438 .25372 .13583 .2453 Mtetra
.13583 .2453 .14438 .25372 .15625 .24917 .14773 .24071 Mtetra
.14773 .24071 .15625 .24917 .16817 .24459 .15968 .23609 Mtetra
.15968 .23609 .16817 .24459 .18015 .24 .17169 .23146 Mtetra
.17169 .23146 .18015 .24 .19218 .23538 .18376 .2268 Mtetra
.18376 .2268 .19218 .23538 .20427 .23074 .19588 .22212 Mtetra
.19588 .22212 .20427 .23074 .21642 .22608 .20806 .21742 Mtetra
.20806 .21742 .21642 .22608 .22862 .2214 .2203 .2127 Mtetra
.2203 .2127 .22862 .2214 .24088 .2167 .23259 .20796 Mtetra
.23259 .20796 .24088 .2167 .2532 .21197 .24494 .20319 Mtetra
.24494 .20319 .2532 .21197 .26558 .20722 .25735 .1984 Mtetra
.25735 .1984 .26558 .20722 .27801 .20245 .26982 .19359 Mtetra
.26982 .19359 .27801 .20245 .29051 .19766 .28235 .18875 Mtetra
.28235 .18875 .29051 .19766 .30306 .19284 .29494 .18389 Mtetra
.29494 .18389 .30306 .19284 .31567 .188 .30759 .17901 Mtetra
.30759 .17901 .31567 .188 .32835 .18314 .32031 .1741 Mtetra
.32031 .1741 .32835 .18314 .34108 .17826 .33308 .16917 Mtetra
.33308 .16917 .34108 .17826 .35388 .17335 .34591 .16422 Mtetra
.34591 .16422 .35388 .17335 .36674 .16841 .35881 .15924 Mtetra
.966 .658 .389 r
.35881 .15924 .36674 .16841 .37105 .34046 .36265 .33153 Mtetra
.65 .758 .928 r
.36265 .33153 .37105 .34046 .38478 .33563 .37643 .32667 Mtetra
.37643 .32667 .38478 .33563 .39859 .33079 .39028 .32177 Mtetra
.39028 .32177 .39859 .33079 .41246 .32591 .40419 .31685 Mtetra
.40419 .31685 .41246 .32591 .42641 .32102 .41819 .31191 Mtetra
.41819 .31191 .42641 .32102 .44043 .31609 .43225 .30694 Mtetra
.43225 .30694 .44043 .31609 .45452 .31115 .44639 .30194 Mtetra
.44639 .30194 .45452 .31115 .46869 .30617 .4606 .29692 Mtetra
.4606 .29692 .46869 .30617 .48293 .30117 .47489 .29187 Mtetra
.47489 .29187 .48293 .30117 .49724 .29614 .48925 .2868 Mtetra
.48925 .2868 .49724 .29614 .51163 .29109 .50369 .28169 Mtetra
.50369 .28169 .51163 .29109 .5261 .28601 .51821 .27656 Mtetra
.629 .161 0 r
.51821 .27656 .5261 .28601 .54077 .30642 .53287 .29697 Mtetra
.648 .76 .931 r
.53287 .29697 .54077 .30642 .55551 .30131 .54766 .29181 Mtetra
.54766 .29181 .55551 .30131 .57033 .29618 .56253 .28662 Mtetra
.56253 .28662 .57033 .29618 .58522 .29101 .57748 .28141 Mtetra
.57748 .28141 .58522 .29101 .6002 .28582 .59251 .27617 Mtetra
.59251 .27617 .6002 .28582 .61526 .28061 .60763 .2709 Mtetra
.60763 .2709 .61526 .28061 .6304 .27536 .62283 .2656 Mtetra
.62283 .2656 .6304 .27536 .64563 .27008 .6381 .26027 Mtetra
.6381 .26027 .64563 .27008 .66093 .26478 .65347 .25491 Mtetra
.65347 .25491 .66093 .26478 .67632 .25945 .66892 .24952 Mtetra
.66892 .24952 .67632 .25945 .6918 .25408 .68445 .24411 Mtetra
.68445 .24411 .6918 .25408 .70736 .24869 .70007 .23866 Mtetra
.70007 .23866 .70736 .24869 .723 .24327 .71577 .23318 Mtetra
.664 .741 .908 r
.04524 .26863 .05408 .27685 .06559 .2724 .05679 .26414 Mtetra
.05679 .26414 .06559 .2724 .07717 .26794 .06839 .25964 Mtetra
.06839 .25964 .07717 .26794 .08879 .26345 .08005 .25511 Mtetra
.08005 .25511 .08879 .26345 .10047 .25894 .09176 .25057 Mtetra
.09176 .25057 .10047 .25894 .1122 .25442 .10352 .246 Mtetra
.10352 .246 .1122 .25442 .12399 .24987 .11534 .24141 Mtetra
.11534 .24141 .12399 .24987 .13583 .2453 .12721 .2368 Mtetra
.12721 .2368 .13583 .2453 .14773 .24071 .13914 .23217 Mtetra
.13914 .23217 .14773 .24071 .15968 .23609 .15112 .22752 Mtetra
.15112 .22752 .15968 .23609 .17169 .23146 .16316 .22284 Mtetra
.16316 .22284 .17169 .23146 .18376 .2268 .17526 .21815 Mtetra
.17526 .21815 .18376 .2268 .19588 .22212 .18742 .21343 Mtetra
.18742 .21343 .19588 .22212 .20806 .21742 .19963 .20869 Mtetra
.19963 .20869 .20806 .21742 .2203 .2127 .2119 .20392 Mtetra
.2119 .20392 .2203 .2127 .23259 .20796 .22423 .19914 Mtetra
.22423 .19914 .23259 .20796 .24494 .20319 .23661 .19433 Mtetra
.23661 .19433 .24494 .20319 .25735 .1984 .24906 .1895 Mtetra
.24906 .1895 .25735 .1984 .26982 .19359 .26157 .18464 Mtetra
.26157 .18464 .26982 .19359 .28235 .18875 .27413 .17976 Mtetra
.27413 .17976 .28235 .18875 .29494 .18389 .28676 .17486 Mtetra
.28676 .17486 .29494 .18389 .30759 .17901 .29944 .16993 Mtetra
.29944 .16993 .30759 .17901 .32031 .1741 .31219 .16498 Mtetra
.31219 .16498 .32031 .1741 .33308 .16917 .325 .16001 Mtetra
.325 .16001 .33308 .16917 .34591 .16422 .33788 .15501 Mtetra
.33788 .15501 .34591 .16422 .35881 .15924 .35081 .14999 Mtetra
.966 .658 .389 r
.35081 .14999 .35881 .15924 .36265 .33153 .35417 .32253 Mtetra
.65 .758 .928 r
.35417 .32253 .36265 .33153 .37643 .32667 .36799 .31761 Mtetra
.36799 .31761 .37643 .32667 .39028 .32177 .38188 .31267 Mtetra
.38188 .31267 .39028 .32177 .40419 .31685 .39585 .3077 Mtetra
.39585 .3077 .40419 .31685 .41819 .31191 .40989 .30271 Mtetra
.40989 .30271 .41819 .31191 .43225 .30694 .424 .29769 Mtetra
.424 .29769 .43225 .30694 .44639 .30194 .43818 .29265 Mtetra
.43818 .29265 .44639 .30194 .4606 .29692 .45244 .28758 Mtetra
.45244 .28758 .4606 .29692 .47489 .29187 .46678 .28248 Mtetra
.46678 .28248 .47489 .29187 .48925 .2868 .48119 .27735 Mtetra
.48119 .27735 .48925 .2868 .50369 .28169 .49568 .2722 Mtetra
.49568 .2722 .50369 .28169 .51821 .27656 .51024 .26702 Mtetra
.629 .161 0 r
.51024 .26702 .51821 .27656 .53287 .29697 .52489 .28742 Mtetra
.648 .76 .931 r
.52489 .28742 .53287 .29697 .54766 .29181 .53973 .28221 Mtetra
.53973 .28221 .54766 .29181 .56253 .28662 .55466 .27698 Mtetra
.55466 .27698 .56253 .28662 .57748 .28141 .56966 .27171 Mtetra
.56966 .27171 .57748 .28141 .59251 .27617 .58475 .26641 Mtetra
.58475 .26641 .59251 .27617 .60763 .2709 .59992 .26109 Mtetra
.59992 .26109 .60763 .2709 .62283 .2656 .61517 .25574 Mtetra
.61517 .25574 .62283 .2656 .6381 .26027 .63051 .25035 Mtetra
.63051 .25035 .6381 .26027 .65347 .25491 .64593 .24494 Mtetra
.64593 .24494 .65347 .25491 .66892 .24952 .66143 .2395 Mtetra
.66143 .2395 .66892 .24952 .68445 .24411 .67702 .23403 Mtetra
.67702 .23403 .68445 .24411 .70007 .23866 .6927 .22853 Mtetra
.6927 .22853 .70007 .23866 .71577 .23318 .70847 .22299 Mtetra
.664 .741 .908 r
.03634 .26033 .04524 .26863 .05679 .26414 .04791 .25581 Mtetra
.04791 .25581 .05679 .26414 .06839 .25964 .05954 .25127 Mtetra
.05954 .25127 .06839 .25964 .08005 .25511 .07123 .24671 Mtetra
.07123 .24671 .08005 .25511 .09176 .25057 .08297 .24212 Mtetra
.08297 .24212 .09176 .25057 .10352 .246 .09476 .23751 Mtetra
.09476 .23751 .10352 .246 .11534 .24141 .10661 .23289 Mtetra
.10661 .23289 .11534 .24141 .12721 .2368 .11851 .22824 Mtetra
.11851 .22824 .12721 .2368 .13914 .23217 .13047 .22356 Mtetra
.13047 .22356 .13914 .23217 .15112 .22752 .14249 .21887 Mtetra
.14249 .21887 .15112 .22752 .16316 .22284 .15456 .21416 Mtetra
.15456 .21416 .16316 .22284 .17526 .21815 .16669 .20942 Mtetra
.16669 .20942 .17526 .21815 .18742 .21343 .17888 .20466 Mtetra
.17888 .20466 .18742 .21343 .19963 .20869 .19112 .19987 Mtetra
.19112 .19987 .19963 .20869 .2119 .20392 .20343 .19507 Mtetra
.20343 .19507 .2119 .20392 .22423 .19914 .21579 .19024 Mtetra
.21579 .19024 .22423 .19914 .23661 .19433 .22821 .18539 Mtetra
.22821 .18539 .23661 .19433 .24906 .1895 .24069 .18051 Mtetra
.24069 .18051 .24906 .1895 .26157 .18464 .25323 .17561 Mtetra
.25323 .17561 .26157 .18464 .27413 .17976 .26583 .17069 Mtetra
.26583 .17069 .27413 .17976 .28676 .17486 .2785 .16575 Mtetra
.2785 .16575 .28676 .17486 .29944 .16993 .29122 .16078 Mtetra
.29122 .16078 .29944 .16993 .31219 .16498 .30401 .15578 Mtetra
.30401 .15578 .31219 .16498 .325 .16001 .31685 .15076 Mtetra
.31685 .15076 .325 .16001 .33788 .15501 .32977 .14572 Mtetra
.32977 .14572 .33788 .15501 .35081 .14999 .34274 .14065 Mtetra
.966 .658 .389 r
.34274 .14065 .35081 .14999 .35417 .32253 .34561 .31343 Mtetra
.65 .758 .928 r
.34561 .31343 .35417 .32253 .36799 .31761 .35947 .30847 Mtetra
.35947 .30847 .36799 .31761 .38188 .31267 .37341 .30348 Mtetra
.37341 .30348 .38188 .31267 .39585 .3077 .38742 .29847 Mtetra
.38742 .29847 .39585 .3077 .40989 .30271 .4015 .29343 Mtetra
.4015 .29343 .40989 .30271 .424 .29769 .41566 .28836 Mtetra
.41566 .28836 .424 .29769 .43818 .29265 .42989 .28327 Mtetra
.42989 .28327 .43818 .29265 .45244 .28758 .4442 .27814 Mtetra
.4442 .27814 .45244 .28758 .46678 .28248 .45859 .273 Mtetra
.45859 .273 .46678 .28248 .48119 .27735 .47305 .26782 Mtetra
.47305 .26782 .48119 .27735 .49568 .2722 .48759 .26262 Mtetra
.48759 .26262 .49568 .2722 .51024 .26702 .5022 .25739 Mtetra
.629 .161 0 r
.5022 .25739 .51024 .26702 .52489 .28742 .51683 .27778 Mtetra
.648 .76 .931 r
.51683 .27778 .52489 .28742 .53973 .28221 .53172 .27252 Mtetra
.53172 .27252 .53973 .28221 .55466 .27698 .5467 .26723 Mtetra
.5467 .26723 .55466 .27698 .56966 .27171 .56176 .26191 Mtetra
.56176 .26191 .56966 .27171 .58475 .26641 .5769 .25656 Mtetra
.5769 .25656 .58475 .26641 .59992 .26109 .59213 .25118 Mtetra
.59213 .25118 .59992 .26109 .61517 .25574 .60744 .24578 Mtetra
.60744 .24578 .61517 .25574 .63051 .25035 .62283 .24034 Mtetra
.62283 .24034 .63051 .25035 .64593 .24494 .63831 .23487 Mtetra
.63831 .23487 .64593 .24494 .66143 .2395 .65387 .22937 Mtetra
.65387 .22937 .66143 .2395 .67702 .23403 .66952 .22385 Mtetra
.66952 .22385 .67702 .23403 .6927 .22853 .68526 .21829 Mtetra
.68526 .21829 .6927 .22853 .70847 .22299 .70108 .2127 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 154.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000VR000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Q@3oool2o`000<@0oooo0_l0
00130?ooo`00PP3oool3o`0000030?ooool00000oooo0<00oooo0ol000000`3ooooo00000?ooo`12
0?ooo`00P03oool2o`0000<0oooo00<0ZKgXo`000?l00000_P3oool2o`0000@0oooo0_l000120?oo
o`00O@3oool3o`000080oooo102Y_NP00ol00000ooooo`00002j0?ooo`?o00001P3oool00ol00000
ooooo`0000110?ooo`00NP3oool3o`0000<0oooo1P2Y_NP00ol00000ZKgXo`00002h0?ooo`;o0000
2@3oool00ol00000ooooo`0000110?ooo`00N03oool2o`0000<0oooo2@2Y_NP01?l00000ZKgX0:Vm
j?l0002d0?ooo`?o00002`3oool01?l00000oooo0?ooool000100?ooo`00M@3oool3o`000080oooo
302Y_NP01Ol00000ZKgX0:Vmj02Y_NSo00000;00oooo0ol0000>0?ooo`05o`00003oool0oooo0?oo
ool00000?`3oool007<0oooo0_l000030?ooo`h0ZKgX00Go00000:Vmj02Y_NP0ZKgXo`00002^0?oo
o`;o00004@3oool01Ol00000oooo0?ooo`3ooooo000003l0oooo001`0?ooo`?o00000P3ooolA0:Vm
j003o`00002Y_NP0ZKgX0080ZKgX00?o00000?ooo`3oool0Z03oool3o`0001@0oooo00Go00000?oo
o`3oool0ooooo`00000n0?ooo`00KP3oool2o`0000<0oooo4`2Y_NP00ol00000ZKgX0:Vmj0020:Vm
j0030?ooool00000oooo0:H0oooo0_l0000G0?ooo`03o`00003oool0oooo0080oooo00?o00000?oo
o`3oool0>`3oool006/0oooo0ol000020?oooaH0ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00ol00000
oooo0?ooo`2R0?ooo`?o00006@3oool00ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo03/0
oooo001X0?ooo`?o00000`3ooolH0:Vmj003o`00002Y_NP0ZKgX00<0ZKgX00<0ooooo`00003oool0
X03oool2o`0001`0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`0j0?ooo`00IP3o
ool2o`0000<0oooo702Y_NP00ol00000ZKgX0:Vmj0030:Vmj003o`00003oool0oooo09`0oooo0ol0
000N0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0>@3oool006<0oooo0ol00002
0?oooal0ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00`3ooooo00000?ooo`2J0?ooo`;o00008@3oool0
0ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo03T0oooo001Q0?ooo`;o00000`3ooolQ0:Vm
j003o`00002Y_NP0ZKgX00@0ZKgX00<0ooooo`00003oool0UP3oool3o`0002<0oooo00?o00000?oo
o`3oool01@3oool00ol00000oooo0?ooo`0h0?ooo`00GP3oool3o`000080oooo902Y_NP00ol00000
ZKgX0:Vmj0050:Vmj003o`00003oool0oooo09<0oooo0_l0000V0?ooo`03o`00003oool0oooo00H0
oooo00?o00000?ooo`3oool0=`3oool005`0oooo0_l000030?ooobH0ZKgX00?o00000:Vmj02Y_NP0
1P2Y_NP00ol00000oooo0?ooo`2?0?ooo`?o0000:03oool00ol00000oooo0?ooo`060?ooo`03o`00
003oool0oooo03L0oooo001I0?ooo`?o00000`3ooolX0:Vmj003o`00002Y_NP0ZKgX00L0ZKgX00?o
00000?ooo`3oool0R`3oool3o`0002/0oooo00?o00000?ooo`3oool01`3oool00ol00000oooo0?oo
o`0f0?ooo`00E`3oool2o`0000<0oooo:`2Y_NP00ol00000ZKgX0:Vmj0070:Vmj003o`00003oool0
oooo08T0oooo0_l0000^0?ooo`03o`00003oool0oooo00P0oooo00?o00000?ooo`3oool0=@3oool0
05@0oooo0ol000030?ooobd0ZKgX00?o00000:Vmj02Y_NP0202Y_NP00ol00000oooo0?ooo`250?oo
o`?o0000<03oool00ol00000oooo0?ooo`080?ooo`03o`00003oool0oooo03D0oooo001A0?ooo`?o
000000<0oooo0:Vmj02Y_NP0<02Y_NP00ol00000ZKgX0:Vmj0080:Vmj0030?ooool00000oooo08<0
oooo0_l0000c0?ooo`03o`00003oool0oooo00T0oooo00?o00000?ooo`3oool0=03oool004l0oooo
0_l000000`3oool0ZKgX0:Vmj00c0:Vmj003o`00002Y_NP0ZKgX00T0ZKgX00?o00000?ooo`3oool0
O`3oool3o`0003D0oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0c0?ooo`00C03o
ool3o`0000030?ooo`2Y_NP0ZKgX03D0ZKgX00?o00000:Vmj02Y_NP02P2Y_NP00ol00000oooo0?oo
o`1l0?ooo`;o0000>03oool00ol00000oooo0?ooo`0:0?ooo`03o`00003oool0oooo03<0oooo001:
0?ooo`;o00000P3oooli0:Vmj003o`00002Y_NP0ZKgX00X0ZKgX00<0ooooo`00003oool0N@3oool3
o`0003/0oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0b0?ooo`00A`3oool3o`00
00030?ooo`2Y_NP0ZKgX03X0ZKgX00?o00000:Vmj02Y_NP02`2Y_NP00ol00000oooo0?ooo`1f0?oo
o`;o0000?P3oool00ol00000oooo0?ooo`0;0?ooo`03o`00003oool0oooo0340oooo00150?ooo`;o
00000`3ooolm0:Vmj003o`00002Y_NP0ZKgX00/0ZKgX00<0ooooo`00003oool0L`3oool3o`000400
oooo00?o00000?ooo`3oool02`3oool00ol00000oooo0?ooo`0a0?ooo`00@P3oool3o`0000D0oooo
00<0mKR80:Vmj02Y_NP0>P2Y_NP00ol00000ZKgX0:Vmj00<0:Vmj0030?ooool00000oooo0700oooo
0_l000020?ooo`03ojVmj03oool0oooo03h0oooo00?o00000?ooo`3oool0303oool00ol00000oooo
0?ooo`0`0?ooo`00?`3oool3o`0000P0oooo0`3e^8Pj0:Vmj003o`00002Y_NP0ZKgX00d0ZKgX00?o
00000?ooo`3oool0K03oool3o`0000030?oooonY_NSoZKgX00;oZKgX00?omjQS0?ooo`3oool0?@3o
ool00ol00000oooo0?ooo`0=0?ooo`03o`00003oool0oooo02l0oooo000m0?ooo`;o00002P3oool4
0?FhR3X0ZKgX00?o00000:Vmj02Y_NP03P2Y_NP00ol00000oooo0?ooo`1Y0?ooo`;o00000P3oool6
ojVmj0?omjQS?@3oool00ol00000oooo0?ooo`0=0?ooo`03o`00003oool0oooo02l0oooo000j0?oo
o`?o0000303oool50?FhR3T0ZKgX00?o00000:Vmj02Y_NP03`2Y_NP00ol00000oooo0?ooo`1U0?oo
o`?o00000P3oool8ojVmj0?omjQS?@3oool00ol00000oooo0?ooo`0>0?ooo`03o`00003oool0oooo
02h0oooo000h0?ooo`;o00003`3oool60?FhR3P0ZKgX00?o00000:Vmj02Y_NP03`2Y_NP00ol00000
oooo0?ooo`1R0?ooo`?o00000P3oool;ojVmj0ComjQS?03oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo02d0oooo000e0?ooo`?o00004@3oool70?FhR3L0ZKgX00?o00000:Vmj02Y_NP0
402Y_NP00ol00000oooo0?ooo`1O0?ooo`;o000000<0ooooojVmj?nY_NP03OnY_NP5ooNXHc/0oooo
00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0]0?ooo`00<`3oool2o`0001@0oooo203e
^8Pf0:Vmj003o`00002Y_NP0ZKgX0100ZKgX00?o00000?ooo`3oool0G03oool3o`0000030?oooonY
_NSoZKgX00ooZKgX1_ogZ6<j0?ooo`03o`00003oool0oooo0100oooo00?o00000?ooo`3oool0;03o
ool00300oooo0ol0000E0?ooo`T0mKR8=P2Y_NP00ol00000ZKgX0:Vmj00A0:Vmj003o`00003oool0
oooo05T0oooo0_l000000`3oooooZKgXojVmj00BojVmj0OomjQS>@3oool00ol00000oooo0?ooo`0A
0?ooo`03o`00003oool0oooo02/0oooo000]0?ooo`?o0000603oool:0?FhR3H0ZKgX00?o00000:Vm
j02Y_NP04@2Y_NP00ol00000oooo0?ooo`1E0?ooo`?o000000<0ooooojVmj?nY_NP05?nY_NP7ooNX
HcT0oooo00?o00000?ooo`3oool04@3oool00ol00000oooo0?ooo`0[0?ooo`00:`3oool2o`0001/0
oooo2`3e^8Pe0:Vmj003o`00002Y_NP0ZKgX0140ZKgX00?o00000?ooo`3oool0D`3oool2o`000080
oooo6?nY_NP8ooNXHcP0oooo00?o00000?ooo`3oool04P3oool00ol00000oooo0?ooo`0Z0?ooo`00
:03oool3o`0001d0oooo303e^8Pd0:Vmj003o`00002Y_NP0ZKgX0180ZKgX00?o00000?ooo`3oool0
C`3oool3o`000080oooo6_nY_NP9ooNXHcL0oooo00?o00000?ooo`3oool04`3oool00ol00000oooo
0?ooo`0Y0?ooo`009P3oool2o`000200oooo3@3e^8Pc0:Vmj003o`00002Y_NP0ZKgX01<0ZKgX00?o
00000?ooo`3oool0C03oool2o`000080oooo7OnY_NP:ooNXHcH0oooo00?o00000?ooo`3oool04`3o
ool00ol00000oooo0?ooo`0Y0?ooo`008`3oool3o`000240oooo3P3e^8Pc0:Vmj003o`00002Y_NP0
ZKgX01<0ZKgX00?o00000?ooo`3oool0B@3oool3o`00027oZKgX2oogZ6<f0?ooo`03o`00003oool0
oooo01<0oooo00?o00000?ooo`3oool0:03oool00240oooo0_l0000T0?ooo`l0mKR8<P2Y_NP00ol0
0000ZKgX0:Vmj00D0:Vmj003o`00003oool0oooo04H0oooo0_l000000`3oooooZKgXojVmj00QojVm
j0_omjQS=03oool2ojG2kP03o`00003oool0oooo01@0oooo00?o00000?ooo`3oool09`3oool001h0
oooo0ol0000V0?oooa40mKR8<02Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003o`00003oool0oooo0480
oooo0ol000000`3oooooZKgXojVmj00SojVmj0comjQS<03oool5ojG2kP03o`00003oool0oooo01@0
oooo00?o00000?ooo`3oool09`3oool001`0oooo0_l0000Y0?oooa40mKR8<02Y_NP00ol00000ZKgX
0:Vmj00E0:Vmj003o`00003oool0oooo03l0oooo0ol000020?ooobOoZKgX3_ogZ6</0?ooo`OoYL;^
00?o00000?ooo`3oool05@3oool00ol00000oooo0?ooo`0V0?ooo`006@3oool3o`0002/0oooo4P3e
^8P_0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o00000?ooo`3oool0?03oool2o`000080oooo:_nY
_NP>ooNXHbT0oooo2_nU`^h00ol0003oYL;^0?ooo`0E0?ooo`03o`00003oool0oooo02H0oooo000F
0?ooo`?o0000;@3ooolD0?FhR2h0ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ol00000oooo0?ooo`0h
0?ooo`?o0000;_nY_NP?ooNXHbD0oooo3OnU`^h00ol0003oYL;^0?ooo`0F0?ooo`03o`00003oool0
oooo02D0oooo000D0?ooo`;o0000<03ooolD0?FhR0030=RGS`2Y_NP0ZKgX02X0ZKgX0_l0000I0:Vm
j003o`00003oool0oooo03H0oooo0_l000000`3oooooZKgXojVmj00^ojVmj13omjQS8@3oool?ojG2
kP;o00000_nU`^hG0?ooo`03o`00003oool0oooo02@0oooo000A0?ooo`?o0000<@3oool30:O0ja80
mKR80P3HUhlX0:Vmj0?o000000<0ZKgXo`00002Y_NP06@2Y_NP00ol00000oooo0?ooo`0b0?ooo`?o
000000<0ooooojVmj?nY_NP0<?nY_NPAooNXHad0oooo3onU`^h3o`000003ojG2k_l0003oYL;^00?o
YL;^5@3oool00ol00000oooo0?ooo`0T0?ooo`00403oool2o`0002l0oooo1`2W`>/B0?FhR080f9N?
00<0m[J10:Vmj02Y_NP08P2Y_NP3o`0000D0ZKgX00?o00000:Vmj02Y_NP0602Y_NP00ol00000oooo
0?ooo`0`0?ooo`;o000000<0ooooojVmj?nY_NP0<_nY_NPBooNXHaX0oooo3_nU`^h3o`0000GoYL;^
00Co0000ojG2k_nU`^koYL;^5P3oool00ol00000oooo0?ooo`0S0?ooo`00403oool00ol00000oooo
o`00000[0?ooo`/0Yl3[4@3e^8P20=RGS`030?JfP@2Y_NP0ZKgX01l0ZKgX0ol000090:Vmj003o`00
002Y_NP0ZKgX01L0ZKgX00?o00000?ooo`3oool0<03oool00ol0003oZKgXojVmj00dojVmj1;omjQS
00?omZEL0?ooo`3oool01P3oool00onV`^goXBT00?ooo`0;0?ooo`koYL;^0ol00009ojG2kP04o`00
0?nU`^koYL;^ojG2kQH0oooo00?o00000?ooo`3oool08P3oool00100oooo00Co00000?ooo`3ooooo
0000:03oool>0:O0ja00mKR80P3HUhl20?JfPAd0ZKgX0ol0000=0:Vmj003o`00002Y_NP0ZKgX01L0
ZKgX00?o00000?ooo`3oool0;`3oool00ol0003oZKgXojVmj00dojVmj1;omjQS00?omZEL0?ooo`3o
ool0103oool4ojK2k@03oj4Y003oool0oooo00H0oooo3_nU`^h3o`0000goYL;^00?o0000ojG2k_nU
`^h05P3oool00ol00000oooo0?ooo`0R0?ooo`00403oool01Ol00000oooo0?ooo`3ooooo000002@0
oooo4P2W`>/?0?FhR080f9N?103f]X4H0:Vmj0?o0000402Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003
o`00003oool0oooo02l0oooo00?o00000?oooonY_NP0=?nY_NPBooNXH`;omZEL0P3oool8ojK2k@03
oj4Y003oool0oooo00<0oooo3OnU`^h3o`00013oYL;^00Co0000ojG2k_nU`^koYL;^5P3oool00ol0
0000oooo0?ooo`0Q0?ooo`003`3oool00ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo01l0
oooo5@2W`>/=0?FhR0<0f9N?103f]X4E0:Vmj0?o0000502Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003
o`00003oool0oooo02d0oooo00Co00000?ooo`3oool0oooo=?nY_NPBooNXH`;omZEL2onV`^d00onQ
:@00ooooojG2kP0<ojG2kP?o00005?nU`^h00ol0003oYL;^ojG2kP0G0?ooo`03o`00003oool0oooo
0200oooo000?0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0703ooolH0:O0j``0
mKR80`3HUhl50?JfPA80ZKgX0_l0000H0:Vmj003o`00002Y_NP0ZKgX01L0ZKgX00?o00000?ooo`3o
ool0;03oool00ol00000oooo0?ooo`020?oooc?oZKgX4OogZ6<?ojK2k@03oj4Y0?nU`^koYL;^00So
YL;^0ol0000HojG2kP03o`000?nU`^koYL;^01H0oooo00?o00000?ooo`3oool0803oool000l0oooo
00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`0H0?oooa`0Yl3[2`3e^8P20=RGS`L0m[J1
3P2Y_NP3o`0001/0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol00000oooo0?ooo`0/0?ooo`03o`00
003oool0oooo00<0oooo<_nY_NP>ooNXHa?oY/;]1onU`^h3o`0001_oYL;^00?o0000ojG2k_nU`^h0
0_nU`^hE0?ooo`03o`00003oool0oooo01l0oooo000?0?ooo`03o`00003oool0oooo00H0oooo00?o
00000?ooo`3oool04`3ooolQ0:O0j`X0mKR80P3HUhl70?JfP@/0ZKgX0ol0000N0:Vmj003o`00002Y
_NP0ZKgX01L0ZKgX00?o00000?ooo`3oool0:`3oool00ol00000oooo0?ooo`040?oooc7oZKgX3?og
Z6<FojK2k@CoYL;^0_l0000OojG2kP04o`000?nU`^koYL;^ojG2kQH0oooo00?o00000?ooo`3oool0
7P3oool000l0oooo00?o00000?ooo`3oool01`3oool00ol00000oooo0?ooo`0?0?ooobD0Yl3[2@3e
^8P20=RGS`P0m[J11`2Y_NP3o`000280ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ol00000oooo0?oo
o`0Z0?ooo`03o`00003oool0oooo00D0oooo<?nY_NP7ooNXHa_oY/;]00CoYL;^o`000?l0003o0000
8_nU`^h01?l0003oYL;^ojG2k_nU`^hE0?ooo`03o`00003oool0oooo01h0oooo000?0?ooo`03o`00
003oool0oooo00P0oooo00?o00000?ooo`3oool03@3oool00`3`^9@0Yl3[0:O0j`0T0:O0j`P0mKR8
0P3HUhl:0?JfP@80ZKgX0ol0000V0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o00000?ooo`3oool0
:P3oool00ol00000oooo0?ooo`070?ooobkoZKgX1?ogZ6<LojK2k@?o00009_nU`^h00ol0003oYL;^
ojG2kP0F0?ooo`03o`00003oool0oooo01d0oooo000?0?ooo`03o`00003oool0oooo00T0oooo00?o
00000?ooo`3oool0303oool20?2hU2H0Yl3[1`3e^8P20=RGS`T0m[J10ol0000Z0:Vmj003o`00002Y
_NP0ZKgX01H0ZKgX00?o00000?ooo`3oool0:03oool00ol00000oooo0?ooo`090?ooobgoZKgX0_og
Z6<KojK2k@?o00001?nV`^dUojG2kP04o`000?nU`^koYL;^ojG2kPh0oooo00?oQd^00?ooo`3oool0
1@3oool00ol00000oooo0?ooo`0L0?ooo`003P3oool00ol00000oooo0?ooo`0;0?ooo`03o`00003o
ool0oooo00/0oooo0`3`^9@U0:O0j`L0mKR80P3HUhl60?JfP@?o00000P3f]X4[0:Vmj003o`00002Y
_NP0ZKgX01L0ZKgX00?o00000?ooo`3oool09`3oool00ol00000oooo0?ooo`0:0?ooobgoZKgX6OnV
`^d3o`0000SoY/;]9OnU`^h01?l0003oYL;^ojG2k_nU`^h;0?ooo`?oQd^000?oZ;kY0?ooo`3oool0
103oool00ol00000oooo0?ooo`0L0?ooo`003P3oool00ol00000oooo0?ooo`0<0?ooo`;o00002P3o
ool50?2hU2D0Yl3[1P3e^8P20=RGS`<0m[J10ol000060?JfPB/0ZKgX00?o00000:Vmj02Y_NP05P2Y
_NP00ol00000oooo0?ooo`0W0?ooo`03o`00003oool0oooo00/0oooo;OnY_NPEojK2k@?o00003?nV
`^dUojG2kP03o`000?nU`^koYL;^00H0oooo2?n7Bh02ojRnj@H0oooo00?o00000?ooo`3oool06`3o
ool000h0oooo00?o00000?ooo`3oool03P3oool00ol00000oooo0?ooo`070?ooo`H0l;RD9@2W`>/5
0?FhR080f9N?00<0m[J1o`000?l000002@3f]X4/0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o0000
0?ooo`3oool09P3oool00ol00000oooo0?ooo`0<0?ooobgoZKgX4OnV`^d3o`0000ooY/;]00?oXBT0
ojG2k_nU`^h08onU`^h00ol0003oYL;^ojG2kP020?ooo`_oQd^00onX_^T60?ooo`03o`00003oool0
oooo01X0oooo000>0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool01P3oool70?2h
U2D0Yl3[0`3e^8P0103HUhoo0000o`000?l0000<0?JfPB/0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP0
0`3ooooo00000?ooo`0V0?ooo`03o`00003oool0oooo00d0oooo;OnY_NP=ojK2k@?o00004onV`^d0
0onQ:@3oYL;^ojG2kP0RojG2kP03o`000?nU`^koUgF[00goQd^00onX_^T60?ooo`03o`00003oool0
oooo01X0oooo000>0?ooo`03o`00003oool0oooo0100oooo00?o00000?ooo`3oool01@3oool80?2h
U2D0Yl3[0ol000000`3HUhl0m[J10?JfP@0=0?JfPB/0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0
0000oooo0?ooo`0U0?ooo`03o`00003oool0oooo00h0oooo;OnY_NP9ojK2k@?o00005onV`^dTojG2
kP04oiMeZol0003oUgF[oiMeZ`coQd^01?nX_^T60?ooo`03o`00003oool0oooo01T0oooo000>0?oo
o`03o`00003oool0oooo0140oooo00?o00000?ooo`3oool00`3oool:0?2hU240Yl3[0ol00000102W
`>/0mKR80=RGS`3HUhlA0?JfPBX0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol00000oooo0?ooo`0S
0?ooo`03o`00003oool0oooo0100oooo;?nY_NP7ojK2k@;o00006onV`^dPojG2kPGoUgF[00?o0000
oiMeZon7Bh002on7Bh05ojRnj@H0oooo00?o00000?ooo`3oool0603oool000h0oooo00?o00000?oo
o`3oool04P3oool00ol00000oooo0?ooo`020?ooo``0l;RD702W`>/3o`0000D0Yl3[0P3HUhlA0?Jf
PB/0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00`3ooooo00000?ooo`0S0?ooo`03o`00003oool0oooo
0140oooo;?nY_NP3ojK2k@?o00007_nV`^dLojG2kPSoUgF[00?o0000oiMeZon7Bh003?n7Bh04ojRn
j@H0oooo00?o00000?ooo`3oool0603oool000d0oooo00?o00000?ooo`3oool0503oool01?l00000
oooo0?ooo`3oool<0?2hU1T0Yl3[0ol000040:O0j`@0T6:I0P3HUhlA0?JfP@030>^YR02Y_NP0ZKgX
02P0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol00000oooo0?ooo`0R0?ooo`03o`00003oool0oooo
0180oooo:onY_NP3o`0002;oY/;]6OnU`^h;oiMeZ`03o`000?nGMJ_oQd^000_oQd^01OnX_^T60?oo
o`03o`00003oool0oooo01L0oooo000=0?ooo`03o`00003oool0oooo01D0oooo00?o00000?ooo`3o
ool03@3`^9@E0:O0j`?o00001@2W`>/6091RV@80f9N?4@3f]X400`3[ZHP0m[Eo0:Vmj00Y0:Vmj003
o`00002Y_NP0ZKgX01H0ZKgX00?o00000?ooo`3oool08@3oool00ol00000oooo0?ooo`0C0?ooobOo
ZKgX0ol00002ojVmj2CoY/;]4_nU`^hBoiMeZ`03o`000?n7Bh3oQd^000[oQd^01_nX_^T60?ooo`03
o`00003oool0oooo01H0oooo000=0?ooo`03o`00003oool0oooo01H0oooo00?o00000?2hU03`^9@0
3P3`^9@A0:O0j`;o00001P2W`>/8091RV@80f9N?4@3f]X400`3[ZHP0m[Eo0?JeO`0Z0:Vmj003o`00
002Y_NP0ZKgX01H0ZKgX00?o00000?ooo`3oool0803oool00ol00000oooo0?ooo`0E0?ooob;oZKgX
0ol00006ojVmj2CoY/;]3onU`^hDoiMeZ`03ojG3kol0003oQd^000[oQd^01_nX_^T60?ooo`03o`00
003oool0oooo01H0oooo000=0?ooo`03o`00003oool0oooo01L0oooo403`^9@>0:O0j`?o00001@2W
`>/;091RV@80f9N?4@3f]X400`3[ZHP0m[Eo0?JeO`0[0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?o
00000?ooo`3oool0803oool00ol00000oooo0?ooo`0E0?oooaooZKgX0ol0000;ojVmj27oY/;]00?o
Yl3/ojG2k_nU`^h02_nU`^hDoiMeZ`CoYL?_00?o0000ohM;P?n7Bh002On7Bh07ojRnj@H0oooo00?o
00000?ooo`3oool05@3oool000d0oooo00?o00000?ooo`3oool05`3ooolA0?2hU0X0Yl3[0ol00004
0:O0j`l0T6:I0P3HUhlA0?JfP@040>^YR03f]Gl0m[Eo0?JeObX0ZKgX00?o00000:Vmj02Y_NP05P2Y
_NP00ol00000oooo0?ooo`0N0?ooo`03o`00003oool0oooo01L0oooo6onY_NP3o`0000koZKgX7_nV
`^d5ojO0k0SoYL;^5OnGMJ/7ojG3k`03o`000?n7Bh3oQd^000SoQd^02?nX_^T60?ooo`03o`00003o
ool0oooo01@0oooo000=0?ooo`03o`00003oool0oooo01L0oooo4P3`^9@60:O0j`?o00001@2W`>/B
091RV@030=RGS`3f]X40m[J100h0m[J10P3[ZHP40?JeObX0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP0
0ol00000oooo0?ooo`0N0?ooo`03o`00003oool0oooo01T0oooo5_nY_NP3o`0001;oZKgX6?nV`^d;
ojO0k0GoYL;^5?nGMJ/;ojG3k`03o`000?n7Bh3oQd^000OoQd^02OnX_^T50?ooo`03o`00003oool0
oooo01@0oooo000=0?ooo`03o`00003oool0oooo01H0oooo503`^9@20:O0j`?o00001@2W`>/E091R
V@030=RGS`3f]X40m[J100h0m[J10P3[ZHP50?JeObX0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ol0
0000oooo0?ooo`0M0?ooo`03o`00003oool0oooo01X0oooo4onY_NP2o`0001OoZKgX5?nV`^d>ojO0
k003ojG2k_nGMJ_oUgF[01;oUgF[3onU`nl00ol0003oQd^0ohM;P006ohM;P0WoZ;kY1P3oool00ol0
0000oooo0?ooo`0C0?ooo`00303oool00ol00000oooo0?ooo`0D0?ooo`D0Y/;]4@3`^9@3o`0000@0
Yl3[6@2@HYTA0?JfP@80jjV81@3f]Gl[0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?o00000?ooo`3o
ool0703oool00ol00000oooo0?ooo`0J0?oooa3oZKgX0ol0000IojVmj17oY/;]4OnW`>`BoiMeZa;o
YL?_00?o0000ohM;P?n7Bh001_n7Bh0:ojRnj@H0oooo00?o00000?ooo`3oool04P3oool000`0oooo
00?o00000?ooo`3oool04P3oool70:K2k@h0l;RD0ol000030?2hU080Yl3[6`2@HYTA0?JfP@80jjV8
1P3f]GlZ0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?o00000?ooo`3oool0703oool00ol00000oooo
0?ooo`0K0?ooo`coZKgX0ol0000MojVmj0koY/;]4onW`>`=oiMeZaSoYL?_00?o0000ohM;P?n7Bh00
1On7Bh09ojRnj@03oi=RUP3oool0oooo00@0oooo00?o00000?ooo`3oool04P3oool000`0oooo00?o
00000?ooo`3oool03`3oool;0:K2k@/0l;RD0_l000060?2hU1d0T6:I4@3f]X420>^YR0P0m[Eo:@2Y
_NP00ol00000ZKgX0:Vmj00E0:Vmj003o`00003oool0oooo01/0oooo00?o00000?ooo`3oool07@3o
ool7ojVmj0?o00008OnY_NP8ojK2k@03ojVmj?nW`>coYl3/01GoYl3/2_nGMJ/LojG3k`03o`000?n7
Bh3oQd^000CoQd^01?nX_^T6oi=RUPL0oooo00?o00000?ooo`3oool04@3oool000`0oooo00?o0000
0?ooo`3oool03@3oool?0:K2k@H0l;RD0ol000080?2hU1d0T6:I4@3f]X400`3[ZHP0m[Eo0?JeO`08
0?JeObT0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ol00000oooo0?ooo`0I0?ooo`03o`00003oool0
oooo01l0oooo0onY_NP3o`0002GoZKgX1OnV`^d3ojVmj1SoYl3/1onGMJ/NojG3k`03o`000?n7Bh3o
Qd^000CoQd^00_nX_^T8oi=RUPP0oooo00?o00000?ooo`3oool0403oool000`0oooo00?o00000?oo
o`3oool02`3ooolB0:K2k@80l;RD0ol0000;0?2hU1T0T6:I1@2V`Nd@0?JfP@030>^YR03f]Gl0m[Eo
00T0m[Eo:@2Y_NP00ol00000ZKgX0:Vmj00D0:Vmj003o`00003oool0oooo01T0oooo00?o00000?oo
o`3oool07`3oool3o`0002WoZKgX00?oY/;]ojVmj?nY_NP01OnY_NPGojO0k0CoUgF[8_nU`nl00ol0
003oQd^0ohM;P003ohM;P0_oTf:F1`3oool00ol00000oooo0?ooo`0@0?ooo`00303oool00ol00000
oooo0?ooo`060?oooaH0Y/;]0ol0000=0?2hU0030;Re;@2@HYT0T6:I01D0T6:I1`2V`Nd@0?JfP@03
0>^YR03f]Gl0m[Eo00T0m[Eo:@2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003o`00003oool0oooo01P0
oooo00?o00000?ooo`3oool0703oool3o`000080oooo<onY_NPFojO0k0;oUgF[9OnU`nl00ol0003o
Qd^0ohM;P002ohM;P0_oTf:F203oool00ol00000oooo0?ooo`0?0?ooo`00303oool00ol00000oooo
0?ooo`040?oooaD0Y/;]0ol000030:K2k@d0l;RD00<0^;D]091RV@2@HYT04`2@HYT:0:K1k@l0m[J1
00<0jjV80?JeO`3f]Gl02P3f]GlY0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?o00000?ooo`3oool0
5`3oool00ol00000oooo0?ooo`0I0?ooo`?o00001P3ooolcojVmj1KoYl3/9onU`nl01?l0003oQd^0
ohM;P?n7Bh0;oi=RUPL0oooo0ol0000@0?ooo`002`3oool00ol00000oooo0?ooo`030?oooa@0Y/;]
0ol000070:K2k@`0l;RD0P2h]BdA091RV@l0Y/7]303f]X420>^YR0d0m[Eo:@2Y_NP00ol00000ZKgX
0:Vmj00D0:Vmj003o`00003oool0oooo01L0oooo00?o00000?ooo`3oool05P3oool3o`0000X0oooo
<onY_NPFojO0k2KoYL?_00?o0000ohM;P?n7Bh000_n7Bh0:oi=RUP@0oooo0ol000020?ooo`03o`00
003oool0oooo00h0oooo000;0?ooo`04o`00003oool0oooo0?oooa<0Y/;]0ol0000;0:K2k@/0l;RD
00<0Yl3[0;Re;@2@HYT0302@HYTD0:K1k@/0m[J10P3[ZHP>0?JeObT0ZKgX00?o00000:Vmj02Y_NP0
4`2Y_NP00ol00000oooo0?ooo`0G0?ooo`03o`00003oool0oooo01@0oooo0_l0000?0?oooc;oZKgX
5_nW`>`VojG3k`04o`000?n7Bh3oQd^0ohM;P0[oTf:F00@0ooooo`000?l0003o00001@3oool00ol0
0000oooo0?ooo`0>0?ooo`002`3oool00ol00000Y/;]0:K2k@0A0:K2k@?o00003`2V`^d:0?2hU003
0:O0j`2h]Bd0T6:I00T0T6:I5`2V`Nd;0?JfP@80jjV83`3f]GlX0:Vmj003o`00002Y_NP0ZKgX00h0
ZKgX1@3oool00ol00000oooo0?ooo`0F0?ooo`03o`00003oool0oooo0180oooo0ol0000A0?oooc?o
ZKgX4onW`>`3ojRojRKoYL?_00?o0000ohM;P?n7Bh002_nCHYH00ol00000oooo0?ooo`060?ooo`03
o`00003oool0oooo00h0oooo000;0?ooo`03o`00003oool0Y/;]00l0Y/;]0_l0000D0:K2k@L0l;RD
0P2W`>/00`2h]Bd0T6:I091RV@06091RVAX0Y/7]2P3f]X420>^YR0l0m[Eo:@2Y_NP00ol00000ZKgX
0:Vmj00;0:Vmj0P0oooo00?o00000?ooo`3oool05@3oool00ol00000oooo0?ooo`0?0?ooo`?o0000
5@3ooolbojVmj17oYl3/1OnX_nXWojG3k`03o`000?n7Bh3oTf:F00WoTf:F2@3oool00ol00000oooo
0?ooo`0>0?ooo`002`3oool01?l00000oooo0?ooo`3oool;0:K2k@?o00005`2V`^d60?2hU0<0Yl3[
102@HYTP0:K1k@P0m[J10P3[ZHP@0?JeObT0ZKgX00?o00000:Vmj02Y_NP01@2Y_NP=0?ooo`03o`00
003oool0oooo01D0oooo00?o00000?ooo`3oool0303oool3o`0001T0oooo<_nY_NP=ojO0k0WoZ;oZ
9_nU`nl00ol0003oQd^0oi=RUP0:oi=RUPT0oooo00?o00000?ooo`3oool03@3oool000/0oooo00Co
00000?ooo`3oool0oooo202V`^d3o`0001/0Y/;]1@3`^9@30:O0j`03091RV@2V`Nd0Y/7]0240Y/7]
203f]X420>^YR140m[Eo:02Y_NP00ol00000ZKgX0:Vmj0030:Vmj0l0oooo00?o00000?ooo`3oool0
5@3oool00ol00000oooo0?ooo`090?ooo`?o00007P3ooolbojVmj0OoYl3/3_nX_nXVojG3k`03o`00
0?nCHYKoTf:F00WoTf:F2@3oool00ol00000oooo0?ooo`0=0?ooo`002`3oool00ol00000oooo0?oo
o`020?ooo`@0Y/;]0ol0000O0:K2k@@0l;RD1@2W`>/S0:K1k@L0m[J10P3[ZHPB0?JeObP0ZKgX00?o
00000?ooo`3oool04@3oool00ol00000oooo0?ooo`0E0?ooo`03o`00003oool0oooo00H0oooo0ol0
000R0?oooc;oZKgX0onW`>`4ojVmj0koZ;oZ9_nU`nl00ol0003oTf:Foi=RUP08oi=RUPT0oooo00?o
00000?ooo`3oool03@3oool000X0oooo00?o00000?ooo`3oool0103oool3o`0002<0Y/;]0`3`^9@5
0:O0jb@0Y/7]1P3f]X420>^YR1<0m[Eo9P2Y_NP20?ooo`03o`00003oool0oooo0100oooo00?o0000
0?ooo`3oool05@3oool00ol00000oooo0?ooo`030?ooo`?o00009P3oooliojVmj0koZ;oZ9?nU`nl0
0onCHYKo0000oi=RUP09oi=RUPT0oooo00?o00000?ooo`3oool03@3oool000X0oooo00Co00000?oo
o`3oool0oooo0ol000030?ooob@0Y/;]00<0l;RD0:O0j`2W`>/01@2W`>/U0:K1k@@0m[J10P3[ZHPD
0?JeOb00ZKgX203oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01@0oooo00Co0000
0?ooo`3oool0oooo0ol0000Y0?ooocWoZKgX3onX_nXNojG3k`OoTf:F00?o0000oi=RU_nCHYH01onC
HYH90?ooo`03o`00003oool0oooo00d0oooo000:0?ooo`Co00001P3ooolU0:K2k@P0Yl3[902V`Nd3
0?JfP@<0jjV8503f]GlL0:Vmj0`0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0D
0?ooo`Co0000;@3oooliojVmj0ooZ;oZ6onU`nl:oi=RUP03o`000?nCHYKoTf:F00KoTf:F2@3oool0
0ol00000oooo0?ooo`0=0?ooo`002P3oool2o`0000T0oooo8`2V`^d;0:O0jb<0Y/7]0P3f]X430>^Y
R1D0m[Eo6@2Y_NP?0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool04`3oool2o`00
0340oooo>?nY_NP>ojRojQSoYL?_3_nCHYH00ol0003oTf:Foi=RUP05oi=RUPT0oooo00?o00000?oo
o`3oool03@3oool000`0oooo00?o00000?ooo`3oool0203ooolO0:K2k@d0Yl3[902V`Nd0103f]X40
jjV80>^YR03[ZHPF0?JeOa@0ZKgX503oool00ol00000oooo0?ooo`0>0?ooo`03o`00003oool0oooo
01D0oooo00?o00000?ooo`3oool0;`3ooolhojVmj0coZ;oZ0_nFJI`BojG3ka?oTf:F00?o0000oi=R
U_nCHYH01_nCHYH80?ooo`03o`00003oool0oooo00d0oooo000=0?ooo`03o`00003oool0oooo00P0
oooo6@2V`^dC0:O0jb@0Y/7]0P3[ZHPH0?JeOa40ZKgX5`3oool00ol00000oooo0?ooo`0=0?ooo`03
o`00003oool0oooo01H0oooo00?o00000?ooo`3oool0;`3ooolhojVmj0WoZ;oZ1OnFJI`>ojG3k`03
ojaiV_nCHYKoTf:F01CoTf:F00?o0000oi=RU_nCHYH01OnCHYH90?ooo`03o`00003oool0oooo00`0
oooo000>0?ooo`03o`00003oool0oooo00P0oooo5P2V`^dG0:O0jb40Y/7]00<0V7FZ0>^YR03[ZHP0
6@3f]Gl;0:Vmj1`0oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?ooo`0G0?ooo`03o`00
003oool0oooo02l0oooo>?nY_NP4ojRojP[oUVVL2onU`nl00onFJIco[7VJojaiVP0Goi=RUP03o`00
0?nCHYKoTf:F00CoTf:F2@3oool00ol00000oooo0?ooo`0<0?ooo`003`3oool2o`0000T0oooo4@2V
`^dL0:O0jah0Y/7]102HMJX00`3[ZHP0m[Eo0?JeO`0H0?JeO`P0ZKgX7`3oool00ol00000oooo0?oo
o`0<0?ooo`03o`00003oool0oooo01P0oooo0_l0000a0?ooocOoZKgX00?oZ;oZoiIYW?nFJI`02onF
JI`7ojG3k`CoUVVL0_n/NIXGoi=RUP04o`000?nCHYKoTf:Foi=RUPCoY/7]203oool00ol00000oooo
0?ooo`0<0?ooo`004@3oool00ol00000oooo0?ooo`080?ooo`d0Y/;]0P3ooolM0:O0jaT0Y/7]202H
MJX00`3[ZHP0m[Eo0?JeO`0I0?JeO`<0ZKgX903oool00ol00000oooo0?ooo`0;0?ooo`03o`00003o
ool0oooo01X0oooo00?o00000?ooo`3oool0;`3ooolfojVmj0ooUVVL00?oYL?_oiIYW?nFJI`01onF
JI`2ojaiVQSoTf:F00?o0000ojK1kOnV`Nd01OnV`Nd70?ooo`03o`00003oool0oooo00`0oooo000B
0?ooo`03o`00003oool0oooo00P0oooo2@2V`^d60?oooad0Yl3[5@2V`Nd;09QeZP030>^YR03f]Gl0
m[Eo01T0m[Eo:03oool00ol00000oooo0?ooo`0:0?ooo`03o`00003oool0oooo01/0oooo00?o0000
0?ooo`3oool0;P3ooolfojVmj1[oUVVL00?o[7VJoi=RU_nCHYH05?nCHYH3ojK1k@03o`000?nV`Ngo
Y/7]00CoY/7]1`3oool00ol00000oooo0?ooo`0<0?ooo`004`3oool00ol00000oooo0?ooo`080?oo
o`@0Y/;]2`3ooolH0:O0j`0308mMT_n?GI;oSefB0080SefB402V`Nd@09QeZQ/0m[Eo:03oool00ol0
0000oooo0?ooo`0;0?ooo`03o`00003oool0oooo01/0oooo00?o00000?ooo`3oool0;P3oooleojVm
j1[oUVVL0_n/NIX@oi=RUPWoY/7]00?o0000ojK1kOnV`Nd01?nV`Nd60?ooo`03o`00003oool0oooo
00`0oooo000D0?ooo`03o`00003oool0oooo00P0oooo00<0Y/;]0?ooo`3oool0303ooolD0:O0j`@0
SefB0_n?GI8308mMTPd0Y/7]4P2HMJXK0?JeObT0oooo00?o00000?ooo`3oool02P3oool00ol00000
oooo0?ooo`0L0?ooo`;o0000;`3oooldojVmj1[oUVVL0_n/NIX=oi=RUPcoY/7]00?o0000ojK1kOnV
`Nd01OnV`Nd50?ooo`03o`00003oool0oooo00`0oooo000E0?ooo`;o0000603oool?0:O0j`P0SefB
0_n?GI8408mMTPT0Y/7]502HMJX00`2V`^d0m[Eo0?JeO`0I0?JeObX0oooo00?o00000?ooo`3oool0
2@3oool00ol00000oooo0?ooo`0N0?ooo`03o`00003oool0oooo02d0oooo;onY_NP40:Vmj1KoUVVL
1?nW`N`2ojaiVPWoTf:F4OnV`Nd00ol0003oY/7]ojK1k@05ojK1k@@0oooo00?o00000?ooo`3oool0
303oool001L0oooo00?o00000?ooo`3oool05P3oool<0:O0j`X0SefB0_n?GI8408mMTP0306@lS02V
`Nd0Y/7]0080Y/7]5@2HMJX50:K2kAX0m[Eo:`3oool00ol00000oooo0?ooo`080?ooo`03o`00003o
ool0oooo01l0oooo00?o00000?ooo`3oool0;P3oool[ojVmj0D0ZKgX00<0ooooooBMCOnFJI`04_nF
JI`7ojO1k003ojaiV_nCHYKoTf:F00CoTf:F5OnV`Nd00ol0003oY/7]ojK1k@04ojK1k@D0oooo00?o
00000?ooo`3oool02`3oool001P0oooo00?o00000?ooo`3oool05`3oool60:O0j`h0SefB0_n?GI84
08mMTP80I3b<00<0Y/7]09QeZP2HMJX04@2HMJX:0:K2kAT0m[Eo:`3oool00ol00000oooo0?ooo`08
0?ooo`03o`00003oool0oooo0200oooo00?o00000?ooo`3oool0;P3ooolVojVmj0D0ZKgX1@3oool0
0oodWDgoUVVLoiIYW00=oiIYW0coYl7/0_nCHYHJojK1k@03o`000?nV`NgoY/7]00?oY/7]1@3oool0
0ol00000oooo0?ooo`0;0?ooo`006@3oool00ol00000oooo0?ooo`0G0?ooo`<0Yl3[402?GI82ohmM
TP@0SefB0P1T?8`A09QeZPh0Y/;]603f]Gl/0?ooo`03o`00003oool0oooo00L0oooo00?o00000?oo
o`3oool08@3oool2o`0002l0oooo8_nY_NP40:Vmj0X0oooo3?nFJI`@ojO1k1_oY/7]00?o0000ojK1
kOnV`Nd01?nV`Nd40?ooo`03o`00003oool0oooo00/0oooo000J0?ooo`;o00005`3ooolC08mMTP;o
SefB102?GI8206@lS0d0V7FZ4`2V`^dG0?JeObd0oooo00?o00000?ooo`3oool01`3oool00ol00000
oooo0?ooo`0R0?ooo`03o`00003oool0oooo02d0oooo7onY_NP40:Vmj0`0oooo2?nFJI`DojO1k1co
Y/7]00?o0000ojK1kOnV`Nd01?nV`Nd30?ooo`03o`00003oool0oooo00/0oooo000L0?ooo`03o`00
003oool0oooo01@0oooo4`2?GI82ohmMTP@0SefB0P1T?8`;09QeZQH0Y/;]5P3f]Gl^0?ooo`03o`00
003oool0oooo00H0oooo00?o00000?ooo`3oool08`3oool00ol00000oooo0?ooo`0]0?oooa[oZKgX
1@2Y_NP?0?ooo`KoUVVL5onW`N`LojK1k@03o`000?nV`NgoY/7]00CoY/7]0P3oool00ol00000oooo
0?ooo`0;0?ooo`007@3oool00ol00000oooo0?ooo`0C0?oooa<0SefB0_n?GI8408mMTP<0I3b<202H
MJXI0:K2kAD0m[Eo;P3oool00ol00000oooo0?ooo`060?ooo`03o`00003oool0oooo02@0oooo00?o
00000?ooo`3oool0;@3ooolEojVmj0D0ZKgX4`3oool00onFJIcoYl7/ojO1k00KojO1k1_oY/7]00?o
0000ojK1kOnV`Nd01OnV`Nd00`3ooooo00000?ooo`0<0?ooo`007P3oool00ol00000oooo0?ooo`0B
0?oooa<0SefB0_n?GI8408mMTP<0I3b<0`2HMJXO0:K2kA@0m[Eo;`3oool00ol00000oooo0?ooo`05
0?ooo`03o`00003oool0oooo02D0oooo00?o00000?ooo`3oool0;P3ooolAojVmj0<0ZKgX603ooolN
ojO1k1_oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00`3ooooo00000?ooo`0<0?ooo`007`3oool00ol0
0000oooo0?ooo`0A0?oooa<0SefB0_n?GI8408mMTP<0I3b<00<0V7FZ0:K2k@2V`^d0802V`^dC0?Je
Oc00oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`0V0?ooo`;o0000;`3oool<ojVm
j0D0ZKgX6`3ooolNojO1k1_oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol00000oooo0?ooo`0;0?oo
o`00803oool2o`000140oooo4`2?GI82ohmMTP@0SefB0`1T?8`00`3/_Z<0Y/;]0:K2k@0Q0:K2kA80
m[Eo<03oool00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo02P0oooo00?o00000?ooo`3o
ool0;@3oool7ojVmj0D0ZKgX803ooolNojO1k1_oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol00000
oooo0?ooo`0:0?ooo`008P3oool00ol00000oooo0?ooo`0>0?oooa<0SefB0_n?GI8408mMTP<0I3b<
0P3/_Z<R0:K2kA80m[Eo<@3oool00ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo02T0oooo
00?o00000?ooo`3oool0;@3oool3ojVmj0D0ZKgX8`3ooolNojO1k1_oY/7]00?o0000ojK1kOnV`Nd0
103oool00ol00000oooo0?ooo`0:0?ooo`008`3oool00ol00000oooo0?ooo`0=0?oooa<0SefB0_n?
GI8408mMTP80I3b<1@3/_Z<Q0:K2kA40m[Eo<P3oool00ol00000oooo0?ooo`030?ooo`03o`00003o
ool0oooo02T0oooo00?o00000?ooo`3oool0;@3oool30:Vmj2P0oooo7_nW`N`KojK1k@03o`00003o
ool0oooo00<0oooo00?o00000?ooo`3oool02P3oool002@0oooo00?o00000?ooo`3oool0303ooolC
08mMTP;oSefB102?GI8206@lS0H0k;jS8@2V`^d@0?JeOc<0oooo00?o00000?ooo`3oool00P3oool0
0ol00000oooo0?ooo`0Z0?ooo`;o0000;@3oool00ol00000oooo0?ooo`0Y0?oooakoYl7/5OnV`Nd6
0?ooo`03o`00003oool0oooo0080oooo00?o00000?ooo`3oool02P3oool002D0oooo0_l0000<0?oo
oa<0SefB0_n?GI8408mMTP0306@lS03/_Z<0k;jS00D0k;jS8`2V`^d=0?JeOc@0oooo00?o00000?oo
o`3oool00P3oool00ol00000oooo0?ooo`0/0?ooo`03o`00003oool0oooo02X0oooo00?o00000?oo
o`3oool0:P3ooolNojO1k1;oY/7]2@3oool01Ol00000oooo0?ooo`3ooooo000000`0oooo000W0?oo
o`03o`00003oool0oooo00T0oooo4`2?GI82ohmMTP@0SefB00<0I3b<0>bnX`3/_Z<01P3/_Z<S0:K2
k@`0m[Eo=@3oool01Ol00000oooo0?ooo`3ooooo000002l0oooo00?o00000?ooo`3oool0:@3oool0
0ol00000oooo0?ooo`0[0?oooacoYl7/0P3oool<ojK1k@h0oooo00Go00000?ooo`3oool0ooooo`00
000<0?ooo`00:03oool00ol00000oooo0?ooo`080?oooa<0SefB0_n?GI8408mMTP0306@lS03/_Z<0
k;jS00L0k;jS8`2V`^d;0?JeOcH0oooo00Co00000?ooo`3ooooo0000<03oool00ol00000oooo0?oo
o`0X0?ooo`03o`00003oool0oooo02`0oooo5onW`N`70?ooo`WoY/7]4@3oool01?l00000oooo0?oo
ool0000<0?ooo`00:@3oool00ol00000oooo0?ooo`070?oooa<0SefB0_n?GI8308mMTP80YL?_2`3/
_Z<R0:K2k@X0m[Eo=`3oool00ol00000ooooo`00000a0?ooo`;o0000:03oool00ol00000oooo0?oo
o`0]0?oooa;oYl7/303oool3ojK1kAL0oooo00?o00000?ooool00000303oool002X0oooo00?o0000
0?ooo`3oool01P3ooolC08mMTP;oSefB00<0SefB0:G3k`2U`nl00`2U`nl;0>bnXb40Y/;]2P3f]Glg
0?ooo`03o`00003ooooo000003<0oooo00?o00000?ooo`3oool09@3oool00ol00000oooo0?ooo`0^
0?ooo`koYl7/:@3oool01?l00000oooo0?ooool0000;0?ooo`00:`3oool2o`0000H0oooo4P2?GI8:
0:G3k`/0k;jS8@2V`^d90?JeOcP0oooo00?o00000?ooool00000<`3oool00ol00000oooo0?ooo`0T
0?ooo`03o`00003oool0oooo02l0oooo1?nW`N`20:O1k0?oYl7/;P3oool00ol00000ooooo`00000;
0?ooo`00;@3oool00ol00000oooo0?ooo`030?oooa00SefB3@2U`nl;0>bnXb40Y/;]203f]Gli0?oo
o`;o0000=03oool00ol00000oooo0?ooo`0S0?ooo`03o`00003oool0oooo02l0oooo1@2W`N`c0?oo
o`;o00002`3oool002h0oooo00?o00000?ooo`3oool00P3oool;08mMTQ@0YL?_2`3/_Z<P0:K2k@L0
m[Eo>03oool3o`0003D0oooo0_l0000S0?ooo`03o`00003oool0oooo0300oooo0P2W`N`d0?ooo`?o
00002`3oool002l0oooo00Co00000?ooo`3oool0oooo1`2?GI8I0:G3k`X0k;jS00<0Y/7]0:K2k@2V
`^d07P2V`^d60?JeOc@0oooo1?l0000j0?ooo`03o`00003oool0oooo0200oooo00?o00000?ooo`3o
ool0HP3oool4o`0000h0oooo000`0?ooo`;o000000<0oooo08mMTP2?GI800`2?GI8L0:G3k`T0k;jS
00<0Y/7]0:K2k@2V`^d07`2V`^d50?JeOc40oooo0ol0000o0?ooo`03o`00003oool0oooo01l0oooo
00?o00000?ooo`3oool0G`3oool3o`000180oooo000b0?ooo`03o`00002?GI80YL?_01l0YL?_203/
_Z<30:K1kB40Y/;]103f]Gl]0?ooo`Co0000@`3oool00ol00000oooo0?ooo`0N0?ooo`03o`00003o
ool0oooo05/0oooo1?l0000E0?ooo`00<`3oool00ol00000YL?_0:G3k`0O0:G3k`L0k;jS102V`NdQ
0:K2k@<0m[Eo:@3oool4o`0004P0oooo0_l0000N0?ooo`03o`00003oool0oooo05L0oooo1?l0000I
0?ooo`00=03oool00ol00000oooo0:G3k`0P0:G3k`D0k;jS1@2V`NdQ0:K2k@80m[Eo9@3oool4o`00
04h0oooo00?o00000?ooo`3oool06`3oool00ol00000oooo0?ooo`1D0?ooo`?o00007@3oool003D0
oooo00?o00000?ooo`2U`nl0802U`nl30>bnX`L0Y/7]8@2V`^d00`3f]Gl0oooo0?ooo`0P0?ooo`?o
0000D`3oool00ol00000oooo0?ooo`0J0?ooo`03o`00003oool0oooo0500oooo1?l0000P0?ooo`00
=P3oool2o`000240YL?_0P3/_Z<90:K1kB00Y/;]7P3oool4o`0005L0oooo00?o00000?ooo`3oool0
6@3oool00ol00000oooo0?ooo`1<0?ooo`Co0000903oool003P0oooo00?o00000:G3k`2U`nl07`2U
`nl00`3/_Z<0Y/7]0:K1k@080:K1kAh0Y/;]6`3oool4o`0005`0oooo0_l0000I0?ooo`03o`00003o
ool0oooo04P0oooo1?l0000X0?ooo`00>@3oool00ol00000YL?_0:G3k`0M0:G3k`d0Y/7]6`2V`^dI
0?ooo`Co0000HP3oool00ol00000oooo0?ooo`0F0?ooo`03o`00003oool0oooo04D0oooo0ol0000/
0?ooo`00>P3oool00ol00000YL?_0:G3k`0H0:G3ka80Y/7]5P2V`^dJ0?ooo`?o0000I`3oool00ol0
0000oooo0?ooo`0E0?ooo`03o`00003oool0oooo0440oooo1?l0000_0?ooo`00>`3oool00ol00000
YL?_0:G3k`0C0:G3kaL0Y/7]4@2V`^dJ0?ooo`Co0000J`3oool00ol00000oooo0?ooo`0C0?ooo`03
o`00003oool0oooo03h0oooo1?l0000c0?ooo`00?@3oool00ol00000YL?_0:G3k`0?0:G3kaD0Y/7]
1@3oool<0:K2kAX0oooo1?l0001`0?ooo`;o00004`3oool00ol00000oooo0?ooo`0j0?ooo`Co0000
=`3oool003h0oooo00?o00000:G3k`2U`nl02P2U`nl20?oooa<0Y/7]2P3oool90:K2kAP0oooo1?l0
001f0?ooo`03o`00003oool0oooo0100oooo00?o00000?ooo`3oool0=`3oool3o`0003/0oooo000o
0?ooo`03o`00002U`nl0YL?_00D0YL?_1`3ooolA0:K1k@`0oooo102V`^dH0?ooo`Co0000N`3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03<0oooo1?l0000n0?ooo`00@03oool00ol0
0000oooo0:G3k`0=0?ooo`/0Y/7]:@3oool3o`000800oooo00?o00000?ooo`3oool03P3oool00ol0
0000oooo0?ooo`0_0?ooo`Co0000@P3oool00440oooo0_l0000>0?ooo`H0Y/7]:@3oool4o`0008@0
oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?ooo`0/0?ooo`?o0000AP3oool004<0oooo
00?o00000?ooo`3oool0303oool00`2V`Nd0oooo0?ooo`0W0?ooo`Co0000R@3oool2o`0000d0oooo
00?o00000?ooo`3oool0:03oool4o`0004T0oooo00140?ooo`03o`00003oool0oooo00/0oooo00?o
00000?ooo`3oool08`3oool4o`0008l0oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?oo
o`0T0?ooo`Co0000C@3oool004D0oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0P
0?ooo`?o0000U03oool00ol00000oooo0?ooo`090?ooo`03o`00003oool0oooo0200oooo1?l0001A
0?ooo`00AP3oool2o`0000T0oooo00?o00000?ooo`3oool07@3oool4o`0009P0oooo00?o00000?oo
o`3oool0203oool00ol00000oooo0?ooo`0M0?ooo`?o0000E@3oool004P0oooo00?o00000?ooo`3o
ool01P3oool00ol00000oooo0?ooo`0I0?ooo`Co0000W@3oool2o`0000P0oooo00?o00000?ooo`3o
ool06@3oool4o`0005P0oooo00190?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0
5@3oool4o`000:<0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`0E0?ooo`Co0000
G03oool004X0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`0B0?ooo`?o0000Z03o
ool00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo0140oooo1?l0001P0?ooo`00B`3oool0
0ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo00h0oooo1?l0002/0?ooo`03o`00003oool0
oooo00<0oooo00?o00000?ooo`3oool03P3oool3o`0006@0oooo001<0?ooo`;o00000`3oool00ol0
0000oooo0?ooo`0:0?ooo`Co0000/@3oool2o`0000<0oooo00?o00000?ooo`3oool02P3oool4o`00
06L0oooo001>0?ooo`04o`00003oool0ooooo`0000P0oooo1?l0002g0?ooo`04o`00003oool0oooo
o`0000P0oooo1?l0001[0?ooo`00C`3oool00ol00000ooooo`0000050?ooo`?o0000_03oool00ol0
0000ooooo`0000050?ooo`?o0000K`3oool00500oooo0_l000000`3ooooo0000o`000002o`000<00
oooo0_l000000`3ooooo0000o`000002o`000780oooo001A0?ooo`;o0000a@3oool2o`0007H0oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {153.5, 0}} -> {-0.0542361, -0.0193168, \
0.0052844, 0.0052844}, {{10.25, 190.438}, {149.812, 3.625}} -> {-0.0541935, \
0.0451583, 0.00528671, 0.00528671}, {{208.5, 388.688}, {149.812, 3.625}} -> \
{-1.10228, 0.0451583, 0.00528671, 0.00528671}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gdnoFrame\  = \ 
        Show[gd, \ Frame \[Rule] False, \ nS];\)\), "\[IndentingNewLine]", 
    \(\(gclass\  = \ 
        DrawHistogramClass[{h1, h2}, \ {class1Color, class2Color}, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gdnoFrame, gclass}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.32705 .5164 Mdot
.29668 .60644 Mdot
.15864 .36367 Mdot
.27753 .96099 Mdot
.05386 .03889 Mdot
.29317 .47122 Mdot
.24512 .97593 Mdot
.28241 .9681 Mdot
.06004 .57488 Mdot
.4336 .22093 Mdot
.39592 .0594 Mdot
.44328 .68243 Mdot
.07382 .53805 Mdot
.15156 .08094 Mdot
.41518 .17934 Mdot
.37402 .115 Mdot
.36627 .1454 Mdot
.0858 .63883 Mdot
.1261 .16452 Mdot
.30339 .66578 Mdot
.07101 .58469 Mdot
.36979 .4498 Mdot
.17509 .53024 Mdot
.42651 .76242 Mdot
.10622 .98723 Mdot
.2799 .68643 Mdot
.19105 .81285 Mdot
.40588 .57638 Mdot
.32478 .6724 Mdot
.32503 .9326 Mdot
.20362 .51284 Mdot
.02659 .27178 Mdot
.13756 .9232 Mdot
.15679 .81703 Mdot
.46247 .39791 Mdot
.23028 .05956 Mdot
.36119 .40572 Mdot
.45038 .36818 Mdot
.1751 .58793 Mdot
.04944 .78685 Mdot
.35032 .91058 Mdot
.22441 .84929 Mdot
.15165 .40269 Mdot
.20278 .58247 Mdot
.01904 .47454 Mdot
.05094 .76049 Mdot
.05657 .08159 Mdot
.32066 .70588 Mdot
.19538 .67091 Mdot
.37028 .34265 Mdot
.02523 .08794 Mdot
.32579 .55085 Mdot
.17491 .17241 Mdot
.10633 .69661 Mdot
.02821 .76477 Mdot
.40355 .11909 Mdot
.01413 .29518 Mdot
.35756 .35366 Mdot
.45756 .21854 Mdot
.04185 .64283 Mdot
.26713 .54268 Mdot
.17157 .30513 Mdot
.24685 .45969 Mdot
.34577 .74933 Mdot
.07689 .29222 Mdot
.2444 .05767 Mdot
.05363 .5225 Mdot
.34085 .93363 Mdot
.04445 .23227 Mdot
.48329 .58492 Mdot
.08689 .01868 Mdot
.4464 .93715 Mdot
.31976 .47106 Mdot
.27978 .63697 Mdot
.07786 .01632 Mdot
.43401 .88269 Mdot
.00592 .71915 Mdot
.19456 .82997 Mdot
.45229 .2016 Mdot
.3537 .89139 Mdot
.41279 .96437 Mdot
.37041 .31142 Mdot
.33084 .95064 Mdot
.42402 .36932 Mdot
.01603 .48453 Mdot
.14919 .7274 Mdot
.43817 .47316 Mdot
.21518 .83977 Mdot
.43721 .74907 Mdot
.02557 .01475 Mdot
.48492 .55242 Mdot
.17187 .11841 Mdot
.07709 .5831 Mdot
.30146 .80205 Mdot
.24624 .62751 Mdot
.37744 .43768 Mdot
.23516 .14793 Mdot
.23321 .70532 Mdot
.29699 .66981 Mdot
.02298 .86061 Mdot
0 0 1 r
.64022 .9158 Mdot
.5026 .85081 Mdot
.62514 .36833 Mdot
.66952 .73735 Mdot
.69727 .78027 Mdot
.96602 .93035 Mdot
.93857 .15771 Mdot
.84347 .49762 Mdot
.67373 .01473 Mdot
.57668 .78735 Mdot
.96577 .33997 Mdot
.59471 .9218 Mdot
.82555 .41922 Mdot
.59211 .07594 Mdot
.70041 .05585 Mdot
.91765 .33364 Mdot
.50313 .27062 Mdot
.94667 .39834 Mdot
.55962 .11786 Mdot
.6032 .89577 Mdot
.88094 .10808 Mdot
.52652 .11337 Mdot
.91022 .76316 Mdot
.92686 .18662 Mdot
.58468 .34889 Mdot
.83475 .11563 Mdot
.87932 .29799 Mdot
.91215 .77704 Mdot
.87618 .03232 Mdot
.96053 .38364 Mdot
.81657 .90951 Mdot
.85733 .48293 Mdot
.93068 .80638 Mdot
.83081 .37451 Mdot
.52045 .04817 Mdot
.89899 .19284 Mdot
.93082 .69434 Mdot
.56424 .08217 Mdot
.55151 .4013 Mdot
.64714 .30018 Mdot
.67037 .37393 Mdot
.68166 .91158 Mdot
.84886 .45948 Mdot
.81938 .43361 Mdot
.91323 .64815 Mdot
.98362 .06405 Mdot
.89278 .60492 Mdot
.58462 .86625 Mdot
.957 .90563 Mdot
.52038 .78904 Mdot
.9055 .50928 Mdot
.86829 .49381 Mdot
.73512 .1403 Mdot
.68663 .57727 Mdot
.88132 .67587 Mdot
.86231 .14862 Mdot
.96313 .03268 Mdot
.87374 .08952 Mdot
.57035 .4228 Mdot
.78911 .21832 Mdot
.6084 .51222 Mdot
.76873 .42433 Mdot
.69795 .00789 Mdot
.89549 .92557 Mdot
.95787 .86264 Mdot
.70886 .35325 Mdot
.57656 .19171 Mdot
.8416 .20958 Mdot
.60848 .16399 Mdot
.96291 .12501 Mdot
.53812 .73623 Mdot
.6738 .90174 Mdot
.92478 .22896 Mdot
.90012 .48236 Mdot
.72683 .22603 Mdot
.50463 .55184 Mdot
.764 .35844 Mdot
.79082 .20354 Mdot
.68744 .17168 Mdot
.94427 .98901 Mdot
.57897 .01264 Mdot
.97641 .86896 Mdot
.54084 .27145 Mdot
.80261 .96226 Mdot
.61112 .04744 Mdot
.89754 .48485 Mdot
.87934 .81646 Mdot
.89291 .92807 Mdot
.61534 .46297 Mdot
.60209 .72947 Mdot
.92294 .29624 Mdot
.65286 .73551 Mdot
.84397 .28856 Mdot
.6715 .8616 Mdot
.80313 .02205 Mdot
.86394 .89439 Mdot
.69201 .96967 Mdot
.96145 .41448 Mdot
.80772 .15815 Mdot
.56855 .48147 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.0238095 0.0186741 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
153 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00L@3oool3o`00oa80oooo0ol00?oo0?ooo`P0oooo000=0?ooo`?oo`001P3oool5ool005H0
oooo0ol00?l>0?ooo`?o003o00@0ooooo`00ool00?oo003oo`3oool80?ooo`003@3oool3ool000H0
oooo1Ooo001F0?ooo`?o003o3P3oool3o`00oa@0oooo0ol00?od0?ooo`003@3oool3ool000H0oooo
1Ooo001W0?ooo`?o003o503oool3o`00oo@0oooo002I0?ooo`?o003o2P3oool3o`00o`d0oooo0ol0
0?lK0?oooeSoo`00EOl00?l?0?ooo`004P3oool3ool00940oooo0ol00?l=0?ooo`?o003o6`3ooomH
ool005Go003o3`3oool00180oooo0ooo001R0?ooo`?o003o;03oool3o`00o`d0oooo0ol00?lK0?oo
oeSoo`00EOl00?l?0?ooo`004P3oool3ool00540oooo0ol00?l>0?ooo`?o003oFP3ooomHool005Go
003o3`3oool003@0oooo0ooo000_0?ooo`?o003o3P3oool3o`00o`d0oooo0ol00?m:0?oooeSoo`00
EOl00?l?0?ooo`00<P3oool5ool001T0oooo0ooo000C0?ooo`?o003o7P3oool3o`00oc00oooo0ol0
0?lG0?oooeSoo`00EOl00?l?0?ooo`00<P3oool5ool001T0oooo0ooo000d0?ooo`?o003o<03oool3
o`00oaL0ooooF?oo001Eo`00o`l0oooo000b0?ooo`?oo`006`3oool3ool006L0oooo0ol00?lG0?oo
oeSoo`00EOl00?l?0?ooo`00903oool3ool004`0oooo0ol00?mN0?oooeSoo`00EOl00?l?0?ooo`00
4`3oool3ool000h0oooo0ooo00170?ooo`?o003o0P3oool3o`00oeh0ooooF?oo001Eo`00o`l0oooo
000=0?ooo`?oo`000`3oool3ool000h0oooo0ooo00170?ooo`?o003o0P3oool3o`00oc00oooo0ol0
0?l[0?oooeSoo`00EOl00?l?0?ooo`003@3oool3ool000<0oooo0ooo001H0?ooo`?o003o=@3oool3
o`00ob/0ooooF?oo001Eo`00o`l0oooo000=0?ooo`?oo`00UP3oool3o`00ob/0ooooF?oo001Eo`00
o`l0oooo002W0?ooo`?o003o:P3ooomHool005Go003o3`3oool006L0oooo0ol00?lm0?ooo`?o003o
:P3ooomHool005Go003o3`3oool002L0oooo0ooo000R0?ooo`?oo`000P3oool3ool001<0oooo0ol0
0?l30?ooo`?o003o;`3oool3o`00o`D0oooo0ol00?lZ0?oooeSoo`00EOl00?l?0?ooo`009`3oool3
ool00280oooo0ooo00020?ooo`?oo`004`3oool3o`00o`<0oooo0ol00?l_0?ooo`?o003o503oool3
o`00oa/0ooooF?oo001Eo`00o`l0oooo000W0?ooo`?oo`008P3oool3ool00080oooo0ooo000I0?oo
o`?o003o;`3oool3o`00oa@0oooo0ol00?lK0?oooeSoo`00EOl00?l?0?ooo`00]P3oool3o`00oa/0
ooooF?oo001Eo`00o`l0oooo002=0?ooo`?o003oA03ooomHool005Go003o3`3oool004X0oooo0ooo
00100?ooo`?o003oA03ooomHool005Go003o3`3oool003<0oooo0ooo000D0?ooo`?oo`00@03oool3
o`00oa@0oooo0ol00?l]0?oooeSoo`00EOl00?l?0?ooo`00<`3oool3ool001@0oooo0ooo001=0?oo
o`?o003o1`3oool3o`00o`/0oooo0ol00?lO0?oooeSoo`00EOl00?l?0?ooo`00<`3oool3ool00400
oooo0ol00?lQ0?ooo`?o003o1`3oool3o`00o`/0oooo0ol00?lO0?oooeSoo`00EOl00?l?0?ooo`00
7`3oool3ool005@0oooo0ol00?lQ0?ooo`?o003o5@3oool3o`00oal0ooooF?oo001Eo`00o`l0oooo
000O0?ooo`?oo`001P3oool3ool004/0oooo0ol00?l;0?ooo`?o003oC@3ooomHool005Go003o3`3o
ool001l0oooo0ooo00060?ooo`?oo`00:03oool3ool002h0oooo0ol00?m=0?oooeSoo`00EOl00?l?
0?ooo`00:03oool3ool002P0oooo0ooo000^0?ooo`?o003oC@3ooomHool005Go003o3`3oool005<0
oooo0ooo000J0?ooo`?o003o?03oool3o`00ob80ooooF?oo001Eo`00o`l0oooo001`0?ooo`?o003o
=`3oool3o`00o`80oooo0ol00?lR0?oooeSoo`00EOl00?l?0?ooo`00FP3oool3ool001<0oooo0ol0
0?lg0?ooo`?o003o0P3oool3o`00ob80ooooF?oo001Eo`00o`l0oooo001J0?ooo`?oo`00>P3oool3
o`00oa00oooo0ol00?lW0?oooeSoo`00EOl00?l?0?ooo`00FP3oool3ool003X0oooo0ol00?l60?oo
o`?o003o<@3ooomHool005Go003o3`3oool005/0oooo0ooo000i0?ooo`?o003o1P3oool3o`00oc40
ooooF?oo001Eo`00o`l0oooo001G0?ooo`?oo`0000@0ooooool00?oo003oo`00>@3oool3o`00o`H0
oooo0ol00?la0?oooeSoo`00EOl00?l?0?ooo`00E`3oool3ool000040?oooooo003oo`00ool002d0
oooo0ol00?l90?ooo`?o003o5@3oool3o`00ob80ooooF?oo001Eo`00o`l0oooo000@0?ooo`?oo`00
A03oool3ool00340oooo0ol00?lQ0?ooo`?o003o8P3ooomHool005Go003o3`3oool00100oooo0ooo
001h0?ooo`?o003o8@3oool3o`00ob80ooooF?oo001Eo`00o`l0oooo000@0?ooo`?oo`00`@3ooomH
ool005Go003o3`3oool00=@0ooooF?oo001Eo`00o`l0oooo003D0?oooeSoo`00EOl00?l?0?ooo`00
e03ooomHool005Go003o3`3oool00=@0ooooF?oo001Eo`00o`l0oooo000=0?ooo`?oo`00D`3oool3
o`00o`@0oooo0ol00?mW0?oooeSoo`00EOl00?l?0?ooo`003@3oool3ool005<0oooo0ol00?l40?oo
o`?o003oI`3ooomHool005Go003o3`3oool000d0oooo0ooo001C0?ooo`?o003o103oool3o`00ofL0
ooooF?oo001Eo`00o`l0oooo002Q0?ooo`?o003o<03ooomHool005Go003o3`3oool000/0oooo0ooo
00080?ooo`?oo`00R03oool3o`00o`/0oooo0ol00?lR0?oooeSoo`00EOl00?l?0?ooo`002`3oool3
ool000P0oooo0ooo001T0?ooo`?o003o8@3oool3o`00o`<0oooo0ol00?l50?ooo`?o003o8P3ooomH
ool005Go003o3`3oool000/0oooo0ooo00080?ooo`?oo`003P3oool3ool005<0oooo0ol00?lW0?oo
o`?o003o1@3oool3o`00ob80ooooF?oo001Eo`00o`l0oooo000W0?ooo`?oo`008@3oool3ool002l0
oooo0ol00?lW0?ooo`?o003o:P3ooomHool005Go003o3`3oool002L0oooo0ooo000Q0?ooo`?oo`00
QP3ooomHool005Go003o3`3oool004/0oooo0ooo00260?oooeSoo`00EOl00?l?0?ooo`00e03ooomH
ool005Go003o3`3oool00:h0oooo0ol00?lS0?oooeSoo`00EOl00?l?0?ooo`00[P3oool3o`00o`H0
oooo0ol00?lJ0?oooeSoo`00EOl00?l?0?ooo`00B`3oool3ool00600oooo0ol00?l60?ooo`?o003o
6P3ooomHool005Go003o3`3oool004/0oooo0ooo000T0?ooo`?o003o@P3oool3o`00oaX0ooooF?oo
001Eo`00o`l0oooo00190?ooo`Goo`00903oool3o`00oa<0oooo0ol00?m90?oooeSoo`00EOl00?l?
0?ooo`009@3oool3ool00240oooo0ooo000V0?ooo`?o003o4`3oool3o`00o`L0oooo0ol00?lo0?oo
oeSoo`00EOl00?l?0?ooo`009@3oool3ool00240oooo0ooo00090?ooo`?oo`000P3oool3ool001`0
oooo0ol00?l<0?ooo`?o003o1`3oool3o`00ocl0ooooF?oo001Eo`00o`l0oooo000U0?ooo`?oo`00
;@3oool3ool00080oooo0ooo000L0?ooo`?o003o1@3oool3o`00o`h0oooo0ol00?l90?ooo`?o003o
<`3ooomHool005Go003o3`3oool005D0oooo0ooo00020?ooo`?oo`00703oool3o`00o`D0oooo0ol0
0?lJ0?ooo`?o003o<`3ooomHool005Go003o3`3oool00840oooo0ol00?lJ0?ooo`?o003o5@3oool3
o`00oa/0ooooF?oo001Eo`00o`l0oooo002f0?ooo`?o003o6`3ooomHool005Go003o3`3oool00;H0
oooo0ol00?lK0?oooeSoo`00EOl00?l?0?ooo`00G03oool3ool000d0oooo0ol00?m40?ooo`?o003o
7P3ooomHool005Go003o3`3oool002@0oooo0ooo000R0?ooo`?oo`00403oool3ool000d0oooo0ol0
0?m40?ooo`?o003o7P3ooomHool005Go003o3`3oool002@0oooo0ooo000R0?ooo`?oo`00403oool3
ool000d0oooo0ol00?m40?ooo`?o003o7P3ooomHool005Go003o3`3oool002@0oooo0ooo000R0?oo
o`?oo`00D@3oool3o`00oaH0oooo0ol00?lK0?oooeSoo`00EOl00?l?0?ooo`00K`3oool3o`00ob40
oooo0ol00?l70?ooo`?o003o5P3oool3o`00oa/0ooooF?oo001Eo`00o`l0oooo001_0?ooo`?o003o
8@3oool3o`00o`L0oooo0ol00?lF0?ooo`?o003o6`3ooomHool005Go003o3`3oool006l0oooo0ol0
0?lQ0?ooo`?o003o1P3oool3o`00ocD0ooooF?oo001Eo`00o`l0oooo001<0?ooo`?oo`00C@3oool3
o`00ocD0ooooF?oo001Eo`00o`l0oooo001<0?ooo`?oo`00C@3oool3o`00ocD0ooooF?oo001Eo`00
o`l0oooo001;0?ooo`Coo`00Q@3ooomHool005Go003o3`3oool004/0oooo0ooo00260?oooeSoo`00
EOl00?l?0?ooo`00=@3oool3ool001<0oooo0ooo000Y0?ooo`?o003o9`3oool3o`00oc00ooooF?oo
001Eo`00o`l0oooo000e0?ooo`?oo`00?`3oool3o`00obL0oooo0ol00?l`0?oooeSoo`00EOl00?l?
0?ooo`00303oool3ool002H0oooo0ooo00050?ooo`?oo`000P3oool3ool00180oooo0ooo000M0?oo
o`?o003o9`3oool3o`00oc00ooooF?oo001Eo`00o`l0oooo000<0?ooo`?oo`00;P3oool3ool00080
oooo0ooo000B0?ooo`?oo`00NP3ooomHool005Go003o3`3oool000/0oooo1?oo000^0?ooo`?oo`00
0P3oool3ool00180oooo0ooo000E0?ooo`?o003o<@3oool3o`00o`@0oooo1?l00?lV0?oooeSoo`00
EOl00?l?0?ooo`002`3oool3ool00640oooo0ol00?la0?ooo`?o003o103oool4o`00obH0ooooF?oo
001Eo`00o`l0oooo000;0?ooo`?oo`00H@3oool3o`00oc40oooo1Ol00?l20?ooo`Co003o9P3ooomH
ool005Go003o3`3oool00:00oooo0ol00?l20?ooo`?o003o;03ooomHool005Go003o3`3oool00:00
oooo0ol00?l20?ooo`?o003o;03ooomHool005Go003o3`3oool002d0oooo0ooo00160?ooo`?o003o
9`3oool3o`00o`T0oooo0ol00?lU0?oooeSoo`00EOl00?l?0?ooo`00;@3oool3ool001<0oooo0ooo
000`0?ooo`?o003o<`3oool3o`00obD0ooooF?oo001Eo`00o`l0oooo000B0?ooo`?oo`00603oool3
ool001<0oooo0ooo000`0?ooo`?o003o<`3oool3o`00obD0ooooF?oo001Eo`00o`l0oooo000B0?oo
o`?oo`00;P3oool3ool008h0ooooF?oo001Eo`00o`l0oooo000B0?ooo`?oo`004`3oool3ool00:T0
ooooF?oo001Eo`00o`l0oooo000F0?ooo`?oo`003`3oool3ool00:T0ooooF?oo001Eo`00o`l0oooo
000F0?ooo`?oo`003`3oool3ool000d0oooo0ooo002I0?oooeSoo`00EOl00?l?0?ooo`005P3oool3
ool001l0oooo0ooo00080?ooo`?oo`007@3oool3o`00ofh0ooooF?oo001Eo`00o`l0oooo000h0?oo
o`?oo`00203oool3ool001X0oooo0ooo0003o`00ofh0ooooF?oo001Eo`00o`l0oooo00130?ooo`?o
o`006P3oool3ool000?o003oKP3ooomHool005Go003o3`3oool00600oooo0ooo001a0?oooeSoo`00
EOl00?l?0?ooo`00e03ooomHool005Go003o3`3oool001<0oooo0ooo000l0?ooo`?oo`00;`3oool3
o`00odd0ooooF?oo001Eo`00o`l0oooo000C0?ooo`Koo`00503oool3ool00280oooo0ooo000:0?oo
o`?oo`008P3oool3o`00odd0ooooF?oo001Eo`00o`l0oooo000C0?ooo`Koo`003`3oool3ool00080
oooo0ooo000R0?ooo`?oo`002P3oool3ool00280oooo0ol00?m=0?oooeSoo`00EOl00?l?0?ooo`00
5@3oool4ool000l0oooo0ooo00020?ooo`?oo`00;`3oool3ool00780ooooF?oo001Eo`00o`l0oooo
000X0?ooo`?oo`00Z@3ooomHool005Go003o3`3oool003h0oooo0ooo001X0?ooo`?o003o:03ooomH
ool005Go003o3`3oool003h0oooo0ooo001X0?ooo`?o003o:03ooomHool005Go003o3`3oool003h0
oooo0ooo001X0?ooo`?o003o:03ooomHool005Go003o3`3oool00=@0ooooF?oo001Eo`00o`l0oooo
000e0?ooo`?oo`00W03ooomHool005Go003o3`3oool003D0oooo0ooo002L0?oooeSoo`00EOl00?l?
0?ooo`00603oool3ool001X0oooo0ooo00030?ooo`?oo`00UP3ooomHool005Go003o3`3oool00100
oooo0ooo00050?ooo`?oo`00803oool3ool009H0ooooF?oo001Eo`00o`l0oooo000@0?ooo`?oo`00
1@3oool3ool00200oooo0ooo001_0?ooo`?o003o903ooomHool005Go003o3`3oool00100oooo0ooo
002J0?ooo`?o003o903ooomHool005Go003o3`3oool00:d0oooo0ol00?lT0?oooeSoo`00EOl00?l?
0?ooo`00?`3oool3ool00980ooooF?oo001Eo`00o`l0oooo000/0?ooo`?oo`003`3oool4ool00004
0?oooooo003oo`00ool008h0ooooF?oo001Eo`00o`l0oooo000/0?ooo`?oo`003`3oool4ool00004
0?oooooo003oo`00ool00640oooo0ol00?lZ0?oooeSoo`00EOl00?l?0?ooo`00;03oool3ool000l0
oooo0ooo00020?ooo`?oo`004P3oool3ool004`0oooo0ol00?lZ0?oooeSoo`00EOl00?l?0?ooo`00
>`3oool3ool001X0oooo0ooo001<0?ooo`?o003o:P3ooomHool005Go003o3`3oool003/0oooo0ooo
000J0?ooo`?oo`00E@3oool3o`00ob40ooooF?oo001Eo`00o`l0oooo000K0?ooo`?oo`007@3oool3
ool00780oooo0ol00?lQ0?oooeSoo`00EOl00?l?0?ooo`006`3oool3ool001@0oooo0ooo000=0?oo
o`?oo`00J`3oool3o`00ob40ooooF?oo001Eo`00o`l0oooo000K0?ooo`?oo`00503oool3ool000d0
oooo0ooo002?0?oooeSoo`00EOl00?l?0?ooo`00<P3oool3ool000d0oooo0ooo002?0?oooeSoo`00
EOl00?l?0?ooo`002P3oool2ool00<P0ooooF?oo001Eo`00o`l0oooo000:0?ooo`;oo`005`3oool3
ool004l0oooo0ol00?mL0?oooeSoo`00EOl00?l?0?ooo`002P3oool2ool001L0oooo0ooo001?0?oo
o`?o003oG03ooomHool005Go003o3`3oool002<0oooo0ooo00130?ooo`?o003o2@3oool3o`00o`H0
oooo1_l00?m@0?oooeSoo`00EOl00?l?0?ooo`00J@3oool3o`00oa80oooo1_l00?m@0?oooeSoo`00
EOl00?l?0?ooo`00A`3oool3ool000d0oooo0ooo000?0?ooo`?o003o4P3oool6o`00oe00ooooF?oo
001Eo`00o`l0oooo00170?ooo`?oo`003@3oool3ool007X0ooooF?oo001Eo`00o`l0oooo000B0?oo
o`?oo`00<P3oool3ool000/0oooo1Ooo001j0?oooeSoo`00EOl00?l?0?ooo`003@3oool3ool00080
oooo0ooo00100?ooo`?oo`00E03oool3o`00obD0ooooF?oo001Eo`00o`l0oooo000=0?ooo`?oo`00
0P3oool3ool00400oooo0ooo001D0?ooo`?o003o9@3ooomHool005Go003o3`3oool000d0oooo0ooo
002L0?ooo`Co003o903ooomHool005Go003o3`3oool008H0oooo0ol00?lT0?ooo`?o003o903ooomH
ool005Go003o3`3oool00140oooo0ooo001B0?ooo`?o003o1`3oool3o`00oa<0oooo0ol00?lT0?oo
o`?o003o903ooomHool005Go003o3`3oool00140oooo0ooo001B0?ooo`?o003o1`3oool3o`00oa<0
oooo0ol00?m;0?oooeSoo`00EOl00?l?0?ooo`004@3oool3ool00580oooo0ol00?l70?ooo`?o003o
H@3ooomHool005Go003o3`3oool003l0oooo0ooo001^0?ooo`?o003o8@3ooomHool005Go003o3`3o
ool002/0oooo0ooo000A0?ooo`?oo`00KP3oool3o`00ob40ooooF?oo001Eo`00o`l0oooo000U0?oo
o`?oo`000`3oool3ool00140oooo0ooo001U0?ooo`?o003o1P3oool3o`00ob40ooooF?oo001Eo`00
o`l0oooo000U0?ooo`?oo`000`3oool3ool007T0oooo0ol00?lZ0?oooeSoo`00EOl00?l?0?ooo`00
9@3oool3ool007l0oooo0ol00?lZ0?oooeSoo`00EOl00?l?0?ooo`00:`3oool3ool00:H0ooooF?oo
001Eo`00o`l0oooo000[0?ooo`?oo`0000@0ooooool00?oo003oo`00XP3ooomHool005Go003o3`3o
ool002/0oooo0ooo0000103oooooo`00ool00?oo002R0?oooeSoo`00EOl00?l?0?ooo`00;`3oool5
ool002l0oooo0ol00?m^0?oooeSoo`00EOl00?l?0?ooo`00<@3oool3ool002l0oooo0ol00?m^0?oo
oeSoo`00EOl00?l?0?ooo`00303oool3ool00280oooo0ooo000_0?ooo`?o003o6`3oool3o`00oc40
oooo0ol00?lL0?oooeSoo`00EOl00?l?0?ooo`00303oool3ool006<0oooo0ol00?l<0?ooo`?o003o
<@3oool3o`00oa`0ooooF?oo001Eo`00o`l0oooo000<0?ooo`?oo`00H`3oool3o`00o``0oooo0ol0
0?la0?ooo`Ko003o6@3ooomHool005Go003o3`3oool00780oooo0ol00?m30?ooo`?o003o6@3ooomH
ool005Go003o3`3oool005L0oooo0ooo001N0?ooo`?o003o6@3ooomHool005Go003o3`3oool005L0
oooo0ooo001j0?oooeSoo`00EOl00?l?0?ooo`00B03oool3ool000`0oooo0ooo000K0?ooo`?o003o
;03oool3o`00obd0ooooF?oo001Eo`00o`l0oooo00180?ooo`?oo`00:P3oool3o`00ob`0oooo0ol0
0?l]0?oooeSoo`00EOl00?l?0?ooo`00B03oool3ool002X0oooo0ol00?l:0?ooo`?o003o7`3oool3
o`00o`h0oooo0ol00?lL0?oooeSoo`00EOl00?l?0?ooo`00B03oool3ool003L0oooo1?l00?lF0?oo
o`?o003o5P3oool3o`00oa`0ooooF?oo001Eo`00o`l0oooo00180?ooo`?oo`00<@3oool3o`00o`<0
oooo1?l00?lF0?ooo`?o003o5P3oool3o`00oa`0ooooF?oo001Eo`00o`l0oooo000Q0?ooo`?oo`00
903oool3ool002T0oooo0ol00?l50?ooo`?o003o103oool3o`00oaH0oooo0ol00?le0?oooeSoo`00
EOl00?l?0?ooo`008@3oool3ool00500oooo0ol00?l50?ooo`?o003o:P3oool4o`00obL0ooooF?oo
001Eo`00o`l0oooo000Q0?ooo`?oo`007`3oool6ool002/0oooo0ol00?lb0?ooo`Co003o2P3oool3
o`00oaX0ooooF?oo001Eo`00o`l0oooo00130?ooo`Koo`00403oool3ool004d0oooo1?l00?l:0?oo
o`?o003o6P3ooomHool005Go003o3`3oool004<0oooo1_oo000@0?ooo`?oo`00F`3oool3o`00oaX0
ooooF?oo001Eo`00o`l0oooo00140?ooo`?oo`004P3oool3ool007P0ooooF?oo001Eo`00o`l0oooo
00140?ooo`?oo`00S@3ooomHool005Go003o3`3oool003X0oooo0ooo00070?ooo`?oo`00DP3oool3
o`00ocP0ooooF?oo001Eo`00o`l0oooo000j0?ooo`Coo`005@3oool3ool004<0oooo0ol00?lh0?oo
oeSoo`00EOl00?l?0?ooo`00>P3oool4ool001D0oooo0ooo000_0?ooo`?o003o4@3oool3o`00ocP0
ooooF?oo001Eo`00o`l0oooo000e0?ooo`?oo`000`3oool3ool001D0oooo0ooo000_0?ooo`?o003o
C03ooomHool005Go003o3`3oool003D0oooo0ooo001=0?ooo`?o003oo`3oool90?ooo`006`3oool3
ool001L0oooo0ooo001k0?ooo`?o003ofP3oool001/0oooo0ooo002E0?ooo`?o003ofP3oool001/0
oooo0ooo002E0?ooo`?o003ofP3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-1.1227, \
-1.0611, 0.011199, 0.011199}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-63.1851, -2.62981, 0.296885, 0.296885}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example B different uniform distributions", "Section"],

Cell[CellGroupData[{

Cell["Generate data from two non-rectangular uniform classes", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[{
    \(\(n1\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(n2\  = \ 100;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Specialized data generation", "Subsubsection"],

Cell[BoxData[
    \(\(SpecialDataGeneration[\ 
          flag_] := \[IndentingNewLine]Module[{x, 
            y}, \[IndentingNewLine]{x, y}\  = \ 
            r2[1]; \[IndentingNewLine]While[\(-flag\)*x\  > \ 
              flag\ *\ y, \ {x, y}\  = \ r2[1]]; {x, y}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = \ Table[SpecialDataGeneration[1], {n1}];\)\), "\n", 
    \(\(data2\  = \ Table[SpecialDataGeneration[\(-1\)], \ {n2}];\)\), "\n", 
    \(\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[data2, pr, style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ 
        Show[gd1, gd2, \ yS, \ FrameTicks \[Rule] None];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.38973 .69023 Mdot
.92797 .74704 Mdot
.60864 .83117 Mdot
.22047 .96051 Mdot
.82579 .27522 Mdot
.53863 .60265 Mdot
.2968 .87133 Mdot
.91144 .59112 Mdot
.45575 .76095 Mdot
.63715 .44613 Mdot
.5605 .811 Mdot
.59119 .67109 Mdot
.91839 .36981 Mdot
.97032 .45441 Mdot
.34058 .80496 Mdot
.80078 .8659 Mdot
.32506 .79524 Mdot
.46199 .55758 Mdot
.84323 .39312 Mdot
.8189 .4495 Mdot
.48331 .98672 Mdot
.87106 .43289 Mdot
.80054 .44265 Mdot
.74015 .4626 Mdot
.97669 .98821 Mdot
.52307 .54708 Mdot
.83911 .21721 Mdot
.64299 .97918 Mdot
.76698 .55124 Mdot
.14661 .8664 Mdot
.73915 .51147 Mdot
.99405 .05383 Mdot
.61824 .79364 Mdot
.83145 .88351 Mdot
.77418 .58138 Mdot
.79168 .33306 Mdot
.43444 .89351 Mdot
.62011 .53453 Mdot
.94673 .59841 Mdot
.62112 .48566 Mdot
.75581 .27935 Mdot
.95918 .94134 Mdot
.72835 .46244 Mdot
.11319 .92296 Mdot
.48425 .75023 Mdot
.93225 .97514 Mdot
.96812 .03875 Mdot
.44338 .98102 Mdot
.43463 .67366 Mdot
.20648 .9603 Mdot
.32639 .74575 Mdot
.91135 .54294 Mdot
.83432 .30845 Mdot
.09948 .90378 Mdot
.92659 .76768 Mdot
.86467 .28858 Mdot
.74685 .77544 Mdot
.52852 .49195 Mdot
.97622 .48654 Mdot
.88169 .57781 Mdot
.92943 .90906 Mdot
.95015 .80517 Mdot
.45819 .71115 Mdot
.64981 .52667 Mdot
.94653 .32803 Mdot
.96536 .83654 Mdot
.87391 .84616 Mdot
.93952 .93214 Mdot
.87477 .31165 Mdot
.67038 .73746 Mdot
.82334 .47792 Mdot
.70204 .44321 Mdot
.82319 .5921 Mdot
.38218 .94137 Mdot
.87871 .65501 Mdot
.57828 .75035 Mdot
.69755 .86085 Mdot
.75446 .33419 Mdot
.99056 .42259 Mdot
.90643 .18282 Mdot
.65778 .68512 Mdot
.28471 .82223 Mdot
.08445 .92982 Mdot
.75392 .48346 Mdot
.88392 .55404 Mdot
.88854 .36953 Mdot
.92451 .91285 Mdot
.5662 .88341 Mdot
.30331 .73892 Mdot
.55549 .70115 Mdot
.94571 .50711 Mdot
.93968 .97501 Mdot
.54954 .97624 Mdot
.47242 .71703 Mdot
.10551 .90556 Mdot
.73586 .78802 Mdot
.59442 .69731 Mdot
.604 .51509 Mdot
.96388 .56201 Mdot
.65936 .53513 Mdot
0 0 1 r
.02299 .29904 Mdot
.35992 .33389 Mdot
.25936 .42337 Mdot
.40621 .28343 Mdot
.70933 .21896 Mdot
.11987 .5167 Mdot
.40204 .44024 Mdot
.24158 .63961 Mdot
.384 .14616 Mdot
.43216 .28566 Mdot
.7931 .1566 Mdot
.64702 .20191 Mdot
.30332 .37959 Mdot
.41039 .55735 Mdot
.52873 .25163 Mdot
.08591 .66928 Mdot
.20036 .53938 Mdot
.18657 .77355 Mdot
.54839 .34242 Mdot
.14294 .78012 Mdot
.70283 .17407 Mdot
.23417 .10762 Mdot
.34719 .5093 Mdot
.16557 .7308 Mdot
.28232 .33684 Mdot
.31841 .17631 Mdot
.21833 .28273 Mdot
.51055 .1136 Mdot
.20623 .57744 Mdot
.85409 .0731 Mdot
.28721 .69184 Mdot
.32164 .1005 Mdot
.41609 .00546 Mdot
.49405 .28432 Mdot
.10263 .8242 Mdot
.28067 .00655 Mdot
.66224 .14903 Mdot
.36504 .47006 Mdot
.49237 .16559 Mdot
.39469 .33645 Mdot
.59032 .18909 Mdot
.7275 .19236 Mdot
.27148 .62077 Mdot
.85126 .0387 Mdot
.6646 .12722 Mdot
.17449 .46815 Mdot
.34813 .62327 Mdot
.14654 .27662 Mdot
.52297 .33208 Mdot
.66676 .29833 Mdot
.21045 .52863 Mdot
.18559 .76703 Mdot
.74933 .02469 Mdot
.31155 .30794 Mdot
.40615 .39646 Mdot
.16996 .03627 Mdot
.87823 .06933 Mdot
.2949 .38042 Mdot
.21641 .76605 Mdot
.0894 .84684 Mdot
.63509 .28429 Mdot
.03141 .11367 Mdot
.45445 .51231 Mdot
.27713 .09394 Mdot
.14785 .20932 Mdot
.0621 .91632 Mdot
.03564 .8076 Mdot
.50901 .15413 Mdot
.88259 .03104 Mdot
.12835 .53587 Mdot
.10667 .03337 Mdot
.07121 .6146 Mdot
.1432 .36693 Mdot
.04052 .80205 Mdot
.62924 .21775 Mdot
.282 .08838 Mdot
.26808 .27294 Mdot
.39447 .06229 Mdot
.1796 .52697 Mdot
.37133 .12846 Mdot
.07788 .49855 Mdot
.30508 .50891 Mdot
.26951 .70192 Mdot
.04231 .64587 Mdot
.16244 .14965 Mdot
.42685 .26934 Mdot
.16229 .56247 Mdot
.66979 .07369 Mdot
.5768 .38284 Mdot
.47495 .27817 Mdot
.47849 .48108 Mdot
.32466 .43845 Mdot
.30476 .06209 Mdot
.41573 .54915 Mdot
.3377 .12844 Mdot
.19069 .36524 Mdot
.14852 .04338 Mdot
.69872 .05577 Mdot
.21133 .55842 Mdot
.70619 .12378 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`1;ooooo`Go003o8_ooool5o`00ojCo
oooo0Ol00001ooooo`0000?o0000ooooooooool0Boooool5o`00ob;ooooo1Ol00?nTooooo`7o0000
0Oooool00003o`000?oooooooooo04_ooooo1Ol00?lRooooo`Go003oY?ooool1o`00007ooooo0000
0ol0003oooooooooo`1<ooooo`?o003o9?ooool3o`00ojGooooo0Ol00001ooooo`0000?o0000oooo
ooooool0d_ooool3o`00odKooooo0Ol00001ooooo`0000?o0000ooooooooool0dOooool5o`00odGo
oooo0Ol00001ooooo`0000?o0000ooooooooool0dOooool5o`00ob;ooooo0ol00?lPooooo`7o0000
0Oooool00003o`000?oooooooooo01[ooooo0ol00?l?ooooo`?o003oX_ooool5o`00ob7ooooo1Ol0
0?lOooooo`7o00000Oooool00003o`000?oooooooooo01Wooooo1Ol00?l=ooooo`Go003oX_ooool3
o`00oa[ooooo0ol00?l5ooooo`Go003o5Oooool3ool000Oooooo0Ol00001ooooo`0000?o0000oooo
ooooool06Oooool5o`00o`Sooooo0ol00?l2ooooo`Go003o__ooool5o`00o`Cooooo1Ol00?lDoooo
o`Goo`001_ooool1o`00007ooooo00000ol0003oooooooooo`0Iooooo`Go003o1oooool5o`00o`03
ooooool00?oo003o00?o003o__ooool5o`00o`Gooooo0ol00?lEooooo`Goo`001_ooool1o`00007o
oooo00000ol0003oooooooooo`0Jooooo`?o003o2?ooool5o`00o`;ooooo0ol00?noooooo`Go003o
7Oooool5ool000Kooooo0Ol00001ooooo`0000?o0000ooooooooool09Oooool5o`00olGooooo0ol0
0?lOooooo`?oo`001?ooool3ool0007o00000Oooool00003o`000?oooooooooo02Kooooo0ol00?nK
ooooo`?o003oD?ooool4ool0007o00000Oooool00003o`000?oooooooooo0<?ooooo1Ol00?m?oooo
o`Coo`000Ol00001ooooo`0000?o0000ooooooooool0Doooool3o`00oaKooooo0ol00?mDooooo`Go
003oCoooool4ool0007o00000Oooool00003o`000?oooooooooo05;ooooo1Ol00?lDooooo`Go003o
Doooool5o`00oe3ooooo0ooo0001o`00007ooooo00000ol0003oooooooooo`1Booooo`Go003o5?oo
ool5o`00oeCooooo0ol00?l`ooooo`?o003o8Oooool1o`00007ooooo00000ol0003oooooooooo`1B
ooooo`Go003o5?ooool5o`00od_ooooo0ol00?lbooooo`?o003o0oooool5o`00ob3ooooo0Ol00001
ooooo`0000?o0000ooooooooool0Doooool3o`00oaKooooo0ol00?m;ooooo`Go003o<?ooool5o`00
o`;ooooo1Ol00?lPooooo`7o00000Oooool00003o`000?oooooooooo0;[ooooo1Ol00?l`ooooo`Go
003o0_ooool5o`00ob3ooooo0Ol00001ooooo`0000?o0000ooooooooool0^_ooool5o`00oc3ooooo
1Ol00?l3ooooo`?o003o8Oooool1o`00007ooooo00000ol0003oooooooooo`1<ooooo`?o003oK?oo
ool3o`00oc;ooooo0ol00?lXooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo1Ol00?o;
ooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo1Ol00?o;ooooo`7o00000Oooool00003
o`000?oooooooooo04[ooooo1_l00?o;ooooo`7o00000Oooool00003o`000?oooooooooo04[ooooo
1Ol00?l9ooooo`?o003o`?ooool1o`00007ooooo00000ol0003oooooooooo`1:ooooo`Go003o2?oo
ool5o`00okoooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool3o`00o`[ooooo0ol00?l9
ooooo`Go003o_oooool1o`00007ooooo00000ol0003oooooooooo`0mooooo`Go003o5Oooool5o`00
okoooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool3o`00ocKooooo1Ol00?lFooooo`?o
003o<oooool3o`00oh[ooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool5o`00ocGooooo
1Ol00?m;ooooo`Go003oROooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`Go003o=_oo
ool3o`00odcooooo1Ol00?ldooooo`?o003oD_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooo`Go003oQOooool5o`00obSooooo0ol00?l8ooooo`Go003oDOooool1o`00007ooooo00000ol0
003oooooooooo`04ooooo`?o003oEOooool3o`00o`Oooooo0ol00?lUooooo`?o003o:?ooool5o`00
o`Oooooo1Ol00?mAooooo`7o00000Oooool00003o`000?oooooooooo05_ooooo1Ol00?l5ooooo`Go
003oCoooool5o`00o`Oooooo1Ol00?mAooooo`7o00000Oooool00003o`000?oooooooooo05_ooooo
1Ol00?l5ooooo`Go003oCoooool5o`00o`Sooooo0ol00?mBooooo`7o00000Oooool00003o`000?oo
oooooooo05_ooooo1Ol00?l5ooooo`Go003oD?ooool3o`00oekooooo0Ol00001ooooo`0000?o0000
ooooooooool0G?ooool3o`00o`Oooooo0ol00?nbooooo`7o00000Oooool00003o`000?oooooooooo
06Wooooo0ol00?n_ooooo`7o00000Oooool00003o`000?oooooooooo02[ooooo0ol00?lkooooo`Go
003oC?ooool3o`00oeoooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool5o`00oc[ooooo
1Ol00?lPooooo`?o003o:?ooool5o`00oekooooo0Ol00001ooooo`0000?o0000ooooooooool0:Ooo
ool5o`00oc[ooooo1Ol00?lOooooo`Go003o9oooool5o`00ob;ooooo0ol00?liooooo`7o00000Ooo
ool00003o`000?oooooooooo02Wooooo1Ol00?lkooooo`?o003o8?ooool5o`00obOooooo1Ol00?lQ
ooooo`Go003o>?ooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`?o003oG?ooool8o`00
obSooooo0ol00?lRooooo`Go003o>?ooool1o`00007ooooo00000ol0003oooooooooo`28ooooo`So
003oC_ooool5o`00ocSooooo0Ol00001ooooo`0000?o0000ooooooooool0R?ooool5o`00oe;ooooo
0ol00?liooooo`7o00000Oooool00003o`000?oooooooooo05Oooooo0ol00?l^ooooo`Go003o>?oo
ool3o`00oe?ooooo0Ol00001ooooo`0000?o0000ooooooooool0E_ooool5o`00obkooooo0ol00?lh
ooooo`Go003oD_ooool1o`00007ooooo00000ol0003oooooooooo`1Fooooo`Go003oJOooool5o`00
ocKooooo0ooo000Iooooo`7o00000Oooool00003o`000?oooooooooo05Kooooo1Ol00?mYooooo`Go
003o=Oooool5ool001Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Eoooool3o`00od_ooooo
0ol00?lMooooo`?o003o=_ooool5ool001Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Y?oo
ool5o`00ob?ooooo0ol00?l_ooooo`Goo`006?ooool1o`00007ooooo00000ol0003oooooooooo`2T
ooooo`Go003o8_ooool5o`00oboooooo0ooo000Iooooo`7o00000Oooool00003o`000?oooooooooo
0:Cooooo1Ol00?lRooooo`Go003oBoooool1o`00007ooooo00000ol0003oooooooooo`2Uooooo`?o
003o3Oooool3o`00oa?ooooo1Ol00?m;ooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo
1Ol00?lCooooo`?o003oC?ooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`?o003oRooo
ool5o`00of;ooooo0Ol00001ooooo`0000?o0000ooooooooool09Oooool5o`00oh[ooooo1Ol00?mR
ooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo1Ol00?n6ooooo`?o003o0_ooool3o`00
ocCooooo0ooo000/ooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo1Ol00?n5ooooo`Go
003o4oooool3o`00ob7ooooo1Ooo000[ooooo`7o00000Oooool00003o`000?oooooooooo02Kooooo
0ol00?n6ooooo`Go003o4_ooool5o`00ob3ooooo1Ooo000[ooooo`7o00000Oooool00003o`000?oo
oooooooo0:oooooo1Ol00?lBooooo`Go003o8?ooool5ool002_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0/?ooool3o`00oa?ooooo1Ol00?lQooooo`?oo`00;?ooool1o`00007ooooo00000ol0
003oooooooooo`37ooooo`?o003oDOooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0Toooool3o`00ohGooooo0Ol00001ooooo`0000?o0000oooooooo
ool0T_ooool5o`00ohCooooo0Ol00001ooooo`0000?o0000ooooooooool0T_ooool5o`00ohCooooo
0Ol00001ooooo`0000?o0000ooooooooool0T_ooool5o`00ohCooooo0Ol00001ooooo`0000?o0000
ooooooooool0Toooool3o`00ohGooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool3o`00
oj;ooooo0Ol00001ooooo`0000?o0000ooooooooool0B?ooool3o`00ob[ooooo1Ol00?nQooooo`7o
00000Oooool00003o`000?oooooooooo02Gooooo0ol00?lOooooo`Go003o:Oooool5o`00ofkooooo
0ooo000`ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo1Ol00?lNooooo`Go003o:Ooo
ool5o`00o`[ooooo0ol00?m=ooooo`?oo`004?ooool5ool002oooooo0Ol00001ooooo`0000?o0000
ooooooooool09?ooool5o`00oa7ooooo0ol00?l:ooooo`Go003o9?ooool3o`00o`?ooooo0ol00?l:
ooooo`Go003o00Coooooo`00ool00?oo003o9Oooool3o`00oaoooooo1Ooo000?ooooo`Goo`00;ooo
ool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`Go003o4?ooool5o`00o`[ooooo0ol00?lT
ooooo`Go003o0oooool3o`00o`Wooooo2_l00?lSooooo`Go003o7_ooool5ool000oooooo1Ooo000_
ooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo0ol00?lAooooo`Go003o<Oooool5o`00
o`;ooooo1Ol00?l8ooooo`[o003o8oooool5o`00oakooooo1Ooo000@ooooo`?oo`002?ooool3ool0
02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool5o`00oc7ooooo1Ol00?l2ooooo`Go
003o2Oooool3o`00o`03ooooool00?oo003o00?o003o8oooool5o`00oaoooooo0ooo000Kooooo`Go
o`009?ooool1o`00007ooooo00000ol0003oooooooooo`0jooooo`?o003o<oooool3o`00o`?ooooo
1Ol00?l>ooooo`?o003o9Oooool3o`00o`Oooooo0ol00?ldooooo`Goo`009?ooool1o`00007ooooo
00000ol0003oooooooooo`02ooooo`?o003oL_ooool3o`00od3ooooo1Ol00?lcooooo`Goo`009?oo
ool1o`00007ooooo00001?l0003oooooooooooooool5o`00okCooooo1Ol00?ldooooo`?oo`009Ooo
ool1o`00007ooooo00001?l0003oooooooooooooool5o`00odoooooo0ol00?mRooooo`Go003o;?oo
ool3ool002gooooo0Ol00001ooooo`0000Co0000oooooooooooooooo1Ol00?m>ooooo`Go003oH_oo
ool3o`00obcooooo1Ooo0007ooooo`?oo`008_ooool1o`00007ooooo00000ol0003oooooooooo`02
ooooo`?o003oCoooool5o`00oi7ooooo1Ooo0006ooooo`Goo`008Oooool1o`00007ooooo00000ol0
003oooooooooo`1Dooooo`Go003oTOooool5ool000Kooooo1Ooo000Qooooo`7o00000Oooool00003
o`000?oooooooooo05Gooooo0ol00?nCooooo`?oo`001oooool5ool0027ooooo0Ol00001ooooo`00
00?o0000ooooooooool0m_ooool3ool002;ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
ool<ooooo`?oo`003Oooool1o`00007ooooo00000ol0003oooooooooo`2Aooooo`?o003oB_ooool3
ool002Wooooo1Ooo000<ooooo`7o00000Oooool00003o`000?oooooooooo06?ooooo0ol00?l6oooo
o`?o003o8Oooool5o`00ocoooooo0ooo0006ooooo`Goo`00:?ooool5ool000cooooo0Ol00001oooo
o`0000?o0000ooooooooool0C?ooool3o`00oa?ooooo1Ol00?l4ooooo`Go003o8?ooool5o`00ocko
oooo1Ooo0005ooooo`Goo`00:?ooool5ool000cooooo0Ol00001ooooo`0000?o0000ooooooooool0
Boooool5o`00oa;ooooo1Ol00?l4ooooo`Go003o8?ooool5o`00o`Cooooo0ol00?lgooooo`Goo`00
1Oooool5ool002Wooooo0ooo000=ooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo1Ol0
0?lBooooo`Go003o1?ooool5o`00ob7ooooo0ol00?l4ooooo`Go003o=_ooool5ool000Kooooo0ooo
000jooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo1Ol00?lCooooo`?o003o1_ooool3
o`00obWooooo1Ol00?lgooooo`?oo`00A?ooool1o`00007ooooo00000ol0003oooooooooo`1<oooo
o`?o003oBOooool5o`00ogkooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool3o`00ogoo
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`?o003o2oooool3
o`00onKooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool5o`00o`Wooooo1Ol00?o4oooo
o`?oo`001_ooool3ool001Gooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool5o`00o`Wo
oooo1Ol00?o3ooooo`Goo`001?ooool5ool001Cooooo0Ol00001ooooo`0000?o0000ooooooooool0
8oooool5o`00o`Wooooo1Ol00?o3ooooo`Goo`001?ooool5ool001Cooooo0Ol00001ooooo`0000?o
0000ooooooooool09?ooool3o`00o`_ooooo0ol00?lKooooo`Go003oY?ooool5ool000Cooooo1Ooo
000Dooooo`7o00000Oooool00003o`000?oooooooooo04oooooo1ol00?m;ooooo`?o003oE_ooool3
ool000Kooooo0ooo000Eooooo`7o00000Oooool00003o`000?oooooooooo04oooooo1ol00?m:oooo
o`Go003oM_ooool1o`00007ooooo00000ol0003oooooooooo`1?ooooo`Oo003oB_ooool5o`00ogKo
oooo0Ol00001ooooo`0000?o0000ooooooooool0D?ooool5o`00od_ooooo1Ol00?m8ooooo`?oo`00
:oooool1o`00007ooooo00000ol0003oooooooooo`1`ooooo`?o003o;_ooool3o`00odSooooo1Ooo
000Zooooo`7o00000Oooool00003o`000?oooooooooo06oooooo1Ol00?mhooooo`Goo`00:_ooool1
o`00007ooooo00000ol0003oooooooooo`1_ooooo`Go003oN?ooool5ool002[ooooo0Ol00001oooo
o`0000?o0000ooooooooool0Koooool5o`00ogWooooo0ooo000[ooooo`7o00000Oooool00003o`00
0?oooooooooo073ooooo0ol00?nXooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0A_ooool3o`00olkooooo0ooo0001ooooo`7o00000Oooool00003o`000?oooooooooo04Go
oooo1Ol00?o<ooooo`Goo`000Ol00001ooooo`0000?o0000ooooooooool0AOooool5o`00olcooooo
1Ooo0001o`00007ooooo00000ol0003oooooooooo`15ooooo`Go003oZoooool3ool001kooooo1Ooo
0001o`00007ooooo00000ol0003oooooooooo`16ooooo`?o003oZoooool5ool001kooooo0ooo0001
ooooo`7o00000Oooool00003o`000?oooooooooo05Sooooo0ol00?lDooooo`?o003oP_ooool5ool0
02;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Eoooool5o`00oa;ooooo1Ol00?mBooooo`?o
o`006Oooool3ool0013ooooo1Ooo000Rooooo`7o00000Oooool00003o`000?oooooooooo05Oooooo
1Ol00?lBooooo`Go003o?oooool3ool000oooooo1Ooo000Gooooo`Goo`004?ooool3ool002?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0Eoooool5o`00oa;ooooo1Ol00?lnooooo`Goo`003_oo
ool5ool001Oooooo1Ooo00001?ooooooo`00ool00?oo000booooo`7o00000Oooool00003o`000?oo
oooooooo05Sooooo0ol00?lDooooo`?o003o?oooool5ool000kooooo1Ooo000Gooooo`[oo`00:?oo
ool3ool000Kooooo0Ol00001ooooo`0000?o0000ooooooooool0/Oooool5ool000oooooo0ooo000I
ooooo`?oo`0000?oooooool00?oo00000ooo000Wooooo`Goo`001Oooool1o`00007ooooo00000ol0
003oooooooooo`2booooo`?oo`00<?ooool5ool002Oooooo1Ooo0005ooooo`7o00000Oooool00003
o`000?oooooooooo0<cooooo0ooo00001?ooooooo`00ool00?oo000Cooooo`?oo`00:?ooool5ool0
00Gooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool3o`00oi_ooooo2Ooo000nooooo`?o
o`001_ooool1o`00007ooooo00000ol0003oooooooooo`0/ooooo`Go003o<oooool3o`00ofCooooo
2Ooo0017ooooo`7o00000Oooool00003o`000?oooooooooo02cooooo1Ol00?lbooooo`Go003oHooo
ool9ool004Oooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool5o`00oc;ooooo1Ol00?mT
ooooo`?oo`0000Coooooool00?oo003oo`005?ooool3ool0037ooooo0Ol00001ooooo`0000?o0000
ooooooooool0;Oooool3o`00oc?ooooo1Ol00?lMooooo`?o003oG_ooool5ool0033ooooo0Ol00001
ooooo`0000?o0000ooooooooool0I?ooool3o`00oagooooo1Ol00?lTooooo`?oo`009?ooool3ool0
00oooooo1Ooo000Xooooo`?oo`001Oooool1o`00007ooooo00000ol0003oooooooooo`24ooooo`Go
003o8oooool5ool002;ooooo1Ooo000>ooooo`Goo`009oooool5ool000Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0Q?ooool5o`00o`[ooooo0ooo000Fooooo`Goo`008_ooool5ool000oooooo
0ooo000Xooooo`Goo`001?ooool1o`00007ooooo00000ol0003oooooooooo`25ooooo`?o003o2_oo
ool5ool001Gooooo1Ooo000Rooooo`Goo`00>_ooool5ool000Cooooo0Ol00001ooooo`0000?o0000
ooooooooool04_ooool3o`00oggooooo1Ooo000Fooooo`?oo`009?ooool3ool003cooooo0ooo0005
ooooo`7o00000Oooool00003o`000?oooooooooo017ooooo1Ol00?mlooooo`Goo`00Q?ooool1o`00
007ooooo00000ol0003oooooooooo`0Aooooo`Go003oOOooool3ool007Cooooo0ooo000>ooooo`7o
00000Oooool00003o`000?oooooooooo017ooooo1Ol00?lmooooo`?o003o2Oooool3o`00ojOooooo
1Ooo000=ooooo`7o00000Oooool00003o`000?oooooooooo01;ooooo0ol00?lmooooo`Go003o1ooo
ool5o`00oa_ooooo0ol00?m>ooooo`?oo`00=oooool5ool000gooooo0Ol00001ooooo`0000?o0000
ooooooooool07_ooool3o`00oc7ooooo1Ol00?l7ooooo`Go003o6_ooool5o`00obOooooo0ooo000R
ooooo`Goo`00=_ooool5ool000gooooo0Ol00001ooooo`0000?o0000ooooooooool07Oooool5o`00
oc3ooooo1Ol00?l7ooooo`Go003o6_ooool5o`00obKooooo1Ooo000Qooooo`Goo`00=oooool3ool0
00kooooo0Ol00001ooooo`0000?o0000ooooooooool07Oooool5o`00oc7ooooo0ol00?l9ooooo`?o
003o6oooool5o`00obKooooo1Ooo000Qooooo`Goo`00B?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Mooooo`Go003o3Oooool3o`00odcooooo0ol00?lWooooo`Goo`002Oooool3ool001Kooooo
0ooo0019ooooo`7o00000Oooool00003o`000?oooooooooo01kooooo0ol00?l=ooooo`Go003o1Ooo
ool3o`00ofkooooo0ooo0009ooooo`Goo`00HOooool1o`00007ooooo00000ol0003oooooooooo`0^
ooooo`Go003o1?ooool5o`00og7ooooo0ooo0005ooooo`Koo`00H?ooool1o`00007ooooo00000ol0
003oooooooooo`0Pooooo`?o003o2oooool5o`00o`Cooooo1Ol00?m`ooooo`Goo`001?ooool7ool0
05oooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool5o`00o`_ooooo0ol00?l3ooooo`Oo
003oL?ooool5ool000Gooooo1_oo001Oooooo`7o00000Oooool00003o`000?oooooooooo01oooooo
1Ol00?l@ooooo`Oo003oLOooool5ool000Kooooo1Ooo0015ooooo`?oo`005oooool1o`00007ooooo
00000ol0003oooooooooo`0Oooooo`Go003o4?ooool5o`00oc[ooooo0ol00?lKooooo`?oo`006Ooo
ool3ool000Sooooo0ooo0015ooooo`Goo`005_ooool1o`00007ooooo00000ol0003oooooooooo`0P
ooooo`?o003o4Oooool5o`00ocWooooo1Ol00?lIooooo`Goo`00@_ooool3ool002Kooooo1Ooo000F
ooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo0ol00?ljooooo`Go003o6Oooool5ool0
047ooooo1Ooo000Nooooo`?oo`001?ooool5ool001Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0>?ooool3o`00ocKooooo1_l00?l9ooooo`?oo`003Oooool5ool0047ooooo1Ooo000Mooooo`Go
o`001?ooool3ool001Oooooo0Ol00001ooooo`0000?o0000ooooooooool0:_ooool3o`00o`[ooooo
1Ol00?ldooooo`Ko003o2Oooool5ool000gooooo0ooo0012ooooo`Goo`007Oooool5ool001?ooooo
0ooo0008ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo1Ol00?l9ooooo`Go003o=?oo
ool5o`00o`[ooooo1Ooo001Cooooo`?oo`007_ooool5ool001;ooooo1Ooo0007ooooo`7o00000Ooo
ool00003o`000?oooooooooo02Wooooo1Ol00?l9ooooo`Go003o=?ooool5o`00o`[ooooo1Ooo001e
ooooo`?oo`004oooool5ool000Oooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool5o`00
o`[ooooo0ol00?lfooooo`?o003o3?ooool3ool008cooooo1Ooo0007ooooo`7o00000Oooool00003
o`000?oooooooooo02[ooooo0ol00?oSooooo`?oo`002?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0fooooo`?o003o_oooool3ool0023ooooo0Ol00001ooooo`0000?o0000ooooooooool0=Ooo
ool5o`00oioooooo0ooo000Kooooo`Goo`007oooool1o`00007ooooo00000ol0003oooooooooo`0e
ooooo`Go003oW_ooool5ool001[ooooo1Ooo000Oooooo`7o00000Oooool00003o`000?oooooooooo
03Gooooo1Ol00?nNooooo`Goo`006_ooool5ool000Gooooo0ooo000Gooooo`7o00000Oooool00003
o`000?oooooooooo03Kooooo0ol00?nOooooo`Goo`002_ooool3ool000kooooo0ooo0005ooooo`Go
o`005_ooool1o`00007ooooo00000ol0003oooooooooo`3Iooooo`?oo`002_ooool5ool001Gooooo
1Ooo000Fooooo`7o00000Oooool00003o`000?oooooooooo0>Kooooo1Ooo000Eooooo`Goo`001_oo
ool3ool000gooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool3ool004gooooo1Ooo000F
ooooo`?oo`001_ooool5ool000cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool5ool0
04gooooo0ooo000Pooooo`Goo`003?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`Go
o`00L?ooool5ool000cooooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool3o`00oh;ooooo
1Ooo001aooooo`?oo`003Oooool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`Go003oP_oo
ool3ool008;ooooo0Ol00001ooooo`0000?o0000ooooooooool03oooool5o`00ocGooooo0ol00?o?
ooooo`7o00000Oooool00003o`000?oooooooooo00oooooo1Ol00?ldooooo`Go003o4_ooool3o`00
okWooooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool3o`00ocGooooo1Ol00?lAooooo`Go
003o^?ooool1o`00007ooooo00000ol0003oooooooooo`18ooooo`Go003o4Oooool5o`00okSooooo
0Ol00001ooooo`0000?o0000ooooooooool0BOooool3o`00oa;ooooo1Ol00?nhooooo`7o00000Ooo
ool00003o`000?oooooooooo047ooooo0ol00?lKooooo`?o003o^Oooool1o`00007ooooo00000ol0
003oooooooooo`10ooooo`Go003oe_ooool1o`00007ooooo00000ol0003oooooooooo`07ooooo`?o
003o=_ooool5o`00omKooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool5o`00ocGooooo
1Ol00?oFooooo`7o00000Oooool00003o`000?oooooooooo00Kooooo1Ol00?lfooooo`?o003oeooo
ool1o`00007ooooo00000ol0003oooooooooo`06ooooo`Go003ok?ooool3ool0027ooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool3o`00oncooooo1Ooo000Pooooo`7o00000Oooool00003
o`000?oooooooooo0?Kooooo1Ooo000Pooooo`7o00000Oooool00003o`000?oooooooooo0?Kooooo
1Ooo000Pooooo`7o00000Oooool00003o`000?oooooooooo01Cooooo0ol00?n>ooooo`?oo`00Cooo
ool3ool0027ooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool5o`00of3ooooo0ooo000Y
ooooo`Goo`00L_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`Go003oGoooool5ool0
02Sooooo1Ooo001booooo`7o00000Oooool00003o`000?oooooooooo01?ooooo1Ol00?mOooooo`Go
o`00:?ooool5ool007;ooooo0Ol00001ooooo`0000?o0000ooooooooool05?ooool3o`00of3ooooo
1Ooo000Yooooo`?oo`004?ooool3ool0063ooooo0Ol00001ooooo`0000?o0000ooooooooool0N?oo
ool3ool003cooooo1Ooo001Oooooo`7o00000Oooool00003o`000?oooooooooo04kooooo0ol00?lJ
ooooo`?oo`00BOooool5ool005oooooo0Ol00001ooooo`0000?o0000ooooooooool0COooool5o`00
oaSooooo1Ooo0018ooooo`Goo`00Goooool1o`00007ooooo00000ol0003oooooooooo`1=ooooo`Go
003o6?ooool5ool003Oooooo0ooo000?ooooo`?oo`00H?ooool1o`00007ooooo00000ol0003ooooo
ooooo`19ooooo`?o003o00?oooooo`00ool00?l00ol00?lHooooo`Goo`00;?ooool3ool000Oooooo
1Ooo001aooooo`7o00000Oooool00003o`000?oooooooooo04Sooooo1Ol00?l01?oooooo003oo`00
ool00?lJooooo`?oo`00;?ooool5ool000Kooooo1Ooo001aooooo`7o00000Oooool00003o`000?oo
oooooooo04Sooooo1Ol00?m=ooooo`Goo`001_ooool5ool0077ooooo0Ol00001ooooo`0000?o0000
ooooooooool0B?ooool5o`00oc;ooooo0ooo000Hooooo`Goo`001oooool3ool007;ooooo0Ol00001
ooooo`0000?o0000ooooooooool0BOooool3o`00oc;ooooo1Ooo000Hooooo`?oo`00OOooool1o`00
007ooooo00000ol0003oooooooooo`1nooooo`Soo`00UOooool1o`00007ooooo00000ol0003ooooo
ooooo`1nooooo`Woo`00U?ooool1o`00007ooooo00000ol0003oooooooooo`1oooooo`Soo`00U?oo
ool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`?o003oE?ooool5ool009Cooooo0Ol00001
ooooo`0000?o0000ooooooooool0:_ooool5o`00oeCooooo0ooo002Eooooo`7o00000Oooool00003
o`000?oooooooooo02[ooooo1Ol00?n=ooooo`?oo`00G?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Zooooo`Go003o8oooool3ool006Kooooo1Ooo001Kooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo0ol00?lSooooo`Goo`00IOooool5ool005_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0DOooool5ool000?ooooo0ooo001Oooooo`Goo`00AOooool3ool001?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0DOooool5ool000;ooooo1Ooo000Yooooo`?oo`006?ooool3ool0
01Sooooo0ooo0015ooooo`Goo`004_ooool1o`00007ooooo00000ol0003oooooooooo`1Booooo`?o
o`000oooool5ool002Sooooo1Ooo000Fooooo`Goo`00Goooool5ool001;ooooo0Ol00001ooooo`00
00?o0000ooooooooool0F?ooool5ool002Sooooo1Ooo000Fooooo`Goo`00Goooool5ool001;ooooo
0Ol00001ooooo`0000?o0000ooooooooool0FOooool3ool002;ooooo0ooo0004ooooo`Goo`005_oo
ool5ool0063ooooo0ooo000Cooooo`7o00000Oooool00003o`000?oooooooooo07gooooo1Ooo0004
ooooo`?oo`006?ooool3ool007Oooooo0Ol00001ooooo`0000?o0000ooooooooool0<Oooool3o`00
o`Gooooo0ol00?m1ooooo`Goo`00Poooool3ool001?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0<?ooool5o`00o`?ooooo1Ol00?m0ooooo`Goo`00P_ooool5ool001;ooooo0Ol00001ooooo`00
00?o0000ooooooooool0<?ooool5o`00o`?ooooo1Ol00?m1ooooo`?oo`00D?ooool3ool0033ooooo
1Ooo000Booooo`7o00000Oooool00003o`000?oooooooooo033ooooo1Ol00?l3ooooo`Go003oTooo
ool5ool002oooooo1Ooo000Booooo`7o00000Oooool00003o`000?oooooooooo02Cooooo0ol00?l9
ooooo`Go003o1?ooool3o`00oiCooooo1Ooo000`ooooo`?oo`004oooool1o`00007ooooo00000ol0
003oooooooooo`0Sooooo`Go003o2?ooool5o`00oi_ooooo1Ooo0016ooooo`7o00000Oooool00003
o`000?oooooooooo02?ooooo1Ol00?l9ooooo`?o003oV_ooool6ool004Oooooo0Ol00001ooooo`00
00?o0000ooooooooool08oooool5o`00ojGooooo1Ooo0019ooooo`7o00000Oooool00003o`000?oo
oooooooo02Cooooo0ol00?lbooooo`?oo`00DOooool3ool001gooooo1Ooo0019ooooo`7o00000Ooo
ool00003o`000?oooooooooo05Sooooo1Ooo001?ooooo`Goo`007?ooool5ool004Wooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool3o`00odkooooo1Ooo001?ooooo`Goo`007Oooool3ool0
04[ooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool5o`00odgooooo2?oo001<ooooo`Go
o`00Foooool3ool000cooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool5o`00odkooooo
2?oo000kooooo`?oo`003_ooool3ool005_ooooo1Ooo000;ooooo`7o00000Oooool00003o`000?oo
oooooooo00Gooooo1_l00?mAooooo`Goo`00>_ooool5ool006_ooooo1Ooo000;ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Gooooo1Ol00?mBooooo`Goo`00>_ooool5ool006_ooooo1Ooo000;
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo1Ol00?mCooooo`?oo`00>oooool5ool0
06cooooo0ooo000<ooooo`7o00000Oooool00003o`000?oooooooooo00Kooooo0ol00?l@ooooo`?o
003o<Oooool3ool004cooooo0ooo001looooo`7o00000Oooool00003o`000?oooooooooo01Sooooo
1Ol00?l_ooooo`Goo`00b_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`Go003o;ooo
ool5ool005Wooooo0ooo001^ooooo`7o00000Oooool00003o`000?oooooooooo01Sooooo1Ol00?l_
ooooo`Goo`00F?ooool5ool006gooooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool3o`00
oc7ooooo0ooo001Iooooo`Goo`00H_ooool3ool000Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool0ZOooool5ool0067ooooo1Ooo0007ooooo`7o00000Oooool00003o`000?oooooooooo0:[ooooo
0ooo001Rooooo`Goo`001oooool1o`00007ooooo00000ol0003oooooooooo`0Eooooo`?o003og_oo
ool3ool001Kooooo1Ooo0007ooooo`7o00000Oooool00003o`000?oooooooooo01Cooooo1Ol00?oL
ooooo`Goo`005_ooool3ool000Sooooo0Ol00001ooooo`0000?o0000ooooooooool05?ooool5o`00
omcooooo1Ooo000Qooooo`7o00000Oooool00003o`000?oooooooooo01Cooooo1Ol00?oLooooo`Go
o`008Oooool1o`00007ooooo00000ol0003oooooooooo`0Eooooo`?o003oZoooool3ool0033ooooo
0ooo000Rooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo0ooo002Jooooo`Goo`006_oo
ool3ool003Oooooo0Ol00001ooooo`0000?o0000ooooooooool09?ooool5ool009Wooooo1Ooo000I
ooooo`Goo`00=_ooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`Goo`009oooool3ool0
06oooooo1Ooo000Iooooo`Goo`00=_ooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`Go
o`009_ooool5ool006oooooo0ooo000Jooooo`Goo`00=_ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Uooooo`?oo`009oooool5ool008gooooo0ooo000gooooo`7o00000Oooool00003o`000?oo
oooooooo04oooooo1Ooo001:ooooo`?oo`00BOooool3ool002kooooo0Ol00001ooooo`0000?o0000
ooooooooool0D?ooool3ool004[ooooo1Ooo0017ooooo`Goo`00;Oooool1o`00007ooooo00000ol0
003oooooooooo`2Mooooo`Goo`00Aoooool5ool002gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0N?ooool3ool002;ooooo1Ooo0017ooooo`Goo`00;Oooool1o`00007ooooo00000ol0003ooooo
ooooo`1gooooo`Goo`008_ooool3ool004Wooooo0ooo000^ooooo`7o00000Oooool00003o`000?oo
oooooooo07Oooooo1Ooo002Oooooo`7o00000Oooool00003o`000?oooooooooo01Sooooo0ooo001L
ooooo`Goo`00Woooool1o`00007ooooo00000ol0003oooooooooo`0Gooooo`Koo`00Foooool3ool0
0:3ooooo0Ol00001ooooo`0000?o0000ooooooooool05oooool7ool00>Sooooo0ooo000Booooo`7o
00000Oooool00003o`000?oooooooooo01Oooooo1ooo003Vooooo`Koo`004Oooool1o`00007ooooo
00000ol0003oooooooooo`0=ooooo`?o003o2?ooool6ool00>Gooooo1ooo000Aooooo`7o00000Ooo
ool00003o`000?oooooooooo00cooooo1Ol00?l9ooooo`?oo`00i_ooool7ool0017ooooo0Ol00001
ooooo`0000?o0000ooooooooool03?ooool5o`00o`_ooooo0ooo003Tooooo`Koo`004_ooool1o`00
007ooooo00000ol0003oooooooooo`0<ooooo`Go003o2_ooool5ool00>Cooooo0ooo000Dooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo0ol00?l4ooooo`?oo`001?ooool5ool00>Wooooo
0ooo000?ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo1Ooo0003ooooo`Goo`00j?oo
ool5ool000kooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool5ool000Cooooo0ooo003Y
ooooo`Goo`003_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`Goo`00DOooool3ool0
09cooooo1Ooo00001?ooooooo`00ool00?oo000:ooooo`7o00000Oooool00003o`000?oooooooooo
01Cooooo0ooo001Aooooo`Goo`00W?ooool3ool00003oooooooo003oo`0000?oo`002Oooool1o`00
007ooooo00000ol0003oooooooooo`1Xooooo`Goo`00X?ooool5ool000Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0J?ooool5ool00:3ooooo1Ooo0009ooooo`7o00000Oooool00003o`000?oo
oooooooo06Wooooo0ooo002Rooooo`?oo`002_ooool1o`00007ooooo00000ol0003oooooooooo`0g
ooooo`?oo`0000Coooooool00?oo003oo`00gOooool1o`00007ooooo00000ol0003oooooooooo`0f
ooooo`Woo`00g?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`Woo`00g?ooool1o`00
007ooooo00000ol0003oooooooooo`0fooooo`Woo`00g?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0gooooo`?oo`0000Coooooool00?oo003oo`00gOooool1o`00007ooooo00000ol0003ooooo
ooooo`2Iooooo`?oo`00Joooool5ool000oooooo0Ol00001ooooo`0000?o0000ooooooooool0N_oo
ool3ool001_ooooo1Ooo000Gooooo`?oo`00Coooool7ool000kooooo0Ol00001ooooo`0000?o0000
ooooooooool0NOooool5ool001[ooooo1Ooo000Fooooo`Goo`00C_ooool7ool000kooooo0Ol00001
ooooo`0000?o0000ooooooooool0NOooool5ool000Sooooo0ooo000?ooooo`Goo`005_ooool5ool0
04kooooo1ooo0006ooooo`?oo`001Oooool1o`00007ooooo00000ol0003oooooooooo`1iooooo`Go
o`001oooool5ool000oooooo0ooo000Gooooo`Goo`00Coooool5ool000Kooooo1Ooo0004ooooo`7o
00000Oooool00003o`000?oooooooooo07[ooooo0ooo0008ooooo`Goo`00:_ooool3ool005_ooooo
1Ooo0004ooooo`7o00000Oooool00003o`000?oooooooooo08Gooooo1Ooo0028ooooo`Goo`001?oo
ool1o`00007ooooo00000ol0003oooooooooo`26ooooo`?oo`00R_ooool3ool000Gooooo0Ol00001
ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Uniform quantization", "Subsection"],

Cell[CellGroupData[{

Cell["Number of centroids in each direction", "Subsubsection"],

Cell[BoxData[
    \(\(nCentroids\  = \ 3;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute uniformly distributed centroids", "Subsubsection"],

Cell[BoxData[
    \(\(uniformCentroids\  = \ 
        UniformQuantization[pr[\([1]\)], pr[\([2]\)], 
          nCentroids];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gCentroids = \ 
        PlotData2D[uniformCentroids, pr, \ centroidStyle, \ 
          FrameTicks \[Rule] None];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 1 r
.02 w
.16997 .16997 Mdot
.16997 .5 Mdot
.16997 .83004 Mdot
.5 .16997 Mdot
.5 .5 Mdot
.5 .83004 Mdot
.83004 .16997 Mdot
.83004 .5 Mdot
.83004 .83004 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
;?ooool3ool0oecooooo0ooo0?mKooooo`?oo`3o;oooool1o`00007ooooo00000ol0003ooooooooo
o`0[ooooo`Goo`3oF_ooool5ool0oeWooooo1Ooo0?l^ooooo`7o00000Oooool00003o`000?oooooo
oooo02_ooooo1Ooo0?mJooooo`Goo`3oFOooool5ool0obkooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:oooool5ool0oe[ooooo1Ooo0?mIooooo`Goo`3o;_ooool1o`00007ooooo00000ol0003o
ooooooooo`0/ooooo`?oo`3oG?ooool3ool0oe_ooooo0ooo0?l_ooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0;?ooool3ool0oecooooo0ooo0?mKooooo`?oo`3o;oooool1o`00007ooooo00000ol0003ooooo
ooooo`0[ooooo`Goo`3oF_ooool5ool0oeWooooo1Ooo0?l^ooooo`7o00000Oooool00003o`000?oo
oooooooo02_ooooo1Ooo0?mJooooo`Goo`3oFOooool5ool0obkooooo0Ol00001ooooo`0000?o0000
ooooooooool0:oooool5ool0oe[ooooo1Ooo0?mIooooo`Goo`3o;_ooool1o`00007ooooo00000ol0
003oooooooooo`0/ooooo`?oo`3oG?ooool3ool0oe_ooooo0ooo0?l_ooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo02cooooo0ooo0?mLooooo`?o
o`3oFoooool3ool0oboooooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool5ool0oe[ooooo
1Ooo0?mIooooo`Goo`3o;_ooool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`Goo`3oF_oo
ool5ool0oeWooooo1Ooo0?l^ooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo1Ooo0?mJ
ooooo`Goo`3oFOooool5ool0obkooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool3ool0
oecooooo0ooo0?mKooooo`?oo`3o;oooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Histograms for two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Compute histograms based on uniform centroids", "Subsubsection"],

Cell[BoxData[{
    \(\(h1\  = Histogram[data1, uniformCentroids, pr, 50];\)\), "\n", 
    \(\(h2\  = Histogram[data2, uniformCentroids, pr, 50];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize two histograms", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gh1\  = 
        DrawHistogram[h1, pr, \ nS, 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(gh2\  = 
        DrawHistogram[h2, pr, \ nS, 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gh1, gh2}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
%%ImageSize: 400 154.502 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .919 r
.39569 .6886 .40196 .6941 .41247 .69113 .40622 .6856 Mtetra
.40622 .6856 .41247 .69113 .42302 .68814 .4168 .68259 Mtetra
.4168 .68259 .42302 .68814 .43361 .68514 .42741 .67956 Mtetra
.42741 .67956 .43361 .68514 .44424 .68212 .43807 .67653 Mtetra
.43807 .67653 .44424 .68212 .45492 .6791 .44877 .67348 Mtetra
.44877 .67348 .45492 .6791 .46564 .67606 .45952 .67042 Mtetra
.45952 .67042 .46564 .67606 .4764 .67301 .47031 .66735 Mtetra
.47031 .66735 .4764 .67301 .4872 .66995 .48113 .66427 Mtetra
.48113 .66427 .4872 .66995 .49804 .66688 .49201 .66117 Mtetra
.49201 .66117 .49804 .66688 .50893 .66379 .50292 .65806 Mtetra
.50292 .65806 .50893 .66379 .51986 .66069 .51388 .65494 Mtetra
.51388 .65494 .51986 .66069 .53084 .65758 .52489 .65181 Mtetra
.52489 .65181 .53084 .65758 .54186 .65446 .53593 .64867 Mtetra
.53593 .64867 .54186 .65446 .55292 .65133 .54703 .64551 Mtetra
.54703 .64551 .55292 .65133 .56403 .64818 .55816 .64234 Mtetra
.55816 .64234 .56403 .64818 .57518 .64502 .56935 .63915 Mtetra
.956 .634 .373 r
.56935 .63915 .57518 .64502 .58781 .72246 .58187 .71674 Mtetra
.649 .759 .929 r
.58187 .71674 .58781 .72246 .59932 .71936 .59341 .71362 Mtetra
.59341 .71362 .59932 .71936 .61087 .71626 .605 .71049 Mtetra
.605 .71049 .61087 .71626 .62247 .71314 .61664 .70735 Mtetra
.61664 .70735 .62247 .71314 .63413 .71001 .62832 .70419 Mtetra
.62832 .70419 .63413 .71001 .64583 .70686 .64006 .70102 Mtetra
.64006 .70102 .64583 .70686 .65758 .7037 .65184 .69784 Mtetra
.65184 .69784 .65758 .7037 .66937 .70053 .66367 .69464 Mtetra
.66367 .69464 .66937 .70053 .68122 .69735 .67555 .69143 Mtetra
.67555 .69143 .68122 .69735 .69312 .69415 .68748 .68821 Mtetra
.68748 .68821 .69312 .69415 .70507 .69094 .69947 .68497 Mtetra
.69947 .68497 .70507 .69094 .71707 .68771 .7115 .68172 Mtetra
.7115 .68172 .71707 .68771 .72912 .68447 .72359 .67846 Mtetra
.72359 .67846 .72912 .68447 .74122 .68122 .73572 .67518 Mtetra
.73572 .67518 .74122 .68122 .75337 .67795 .74791 .67189 Mtetra
.74791 .67189 .75337 .67795 .76557 .67467 .76015 .66858 Mtetra
.76015 .66858 .76557 .67467 .77783 .67138 .77244 .66526 Mtetra
.947 .772 .632 r
.77244 .66526 .77783 .67138 .7876 .63472 .7823 .62851 Mtetra
.652 .756 .925 r
.7823 .62851 .7876 .63472 .79984 .63136 .79457 .62512 Mtetra
.79457 .62512 .79984 .63136 .81213 .62799 .8069 .62171 Mtetra
.8069 .62171 .81213 .62799 .82447 .62459 .81928 .6183 Mtetra
.81928 .6183 .82447 .62459 .83686 .62119 .83171 .61487 Mtetra
.83171 .61487 .83686 .62119 .84931 .61777 .84419 .61142 Mtetra
.84419 .61142 .84931 .61777 .86181 .61434 .85673 .60796 Mtetra
.85673 .60796 .86181 .61434 .87437 .61089 .86933 .60448 Mtetra
.86933 .60448 .87437 .61089 .88698 .60742 .88198 .60099 Mtetra
.88198 .60099 .88698 .60742 .89964 .60395 .89468 .59748 Mtetra
.89468 .59748 .89964 .60395 .91236 .60045 .90744 .59396 Mtetra
.90744 .59396 .91236 .60045 .92513 .59694 .92025 .59042 Mtetra
.92025 .59042 .92513 .59694 .93796 .59342 .93312 .58687 Mtetra
.93312 .58687 .93796 .59342 .95085 .58988 .94605 .5833 Mtetra
.94605 .5833 .95085 .58988 .96379 .58632 .95903 .57972 Mtetra
.95903 .57972 .96379 .58632 .97679 .58275 .97207 .57612 Mtetra
.97207 .57612 .97679 .58275 .98984 .57917 .98517 .5725 Mtetra
.656 .751 .919 r
.38936 .68305 .39569 .6886 .40622 .6856 .39992 .68003 Mtetra
.39992 .68003 .40622 .6856 .4168 .68259 .41053 .677 Mtetra
.41053 .677 .4168 .68259 .42741 .67956 .42117 .67395 Mtetra
.42117 .67395 .42741 .67956 .43807 .67653 .43186 .67089 Mtetra
.43186 .67089 .43807 .67653 .44877 .67348 .44258 .66782 Mtetra
.44258 .66782 .44877 .67348 .45952 .67042 .45336 .66474 Mtetra
.45336 .66474 .45952 .67042 .47031 .66735 .46417 .66165 Mtetra
.46417 .66165 .47031 .66735 .48113 .66427 .47503 .65854 Mtetra
.47503 .65854 .48113 .66427 .49201 .66117 .48593 .65542 Mtetra
.48593 .65542 .49201 .66117 .50292 .65806 .49687 .65229 Mtetra
.49687 .65229 .50292 .65806 .51388 .65494 .50786 .64915 Mtetra
.50786 .64915 .51388 .65494 .52489 .65181 .51889 .64599 Mtetra
.51889 .64599 .52489 .65181 .53593 .64867 .52997 .64282 Mtetra
.52997 .64282 .53593 .64867 .54703 .64551 .54109 .63964 Mtetra
.54109 .63964 .54703 .64551 .55816 .64234 .55226 .63645 Mtetra
.55226 .63645 .55816 .64234 .56935 .63915 .56347 .63324 Mtetra
.956 .634 .373 r
.56347 .63324 .56935 .63915 .58187 .71674 .5759 .71097 Mtetra
.649 .759 .929 r
.5759 .71097 .58187 .71674 .59341 .71362 .58747 .70783 Mtetra
.58747 .70783 .59341 .71362 .605 .71049 .59909 .70468 Mtetra
.59909 .70468 .605 .71049 .61664 .70735 .61076 .70151 Mtetra
.61076 .70151 .61664 .70735 .62832 .70419 .62247 .69833 Mtetra
.62247 .69833 .62832 .70419 .64006 .70102 .63424 .69513 Mtetra
.63424 .69513 .64006 .70102 .65184 .69784 .64606 .69193 Mtetra
.64606 .69193 .65184 .69784 .66367 .69464 .65792 .68871 Mtetra
.65792 .68871 .66367 .69464 .67555 .69143 .66984 .68547 Mtetra
.66984 .68547 .67555 .69143 .68748 .68821 .68181 .68222 Mtetra
.68181 .68222 .68748 .68821 .69947 .68497 .69382 .67896 Mtetra
.69382 .67896 .69947 .68497 .7115 .68172 .70589 .67568 Mtetra
.70589 .67568 .7115 .68172 .72359 .67846 .71801 .67239 Mtetra
.71801 .67239 .72359 .67846 .73572 .67518 .73018 .66909 Mtetra
.73018 .66909 .73572 .67518 .74791 .67189 .74241 .66577 Mtetra
.74241 .66577 .74791 .67189 .76015 .66858 .75469 .66244 Mtetra
.75469 .66244 .76015 .66858 .77244 .66526 .76702 .65909 Mtetra
.947 .772 .632 r
.76702 .65909 .77244 .66526 .7823 .62851 .77695 .62224 Mtetra
.652 .756 .925 r
.77695 .62224 .7823 .62851 .79457 .62512 .78926 .61882 Mtetra
.78926 .61882 .79457 .62512 .8069 .62171 .80162 .61539 Mtetra
.80162 .61539 .8069 .62171 .81928 .6183 .81404 .61195 Mtetra
.81404 .61195 .81928 .6183 .83171 .61487 .82651 .60849 Mtetra
.82651 .60849 .83171 .61487 .84419 .61142 .83904 .60502 Mtetra
.83904 .60502 .84419 .61142 .85673 .60796 .85161 .60153 Mtetra
.85161 .60153 .85673 .60796 .86933 .60448 .86425 .59802 Mtetra
.86425 .59802 .86933 .60448 .88198 .60099 .87694 .5945 Mtetra
.87694 .5945 .88198 .60099 .89468 .59748 .88968 .59097 Mtetra
.88968 .59097 .89468 .59748 .90744 .59396 .90248 .58742 Mtetra
.90248 .58742 .90744 .59396 .92025 .59042 .91533 .58385 Mtetra
.91533 .58385 .92025 .59042 .93312 .58687 .92824 .58027 Mtetra
.92824 .58027 .93312 .58687 .94605 .5833 .94121 .57667 Mtetra
.94121 .57667 .94605 .5833 .95903 .57972 .95424 .57306 Mtetra
.95424 .57306 .95903 .57972 .97207 .57612 .96732 .56943 Mtetra
.96732 .56943 .97207 .57612 .98517 .5725 .98046 .56579 Mtetra
.656 .751 .919 r
.383 .67746 .38936 .68305 .39992 .68003 .39358 .67442 Mtetra
.39358 .67442 .39992 .68003 .41053 .677 .40421 .67136 Mtetra
.40421 .67136 .41053 .677 .42117 .67395 .41488 .6683 Mtetra
.41488 .6683 .42117 .67395 .43186 .67089 .42559 .66522 Mtetra
.42559 .66522 .43186 .67089 .44258 .66782 .43635 .66213 Mtetra
.43635 .66213 .44258 .66782 .45336 .66474 .44715 .65902 Mtetra
.44715 .65902 .45336 .66474 .46417 .66165 .45799 .65591 Mtetra
.45799 .65591 .46417 .66165 .47503 .65854 .46887 .65278 Mtetra
.46887 .65278 .47503 .65854 .48593 .65542 .4798 .64963 Mtetra
.4798 .64963 .48593 .65542 .49687 .65229 .49078 .64648 Mtetra
.49078 .64648 .49687 .65229 .50786 .64915 .50179 .64331 Mtetra
.50179 .64331 .50786 .64915 .51889 .64599 .51285 .64013 Mtetra
.51285 .64013 .51889 .64599 .52997 .64282 .52396 .63694 Mtetra
.52396 .63694 .52997 .64282 .54109 .63964 .53511 .63373 Mtetra
.53511 .63373 .54109 .63964 .55226 .63645 .54631 .63052 Mtetra
.54631 .63052 .55226 .63645 .56347 .63324 .55755 .62728 Mtetra
.956 .634 .373 r
.55755 .62728 .56347 .63324 .5759 .71097 .56987 .70516 Mtetra
.649 .759 .929 r
.56987 .70516 .5759 .71097 .58747 .70783 .58147 .702 Mtetra
.58147 .702 .58747 .70783 .59909 .70468 .59313 .69882 Mtetra
.59313 .69882 .59909 .70468 .61076 .70151 .60483 .69563 Mtetra
.60483 .69563 .61076 .70151 .62247 .69833 .61658 .69242 Mtetra
.61658 .69242 .62247 .69833 .63424 .69513 .62838 .6892 Mtetra
.62838 .6892 .63424 .69513 .64606 .69193 .64023 .68597 Mtetra
.64023 .68597 .64606 .69193 .65792 .68871 .65213 .68272 Mtetra
.65213 .68272 .65792 .68871 .66984 .68547 .66408 .67946 Mtetra
.66408 .67946 .66984 .68547 .68181 .68222 .67608 .67619 Mtetra
.67608 .67619 .68181 .68222 .69382 .67896 .68813 .6729 Mtetra
.68813 .6729 .69382 .67896 .70589 .67568 .70024 .6696 Mtetra
.70024 .6696 .70589 .67568 .71801 .67239 .71239 .66628 Mtetra
.71239 .66628 .71801 .67239 .73018 .66909 .7246 .66295 Mtetra
.7246 .66295 .73018 .66909 .74241 .66577 .73686 .65961 Mtetra
.73686 .65961 .74241 .66577 .75469 .66244 .74918 .65625 Mtetra
.74918 .65625 .75469 .66244 .76702 .65909 .76155 .65288 Mtetra
.947 .772 .632 r
.76155 .65288 .76702 .65909 .77695 .62224 .77156 .61592 Mtetra
.652 .756 .925 r
.77156 .61592 .77695 .62224 .78926 .61882 .78391 .61248 Mtetra
.78391 .61248 .78926 .61882 .80162 .61539 .79631 .60902 Mtetra
.79631 .60902 .80162 .61539 .81404 .61195 .80876 .60555 Mtetra
.80876 .60555 .81404 .61195 .82651 .60849 .82127 .60207 Mtetra
.82127 .60207 .82651 .60849 .83904 .60502 .83384 .59856 Mtetra
.83384 .59856 .83904 .60502 .85161 .60153 .84645 .59505 Mtetra
.84645 .59505 .85161 .60153 .86425 .59802 .85913 .59151 Mtetra
.85913 .59151 .86425 .59802 .87694 .5945 .87185 .58797 Mtetra
.87185 .58797 .87694 .5945 .88968 .59097 .88464 .5844 Mtetra
.88464 .5844 .88968 .59097 .90248 .58742 .89748 .58082 Mtetra
.89748 .58082 .90248 .58742 .91533 .58385 .91037 .57723 Mtetra
.91037 .57723 .91533 .58385 .92824 .58027 .92333 .57362 Mtetra
.92333 .57362 .92824 .58027 .94121 .57667 .93634 .56999 Mtetra
.93634 .56999 .94121 .57667 .95424 .57306 .9494 .56635 Mtetra
.9494 .56635 .95424 .57306 .96732 .56943 .96253 .56269 Mtetra
.96253 .56269 .96732 .56943 .98046 .56579 .97571 .55902 Mtetra
.656 .751 .919 r
.37658 .67184 .383 .67746 .39358 .67442 .38719 .66877 Mtetra
.38719 .66877 .39358 .67442 .40421 .67136 .39785 .66569 Mtetra
.39785 .66569 .40421 .67136 .41488 .6683 .40855 .6626 Mtetra
.40855 .6626 .41488 .6683 .42559 .66522 .41929 .6595 Mtetra
.41929 .6595 .42559 .66522 .43635 .66213 .43007 .65639 Mtetra
.43007 .65639 .43635 .66213 .44715 .65902 .44089 .65326 Mtetra
.44089 .65326 .44715 .65902 .45799 .65591 .45176 .65012 Mtetra
.45176 .65012 .45799 .65591 .46887 .65278 .46268 .64697 Mtetra
.46268 .64697 .46887 .65278 .4798 .64963 .47363 .6438 Mtetra
.47363 .6438 .4798 .64963 .49078 .64648 .48463 .64062 Mtetra
.48463 .64062 .49078 .64648 .50179 .64331 .49568 .63743 Mtetra
.49568 .63743 .50179 .64331 .51285 .64013 .50677 .63423 Mtetra
.50677 .63423 .51285 .64013 .52396 .63694 .5179 .63101 Mtetra
.5179 .63101 .52396 .63694 .53511 .63373 .52908 .62778 Mtetra
.52908 .62778 .53511 .63373 .54631 .63052 .54031 .62454 Mtetra
.54031 .62454 .54631 .63052 .55755 .62728 .55158 .62128 Mtetra
.956 .634 .373 r
.55158 .62128 .55755 .62728 .56987 .70516 .5638 .69931 Mtetra
.649 .759 .929 r
.5638 .69931 .56987 .70516 .58147 .702 .57544 .69612 Mtetra
.57544 .69612 .58147 .702 .59313 .69882 .58712 .69291 Mtetra
.58712 .69291 .59313 .69882 .60483 .69563 .59885 .6897 Mtetra
.59885 .6897 .60483 .69563 .61658 .69242 .61064 .68647 Mtetra
.61064 .68647 .61658 .69242 .62838 .6892 .62247 .68322 Mtetra
.62247 .68322 .62838 .6892 .64023 .68597 .63436 .67997 Mtetra
.63436 .67997 .64023 .68597 .65213 .68272 .64629 .67669 Mtetra
.64629 .67669 .65213 .68272 .66408 .67946 .65828 .67341 Mtetra
.65828 .67341 .66408 .67946 .67608 .67619 .67031 .67011 Mtetra
.67031 .67011 .67608 .67619 .68813 .6729 .6824 .66679 Mtetra
.6824 .66679 .68813 .6729 .70024 .6696 .69454 .66347 Mtetra
.69454 .66347 .70024 .6696 .71239 .66628 .70673 .66012 Mtetra
.70673 .66012 .71239 .66628 .7246 .66295 .71898 .65677 Mtetra
.71898 .65677 .7246 .66295 .73686 .65961 .73128 .6534 Mtetra
.73128 .6534 .73686 .65961 .74918 .65625 .74363 .65001 Mtetra
.74363 .65001 .74918 .65625 .76155 .65288 .75603 .64661 Mtetra
.947 .772 .632 r
.75603 .64661 .76155 .65288 .77156 .61592 .76612 .60956 Mtetra
.652 .756 .925 r
.76612 .60956 .77156 .61592 .78391 .61248 .77851 .60609 Mtetra
.77851 .60609 .78391 .61248 .79631 .60902 .79095 .6026 Mtetra
.79095 .6026 .79631 .60902 .80876 .60555 .80344 .5991 Mtetra
.80344 .5991 .80876 .60555 .82127 .60207 .81599 .59559 Mtetra
.81599 .59559 .82127 .60207 .83384 .59856 .82859 .59206 Mtetra
.82859 .59206 .83384 .59856 .84645 .59505 .84125 .58851 Mtetra
.84125 .58851 .84645 .59505 .85913 .59151 .85396 .58495 Mtetra
.85396 .58495 .85913 .59151 .87185 .58797 .86673 .58138 Mtetra
.86673 .58138 .87185 .58797 .88464 .5844 .87956 .57778 Mtetra
.87956 .57778 .88464 .5844 .89748 .58082 .89244 .57418 Mtetra
.89244 .57418 .89748 .58082 .91037 .57723 .90537 .57055 Mtetra
.90537 .57055 .91037 .57723 .92333 .57362 .91837 .56691 Mtetra
.91837 .56691 .92333 .57362 .93634 .56999 .93142 .56325 Mtetra
.93142 .56325 .93634 .56999 .9494 .56635 .94453 .55958 Mtetra
.94453 .55958 .9494 .56635 .96253 .56269 .9577 .55589 Mtetra
.9577 .55589 .96253 .56269 .97571 .55902 .97093 .55219 Mtetra
.656 .751 .919 r
.37012 .66617 .37658 .67184 .38719 .66877 .38076 .66308 Mtetra
.38076 .66308 .38719 .66877 .39785 .66569 .39144 .65998 Mtetra
.39144 .65998 .39785 .66569 .40855 .6626 .40216 .65687 Mtetra
.40216 .65687 .40855 .6626 .41929 .6595 .41293 .65374 Mtetra
.41293 .65374 .41929 .6595 .43007 .65639 .42374 .6506 Mtetra
.42374 .6506 .43007 .65639 .44089 .65326 .43459 .64745 Mtetra
.43459 .64745 .44089 .65326 .45176 .65012 .44549 .64429 Mtetra
.44549 .64429 .45176 .65012 .46268 .64697 .45643 .64111 Mtetra
.45643 .64111 .46268 .64697 .47363 .6438 .46742 .63792 Mtetra
.46742 .63792 .47363 .6438 .48463 .64062 .47844 .63472 Mtetra
.47844 .63472 .48463 .64062 .49568 .63743 .48952 .63151 Mtetra
.48952 .63151 .49568 .63743 .50677 .63423 .50064 .62828 Mtetra
.50064 .62828 .50677 .63423 .5179 .63101 .5118 .62504 Mtetra
.5118 .62504 .5179 .63101 .52908 .62778 .52301 .62179 Mtetra
.52301 .62179 .52908 .62778 .54031 .62454 .53427 .61852 Mtetra
.53427 .61852 .54031 .62454 .55158 .62128 .54557 .61524 Mtetra
.956 .634 .373 r
.54557 .61524 .55158 .62128 .5638 .69931 .55768 .69341 Mtetra
.649 .759 .929 r
.55768 .69341 .5638 .69931 .57544 .69612 .56935 .69019 Mtetra
.56935 .69019 .57544 .69612 .58712 .69291 .58107 .68697 Mtetra
.58107 .68697 .58712 .69291 .59885 .6897 .59283 .68372 Mtetra
.59283 .68372 .59885 .6897 .61064 .68647 .60465 .68047 Mtetra
.60465 .68047 .61064 .68647 .62247 .68322 .61652 .6772 Mtetra
.61652 .6772 .62247 .68322 .63436 .67997 .62844 .67391 Mtetra
.62844 .67391 .63436 .67997 .64629 .67669 .64041 .67062 Mtetra
.64041 .67062 .64629 .67669 .65828 .67341 .65243 .6673 Mtetra
.65243 .6673 .65828 .67341 .67031 .67011 .6645 .66398 Mtetra
.6645 .66398 .67031 .67011 .6824 .66679 .67662 .66064 Mtetra
.67662 .66064 .6824 .66679 .69454 .66347 .6888 .65728 Mtetra
.6888 .65728 .69454 .66347 .70673 .66012 .70103 .65392 Mtetra
.70103 .65392 .70673 .66012 .71898 .65677 .71331 .65053 Mtetra
.71331 .65053 .71898 .65677 .73128 .6534 .72564 .64713 Mtetra
.72564 .64713 .73128 .6534 .74363 .65001 .73803 .64372 Mtetra
.73803 .64372 .74363 .65001 .75603 .64661 .75047 .64029 Mtetra
.947 .772 .632 r
.75047 .64029 .75603 .64661 .76612 .60956 .76065 .60314 Mtetra
.652 .756 .925 r
.76065 .60314 .76612 .60956 .77851 .60609 .77307 .59964 Mtetra
.77307 .59964 .77851 .60609 .79095 .6026 .78555 .59613 Mtetra
.78555 .59613 .79095 .6026 .80344 .5991 .79808 .5926 Mtetra
.79808 .5926 .80344 .5991 .81599 .59559 .81067 .58906 Mtetra
.81067 .58906 .81599 .59559 .82859 .59206 .82331 .5855 Mtetra
.82331 .5855 .82859 .59206 .84125 .58851 .83601 .58193 Mtetra
.83601 .58193 .84125 .58851 .85396 .58495 .84876 .57834 Mtetra
.84876 .57834 .85396 .58495 .86673 .58138 .86157 .57473 Mtetra
.86157 .57473 .86673 .58138 .87956 .57778 .87443 .57111 Mtetra
.87443 .57111 .87956 .57778 .89244 .57418 .88735 .56747 Mtetra
.88735 .56747 .89244 .57418 .90537 .57055 .90033 .56382 Mtetra
.90033 .56382 .90537 .57055 .91837 .56691 .91337 .56015 Mtetra
.91337 .56015 .91837 .56691 .93142 .56325 .92646 .55646 Mtetra
.92646 .55646 .93142 .56325 .94453 .55958 .93962 .55276 Mtetra
.93962 .55276 .94453 .55958 .9577 .55589 .95283 .54904 Mtetra
.95283 .54904 .9577 .55589 .97093 .55219 .9661 .5453 Mtetra
.656 .751 .919 r
.36361 .66046 .37012 .66617 .38076 .66308 .37428 .65735 Mtetra
.37428 .65735 .38076 .66308 .39144 .65998 .38498 .65422 Mtetra
.38498 .65422 .39144 .65998 .40216 .65687 .39573 .65109 Mtetra
.39573 .65109 .40216 .65687 .41293 .65374 .40653 .64794 Mtetra
.40653 .64794 .41293 .65374 .42374 .6506 .41736 .64478 Mtetra
.41736 .64478 .42374 .6506 .43459 .64745 .42825 .6416 Mtetra
.42825 .6416 .43459 .64745 .44549 .64429 .43917 .63842 Mtetra
.43917 .63842 .44549 .64429 .45643 .64111 .45014 .63522 Mtetra
.45014 .63522 .45643 .64111 .46742 .63792 .46115 .632 Mtetra
.46115 .632 .46742 .63792 .47844 .63472 .47221 .62878 Mtetra
.47221 .62878 .47844 .63472 .48952 .63151 .48331 .62554 Mtetra
.48331 .62554 .48952 .63151 .50064 .62828 .49446 .62229 Mtetra
.49446 .62229 .50064 .62828 .5118 .62504 .50566 .61902 Mtetra
.50566 .61902 .5118 .62504 .52301 .62179 .5169 .61574 Mtetra
.5169 .61574 .52301 .62179 .53427 .61852 .52818 .61245 Mtetra
.52818 .61245 .53427 .61852 .54557 .61524 .53952 .60914 Mtetra
.956 .634 .373 r
.53952 .60914 .54557 .61524 .55768 .69341 .55152 .68746 Mtetra
.649 .759 .929 r
.55152 .68746 .55768 .69341 .56935 .69019 .56322 .68422 Mtetra
.56322 .68422 .56935 .69019 .58107 .68697 .57497 .68097 Mtetra
.57497 .68097 .58107 .68697 .59283 .68372 .58677 .6777 Mtetra
.58677 .6777 .59283 .68372 .60465 .68047 .59862 .67442 Mtetra
.59862 .67442 .60465 .68047 .61652 .6772 .61052 .67112 Mtetra
.61052 .67112 .61652 .6772 .62844 .67391 .62247 .66782 Mtetra
.62247 .66782 .62844 .67391 .64041 .67062 .63447 .66449 Mtetra
.63447 .66449 .64041 .67062 .65243 .6673 .64653 .66115 Mtetra
.64653 .66115 .65243 .6673 .6645 .66398 .65864 .6578 Mtetra
.65864 .6578 .6645 .66398 .67662 .66064 .6708 .65443 Mtetra
.6708 .65443 .67662 .66064 .6888 .65728 .68301 .65105 Mtetra
.68301 .65105 .6888 .65728 .70103 .65392 .69527 .64766 Mtetra
.69527 .64766 .70103 .65392 .71331 .65053 .70759 .64425 Mtetra
.70759 .64425 .71331 .65053 .72564 .64713 .71996 .64082 Mtetra
.71996 .64082 .72564 .64713 .73803 .64372 .73239 .63738 Mtetra
.73239 .63738 .73803 .64372 .75047 .64029 .74487 .63392 Mtetra
.947 .772 .632 r
.74487 .63392 .75047 .64029 .76065 .60314 .75513 .59667 Mtetra
.652 .756 .925 r
.75513 .59667 .76065 .60314 .77307 .59964 .76759 .59315 Mtetra
.76759 .59315 .77307 .59964 .78555 .59613 .78011 .58961 Mtetra
.78011 .58961 .78555 .59613 .79808 .5926 .79268 .58605 Mtetra
.79268 .58605 .79808 .5926 .81067 .58906 .8053 .58248 Mtetra
.8053 .58248 .81067 .58906 .82331 .5855 .81798 .57889 Mtetra
.81798 .57889 .82331 .5855 .83601 .58193 .83072 .57529 Mtetra
.83072 .57529 .83601 .58193 .84876 .57834 .84351 .57167 Mtetra
.84351 .57167 .84876 .57834 .86157 .57473 .85636 .56803 Mtetra
.85636 .56803 .86157 .57473 .87443 .57111 .86927 .56438 Mtetra
.86927 .56438 .87443 .57111 .88735 .56747 .88223 .56071 Mtetra
.88223 .56071 .88735 .56747 .90033 .56382 .89525 .55703 Mtetra
.89525 .55703 .90033 .56382 .91337 .56015 .90833 .55333 Mtetra
.90833 .55333 .91337 .56015 .92646 .55646 .92147 .54961 Mtetra
.92147 .54961 .92646 .55646 .93962 .55276 .93466 .54588 Mtetra
.93466 .54588 .93962 .55276 .95283 .54904 .94792 .54213 Mtetra
.94792 .54213 .95283 .54904 .9661 .5453 .96123 .53836 Mtetra
.656 .751 .919 r
.35705 .6547 .36361 .66046 .37428 .65735 .36775 .65157 Mtetra
.36775 .65157 .37428 .65735 .38498 .65422 .37848 .64842 Mtetra
.37848 .64842 .38498 .65422 .39573 .65109 .38926 .64526 Mtetra
.38926 .64526 .39573 .65109 .40653 .64794 .40008 .64209 Mtetra
.40008 .64209 .40653 .64794 .41736 .64478 .41094 .63891 Mtetra
.41094 .63891 .41736 .64478 .42825 .6416 .42185 .63571 Mtetra
.42185 .63571 .42825 .6416 .43917 .63842 .4328 .6325 Mtetra
.4328 .6325 .43917 .63842 .45014 .63522 .4438 .62927 Mtetra
.4438 .62927 .45014 .63522 .46115 .632 .45484 .62604 Mtetra
.45484 .62604 .46115 .632 .47221 .62878 .46593 .62279 Mtetra
.46593 .62279 .47221 .62878 .48331 .62554 .47706 .61952 Mtetra
.47706 .61952 .48331 .62554 .49446 .62229 .48824 .61625 Mtetra
.48824 .61625 .49446 .62229 .50566 .61902 .49946 .61296 Mtetra
.49946 .61296 .50566 .61902 .5169 .61574 .51073 .60965 Mtetra
.51073 .60965 .5169 .61574 .52818 .61245 .52205 .60634 Mtetra
.52205 .60634 .52818 .61245 .53952 .60914 .53341 .60301 Mtetra
.956 .634 .373 r
.53341 .60301 .53952 .60914 .55152 .68746 .5453 .68147 Mtetra
.649 .759 .929 r
.5453 .68147 .55152 .68746 .56322 .68422 .55703 .67821 Mtetra
.55703 .67821 .56322 .68422 .57497 .68097 .56882 .67493 Mtetra
.56882 .67493 .57497 .68097 .58677 .6777 .58065 .67163 Mtetra
.58065 .67163 .58677 .6777 .59862 .67442 .59254 .66833 Mtetra
.59254 .66833 .59862 .67442 .61052 .67112 .60447 .665 Mtetra
.60447 .665 .61052 .67112 .62247 .66782 .61646 .66167 Mtetra
.61646 .66167 .62247 .66782 .63447 .66449 .6285 .65832 Mtetra
.6285 .65832 .63447 .66449 .64653 .66115 .64059 .65495 Mtetra
.64059 .65495 .64653 .66115 .65864 .6578 .65273 .65157 Mtetra
.65273 .65157 .65864 .6578 .6708 .65443 .66492 .64818 Mtetra
.66492 .64818 .6708 .65443 .68301 .65105 .67717 .64477 Mtetra
.67717 .64477 .68301 .65105 .69527 .64766 .68947 .64135 Mtetra
.68947 .64135 .69527 .64766 .70759 .64425 .70183 .63791 Mtetra
.70183 .63791 .70759 .64425 .71996 .64082 .71424 .63446 Mtetra
.71424 .63446 .71996 .64082 .73239 .63738 .7267 .63099 Mtetra
.7267 .63099 .73239 .63738 .74487 .63392 .73922 .6275 Mtetra
.947 .772 .632 r
.73922 .6275 .74487 .63392 .75513 .59667 .74956 .59015 Mtetra
.652 .756 .925 r
.74956 .59015 .75513 .59667 .76759 .59315 .76206 .5866 Mtetra
.76206 .5866 .76759 .59315 .78011 .58961 .77462 .58303 Mtetra
.77462 .58303 .78011 .58961 .79268 .58605 .78723 .57944 Mtetra
.78723 .57944 .79268 .58605 .8053 .58248 .79989 .57584 Mtetra
.79989 .57584 .8053 .58248 .81798 .57889 .81261 .57223 Mtetra
.81261 .57223 .81798 .57889 .83072 .57529 .82539 .56859 Mtetra
.82539 .56859 .83072 .57529 .84351 .57167 .83822 .56494 Mtetra
.83822 .56494 .84351 .57167 .85636 .56803 .85111 .56128 Mtetra
.85111 .56128 .85636 .56803 .86927 .56438 .86406 .5576 Mtetra
.86406 .5576 .86927 .56438 .88223 .56071 .87706 .5539 Mtetra
.87706 .5539 .88223 .56071 .89525 .55703 .89013 .55019 Mtetra
.89013 .55019 .89525 .55703 .90833 .55333 .90325 .54646 Mtetra
.90325 .54646 .90833 .55333 .92147 .54961 .91643 .54271 Mtetra
.91643 .54271 .92147 .54961 .93466 .54588 .92967 .53894 Mtetra
.92967 .53894 .93466 .54588 .94792 .54213 .94297 .53516 Mtetra
.94297 .53516 .94792 .54213 .96123 .53836 .95633 .53136 Mtetra
.656 .751 .919 r
.35045 .64891 .35705 .6547 .36775 .65157 .36117 .64575 Mtetra
.36117 .64575 .36775 .65157 .37848 .64842 .37193 .64258 Mtetra
.37193 .64258 .37848 .64842 .38926 .64526 .38273 .6394 Mtetra
.38273 .6394 .38926 .64526 .40008 .64209 .39358 .6362 Mtetra
.39358 .6362 .40008 .64209 .41094 .63891 .40447 .63299 Mtetra
.40447 .63299 .41094 .63891 .42185 .63571 .41541 .62977 Mtetra
.41541 .62977 .42185 .63571 .4328 .6325 .42639 .62654 Mtetra
.42639 .62654 .4328 .6325 .4438 .62927 .43741 .62329 Mtetra
.43741 .62329 .4438 .62927 .45484 .62604 .44848 .62003 Mtetra
.44848 .62003 .45484 .62604 .46593 .62279 .4596 .61675 Mtetra
.4596 .61675 .46593 .62279 .47706 .61952 .47076 .61346 Mtetra
.47076 .61346 .47706 .61952 .48824 .61625 .48197 .61016 Mtetra
.48197 .61016 .48824 .61625 .49946 .61296 .49322 .60685 Mtetra
.49322 .60685 .49946 .61296 .51073 .60965 .50452 .60352 Mtetra
.50452 .60352 .51073 .60965 .52205 .60634 .51587 .60018 Mtetra
.51587 .60018 .52205 .60634 .53341 .60301 .52726 .59682 Mtetra
.956 .634 .373 r
.52726 .59682 .53341 .60301 .5453 .68147 .53904 .67543 Mtetra
.649 .759 .929 r
.53904 .67543 .5453 .68147 .55703 .67821 .5508 .67214 Mtetra
.5508 .67214 .55703 .67821 .56882 .67493 .56262 .66884 Mtetra
.56262 .66884 .56882 .67493 .58065 .67163 .57449 .66552 Mtetra
.57449 .66552 .58065 .67163 .59254 .66833 .58641 .66218 Mtetra
.58641 .66218 .59254 .66833 .60447 .665 .59838 .65883 Mtetra
.59838 .65883 .60447 .665 .61646 .66167 .6104 .65547 Mtetra
.6104 .65547 .61646 .66167 .6285 .65832 .62247 .65209 Mtetra
.62247 .65209 .6285 .65832 .64059 .65495 .6346 .6487 Mtetra
.6346 .6487 .64059 .65495 .65273 .65157 .64677 .6453 Mtetra
.64677 .6453 .65273 .65157 .66492 .64818 .65901 .64188 Mtetra
.65901 .64188 .66492 .64818 .67717 .64477 .67129 .63844 Mtetra
.67129 .63844 .67717 .64477 .68947 .64135 .68363 .63499 Mtetra
.68363 .63499 .68947 .64135 .70183 .63791 .69602 .63152 Mtetra
.69602 .63152 .70183 .63791 .71424 .63446 .70847 .62804 Mtetra
.70847 .62804 .71424 .63446 .7267 .63099 .72097 .62454 Mtetra
.72097 .62454 .7267 .63099 .73922 .6275 .73352 .62103 Mtetra
.947 .772 .632 r
.73352 .62103 .73922 .6275 .74956 .59015 .74395 .58358 Mtetra
.652 .756 .925 r
.74395 .58358 .74956 .59015 .76206 .5866 .75649 .58 Mtetra
.75649 .58 .76206 .5866 .77462 .58303 .76909 .5764 Mtetra
.76909 .5764 .77462 .58303 .78723 .57944 .78173 .57278 Mtetra
.78173 .57278 .78723 .57944 .79989 .57584 .79444 .56915 Mtetra
.79444 .56915 .79989 .57584 .81261 .57223 .8072 .56551 Mtetra
.8072 .56551 .81261 .57223 .82539 .56859 .82002 .56184 Mtetra
.82002 .56184 .82539 .56859 .83822 .56494 .83289 .55817 Mtetra
.83289 .55817 .83822 .56494 .85111 .56128 .84582 .55447 Mtetra
.84582 .55447 .85111 .56128 .86406 .5576 .85881 .55076 Mtetra
.85881 .55076 .86406 .5576 .87706 .5539 .87186 .54703 Mtetra
.87186 .54703 .87706 .5539 .89013 .55019 .88496 .54329 Mtetra
.88496 .54329 .89013 .55019 .90325 .54646 .89813 .53952 Mtetra
.89813 .53952 .90325 .54646 .91643 .54271 .91135 .53575 Mtetra
.91135 .53575 .91643 .54271 .92967 .53894 .92463 .53195 Mtetra
.92463 .53195 .92967 .53894 .94297 .53516 .93798 .52814 Mtetra
.93798 .52814 .94297 .53516 .95633 .53136 .95138 .52431 Mtetra
.656 .751 .919 r
.34379 .64307 .35045 .64891 .36117 .64575 .35454 .63989 Mtetra
.35454 .63989 .36117 .64575 .37193 .64258 .36533 .63669 Mtetra
.36533 .63669 .37193 .64258 .38273 .6394 .37616 .63349 Mtetra
.37616 .63349 .38273 .6394 .39358 .6362 .38703 .63027 Mtetra
.38703 .63027 .39358 .6362 .40447 .63299 .39795 .62704 Mtetra
.39795 .62704 .40447 .63299 .41541 .62977 .40892 .62379 Mtetra
.40892 .62379 .41541 .62977 .42639 .62654 .41992 .62053 Mtetra
.41992 .62053 .42639 .62654 .43741 .62329 .43098 .61726 Mtetra
.43098 .61726 .43741 .62329 .44848 .62003 .44208 .61397 Mtetra
.44208 .61397 .44848 .62003 .4596 .61675 .45322 .61067 Mtetra
.45322 .61067 .4596 .61675 .47076 .61346 .46441 .60736 Mtetra
.46441 .60736 .47076 .61346 .48197 .61016 .47565 .60403 Mtetra
.47565 .60403 .48197 .61016 .49322 .60685 .48693 .60069 Mtetra
.48693 .60069 .49322 .60685 .50452 .60352 .49827 .59734 Mtetra
.49827 .59734 .50452 .60352 .51587 .60018 .50964 .59397 Mtetra
.50964 .59397 .51587 .60018 .52726 .59682 .52107 .59059 Mtetra
.956 .634 .373 r
.52107 .59059 .52726 .59682 .53904 .67543 .53273 .66934 Mtetra
.649 .759 .929 r
.53273 .66934 .53904 .67543 .5508 .67214 .54452 .66603 Mtetra
.54452 .66603 .5508 .67214 .56262 .66884 .55637 .6627 Mtetra
.55637 .6627 .56262 .66884 .57449 .66552 .56828 .65935 Mtetra
.56828 .65935 .57449 .66552 .58641 .66218 .58023 .65599 Mtetra
.58023 .65599 .58641 .66218 .59838 .65883 .59223 .65262 Mtetra
.59223 .65262 .59838 .65883 .6104 .65547 .60429 .64923 Mtetra
.60429 .64923 .6104 .65547 .62247 .65209 .6164 .64582 Mtetra
.6164 .64582 .62247 .65209 .6346 .6487 .62856 .6424 Mtetra
.62856 .6424 .6346 .6487 .64677 .6453 .64077 .63897 Mtetra
.64077 .63897 .64677 .6453 .65901 .64188 .65304 .63552 Mtetra
.65304 .63552 .65901 .64188 .67129 .63844 .66536 .63206 Mtetra
.66536 .63206 .67129 .63844 .68363 .63499 .67773 .62858 Mtetra
.67773 .62858 .68363 .63499 .69602 .63152 .69016 .62508 Mtetra
.69016 .62508 .69602 .63152 .70847 .62804 .70265 .62157 Mtetra
.70265 .62157 .70847 .62804 .72097 .62454 .71519 .61805 Mtetra
.71519 .61805 .72097 .62454 .73352 .62103 .72778 .61451 Mtetra
.947 .772 .632 r
.72778 .61451 .73352 .62103 .74395 .58358 .7383 .57695 Mtetra
.652 .756 .925 r
.7383 .57695 .74395 .58358 .75649 .58 .75088 .57334 Mtetra
.75088 .57334 .75649 .58 .76909 .5764 .76351 .56971 Mtetra
.76351 .56971 .76909 .5764 .78173 .57278 .7762 .56607 Mtetra
.7762 .56607 .78173 .57278 .79444 .56915 .78894 .56241 Mtetra
.78894 .56241 .79444 .56915 .8072 .56551 .80174 .55873 Mtetra
.80174 .55873 .8072 .56551 .82002 .56184 .8146 .55504 Mtetra
.8146 .55504 .82002 .56184 .83289 .55817 .82751 .55133 Mtetra
.82751 .55133 .83289 .55817 .84582 .55447 .84048 .54761 Mtetra
.84048 .54761 .84582 .55447 .85881 .55076 .85352 .54386 Mtetra
.85352 .54386 .85881 .55076 .87186 .54703 .8666 .5401 Mtetra
.8666 .5401 .87186 .54703 .88496 .54329 .87975 .53633 Mtetra
.87975 .53633 .88496 .54329 .89813 .53952 .89296 .53254 Mtetra
.89296 .53254 .89813 .53952 .91135 .53575 .90623 .52873 Mtetra
.90623 .52873 .91135 .53575 .92463 .53195 .91955 .5249 Mtetra
.91955 .5249 .92463 .53195 .93798 .52814 .93294 .52105 Mtetra
.93294 .52105 .93798 .52814 .95138 .52431 .94639 .51719 Mtetra
.656 .751 .919 r
.33709 .63719 .34379 .64307 .35454 .63989 .34786 .63398 Mtetra
.34786 .63398 .35454 .63989 .36533 .63669 .35867 .63076 Mtetra
.35867 .63076 .36533 .63669 .37616 .63349 .36953 .62753 Mtetra
.36953 .62753 .37616 .63349 .38703 .63027 .38044 .62429 Mtetra
.38044 .62429 .38703 .63027 .39795 .62704 .39138 .62103 Mtetra
.39138 .62103 .39795 .62704 .40892 .62379 .40237 .61776 Mtetra
.40237 .61776 .40892 .62379 .41992 .62053 .41341 .61448 Mtetra
.41341 .61448 .41992 .62053 .43098 .61726 .42449 .61118 Mtetra
.42449 .61118 .43098 .61726 .44208 .61397 .43562 .60787 Mtetra
.43562 .60787 .44208 .61397 .45322 .61067 .4468 .60454 Mtetra
.4468 .60454 .45322 .61067 .46441 .60736 .45802 .60121 Mtetra
.45802 .60121 .46441 .60736 .47565 .60403 .46928 .59785 Mtetra
.46928 .59785 .47565 .60403 .48693 .60069 .4806 .59449 Mtetra
.4806 .59449 .48693 .60069 .49827 .59734 .49196 .59111 Mtetra
.49196 .59111 .49827 .59734 .50964 .59397 .50337 .58771 Mtetra
.50337 .58771 .50964 .59397 .52107 .59059 .51482 .5843 Mtetra
.956 .634 .373 r
.51482 .5843 .52107 .59059 .53273 .66934 .52636 .66321 Mtetra
.649 .759 .929 r
.52636 .66321 .53273 .66934 .54452 .66603 .53819 .65987 Mtetra
.53819 .65987 .54452 .66603 .55637 .6627 .55008 .65651 Mtetra
.55008 .65651 .55637 .6627 .56828 .65935 .56201 .65314 Mtetra
.56201 .65314 .56828 .65935 .58023 .65599 .574 .64975 Mtetra
.574 .64975 .58023 .65599 .59223 .65262 .58604 .64635 Mtetra
.58604 .64635 .59223 .65262 .60429 .64923 .59813 .64293 Mtetra
.59813 .64293 .60429 .64923 .6164 .64582 .61027 .6395 Mtetra
.61027 .6395 .6164 .64582 .62856 .6424 .62247 .63605 Mtetra
.62247 .63605 .62856 .6424 .64077 .63897 .63472 .63259 Mtetra
.63472 .63259 .64077 .63897 .65304 .63552 .64702 .62911 Mtetra
.64702 .62911 .65304 .63552 .66536 .63206 .65938 .62562 Mtetra
.65938 .62562 .66536 .63206 .67773 .62858 .67179 .62211 Mtetra
.67179 .62211 .67773 .62858 .69016 .62508 .68426 .61859 Mtetra
.68426 .61859 .69016 .62508 .70265 .62157 .69678 .61505 Mtetra
.69678 .61505 .70265 .62157 .71519 .61805 .70936 .6115 Mtetra
.70936 .6115 .71519 .61805 .72778 .61451 .72199 .60793 Mtetra
.947 .772 .632 r
.72199 .60793 .72778 .61451 .7383 .57695 .7326 .57027 Mtetra
.652 .756 .925 r
.7326 .57027 .7383 .57695 .75088 .57334 .74521 .56663 Mtetra
.74521 .56663 .75088 .57334 .76351 .56971 .75788 .56297 Mtetra
.75788 .56297 .76351 .56971 .7762 .56607 .77061 .5593 Mtetra
.77061 .5593 .7762 .56607 .78894 .56241 .7834 .55561 Mtetra
.7834 .55561 .78894 .56241 .80174 .55873 .79624 .5519 Mtetra
.79624 .5519 .80174 .55873 .8146 .55504 .80913 .54818 Mtetra
.80913 .54818 .8146 .55504 .82751 .55133 .82209 .54444 Mtetra
.82209 .54444 .82751 .55133 .84048 .54761 .8351 .54068 Mtetra
.8351 .54068 .84048 .54761 .85352 .54386 .84818 .53691 Mtetra
.84818 .53691 .85352 .54386 .8666 .5401 .86131 .53312 Mtetra
.86131 .53312 .8666 .5401 .87975 .53633 .8745 .52931 Mtetra
.8745 .52931 .87975 .53633 .89296 .53254 .88775 .52549 Mtetra
.88775 .52549 .89296 .53254 .90623 .52873 .90106 .52165 Mtetra
.90106 .52165 .90623 .52873 .91955 .5249 .91443 .51779 Mtetra
.91443 .51779 .91955 .5249 .93294 .52105 .92787 .51391 Mtetra
.92787 .51391 .93294 .52105 .94639 .51719 .94136 .51001 Mtetra
.656 .751 .919 r
.33034 .63126 .33709 .63719 .34786 .63398 .34113 .62803 Mtetra
.34113 .62803 .34786 .63398 .35867 .63076 .35197 .62479 Mtetra
.35197 .62479 .35867 .63076 .36953 .62753 .36286 .62153 Mtetra
.36286 .62153 .36953 .62753 .38044 .62429 .37379 .61827 Mtetra
.37379 .61827 .38044 .62429 .39138 .62103 .38476 .61498 Mtetra
.38476 .61498 .39138 .62103 .40237 .61776 .39578 .61169 Mtetra
.39578 .61169 .40237 .61776 .41341 .61448 .40685 .60838 Mtetra
.40685 .60838 .41341 .61448 .42449 .61118 .41796 .60506 Mtetra
.41796 .60506 .42449 .61118 .43562 .60787 .42912 .60172 Mtetra
.42912 .60172 .43562 .60787 .4468 .60454 .44032 .59837 Mtetra
.44032 .59837 .4468 .60454 .45802 .60121 .45157 .59501 Mtetra
.45157 .59501 .45802 .60121 .46928 .59785 .46287 .59163 Mtetra
.46287 .59163 .46928 .59785 .4806 .59449 .47421 .58824 Mtetra
.47421 .58824 .4806 .59449 .49196 .59111 .4856 .58483 Mtetra
.4856 .58483 .49196 .59111 .50337 .58771 .49704 .58141 Mtetra
.49704 .58141 .50337 .58771 .51482 .5843 .50853 .57797 Mtetra
.956 .634 .373 r
.50853 .57797 .51482 .5843 .52636 .66321 .51995 .65703 Mtetra
.649 .759 .929 r
.51995 .65703 .52636 .66321 .53819 .65987 .53181 .65366 Mtetra
.53181 .65366 .53819 .65987 .55008 .65651 .54373 .65027 Mtetra
.54373 .65027 .55008 .65651 .56201 .65314 .5557 .64687 Mtetra
.5557 .64687 .56201 .65314 .574 .64975 .56772 .64346 Mtetra
.56772 .64346 .574 .64975 .58604 .64635 .5798 .64003 Mtetra
.5798 .64003 .58604 .64635 .59813 .64293 .59192 .63658 Mtetra
.59192 .63658 .59813 .64293 .61027 .6395 .6041 .63312 Mtetra
.6041 .63312 .61027 .6395 .62247 .63605 .61633 .62965 Mtetra
.61633 .62965 .62247 .63605 .63472 .63259 .62862 .62616 Mtetra
.62862 .62616 .63472 .63259 .64702 .62911 .64096 .62266 Mtetra
.64096 .62266 .64702 .62911 .65938 .62562 .65335 .61913 Mtetra
.65335 .61913 .65938 .62562 .67179 .62211 .6658 .6156 Mtetra
.6658 .6156 .67179 .62211 .68426 .61859 .67831 .61205 Mtetra
.67831 .61205 .68426 .61859 .69678 .61505 .69087 .60848 Mtetra
.69087 .60848 .69678 .61505 .70936 .6115 .70349 .6049 Mtetra
.70349 .6049 .70936 .6115 .72199 .60793 .71616 .6013 Mtetra
.947 .772 .632 r
.71616 .6013 .72199 .60793 .7326 .57027 .72685 .56354 Mtetra
.652 .756 .925 r
.72685 .56354 .7326 .57027 .74521 .56663 .7395 .55987 Mtetra
.7395 .55987 .74521 .56663 .75788 .56297 .75221 .55618 Mtetra
.75221 .55618 .75788 .56297 .77061 .5593 .76498 .55247 Mtetra
.76498 .55247 .77061 .5593 .7834 .55561 .77781 .54875 Mtetra
.77781 .54875 .7834 .55561 .79624 .5519 .79069 .54502 Mtetra
.79069 .54502 .79624 .5519 .80913 .54818 .80363 .54126 Mtetra
.80363 .54126 .80913 .54818 .82209 .54444 .81662 .53749 Mtetra
.81662 .53749 .82209 .54444 .8351 .54068 .82968 .5337 Mtetra
.82968 .5337 .8351 .54068 .84818 .53691 .84279 .5299 Mtetra
.84279 .5299 .84818 .53691 .86131 .53312 .85597 .52608 Mtetra
.85597 .52608 .86131 .53312 .8745 .52931 .8692 .52224 Mtetra
.8692 .52224 .8745 .52931 .88775 .52549 .8825 .51838 Mtetra
.8825 .51838 .88775 .52549 .90106 .52165 .89585 .51451 Mtetra
.89585 .51451 .90106 .52165 .91443 .51779 .90927 .51061 Mtetra
.90927 .51061 .91443 .51779 .92787 .51391 .92275 .5067 Mtetra
.92275 .5067 .92787 .51391 .94136 .51001 .93629 .50278 Mtetra
.656 .751 .919 r
.32353 .62529 .33034 .63126 .34113 .62803 .33435 .62204 Mtetra
.33435 .62204 .34113 .62803 .35197 .62479 .34522 .61877 Mtetra
.34522 .61877 .35197 .62479 .36286 .62153 .35613 .61549 Mtetra
.35613 .61549 .36286 .62153 .37379 .61827 .36709 .6122 Mtetra
.36709 .6122 .37379 .61827 .38476 .61498 .3781 .60889 Mtetra
.3781 .60889 .38476 .61498 .39578 .61169 .38914 .60557 Mtetra
.38914 .60557 .39578 .61169 .40685 .60838 .40024 .60223 Mtetra
.40024 .60223 .40685 .60838 .41796 .60506 .41138 .59889 Mtetra
.41138 .59889 .41796 .60506 .42912 .60172 .42256 .59552 Mtetra
.42256 .59552 .42912 .60172 .44032 .59837 .4338 .59215 Mtetra
.4338 .59215 .44032 .59837 .45157 .59501 .44508 .58876 Mtetra
.44508 .58876 .45157 .59501 .46287 .59163 .4564 .58535 Mtetra
.4564 .58535 .46287 .59163 .47421 .58824 .46778 .58194 Mtetra
.46778 .58194 .47421 .58824 .4856 .58483 .4792 .5785 Mtetra
.4792 .5785 .4856 .58483 .49704 .58141 .49067 .57506 Mtetra
.49067 .57506 .49704 .58141 .50853 .57797 .50219 .57159 Mtetra
.956 .634 .373 r
.50219 .57159 .50853 .57797 .51995 .65703 .51348 .65079 Mtetra
.649 .759 .929 r
.51348 .65079 .51995 .65703 .53181 .65366 .52538 .64739 Mtetra
.52538 .64739 .53181 .65366 .54373 .65027 .53733 .64398 Mtetra
.53733 .64398 .54373 .65027 .5557 .64687 .54934 .64056 Mtetra
.54934 .64056 .5557 .64687 .56772 .64346 .56139 .63711 Mtetra
.56139 .63711 .56772 .64346 .5798 .64003 .5735 .63366 Mtetra
.5735 .63366 .5798 .64003 .59192 .63658 .58566 .63019 Mtetra
.58566 .63019 .59192 .63658 .6041 .63312 .59788 .6267 Mtetra
.59788 .6267 .6041 .63312 .61633 .62965 .61015 .6232 Mtetra
.61015 .6232 .61633 .62965 .62862 .62616 .62247 .61968 Mtetra
.62247 .61968 .62862 .62616 .64096 .62266 .63485 .61614 Mtetra
.63485 .61614 .64096 .62266 .65335 .61913 .64728 .61259 Mtetra
.64728 .61259 .65335 .61913 .6658 .6156 .65976 .60903 Mtetra
.65976 .60903 .6658 .6156 .67831 .61205 .67231 .60545 Mtetra
.67231 .60545 .67831 .61205 .69087 .60848 .68491 .60185 Mtetra
.68491 .60185 .69087 .60848 .70349 .6049 .69756 .59824 Mtetra
.69756 .59824 .70349 .6049 .71616 .6013 .71027 .59461 Mtetra
.947 .772 .632 r
.71027 .59461 .71616 .6013 .72685 .56354 .72106 .55675 Mtetra
.652 .756 .925 r
.72106 .55675 .72685 .56354 .7395 .55987 .73375 .55305 Mtetra
.73375 .55305 .7395 .55987 .75221 .55618 .7465 .54933 Mtetra
.7465 .54933 .75221 .55618 .76498 .55247 .75931 .54559 Mtetra
.75931 .54559 .76498 .55247 .77781 .54875 .77217 .54184 Mtetra
.77217 .54184 .77781 .54875 .79069 .54502 .78509 .53807 Mtetra
.78509 .53807 .79069 .54502 .80363 .54126 .79807 .53429 Mtetra
.79807 .53429 .80363 .54126 .81662 .53749 .81111 .53049 Mtetra
.81111 .53049 .81662 .53749 .82968 .5337 .82421 .52667 Mtetra
.82421 .52667 .82968 .5337 .84279 .5299 .83737 .52283 Mtetra
.83737 .52283 .84279 .5299 .85597 .52608 .85058 .51898 Mtetra
.85058 .51898 .85597 .52608 .8692 .52224 .86386 .5151 Mtetra
.86386 .5151 .8692 .52224 .8825 .51838 .8772 .51121 Mtetra
.8772 .51121 .8825 .51838 .89585 .51451 .8906 .50731 Mtetra
.8906 .50731 .89585 .51451 .90927 .51061 .90406 .50338 Mtetra
.90406 .50338 .90927 .51061 .92275 .5067 .91758 .49944 Mtetra
.91758 .49944 .92275 .5067 .93629 .50278 .93117 .49548 Mtetra
.656 .751 .919 r
.31667 .61927 .32353 .62529 .33435 .62204 .32752 .616 Mtetra
.32752 .616 .33435 .62204 .34522 .61877 .33842 .6127 Mtetra
.33842 .6127 .34522 .61877 .35613 .61549 .34936 .6094 Mtetra
.34936 .6094 .35613 .61549 .36709 .6122 .36034 .60608 Mtetra
.36034 .60608 .36709 .6122 .3781 .60889 .37138 .60275 Mtetra
.37138 .60275 .3781 .60889 .38914 .60557 .38245 .5994 Mtetra
.38245 .5994 .38914 .60557 .40024 .60223 .39358 .59604 Mtetra
.39358 .59604 .40024 .60223 .41138 .59889 .40474 .59267 Mtetra
.40474 .59267 .41138 .59889 .42256 .59552 .41596 .58928 Mtetra
.41596 .58928 .42256 .59552 .4338 .59215 .42722 .58588 Mtetra
.42722 .58588 .4338 .59215 .44508 .58876 .43853 .58246 Mtetra
.43853 .58246 .44508 .58876 .4564 .58535 .44989 .57903 Mtetra
.44989 .57903 .4564 .58535 .46778 .58194 .46129 .57559 Mtetra
.46129 .57559 .46778 .58194 .4792 .5785 .47275 .57213 Mtetra
.47275 .57213 .4792 .5785 .49067 .57506 .48425 .56865 Mtetra
.48425 .56865 .49067 .57506 .50219 .57159 .4958 .56516 Mtetra
.956 .634 .373 r
.4958 .56516 .50219 .57159 .51348 .65079 .50697 .64451 Mtetra
.649 .759 .929 r
.50697 .64451 .51348 .65079 .52538 .64739 .5189 .64108 Mtetra
.5189 .64108 .52538 .64739 .53733 .64398 .53089 .63764 Mtetra
.53089 .63764 .53733 .64398 .54934 .64056 .54292 .63419 Mtetra
.54292 .63419 .54934 .64056 .56139 .63711 .55501 .63072 Mtetra
.55501 .63072 .56139 .63711 .5735 .63366 .56716 .62724 Mtetra
.56716 .62724 .5735 .63366 .58566 .63019 .57935 .62374 Mtetra
.57935 .62374 .58566 .63019 .59788 .6267 .5916 .62022 Mtetra
.5916 .62022 .59788 .6267 .61015 .6232 .60391 .61669 Mtetra
.60391 .61669 .61015 .6232 .62247 .61968 .61627 .61314 Mtetra
.61627 .61314 .62247 .61968 .63485 .61614 .62868 .60958 Mtetra
.62868 .60958 .63485 .61614 .64728 .61259 .64115 .606 Mtetra
.64115 .606 .64728 .61259 .65976 .60903 .65368 .60241 Mtetra
.65368 .60241 .65976 .60903 .67231 .60545 .66626 .5988 Mtetra
.66626 .5988 .67231 .60545 .68491 .60185 .67889 .59517 Mtetra
.67889 .59517 .68491 .60185 .69756 .59824 .69159 .59153 Mtetra
.69159 .59153 .69756 .59824 .71027 .59461 .70434 .58787 Mtetra
.947 .772 .632 r
.70434 .58787 .71027 .59461 .72106 .55675 .71521 .5499 Mtetra
.652 .756 .925 r
.71521 .5499 .72106 .55675 .73375 .55305 .72795 .54617 Mtetra
.72795 .54617 .73375 .55305 .7465 .54933 .74074 .54242 Mtetra
.74074 .54242 .7465 .54933 .75931 .54559 .75358 .53865 Mtetra
.75358 .53865 .75931 .54559 .77217 .54184 .76649 .53487 Mtetra
.76649 .53487 .77217 .54184 .78509 .53807 .77945 .53107 Mtetra
.77945 .53107 .78509 .53807 .79807 .53429 .79247 .52726 Mtetra
.79247 .52726 .79807 .53429 .81111 .53049 .80555 .52342 Mtetra
.80555 .52342 .81111 .53049 .82421 .52667 .81869 .51957 Mtetra
.81869 .51957 .82421 .52667 .83737 .52283 .83189 .5157 Mtetra
.83189 .5157 .83737 .52283 .85058 .51898 .84515 .51181 Mtetra
.84515 .51181 .85058 .51898 .86386 .5151 .85848 .50791 Mtetra
.85848 .50791 .86386 .5151 .8772 .51121 .87186 .50399 Mtetra
.87186 .50399 .8772 .51121 .8906 .50731 .8853 .50005 Mtetra
.8853 .50005 .8906 .50731 .90406 .50338 .89881 .49609 Mtetra
.89881 .49609 .90406 .50338 .91758 .49944 .91238 .49211 Mtetra
.91238 .49211 .91758 .49944 .93117 .49548 .92601 .48812 Mtetra
.656 .751 .919 r
.30976 .61321 .31667 .61927 .32752 .616 .32064 .60991 Mtetra
.32064 .60991 .32752 .616 .33842 .6127 .33156 .60659 Mtetra
.33156 .60659 .33842 .6127 .34936 .6094 .34253 .60326 Mtetra
.34253 .60326 .34936 .6094 .36034 .60608 .35355 .59992 Mtetra
.35355 .59992 .36034 .60608 .37138 .60275 .3646 .59656 Mtetra
.3646 .59656 .37138 .60275 .38245 .5994 .37571 .59319 Mtetra
.37571 .59319 .38245 .5994 .39358 .59604 .38686 .5898 Mtetra
.38686 .5898 .39358 .59604 .40474 .59267 .39806 .5864 Mtetra
.39806 .5864 .40474 .59267 .41596 .58928 .4093 .58299 Mtetra
.4093 .58299 .41596 .58928 .42722 .58588 .4206 .57956 Mtetra
.4206 .57956 .42722 .58588 .43853 .58246 .43194 .57612 Mtetra
.43194 .57612 .43853 .58246 .44989 .57903 .44332 .57266 Mtetra
.44332 .57266 .44989 .57903 .46129 .57559 .45476 .56919 Mtetra
.45476 .56919 .46129 .57559 .47275 .57213 .46624 .5657 Mtetra
.46624 .5657 .47275 .57213 .48425 .56865 .47777 .5622 Mtetra
.47777 .5622 .48425 .56865 .4958 .56516 .48936 .55868 Mtetra
.956 .634 .373 r
.48936 .55868 .4958 .56516 .50697 .64451 .5004 .63817 Mtetra
.649 .759 .929 r
.5004 .63817 .50697 .64451 .5189 .64108 .51237 .63472 Mtetra
.51237 .63472 .5189 .64108 .53089 .63764 .52438 .63126 Mtetra
.52438 .63126 .53089 .63764 .54292 .63419 .53646 .62777 Mtetra
.53646 .62777 .54292 .63419 .55501 .63072 .54858 .62427 Mtetra
.54858 .62427 .55501 .63072 .56716 .62724 .56076 .62076 Mtetra
.56076 .62076 .56716 .62724 .57935 .62374 .57299 .61723 Mtetra
.57299 .61723 .57935 .62374 .5916 .62022 .58528 .61369 Mtetra
.58528 .61369 .5916 .62022 .60391 .61669 .59762 .61013 Mtetra
.59762 .61013 .60391 .61669 .61627 .61314 .61002 .60655 Mtetra
.61002 .60655 .61627 .61314 .62868 .60958 .62247 .60296 Mtetra
.62247 .60296 .62868 .60958 .64115 .606 .63497 .59935 Mtetra
.63497 .59935 .64115 .606 .65368 .60241 .64754 .59573 Mtetra
.64754 .59573 .65368 .60241 .66626 .5988 .66016 .59209 Mtetra
.66016 .59209 .66626 .5988 .67889 .59517 .67283 .58843 Mtetra
.67283 .58843 .67889 .59517 .69159 .59153 .68557 .58476 Mtetra
.68557 .58476 .69159 .59153 .70434 .58787 .69836 .58107 Mtetra
.947 .772 .632 r
.69836 .58107 .70434 .58787 .71521 .5499 .70932 .543 Mtetra
.652 .756 .925 r
.70932 .543 .71521 .5499 .72795 .54617 .72209 .53923 Mtetra
.72209 .53923 .72795 .54617 .74074 .54242 .73492 .53545 Mtetra
.73492 .53545 .74074 .54242 .75358 .53865 .74781 .53166 Mtetra
.74781 .53166 .75358 .53865 .76649 .53487 .76076 .52784 Mtetra
.76076 .52784 .76649 .53487 .77945 .53107 .77376 .52401 Mtetra
.77376 .52401 .77945 .53107 .79247 .52726 .78683 .52016 Mtetra
.78683 .52016 .79247 .52726 .80555 .52342 .79995 .5163 Mtetra
.79995 .5163 .80555 .52342 .81869 .51957 .81313 .51241 Mtetra
.81313 .51241 .81869 .51957 .83189 .5157 .82637 .50851 Mtetra
.82637 .50851 .83189 .5157 .84515 .51181 .83968 .50459 Mtetra
.83968 .50459 .84515 .51181 .85848 .50791 .85304 .50065 Mtetra
.85304 .50065 .85848 .50791 .87186 .50399 .86647 .4967 Mtetra
.86647 .4967 .87186 .50399 .8853 .50005 .87996 .49272 Mtetra
.87996 .49272 .8853 .50005 .89881 .49609 .89351 .48873 Mtetra
.89351 .48873 .89881 .49609 .91238 .49211 .90713 .48472 Mtetra
.90713 .48472 .91238 .49211 .92601 .48812 .9208 .48069 Mtetra
.656 .751 .919 r
.3028 .6071 .30976 .61321 .32064 .60991 .31371 .60378 Mtetra
.31371 .60378 .32064 .60991 .33156 .60659 .32466 .60043 Mtetra
.32466 .60043 .33156 .60659 .34253 .60326 .33565 .59708 Mtetra
.33565 .59708 .34253 .60326 .35355 .59992 .34669 .59371 Mtetra
.34669 .59371 .35355 .59992 .3646 .59656 .35778 .59032 Mtetra
.35778 .59032 .3646 .59656 .37571 .59319 .36892 .58693 Mtetra
.36892 .58693 .37571 .59319 .38686 .5898 .3801 .58352 Mtetra
.3801 .58352 .38686 .5898 .39806 .5864 .39132 .58009 Mtetra
.39132 .58009 .39806 .5864 .4093 .58299 .4026 .57665 Mtetra
.4026 .57665 .4093 .58299 .4206 .57956 .41392 .57319 Mtetra
.41392 .57319 .4206 .57956 .43194 .57612 .42529 .56972 Mtetra
.42529 .56972 .43194 .57612 .44332 .57266 .43671 .56624 Mtetra
.43671 .56624 .44332 .57266 .45476 .56919 .44817 .56274 Mtetra
.44817 .56274 .45476 .56919 .46624 .5657 .45969 .55923 Mtetra
.45969 .55923 .46624 .5657 .47777 .5622 .47125 .5557 Mtetra
.47125 .5557 .47777 .5622 .48936 .55868 .48286 .55215 Mtetra
.956 .634 .373 r
.48286 .55215 .48936 .55868 .5004 .63817 .49378 .63179 Mtetra
.649 .759 .929 r
.49378 .63179 .5004 .63817 .51237 .63472 .50578 .62831 Mtetra
.50578 .62831 .51237 .63472 .52438 .63126 .51783 .62481 Mtetra
.51783 .62481 .52438 .63126 .53646 .62777 .52994 .6213 Mtetra
.52994 .6213 .53646 .62777 .54858 .62427 .5421 .61778 Mtetra
.5421 .61778 .54858 .62427 .56076 .62076 .55431 .61423 Mtetra
.55431 .61423 .56076 .62076 .57299 .61723 .56658 .61068 Mtetra
.56658 .61068 .57299 .61723 .58528 .61369 .5789 .6071 Mtetra
.5789 .6071 .58528 .61369 .59762 .61013 .59128 .60351 Mtetra
.59128 .60351 .59762 .61013 .61002 .60655 .60371 .59991 Mtetra
.60371 .59991 .61002 .60655 .62247 .60296 .6162 .59629 Mtetra
.6162 .59629 .62247 .60296 .63497 .59935 .62875 .59265 Mtetra
.62875 .59265 .63497 .59935 .64754 .59573 .64135 .58899 Mtetra
.64135 .58899 .64754 .59573 .66016 .59209 .65401 .58532 Mtetra
.65401 .58532 .66016 .59209 .67283 .58843 .66672 .58164 Mtetra
.66672 .58164 .67283 .58843 .68557 .58476 .67949 .57793 Mtetra
.67949 .57793 .68557 .58476 .69836 .58107 .69232 .57421 Mtetra
.947 .772 .632 r
.69232 .57421 .69836 .58107 .70932 .543 .70338 .53604 Mtetra
.652 .756 .925 r
.70338 .53604 .70932 .543 .72209 .53923 .71619 .53224 Mtetra
.71619 .53224 .72209 .53923 .73492 .53545 .72906 .52843 Mtetra
.72906 .52843 .73492 .53545 .74781 .53166 .74199 .5246 Mtetra
.74199 .5246 .74781 .53166 .76076 .52784 .75498 .52076 Mtetra
.75498 .52076 .76076 .52784 .77376 .52401 .76802 .51689 Mtetra
.76802 .51689 .77376 .52401 .78683 .52016 .78113 .51301 Mtetra
.78113 .51301 .78683 .52016 .79995 .5163 .7943 .50911 Mtetra
.7943 .50911 .79995 .5163 .81313 .51241 .80752 .5052 Mtetra
.80752 .5052 .81313 .51241 .82637 .50851 .82081 .50126 Mtetra
.82081 .50126 .82637 .50851 .83968 .50459 .83416 .49731 Mtetra
.83416 .49731 .83968 .50459 .85304 .50065 .84757 .49334 Mtetra
.84757 .49334 .85304 .50065 .86647 .4967 .86104 .48935 Mtetra
.86104 .48935 .86647 .4967 .87996 .49272 .87457 .48534 Mtetra
.87457 .48534 .87996 .49272 .89351 .48873 .88817 .48131 Mtetra
.88817 .48131 .89351 .48873 .90713 .48472 .90183 .47727 Mtetra
.90183 .47727 .90713 .48472 .9208 .48069 .91555 .4732 Mtetra
.656 .751 .919 r
.29579 .60095 .3028 .6071 .31371 .60378 .30672 .5976 Mtetra
.30672 .5976 .31371 .60378 .32466 .60043 .3177 .59423 Mtetra
.3177 .59423 .32466 .60043 .33565 .59708 .32872 .59085 Mtetra
.32872 .59085 .33565 .59708 .34669 .59371 .33979 .58745 Mtetra
.33979 .58745 .34669 .59371 .35778 .59032 .35091 .58404 Mtetra
.35091 .58404 .35778 .59032 .36892 .58693 .36207 .58062 Mtetra
.36207 .58062 .36892 .58693 .3801 .58352 .37328 .57718 Mtetra
.37328 .57718 .3801 .58352 .39132 .58009 .38453 .57373 Mtetra
.38453 .57373 .39132 .58009 .4026 .57665 .39584 .57026 Mtetra
.39584 .57026 .4026 .57665 .41392 .57319 .40719 .56678 Mtetra
.40719 .56678 .41392 .57319 .42529 .56972 .41859 .56328 Mtetra
.41859 .56328 .42529 .56972 .43671 .56624 .43004 .55977 Mtetra
.43004 .55977 .43671 .56624 .44817 .56274 .44153 .55624 Mtetra
.44153 .55624 .44817 .56274 .45969 .55923 .45308 .5527 Mtetra
.45308 .5527 .45969 .55923 .47125 .5557 .46468 .54914 Mtetra
.46468 .54914 .47125 .5557 .48286 .55215 .47632 .54557 Mtetra
.956 .634 .373 r
.47632 .54557 .48286 .55215 .49378 .63179 .4871 .62535 Mtetra
.649 .759 .929 r
.4871 .62535 .49378 .63179 .50578 .62831 .49914 .62184 Mtetra
.49914 .62184 .50578 .62831 .51783 .62481 .51122 .61832 Mtetra
.51122 .61832 .51783 .62481 .52994 .6213 .52337 .61478 Mtetra
.52337 .61478 .52994 .6213 .5421 .61778 .53556 .61123 Mtetra
.53556 .61123 .5421 .61778 .55431 .61423 .54781 .60765 Mtetra
.54781 .60765 .55431 .61423 .56658 .61068 .56011 .60407 Mtetra
.56011 .60407 .56658 .61068 .5789 .6071 .57247 .60046 Mtetra
.57247 .60046 .5789 .6071 .59128 .60351 .58489 .59684 Mtetra
.58489 .59684 .59128 .60351 .60371 .59991 .59736 .59321 Mtetra
.59736 .59321 .60371 .59991 .6162 .59629 .60988 .58956 Mtetra
.60988 .58956 .6162 .59629 .62875 .59265 .62247 .58589 Mtetra
.62247 .58589 .62875 .59265 .64135 .58899 .63511 .5822 Mtetra
.63511 .5822 .64135 .58899 .65401 .58532 .6478 .5785 Mtetra
.6478 .5785 .65401 .58532 .66672 .58164 .66056 .57478 Mtetra
.66056 .57478 .66672 .58164 .67949 .57793 .67337 .57105 Mtetra
.67337 .57105 .67949 .57793 .69232 .57421 .68624 .5673 Mtetra
.947 .772 .632 r
.68624 .5673 .69232 .57421 .70338 .53604 .69739 .52902 Mtetra
.652 .756 .925 r
.69739 .52902 .70338 .53604 .71619 .53224 .71024 .52519 Mtetra
.71024 .52519 .71619 .53224 .72906 .52843 .72315 .52135 Mtetra
.72315 .52135 .72906 .52843 .74199 .5246 .73612 .51749 Mtetra
.73612 .51749 .74199 .5246 .75498 .52076 .74915 .51361 Mtetra
.74915 .51361 .75498 .52076 .76802 .51689 .76224 .50971 Mtetra
.76224 .50971 .76802 .51689 .78113 .51301 .77539 .5058 Mtetra
.77539 .5058 .78113 .51301 .7943 .50911 .7886 .50187 Mtetra
.7886 .50187 .7943 .50911 .80752 .5052 .80186 .49792 Mtetra
.80186 .49792 .80752 .5052 .82081 .50126 .81519 .49395 Mtetra
.81519 .49395 .82081 .50126 .83416 .49731 .82859 .48996 Mtetra
.82859 .48996 .83416 .49731 .84757 .49334 .84204 .48596 Mtetra
.84204 .48596 .84757 .49334 .86104 .48935 .85556 .48193 Mtetra
.85556 .48193 .86104 .48935 .87457 .48534 .86914 .47789 Mtetra
.86914 .47789 .87457 .48534 .88817 .48131 .88278 .47383 Mtetra
.88278 .47383 .88817 .48131 .90183 .47727 .89649 .46975 Mtetra
.89649 .46975 .90183 .47727 .91555 .4732 .91026 .46565 Mtetra
.573 .382 .584 r
.29517 .50134 .29579 .60095 .30672 .5976 .30585 .49786 Mtetra
.30585 .49786 .30672 .5976 .3177 .59423 .31656 .49437 Mtetra
.31656 .49437 .3177 .59423 .32872 .59085 .32732 .49087 Mtetra
.32732 .49087 .32872 .59085 .33979 .58745 .33812 .48735 Mtetra
.33812 .48735 .33979 .58745 .35091 .58404 .34897 .48382 Mtetra
.34897 .48382 .35091 .58404 .36207 .58062 .35986 .48027 Mtetra
.35986 .48027 .36207 .58062 .37328 .57718 .3708 .47671 Mtetra
.3708 .47671 .37328 .57718 .38453 .57373 .38178 .47313 Mtetra
.38178 .47313 .38453 .57373 .39584 .57026 .39281 .46954 Mtetra
.39281 .46954 .39584 .57026 .40719 .56678 .40388 .46593 Mtetra
.40388 .46593 .40719 .56678 .41859 .56328 .415 .46231 Mtetra
.415 .46231 .41859 .56328 .43004 .55977 .42616 .45868 Mtetra
.42616 .45868 .43004 .55977 .44153 .55624 .43737 .45503 Mtetra
.43737 .45503 .44153 .55624 .45308 .5527 .44863 .45136 Mtetra
.44863 .45136 .45308 .5527 .46468 .54914 .45993 .44768 Mtetra
.45993 .44768 .46468 .54914 .47632 .54557 .47128 .44398 Mtetra
.13 .05 .49 r
.47128 .44398 .47632 .54557 .4871 .62535 .48166 .5191 Mtetra
.572 .381 .584 r
.48166 .5191 .4871 .62535 .49914 .62184 .49338 .51545 Mtetra
.49338 .51545 .49914 .62184 .51122 .61832 .50515 .51178 Mtetra
.50515 .51178 .51122 .61832 .52337 .61478 .51698 .5081 Mtetra
.51698 .5081 .52337 .61478 .53556 .61123 .52885 .50441 Mtetra
.52885 .50441 .53556 .61123 .54781 .60765 .54078 .50069 Mtetra
.54078 .50069 .54781 .60765 .56011 .60407 .55275 .49697 Mtetra
.55275 .49697 .56011 .60407 .57247 .60046 .56478 .49322 Mtetra
.56478 .49322 .57247 .60046 .58489 .59684 .57686 .48946 Mtetra
.57686 .48946 .58489 .59684 .59736 .59321 .589 .48568 Mtetra
.589 .48568 .59736 .59321 .60988 .58956 .60118 .48189 Mtetra
.60118 .48189 .60988 .58956 .62247 .58589 .61343 .47808 Mtetra
.61343 .47808 .62247 .58589 .63511 .5822 .62572 .47425 Mtetra
.62572 .47425 .63511 .5822 .6478 .5785 .63807 .47041 Mtetra
.63807 .47041 .6478 .5785 .66056 .57478 .65047 .46655 Mtetra
.65047 .46655 .66056 .57478 .67337 .57105 .66293 .46267 Mtetra
.66293 .46267 .67337 .57105 .68624 .5673 .67544 .45877 Mtetra
0 0 .414 r
.67544 .45877 .68624 .5673 .69739 .52902 .69483 .59183 Mtetra
.524 .27 .471 r
.69483 .59183 .69739 .52902 .71024 .52519 .708 .58805 Mtetra
.708 .58805 .71024 .52519 .72315 .52135 .72123 .58426 Mtetra
.72123 .58426 .72315 .52135 .73612 .51749 .73453 .58045 Mtetra
.73453 .58045 .73612 .51749 .74915 .51361 .74788 .57662 Mtetra
.74788 .57662 .74915 .51361 .76224 .50971 .7613 .57277 Mtetra
.7613 .57277 .76224 .50971 .77539 .5058 .77478 .5689 Mtetra
.77478 .5689 .77539 .5058 .7886 .50187 .78833 .56502 Mtetra
.78833 .56502 .7886 .50187 .80186 .49792 .80193 .56111 Mtetra
.80193 .56111 .80186 .49792 .81519 .49395 .81561 .55719 Mtetra
.81561 .55719 .81519 .49395 .82859 .48996 .82935 .55325 Mtetra
.82935 .55325 .82859 .48996 .84204 .48596 .84315 .5493 Mtetra
.84315 .5493 .84204 .48596 .85556 .48193 .85702 .54532 Mtetra
.85702 .54532 .85556 .48193 .86914 .47789 .87095 .54132 Mtetra
.87095 .54132 .86914 .47789 .88278 .47383 .88496 .53731 Mtetra
.88496 .53731 .88278 .47383 .89649 .46975 .89902 .53327 Mtetra
.89902 .53327 .89649 .46975 .91026 .46565 .91316 .52922 Mtetra
.664 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .3708 .47671 .36408 .47009 Mtetra
.36408 .47009 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.37509 .46649 .38178 .47313 .39281 .46954 .38615 .46287 Mtetra
.38615 .46287 .39281 .46954 .40388 .46593 .39725 .45924 Mtetra
.39725 .45924 .40388 .46593 .415 .46231 .4084 .45559 Mtetra
.4084 .45559 .415 .46231 .42616 .45868 .41959 .45193 Mtetra
.41959 .45193 .42616 .45868 .43737 .45503 .43083 .44825 Mtetra
.43083 .44825 .43737 .45503 .44863 .45136 .44211 .44455 Mtetra
.44211 .44455 .44863 .45136 .45993 .44768 .45345 .44084 Mtetra
.45345 .44084 .45993 .44768 .47128 .44398 .46483 .43712 Mtetra
.956 .632 .366 r
.46483 .43712 .47128 .44398 .48166 .5191 .47508 .51235 Mtetra
.658 .749 .917 r
.47508 .51235 .48166 .5191 .49338 .51545 .48683 .50867 Mtetra
.48683 .50867 .49338 .51545 .50515 .51178 .49864 .50498 Mtetra
.49864 .50498 .50515 .51178 .51698 .5081 .51049 .50127 Mtetra
.51049 .50127 .51698 .5081 .52885 .50441 .5224 .49754 Mtetra
.5224 .49754 .52885 .50441 .54078 .50069 .53436 .4938 Mtetra
.53436 .4938 .54078 .50069 .55275 .49697 .54637 .49004 Mtetra
.54637 .49004 .55275 .49697 .56478 .49322 .55843 .48626 Mtetra
.55843 .48626 .56478 .49322 .57686 .48946 .57055 .48247 Mtetra
.57055 .48247 .57686 .48946 .589 .48568 .58272 .47867 Mtetra
.58272 .47867 .589 .48568 .60118 .48189 .59494 .47484 Mtetra
.59494 .47484 .60118 .48189 .61343 .47808 .60722 .471 Mtetra
.60722 .471 .61343 .47808 .62572 .47425 .61955 .46714 Mtetra
.61955 .46714 .62572 .47425 .63807 .47041 .63194 .46326 Mtetra
.63194 .46326 .63807 .47041 .65047 .46655 .64438 .45937 Mtetra
.64438 .45937 .65047 .46655 .66293 .46267 .65687 .45546 Mtetra
.65687 .45546 .66293 .46267 .67544 .45877 .66942 .45153 Mtetra
.965 .638 .322 r
.66942 .45153 .67544 .45877 .69483 .59183 .68863 .58484 Mtetra
.646 .762 .934 r
.68863 .58484 .69483 .59183 .708 .58805 .70184 .58103 Mtetra
.70184 .58103 .708 .58805 .72123 .58426 .71511 .57721 Mtetra
.71511 .57721 .72123 .58426 .73453 .58045 .72845 .57336 Mtetra
.72845 .57336 .73453 .58045 .74788 .57662 .74185 .5695 Mtetra
.74185 .5695 .74788 .57662 .7613 .57277 .75531 .56562 Mtetra
.75531 .56562 .7613 .57277 .77478 .5689 .76884 .56172 Mtetra
.76884 .56172 .77478 .5689 .78833 .56502 .78243 .5578 Mtetra
.78243 .5578 .78833 .56502 .80193 .56111 .79608 .55386 Mtetra
.79608 .55386 .80193 .56111 .81561 .55719 .8098 .54991 Mtetra
.8098 .54991 .81561 .55719 .82935 .55325 .82359 .54593 Mtetra
.82359 .54593 .82935 .55325 .84315 .5493 .83744 .54194 Mtetra
.83744 .54194 .84315 .5493 .85702 .54532 .85135 .53793 Mtetra
.85135 .53793 .85702 .54532 .87095 .54132 .86534 .53389 Mtetra
.86534 .53389 .87095 .54132 .88496 .53731 .87939 .52984 Mtetra
.87939 .52984 .88496 .53731 .89902 .53327 .89351 .52577 Mtetra
.89351 .52577 .89902 .53327 .91316 .52922 .90769 .52168 Mtetra
.664 .741 .908 r
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.34633 .46705 .35312 .47368 .36408 .47009 .35732 .46343 Mtetra
.35732 .46343 .36408 .47009 .37509 .46649 .36835 .4598 Mtetra
.36835 .4598 .37509 .46649 .38615 .46287 .37944 .45615 Mtetra
.37944 .45615 .38615 .46287 .39725 .45924 .39057 .45249 Mtetra
.39057 .45249 .39725 .45924 .4084 .45559 .40174 .44881 Mtetra
.40174 .44881 .4084 .45559 .41959 .45193 .41296 .44512 Mtetra
.41296 .44512 .41959 .45193 .43083 .44825 .42423 .44141 Mtetra
.42423 .44141 .43083 .44825 .44211 .44455 .43555 .43769 Mtetra
.43555 .43769 .44211 .44455 .45345 .44084 .44691 .43395 Mtetra
.44691 .43395 .45345 .44084 .46483 .43712 .45833 .4302 Mtetra
.956 .632 .366 r
.45833 .4302 .46483 .43712 .47508 .51235 .46844 .50554 Mtetra
.658 .749 .917 r
.46844 .50554 .47508 .51235 .48683 .50867 .48023 .50184 Mtetra
.48023 .50184 .48683 .50867 .49864 .50498 .49207 .49811 Mtetra
.49207 .49811 .49864 .50498 .51049 .50127 .50396 .49437 Mtetra
.50396 .49437 .51049 .50127 .5224 .49754 .5159 .49062 Mtetra
.5159 .49062 .5224 .49754 .53436 .4938 .52789 .48685 Mtetra
.52789 .48685 .53436 .4938 .54637 .49004 .53994 .48306 Mtetra
.53994 .48306 .54637 .49004 .55843 .48626 .55203 .47925 Mtetra
.55203 .47925 .55843 .48626 .57055 .48247 .56419 .47543 Mtetra
.56419 .47543 .57055 .48247 .58272 .47867 .57639 .47159 Mtetra
.57639 .47159 .58272 .47867 .59494 .47484 .58865 .46774 Mtetra
.58865 .46774 .59494 .47484 .60722 .471 .60096 .46386 Mtetra
.60096 .46386 .60722 .471 .61955 .46714 .61333 .45997 Mtetra
.61333 .45997 .61955 .46714 .63194 .46326 .62575 .45606 Mtetra
.62575 .45606 .63194 .46326 .64438 .45937 .63823 .45214 Mtetra
.63823 .45214 .64438 .45937 .65687 .45546 .65076 .4482 Mtetra
.65076 .4482 .65687 .45546 .66942 .45153 .66335 .44424 Mtetra
.965 .638 .322 r
.66335 .44424 .66942 .45153 .68863 .58484 .68237 .5778 Mtetra
.646 .762 .934 r
.68237 .5778 .68863 .58484 .70184 .58103 .69563 .57395 Mtetra
.69563 .57395 .70184 .58103 .71511 .57721 .70894 .57009 Mtetra
.70894 .57009 .71511 .57721 .72845 .57336 .72232 .56621 Mtetra
.72232 .56621 .72845 .57336 .74185 .5695 .73577 .56232 Mtetra
.73577 .56232 .74185 .5695 .75531 .56562 .74927 .5584 Mtetra
.74927 .5584 .75531 .56562 .76884 .56172 .76284 .55447 Mtetra
.76284 .55447 .76884 .56172 .78243 .5578 .77648 .55052 Mtetra
.77648 .55052 .78243 .5578 .79608 .55386 .79018 .54654 Mtetra
.79018 .54654 .79608 .55386 .8098 .54991 .80394 .54255 Mtetra
.80394 .54255 .8098 .54991 .82359 .54593 .81778 .53854 Mtetra
.81778 .53854 .82359 .54593 .83744 .54194 .83167 .53452 Mtetra
.83167 .53452 .83744 .54194 .85135 .53793 .84564 .53047 Mtetra
.84564 .53047 .85135 .53793 .86534 .53389 .85967 .5264 Mtetra
.85967 .5264 .86534 .53389 .87939 .52984 .87377 .52231 Mtetra
.87377 .52231 .87939 .52984 .89351 .52577 .88794 .51821 Mtetra
.88794 .51821 .89351 .52577 .90769 .52168 .90218 .51408 Mtetra
.664 .741 .908 r
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.3285 .46399 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45671 Mtetra
.3505 .45671 .35732 .46343 .36835 .4598 .36156 .45306 Mtetra
.36156 .45306 .36835 .4598 .37944 .45615 .37268 .44938 Mtetra
.37268 .44938 .37944 .45615 .39057 .45249 .38383 .44569 Mtetra
.38383 .44569 .39057 .45249 .40174 .44881 .39504 .44199 Mtetra
.39504 .44199 .40174 .44881 .41296 .44512 .40629 .43827 Mtetra
.40629 .43827 .41296 .44512 .42423 .44141 .41759 .43453 Mtetra
.41759 .43453 .42423 .44141 .43555 .43769 .42893 .43078 Mtetra
.42893 .43078 .43555 .43769 .44691 .43395 .44033 .42701 Mtetra
.44033 .42701 .44691 .43395 .45833 .4302 .45177 .42323 Mtetra
.956 .632 .366 r
.45177 .42323 .45833 .4302 .46844 .50554 .46176 .49869 Mtetra
.658 .749 .917 r
.46176 .49869 .46844 .50554 .48023 .50184 .47357 .49495 Mtetra
.47357 .49495 .48023 .50184 .49207 .49811 .48545 .4912 Mtetra
.48545 .4912 .49207 .49811 .50396 .49437 .49737 .48743 Mtetra
.49737 .48743 .50396 .49437 .5159 .49062 .50934 .48364 Mtetra
.50934 .48364 .5159 .49062 .52789 .48685 .52137 .47984 Mtetra
.52137 .47984 .52789 .48685 .53994 .48306 .53345 .47602 Mtetra
.53345 .47602 .53994 .48306 .55203 .47925 .54558 .47218 Mtetra
.54558 .47218 .55203 .47925 .56419 .47543 .55777 .46833 Mtetra
.55777 .46833 .56419 .47543 .57639 .47159 .57001 .46446 Mtetra
.57001 .46446 .57639 .47159 .58865 .46774 .5823 .46057 Mtetra
.5823 .46057 .58865 .46774 .60096 .46386 .59465 .45667 Mtetra
.59465 .45667 .60096 .46386 .61333 .45997 .60706 .45274 Mtetra
.60706 .45274 .61333 .45997 .62575 .45606 .61952 .4488 Mtetra
.61952 .4488 .62575 .45606 .63823 .45214 .63203 .44485 Mtetra
.63203 .44485 .63823 .45214 .65076 .4482 .64461 .44087 Mtetra
.64461 .44087 .65076 .4482 .66335 .44424 .65723 .43688 Mtetra
.965 .638 .322 r
.65723 .43688 .66335 .44424 .68237 .5778 .67606 .57069 Mtetra
.646 .762 .934 r
.67606 .57069 .68237 .5778 .69563 .57395 .68936 .56681 Mtetra
.68936 .56681 .69563 .57395 .70894 .57009 .70272 .56292 Mtetra
.70272 .56292 .70894 .57009 .72232 .56621 .71614 .55901 Mtetra
.71614 .55901 .72232 .56621 .73577 .56232 .72963 .55507 Mtetra
.72963 .55507 .73577 .56232 .74927 .5584 .74318 .55113 Mtetra
.74318 .55113 .74927 .5584 .76284 .55447 .7568 .54716 Mtetra
.7568 .54716 .76284 .55447 .77648 .55052 .77048 .54317 Mtetra
.77048 .54317 .77648 .55052 .79018 .54654 .78422 .53916 Mtetra
.78422 .53916 .79018 .54654 .80394 .54255 .79804 .53514 Mtetra
.79804 .53514 .80394 .54255 .81778 .53854 .81191 .53109 Mtetra
.81191 .53109 .81778 .53854 .83167 .53452 .82586 .52703 Mtetra
.82586 .52703 .83167 .53452 .84564 .53047 .83987 .52294 Mtetra
.83987 .52294 .84564 .53047 .85967 .5264 .85395 .51884 Mtetra
.85395 .51884 .85967 .5264 .87377 .52231 .8681 .51472 Mtetra
.8681 .51472 .87377 .52231 .88794 .51821 .88232 .51057 Mtetra
.88232 .51057 .88794 .51821 .90218 .51408 .89661 .50641 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.33258 .45362 .33948 .46036 .3505 .45671 .34363 .44995 Mtetra
.34363 .44995 .3505 .45671 .36156 .45306 .35472 .44626 Mtetra
.35472 .44626 .36156 .45306 .37268 .44938 .36586 .44256 Mtetra
.36586 .44256 .37268 .44938 .38383 .44569 .37705 .43884 Mtetra
.37705 .43884 .38383 .44569 .39504 .44199 .38828 .4351 Mtetra
.38828 .4351 .39504 .44199 .40629 .43827 .39956 .43136 Mtetra
.39956 .43136 .40629 .43827 .41759 .43453 .41089 .42759 Mtetra
.41089 .42759 .41759 .43453 .42893 .43078 .42227 .42381 Mtetra
.42227 .42381 .42893 .43078 .44033 .42701 .43369 .42001 Mtetra
.43369 .42001 .44033 .42701 .45177 .42323 .44517 .4162 Mtetra
.956 .632 .366 r
.44517 .4162 .45177 .42323 .46176 .49869 .45501 .49178 Mtetra
.658 .749 .917 r
.45501 .49178 .46176 .49869 .47357 .49495 .46687 .48801 Mtetra
.46687 .48801 .47357 .49495 .48545 .4912 .47877 .48423 Mtetra
.47877 .48423 .48545 .4912 .49737 .48743 .49073 .48043 Mtetra
.49073 .48043 .49737 .48743 .50934 .48364 .50273 .47661 Mtetra
.50273 .47661 .50934 .48364 .52137 .47984 .5148 .47277 Mtetra
.5148 .47277 .52137 .47984 .53345 .47602 .52691 .46892 Mtetra
.52691 .46892 .53345 .47602 .54558 .47218 .53908 .46506 Mtetra
.53908 .46506 .54558 .47218 .55777 .46833 .5513 .46117 Mtetra
.5513 .46117 .55777 .46833 .57001 .46446 .56358 .45727 Mtetra
.56358 .45727 .57001 .46446 .5823 .46057 .57591 .45335 Mtetra
.57591 .45335 .5823 .46057 .59465 .45667 .58829 .44941 Mtetra
.58829 .44941 .59465 .45667 .60706 .45274 .60074 .44546 Mtetra
.60074 .44546 .60706 .45274 .61952 .4488 .61323 .44149 Mtetra
.61323 .44149 .61952 .4488 .63203 .44485 .62579 .43749 Mtetra
.62579 .43749 .63203 .44485 .64461 .44087 .6384 .43349 Mtetra
.6384 .43349 .64461 .44087 .65723 .43688 .65106 .42946 Mtetra
.965 .638 .322 r
.65106 .42946 .65723 .43688 .67606 .57069 .66969 .56352 Mtetra
.646 .762 .934 r
.66969 .56352 .67606 .57069 .68936 .56681 .68303 .55961 Mtetra
.68303 .55961 .68936 .56681 .70272 .56292 .69644 .55568 Mtetra
.69644 .55568 .70272 .56292 .71614 .55901 .70991 .55173 Mtetra
.70991 .55173 .71614 .55901 .72963 .55507 .72344 .54777 Mtetra
.72344 .54777 .72963 .55507 .74318 .55113 .73703 .54378 Mtetra
.73703 .54378 .74318 .55113 .7568 .54716 .75069 .53978 Mtetra
.75069 .53978 .7568 .54716 .77048 .54317 .76442 .53576 Mtetra
.76442 .53576 .77048 .54317 .78422 .53916 .77821 .53172 Mtetra
.77821 .53172 .78422 .53916 .79804 .53514 .79207 .52765 Mtetra
.79207 .52765 .79804 .53514 .81191 .53109 .806 .52357 Mtetra
.806 .52357 .81191 .53109 .82586 .52703 .81999 .51947 Mtetra
.81999 .51947 .82586 .52703 .83987 .52294 .83405 .51535 Mtetra
.83405 .51535 .83987 .52294 .85395 .51884 .84818 .51121 Mtetra
.84818 .51121 .85395 .51884 .8681 .51472 .86238 .50705 Mtetra
.86238 .50705 .8681 .51472 .88232 .51057 .87665 .50287 Mtetra
.87665 .50287 .88232 .51057 .89661 .50641 .89099 .49867 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
.3146 .45051 .32158 .45728 .33258 .45362 .32563 .44683 Mtetra
.32563 .44683 .33258 .45362 .34363 .44995 .3367 .44313 Mtetra
.3367 .44313 .34363 .44995 .35472 .44626 .34783 .43941 Mtetra
.34783 .43941 .35472 .44626 .36586 .44256 .35899 .43568 Mtetra
.35899 .43568 .36586 .44256 .37705 .43884 .37021 .43193 Mtetra
.37021 .43193 .37705 .43884 .38828 .4351 .38147 .42817 Mtetra
.38147 .42817 .38828 .4351 .39956 .43136 .39278 .42439 Mtetra
.39278 .42439 .39956 .43136 .41089 .42759 .40414 .4206 Mtetra
.40414 .4206 .41089 .42759 .42227 .42381 .41555 .41679 Mtetra
.41555 .41679 .42227 .42381 .43369 .42001 .427 .41296 Mtetra
.427 .41296 .43369 .42001 .44517 .4162 .43851 .40912 Mtetra
.956 .632 .366 r
.43851 .40912 .44517 .4162 .45501 .49178 .44822 .48481 Mtetra
.658 .749 .917 r
.44822 .48481 .45501 .49178 .46687 .48801 .4601 .48101 Mtetra
.4601 .48101 .46687 .48801 .47877 .48423 .47204 .4772 Mtetra
.47204 .4772 .47877 .48423 .49073 .48043 .48403 .47337 Mtetra
.48403 .47337 .49073 .48043 .50273 .47661 .49607 .46952 Mtetra
.49607 .46952 .50273 .47661 .5148 .47277 .50817 .46565 Mtetra
.50817 .46565 .5148 .47277 .52691 .46892 .52032 .46177 Mtetra
.52032 .46177 .52691 .46892 .53908 .46506 .53252 .45787 Mtetra
.53252 .45787 .53908 .46506 .5513 .46117 .54478 .45395 Mtetra
.54478 .45395 .5513 .46117 .56358 .45727 .55709 .45002 Mtetra
.55709 .45002 .56358 .45727 .57591 .45335 .56946 .44607 Mtetra
.56946 .44607 .57591 .45335 .58829 .44941 .58188 .4421 Mtetra
.58188 .4421 .58829 .44941 .60074 .44546 .59436 .43811 Mtetra
.59436 .43811 .60074 .44546 .61323 .44149 .60689 .4341 Mtetra
.60689 .4341 .61323 .44149 .62579 .43749 .61949 .43008 Mtetra
.61949 .43008 .62579 .43749 .6384 .43349 .63213 .42604 Mtetra
.63213 .42604 .6384 .43349 .65106 .42946 .64484 .42198 Mtetra
.965 .638 .322 r
.64484 .42198 .65106 .42946 .66969 .56352 .66327 .55629 Mtetra
.646 .762 .934 r
.66327 .55629 .66969 .56352 .68303 .55961 .67666 .55234 Mtetra
.67666 .55234 .68303 .55961 .69644 .55568 .6901 .54838 Mtetra
.6901 .54838 .69644 .55568 .70991 .55173 .70361 .5444 Mtetra
.70361 .5444 .70991 .55173 .72344 .54777 .71719 .5404 Mtetra
.71719 .5404 .72344 .54777 .73703 .54378 .73083 .53638 Mtetra
.73083 .53638 .73703 .54378 .75069 .53978 .74454 .53234 Mtetra
.74454 .53234 .75069 .53978 .76442 .53576 .75831 .52828 Mtetra
.75831 .52828 .76442 .53576 .77821 .53172 .77215 .5242 Mtetra
.77215 .5242 .77821 .53172 .79207 .52765 .78606 .5201 Mtetra
.78606 .5201 .79207 .52765 .806 .52357 .80003 .51599 Mtetra
.80003 .51599 .806 .52357 .81999 .51947 .81407 .51185 Mtetra
.81407 .51185 .81999 .51947 .83405 .51535 .82818 .50769 Mtetra
.82818 .50769 .83405 .51535 .84818 .51121 .84236 .50351 Mtetra
.84236 .50351 .84818 .51121 .86238 .50705 .85661 .49931 Mtetra
.85661 .49931 .86238 .50705 .87665 .50287 .87093 .49509 Mtetra
.87093 .49509 .87665 .50287 .89099 .49867 .88532 .49085 Mtetra
.664 .741 .908 r
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.28559 .45108 .29268 .45784 .30361 .45418 .29655 .4474 Mtetra
.29655 .4474 .30361 .45418 .3146 .45051 .30756 .4437 Mtetra
.30756 .4437 .3146 .45051 .32563 .44683 .31862 .43998 Mtetra
.31862 .43998 .32563 .44683 .3367 .44313 .32973 .43626 Mtetra
.32973 .43626 .3367 .44313 .34783 .43941 .34088 .43251 Mtetra
.34088 .43251 .34783 .43941 .35899 .43568 .35207 .42875 Mtetra
.35207 .42875 .35899 .43568 .37021 .43193 .36332 .42497 Mtetra
.36332 .42497 .37021 .43193 .38147 .42817 .37461 .42118 Mtetra
.37461 .42118 .38147 .42817 .39278 .42439 .38595 .41737 Mtetra
.38595 .41737 .39278 .42439 .40414 .4206 .39734 .41355 Mtetra
.39734 .41355 .40414 .4206 .41555 .41679 .40878 .40971 Mtetra
.40878 .40971 .41555 .41679 .427 .41296 .42026 .40585 Mtetra
.42026 .40585 .427 .41296 .43851 .40912 .4318 .40198 Mtetra
.956 .632 .366 r
.4318 .40198 .43851 .40912 .44822 .48481 .44137 .47778 Mtetra
.658 .749 .917 r
.44137 .47778 .44822 .48481 .4601 .48101 .45328 .47396 Mtetra
.45328 .47396 .4601 .48101 .47204 .4772 .46525 .47011 Mtetra
.46525 .47011 .47204 .4772 .48403 .47337 .47728 .46625 Mtetra
.47728 .46625 .48403 .47337 .49607 .46952 .48935 .46237 Mtetra
.48935 .46237 .49607 .46952 .50817 .46565 .50149 .45847 Mtetra
.50149 .45847 .50817 .46565 .52032 .46177 .51367 .45456 Mtetra
.51367 .45456 .52032 .46177 .53252 .45787 .52591 .45063 Mtetra
.52591 .45063 .53252 .45787 .54478 .45395 .5382 .44668 Mtetra
.5382 .44668 .54478 .45395 .55709 .45002 .55055 .44271 Mtetra
.55055 .44271 .55709 .45002 .56946 .44607 .56296 .43872 Mtetra
.56296 .43872 .56946 .44607 .58188 .4421 .57542 .43472 Mtetra
.57542 .43472 .58188 .4421 .59436 .43811 .58793 .4307 Mtetra
.58793 .4307 .59436 .43811 .60689 .4341 .6005 .42666 Mtetra
.6005 .42666 .60689 .4341 .61949 .43008 .61313 .42261 Mtetra
.61313 .42261 .61949 .43008 .63213 .42604 .62582 .41853 Mtetra
.62582 .41853 .63213 .42604 .64484 .42198 .63857 .41444 Mtetra
.965 .638 .322 r
.63857 .41444 .64484 .42198 .66327 .55629 .65679 .54899 Mtetra
.646 .762 .934 r
.65679 .54899 .66327 .55629 .67666 .55234 .67022 .54501 Mtetra
.67022 .54501 .67666 .55234 .6901 .54838 .68371 .54101 Mtetra
.68371 .54101 .6901 .54838 .70361 .5444 .69727 .537 Mtetra
.69727 .537 .70361 .5444 .71719 .5404 .71089 .53296 Mtetra
.71089 .53296 .71719 .5404 .73083 .53638 .72458 .52891 Mtetra
.72458 .52891 .73083 .53638 .74454 .53234 .73833 .52483 Mtetra
.73833 .52483 .74454 .53234 .75831 .52828 .75215 .52074 Mtetra
.75215 .52074 .75831 .52828 .77215 .5242 .76604 .51662 Mtetra
.76604 .51662 .77215 .5242 .78606 .5201 .77999 .51249 Mtetra
.77999 .51249 .78606 .5201 .80003 .51599 .79401 .50833 Mtetra
.79401 .50833 .80003 .51599 .81407 .51185 .8081 .50416 Mtetra
.8081 .50416 .81407 .51185 .82818 .50769 .82226 .49996 Mtetra
.82226 .49996 .82818 .50769 .84236 .50351 .83649 .49575 Mtetra
.83649 .49575 .84236 .50351 .85661 .49931 .85079 .49151 Mtetra
.85079 .49151 .85661 .49931 .87093 .49509 .86516 .48725 Mtetra
.86516 .48725 .87093 .49509 .88532 .49085 .8796 .48297 Mtetra
.664 .741 .908 r
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .4437 .30048 .43683 Mtetra
.30048 .43683 .30756 .4437 .31862 .43998 .31156 .43309 Mtetra
.31156 .43309 .31862 .43998 .32973 .43626 .32269 .42933 Mtetra
.32269 .42933 .32973 .43626 .34088 .43251 .33387 .42556 Mtetra
.33387 .42556 .34088 .43251 .35207 .42875 .3451 .42177 Mtetra
.3451 .42177 .35207 .42875 .36332 .42497 .35637 .41796 Mtetra
.35637 .41796 .36332 .42497 .37461 .42118 .3677 .41414 Mtetra
.3677 .41414 .37461 .42118 .38595 .41737 .37907 .4103 Mtetra
.37907 .4103 .38595 .41737 .39734 .41355 .39048 .40644 Mtetra
.39048 .40644 .39734 .41355 .40878 .40971 .40195 .40257 Mtetra
.40195 .40257 .40878 .40971 .42026 .40585 .41347 .39869 Mtetra
.41347 .39869 .42026 .40585 .4318 .40198 .42503 .39478 Mtetra
.956 .632 .366 r
.42503 .39478 .4318 .40198 .44137 .47778 .43446 .4707 Mtetra
.658 .749 .917 r
.43446 .4707 .44137 .47778 .45328 .47396 .44641 .46684 Mtetra
.44641 .46684 .45328 .47396 .46525 .47011 .45841 .46297 Mtetra
.45841 .46297 .46525 .47011 .47728 .46625 .47047 .45907 Mtetra
.47047 .45907 .47728 .46625 .48935 .46237 .48258 .45516 Mtetra
.48258 .45516 .48935 .46237 .50149 .45847 .49475 .45123 Mtetra
.49475 .45123 .50149 .45847 .51367 .45456 .50697 .44728 Mtetra
.50697 .44728 .51367 .45456 .52591 .45063 .51924 .44332 Mtetra
.51924 .44332 .52591 .45063 .5382 .44668 .53157 .43934 Mtetra
.53157 .43934 .5382 .44668 .55055 .44271 .54396 .43534 Mtetra
.54396 .43534 .55055 .44271 .56296 .43872 .5564 .43132 Mtetra
.5564 .43132 .56296 .43872 .57542 .43472 .5689 .42728 Mtetra
.5689 .42728 .57542 .43472 .58793 .4307 .58145 .42323 Mtetra
.58145 .42323 .58793 .4307 .6005 .42666 .59406 .41916 Mtetra
.59406 .41916 .6005 .42666 .61313 .42261 .60673 .41507 Mtetra
.60673 .41507 .61313 .42261 .62582 .41853 .61945 .41096 Mtetra
.61945 .41096 .62582 .41853 .63857 .41444 .63224 .40683 Mtetra
.965 .638 .322 r
.63224 .40683 .63857 .41444 .65679 .54899 .65026 .54163 Mtetra
.646 .762 .934 r
.65026 .54163 .65679 .54899 .67022 .54501 .66373 .53762 Mtetra
.66373 .53762 .67022 .54501 .68371 .54101 .67726 .53358 Mtetra
.67726 .53358 .68371 .54101 .69727 .537 .69087 .52953 Mtetra
.69087 .52953 .69727 .537 .71089 .53296 .70453 .52546 Mtetra
.70453 .52546 .71089 .53296 .72458 .52891 .71826 .52137 Mtetra
.71826 .52137 .72458 .52891 .73833 .52483 .73206 .51726 Mtetra
.73206 .51726 .73833 .52483 .75215 .52074 .74593 .51312 Mtetra
.74593 .51312 .75215 .52074 .76604 .51662 .75986 .50897 Mtetra
.75986 .50897 .76604 .51662 .77999 .51249 .77387 .5048 Mtetra
.77387 .5048 .77999 .51249 .79401 .50833 .78794 .50061 Mtetra
.78794 .50061 .79401 .50833 .8081 .50416 .80208 .4964 Mtetra
.80208 .4964 .8081 .50416 .82226 .49996 .81628 .49216 Mtetra
.81628 .49216 .82226 .49996 .83649 .49575 .83056 .48791 Mtetra
.83056 .48791 .83649 .49575 .85079 .49151 .84491 .48363 Mtetra
.84491 .48363 .85079 .49151 .86516 .48725 .85933 .47933 Mtetra
.85933 .47933 .86516 .48725 .8796 .48297 .87383 .47502 Mtetra
.664 .741 .908 r
.23846 .44853 .24574 .45531 .25659 .45164 .24934 .44484 Mtetra
.24934 .44484 .25659 .45164 .2675 .44796 .26027 .44113 Mtetra
.26027 .44113 .2675 .44796 .27844 .44427 .27124 .4374 Mtetra
.27124 .4374 .27844 .44427 .28944 .44056 .28226 .43366 Mtetra
.28226 .43366 .28944 .44056 .30048 .43683 .29333 .42991 Mtetra
.29333 .42991 .30048 .43683 .31156 .43309 .30445 .42614 Mtetra
.30445 .42614 .31156 .43309 .32269 .42933 .31561 .42235 Mtetra
.31561 .42235 .32269 .42933 .33387 .42556 .32681 .41855 Mtetra
.32681 .41855 .33387 .42556 .3451 .42177 .33807 .41473 Mtetra
.33807 .41473 .3451 .42177 .35637 .41796 .34937 .41089 Mtetra
.34937 .41089 .35637 .41796 .3677 .41414 .36072 .40704 Mtetra
.36072 .40704 .3677 .41414 .37907 .4103 .37213 .40317 Mtetra
.37213 .40317 .37907 .4103 .39048 .40644 .38357 .39928 Mtetra
.38357 .39928 .39048 .40644 .40195 .40257 .39507 .39538 Mtetra
.39507 .39538 .40195 .40257 .41347 .39869 .40662 .39146 Mtetra
.40662 .39146 .41347 .39869 .42503 .39478 .41822 .38753 Mtetra
.956 .632 .366 r
.41822 .38753 .42503 .39478 .43446 .4707 .42749 .46356 Mtetra
.658 .749 .917 r
.42749 .46356 .43446 .4707 .44641 .46684 .43948 .45967 Mtetra
.43948 .45967 .44641 .46684 .45841 .46297 .45152 .45576 Mtetra
.45152 .45576 .45841 .46297 .47047 .45907 .46361 .45184 Mtetra
.46361 .45184 .47047 .45907 .48258 .45516 .47576 .44789 Mtetra
.47576 .44789 .48258 .45516 .49475 .45123 .48796 .44393 Mtetra
.48796 .44393 .49475 .45123 .50697 .44728 .50021 .43995 Mtetra
.50021 .43995 .50697 .44728 .51924 .44332 .51252 .43596 Mtetra
.51252 .43596 .51924 .44332 .53157 .43934 .52489 .43194 Mtetra
.52489 .43194 .53157 .43934 .54396 .43534 .53731 .42791 Mtetra
.53731 .42791 .54396 .43534 .5564 .43132 .54979 .42386 Mtetra
.54979 .42386 .5564 .43132 .5689 .42728 .56232 .41979 Mtetra
.56232 .41979 .5689 .42728 .58145 .42323 .57491 .4157 Mtetra
.57491 .4157 .58145 .42323 .59406 .41916 .58756 .41159 Mtetra
.58756 .41159 .59406 .41916 .60673 .41507 .60027 .40746 Mtetra
.60027 .40746 .60673 .41507 .61945 .41096 .61303 .40332 Mtetra
.61303 .40332 .61945 .41096 .63224 .40683 .62586 .39916 Mtetra
.965 .638 .322 r
.62586 .39916 .63224 .40683 .65026 .54163 .64366 .53421 Mtetra
.646 .762 .934 r
.64366 .53421 .65026 .54163 .66373 .53762 .65718 .53016 Mtetra
.65718 .53016 .66373 .53762 .67726 .53358 .67076 .52609 Mtetra
.67076 .52609 .67726 .53358 .69087 .52953 .68441 .522 Mtetra
.68441 .522 .69087 .52953 .70453 .52546 .69812 .51789 Mtetra
.69812 .51789 .70453 .52546 .71826 .52137 .7119 .51376 Mtetra
.7119 .51376 .71826 .52137 .73206 .51726 .72574 .50961 Mtetra
.72574 .50961 .73206 .51726 .74593 .51312 .73966 .50544 Mtetra
.73966 .50544 .74593 .51312 .75986 .50897 .75364 .50125 Mtetra
.75364 .50125 .75986 .50897 .77387 .5048 .76769 .49704 Mtetra
.76769 .49704 .77387 .5048 .78794 .50061 .78181 .49281 Mtetra
.78181 .49281 .78794 .50061 .80208 .4964 .79599 .48856 Mtetra
.79599 .48856 .80208 .4964 .81628 .49216 .81025 .48429 Mtetra
.81025 .48429 .81628 .49216 .83056 .48791 .82458 .48 Mtetra
.82458 .48 .83056 .48791 .84491 .48363 .83898 .47568 Mtetra
.83898 .47568 .84491 .48363 .85933 .47933 .85345 .47135 Mtetra
.85345 .47135 .85933 .47933 .87383 .47502 .868 .46699 Mtetra
.664 .741 .908 r
.23112 .4417 .23846 .44853 .24934 .44484 .24203 .43798 Mtetra
.24203 .43798 .24934 .44484 .26027 .44113 .25299 .43424 Mtetra
.25299 .43424 .26027 .44113 .27124 .4374 .26399 .43049 Mtetra
.26399 .43049 .27124 .4374 .28226 .43366 .27504 .42672 Mtetra
.27504 .42672 .28226 .43366 .29333 .42991 .28613 .42293 Mtetra
.28613 .42293 .29333 .42991 .30445 .42614 .29727 .41913 Mtetra
.29727 .41913 .30445 .42614 .31561 .42235 .30846 .41532 Mtetra
.30846 .41532 .31561 .42235 .32681 .41855 .3197 .41148 Mtetra
.3197 .41148 .32681 .41855 .33807 .41473 .33099 .40763 Mtetra
.33099 .40763 .33807 .41473 .34937 .41089 .34232 .40377 Mtetra
.34232 .40377 .34937 .41089 .36072 .40704 .3537 .39988 Mtetra
.3537 .39988 .36072 .40704 .37213 .40317 .36513 .39598 Mtetra
.36513 .39598 .37213 .40317 .38357 .39928 .37661 .39207 Mtetra
.37661 .39207 .38357 .39928 .39507 .39538 .38814 .38814 Mtetra
.38814 .38814 .39507 .39538 .40662 .39146 .39972 .38419 Mtetra
.39972 .38419 .40662 .39146 .41822 .38753 .41135 .38022 Mtetra
.956 .632 .366 r
.41135 .38022 .41822 .38753 .42749 .46356 .42047 .45637 Mtetra
.658 .749 .917 r
.42047 .45637 .42749 .46356 .43948 .45967 .43249 .45244 Mtetra
.43249 .45244 .43948 .45967 .45152 .45576 .44456 .4485 Mtetra
.44456 .4485 .45152 .45576 .46361 .45184 .45669 .44454 Mtetra
.45669 .44454 .46361 .45184 .47576 .44789 .46887 .44057 Mtetra
.46887 .44057 .47576 .44789 .48796 .44393 .48111 .43657 Mtetra
.48111 .43657 .48796 .44393 .50021 .43995 .4934 .43256 Mtetra
.4934 .43256 .50021 .43995 .51252 .43596 .50574 .42853 Mtetra
.50574 .42853 .51252 .43596 .52489 .43194 .51815 .42448 Mtetra
.51815 .42448 .52489 .43194 .53731 .42791 .5306 .42041 Mtetra
.5306 .42041 .53731 .42791 .54979 .42386 .54312 .41633 Mtetra
.54312 .41633 .54979 .42386 .56232 .41979 .55569 .41222 Mtetra
.55569 .41222 .56232 .41979 .57491 .4157 .56832 .4081 Mtetra
.56832 .4081 .57491 .4157 .58756 .41159 .58101 .40396 Mtetra
.58101 .40396 .58756 .41159 .60027 .40746 .59375 .3998 Mtetra
.59375 .3998 .60027 .40746 .61303 .40332 .60656 .39562 Mtetra
.60656 .39562 .61303 .40332 .62586 .39916 .61942 .39142 Mtetra
.965 .638 .322 r
.61942 .39142 .62586 .39916 .64366 .53421 .63701 .52671 Mtetra
.646 .762 .934 r
.63701 .52671 .64366 .53421 .65718 .53016 .65057 .52263 Mtetra
.65057 .52263 .65718 .53016 .67076 .52609 .6642 .51852 Mtetra
.6642 .51852 .67076 .52609 .68441 .522 .67789 .5144 Mtetra
.67789 .5144 .68441 .522 .69812 .51789 .69165 .51025 Mtetra
.69165 .51025 .69812 .51789 .7119 .51376 .70547 .50609 Mtetra
.70547 .50609 .7119 .51376 .72574 .50961 .71936 .5019 Mtetra
.71936 .5019 .72574 .50961 .73966 .50544 .73332 .49769 Mtetra
.73332 .49769 .73966 .50544 .75364 .50125 .74735 .49347 Mtetra
.74735 .49347 .75364 .50125 .76769 .49704 .76145 .48922 Mtetra
.76145 .48922 .76769 .49704 .78181 .49281 .77562 .48495 Mtetra
.77562 .48495 .78181 .49281 .79599 .48856 .78986 .48066 Mtetra
.78986 .48066 .79599 .48856 .81025 .48429 .80417 .47635 Mtetra
.80417 .47635 .81025 .48429 .82458 .48 .81855 .47201 Mtetra
.81855 .47201 .82458 .48 .83898 .47568 .833 .46766 Mtetra
.833 .46766 .83898 .47568 .85345 .47135 .84752 .46328 Mtetra
.84752 .46328 .85345 .47135 .868 .46699 .86212 .45888 Mtetra
.664 .741 .908 r
.22373 .43482 .23112 .4417 .24203 .43798 .23467 .43107 Mtetra
.23467 .43107 .24203 .43798 .25299 .43424 .24565 .4273 Mtetra
.24565 .4273 .25299 .43424 .26399 .43049 .25668 .42352 Mtetra
.25668 .42352 .26399 .43049 .27504 .42672 .26775 .41972 Mtetra
.26775 .41972 .27504 .42672 .28613 .42293 .27888 .4159 Mtetra
.27888 .4159 .28613 .42293 .29727 .41913 .29005 .41207 Mtetra
.29005 .41207 .29727 .41913 .30846 .41532 .30127 .40823 Mtetra
.30127 .40823 .30846 .41532 .3197 .41148 .31253 .40436 Mtetra
.31253 .40436 .3197 .41148 .33099 .40763 .32384 .40048 Mtetra
.32384 .40048 .33099 .40763 .34232 .40377 .33521 .39659 Mtetra
.33521 .39659 .34232 .40377 .3537 .39988 .34662 .39267 Mtetra
.34662 .39267 .3537 .39988 .36513 .39598 .35808 .38874 Mtetra
.35808 .38874 .36513 .39598 .37661 .39207 .36959 .38479 Mtetra
.36959 .38479 .37661 .39207 .38814 .38814 .38115 .38083 Mtetra
.38115 .38083 .38814 .38814 .39972 .38419 .39276 .37685 Mtetra
.39276 .37685 .39972 .38419 .41135 .38022 .40442 .37285 Mtetra
.956 .632 .366 r
.40442 .37285 .41135 .38022 .42047 .45637 .41339 .44911 Mtetra
.658 .749 .917 r
.41339 .44911 .42047 .45637 .43249 .45244 .42545 .44515 Mtetra
.42545 .44515 .43249 .45244 .44456 .4485 .43755 .44118 Mtetra
.43755 .44118 .44456 .4485 .45669 .44454 .44971 .43719 Mtetra
.44971 .43719 .45669 .44454 .46887 .44057 .46193 .43318 Mtetra
.46193 .43318 .46887 .44057 .48111 .43657 .4742 .42915 Mtetra
.4742 .42915 .48111 .43657 .4934 .43256 .48653 .4251 Mtetra
.48653 .4251 .4934 .43256 .50574 .42853 .49891 .42104 Mtetra
.49891 .42104 .50574 .42853 .51815 .42448 .51135 .41696 Mtetra
.51135 .41696 .51815 .42448 .5306 .42041 .52384 .41286 Mtetra
.52384 .41286 .5306 .42041 .54312 .41633 .5364 .40874 Mtetra
.5364 .40874 .54312 .41633 .55569 .41222 .549 .4046 Mtetra
.549 .4046 .55569 .41222 .56832 .4081 .56167 .40044 Mtetra
.56167 .40044 .56832 .4081 .58101 .40396 .5744 .39626 Mtetra
.5744 .39626 .58101 .40396 .59375 .3998 .58718 .39207 Mtetra
.58718 .39207 .59375 .3998 .60656 .39562 .60003 .38785 Mtetra
.60003 .38785 .60656 .39562 .61942 .39142 .61293 .38362 Mtetra
.965 .638 .322 r
.61293 .38362 .61942 .39142 .63701 .52671 .6303 .51916 Mtetra
.646 .762 .934 r
.6303 .51916 .63701 .52671 .65057 .52263 .64391 .51503 Mtetra
.64391 .51503 .65057 .52263 .6642 .51852 .65758 .51089 Mtetra
.65758 .51089 .6642 .51852 .67789 .5144 .67131 .50673 Mtetra
.67131 .50673 .67789 .5144 .69165 .51025 .68512 .50255 Mtetra
.68512 .50255 .69165 .51025 .70547 .50609 .69899 .49834 Mtetra
.69899 .49834 .70547 .50609 .71936 .5019 .71293 .49412 Mtetra
.71293 .49412 .71936 .5019 .73332 .49769 .72693 .48987 Mtetra
.72693 .48987 .73332 .49769 .74735 .49347 .74101 .48561 Mtetra
.74101 .48561 .74735 .49347 .76145 .48922 .75516 .48132 Mtetra
.75516 .48132 .76145 .48922 .77562 .48495 .76938 .47701 Mtetra
.76938 .47701 .77562 .48495 .78986 .48066 .78366 .47268 Mtetra
.78366 .47268 .78986 .48066 .80417 .47635 .79802 .46833 Mtetra
.79802 .46833 .80417 .47635 .81855 .47201 .81245 .46396 Mtetra
.81245 .46396 .81855 .47201 .833 .46766 .82696 .45956 Mtetra
.82696 .45956 .833 .46766 .84752 .46328 .84153 .45515 Mtetra
.84153 .45515 .84752 .46328 .86212 .45888 .85618 .45071 Mtetra
.664 .741 .908 r
.21628 .42788 .22373 .43482 .23467 .43107 .22724 .4241 Mtetra
.22724 .4241 .23467 .43107 .24565 .4273 .23825 .4203 Mtetra
.23825 .4203 .24565 .4273 .25668 .42352 .24931 .41649 Mtetra
.24931 .41649 .25668 .42352 .26775 .41972 .26041 .41266 Mtetra
.26041 .41266 .26775 .41972 .27888 .4159 .27156 .40882 Mtetra
.27156 .40882 .27888 .4159 .29005 .41207 .28276 .40496 Mtetra
.28276 .40496 .29005 .41207 .30127 .40823 .29401 .40108 Mtetra
.29401 .40108 .30127 .40823 .31253 .40436 .3053 .39719 Mtetra
.3053 .39719 .31253 .40436 .32384 .40048 .31665 .39327 Mtetra
.31665 .39327 .32384 .40048 .33521 .39659 .32804 .38935 Mtetra
.32804 .38935 .33521 .39659 .34662 .39267 .33948 .3854 Mtetra
.33948 .3854 .34662 .39267 .35808 .38874 .35097 .38144 Mtetra
.35097 .38144 .35808 .38874 .36959 .38479 .36251 .37746 Mtetra
.36251 .37746 .36959 .38479 .38115 .38083 .3741 .37347 Mtetra
.3741 .37347 .38115 .38083 .39276 .37685 .38574 .36945 Mtetra
.38574 .36945 .39276 .37685 .40442 .37285 .39744 .36542 Mtetra
.956 .632 .366 r
.39744 .36542 .40442 .37285 .41339 .44911 .40626 .44179 Mtetra
.658 .749 .917 r
.40626 .44179 .41339 .44911 .42545 .44515 .41834 .4378 Mtetra
.41834 .4378 .42545 .44515 .43755 .44118 .43048 .4338 Mtetra
.43048 .4338 .43755 .44118 .44971 .43719 .44268 .42977 Mtetra
.44268 .42977 .44971 .43719 .46193 .43318 .45493 .42573 Mtetra
.45493 .42573 .46193 .43318 .4742 .42915 .46724 .42167 Mtetra
.46724 .42167 .4742 .42915 .48653 .4251 .4796 .41759 Mtetra
.4796 .41759 .48653 .4251 .49891 .42104 .49202 .41349 Mtetra
.49202 .41349 .49891 .42104 .51135 .41696 .50449 .40937 Mtetra
.50449 .40937 .51135 .41696 .52384 .41286 .51703 .40523 Mtetra
.51703 .40523 .52384 .41286 .5364 .40874 .52961 .40108 Mtetra
.52961 .40108 .5364 .40874 .549 .4046 .54226 .39691 Mtetra
.54226 .39691 .549 .4046 .56167 .40044 .55497 .39271 Mtetra
.55497 .39271 .56167 .40044 .5744 .39626 .56773 .3885 Mtetra
.56773 .3885 .5744 .39626 .58718 .39207 .58056 .38427 Mtetra
.58056 .38427 .58718 .39207 .60003 .38785 .59344 .38002 Mtetra
.59344 .38002 .60003 .38785 .61293 .38362 .60638 .37574 Mtetra
.965 .638 .322 r
.60638 .37574 .61293 .38362 .6303 .51916 .62353 .51153 Mtetra
.646 .762 .934 r
.62353 .51153 .6303 .51916 .64391 .51503 .63718 .50737 Mtetra
.63718 .50737 .64391 .51503 .65758 .51089 .65089 .50319 Mtetra
.65089 .50319 .65758 .51089 .67131 .50673 .66468 .49899 Mtetra
.66468 .49899 .67131 .50673 .68512 .50255 .67853 .49477 Mtetra
.67853 .49477 .68512 .50255 .69899 .49834 .69244 .49053 Mtetra
.69244 .49053 .69899 .49834 .71293 .49412 .70643 .48626 Mtetra
.70643 .48626 .71293 .49412 .72693 .48987 .72049 .48198 Mtetra
.72049 .48198 .72693 .48987 .74101 .48561 .73461 .47768 Mtetra
.73461 .47768 .74101 .48561 .75516 .48132 .74881 .47335 Mtetra
.74881 .47335 .75516 .48132 .76938 .47701 .76308 .469 Mtetra
.76308 .469 .76938 .47701 .78366 .47268 .77741 .46463 Mtetra
.77741 .46463 .78366 .47268 .79802 .46833 .79182 .46024 Mtetra
.79182 .46024 .79802 .46833 .81245 .46396 .80631 .45583 Mtetra
.80631 .45583 .81245 .46396 .82696 .45956 .82086 .45139 Mtetra
.82086 .45139 .82696 .45956 .84153 .45515 .83549 .44693 Mtetra
.83549 .44693 .84153 .45515 .85618 .45071 .85019 .44245 Mtetra
.664 .741 .908 r
.20877 .42089 .21628 .42788 .22724 .4241 .21976 .41708 Mtetra
.21976 .41708 .22724 .4241 .23825 .4203 .2308 .41325 Mtetra
.2308 .41325 .23825 .4203 .24931 .41649 .24188 .40941 Mtetra
.24188 .40941 .24931 .41649 .26041 .41266 .25302 .40555 Mtetra
.25302 .40555 .26041 .41266 .27156 .40882 .26419 .40168 Mtetra
.26419 .40168 .27156 .40882 .28276 .40496 .27542 .39779 Mtetra
.27542 .39779 .28276 .40496 .29401 .40108 .2867 .39388 Mtetra
.2867 .39388 .29401 .40108 .3053 .39719 .29802 .38995 Mtetra
.29802 .38995 .3053 .39719 .31665 .39327 .30939 .38601 Mtetra
.30939 .38601 .31665 .39327 .32804 .38935 .32082 .38205 Mtetra
.32082 .38205 .32804 .38935 .33948 .3854 .33229 .37807 Mtetra
.33229 .37807 .33948 .3854 .35097 .38144 .34381 .37408 Mtetra
.34381 .37408 .35097 .38144 .36251 .37746 .35538 .37007 Mtetra
.35538 .37007 .36251 .37746 .3741 .37347 .367 .36604 Mtetra
.367 .36604 .3741 .37347 .38574 .36945 .37867 .362 Mtetra
.37867 .362 .38574 .36945 .39744 .36542 .3904 .35793 Mtetra
.956 .632 .366 r
.3904 .35793 .39744 .36542 .40626 .44179 .39906 .43441 Mtetra
.658 .749 .917 r
.39906 .43441 .40626 .44179 .41834 .4378 .41118 .43039 Mtetra
.41118 .43039 .41834 .4378 .43048 .4338 .42336 .42635 Mtetra
.42336 .42635 .43048 .4338 .44268 .42977 .43559 .42229 Mtetra
.43559 .42229 .44268 .42977 .45493 .42573 .44787 .41822 Mtetra
.44787 .41822 .45493 .42573 .46724 .42167 .46021 .41412 Mtetra
.46021 .41412 .46724 .42167 .4796 .41759 .47261 .41001 Mtetra
.47261 .41001 .4796 .41759 .49202 .41349 .48507 .40587 Mtetra
.48507 .40587 .49202 .41349 .50449 .40937 .49758 .40172 Mtetra
.49758 .40172 .50449 .40937 .51703 .40523 .51015 .39755 Mtetra
.51015 .39755 .51703 .40523 .52961 .40108 .52278 .39336 Mtetra
.52278 .39336 .52961 .40108 .54226 .39691 .53546 .38915 Mtetra
.53546 .38915 .54226 .39691 .55497 .39271 .54821 .38492 Mtetra
.54821 .38492 .55497 .39271 .56773 .3885 .56101 .38067 Mtetra
.56101 .38067 .56773 .3885 .58056 .38427 .57387 .3764 Mtetra
.57387 .3764 .58056 .38427 .59344 .38002 .5868 .37211 Mtetra
.5868 .37211 .59344 .38002 .60638 .37574 .59978 .36781 Mtetra
.965 .638 .322 r
.59978 .36781 .60638 .37574 .62353 .51153 .6167 .50383 Mtetra
.646 .762 .934 r
.6167 .50383 .62353 .51153 .63718 .50737 .63039 .49964 Mtetra
.63039 .49964 .63718 .50737 .65089 .50319 .64415 .49542 Mtetra
.64415 .49542 .65089 .50319 .66468 .49899 .65798 .49118 Mtetra
.65798 .49118 .66468 .49899 .67853 .49477 .67188 .48692 Mtetra
.67188 .48692 .67853 .49477 .69244 .49053 .68584 .48264 Mtetra
.68584 .48264 .69244 .49053 .70643 .48626 .69988 .47834 Mtetra
.69988 .47834 .70643 .48626 .72049 .48198 .71398 .47402 Mtetra
.71398 .47402 .72049 .48198 .73461 .47768 .72815 .46967 Mtetra
.72815 .46967 .73461 .47768 .74881 .47335 .7424 .46531 Mtetra
.7424 .46531 .74881 .47335 .76308 .469 .75672 .46092 Mtetra
.75672 .46092 .76308 .469 .77741 .46463 .77111 .45651 Mtetra
.77111 .45651 .77741 .46463 .79182 .46024 .78557 .45207 Mtetra
.78557 .45207 .79182 .46024 .80631 .45583 .8001 .44762 Mtetra
.8001 .44762 .80631 .45583 .82086 .45139 .81471 .44314 Mtetra
.81471 .44314 .82086 .45139 .83549 .44693 .82939 .43864 Mtetra
.82939 .43864 .83549 .44693 .85019 .44245 .84415 .43412 Mtetra
.664 .741 .908 r
.2012 .41384 .20877 .42089 .21976 .41708 .21222 .41 Mtetra
.21222 .41 .21976 .41708 .2308 .41325 .22329 .40615 Mtetra
.22329 .40615 .2308 .41325 .24188 .40941 .2344 .40227 Mtetra
.2344 .40227 .24188 .40941 .25302 .40555 .24556 .39839 Mtetra
.24556 .39839 .25302 .40555 .26419 .40168 .25677 .39448 Mtetra
.25677 .39448 .26419 .40168 .27542 .39779 .26802 .39056 Mtetra
.26802 .39056 .27542 .39779 .2867 .39388 .27933 .38662 Mtetra
.27933 .38662 .2867 .39388 .29802 .38995 .29068 .38266 Mtetra
.29068 .38266 .29802 .38995 .30939 .38601 .30208 .37869 Mtetra
.30208 .37869 .30939 .38601 .32082 .38205 .31353 .3747 Mtetra
.31353 .3747 .32082 .38205 .33229 .37807 .32503 .37069 Mtetra
.32503 .37069 .33229 .37807 .34381 .37408 .33659 .36666 Mtetra
.33659 .36666 .34381 .37408 .35538 .37007 .34819 .36262 Mtetra
.34819 .36262 .35538 .37007 .367 .36604 .35984 .35856 Mtetra
.35984 .35856 .367 .36604 .37867 .362 .37155 .35448 Mtetra
.37155 .35448 .37867 .362 .3904 .35793 .3833 .35038 Mtetra
.956 .632 .366 r
.3833 .35038 .3904 .35793 .39906 .43441 .3918 .42697 Mtetra
.658 .749 .917 r
.3918 .42697 .39906 .43441 .41118 .43039 .40396 .42292 Mtetra
.40396 .42292 .41118 .43039 .42336 .42635 .41617 .41884 Mtetra
.41617 .41884 .42336 .42635 .43559 .42229 .42843 .41475 Mtetra
.42843 .41475 .43559 .42229 .44787 .41822 .44075 .41064 Mtetra
.44075 .41064 .44787 .41822 .46021 .41412 .45313 .40651 Mtetra
.45313 .40651 .46021 .41412 .47261 .41001 .46557 .40236 Mtetra
.46557 .40236 .47261 .41001 .48507 .40587 .47806 .39819 Mtetra
.47806 .39819 .48507 .40587 .49758 .40172 .49061 .39401 Mtetra
.49061 .39401 .49758 .40172 .51015 .39755 .50321 .3898 Mtetra
.50321 .3898 .51015 .39755 .52278 .39336 .51588 .38557 Mtetra
.51588 .38557 .52278 .39336 .53546 .38915 .5286 .38133 Mtetra
.5286 .38133 .53546 .38915 .54821 .38492 .54139 .37706 Mtetra
.54139 .37706 .54821 .38492 .56101 .38067 .55423 .37278 Mtetra
.55423 .37278 .56101 .38067 .57387 .3764 .56713 .36847 Mtetra
.56713 .36847 .57387 .3764 .5868 .37211 .5801 .36415 Mtetra
.5801 .36415 .5868 .37211 .59978 .36781 .59312 .3598 Mtetra
.965 .638 .322 r
.59312 .3598 .59978 .36781 .6167 .50383 .6098 .49607 Mtetra
.646 .762 .934 r
.6098 .49607 .6167 .50383 .63039 .49964 .62354 .49183 Mtetra
.62354 .49183 .63039 .49964 .64415 .49542 .63735 .48758 Mtetra
.63735 .48758 .64415 .49542 .65798 .49118 .65122 .4833 Mtetra
.65122 .4833 .65798 .49118 .67188 .48692 .66517 .479 Mtetra
.66517 .479 .67188 .48692 .68584 .48264 .67918 .47468 Mtetra
.67918 .47468 .68584 .48264 .69988 .47834 .69326 .47034 Mtetra
.69326 .47034 .69988 .47834 .71398 .47402 .70741 .46598 Mtetra
.70741 .46598 .71398 .47402 .72815 .46967 .72164 .46159 Mtetra
.72164 .46159 .72815 .46967 .7424 .46531 .73593 .45719 Mtetra
.73593 .45719 .7424 .46531 .75672 .46092 .7503 .45276 Mtetra
.7503 .45276 .75672 .46092 .77111 .45651 .76474 .44831 Mtetra
.76474 .44831 .77111 .45651 .78557 .45207 .77925 .44383 Mtetra
.77925 .44383 .78557 .45207 .8001 .44762 .79384 .43934 Mtetra
.79384 .43934 .8001 .44762 .81471 .44314 .8085 .43482 Mtetra
.8085 .43482 .81471 .44314 .82939 .43864 .82323 .43027 Mtetra
.82323 .43027 .82939 .43864 .84415 .43412 .83804 .42571 Mtetra
.664 .741 .908 r
.19358 .40674 .2012 .41384 .21222 .41 .20462 .40287 Mtetra
.20462 .40287 .21222 .41 .22329 .40615 .21571 .39899 Mtetra
.21571 .39899 .22329 .40615 .2344 .40227 .22685 .39508 Mtetra
.22685 .39508 .2344 .40227 .24556 .39839 .23804 .39116 Mtetra
.23804 .39116 .24556 .39839 .25677 .39448 .24928 .38723 Mtetra
.24928 .38723 .25677 .39448 .26802 .39056 .26056 .38327 Mtetra
.26056 .38327 .26802 .39056 .27933 .38662 .2719 .3793 Mtetra
.2719 .3793 .27933 .38662 .29068 .38266 .28328 .37531 Mtetra
.28328 .37531 .29068 .38266 .30208 .37869 .29471 .37131 Mtetra
.29471 .37131 .30208 .37869 .31353 .3747 .30619 .36728 Mtetra
.30619 .36728 .31353 .3747 .32503 .37069 .31772 .36324 Mtetra
.31772 .36324 .32503 .37069 .33659 .36666 .32931 .35918 Mtetra
.32931 .35918 .33659 .36666 .34819 .36262 .34094 .35511 Mtetra
.34094 .35511 .34819 .36262 .35984 .35856 .35262 .35101 Mtetra
.35262 .35101 .35984 .35856 .37155 .35448 .36436 .3469 Mtetra
.36436 .3469 .37155 .35448 .3833 .35038 .37615 .34277 Mtetra
.956 .632 .366 r
.37615 .34277 .3833 .35038 .3918 .42697 .38449 .41947 Mtetra
.658 .749 .917 r
.38449 .41947 .3918 .42697 .40396 .42292 .39667 .41538 Mtetra
.39667 .41538 .40396 .42292 .41617 .41884 .40892 .41127 Mtetra
.40892 .41127 .41617 .41884 .42843 .41475 .42122 .40715 Mtetra
.42122 .40715 .42843 .41475 .44075 .41064 .43358 .403 Mtetra
.43358 .403 .44075 .41064 .45313 .40651 .44599 .39883 Mtetra
.44599 .39883 .45313 .40651 .46557 .40236 .45846 .39465 Mtetra
.45846 .39465 .46557 .40236 .47806 .39819 .47099 .39045 Mtetra
.47099 .39045 .47806 .39819 .49061 .39401 .48358 .38622 Mtetra
.48358 .38622 .49061 .39401 .50321 .3898 .49622 .38198 Mtetra
.49622 .38198 .50321 .3898 .51588 .38557 .50892 .37772 Mtetra
.50892 .37772 .51588 .38557 .5286 .38133 .52169 .37344 Mtetra
.52169 .37344 .5286 .38133 .54139 .37706 .53451 .36913 Mtetra
.53451 .36913 .54139 .37706 .55423 .37278 .54739 .36481 Mtetra
.54739 .36481 .55423 .37278 .56713 .36847 .56033 .36047 Mtetra
.56033 .36047 .56713 .36847 .5801 .36415 .57334 .35611 Mtetra
.57334 .35611 .5801 .36415 .59312 .3598 .5864 .35172 Mtetra
.965 .638 .322 r
.5864 .35172 .59312 .3598 .6098 .49607 .60285 .48823 Mtetra
.646 .762 .934 r
.60285 .48823 .6098 .49607 .62354 .49183 .61663 .48396 Mtetra
.61663 .48396 .62354 .49183 .63735 .48758 .63048 .47967 Mtetra
.63048 .47967 .63735 .48758 .65122 .4833 .6444 .47535 Mtetra
.6444 .47535 .65122 .4833 .66517 .479 .65839 .47101 Mtetra
.65839 .47101 .66517 .479 .67918 .47468 .67245 .46665 Mtetra
.67245 .46665 .67918 .47468 .69326 .47034 .68658 .46227 Mtetra
.68658 .46227 .69326 .47034 .70741 .46598 .70079 .45787 Mtetra
.70079 .45787 .70741 .46598 .72164 .46159 .71506 .45344 Mtetra
.71506 .45344 .72164 .46159 .73593 .45719 .7294 .44899 Mtetra
.7294 .44899 .73593 .45719 .7503 .45276 .74382 .44452 Mtetra
.74382 .44452 .7503 .45276 .76474 .44831 .75831 .44003 Mtetra
.75831 .44003 .76474 .44831 .77925 .44383 .77288 .43551 Mtetra
.77288 .43551 .77925 .44383 .79384 .43934 .78751 .43097 Mtetra
.78751 .43097 .79384 .43934 .8085 .43482 .80223 .42641 Mtetra
.80223 .42641 .8085 .43482 .82323 .43027 .81702 .42183 Mtetra
.81702 .42183 .82323 .43027 .83804 .42571 .83188 .41722 Mtetra
.664 .741 .908 r
.18589 .39958 .19358 .40674 .20462 .40287 .19696 .39568 Mtetra
.19696 .39568 .20462 .40287 .21571 .39899 .20808 .39177 Mtetra
.20808 .39177 .21571 .39899 .22685 .39508 .21925 .38783 Mtetra
.21925 .38783 .22685 .39508 .23804 .39116 .23047 .38388 Mtetra
.23047 .38388 .23804 .39116 .24928 .38723 .24173 .37991 Mtetra
.24173 .37991 .24928 .38723 .26056 .38327 .25304 .37593 Mtetra
.25304 .37593 .26056 .38327 .2719 .3793 .26441 .37192 Mtetra
.26441 .37192 .2719 .3793 .28328 .37531 .27582 .3679 Mtetra
.27582 .3679 .28328 .37531 .29471 .37131 .28728 .36387 Mtetra
.28728 .36387 .29471 .37131 .30619 .36728 .29879 .35981 Mtetra
.29879 .35981 .30619 .36728 .31772 .36324 .31035 .35574 Mtetra
.31035 .35574 .31772 .36324 .32931 .35918 .32197 .35165 Mtetra
.32197 .35165 .32931 .35918 .34094 .35511 .33363 .34754 Mtetra
.33363 .34754 .34094 .35511 .35262 .35101 .34535 .34341 Mtetra
.34535 .34341 .35262 .35101 .36436 .3469 .35711 .33926 Mtetra
.35711 .33926 .36436 .3469 .37615 .34277 .36893 .3351 Mtetra
.956 .632 .366 r
.36893 .3351 .37615 .34277 .38449 .41947 .37711 .41191 Mtetra
.658 .749 .917 r
.37711 .41191 .38449 .41947 .39667 .41538 .38933 .40778 Mtetra
.38933 .40778 .39667 .41538 .40892 .41127 .40161 .40364 Mtetra
.40161 .40364 .40892 .41127 .42122 .40715 .41395 .39948 Mtetra
.41395 .39948 .42122 .40715 .43358 .403 .42634 .3953 Mtetra
.42634 .3953 .43358 .403 .44599 .39883 .43879 .39109 Mtetra
.43879 .39109 .44599 .39883 .45846 .39465 .4513 .38687 Mtetra
.4513 .38687 .45846 .39465 .47099 .39045 .46386 .38264 Mtetra
.46386 .38264 .47099 .39045 .48358 .38622 .47648 .37838 Mtetra
.47648 .37838 .48358 .38622 .49622 .38198 .48917 .3741 Mtetra
.48917 .3741 .49622 .38198 .50892 .37772 .50191 .3698 Mtetra
.50191 .3698 .50892 .37772 .52169 .37344 .51471 .36548 Mtetra
.51471 .36548 .52169 .37344 .53451 .36913 .52757 .36114 Mtetra
.52757 .36114 .53451 .36913 .54739 .36481 .54049 .35678 Mtetra
.54049 .35678 .54739 .36481 .56033 .36047 .55348 .3524 Mtetra
.55348 .3524 .56033 .36047 .57334 .35611 .56652 .348 Mtetra
.56652 .348 .57334 .35611 .5864 .35172 .57962 .34358 Mtetra
.965 .638 .322 r
.57962 .34358 .5864 .35172 .60285 .48823 .59582 .48033 Mtetra
.646 .762 .934 r
.59582 .48033 .60285 .48823 .61663 .48396 .60965 .47601 Mtetra
.60965 .47601 .61663 .48396 .63048 .47967 .62355 .47168 Mtetra
.62355 .47168 .63048 .47967 .6444 .47535 .63752 .46732 Mtetra
.63752 .46732 .6444 .47535 .65839 .47101 .65156 .46295 Mtetra
.65156 .46295 .65839 .47101 .67245 .46665 .66567 .45855 Mtetra
.66567 .45855 .67245 .46665 .68658 .46227 .67985 .45412 Mtetra
.67985 .45412 .68658 .46227 .70079 .45787 .6941 .44968 Mtetra
.6941 .44968 .70079 .45787 .71506 .45344 .70842 .44521 Mtetra
.70842 .44521 .71506 .45344 .7294 .44899 .72281 .44072 Mtetra
.72281 .44072 .7294 .44899 .74382 .44452 .73728 .43621 Mtetra
.73728 .43621 .74382 .44452 .75831 .44003 .75183 .43167 Mtetra
.75183 .43167 .75831 .44003 .77288 .43551 .76644 .42712 Mtetra
.76644 .42712 .77288 .43551 .78751 .43097 .78113 .42253 Mtetra
.78113 .42253 .78751 .43097 .80223 .42641 .7959 .41793 Mtetra
.7959 .41793 .80223 .42641 .81702 .42183 .81074 .4133 Mtetra
.81074 .4133 .81702 .42183 .83188 .41722 .82566 .40865 Mtetra
.664 .741 .908 r
.17814 .39237 .18589 .39958 .19696 .39568 .18924 .38844 Mtetra
.18924 .38844 .19696 .39568 .20808 .39177 .20039 .38449 Mtetra
.20039 .38449 .20808 .39177 .21925 .38783 .21158 .38052 Mtetra
.21158 .38052 .21925 .38783 .23047 .38388 .22283 .37654 Mtetra
.22283 .37654 .23047 .38388 .24173 .37991 .23412 .37254 Mtetra
.23412 .37254 .24173 .37991 .25304 .37593 .24546 .36852 Mtetra
.24546 .36852 .25304 .37593 .26441 .37192 .25686 .36449 Mtetra
.25686 .36449 .26441 .37192 .27582 .3679 .2683 .36043 Mtetra
.2683 .36043 .27582 .3679 .28728 .36387 .27979 .35636 Mtetra
.27979 .35636 .28728 .36387 .29879 .35981 .29133 .35228 Mtetra
.29133 .35228 .29879 .35981 .31035 .35574 .30292 .34817 Mtetra
.30292 .34817 .31035 .35574 .32197 .35165 .31457 .34404 Mtetra
.31457 .34404 .32197 .35165 .33363 .34754 .32626 .3399 Mtetra
.32626 .3399 .33363 .34754 .34535 .34341 .33801 .33574 Mtetra
.33801 .33574 .34535 .34341 .35711 .33926 .34981 .33156 Mtetra
.34981 .33156 .35711 .33926 .36893 .3351 .36166 .32736 Mtetra
.956 .632 .366 r
.36166 .32736 .36893 .3351 .37711 .41191 .36966 .40428 Mtetra
.658 .749 .917 r
.36966 .40428 .37711 .41191 .38933 .40778 .38192 .40012 Mtetra
.38192 .40012 .38933 .40778 .40161 .40364 .39424 .39594 Mtetra
.39424 .39594 .40161 .40364 .41395 .39948 .40661 .39174 Mtetra
.40661 .39174 .41395 .39948 .42634 .3953 .41904 .38753 Mtetra
.41904 .38753 .42634 .3953 .43879 .39109 .43152 .38329 Mtetra
.43152 .38329 .43879 .39109 .4513 .38687 .44407 .37903 Mtetra
.44407 .37903 .4513 .38687 .46386 .38264 .45667 .37476 Mtetra
.45667 .37476 .46386 .38264 .47648 .37838 .46933 .37046 Mtetra
.46933 .37046 .47648 .37838 .48917 .3741 .48205 .36614 Mtetra
.48205 .36614 .48917 .3741 .50191 .3698 .49483 .36181 Mtetra
.49483 .36181 .50191 .3698 .51471 .36548 .50767 .35745 Mtetra
.50767 .35745 .51471 .36548 .52757 .36114 .52057 .35307 Mtetra
.52057 .35307 .52757 .36114 .54049 .35678 .53353 .34868 Mtetra
.53353 .34868 .54049 .35678 .55348 .3524 .54656 .34426 Mtetra
.54656 .34426 .55348 .3524 .56652 .348 .55964 .33982 Mtetra
.55964 .33982 .56652 .348 .57962 .34358 .57279 .33536 Mtetra
.965 .638 .322 r
.57279 .33536 .57962 .34358 .59582 .48033 .58874 .47235 Mtetra
.646 .762 .934 r
.58874 .47235 .59582 .48033 .60965 .47601 .60261 .468 Mtetra
.60261 .468 .60965 .47601 .62355 .47168 .61656 .46362 Mtetra
.61656 .46362 .62355 .47168 .63752 .46732 .63057 .45922 Mtetra
.63057 .45922 .63752 .46732 .65156 .46295 .64466 .45481 Mtetra
.64466 .45481 .65156 .46295 .66567 .45855 .65882 .45036 Mtetra
.65882 .45036 .66567 .45855 .67985 .45412 .67304 .4459 Mtetra
.67304 .4459 .67985 .45412 .6941 .44968 .68734 .44141 Mtetra
.68734 .44141 .6941 .44968 .70842 .44521 .70172 .43691 Mtetra
.70172 .43691 .70842 .44521 .72281 .44072 .71616 .43237 Mtetra
.71616 .43237 .72281 .44072 .73728 .43621 .73068 .42782 Mtetra
.73068 .42782 .73728 .43621 .75183 .43167 .74528 .42324 Mtetra
.74528 .42324 .75183 .43167 .76644 .42712 .75995 .41864 Mtetra
.75995 .41864 .76644 .42712 .78113 .42253 .77469 .41401 Mtetra
.77469 .41401 .78113 .42253 .7959 .41793 .78951 .40936 Mtetra
.78951 .40936 .7959 .41793 .81074 .4133 .80441 .40469 Mtetra
.80441 .40469 .81074 .4133 .82566 .40865 .81938 .39999 Mtetra
.664 .741 .908 r
.17033 .3851 .17814 .39237 .18924 .38844 .18146 .38114 Mtetra
.18146 .38114 .18924 .38844 .20039 .38449 .19263 .37715 Mtetra
.19263 .37715 .20039 .38449 .21158 .38052 .20386 .37316 Mtetra
.20386 .37316 .21158 .38052 .22283 .37654 .21513 .36914 Mtetra
.21513 .36914 .22283 .37654 .23412 .37254 .22645 .36511 Mtetra
.22645 .36511 .23412 .37254 .24546 .36852 .23782 .36106 Mtetra
.23782 .36106 .24546 .36852 .25686 .36449 .24924 .35699 Mtetra
.24924 .35699 .25686 .36449 .2683 .36043 .26072 .35291 Mtetra
.26072 .35291 .2683 .36043 .27979 .35636 .27224 .3488 Mtetra
.27224 .3488 .27979 .35636 .29133 .35228 .28381 .34468 Mtetra
.28381 .34468 .29133 .35228 .30292 .34817 .29543 .34054 Mtetra
.29543 .34054 .30292 .34817 .31457 .34404 .30711 .33638 Mtetra
.30711 .33638 .31457 .34404 .32626 .3399 .31884 .3322 Mtetra
.31884 .3322 .32626 .3399 .33801 .33574 .33061 .32801 Mtetra
.33061 .32801 .33801 .33574 .34981 .33156 .34245 .3238 Mtetra
.34245 .3238 .34981 .33156 .36166 .32736 .35433 .31956 Mtetra
.35433 .31956 .36166 .32736 .36966 .40428 .36627 .31531 Mtetra
.556 .363 .575 r
.36627 .31531 .36966 .40428 .38192 .40012 .37826 .31104 Mtetra
.37826 .31104 .38192 .40012 .39424 .39594 .39031 .30675 Mtetra
.39031 .30675 .39424 .39594 .40661 .39174 .40241 .30244 Mtetra
.40241 .30244 .40661 .39174 .41904 .38753 .41456 .29811 Mtetra
.41456 .29811 .41904 .38753 .43152 .38329 .42677 .29376 Mtetra
.42677 .29376 .43152 .38329 .44407 .37903 .43903 .28939 Mtetra
.43903 .28939 .44407 .37903 .45667 .37476 .45135 .285 Mtetra
.45135 .285 .45667 .37476 .46933 .37046 .46373 .2806 Mtetra
.46373 .2806 .46933 .37046 .48205 .36614 .47617 .27617 Mtetra
.47617 .27617 .48205 .36614 .49483 .36181 .48866 .27172 Mtetra
.48866 .27172 .49483 .36181 .50767 .35745 .5012 .26725 Mtetra
.5012 .26725 .50767 .35745 .52057 .35307 .51381 .26276 Mtetra
.51381 .26276 .52057 .35307 .53353 .34868 .52647 .25825 Mtetra
.52647 .25825 .53353 .34868 .54656 .34426 .5392 .25372 Mtetra
.5392 .25372 .54656 .34426 .55964 .33982 .55198 .24917 Mtetra
.55198 .24917 .55964 .33982 .57279 .33536 .56482 .24459 Mtetra
0 0 .398 r
.56482 .24459 .57279 .33536 .58874 .47235 .57944 .33959 Mtetra
.548 .346 .558 r
.57944 .33959 .58874 .47235 .60261 .468 .59282 .33506 Mtetra
.59282 .33506 .60261 .468 .61656 .46362 .60628 .33052 Mtetra
.60628 .33052 .61656 .46362 .63057 .45922 .61979 .32595 Mtetra
.61979 .32595 .63057 .45922 .64466 .45481 .63338 .32135 Mtetra
.63338 .32135 .64466 .45481 .65882 .45036 .64703 .31674 Mtetra
.64703 .31674 .65882 .45036 .67304 .4459 .66074 .3121 Mtetra
.66074 .3121 .67304 .4459 .68734 .44141 .67452 .30744 Mtetra
.67452 .30744 .68734 .44141 .70172 .43691 .68837 .30276 Mtetra
.68837 .30276 .70172 .43691 .71616 .43237 .70229 .29805 Mtetra
.70229 .29805 .71616 .43237 .73068 .42782 .71628 .29332 Mtetra
.71628 .29332 .73068 .42782 .74528 .42324 .73034 .28857 Mtetra
.73034 .28857 .74528 .42324 .75995 .41864 .74446 .28379 Mtetra
.74446 .28379 .75995 .41864 .77469 .41401 .75866 .27899 Mtetra
.75866 .27899 .77469 .41401 .78951 .40936 .77292 .27417 Mtetra
.77292 .27417 .78951 .40936 .80441 .40469 .78726 .26932 Mtetra
.78726 .26932 .80441 .40469 .81938 .39999 .80167 .26445 Mtetra
.664 .741 .908 r
.16246 .37777 .17033 .3851 .18146 .38114 .17361 .37377 Mtetra
.17361 .37377 .18146 .38114 .19263 .37715 .18482 .36976 Mtetra
.18482 .36976 .19263 .37715 .20386 .37316 .19607 .36573 Mtetra
.19607 .36573 .20386 .37316 .21513 .36914 .20737 .36168 Mtetra
.20737 .36168 .21513 .36914 .22645 .36511 .21872 .35762 Mtetra
.21872 .35762 .22645 .36511 .23782 .36106 .23012 .35354 Mtetra
.23012 .35354 .23782 .36106 .24924 .35699 .24157 .34943 Mtetra
.24157 .34943 .24924 .35699 .26072 .35291 .25307 .34532 Mtetra
.25307 .34532 .26072 .35291 .27224 .3488 .26462 .34118 Mtetra
.26462 .34118 .27224 .3488 .28381 .34468 .27623 .33702 Mtetra
.27623 .33702 .28381 .34468 .29543 .34054 .28788 .33285 Mtetra
.28788 .33285 .29543 .34054 .30711 .33638 .29959 .32866 Mtetra
.29959 .32866 .30711 .33638 .31884 .3322 .31135 .32444 Mtetra
.31135 .32444 .31884 .3322 .33061 .32801 .32316 .32021 Mtetra
.32316 .32021 .33061 .32801 .34245 .3238 .33502 .31597 Mtetra
.33502 .31597 .34245 .3238 .35433 .31956 .34694 .3117 Mtetra
.34694 .3117 .35433 .31956 .36627 .31531 .35891 .30741 Mtetra
.35891 .30741 .36627 .31531 .37826 .31104 .37093 .3031 Mtetra
.37093 .3031 .37826 .31104 .39031 .30675 .38301 .29878 Mtetra
.38301 .29878 .39031 .30675 .40241 .30244 .39515 .29443 Mtetra
.39515 .29443 .40241 .30244 .41456 .29811 .40734 .29007 Mtetra
.40734 .29007 .41456 .29811 .42677 .29376 .41958 .28568 Mtetra
.41958 .28568 .42677 .29376 .43903 .28939 .43188 .28128 Mtetra
.43188 .28128 .43903 .28939 .45135 .285 .44424 .27685 Mtetra
.44424 .27685 .45135 .285 .46373 .2806 .45665 .2724 Mtetra
.45665 .2724 .46373 .2806 .47617 .27617 .46912 .26794 Mtetra
.46912 .26794 .47617 .27617 .48866 .27172 .48165 .26345 Mtetra
.48165 .26345 .48866 .27172 .5012 .26725 .49423 .25894 Mtetra
.49423 .25894 .5012 .26725 .51381 .26276 .50688 .25442 Mtetra
.50688 .25442 .51381 .26276 .52647 .25825 .51958 .24987 Mtetra
.51958 .24987 .52647 .25825 .5392 .25372 .53234 .2453 Mtetra
.53234 .2453 .5392 .25372 .55198 .24917 .54516 .24071 Mtetra
.54516 .24071 .55198 .24917 .56482 .24459 .55804 .23609 Mtetra
.958 .617 .28 r
.55804 .23609 .56482 .24459 .57944 .33959 .57248 .33122 Mtetra
.656 .751 .919 r
.57248 .33122 .57944 .33959 .59282 .33506 .58591 .32665 Mtetra
.58591 .32665 .59282 .33506 .60628 .33052 .59941 .32206 Mtetra
.59941 .32206 .60628 .33052 .61979 .32595 .61297 .31745 Mtetra
.61297 .31745 .61979 .32595 .63338 .32135 .6266 .31281 Mtetra
.6266 .31281 .63338 .32135 .64703 .31674 .64029 .30816 Mtetra
.64029 .30816 .64703 .31674 .66074 .3121 .65405 .30348 Mtetra
.65405 .30348 .66074 .3121 .67452 .30744 .66788 .29878 Mtetra
.66788 .29878 .67452 .30744 .68837 .30276 .68178 .29405 Mtetra
.68178 .29405 .68837 .30276 .70229 .29805 .69575 .2893 Mtetra
.69575 .2893 .70229 .29805 .71628 .29332 .70978 .28453 Mtetra
.70978 .28453 .71628 .29332 .73034 .28857 .72388 .27973 Mtetra
.72388 .27973 .73034 .28857 .74446 .28379 .73806 .27491 Mtetra
.73806 .27491 .74446 .28379 .75866 .27899 .7523 .27007 Mtetra
.7523 .27007 .75866 .27899 .77292 .27417 .76662 .2652 Mtetra
.76662 .2652 .77292 .27417 .78726 .26932 .78101 .2603 Mtetra
.78101 .2603 .78726 .26932 .80167 .26445 .79547 .25539 Mtetra
.664 .741 .908 r
.15452 .37038 .16246 .37777 .17361 .37377 .16571 .36635 Mtetra
.16571 .36635 .17361 .37377 .18482 .36976 .17694 .36231 Mtetra
.17694 .36231 .18482 .36976 .19607 .36573 .18822 .35825 Mtetra
.18822 .35825 .19607 .36573 .20737 .36168 .19955 .35416 Mtetra
.19955 .35416 .20737 .36168 .21872 .35762 .21093 .35007 Mtetra
.21093 .35007 .21872 .35762 .23012 .35354 .22236 .34595 Mtetra
.22236 .34595 .23012 .35354 .24157 .34943 .23384 .34182 Mtetra
.23384 .34182 .24157 .34943 .25307 .34532 .24537 .33766 Mtetra
.24537 .33766 .25307 .34532 .26462 .34118 .25695 .33349 Mtetra
.25695 .33349 .26462 .34118 .27623 .33702 .26858 .3293 Mtetra
.26858 .3293 .27623 .33702 .28788 .33285 .28027 .32509 Mtetra
.28027 .32509 .28788 .33285 .29959 .32866 .292 .32087 Mtetra
.292 .32087 .29959 .32866 .31135 .32444 .30379 .31662 Mtetra
.30379 .31662 .31135 .32444 .32316 .32021 .31564 .31236 Mtetra
.31564 .31236 .32316 .32021 .33502 .31597 .32753 .30807 Mtetra
.32753 .30807 .33502 .31597 .34694 .3117 .33948 .30377 Mtetra
.33948 .30377 .34694 .3117 .35891 .30741 .35149 .29944 Mtetra
.35149 .29944 .35891 .30741 .37093 .3031 .36355 .2951 Mtetra
.36355 .2951 .37093 .3031 .38301 .29878 .37566 .29074 Mtetra
.37566 .29074 .38301 .29878 .39515 .29443 .38783 .28636 Mtetra
.38783 .28636 .39515 .29443 .40734 .29007 .40005 .28195 Mtetra
.40005 .28195 .40734 .29007 .41958 .28568 .41233 .27753 Mtetra
.41233 .27753 .41958 .28568 .43188 .28128 .42467 .27309 Mtetra
.42467 .27309 .43188 .28128 .44424 .27685 .43706 .26863 Mtetra
.43706 .26863 .44424 .27685 .45665 .2724 .44951 .26414 Mtetra
.44951 .26414 .45665 .2724 .46912 .26794 .46201 .25964 Mtetra
.46201 .25964 .46912 .26794 .48165 .26345 .47458 .25511 Mtetra
.47458 .25511 .48165 .26345 .49423 .25894 .4872 .25057 Mtetra
.4872 .25057 .49423 .25894 .50688 .25442 .49988 .246 Mtetra
.49988 .246 .50688 .25442 .51958 .24987 .51262 .24141 Mtetra
.51262 .24141 .51958 .24987 .53234 .2453 .52542 .2368 Mtetra
.52542 .2368 .53234 .2453 .54516 .24071 .53828 .23217 Mtetra
.53828 .23217 .54516 .24071 .55804 .23609 .5512 .22752 Mtetra
.958 .617 .28 r
.5512 .22752 .55804 .23609 .57248 .33122 .56547 .32277 Mtetra
.656 .751 .919 r
.56547 .32277 .57248 .33122 .58591 .32665 .57894 .31816 Mtetra
.57894 .31816 .58591 .32665 .59941 .32206 .59248 .31353 Mtetra
.59248 .31353 .59941 .32206 .61297 .31745 .60609 .30888 Mtetra
.60609 .30888 .61297 .31745 .6266 .31281 .61976 .3042 Mtetra
.61976 .3042 .6266 .31281 .64029 .30816 .6335 .2995 Mtetra
.6335 .2995 .64029 .30816 .65405 .30348 .64731 .29478 Mtetra
.64731 .29478 .65405 .30348 .66788 .29878 .66118 .29003 Mtetra
.66118 .29003 .66788 .29878 .68178 .29405 .67513 .28526 Mtetra
.67513 .28526 .68178 .29405 .69575 .2893 .68914 .28047 Mtetra
.68914 .28047 .69575 .2893 .70978 .28453 .70322 .27565 Mtetra
.70322 .27565 .70978 .28453 .72388 .27973 .71738 .27081 Mtetra
.71738 .27081 .72388 .27973 .73806 .27491 .7316 .26595 Mtetra
.7316 .26595 .73806 .27491 .7523 .27007 .74589 .26106 Mtetra
.74589 .26106 .7523 .27007 .76662 .2652 .76026 .25615 Mtetra
.76026 .25615 .76662 .2652 .78101 .2603 .7747 .25121 Mtetra
.7747 .25121 .78101 .2603 .79547 .25539 .78921 .24624 Mtetra
.664 .741 .908 r
.14652 .36293 .15452 .37038 .16571 .36635 .15773 .35887 Mtetra
.15773 .35887 .16571 .36635 .17694 .36231 .16899 .35479 Mtetra
.16899 .35479 .17694 .36231 .18822 .35825 .1803 .3507 Mtetra
.1803 .3507 .18822 .35825 .19955 .35416 .19166 .34658 Mtetra
.19166 .34658 .19955 .35416 .21093 .35007 .20307 .34245 Mtetra
.20307 .34245 .21093 .35007 .22236 .34595 .21453 .3383 Mtetra
.21453 .3383 .22236 .34595 .23384 .34182 .22604 .33414 Mtetra
.22604 .33414 .23384 .34182 .24537 .33766 .2376 .32995 Mtetra
.2376 .32995 .24537 .33766 .25695 .33349 .24921 .32574 Mtetra
.24921 .32574 .25695 .33349 .26858 .3293 .26087 .32152 Mtetra
.26087 .32152 .26858 .3293 .28027 .32509 .27259 .31728 Mtetra
.27259 .31728 .28027 .32509 .292 .32087 .28436 .31301 Mtetra
.28436 .31301 .292 .32087 .30379 .31662 .29618 .30873 Mtetra
.29618 .30873 .30379 .31662 .31564 .31236 .30806 .30443 Mtetra
.30806 .30443 .31564 .31236 .32753 .30807 .31998 .30011 Mtetra
.31998 .30011 .32753 .30807 .33948 .30377 .33197 .29577 Mtetra
.33197 .29577 .33948 .30377 .35149 .29944 .344 .29141 Mtetra
.344 .29141 .35149 .29944 .36355 .2951 .3561 .28703 Mtetra
.3561 .28703 .36355 .2951 .37566 .29074 .36824 .28263 Mtetra
.36824 .28263 .37566 .29074 .38783 .28636 .38045 .27821 Mtetra
.38045 .27821 .38783 .28636 .40005 .28195 .3927 .27377 Mtetra
.3927 .27377 .40005 .28195 .41233 .27753 .40502 .26932 Mtetra
.40502 .26932 .41233 .27753 .42467 .27309 .41739 .26483 Mtetra
.41739 .26483 .42467 .27309 .43706 .26863 .42982 .26033 Mtetra
.42982 .26033 .43706 .26863 .44951 .26414 .4423 .25581 Mtetra
.4423 .25581 .44951 .26414 .46201 .25964 .45485 .25127 Mtetra
.45485 .25127 .46201 .25964 .47458 .25511 .46745 .24671 Mtetra
.46745 .24671 .47458 .25511 .4872 .25057 .48011 .24212 Mtetra
.48011 .24212 .4872 .25057 .49988 .246 .49283 .23751 Mtetra
.49283 .23751 .49988 .246 .51262 .24141 .50561 .23289 Mtetra
.50561 .23289 .51262 .24141 .52542 .2368 .51844 .22824 Mtetra
.51844 .22824 .52542 .2368 .53828 .23217 .53134 .22356 Mtetra
.53134 .22356 .53828 .23217 .5512 .22752 .5443 .21887 Mtetra
.958 .617 .28 r
.5443 .21887 .5512 .22752 .56547 .32277 .55839 .31424 Mtetra
.656 .751 .919 r
.55839 .31424 .56547 .32277 .57894 .31816 .57191 .30959 Mtetra
.57191 .30959 .57894 .31816 .59248 .31353 .58549 .30492 Mtetra
.58549 .30492 .59248 .31353 .60609 .30888 .59914 .30022 Mtetra
.59914 .30022 .60609 .30888 .61976 .3042 .61286 .29551 Mtetra
.61286 .29551 .61976 .3042 .6335 .2995 .62665 .29076 Mtetra
.62665 .29076 .6335 .2995 .64731 .29478 .6405 .286 Mtetra
.6405 .286 .64731 .29478 .66118 .29003 .65442 .28121 Mtetra
.65442 .28121 .66118 .29003 .67513 .28526 .66841 .2764 Mtetra
.66841 .2764 .67513 .28526 .68914 .28047 .68247 .27156 Mtetra
.68247 .27156 .68914 .28047 .70322 .27565 .6966 .2667 Mtetra
.6966 .2667 .70322 .27565 .71738 .27081 .71081 .26181 Mtetra
.71081 .26181 .71738 .27081 .7316 .26595 .72508 .2569 Mtetra
.72508 .2569 .7316 .26595 .74589 .26106 .73942 .25197 Mtetra
.73942 .25197 .74589 .26106 .76026 .25615 .75384 .24701 Mtetra
.75384 .24701 .76026 .25615 .7747 .25121 .76833 .24202 Mtetra
.76833 .24202 .7747 .25121 .78921 .24624 .78289 .23701 Mtetra
.664 .741 .908 r
.13846 .35542 .14652 .36293 .15773 .35887 .1497 .35133 Mtetra
.1497 .35133 .15773 .35887 .16899 .35479 .16098 .34722 Mtetra
.16098 .34722 .16899 .35479 .1803 .3507 .17232 .34309 Mtetra
.17232 .34309 .1803 .3507 .19166 .34658 .18371 .33894 Mtetra
.18371 .33894 .19166 .34658 .20307 .34245 .19515 .33478 Mtetra
.19515 .33478 .20307 .34245 .21453 .3383 .20663 .33059 Mtetra
.20663 .33059 .21453 .3383 .22604 .33414 .21817 .32639 Mtetra
.21817 .32639 .22604 .33414 .2376 .32995 .22976 .32217 Mtetra
.22976 .32217 .2376 .32995 .24921 .32574 .24141 .31793 Mtetra
.24141 .31793 .24921 .32574 .26087 .32152 .2531 .31367 Mtetra
.2531 .31367 .26087 .32152 .27259 .31728 .26485 .30939 Mtetra
.26485 .30939 .27259 .31728 .28436 .31301 .27665 .30509 Mtetra
.27665 .30509 .28436 .31301 .29618 .30873 .2885 .30078 Mtetra
.2885 .30078 .29618 .30873 .30806 .30443 .30041 .29644 Mtetra
.30041 .29644 .30806 .30443 .31998 .30011 .31237 .29208 Mtetra
.31237 .29208 .31998 .30011 .33197 .29577 .32439 .28771 Mtetra
.32439 .28771 .33197 .29577 .344 .29141 .33646 .28331 Mtetra
.33646 .28331 .344 .29141 .3561 .28703 .34858 .2789 Mtetra
.34858 .2789 .3561 .28703 .36824 .28263 .36077 .27446 Mtetra
.36077 .27446 .36824 .28263 .38045 .27821 .373 .27 Mtetra
.373 .27 .38045 .27821 .3927 .27377 .3853 .26553 Mtetra
.3853 .26553 .3927 .27377 .40502 .26932 .39764 .26103 Mtetra
.39764 .26103 .40502 .26932 .41739 .26483 .41005 .25651 Mtetra
.41005 .25651 .41739 .26483 .42982 .26033 .42252 .25197 Mtetra
.42252 .25197 .42982 .26033 .4423 .25581 .43504 .24741 Mtetra
.43504 .24741 .4423 .25581 .45485 .25127 .44762 .24283 Mtetra
.44762 .24283 .45485 .25127 .46745 .24671 .46026 .23822 Mtetra
.46026 .23822 .46745 .24671 .48011 .24212 .47296 .2336 Mtetra
.47296 .2336 .48011 .24212 .49283 .23751 .48571 .22895 Mtetra
.48571 .22895 .49283 .23751 .50561 .23289 .49853 .22429 Mtetra
.49853 .22429 .50561 .23289 .51844 .22824 .51141 .2196 Mtetra
.51141 .2196 .51844 .22824 .53134 .22356 .52435 .21488 Mtetra
.52435 .21488 .53134 .22356 .5443 .21887 .53735 .21015 Mtetra
.958 .617 .28 r
.53735 .21015 .5443 .21887 .55839 .31424 .55125 .30564 Mtetra
.656 .751 .919 r
.55125 .30564 .55839 .31424 .57191 .30959 .56481 .30095 Mtetra
.56481 .30095 .57191 .30959 .58549 .30492 .57844 .29623 Mtetra
.57844 .29623 .58549 .30492 .59914 .30022 .59214 .29149 Mtetra
.59214 .29149 .59914 .30022 .61286 .29551 .6059 .28673 Mtetra
.6059 .28673 .61286 .29551 .62665 .29076 .61973 .28195 Mtetra
.61973 .28195 .62665 .29076 .6405 .286 .63363 .27714 Mtetra
.63363 .27714 .6405 .286 .65442 .28121 .6476 .27231 Mtetra
.6476 .27231 .65442 .28121 .66841 .2764 .66164 .26745 Mtetra
.66164 .26745 .66841 .2764 .68247 .27156 .67574 .26257 Mtetra
.67574 .26257 .68247 .27156 .6966 .2667 .68992 .25766 Mtetra
.68992 .25766 .6966 .2667 .71081 .26181 .70417 .25273 Mtetra
.70417 .25273 .71081 .26181 .72508 .2569 .7185 .24777 Mtetra
.7185 .24777 .72508 .2569 .73942 .25197 .73289 .24279 Mtetra
.73289 .24279 .73942 .25197 .75384 .24701 .74736 .23779 Mtetra
.74736 .23779 .75384 .24701 .76833 .24202 .7619 .23276 Mtetra
.7619 .23276 .76833 .24202 .78289 .23701 .77652 .2277 Mtetra
.664 .741 .908 r
.13033 .34785 .13846 .35542 .1497 .35133 .1416 .34373 Mtetra
.1416 .34373 .1497 .35133 .16098 .34722 .15291 .33958 Mtetra
.15291 .33958 .16098 .34722 .17232 .34309 .16428 .33542 Mtetra
.16428 .33542 .17232 .34309 .18371 .33894 .17569 .33124 Mtetra
.17569 .33124 .18371 .33894 .19515 .33478 .18716 .32704 Mtetra
.18716 .32704 .19515 .33478 .20663 .33059 .19868 .32282 Mtetra
.19868 .32282 .20663 .33059 .21817 .32639 .21025 .31858 Mtetra
.21025 .31858 .21817 .32639 .22976 .32217 .22187 .31433 Mtetra
.22187 .31433 .22976 .32217 .24141 .31793 .23354 .31005 Mtetra
.23354 .31005 .24141 .31793 .2531 .31367 .24527 .30576 Mtetra
.24527 .30576 .2531 .31367 .26485 .30939 .25704 .30144 Mtetra
.25704 .30144 .26485 .30939 .27665 .30509 .26888 .29711 Mtetra
.26888 .29711 .27665 .30509 .2885 .30078 .28076 .29276 Mtetra
.28076 .29276 .2885 .30078 .30041 .29644 .2927 .28838 Mtetra
.2927 .28838 .30041 .29644 .31237 .29208 .3047 .28399 Mtetra
.3047 .28399 .31237 .29208 .32439 .28771 .31674 .27958 Mtetra
.31674 .27958 .32439 .28771 .33646 .28331 .32885 .27514 Mtetra
.32885 .27514 .33646 .28331 .34858 .2789 .34101 .27069 Mtetra
.34101 .27069 .34858 .2789 .36077 .27446 .35322 .26622 Mtetra
.35322 .26622 .36077 .27446 .373 .27 .36549 .26172 Mtetra
.36549 .26172 .373 .27 .3853 .26553 .37782 .25721 Mtetra
.37782 .25721 .3853 .26553 .39764 .26103 .39021 .25267 Mtetra
.39021 .25267 .39764 .26103 .41005 .25651 .40265 .24811 Mtetra
.40265 .24811 .41005 .25651 .42252 .25197 .41515 .24353 Mtetra
.41515 .24353 .42252 .25197 .43504 .24741 .42771 .23893 Mtetra
.42771 .23893 .43504 .24741 .44762 .24283 .44033 .23431 Mtetra
.44033 .23431 .44762 .24283 .46026 .23822 .453 .22967 Mtetra
.453 .22967 .46026 .23822 .47296 .2336 .46574 .225 Mtetra
.46574 .225 .47296 .2336 .48571 .22895 .47854 .22032 Mtetra
.47854 .22032 .48571 .22895 .49853 .22429 .49139 .21561 Mtetra
.49139 .21561 .49853 .22429 .51141 .2196 .50431 .21088 Mtetra
.50431 .21088 .51141 .2196 .52435 .21488 .51729 .20612 Mtetra
.51729 .20612 .52435 .21488 .53735 .21015 .53033 .20135 Mtetra
.958 .617 .28 r
.53033 .20135 .53735 .21015 .55125 .30564 .54405 .29696 Mtetra
.656 .751 .919 r
.54405 .29696 .55125 .30564 .56481 .30095 .55765 .29223 Mtetra
.55765 .29223 .56481 .30095 .57844 .29623 .57132 .28747 Mtetra
.57132 .28747 .57844 .29623 .59214 .29149 .58506 .28269 Mtetra
.58506 .28269 .59214 .29149 .6059 .28673 .59887 .27788 Mtetra
.59887 .27788 .6059 .28673 .61973 .28195 .61275 .27305 Mtetra
.61275 .27305 .61973 .28195 .63363 .27714 .62669 .2682 Mtetra
.62669 .2682 .63363 .27714 .6476 .27231 .64071 .26332 Mtetra
.64071 .26332 .6476 .27231 .66164 .26745 .6548 .25842 Mtetra
.6548 .25842 .66164 .26745 .67574 .26257 .66895 .25349 Mtetra
.66895 .25349 .67574 .26257 .68992 .25766 .68318 .24854 Mtetra
.68318 .24854 .68992 .25766 .70417 .25273 .69748 .24356 Mtetra
.69748 .24356 .70417 .25273 .7185 .24777 .71185 .23856 Mtetra
.71185 .23856 .7185 .24777 .73289 .24279 .7263 .23353 Mtetra
.7263 .23353 .73289 .24279 .74736 .23779 .74082 .22848 Mtetra
.74082 .22848 .74736 .23779 .7619 .23276 .75541 .2234 Mtetra
.75541 .2234 .7619 .23276 .77652 .2277 .77008 .21829 Mtetra
.664 .741 .908 r
.12213 .34022 .13033 .34785 .1416 .34373 .13343 .33606 Mtetra
.13343 .33606 .1416 .34373 .15291 .33958 .14477 .33188 Mtetra
.14477 .33188 .15291 .33958 .16428 .33542 .15616 .32769 Mtetra
.15616 .32769 .16428 .33542 .17569 .33124 .16761 .32347 Mtetra
.16761 .32347 .17569 .33124 .18716 .32704 .17911 .31924 Mtetra
.17911 .31924 .18716 .32704 .19868 .32282 .19065 .31498 Mtetra
.19065 .31498 .19868 .32282 .21025 .31858 .20225 .31071 Mtetra
.20225 .31071 .21025 .31858 .22187 .31433 .2139 .30642 Mtetra
.2139 .30642 .22187 .31433 .23354 .31005 .22561 .30211 Mtetra
.22561 .30211 .23354 .31005 .24527 .30576 .23736 .29778 Mtetra
.23736 .29778 .24527 .30576 .25704 .30144 .24917 .29343 Mtetra
.24917 .29343 .25704 .30144 .26888 .29711 .26104 .28906 Mtetra
.26104 .28906 .26888 .29711 .28076 .29276 .27296 .28467 Mtetra
.27296 .28467 .28076 .29276 .2927 .28838 .28493 .28026 Mtetra
.28493 .28026 .2927 .28838 .3047 .28399 .29695 .27583 Mtetra
.29695 .27583 .3047 .28399 .31674 .27958 .30904 .27138 Mtetra
.30904 .27138 .31674 .27958 .32885 .27514 .32117 .26691 Mtetra
.32117 .26691 .32885 .27514 .34101 .27069 .33337 .26241 Mtetra
.33337 .26241 .34101 .27069 .35322 .26622 .34562 .2579 Mtetra
.34562 .2579 .35322 .26622 .36549 .26172 .35792 .25337 Mtetra
.35792 .25337 .36549 .26172 .37782 .25721 .37029 .24881 Mtetra
.37029 .24881 .37782 .25721 .39021 .25267 .38271 .24424 Mtetra
.38271 .24424 .39021 .25267 .40265 .24811 .39519 .23964 Mtetra
.39519 .23964 .40265 .24811 .41515 .24353 .40772 .23502 Mtetra
.40772 .23502 .41515 .24353 .42771 .23893 .42032 .23039 Mtetra
.42032 .23039 .42771 .23893 .44033 .23431 .43297 .22572 Mtetra
.43297 .22572 .44033 .23431 .453 .22967 .44569 .22104 Mtetra
.44569 .22104 .453 .22967 .46574 .225 .45846 .21634 Mtetra
.45846 .21634 .46574 .225 .47854 .22032 .4713 .21161 Mtetra
.4713 .21161 .47854 .22032 .49139 .21561 .48419 .20686 Mtetra
.48419 .20686 .49139 .21561 .50431 .21088 .49715 .20209 Mtetra
.49715 .20209 .50431 .21088 .51729 .20612 .51017 .19729 Mtetra
.51017 .19729 .51729 .20612 .53033 .20135 .52325 .19247 Mtetra
.958 .617 .28 r
.52325 .19247 .53033 .20135 .54405 .29696 .53677 .2882 Mtetra
.656 .751 .919 r
.53677 .2882 .54405 .29696 .55765 .29223 .55042 .28342 Mtetra
.55042 .28342 .55765 .29223 .57132 .28747 .56414 .27862 Mtetra
.56414 .27862 .57132 .28747 .58506 .28269 .57793 .27379 Mtetra
.57793 .27379 .58506 .28269 .59887 .27788 .59178 .26894 Mtetra
.59178 .26894 .59887 .27788 .61275 .27305 .6057 .26407 Mtetra
.6057 .26407 .61275 .27305 .62669 .2682 .6197 .25917 Mtetra
.6197 .25917 .62669 .2682 .64071 .26332 .63376 .25425 Mtetra
.63376 .25425 .64071 .26332 .6548 .25842 .64789 .2493 Mtetra
.64789 .2493 .6548 .25842 .66895 .25349 .6621 .24433 Mtetra
.6621 .24433 .66895 .25349 .68318 .24854 .67638 .23933 Mtetra
.67638 .23933 .68318 .24854 .69748 .24356 .69073 .23431 Mtetra
.69073 .23431 .69748 .24356 .71185 .23856 .70515 .22926 Mtetra
.70515 .22926 .71185 .23856 .7263 .23353 .71965 .22418 Mtetra
.71965 .22418 .7263 .23353 .74082 .22848 .73422 .21908 Mtetra
.73422 .21908 .74082 .22848 .75541 .2234 .74886 .21395 Mtetra
.74886 .21395 .75541 .2234 .77008 .21829 .76358 .2088 Mtetra
.664 .741 .908 r
.11387 .33253 .12213 .34022 .13343 .33606 .12519 .32833 Mtetra
.12519 .32833 .13343 .33606 .14477 .33188 .13656 .32412 Mtetra
.13656 .32412 .14477 .33188 .15616 .32769 .14799 .31989 Mtetra
.14799 .31989 .15616 .32769 .16761 .32347 .15946 .31564 Mtetra
.15946 .31564 .16761 .32347 .17911 .31924 .17099 .31137 Mtetra
.17099 .31137 .17911 .31924 .19065 .31498 .18256 .30708 Mtetra
.18256 .30708 .19065 .31498 .20225 .31071 .19419 .30277 Mtetra
.19419 .30277 .20225 .31071 .2139 .30642 .20587 .29844 Mtetra
.20587 .29844 .2139 .30642 .22561 .30211 .21761 .2941 Mtetra
.21761 .2941 .22561 .30211 .23736 .29778 .2294 .28973 Mtetra
.2294 .28973 .23736 .29778 .24917 .29343 .24124 .28534 Mtetra
.24124 .28534 .24917 .29343 .26104 .28906 .25313 .28094 Mtetra
.25313 .28094 .26104 .28906 .27296 .28467 .26508 .27651 Mtetra
.26508 .27651 .27296 .28467 .28493 .28026 .27709 .27206 Mtetra
.27709 .27206 .28493 .28026 .29695 .27583 .28915 .26759 Mtetra
.28915 .26759 .29695 .27583 .30904 .27138 .30126 .26311 Mtetra
.30126 .26311 .30904 .27138 .32117 .26691 .31343 .2586 Mtetra
.31343 .2586 .32117 .26691 .33337 .26241 .32566 .25407 Mtetra
.32566 .25407 .33337 .26241 .34562 .2579 .33795 .24952 Mtetra
.33795 .24952 .34562 .2579 .35792 .25337 .35029 .24494 Mtetra
.35029 .24494 .35792 .25337 .37029 .24881 .36269 .24035 Mtetra
.36269 .24035 .37029 .24881 .38271 .24424 .37514 .23574 Mtetra
.37514 .23574 .38271 .24424 .39519 .23964 .38766 .2311 Mtetra
.38766 .2311 .39519 .23964 .40772 .23502 .40023 .22644 Mtetra
.40023 .22644 .40772 .23502 .42032 .23039 .41286 .22176 Mtetra
.41286 .22176 .42032 .23039 .43297 .22572 .42556 .21706 Mtetra
.42556 .21706 .43297 .22572 .44569 .22104 .43831 .21234 Mtetra
.43831 .21234 .44569 .22104 .45846 .21634 .45112 .20759 Mtetra
.45112 .20759 .45846 .21634 .4713 .21161 .46399 .20282 Mtetra
.46399 .20282 .4713 .21161 .48419 .20686 .47693 .19803 Mtetra
.47693 .19803 .48419 .20686 .49715 .20209 .48993 .19321 Mtetra
.48993 .19321 .49715 .20209 .51017 .19729 .50298 .18838 Mtetra
.50298 .18838 .51017 .19729 .52325 .19247 .5161 .18352 Mtetra
.958 .617 .28 r
.5161 .18352 .52325 .19247 .53677 .2882 .52944 .27936 Mtetra
.656 .751 .919 r
.52944 .27936 .53677 .2882 .55042 .28342 .54313 .27454 Mtetra
.54313 .27454 .55042 .28342 .56414 .27862 .55689 .26969 Mtetra
.55689 .26969 .56414 .27862 .57793 .27379 .57072 .26482 Mtetra
.57072 .26482 .57793 .27379 .59178 .26894 .58462 .25993 Mtetra
.58462 .25993 .59178 .26894 .6057 .26407 .59859 .25501 Mtetra
.59859 .25501 .6057 .26407 .6197 .25917 .61263 .25006 Mtetra
.61263 .25006 .6197 .25917 .63376 .25425 .62674 .24509 Mtetra
.62674 .24509 .63376 .25425 .64789 .2493 .64093 .2401 Mtetra
.64093 .2401 .64789 .2493 .6621 .24433 .65518 .23508 Mtetra
.65518 .23508 .6621 .24433 .67638 .23933 .66951 .23004 Mtetra
.66951 .23004 .67638 .23933 .69073 .23431 .68391 .22496 Mtetra
.68391 .22496 .69073 .23431 .70515 .22926 .69838 .21987 Mtetra
.69838 .21987 .70515 .22926 .71965 .22418 .71293 .21474 Mtetra
.71293 .21474 .71965 .22418 .73422 .21908 .72755 .20959 Mtetra
.72755 .20959 .73422 .21908 .74886 .21395 .74225 .20442 Mtetra
.74225 .20442 .74886 .21395 .76358 .2088 .75702 .19922 Mtetra
.664 .741 .908 r
.10554 .32477 .11387 .33253 .12519 .32833 .11689 .32054 Mtetra
.11689 .32054 .12519 .32833 .13656 .32412 .12829 .31629 Mtetra
.12829 .31629 .13656 .32412 .14799 .31989 .13974 .31203 Mtetra
.13974 .31203 .14799 .31989 .15946 .31564 .15124 .30774 Mtetra
.15124 .30774 .15946 .31564 .17099 .31137 .1628 .30344 Mtetra
.1628 .30344 .17099 .31137 .18256 .30708 .1744 .29911 Mtetra
.1744 .29911 .18256 .30708 .19419 .30277 .18606 .29477 Mtetra
.18606 .29477 .19419 .30277 .20587 .29844 .19778 .2904 Mtetra
.19778 .2904 .20587 .29844 .21761 .2941 .20954 .28602 Mtetra
.20954 .28602 .21761 .2941 .2294 .28973 .22136 .28162 Mtetra
.22136 .28162 .2294 .28973 .24124 .28534 .23323 .27719 Mtetra
.23323 .27719 .24124 .28534 .25313 .28094 .24516 .27275 Mtetra
.24516 .27275 .25313 .28094 .26508 .27651 .25714 .26828 Mtetra
.25714 .26828 .26508 .27651 .27709 .27206 .26918 .2638 Mtetra
.26918 .2638 .27709 .27206 .28915 .26759 .28127 .25929 Mtetra
.28127 .25929 .28915 .26759 .30126 .26311 .29342 .25477 Mtetra
.29342 .25477 .30126 .26311 .31343 .2586 .30563 .25022 Mtetra
.30563 .25022 .31343 .2586 .32566 .25407 .31789 .24565 Mtetra
.31789 .24565 .32566 .25407 .33795 .24952 .33021 .24106 Mtetra
.33021 .24106 .33795 .24952 .35029 .24494 .34259 .23645 Mtetra
.34259 .23645 .35029 .24494 .36269 .24035 .35502 .23182 Mtetra
.35502 .23182 .36269 .24035 .37514 .23574 .36751 .22716 Mtetra
.36751 .22716 .37514 .23574 .38766 .2311 .38006 .22248 Mtetra
.38006 .22248 .38766 .2311 .40023 .22644 .39267 .21779 Mtetra
.39267 .21779 .40023 .22644 .41286 .22176 .40534 .21306 Mtetra
.40534 .21306 .41286 .22176 .42556 .21706 .41807 .20832 Mtetra
.41807 .20832 .42556 .21706 .43831 .21234 .43086 .20356 Mtetra
.43086 .20356 .43831 .21234 .45112 .20759 .44372 .19877 Mtetra
.44372 .19877 .45112 .20759 .46399 .20282 .45663 .19396 Mtetra
.45663 .19396 .46399 .20282 .47693 .19803 .4696 .18912 Mtetra
.4696 .18912 .47693 .19803 .48993 .19321 .48264 .18427 Mtetra
.48264 .18427 .48993 .19321 .50298 .18838 .49574 .17939 Mtetra
.49574 .17939 .50298 .18838 .5161 .18352 .5089 .17448 Mtetra
.958 .617 .28 r
.5089 .17448 .5161 .18352 .52944 .27936 .52203 .27044 Mtetra
.656 .751 .919 r
.52203 .27044 .52944 .27936 .54313 .27454 .53577 .26557 Mtetra
.53577 .26557 .54313 .27454 .55689 .26969 .54958 .26068 Mtetra
.54958 .26068 .55689 .26969 .57072 .26482 .56345 .25577 Mtetra
.56345 .25577 .57072 .26482 .58462 .25993 .5774 .25083 Mtetra
.5774 .25083 .58462 .25993 .59859 .25501 .59141 .24586 Mtetra
.59141 .24586 .59859 .25501 .61263 .25006 .6055 .24087 Mtetra
.6055 .24087 .61263 .25006 .62674 .24509 .61966 .23585 Mtetra
.61966 .23585 .62674 .24509 .64093 .2401 .63389 .23081 Mtetra
.63389 .23081 .64093 .2401 .65518 .23508 .6482 .22575 Mtetra
.6482 .22575 .65518 .23508 .66951 .23004 .66257 .22065 Mtetra
.66257 .22065 .66951 .23004 .68391 .22496 .67702 .21553 Mtetra
.67702 .21553 .68391 .22496 .69838 .21987 .69155 .21039 Mtetra
.69155 .21039 .69838 .21987 .71293 .21474 .70615 .20522 Mtetra
.70615 .20522 .71293 .21474 .72755 .20959 .72082 .20002 Mtetra
.72082 .20002 .72755 .20959 .74225 .20442 .73557 .19479 Mtetra
.73557 .19479 .74225 .20442 .75702 .19922 .7504 .18954 Mtetra
.664 .741 .908 r
.09714 .31695 .10554 .32477 .11689 .32054 .10852 .31268 Mtetra
.10852 .31268 .11689 .32054 .12829 .31629 .11995 .3084 Mtetra
.11995 .3084 .12829 .31629 .13974 .31203 .13143 .3041 Mtetra
.13143 .3041 .13974 .31203 .15124 .30774 .14296 .29978 Mtetra
.14296 .29978 .15124 .30774 .1628 .30344 .15454 .29544 Mtetra
.15454 .29544 .1628 .30344 .1744 .29911 .16618 .29108 Mtetra
.16618 .29108 .1744 .29911 .18606 .29477 .17787 .28669 Mtetra
.17787 .28669 .18606 .29477 .19778 .2904 .18961 .28229 Mtetra
.18961 .28229 .19778 .2904 .20954 .28602 .20141 .27787 Mtetra
.20141 .27787 .20954 .28602 .22136 .28162 .21326 .27343 Mtetra
.21326 .27343 .22136 .28162 .23323 .27719 .22516 .26897 Mtetra
.22516 .26897 .23323 .27719 .24516 .27275 .23712 .26449 Mtetra
.23712 .26449 .24516 .27275 .25714 .26828 .24914 .25999 Mtetra
.24914 .25999 .25714 .26828 .26918 .2638 .26121 .25546 Mtetra
.26121 .25546 .26918 .2638 .28127 .25929 .27333 .25092 Mtetra
.27333 .25092 .28127 .25929 .29342 .25477 .28552 .24635 Mtetra
.28552 .24635 .29342 .25477 .30563 .25022 .29776 .24177 Mtetra
.29776 .24177 .30563 .25022 .31789 .24565 .31005 .23716 Mtetra
.31005 .23716 .31789 .24565 .33021 .24106 .32241 .23253 Mtetra
.32241 .23253 .33021 .24106 .34259 .23645 .33482 .22788 Mtetra
.33482 .22788 .34259 .23645 .35502 .23182 .34729 .2232 Mtetra
.34729 .2232 .35502 .23182 .36751 .22716 .35982 .21851 Mtetra
.35982 .21851 .36751 .22716 .38006 .22248 .3724 .21379 Mtetra
.3724 .21379 .38006 .22248 .39267 .21779 .38505 .20905 Mtetra
.38505 .20905 .39267 .21779 .40534 .21306 .39776 .20429 Mtetra
.39776 .20429 .40534 .21306 .41807 .20832 .41053 .19951 Mtetra
.41053 .19951 .41807 .20832 .43086 .20356 .42335 .1947 Mtetra
.42335 .1947 .43086 .20356 .44372 .19877 .43624 .18987 Mtetra
.43624 .18987 .44372 .19877 .45663 .19396 .4492 .18501 Mtetra
.4492 .18501 .45663 .19396 .4696 .18912 .46221 .18014 Mtetra
.46221 .18014 .4696 .18912 .48264 .18427 .47529 .17524 Mtetra
.47529 .17524 .48264 .18427 .49574 .17939 .48843 .17031 Mtetra
.48843 .17031 .49574 .17939 .5089 .17448 .50163 .16537 Mtetra
.958 .617 .28 r
.50163 .16537 .5089 .17448 .52203 .27044 .51456 .26144 Mtetra
.656 .751 .919 r
.51456 .26144 .52203 .27044 .53577 .26557 .52834 .25652 Mtetra
.52834 .25652 .53577 .26557 .54958 .26068 .54219 .25159 Mtetra
.54219 .25159 .54958 .26068 .56345 .25577 .55611 .24663 Mtetra
.55611 .24663 .56345 .25577 .5774 .25083 .57011 .24164 Mtetra
.57011 .24164 .5774 .25083 .59141 .24586 .58417 .23663 Mtetra
.58417 .23663 .59141 .24586 .6055 .24087 .59831 .23159 Mtetra
.59831 .23159 .6055 .24087 .61966 .23585 .61251 .22653 Mtetra
.61251 .22653 .61966 .23585 .63389 .23081 .62679 .22144 Mtetra
.62679 .22144 .63389 .23081 .6482 .22575 .64115 .21632 Mtetra
.64115 .21632 .6482 .22575 .66257 .22065 .65557 .21118 Mtetra
.65557 .21118 .66257 .22065 .67702 .21553 .67007 .20601 Mtetra
.67007 .20601 .67702 .21553 .69155 .21039 .68465 .20082 Mtetra
.68465 .20082 .69155 .21039 .70615 .20522 .6993 .1956 Mtetra
.6993 .1956 .70615 .20522 .72082 .20002 .71403 .19035 Mtetra
.71403 .19035 .72082 .20002 .73557 .19479 .72883 .18507 Mtetra
.72883 .18507 .73557 .19479 .7504 .18954 .74372 .17977 Mtetra
.664 .741 .908 r
.08867 .30906 .09714 .31695 .10852 .31268 .10008 .30476 Mtetra
.10008 .30476 .10852 .31268 .11995 .3084 .11153 .30044 Mtetra
.11153 .30044 .11995 .3084 .13143 .3041 .12304 .29611 Mtetra
.12304 .29611 .13143 .3041 .14296 .29978 .1346 .29175 Mtetra
.1346 .29175 .14296 .29978 .15454 .29544 .14622 .28737 Mtetra
.14622 .28737 .15454 .29544 .16618 .29108 .15788 .28297 Mtetra
.15788 .28297 .16618 .29108 .17787 .28669 .1696 .27855 Mtetra
.1696 .27855 .17787 .28669 .18961 .28229 .18138 .27412 Mtetra
.18138 .27412 .18961 .28229 .20141 .27787 .1932 .26966 Mtetra
.1932 .26966 .20141 .27787 .21326 .27343 .20509 .26518 Mtetra
.20509 .26518 .21326 .27343 .22516 .26897 .21702 .26068 Mtetra
.21702 .26068 .22516 .26897 .23712 .26449 .22901 .25616 Mtetra
.22901 .25616 .23712 .26449 .24914 .25999 .24106 .25162 Mtetra
.24106 .25162 .24914 .25999 .26121 .25546 .25317 .24706 Mtetra
.25317 .24706 .26121 .25546 .27333 .25092 .26532 .24247 Mtetra
.26532 .24247 .27333 .25092 .28552 .24635 .27754 .23787 Mtetra
.27754 .23787 .28552 .24635 .29776 .24177 .28981 .23324 Mtetra
.28981 .23324 .29776 .24177 .31005 .23716 .30215 .22859 Mtetra
.30215 .22859 .31005 .23716 .32241 .23253 .31453 .22393 Mtetra
.31453 .22393 .32241 .23253 .33482 .22788 .32698 .21923 Mtetra
.32698 .21923 .33482 .22788 .34729 .2232 .33949 .21452 Mtetra
.33949 .21452 .34729 .2232 .35982 .21851 .35205 .20978 Mtetra
.35205 .20978 .35982 .21851 .3724 .21379 .36468 .20502 Mtetra
.36468 .20502 .3724 .21379 .38505 .20905 .37736 .20024 Mtetra
.37736 .20024 .38505 .20905 .39776 .20429 .39011 .19544 Mtetra
.39011 .19544 .39776 .20429 .41053 .19951 .40291 .19061 Mtetra
.40291 .19061 .41053 .19951 .42335 .1947 .41578 .18576 Mtetra
.41578 .18576 .42335 .1947 .43624 .18987 .42871 .18089 Mtetra
.42871 .18089 .43624 .18987 .4492 .18501 .4417 .17599 Mtetra
.4417 .17599 .4492 .18501 .46221 .18014 .45475 .17107 Mtetra
.45475 .17107 .46221 .18014 .47529 .17524 .46787 .16613 Mtetra
.46787 .16613 .47529 .17524 .48843 .17031 .48105 .16116 Mtetra
.48105 .16116 .48843 .17031 .50163 .16537 .49429 .15617 Mtetra
.958 .617 .28 r
.49429 .15617 .50163 .16537 .51456 .26144 .50701 .25235 Mtetra
.656 .751 .919 r
.50701 .25235 .51456 .26144 .52834 .25652 .52084 .24739 Mtetra
.52084 .24739 .52834 .25652 .54219 .25159 .53474 .24241 Mtetra
.53474 .24241 .54219 .25159 .55611 .24663 .54871 .2374 Mtetra
.54871 .2374 .55611 .24663 .57011 .24164 .56275 .23237 Mtetra
.56275 .23237 .57011 .24164 .58417 .23663 .57686 .22731 Mtetra
.57686 .22731 .58417 .23663 .59831 .23159 .59104 .22222 Mtetra
.59104 .22222 .59831 .23159 .61251 .22653 .6053 .21711 Mtetra
.6053 .21711 .61251 .22653 .62679 .22144 .61963 .21197 Mtetra
.61963 .21197 .62679 .22144 .64115 .21632 .63403 .20681 Mtetra
.63403 .20681 .64115 .21632 .65557 .21118 .64851 .20162 Mtetra
.64851 .20162 .65557 .21118 .67007 .20601 .66306 .1964 Mtetra
.66306 .1964 .67007 .20601 .68465 .20082 .67769 .19116 Mtetra
.67769 .19116 .68465 .20082 .6993 .1956 .69239 .18589 Mtetra
.69239 .18589 .6993 .1956 .71403 .19035 .70717 .18059 Mtetra
.70717 .18059 .71403 .19035 .72883 .18507 .72203 .17526 Mtetra
.72203 .17526 .72883 .18507 .74372 .17977 .73696 .16991 Mtetra
.664 .741 .908 r
.08013 .30111 .08867 .30906 .10008 .30476 .09156 .29677 Mtetra
.09156 .29677 .10008 .30476 .11153 .30044 .10305 .29242 Mtetra
.10305 .29242 .11153 .30044 .12304 .29611 .11459 .28804 Mtetra
.11459 .28804 .12304 .29611 .1346 .29175 .12618 .28365 Mtetra
.12618 .28365 .1346 .29175 .14622 .28737 .13782 .27924 Mtetra
.13782 .27924 .14622 .28737 .15788 .28297 .14952 .2748 Mtetra
.14952 .2748 .15788 .28297 .1696 .27855 .16127 .27035 Mtetra
.16127 .27035 .1696 .27855 .18138 .27412 .17307 .26587 Mtetra
.17307 .26587 .18138 .27412 .1932 .26966 .18493 .26137 Mtetra
.18493 .26137 .1932 .26966 .20509 .26518 .19684 .25686 Mtetra
.19684 .25686 .20509 .26518 .21702 .26068 .20881 .25232 Mtetra
.20881 .25232 .21702 .26068 .22901 .25616 .22084 .24776 Mtetra
.22084 .24776 .22901 .25616 .24106 .25162 .23292 .24318 Mtetra
.23292 .24318 .24106 .25162 .25317 .24706 .24505 .23858 Mtetra
.24505 .23858 .25317 .24706 .26532 .24247 .25725 .23396 Mtetra
.25725 .23396 .26532 .24247 .27754 .23787 .2695 .22931 Mtetra
.2695 .22931 .27754 .23787 .28981 .23324 .2818 .22464 Mtetra
.2818 .22464 .28981 .23324 .30215 .22859 .29417 .21996 Mtetra
.29417 .21996 .30215 .22859 .31453 .22393 .30659 .21525 Mtetra
.30659 .21525 .31453 .22393 .32698 .21923 .31908 .21051 Mtetra
.31908 .21051 .32698 .21923 .33949 .21452 .33162 .20576 Mtetra
.33162 .20576 .33949 .21452 .35205 .20978 .34422 .20098 Mtetra
.34422 .20098 .35205 .20978 .36468 .20502 .35688 .19618 Mtetra
.35688 .19618 .36468 .20502 .37736 .20024 .3696 .19136 Mtetra
.3696 .19136 .37736 .20024 .39011 .19544 .38239 .18651 Mtetra
.38239 .18651 .39011 .19544 .40291 .19061 .39523 .18164 Mtetra
.39523 .18164 .40291 .19061 .41578 .18576 .40813 .17675 Mtetra
.40813 .17675 .41578 .18576 .42871 .18089 .4211 .17183 Mtetra
.4211 .17183 .42871 .18089 .4417 .17599 .43413 .16689 Mtetra
.43413 .16689 .4417 .17599 .45475 .17107 .44723 .16193 Mtetra
.44723 .16193 .45475 .17107 .46787 .16613 .46038 .15694 Mtetra
.46038 .15694 .46787 .16613 .48105 .16116 .4736 .15192 Mtetra
.4736 .15192 .48105 .16116 .49429 .15617 .48689 .14689 Mtetra
.958 .617 .28 r
.48689 .14689 .49429 .15617 .50701 .25235 .4994 .24318 Mtetra
.656 .751 .919 r
.4994 .24318 .50701 .25235 .52084 .24739 .51327 .23817 Mtetra
.51327 .23817 .52084 .24739 .53474 .24241 .52722 .23314 Mtetra
.52722 .23314 .53474 .24241 .54871 .2374 .54123 .22809 Mtetra
.54123 .22809 .54871 .2374 .56275 .23237 .55532 .22301 Mtetra
.55532 .22301 .56275 .23237 .57686 .22731 .56948 .2179 Mtetra
.56948 .2179 .57686 .22731 .59104 .22222 .58371 .21277 Mtetra
.58371 .21277 .59104 .22222 .6053 .21711 .59801 .20761 Mtetra
.59801 .20761 .6053 .21711 .61963 .21197 .61239 .20242 Mtetra
.61239 .20242 .61963 .21197 .63403 .20681 .62684 .19721 Mtetra
.62684 .19721 .63403 .20681 .64851 .20162 .64137 .19197 Mtetra
.64137 .19197 .64851 .20162 .66306 .1964 .65598 .1867 Mtetra
.65598 .1867 .66306 .1964 .67769 .19116 .67066 .18141 Mtetra
.67066 .18141 .67769 .19116 .69239 .18589 .68541 .17608 Mtetra
.68541 .17608 .69239 .18589 .70717 .18059 .70025 .17073 Mtetra
.70025 .17073 .70717 .18059 .72203 .17526 .71516 .16535 Mtetra
.71516 .16535 .72203 .17526 .73696 .16991 .73015 .15995 Mtetra
.664 .741 .908 r
.07152 .29309 .08013 .30111 .09156 .29677 .08298 .28872 Mtetra
.08298 .28872 .09156 .29677 .10305 .29242 .09449 .28433 Mtetra
.09449 .28433 .10305 .29242 .11459 .28804 .10606 .27992 Mtetra
.10606 .27992 .11459 .28804 .12618 .28365 .11768 .27548 Mtetra
.11768 .27548 .12618 .28365 .13782 .27924 .12935 .27103 Mtetra
.12935 .27103 .13782 .27924 .14952 .2748 .14108 .26656 Mtetra
.14108 .26656 .14952 .2748 .16127 .27035 .15286 .26207 Mtetra
.15286 .26207 .16127 .27035 .17307 .26587 .1647 .25755 Mtetra
.1647 .25755 .17307 .26587 .18493 .26137 .17659 .25302 Mtetra
.17659 .25302 .18493 .26137 .19684 .25686 .18853 .24846 Mtetra
.18853 .24846 .19684 .25686 .20881 .25232 .20053 .24389 Mtetra
.20053 .24389 .20881 .25232 .22084 .24776 .21259 .23929 Mtetra
.21259 .23929 .22084 .24776 .23292 .24318 .2247 .23467 Mtetra
.2247 .23467 .23292 .24318 .24505 .23858 .23687 .23003 Mtetra
.23687 .23003 .24505 .23858 .25725 .23396 .2491 .22536 Mtetra
.2491 .22536 .25725 .23396 .2695 .22931 .26138 .22068 Mtetra
.26138 .22068 .2695 .22931 .2818 .22464 .27373 .21597 Mtetra
.27373 .21597 .2818 .22464 .29417 .21996 .28613 .21124 Mtetra
.28613 .21124 .29417 .21996 .30659 .21525 .29858 .20649 Mtetra
.29858 .20649 .30659 .21525 .31908 .21051 .3111 .20172 Mtetra
.3111 .20172 .31908 .21051 .33162 .20576 .32368 .19692 Mtetra
.32368 .19692 .33162 .20576 .34422 .20098 .33632 .1921 Mtetra
.33632 .1921 .34422 .20098 .35688 .19618 .34902 .18726 Mtetra
.34902 .18726 .35688 .19618 .3696 .19136 .36178 .18239 Mtetra
.36178 .18239 .3696 .19136 .38239 .18651 .3746 .1775 Mtetra
.3746 .1775 .38239 .18651 .39523 .18164 .38748 .17259 Mtetra
.38748 .17259 .39523 .18164 .40813 .17675 .40042 .16765 Mtetra
.40042 .16765 .40813 .17675 .4211 .17183 .41343 .16269 Mtetra
.41343 .16269 .4211 .17183 .43413 .16689 .4265 .15771 Mtetra
.4265 .15771 .43413 .16689 .44723 .16193 .43963 .1527 Mtetra
.43963 .1527 .44723 .16193 .46038 .15694 .45283 .14766 Mtetra
.45283 .14766 .46038 .15694 .4736 .15192 .46609 .14261 Mtetra
.46609 .14261 .4736 .15192 .48689 .14689 .47942 .13752 Mtetra
.958 .617 .28 r
.47942 .13752 .48689 .14689 .4994 .24318 .49171 .23392 Mtetra
.656 .751 .919 r
.49171 .23392 .4994 .24318 .51327 .23817 .50563 .22887 Mtetra
.50563 .22887 .51327 .23817 .52722 .23314 .51962 .22379 Mtetra
.51962 .22379 .52722 .23314 .54123 .22809 .53368 .21869 Mtetra
.53368 .21869 .54123 .22809 .55532 .22301 .54782 .21356 Mtetra
.54782 .21356 .55532 .22301 .56948 .2179 .56202 .2084 Mtetra
.56202 .2084 .56948 .2179 .58371 .21277 .5763 .20322 Mtetra
.5763 .20322 .58371 .21277 .59801 .20761 .59066 .19801 Mtetra
.59066 .19801 .59801 .20761 .61239 .20242 .60509 .19278 Mtetra
.60509 .19278 .61239 .20242 .62684 .19721 .61959 .18751 Mtetra
.61959 .18751 .62684 .19721 .64137 .19197 .63417 .18222 Mtetra
.63417 .18222 .64137 .19197 .65598 .1867 .64882 .1769 Mtetra
.64882 .1769 .65598 .1867 .67066 .18141 .66356 .17156 Mtetra
.66356 .17156 .67066 .18141 .68541 .17608 .67837 .16618 Mtetra
.67837 .16618 .68541 .17608 .70025 .17073 .69325 .16078 Mtetra
.69325 .16078 .70025 .17073 .71516 .16535 .70822 .15535 Mtetra
.70822 .15535 .71516 .16535 .73015 .15995 .72326 .14989 Mtetra
.664 .741 .908 r
.06283 .285 .07152 .29309 .08298 .28872 .07432 .2806 Mtetra
.07432 .2806 .08298 .28872 .09449 .28433 .08587 .27617 Mtetra
.08587 .27617 .09449 .28433 .10606 .27992 .09746 .27172 Mtetra
.09746 .27172 .10606 .27992 .11768 .27548 .10911 .26725 Mtetra
.10911 .26725 .11768 .27548 .12935 .27103 .12082 .26276 Mtetra
.12082 .26276 .12935 .27103 .14108 .26656 .13257 .25825 Mtetra
.13257 .25825 .14108 .26656 .15286 .26207 .14438 .25372 Mtetra
.14438 .25372 .15286 .26207 .1647 .25755 .15625 .24917 Mtetra
.15625 .24917 .1647 .25755 .17659 .25302 .16817 .24459 Mtetra
.16817 .24459 .17659 .25302 .18853 .24846 .18015 .24 Mtetra
.18015 .24 .18853 .24846 .20053 .24389 .19218 .23538 Mtetra
.19218 .23538 .20053 .24389 .21259 .23929 .20427 .23074 Mtetra
.20427 .23074 .21259 .23929 .2247 .23467 .21642 .22608 Mtetra
.21642 .22608 .2247 .23467 .23687 .23003 .22862 .2214 Mtetra
.22862 .2214 .23687 .23003 .2491 .22536 .24088 .2167 Mtetra
.24088 .2167 .2491 .22536 .26138 .22068 .2532 .21197 Mtetra
.2532 .21197 .26138 .22068 .27373 .21597 .26558 .20722 Mtetra
.26558 .20722 .27373 .21597 .28613 .21124 .27801 .20245 Mtetra
.27801 .20245 .28613 .21124 .29858 .20649 .29051 .19766 Mtetra
.29051 .19766 .29858 .20649 .3111 .20172 .30306 .19284 Mtetra
.30306 .19284 .3111 .20172 .32368 .19692 .31567 .188 Mtetra
.31567 .188 .32368 .19692 .33632 .1921 .32835 .18314 Mtetra
.32835 .18314 .33632 .1921 .34902 .18726 .34108 .17826 Mtetra
.34108 .17826 .34902 .18726 .36178 .18239 .35388 .17335 Mtetra
.35388 .17335 .36178 .18239 .3746 .1775 .36674 .16841 Mtetra
.36674 .16841 .3746 .1775 .38748 .17259 .37966 .16346 Mtetra
.37966 .16346 .38748 .17259 .40042 .16765 .39264 .15847 Mtetra
.39264 .15847 .40042 .16765 .41343 .16269 .40569 .15347 Mtetra
.40569 .15347 .41343 .16269 .4265 .15771 .4188 .14844 Mtetra
.4188 .14844 .4265 .15771 .43963 .1527 .43197 .14339 Mtetra
.43197 .14339 .43963 .1527 .45283 .14766 .44521 .13831 Mtetra
.44521 .13831 .45283 .14766 .46609 .14261 .45852 .1332 Mtetra
.45852 .1332 .46609 .14261 .47942 .13752 .47188 .12807 Mtetra
.958 .617 .28 r
.47188 .12807 .47942 .13752 .49171 .23392 .48395 .22457 Mtetra
.656 .751 .919 r
.48395 .22457 .49171 .23392 .50563 .22887 .49792 .21947 Mtetra
.49792 .21947 .50563 .22887 .51962 .22379 .51196 .21435 Mtetra
.51196 .21435 .51962 .22379 .53368 .21869 .52607 .2092 Mtetra
.52607 .2092 .53368 .21869 .54782 .21356 .54025 .20402 Mtetra
.54025 .20402 .54782 .21356 .56202 .2084 .5545 .19881 Mtetra
.5545 .19881 .56202 .2084 .5763 .20322 .56883 .19358 Mtetra
.56883 .19358 .5763 .20322 .59066 .19801 .58323 .18832 Mtetra
.58323 .18832 .59066 .19801 .60509 .19278 .59771 .18304 Mtetra
.59771 .18304 .60509 .19278 .61959 .18751 .61227 .17772 Mtetra
.61227 .17772 .61959 .18751 .63417 .18222 .6269 .17238 Mtetra
.6269 .17238 .63417 .18222 .64882 .1769 .6416 .16701 Mtetra
.6416 .16701 .64882 .1769 .66356 .17156 .65639 .16161 Mtetra
.65639 .16161 .66356 .17156 .67837 .16618 .67125 .15619 Mtetra
.67125 .15619 .67837 .16618 .69325 .16078 .68619 .15073 Mtetra
.68619 .15073 .69325 .16078 .70822 .15535 .70121 .14525 Mtetra
.70121 .14525 .70822 .15535 .72326 .14989 .71631 .13973 Mtetra
.664 .741 .908 r
.05408 .27685 .06283 .285 .07432 .2806 .06559 .2724 Mtetra
.06559 .2724 .07432 .2806 .08587 .27617 .07717 .26794 Mtetra
.07717 .26794 .08587 .27617 .09746 .27172 .08879 .26345 Mtetra
.08879 .26345 .09746 .27172 .10911 .26725 .10047 .25894 Mtetra
.10047 .25894 .10911 .26725 .12082 .26276 .1122 .25442 Mtetra
.1122 .25442 .12082 .26276 .13257 .25825 .12399 .24987 Mtetra
.12399 .24987 .13257 .25825 .14438 .25372 .13583 .2453 Mtetra
.13583 .2453 .14438 .25372 .15625 .24917 .14773 .24071 Mtetra
.14773 .24071 .15625 .24917 .16817 .24459 .15968 .23609 Mtetra
.15968 .23609 .16817 .24459 .18015 .24 .17169 .23146 Mtetra
.17169 .23146 .18015 .24 .19218 .23538 .18376 .2268 Mtetra
.18376 .2268 .19218 .23538 .20427 .23074 .19588 .22212 Mtetra
.19588 .22212 .20427 .23074 .21642 .22608 .20806 .21742 Mtetra
.20806 .21742 .21642 .22608 .22862 .2214 .2203 .2127 Mtetra
.2203 .2127 .22862 .2214 .24088 .2167 .23259 .20796 Mtetra
.23259 .20796 .24088 .2167 .2532 .21197 .24494 .20319 Mtetra
.24494 .20319 .2532 .21197 .26558 .20722 .25735 .1984 Mtetra
.25735 .1984 .26558 .20722 .27801 .20245 .26982 .19359 Mtetra
.26982 .19359 .27801 .20245 .29051 .19766 .28235 .18875 Mtetra
.28235 .18875 .29051 .19766 .30306 .19284 .29494 .18389 Mtetra
.29494 .18389 .30306 .19284 .31567 .188 .30759 .17901 Mtetra
.30759 .17901 .31567 .188 .32835 .18314 .32031 .1741 Mtetra
.32031 .1741 .32835 .18314 .34108 .17826 .33308 .16917 Mtetra
.33308 .16917 .34108 .17826 .35388 .17335 .34591 .16422 Mtetra
.34591 .16422 .35388 .17335 .36674 .16841 .35881 .15924 Mtetra
.35881 .15924 .36674 .16841 .37966 .16346 .37177 .15424 Mtetra
.37177 .15424 .37966 .16346 .39264 .15847 .38479 .14922 Mtetra
.38479 .14922 .39264 .15847 .40569 .15347 .39788 .14417 Mtetra
.39788 .14417 .40569 .15347 .4188 .14844 .41103 .13909 Mtetra
.41103 .13909 .4188 .14844 .43197 .14339 .42424 .13399 Mtetra
.42424 .13399 .43197 .14339 .44521 .13831 .43752 .12886 Mtetra
.43752 .12886 .44521 .13831 .45852 .1332 .45087 .12371 Mtetra
.45087 .12371 .45852 .1332 .47188 .12807 .46428 .11854 Mtetra
.958 .617 .28 r
.46428 .11854 .47188 .12807 .48395 .22457 .47612 .21514 Mtetra
.656 .751 .919 r
.47612 .21514 .48395 .22457 .49792 .21947 .49013 .20999 Mtetra
.49013 .20999 .49792 .21947 .51196 .21435 .50422 .20482 Mtetra
.50422 .20482 .51196 .21435 .52607 .2092 .51837 .19962 Mtetra
.51837 .19962 .52607 .2092 .54025 .20402 .5326 .19439 Mtetra
.5326 .19439 .54025 .20402 .5545 .19881 .54691 .18913 Mtetra
.54691 .18913 .5545 .19881 .56883 .19358 .56129 .18385 Mtetra
.56129 .18385 .56883 .19358 .58323 .18832 .57574 .17854 Mtetra
.57574 .17854 .58323 .18832 .59771 .18304 .59027 .17321 Mtetra
.59027 .17321 .59771 .18304 .61227 .17772 .60487 .16784 Mtetra
.60487 .16784 .61227 .17772 .6269 .17238 .61955 .16245 Mtetra
.61955 .16245 .6269 .17238 .6416 .16701 .63431 .15702 Mtetra
.63431 .15702 .6416 .16701 .65639 .16161 .64915 .15157 Mtetra
.64915 .15157 .65639 .16161 .67125 .15619 .66407 .14609 Mtetra
.66407 .14609 .67125 .15619 .68619 .15073 .67906 .14058 Mtetra
.67906 .14058 .68619 .15073 .70121 .14525 .69414 .13505 Mtetra
.69414 .13505 .70121 .14525 .71631 .13973 .70929 .12948 Mtetra
.664 .741 .908 r
.04524 .26863 .05408 .27685 .06559 .2724 .05679 .26414 Mtetra
.05679 .26414 .06559 .2724 .07717 .26794 .06839 .25964 Mtetra
.06839 .25964 .07717 .26794 .08879 .26345 .08005 .25511 Mtetra
.08005 .25511 .08879 .26345 .10047 .25894 .09176 .25057 Mtetra
.09176 .25057 .10047 .25894 .1122 .25442 .10352 .246 Mtetra
.10352 .246 .1122 .25442 .12399 .24987 .11534 .24141 Mtetra
.11534 .24141 .12399 .24987 .13583 .2453 .12721 .2368 Mtetra
.12721 .2368 .13583 .2453 .14773 .24071 .13914 .23217 Mtetra
.13914 .23217 .14773 .24071 .15968 .23609 .15112 .22752 Mtetra
.15112 .22752 .15968 .23609 .17169 .23146 .16316 .22284 Mtetra
.16316 .22284 .17169 .23146 .18376 .2268 .17526 .21815 Mtetra
.17526 .21815 .18376 .2268 .19588 .22212 .18742 .21343 Mtetra
.18742 .21343 .19588 .22212 .20806 .21742 .19963 .20869 Mtetra
.19963 .20869 .20806 .21742 .2203 .2127 .2119 .20392 Mtetra
.2119 .20392 .2203 .2127 .23259 .20796 .22423 .19914 Mtetra
.22423 .19914 .23259 .20796 .24494 .20319 .23661 .19433 Mtetra
.23661 .19433 .24494 .20319 .25735 .1984 .24906 .1895 Mtetra
.24906 .1895 .25735 .1984 .26982 .19359 .26157 .18464 Mtetra
.26157 .18464 .26982 .19359 .28235 .18875 .27413 .17976 Mtetra
.27413 .17976 .28235 .18875 .29494 .18389 .28676 .17486 Mtetra
.28676 .17486 .29494 .18389 .30759 .17901 .29944 .16993 Mtetra
.29944 .16993 .30759 .17901 .32031 .1741 .31219 .16498 Mtetra
.31219 .16498 .32031 .1741 .33308 .16917 .325 .16001 Mtetra
.325 .16001 .33308 .16917 .34591 .16422 .33788 .15501 Mtetra
.33788 .15501 .34591 .16422 .35881 .15924 .35081 .14999 Mtetra
.35081 .14999 .35881 .15924 .37177 .15424 .36381 .14494 Mtetra
.36381 .14494 .37177 .15424 .38479 .14922 .37687 .13987 Mtetra
.37687 .13987 .38479 .14922 .39788 .14417 .39 .13478 Mtetra
.39 .13478 .39788 .14417 .41103 .13909 .40319 .12965 Mtetra
.40319 .12965 .41103 .13909 .42424 .13399 .41644 .12451 Mtetra
.41644 .12451 .42424 .13399 .43752 .12886 .42976 .11934 Mtetra
.42976 .11934 .43752 .12886 .45087 .12371 .44315 .11414 Mtetra
.44315 .11414 .45087 .12371 .46428 .11854 .4566 .10892 Mtetra
.958 .617 .28 r
.4566 .10892 .46428 .11854 .47612 .21514 .46822 .20562 Mtetra
.656 .751 .919 r
.46822 .20562 .47612 .21514 .49013 .20999 .48227 .20042 Mtetra
.48227 .20042 .49013 .20999 .50422 .20482 .49641 .1952 Mtetra
.49641 .1952 .50422 .20482 .51837 .19962 .51061 .18995 Mtetra
.51061 .18995 .51837 .19962 .5326 .19439 .52489 .18467 Mtetra
.52489 .18467 .5326 .19439 .54691 .18913 .53924 .17936 Mtetra
.53924 .17936 .54691 .18913 .56129 .18385 .55367 .17403 Mtetra
.55367 .17403 .56129 .18385 .57574 .17854 .56817 .16867 Mtetra
.56817 .16867 .57574 .17854 .59027 .17321 .58275 .16328 Mtetra
.58275 .16328 .59027 .17321 .60487 .16784 .59741 .15786 Mtetra
.59741 .15786 .60487 .16784 .61955 .16245 .61214 .15241 Mtetra
.61214 .15241 .61955 .16245 .63431 .15702 .62695 .14694 Mtetra
.62695 .14694 .63431 .15702 .64915 .15157 .64184 .14143 Mtetra
.64184 .14143 .64915 .15157 .66407 .14609 .65681 .1359 Mtetra
.65681 .1359 .66407 .14609 .67906 .14058 .67186 .13034 Mtetra
.67186 .13034 .67906 .14058 .69414 .13505 .68699 .12474 Mtetra
.68699 .12474 .69414 .13505 .70929 .12948 .7022 .11912 Mtetra
.664 .741 .908 r
.03634 .26033 .04524 .26863 .05679 .26414 .04791 .25581 Mtetra
.04791 .25581 .05679 .26414 .06839 .25964 .05954 .25127 Mtetra
.05954 .25127 .06839 .25964 .08005 .25511 .07123 .24671 Mtetra
.07123 .24671 .08005 .25511 .09176 .25057 .08297 .24212 Mtetra
.08297 .24212 .09176 .25057 .10352 .246 .09476 .23751 Mtetra
.09476 .23751 .10352 .246 .11534 .24141 .10661 .23289 Mtetra
.10661 .23289 .11534 .24141 .12721 .2368 .11851 .22824 Mtetra
.11851 .22824 .12721 .2368 .13914 .23217 .13047 .22356 Mtetra
.13047 .22356 .13914 .23217 .15112 .22752 .14249 .21887 Mtetra
.14249 .21887 .15112 .22752 .16316 .22284 .15456 .21416 Mtetra
.15456 .21416 .16316 .22284 .17526 .21815 .16669 .20942 Mtetra
.16669 .20942 .17526 .21815 .18742 .21343 .17888 .20466 Mtetra
.17888 .20466 .18742 .21343 .19963 .20869 .19112 .19987 Mtetra
.19112 .19987 .19963 .20869 .2119 .20392 .20343 .19507 Mtetra
.20343 .19507 .2119 .20392 .22423 .19914 .21579 .19024 Mtetra
.21579 .19024 .22423 .19914 .23661 .19433 .22821 .18539 Mtetra
.22821 .18539 .23661 .19433 .24906 .1895 .24069 .18051 Mtetra
.24069 .18051 .24906 .1895 .26157 .18464 .25323 .17561 Mtetra
.25323 .17561 .26157 .18464 .27413 .17976 .26583 .17069 Mtetra
.26583 .17069 .27413 .17976 .28676 .17486 .2785 .16575 Mtetra
.2785 .16575 .28676 .17486 .29944 .16993 .29122 .16078 Mtetra
.29122 .16078 .29944 .16993 .31219 .16498 .30401 .15578 Mtetra
.30401 .15578 .31219 .16498 .325 .16001 .31685 .15076 Mtetra
.31685 .15076 .325 .16001 .33788 .15501 .32977 .14572 Mtetra
.32977 .14572 .33788 .15501 .35081 .14999 .34274 .14065 Mtetra
.34274 .14065 .35081 .14999 .36381 .14494 .35578 .13556 Mtetra
.35578 .13556 .36381 .14494 .37687 .13987 .36888 .13044 Mtetra
.36888 .13044 .37687 .13987 .39 .13478 .38204 .1253 Mtetra
.38204 .1253 .39 .13478 .40319 .12965 .39527 .12013 Mtetra
.39527 .12013 .40319 .12965 .41644 .12451 .40857 .11494 Mtetra
.40857 .11494 .41644 .12451 .42976 .11934 .42193 .10972 Mtetra
.42193 .10972 .42976 .11934 .44315 .11414 .43536 .10448 Mtetra
.43536 .10448 .44315 .11414 .4566 .10892 .44886 .0992 Mtetra
.958 .617 .28 r
.44886 .0992 .4566 .10892 .46822 .20562 .46024 .196 Mtetra
.656 .751 .919 r
.46024 .196 .46822 .20562 .48227 .20042 .47434 .19075 Mtetra
.47434 .19075 .48227 .20042 .49641 .1952 .48852 .18548 Mtetra
.48852 .18548 .49641 .1952 .51061 .18995 .50277 .18018 Mtetra
.50277 .18018 .51061 .18995 .52489 .18467 .5171 .17485 Mtetra
.5171 .17485 .52489 .18467 .53924 .17936 .5315 .16949 Mtetra
.5315 .16949 .53924 .17936 .55367 .17403 .54597 .16411 Mtetra
.54597 .16411 .55367 .17403 .56817 .16867 .56053 .1587 Mtetra
.56053 .1587 .56817 .16867 .58275 .16328 .57516 .15325 Mtetra
.57516 .15325 .58275 .16328 .59741 .15786 .58987 .14778 Mtetra
.58987 .14778 .59741 .15786 .61214 .15241 .60465 .14228 Mtetra
.60465 .14228 .61214 .15241 .62695 .14694 .61952 .13675 Mtetra
.61952 .13675 .62695 .14694 .64184 .14143 .63446 .13119 Mtetra
.63446 .13119 .64184 .14143 .65681 .1359 .64948 .12561 Mtetra
.64948 .12561 .65681 .1359 .67186 .13034 .66459 .11999 Mtetra
.66459 .11999 .67186 .13034 .68699 .12474 .67978 .11434 Mtetra
.67978 .11434 .68699 .12474 .7022 .11912 .69504 .10866 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.654 .753 .923 r
.39472 .71485 .40105 .7203 .41163 .71735 .40533 .71188 Mtetra
.40533 .71188 .41163 .71735 .42226 .71439 .41598 .7089 Mtetra
.41598 .7089 .42226 .71439 .43293 .71142 .42668 .7059 Mtetra
.42668 .7059 .43293 .71142 .44364 .70844 .43742 .7029 Mtetra
.43742 .7029 .44364 .70844 .45439 .70544 .4482 .69988 Mtetra
.4482 .69988 .45439 .70544 .46519 .70244 .45902 .69685 Mtetra
.45902 .69685 .46519 .70244 .47603 .69942 .46989 .69381 Mtetra
.46989 .69381 .47603 .69942 .48691 .69639 .4808 .69076 Mtetra
.4808 .69076 .48691 .69639 .49784 .69334 .49176 .68769 Mtetra
.49176 .68769 .49784 .69334 .50881 .69029 .50276 .68461 Mtetra
.50276 .68461 .50881 .69029 .51982 .68722 .5138 .68152 Mtetra
.5138 .68152 .51982 .68722 .53088 .68414 .52489 .67842 Mtetra
.52489 .67842 .53088 .68414 .54199 .68105 .53602 .6753 Mtetra
.53602 .6753 .54199 .68105 .55313 .67794 .5472 .67217 Mtetra
.5472 .67217 .55313 .67794 .56433 .67482 .55842 .66903 Mtetra
.55842 .66903 .56433 .67482 .57557 .67169 .56969 .66588 Mtetra
.95 .712 .542 r
.56969 .66588 .57557 .67169 .58474 .54983 .57909 .54376 Mtetra
.664 .741 .908 r
.57909 .54376 .58474 .54983 .59568 .54654 .59006 .54045 Mtetra
.59006 .54045 .59568 .54654 .60667 .54325 .60107 .53713 Mtetra
.60107 .53713 .60667 .54325 .61769 .53994 .61213 .5338 Mtetra
.61213 .5338 .61769 .53994 .62876 .53662 .62323 .53045 Mtetra
.62323 .53045 .62876 .53662 .63988 .53329 .63437 .5271 Mtetra
.63437 .5271 .63988 .53329 .65104 .52994 .64556 .52372 Mtetra
.64556 .52372 .65104 .52994 .66224 .52658 .65679 .52034 Mtetra
.65679 .52034 .66224 .52658 .67349 .5232 .66807 .51694 Mtetra
.66807 .51694 .67349 .5232 .68478 .51982 .67939 .51353 Mtetra
.67939 .51353 .68478 .51982 .69612 .51641 .69076 .5101 Mtetra
.69076 .5101 .69612 .51641 .7075 .513 .70218 .50666 Mtetra
.70218 .50666 .7075 .513 .71893 .50957 .71364 .5032 Mtetra
.71364 .5032 .71893 .50957 .73041 .50613 .72515 .49974 Mtetra
.72515 .49974 .73041 .50613 .74193 .50267 .7367 .49625 Mtetra
.7367 .49625 .74193 .50267 .7535 .4992 .7483 .49276 Mtetra
.7483 .49276 .7535 .4992 .76511 .49572 .75995 .48925 Mtetra
.75995 .48925 .76511 .49572 .77677 .49222 .77165 .48572 Mtetra
.77165 .48572 .77677 .49222 .78848 .48871 .78339 .48218 Mtetra
.78339 .48218 .78848 .48871 .80024 .48518 .79518 .47863 Mtetra
.79518 .47863 .80024 .48518 .81205 .48164 .80702 .47506 Mtetra
.80702 .47506 .81205 .48164 .8239 .47808 .81891 .47148 Mtetra
.81891 .47148 .8239 .47808 .8358 .47451 .83085 .46788 Mtetra
.83085 .46788 .8358 .47451 .84775 .47092 .84283 .46427 Mtetra
.84283 .46427 .84775 .47092 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .45699 Mtetra
.86696 .45699 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.654 .753 .923 r
.38835 .70936 .39472 .71485 .40533 .71188 .39898 .70637 Mtetra
.39898 .70637 .40533 .71188 .41598 .7089 .40966 .70336 Mtetra
.40966 .70336 .41598 .7089 .42668 .7059 .42039 .70035 Mtetra
.42039 .70035 .42668 .7059 .43742 .7029 .43115 .69732 Mtetra
.43115 .69732 .43742 .7029 .4482 .69988 .44196 .69428 Mtetra
.44196 .69428 .4482 .69988 .45902 .69685 .45281 .69123 Mtetra
.45281 .69123 .45902 .69685 .46989 .69381 .46371 .68816 Mtetra
.46371 .68816 .46989 .69381 .4808 .69076 .47465 .68509 Mtetra
.47465 .68509 .4808 .69076 .49176 .68769 .48563 .682 Mtetra
.48563 .682 .49176 .68769 .50276 .68461 .49666 .6789 Mtetra
.49666 .6789 .50276 .68461 .5138 .68152 .50773 .67578 Mtetra
.50773 .67578 .5138 .68152 .52489 .67842 .51885 .67266 Mtetra
.51885 .67266 .52489 .67842 .53602 .6753 .53001 .66952 Mtetra
.53001 .66952 .53602 .6753 .5472 .67217 .54122 .66637 Mtetra
.54122 .66637 .5472 .67217 .55842 .66903 .55247 .6632 Mtetra
.55247 .6632 .55842 .66903 .56969 .66588 .56377 .66002 Mtetra
.95 .712 .542 r
.56377 .66002 .56969 .66588 .57909 .54376 .57339 .53764 Mtetra
.664 .741 .908 r
.57339 .53764 .57909 .54376 .59006 .54045 .58439 .53431 Mtetra
.58439 .53431 .59006 .54045 .60107 .53713 .59543 .53097 Mtetra
.59543 .53097 .60107 .53713 .61213 .5338 .60652 .52761 Mtetra
.60652 .52761 .61213 .5338 .62323 .53045 .61765 .52424 Mtetra
.61765 .52424 .62323 .53045 .63437 .5271 .62882 .52086 Mtetra
.62882 .52086 .63437 .5271 .64556 .52372 .64004 .51746 Mtetra
.64004 .51746 .64556 .52372 .65679 .52034 .6513 .51405 Mtetra
.6513 .51405 .65679 .52034 .66807 .51694 .66261 .51063 Mtetra
.66261 .51063 .66807 .51694 .67939 .51353 .67397 .50719 Mtetra
.67397 .50719 .67939 .51353 .69076 .5101 .68537 .50374 Mtetra
.68537 .50374 .69076 .5101 .70218 .50666 .69682 .50027 Mtetra
.69682 .50027 .70218 .50666 .71364 .5032 .70831 .49679 Mtetra
.70831 .49679 .71364 .5032 .72515 .49974 .71985 .4933 Mtetra
.71985 .4933 .72515 .49974 .7367 .49625 .73144 .48979 Mtetra
.73144 .48979 .7367 .49625 .7483 .49276 .74307 .48626 Mtetra
.74307 .48626 .7483 .49276 .75995 .48925 .75475 .48273 Mtetra
.75475 .48273 .75995 .48925 .77165 .48572 .76648 .47918 Mtetra
.76648 .47918 .77165 .48572 .78339 .48218 .77826 .47561 Mtetra
.77826 .47561 .78339 .48218 .79518 .47863 .79008 .47203 Mtetra
.79008 .47203 .79518 .47863 .80702 .47506 .80196 .46843 Mtetra
.80196 .46843 .80702 .47506 .81891 .47148 .81388 .46482 Mtetra
.81388 .46482 .81891 .47148 .83085 .46788 .82585 .4612 Mtetra
.82585 .4612 .83085 .46788 .84283 .46427 .83788 .45756 Mtetra
.83788 .45756 .84283 .46427 .85487 .46064 .84995 .4539 Mtetra
.84995 .4539 .85487 .46064 .86696 .45699 .86207 .45023 Mtetra
.86207 .45023 .86696 .45699 .87909 .45334 .87424 .44654 Mtetra
.87424 .44654 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.654 .753 .923 r
.38193 .70383 .38835 .70936 .39898 .70637 .39259 .70081 Mtetra
.39259 .70081 .39898 .70637 .40966 .70336 .4033 .69779 Mtetra
.4033 .69779 .40966 .70336 .42039 .70035 .41405 .69475 Mtetra
.41405 .69475 .42039 .70035 .43115 .69732 .42484 .6917 Mtetra
.42484 .6917 .43115 .69732 .44196 .69428 .43568 .68864 Mtetra
.43568 .68864 .44196 .69428 .45281 .69123 .44655 .68556 Mtetra
.44655 .68556 .45281 .69123 .46371 .68816 .45748 .68247 Mtetra
.45748 .68247 .46371 .68816 .47465 .68509 .46845 .67937 Mtetra
.46845 .67937 .47465 .68509 .48563 .682 .47946 .67626 Mtetra
.47946 .67626 .48563 .682 .49666 .6789 .49051 .67314 Mtetra
.49051 .67314 .49666 .6789 .50773 .67578 .50161 .67 Mtetra
.50161 .67 .50773 .67578 .51885 .67266 .51276 .66685 Mtetra
.51276 .66685 .51885 .67266 .53001 .66952 .52395 .66369 Mtetra
.52395 .66369 .53001 .66952 .54122 .66637 .53519 .66051 Mtetra
.53519 .66051 .54122 .66637 .55247 .6632 .54647 .65732 Mtetra
.54647 .65732 .55247 .6632 .56377 .66002 .5578 .65412 Mtetra
.95 .712 .542 r
.5578 .65412 .56377 .66002 .57339 .53764 .56766 .53149 Mtetra
.664 .741 .908 r
.56766 .53149 .57339 .53764 .58439 .53431 .57868 .52813 Mtetra
.57868 .52813 .58439 .53431 .59543 .53097 .58975 .52476 Mtetra
.58975 .52476 .59543 .53097 .60652 .52761 .60087 .52138 Mtetra
.60087 .52138 .60652 .52761 .61765 .52424 .61203 .51799 Mtetra
.61203 .51799 .61765 .52424 .62882 .52086 .62323 .51458 Mtetra
.62323 .51458 .62882 .52086 .64004 .51746 .63448 .51115 Mtetra
.63448 .51115 .64004 .51746 .6513 .51405 .64578 .50772 Mtetra
.64578 .50772 .6513 .51405 .66261 .51063 .65712 .50427 Mtetra
.65712 .50427 .66261 .51063 .67397 .50719 .6685 .5008 Mtetra
.6685 .5008 .67397 .50719 .68537 .50374 .67993 .49733 Mtetra
.67993 .49733 .68537 .50374 .69682 .50027 .69141 .49383 Mtetra
.69141 .49383 .69682 .50027 .70831 .49679 .70294 .49033 Mtetra
.70294 .49033 .70831 .49679 .71985 .4933 .71451 .48681 Mtetra
.71451 .48681 .71985 .4933 .73144 .48979 .72613 .48327 Mtetra
.72613 .48327 .73144 .48979 .74307 .48626 .7378 .47972 Mtetra
.7378 .47972 .74307 .48626 .75475 .48273 .74951 .47616 Mtetra
.74951 .47616 .75475 .48273 .76648 .47918 .76127 .47258 Mtetra
.76127 .47258 .76648 .47918 .77826 .47561 .77309 .46899 Mtetra
.77309 .46899 .77826 .47561 .79008 .47203 .78495 .46538 Mtetra
.78495 .46538 .79008 .47203 .80196 .46843 .79686 .46176 Mtetra
.79686 .46176 .80196 .46843 .81388 .46482 .80881 .45812 Mtetra
.80881 .45812 .81388 .46482 .82585 .4612 .82082 .45446 Mtetra
.82082 .45446 .82585 .4612 .83788 .45756 .83288 .4508 Mtetra
.83288 .4508 .83788 .45756 .84995 .4539 .84499 .44711 Mtetra
.84499 .44711 .84995 .4539 .86207 .45023 .85715 .44341 Mtetra
.85715 .44341 .86207 .45023 .87424 .44654 .86936 .4397 Mtetra
.86936 .4397 .87424 .44654 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.654 .753 .923 r
.37546 .69825 .38193 .70383 .39259 .70081 .38615 .69522 Mtetra
.38615 .69522 .39259 .70081 .4033 .69779 .39688 .69217 Mtetra
.39688 .69217 .4033 .69779 .41405 .69475 .40766 .68911 Mtetra
.40766 .68911 .41405 .69475 .42484 .6917 .41848 .68604 Mtetra
.41848 .68604 .42484 .6917 .43568 .68864 .42934 .68295 Mtetra
.42934 .68295 .43568 .68864 .44655 .68556 .44025 .67985 Mtetra
.44025 .67985 .44655 .68556 .45748 .68247 .4512 .67674 Mtetra
.4512 .67674 .45748 .68247 .46845 .67937 .4622 .67362 Mtetra
.4622 .67362 .46845 .67937 .47946 .67626 .47324 .67048 Mtetra
.47324 .67048 .47946 .67626 .49051 .67314 .48432 .66734 Mtetra
.48432 .66734 .49051 .67314 .50161 .67 .49545 .66418 Mtetra
.49545 .66418 .50161 .67 .51276 .66685 .50663 .661 Mtetra
.50663 .661 .51276 .66685 .52395 .66369 .51785 .65781 Mtetra
.51785 .65781 .52395 .66369 .53519 .66051 .52912 .65462 Mtetra
.52912 .65462 .53519 .66051 .54647 .65732 .54043 .6514 Mtetra
.54043 .6514 .54647 .65732 .5578 .65412 .55179 .64818 Mtetra
.95 .712 .542 r
.55179 .64818 .5578 .65412 .56766 .53149 .56188 .52528 Mtetra
.664 .741 .908 r
.56188 .52528 .56766 .53149 .57868 .52813 .57293 .5219 Mtetra
.57293 .5219 .57868 .52813 .58975 .52476 .58403 .51851 Mtetra
.58403 .51851 .58975 .52476 .60087 .52138 .59518 .5151 Mtetra
.59518 .5151 .60087 .52138 .61203 .51799 .60637 .51168 Mtetra
.60637 .51168 .61203 .51799 .62323 .51458 .6176 .50825 Mtetra
.6176 .50825 .62323 .51458 .63448 .51115 .62888 .5048 Mtetra
.62888 .5048 .63448 .51115 .64578 .50772 .64021 .50134 Mtetra
.64021 .50134 .64578 .50772 .65712 .50427 .65158 .49786 Mtetra
.65158 .49786 .65712 .50427 .6685 .5008 .663 .49437 Mtetra
.663 .49437 .6685 .5008 .67993 .49733 .67446 .49087 Mtetra
.67446 .49087 .67993 .49733 .69141 .49383 .68597 .48735 Mtetra
.68597 .48735 .69141 .49383 .70294 .49033 .69753 .48382 Mtetra
.69753 .48382 .70294 .49033 .71451 .48681 .70913 .48027 Mtetra
.70913 .48027 .71451 .48681 .72613 .48327 .72078 .47671 Mtetra
.72078 .47671 .72613 .48327 .7378 .47972 .73248 .47313 Mtetra
.73248 .47313 .7378 .47972 .74951 .47616 .74423 .46954 Mtetra
.74423 .46954 .74951 .47616 .76127 .47258 .75603 .46593 Mtetra
.75603 .46593 .76127 .47258 .77309 .46899 .76788 .46231 Mtetra
.76788 .46231 .77309 .46899 .78495 .46538 .77977 .45868 Mtetra
.77977 .45868 .78495 .46538 .79686 .46176 .79171 .45503 Mtetra
.79171 .45503 .79686 .46176 .80881 .45812 .80371 .45136 Mtetra
.80371 .45136 .80881 .45812 .82082 .45446 .81575 .44768 Mtetra
.81575 .44768 .82082 .45446 .83288 .4508 .82785 .44398 Mtetra
.82785 .44398 .83288 .4508 .84499 .44711 .83999 .44027 Mtetra
.83999 .44027 .84499 .44711 .85715 .44341 .85219 .43654 Mtetra
.85219 .43654 .85715 .44341 .86936 .4397 .86443 .4328 Mtetra
.86443 .4328 .86936 .4397 .88162 .43597 .87673 .42904 Mtetra
.87673 .42904 .88162 .43597 .89393 .43222 .88908 .42526 Mtetra
.88908 .42526 .89393 .43222 .9063 .42846 .90148 .42147 Mtetra
.90148 .42147 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.654 .753 .923 r
.36895 .69264 .37546 .69825 .38615 .69522 .37966 .68958 Mtetra
.37966 .68958 .38615 .69522 .39688 .69217 .39042 .68651 Mtetra
.39042 .68651 .39688 .69217 .40766 .68911 .40123 .68343 Mtetra
.40123 .68343 .40766 .68911 .41848 .68604 .41207 .68033 Mtetra
.41207 .68033 .41848 .68604 .42934 .68295 .42296 .67722 Mtetra
.42296 .67722 .42934 .68295 .44025 .67985 .4339 .6741 Mtetra
.4339 .6741 .44025 .67985 .4512 .67674 .44488 .67097 Mtetra
.44488 .67097 .4512 .67674 .4622 .67362 .4559 .66782 Mtetra
.4559 .66782 .4622 .67362 .47324 .67048 .46697 .66466 Mtetra
.46697 .66466 .47324 .67048 .48432 .66734 .47809 .66149 Mtetra
.47809 .66149 .48432 .66734 .49545 .66418 .48924 .65831 Mtetra
.48924 .65831 .49545 .66418 .50663 .661 .50045 .65511 Mtetra
.50045 .65511 .50663 .661 .51785 .65781 .5117 .6519 Mtetra
.5117 .6519 .51785 .65781 .52912 .65462 .523 .64867 Mtetra
.523 .64867 .52912 .65462 .54043 .6514 .53434 .64544 Mtetra
.53434 .64544 .54043 .6514 .55179 .64818 .54574 .64218 Mtetra
.95 .712 .542 r
.54574 .64218 .55179 .64818 .56188 .52528 .55606 .51903 Mtetra
.664 .741 .908 r
.55606 .51903 .56188 .52528 .57293 .5219 .56714 .51563 Mtetra
.56714 .51563 .57293 .5219 .58403 .51851 .57827 .51221 Mtetra
.57827 .51221 .58403 .51851 .59518 .5151 .58944 .50878 Mtetra
.58944 .50878 .59518 .5151 .60637 .51168 .60066 .50533 Mtetra
.60066 .50533 .60637 .51168 .6176 .50825 .61193 .50187 Mtetra
.61193 .50187 .6176 .50825 .62888 .5048 .62324 .4984 Mtetra
.62324 .4984 .62888 .5048 .64021 .50134 .6346 .49491 Mtetra
.6346 .49491 .64021 .50134 .65158 .49786 .646 .49141 Mtetra
.646 .49141 .65158 .49786 .663 .49437 .65745 .48789 Mtetra
.65745 .48789 .663 .49437 .67446 .49087 .66894 .48436 Mtetra
.66894 .48436 .67446 .49087 .68597 .48735 .68049 .48082 Mtetra
.68049 .48082 .68597 .48735 .69753 .48382 .69208 .47726 Mtetra
.69208 .47726 .69753 .48382 .70913 .48027 .70371 .47368 Mtetra
.70371 .47368 .70913 .48027 .72078 .47671 .7154 .47009 Mtetra
.7154 .47009 .72078 .47671 .73248 .47313 .72713 .46649 Mtetra
.72713 .46649 .73248 .47313 .74423 .46954 .73891 .46287 Mtetra
.73891 .46287 .74423 .46954 .75603 .46593 .75075 .45924 Mtetra
.75075 .45924 .75603 .46593 .76788 .46231 .76263 .45559 Mtetra
.76263 .45559 .76788 .46231 .77977 .45868 .77455 .45193 Mtetra
.77455 .45193 .77977 .45868 .79171 .45503 .78653 .44825 Mtetra
.78653 .44825 .79171 .45503 .80371 .45136 .79856 .44455 Mtetra
.79856 .44455 .80371 .45136 .81575 .44768 .81064 .44084 Mtetra
.81064 .44084 .81575 .44768 .82785 .44398 .82277 .43712 Mtetra
.82277 .43712 .82785 .44398 .83999 .44027 .83495 .43338 Mtetra
.83495 .43338 .83999 .44027 .85219 .43654 .84719 .42962 Mtetra
.84719 .42962 .85219 .43654 .86443 .4328 .85947 .42585 Mtetra
.85947 .42585 .86443 .4328 .87673 .42904 .87181 .42206 Mtetra
.87181 .42206 .87673 .42904 .88908 .42526 .88419 .41825 Mtetra
.88419 .41825 .88908 .42526 .90148 .42147 .89664 .41443 Mtetra
.89664 .41443 .90148 .42147 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.654 .753 .923 r
.36238 .68698 .36895 .69264 .37966 .68958 .37313 .6839 Mtetra
.37313 .6839 .37966 .68958 .39042 .68651 .38391 .68081 Mtetra
.38391 .68081 .39042 .68651 .40123 .68343 .39474 .6777 Mtetra
.39474 .6777 .40123 .68343 .41207 .68033 .40562 .67458 Mtetra
.40562 .67458 .41207 .68033 .42296 .67722 .41654 .67145 Mtetra
.41654 .67145 .42296 .67722 .4339 .6741 .4275 .66831 Mtetra
.4275 .66831 .4339 .6741 .44488 .67097 .43851 .66515 Mtetra
.43851 .66515 .44488 .67097 .4559 .66782 .44956 .66198 Mtetra
.44956 .66198 .4559 .66782 .46697 .66466 .46066 .6588 Mtetra
.46066 .6588 .46697 .66466 .47809 .66149 .4718 .6556 Mtetra
.4718 .6556 .47809 .66149 .48924 .65831 .48299 .65239 Mtetra
.48299 .65239 .48924 .65831 .50045 .65511 .49423 .64917 Mtetra
.49423 .64917 .50045 .65511 .5117 .6519 .50551 .64593 Mtetra
.50551 .64593 .5117 .6519 .523 .64867 .51683 .64269 Mtetra
.51683 .64269 .523 .64867 .53434 .64544 .52821 .63942 Mtetra
.52821 .63942 .53434 .64544 .54574 .64218 .53963 .63615 Mtetra
.95 .712 .542 r
.53963 .63615 .54574 .64218 .55606 .51903 .55019 .51274 Mtetra
.664 .741 .908 r
.55019 .51274 .55606 .51903 .56714 .51563 .5613 .50931 Mtetra
.5613 .50931 .56714 .51563 .57827 .51221 .57246 .50586 Mtetra
.57246 .50586 .57827 .51221 .58944 .50878 .58367 .50241 Mtetra
.58367 .50241 .58944 .50878 .60066 .50533 .59492 .49893 Mtetra
.59492 .49893 .60066 .50533 .61193 .50187 .60621 .49545 Mtetra
.60621 .49545 .61193 .50187 .62324 .4984 .61755 .49195 Mtetra
.61755 .49195 .62324 .4984 .6346 .49491 .62894 .48843 Mtetra
.62894 .48843 .6346 .49491 .646 .49141 .64038 .48491 Mtetra
.64038 .48491 .646 .49141 .65745 .48789 .65186 .48136 Mtetra
.65186 .48136 .65745 .48789 .66894 .48436 .66338 .47781 Mtetra
.66338 .47781 .66894 .48436 .68049 .48082 .67496 .47423 Mtetra
.67496 .47423 .68049 .48082 .69208 .47726 .68658 .47065 Mtetra
.68658 .47065 .69208 .47726 .70371 .47368 .69825 .46705 Mtetra
.69825 .46705 .70371 .47368 .7154 .47009 .70997 .46343 Mtetra
.70997 .46343 .7154 .47009 .72713 .46649 .72174 .4598 Mtetra
.72174 .4598 .72713 .46649 .73891 .46287 .73355 .45615 Mtetra
.73355 .45615 .73891 .46287 .75075 .45924 .74542 .45249 Mtetra
.74542 .45249 .75075 .45924 .76263 .45559 .75733 .44881 Mtetra
.75733 .44881 .76263 .45559 .77455 .45193 .7693 .44512 Mtetra
.7693 .44512 .77455 .45193 .78653 .44825 .78131 .44141 Mtetra
.78131 .44141 .78653 .44825 .79856 .44455 .79338 .43769 Mtetra
.79338 .43769 .79856 .44455 .81064 .44084 .80549 .43395 Mtetra
.80549 .43395 .81064 .44084 .82277 .43712 .81766 .4302 Mtetra
.81766 .4302 .82277 .43712 .83495 .43338 .82988 .42643 Mtetra
.82988 .42643 .83495 .43338 .84719 .42962 .84215 .42264 Mtetra
.84215 .42264 .84719 .42962 .85947 .42585 .85447 .41884 Mtetra
.85447 .41884 .85947 .42585 .87181 .42206 .86684 .41502 Mtetra
.86684 .41502 .87181 .42206 .88419 .41825 .87927 .41119 Mtetra
.87927 .41119 .88419 .41825 .89664 .41443 .89175 .40734 Mtetra
.89175 .40734 .89664 .41443 .90913 .4106 .90428 .40347 Mtetra
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39958 Mtetra
.91687 .39958 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.654 .753 .923 r
.35577 .68128 .36238 .68698 .37313 .6839 .36654 .67818 Mtetra
.36654 .67818 .37313 .6839 .38391 .68081 .37736 .67506 Mtetra
.37736 .67506 .38391 .68081 .39474 .6777 .38821 .67193 Mtetra
.38821 .67193 .39474 .6777 .40562 .67458 .39912 .66879 Mtetra
.39912 .66879 .40562 .67458 .41654 .67145 .41006 .66564 Mtetra
.41006 .66564 .41654 .67145 .4275 .66831 .42105 .66247 Mtetra
.42105 .66247 .4275 .66831 .43851 .66515 .43209 .65929 Mtetra
.43209 .65929 .43851 .66515 .44956 .66198 .44317 .65609 Mtetra
.44317 .65609 .44956 .66198 .46066 .6588 .4543 .65289 Mtetra
.4543 .65289 .46066 .6588 .4718 .6556 .46547 .64967 Mtetra
.46547 .64967 .4718 .6556 .48299 .65239 .47669 .64643 Mtetra
.47669 .64643 .48299 .65239 .49423 .64917 .48795 .64319 Mtetra
.48795 .64319 .49423 .64917 .50551 .64593 .49926 .63993 Mtetra
.49926 .63993 .50551 .64593 .51683 .64269 .51062 .63665 Mtetra
.51062 .63665 .51683 .64269 .52821 .63942 .52203 .63336 Mtetra
.52203 .63336 .52821 .63942 .53963 .63615 .53348 .63006 Mtetra
.95 .712 .542 r
.53348 .63006 .53963 .63615 .55019 .51274 .54428 .50639 Mtetra
.664 .741 .908 r
.54428 .50639 .55019 .51274 .5613 .50931 .55543 .50294 Mtetra
.55543 .50294 .5613 .50931 .57246 .50586 .56661 .49947 Mtetra
.56661 .49947 .57246 .50586 .58367 .50241 .57785 .49599 Mtetra
.57785 .49599 .58367 .50241 .59492 .49893 .58913 .49249 Mtetra
.58913 .49249 .59492 .49893 .60621 .49545 .60045 .48898 Mtetra
.60045 .48898 .60621 .49545 .61755 .49195 .61183 .48545 Mtetra
.61183 .48545 .61755 .49195 .62894 .48843 .62325 .48191 Mtetra
.62325 .48191 .62894 .48843 .64038 .48491 .63471 .47835 Mtetra
.63471 .47835 .64038 .48491 .65186 .48136 .64622 .47478 Mtetra
.64622 .47478 .65186 .48136 .66338 .47781 .65778 .4712 Mtetra
.65778 .4712 .66338 .47781 .67496 .47423 .66939 .4676 Mtetra
.66939 .4676 .67496 .47423 .68658 .47065 .68105 .46399 Mtetra
.68105 .46399 .68658 .47065 .69825 .46705 .69275 .46036 Mtetra
.69275 .46036 .69825 .46705 .70997 .46343 .7045 .45671 Mtetra
.7045 .45671 .70997 .46343 .72174 .4598 .7163 .45306 Mtetra
.7163 .45306 .72174 .4598 .73355 .45615 .72815 .44938 Mtetra
.72815 .44938 .73355 .45615 .74542 .45249 .74005 .44569 Mtetra
.74005 .44569 .74542 .45249 .75733 .44881 .752 .44199 Mtetra
.752 .44199 .75733 .44881 .7693 .44512 .764 .43827 Mtetra
.764 .43827 .7693 .44512 .78131 .44141 .77605 .43453 Mtetra
.77605 .43453 .78131 .44141 .79338 .43769 .78815 .43078 Mtetra
.78815 .43078 .79338 .43769 .80549 .43395 .8003 .42701 Mtetra
.8003 .42701 .80549 .43395 .81766 .4302 .81251 .42323 Mtetra
.81251 .42323 .81766 .4302 .82988 .42643 .82476 .41943 Mtetra
.82476 .41943 .82988 .42643 .84215 .42264 .83707 .41561 Mtetra
.83707 .41561 .84215 .42264 .85447 .41884 .84943 .41178 Mtetra
.84943 .41178 .85447 .41884 .86684 .41502 .86184 .40793 Mtetra
.86184 .40793 .86684 .41502 .87927 .41119 .8743 .40406 Mtetra
.8743 .40406 .87927 .41119 .89175 .40734 .88682 .40018 Mtetra
.88682 .40018 .89175 .40734 .90428 .40347 .89939 .39628 Mtetra
.89939 .39628 .90428 .40347 .91687 .39958 .91202 .39237 Mtetra
.91202 .39237 .91687 .39958 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.654 .753 .923 r
.34911 .67554 .35577 .68128 .36654 .67818 .35991 .67242 Mtetra
.35991 .67242 .36654 .67818 .37736 .67506 .37075 .66928 Mtetra
.37075 .66928 .37736 .67506 .38821 .67193 .38163 .66612 Mtetra
.38163 .66612 .38821 .67193 .39912 .66879 .39256 .66296 Mtetra
.39256 .66296 .39912 .66879 .41006 .66564 .40354 .65978 Mtetra
.40354 .65978 .41006 .66564 .42105 .66247 .41456 .65659 Mtetra
.41456 .65659 .42105 .66247 .43209 .65929 .42562 .65338 Mtetra
.42562 .65338 .43209 .65929 .44317 .65609 .43673 .65016 Mtetra
.43673 .65016 .44317 .65609 .4543 .65289 .44789 .64693 Mtetra
.44789 .64693 .4543 .65289 .46547 .64967 .45909 .64369 Mtetra
.45909 .64369 .46547 .64967 .47669 .64643 .47034 .64043 Mtetra
.47034 .64043 .47669 .64643 .48795 .64319 .48163 .63716 Mtetra
.48163 .63716 .48795 .64319 .49926 .63993 .49297 .63387 Mtetra
.49297 .63387 .49926 .63993 .51062 .63665 .50436 .63057 Mtetra
.50436 .63057 .51062 .63665 .52203 .63336 .5158 .62726 Mtetra
.5158 .62726 .52203 .63336 .53348 .63006 .52728 .62393 Mtetra
.95 .712 .542 r
.52728 .62393 .53348 .63006 .54428 .50639 .53833 .5 Mtetra
.664 .741 .908 r
.53833 .5 .54428 .50639 .55543 .50294 .5495 .49652 Mtetra
.5495 .49652 .55543 .50294 .56661 .49947 .56072 .49303 Mtetra
.56072 .49303 .56661 .49947 .57785 .49599 .57199 .48952 Mtetra
.57199 .48952 .57785 .49599 .58913 .49249 .5833 .48599 Mtetra
.5833 .48599 .58913 .49249 .60045 .48898 .59465 .48245 Mtetra
.59465 .48245 .60045 .48898 .61183 .48545 .60606 .4789 Mtetra
.60606 .4789 .61183 .48545 .62325 .48191 .61751 .47533 Mtetra
.61751 .47533 .62325 .48191 .63471 .47835 .629 .47175 Mtetra
.629 .47175 .63471 .47835 .64622 .47478 .64055 .46816 Mtetra
.64055 .46816 .64622 .47478 .65778 .4712 .65214 .46454 Mtetra
.65214 .46454 .65778 .4712 .66939 .4676 .66378 .46092 Mtetra
.66378 .46092 .66939 .4676 .68105 .46399 .67547 .45728 Mtetra
.67547 .45728 .68105 .46399 .69275 .46036 .68721 .45362 Mtetra
.68721 .45362 .69275 .46036 .7045 .45671 .69899 .44995 Mtetra
.69899 .44995 .7045 .45671 .7163 .45306 .71083 .44626 Mtetra
.71083 .44626 .7163 .45306 .72815 .44938 .72271 .44256 Mtetra
.72271 .44256 .72815 .44938 .74005 .44569 .73465 .43884 Mtetra
.73465 .43884 .74005 .44569 .752 .44199 .74663 .4351 Mtetra
.74663 .4351 .752 .44199 .764 .43827 .75866 .43136 Mtetra
.75866 .43136 .764 .43827 .77605 .43453 .77075 .42759 Mtetra
.77075 .42759 .77605 .43453 .78815 .43078 .78289 .42381 Mtetra
.78289 .42381 .78815 .43078 .8003 .42701 .79507 .42001 Mtetra
.79507 .42001 .8003 .42701 .81251 .42323 .80731 .4162 Mtetra
.80731 .4162 .81251 .42323 .82476 .41943 .81961 .41237 Mtetra
.81961 .41237 .82476 .41943 .83707 .41561 .83195 .40852 Mtetra
.83195 .40852 .83707 .41561 .84943 .41178 .84435 .40466 Mtetra
.84435 .40466 .84943 .41178 .86184 .40793 .8568 .40078 Mtetra
.8568 .40078 .86184 .40793 .8743 .40406 .8693 .39689 Mtetra
.8693 .39689 .8743 .40406 .88682 .40018 .88186 .39297 Mtetra
.88186 .39297 .88682 .40018 .89939 .39628 .89447 .38904 Mtetra
.89447 .38904 .89939 .39628 .91202 .39237 .90713 .3851 Mtetra
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37715 Mtetra
.654 .753 .923 r
.3424 .66976 .34911 .67554 .35991 .67242 .35322 .66661 Mtetra
.35322 .66661 .35991 .67242 .37075 .66928 .36409 .66344 Mtetra
.36409 .66344 .37075 .66928 .38163 .66612 .375 .66027 Mtetra
.375 .66027 .38163 .66612 .39256 .66296 .38596 .65708 Mtetra
.38596 .65708 .39256 .66296 .40354 .65978 .39696 .65387 Mtetra
.39696 .65387 .40354 .65978 .41456 .65659 .40801 .65066 Mtetra
.40801 .65066 .41456 .65659 .42562 .65338 .4191 .64743 Mtetra
.4191 .64743 .42562 .65338 .43673 .65016 .43024 .64419 Mtetra
.43024 .64419 .43673 .65016 .44789 .64693 .44143 .64093 Mtetra
.44143 .64093 .44789 .64693 .45909 .64369 .45266 .63766 Mtetra
.45266 .63766 .45909 .64369 .47034 .64043 .46394 .63438 Mtetra
.46394 .63438 .47034 .64043 .48163 .63716 .47526 .63108 Mtetra
.47526 .63108 .48163 .63716 .49297 .63387 .48663 .62777 Mtetra
.48663 .62777 .49297 .63387 .50436 .63057 .49805 .62445 Mtetra
.49805 .62445 .50436 .63057 .5158 .62726 .50952 .62111 Mtetra
.50952 .62111 .5158 .62726 .52728 .62393 .52104 .61775 Mtetra
.95 .712 .542 r
.52104 .61775 .52728 .62393 .53833 .5 .53233 .49357 Mtetra
.664 .741 .908 r
.53233 .49357 .53833 .5 .5495 .49652 .54353 .49006 Mtetra
.54353 .49006 .5495 .49652 .56072 .49303 .55478 .48654 Mtetra
.55478 .48654 .56072 .49303 .57199 .48952 .56608 .483 Mtetra
.56608 .483 .57199 .48952 .5833 .48599 .57742 .47945 Mtetra
.57742 .47945 .5833 .48599 .59465 .48245 .58881 .47588 Mtetra
.58881 .47588 .59465 .48245 .60606 .4789 .60024 .4723 Mtetra
.60024 .4723 .60606 .4789 .61751 .47533 .61172 .46871 Mtetra
.61172 .46871 .61751 .47533 .629 .47175 .62325 .4651 Mtetra
.62325 .4651 .629 .47175 .64055 .46816 .63483 .46148 Mtetra
.63483 .46148 .64055 .46816 .65214 .46454 .64645 .45784 Mtetra
.64645 .45784 .65214 .46454 .66378 .46092 .65813 .45418 Mtetra
.65813 .45418 .66378 .46092 .67547 .45728 .66985 .45051 Mtetra
.66985 .45051 .67547 .45728 .68721 .45362 .68162 .44683 Mtetra
.68162 .44683 .68721 .45362 .69899 .44995 .69344 .44313 Mtetra
.69344 .44313 .69899 .44995 .71083 .44626 .70531 .43941 Mtetra
.70531 .43941 .71083 .44626 .72271 .44256 .71723 .43568 Mtetra
.71723 .43568 .72271 .44256 .73465 .43884 .7292 .43193 Mtetra
.7292 .43193 .73465 .43884 .74663 .4351 .74122 .42817 Mtetra
.74122 .42817 .74663 .4351 .75866 .43136 .75329 .42439 Mtetra
.75329 .42439 .75866 .43136 .77075 .42759 .76541 .4206 Mtetra
.76541 .4206 .77075 .42759 .78289 .42381 .77758 .41679 Mtetra
.77758 .41679 .78289 .42381 .79507 .42001 .7898 .41296 Mtetra
.7898 .41296 .79507 .42001 .80731 .4162 .80208 .40912 Mtetra
.80208 .40912 .80731 .4162 .81961 .41237 .81441 .40526 Mtetra
.81441 .40526 .81961 .41237 .83195 .40852 .82679 .40138 Mtetra
.82679 .40138 .83195 .40852 .84435 .40466 .83923 .39749 Mtetra
.83923 .39749 .84435 .40466 .8568 .40078 .85171 .39358 Mtetra
.85171 .39358 .8568 .40078 .8693 .39689 .86426 .38965 Mtetra
.86426 .38965 .8693 .39689 .88186 .39297 .87685 .38571 Mtetra
.87685 .38571 .88186 .39297 .89447 .38904 .8895 .38175 Mtetra
.8895 .38175 .89447 .38904 .90713 .3851 .90221 .37777 Mtetra
.90221 .37777 .90713 .3851 .91985 .38114 .91497 .37377 Mtetra
.91497 .37377 .91985 .38114 .93263 .37715 .92778 .36976 Mtetra
.654 .753 .923 r
.33564 .66393 .3424 .66976 .35322 .66661 .34649 .66076 Mtetra
.34649 .66076 .35322 .66661 .36409 .66344 .35738 .65757 Mtetra
.35738 .65757 .36409 .66344 .375 .66027 .36832 .65437 Mtetra
.36832 .65437 .375 .66027 .38596 .65708 .37931 .65115 Mtetra
.37931 .65115 .38596 .65708 .39696 .65387 .39034 .64793 Mtetra
.39034 .64793 .39696 .65387 .40801 .65066 .40142 .64469 Mtetra
.40142 .64469 .40801 .65066 .4191 .64743 .41254 .64143 Mtetra
.41254 .64143 .4191 .64743 .43024 .64419 .42371 .63816 Mtetra
.42371 .63816 .43024 .64419 .44143 .64093 .43492 .63488 Mtetra
.43492 .63488 .44143 .64093 .45266 .63766 .44618 .63159 Mtetra
.44618 .63159 .45266 .63766 .46394 .63438 .45749 .62828 Mtetra
.45749 .62828 .46394 .63438 .47526 .63108 .46884 .62496 Mtetra
.46884 .62496 .47526 .63108 .48663 .62777 .48025 .62162 Mtetra
.48025 .62162 .48663 .62777 .49805 .62445 .4917 .61827 Mtetra
.4917 .61827 .49805 .62445 .50952 .62111 .5032 .61491 Mtetra
.5032 .61491 .50952 .62111 .52104 .61775 .51474 .61153 Mtetra
.95 .712 .542 r
.51474 .61153 .52104 .61775 .53233 .49357 .52629 .48708 Mtetra
.664 .741 .908 r
.52629 .48708 .53233 .49357 .54353 .49006 .53752 .48355 Mtetra
.53752 .48355 .54353 .49006 .55478 .48654 .5488 .48 Mtetra
.5488 .48 .55478 .48654 .56608 .483 .56013 .47643 Mtetra
.56013 .47643 .56608 .483 .57742 .47945 .5715 .47286 Mtetra
.5715 .47286 .57742 .47945 .58881 .47588 .58292 .46926 Mtetra
.58292 .46926 .58881 .47588 .60024 .4723 .59438 .46566 Mtetra
.59438 .46566 .60024 .4723 .61172 .46871 .6059 .46203 Mtetra
.6059 .46203 .61172 .46871 .62325 .4651 .61746 .4584 Mtetra
.61746 .4584 .62325 .4651 .63483 .46148 .62907 .45475 Mtetra
.62907 .45475 .63483 .46148 .64645 .45784 .64072 .45108 Mtetra
.64072 .45108 .64645 .45784 .65813 .45418 .65243 .4474 Mtetra
.65243 .4474 .65813 .45418 .66985 .45051 .66418 .4437 Mtetra
.66418 .4437 .66985 .45051 .68162 .44683 .67599 .43998 Mtetra
.67599 .43998 .68162 .44683 .69344 .44313 .68784 .43626 Mtetra
.68784 .43626 .69344 .44313 .70531 .43941 .69975 .43251 Mtetra
.69975 .43251 .70531 .43941 .71723 .43568 .7117 .42875 Mtetra
.7117 .42875 .71723 .43568 .7292 .43193 .7237 .42497 Mtetra
.7237 .42497 .7292 .43193 .74122 .42817 .73576 .42118 Mtetra
.73576 .42118 .74122 .42817 .75329 .42439 .74786 .41737 Mtetra
.74786 .41737 .75329 .42439 .76541 .4206 .76002 .41355 Mtetra
.76002 .41355 .76541 .4206 .77758 .41679 .77223 .40971 Mtetra
.77223 .40971 .77758 .41679 .7898 .41296 .78449 .40585 Mtetra
.78449 .40585 .7898 .41296 .80208 .40912 .79681 .40198 Mtetra
.79681 .40198 .80208 .40912 .81441 .40526 .80917 .39809 Mtetra
.80917 .39809 .81441 .40526 .82679 .40138 .82159 .39418 Mtetra
.82159 .39418 .82679 .40138 .83923 .39749 .83406 .39025 Mtetra
.83406 .39025 .83923 .39749 .85171 .39358 .84659 .38631 Mtetra
.84659 .38631 .85171 .39358 .86426 .38965 .85917 .38236 Mtetra
.85917 .38236 .86426 .38965 .87685 .38571 .87181 .37838 Mtetra
.87181 .37838 .87685 .38571 .8895 .38175 .8845 .37439 Mtetra
.8845 .37439 .8895 .38175 .90221 .37777 .89724 .37038 Mtetra
.89724 .37038 .90221 .37777 .91497 .37377 .91004 .36635 Mtetra
.91004 .36635 .91497 .37377 .92778 .36976 .9229 .36231 Mtetra
.654 .753 .923 r
.32883 .65806 .33564 .66393 .34649 .66076 .3397 .65486 Mtetra
.3397 .65486 .34649 .66076 .35738 .65757 .35063 .65165 Mtetra
.35063 .65165 .35738 .65757 .36832 .65437 .36159 .64842 Mtetra
.36159 .64842 .36832 .65437 .37931 .65115 .37261 .64519 Mtetra
.37261 .64519 .37931 .65115 .39034 .64793 .38367 .64193 Mtetra
.38367 .64193 .39034 .64793 .40142 .64469 .39477 .63867 Mtetra
.39477 .63867 .40142 .64469 .41254 .64143 .40592 .63539 Mtetra
.40592 .63539 .41254 .64143 .42371 .63816 .41712 .6321 Mtetra
.41712 .6321 .42371 .63816 .43492 .63488 .42836 .62879 Mtetra
.42836 .62879 .43492 .63488 .44618 .63159 .43965 .62547 Mtetra
.43965 .62547 .44618 .63159 .45749 .62828 .45099 .62214 Mtetra
.45099 .62214 .45749 .62828 .46884 .62496 .46238 .61879 Mtetra
.46238 .61879 .46884 .62496 .48025 .62162 .47381 .61543 Mtetra
.47381 .61543 .48025 .62162 .4917 .61827 .48529 .61205 Mtetra
.48529 .61205 .4917 .61827 .5032 .61491 .49682 .60866 Mtetra
.49682 .60866 .5032 .61491 .51474 .61153 .5084 .60525 Mtetra
.95 .712 .542 r
.5084 .60525 .51474 .61153 .52629 .48708 .5202 .48054 Mtetra
.664 .741 .908 r
.5202 .48054 .52629 .48708 .53752 .48355 .53146 .47698 Mtetra
.53146 .47698 .53752 .48355 .5488 .48 .54277 .47341 Mtetra
.54277 .47341 .5488 .48 .56013 .47643 .55413 .46982 Mtetra
.55413 .46982 .56013 .47643 .5715 .47286 .56553 .46621 Mtetra
.56553 .46621 .5715 .47286 .58292 .46926 .57698 .46259 Mtetra
.57698 .46259 .58292 .46926 .59438 .46566 .58848 .45896 Mtetra
.58848 .45896 .59438 .46566 .6059 .46203 .60002 .45531 Mtetra
.60002 .45531 .6059 .46203 .61746 .4584 .61162 .45164 Mtetra
.61162 .45164 .61746 .4584 .62907 .45475 .62326 .44796 Mtetra
.62326 .44796 .62907 .45475 .64072 .45108 .63495 .44427 Mtetra
.63495 .44427 .64072 .45108 .65243 .4474 .64669 .44056 Mtetra
.64669 .44056 .65243 .4474 .66418 .4437 .65848 .43683 Mtetra
.65848 .43683 .66418 .4437 .67599 .43998 .67031 .43309 Mtetra
.67031 .43309 .67599 .43998 .68784 .43626 .6822 .42933 Mtetra
.6822 .42933 .68784 .43626 .69975 .43251 .69414 .42556 Mtetra
.69414 .42556 .69975 .43251 .7117 .42875 .70613 .42177 Mtetra
.70613 .42177 .7117 .42875 .7237 .42497 .71817 .41796 Mtetra
.71817 .41796 .7237 .42497 .73576 .42118 .73026 .41414 Mtetra
.73026 .41414 .73576 .42118 .74786 .41737 .7424 .4103 Mtetra
.7424 .4103 .74786 .41737 .76002 .41355 .75459 .40644 Mtetra
.75459 .40644 .76002 .41355 .77223 .40971 .76684 .40257 Mtetra
.76684 .40257 .77223 .40971 .78449 .40585 .77914 .39869 Mtetra
.77914 .39869 .78449 .40585 .79681 .40198 .79149 .39478 Mtetra
.79149 .39478 .79681 .40198 .80917 .39809 .80389 .39086 Mtetra
.80389 .39086 .80917 .39809 .82159 .39418 .81635 .38692 Mtetra
.81635 .38692 .82159 .39418 .83406 .39025 .82886 .38297 Mtetra
.82886 .38297 .83406 .39025 .84659 .38631 .84143 .37899 Mtetra
.84143 .37899 .84659 .38631 .85917 .38236 .85405 .375 Mtetra
.85405 .375 .85917 .38236 .87181 .37838 .86672 .371 Mtetra
.86672 .371 .87181 .37838 .8845 .37439 .87945 .36697 Mtetra
.87945 .36697 .8845 .37439 .89724 .37038 .89224 .36293 Mtetra
.89224 .36293 .89724 .37038 .91004 .36635 .90508 .35887 Mtetra
.90508 .35887 .91004 .36635 .9229 .36231 .91798 .35479 Mtetra
.654 .753 .923 r
.32196 .65214 .32883 .65806 .3397 .65486 .33287 .64892 Mtetra
.33287 .64892 .3397 .65486 .35063 .65165 .34382 .64568 Mtetra
.34382 .64568 .35063 .65165 .36159 .64842 .35481 .64243 Mtetra
.35481 .64243 .36159 .64842 .37261 .64519 .36585 .63917 Mtetra
.36585 .63917 .37261 .64519 .38367 .64193 .37694 .63589 Mtetra
.37694 .63589 .38367 .64193 .39477 .63867 .38807 .6326 Mtetra
.38807 .6326 .39477 .63867 .40592 .63539 .39925 .6293 Mtetra
.39925 .6293 .40592 .63539 .41712 .6321 .41048 .62598 Mtetra
.41048 .62598 .41712 .6321 .42836 .62879 .42175 .62265 Mtetra
.42175 .62265 .42836 .62879 .43965 .62547 .43307 .6193 Mtetra
.43307 .6193 .43965 .62547 .45099 .62214 .44444 .61594 Mtetra
.44444 .61594 .45099 .62214 .46238 .61879 .45586 .61257 Mtetra
.45586 .61257 .46238 .61879 .47381 .61543 .46732 .60918 Mtetra
.46732 .60918 .47381 .61543 .48529 .61205 .47883 .60578 Mtetra
.47883 .60578 .48529 .61205 .49682 .60866 .4904 .60236 Mtetra
.4904 .60236 .49682 .60866 .5084 .60525 .50201 .59893 Mtetra
.95 .712 .542 r
.50201 .59893 .5084 .60525 .5202 .48054 .51406 .47396 Mtetra
.664 .741 .908 r
.51406 .47396 .5202 .48054 .53146 .47698 .52536 .47037 Mtetra
.52536 .47037 .53146 .47698 .54277 .47341 .5367 .46677 Mtetra
.5367 .46677 .54277 .47341 .55413 .46982 .54809 .46315 Mtetra
.54809 .46315 .55413 .46982 .56553 .46621 .55952 .45952 Mtetra
.55952 .45952 .56553 .46621 .57698 .46259 .571 .45587 Mtetra
.571 .45587 .57698 .46259 .58848 .45896 .58253 .45221 Mtetra
.58253 .45221 .58848 .45896 .60002 .45531 .59411 .44853 Mtetra
.59411 .44853 .60002 .45531 .61162 .45164 .60573 .44484 Mtetra
.60573 .44484 .61162 .45164 .62326 .44796 .61741 .44113 Mtetra
.61741 .44113 .62326 .44796 .63495 .44427 .62913 .4374 Mtetra
.62913 .4374 .63495 .44427 .64669 .44056 .6409 .43366 Mtetra
.6409 .43366 .64669 .44056 .65848 .43683 .65272 .42991 Mtetra
.65272 .42991 .65848 .43683 .67031 .43309 .6646 .42614 Mtetra
.6646 .42614 .67031 .43309 .6822 .42933 .67652 .42235 Mtetra
.67652 .42235 .6822 .42933 .69414 .42556 .68849 .41855 Mtetra
.68849 .41855 .69414 .42556 .70613 .42177 .70051 .41473 Mtetra
.70051 .41473 .70613 .42177 .71817 .41796 .71259 .41089 Mtetra
.71259 .41089 .71817 .41796 .73026 .41414 .72471 .40704 Mtetra
.72471 .40704 .73026 .41414 .7424 .4103 .73689 .40317 Mtetra
.73689 .40317 .7424 .4103 .75459 .40644 .74912 .39928 Mtetra
.74912 .39928 .75459 .40644 .76684 .40257 .76141 .39538 Mtetra
.76141 .39538 .76684 .40257 .77914 .39869 .77374 .39146 Mtetra
.77374 .39146 .77914 .39869 .79149 .39478 .78613 .38753 Mtetra
.78613 .38753 .79149 .39478 .80389 .39086 .79857 .38358 Mtetra
.79857 .38358 .80389 .39086 .81635 .38692 .81107 .37961 Mtetra
.81107 .37961 .81635 .38692 .82886 .38297 .82362 .37562 Mtetra
.82362 .37562 .82886 .38297 .84143 .37899 .83622 .37161 Mtetra
.83622 .37161 .84143 .37899 .85405 .375 .84888 .36759 Mtetra
.84888 .36759 .85405 .375 .86672 .371 .8616 .36355 Mtetra
.8616 .36355 .86672 .371 .87945 .36697 .87437 .3595 Mtetra
.87437 .3595 .87945 .36697 .89224 .36293 .88719 .35542 Mtetra
.88719 .35542 .89224 .36293 .90508 .35887 .90008 .35133 Mtetra
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.654 .753 .923 r
.31504 .64618 .32196 .65214 .33287 .64892 .32598 .64294 Mtetra
.32598 .64294 .33287 .64892 .34382 .64568 .33695 .63967 Mtetra
.33695 .63967 .34382 .64568 .35481 .64243 .34798 .6364 Mtetra
.34798 .6364 .35481 .64243 .36585 .63917 .35905 .63311 Mtetra
.35905 .63311 .36585 .63917 .37694 .63589 .37016 .62981 Mtetra
.37016 .62981 .37694 .63589 .38807 .6326 .38132 .62649 Mtetra
.38132 .62649 .38807 .6326 .39925 .6293 .39253 .62316 Mtetra
.39253 .62316 .39925 .6293 .41048 .62598 .40379 .61982 Mtetra
.40379 .61982 .41048 .62598 .42175 .62265 .41509 .61646 Mtetra
.41509 .61646 .42175 .62265 .43307 .6193 .42644 .61309 Mtetra
.42644 .61309 .43307 .6193 .44444 .61594 .43784 .6097 Mtetra
.43784 .6097 .44444 .61594 .45586 .61257 .44929 .6063 Mtetra
.44929 .6063 .45586 .61257 .46732 .60918 .46078 .60289 Mtetra
.46078 .60289 .46732 .60918 .47883 .60578 .47233 .59946 Mtetra
.47233 .59946 .47883 .60578 .4904 .60236 .48392 .59601 Mtetra
.48392 .59601 .4904 .60236 .50201 .59893 .49556 .59256 Mtetra
.95 .712 .542 r
.49556 .59256 .50201 .59893 .51406 .47396 .50788 .46732 Mtetra
.664 .741 .908 r
.50788 .46732 .51406 .47396 .52536 .47037 .51921 .46371 Mtetra
.51921 .46371 .52536 .47037 .5367 .46677 .53058 .46008 Mtetra
.53058 .46008 .5367 .46677 .54809 .46315 .542 .45643 Mtetra
.542 .45643 .54809 .46315 .55952 .45952 .55346 .45277 Mtetra
.55346 .45277 .55952 .45952 .571 .45587 .56497 .4491 Mtetra
.56497 .4491 .571 .45587 .58253 .45221 .57654 .44541 Mtetra
.57654 .44541 .58253 .45221 .59411 .44853 .58814 .4417 Mtetra
.58814 .4417 .59411 .44853 .60573 .44484 .5998 .43798 Mtetra
.5998 .43798 .60573 .44484 .61741 .44113 .61151 .43424 Mtetra
.61151 .43424 .61741 .44113 .62913 .4374 .62327 .43049 Mtetra
.62327 .43049 .62913 .4374 .6409 .43366 .63507 .42672 Mtetra
.63507 .42672 .6409 .43366 .65272 .42991 .64693 .42293 Mtetra
.64693 .42293 .65272 .42991 .6646 .42614 .65883 .41913 Mtetra
.65883 .41913 .6646 .42614 .67652 .42235 .67079 .41532 Mtetra
.67079 .41532 .67652 .42235 .68849 .41855 .6828 .41148 Mtetra
.6828 .41148 .68849 .41855 .70051 .41473 .69486 .40763 Mtetra
.69486 .40763 .70051 .41473 .71259 .41089 .70697 .40377 Mtetra
.70697 .40377 .71259 .41089 .72471 .40704 .71913 .39988 Mtetra
.71913 .39988 .72471 .40704 .73689 .40317 .73134 .39598 Mtetra
.73134 .39598 .73689 .40317 .74912 .39928 .74361 .39207 Mtetra
.74361 .39207 .74912 .39928 .76141 .39538 .75593 .38814 Mtetra
.75593 .38814 .76141 .39538 .77374 .39146 .7683 .38419 Mtetra
.7683 .38419 .77374 .39146 .78613 .38753 .78073 .38022 Mtetra
.78073 .38022 .78613 .38753 .79857 .38358 .79321 .37623 Mtetra
.79321 .37623 .79857 .38358 .81107 .37961 .80574 .37223 Mtetra
.80574 .37223 .81107 .37961 .82362 .37562 .81833 .36821 Mtetra
.81833 .36821 .82362 .37562 .83622 .37161 .83097 .36418 Mtetra
.83097 .36418 .83622 .37161 .84888 .36759 .84367 .36012 Mtetra
.84367 .36012 .84888 .36759 .8616 .36355 .85643 .35605 Mtetra
.85643 .35605 .8616 .36355 .87437 .3595 .86924 .35196 Mtetra
.86924 .35196 .87437 .3595 .88719 .35542 .88211 .34785 Mtetra
.88211 .34785 .88719 .35542 .90008 .35133 .89503 .34373 Mtetra
.89503 .34373 .90008 .35133 .91302 .34722 .90801 .33958 Mtetra
.654 .753 .923 r
.30807 .64018 .31504 .64618 .32598 .64294 .31903 .6369 Mtetra
.31903 .6369 .32598 .64294 .33695 .63967 .33004 .63362 Mtetra
.33004 .63362 .33695 .63967 .34798 .6364 .34109 .63032 Mtetra
.34109 .63032 .34798 .6364 .35905 .63311 .35219 .627 Mtetra
.35219 .627 .35905 .63311 .37016 .62981 .36333 .62368 Mtetra
.36333 .62368 .37016 .62981 .38132 .62649 .37452 .62033 Mtetra
.37452 .62033 .38132 .62649 .39253 .62316 .38576 .61698 Mtetra
.38576 .61698 .39253 .62316 .40379 .61982 .39705 .61361 Mtetra
.39705 .61361 .40379 .61982 .41509 .61646 .40838 .61023 Mtetra
.40838 .61023 .41509 .61646 .42644 .61309 .41976 .60683 Mtetra
.41976 .60683 .42644 .61309 .43784 .6097 .43119 .60341 Mtetra
.43119 .60341 .43784 .6097 .44929 .6063 .44267 .59999 Mtetra
.44267 .59999 .44929 .6063 .46078 .60289 .45419 .59655 Mtetra
.45419 .59655 .46078 .60289 .47233 .59946 .46577 .59309 Mtetra
.46577 .59309 .47233 .59946 .48392 .59601 .47739 .58962 Mtetra
.47739 .58962 .48392 .59601 .49556 .59256 .48907 .58613 Mtetra
.95 .712 .542 r
.48907 .58613 .49556 .59256 .50788 .46732 .50166 .46064 Mtetra
.664 .741 .908 r
.50166 .46064 .50788 .46732 .51921 .46371 .51301 .45699 Mtetra
.51301 .45699 .51921 .46371 .53058 .46008 .52441 .45334 Mtetra
.52441 .45334 .53058 .46008 .542 .45643 .53586 .44966 Mtetra
.53586 .44966 .542 .45643 .55346 .45277 .54736 .44598 Mtetra
.54736 .44598 .55346 .45277 .56497 .4491 .5589 .44227 Mtetra
.5589 .44227 .56497 .4491 .57654 .44541 .57049 .43855 Mtetra
.57049 .43855 .57654 .44541 .58814 .4417 .58214 .43482 Mtetra
.58214 .43482 .58814 .4417 .5998 .43798 .59383 .43107 Mtetra
.59383 .43107 .5998 .43798 .61151 .43424 .60557 .4273 Mtetra
.60557 .4273 .61151 .43424 .62327 .43049 .61736 .42352 Mtetra
.61736 .42352 .62327 .43049 .63507 .42672 .6292 .41972 Mtetra
.6292 .41972 .63507 .42672 .64693 .42293 .64109 .4159 Mtetra
.64109 .4159 .64693 .42293 .65883 .41913 .65303 .41207 Mtetra
.65303 .41207 .65883 .41913 .67079 .41532 .66502 .40823 Mtetra
.66502 .40823 .67079 .41532 .6828 .41148 .67706 .40436 Mtetra
.67706 .40436 .6828 .41148 .69486 .40763 .68915 .40048 Mtetra
.68915 .40048 .69486 .40763 .70697 .40377 .7013 .39659 Mtetra
.7013 .39659 .70697 .40377 .71913 .39988 .7135 .39267 Mtetra
.7135 .39267 .71913 .39988 .73134 .39598 .72575 .38874 Mtetra
.72575 .38874 .73134 .39598 .74361 .39207 .73805 .38479 Mtetra
.73805 .38479 .74361 .39207 .75593 .38814 .75041 .38083 Mtetra
.75041 .38083 .75593 .38814 .7683 .38419 .76282 .37685 Mtetra
.76282 .37685 .7683 .38419 .78073 .38022 .77528 .37285 Mtetra
.77528 .37285 .78073 .38022 .79321 .37623 .7878 .36883 Mtetra
.7878 .36883 .79321 .37623 .80574 .37223 .80037 .3648 Mtetra
.80037 .3648 .80574 .37223 .81833 .36821 .813 .36075 Mtetra
.813 .36075 .81833 .36821 .83097 .36418 .82568 .35668 Mtetra
.82568 .35668 .83097 .36418 .84367 .36012 .83842 .35259 Mtetra
.83842 .35259 .84367 .36012 .85643 .35605 .85122 .34849 Mtetra
.85122 .34849 .85643 .35605 .86924 .35196 .86407 .34436 Mtetra
.86407 .34436 .86924 .35196 .88211 .34785 .87698 .34022 Mtetra
.87698 .34022 .88211 .34785 .89503 .34373 .88994 .33606 Mtetra
.88994 .33606 .89503 .34373 .90801 .33958 .90297 .33188 Mtetra
.654 .753 .923 r
.30105 .63412 .30807 .64018 .31903 .6369 .31204 .63083 Mtetra
.31204 .63083 .31903 .6369 .33004 .63362 .32307 .62751 Mtetra
.32307 .62751 .33004 .63362 .34109 .63032 .33415 .62419 Mtetra
.33415 .62419 .34109 .63032 .35219 .627 .34528 .62085 Mtetra
.34528 .62085 .35219 .627 .36333 .62368 .35645 .6175 Mtetra
.35645 .6175 .36333 .62368 .37452 .62033 .36767 .61413 Mtetra
.36767 .61413 .37452 .62033 .38576 .61698 .37894 .61075 Mtetra
.37894 .61075 .38576 .61698 .39705 .61361 .39025 .60735 Mtetra
.39025 .60735 .39705 .61361 .40838 .61023 .40161 .60394 Mtetra
.40161 .60394 .40838 .61023 .41976 .60683 .41303 .60052 Mtetra
.41303 .60052 .41976 .60683 .43119 .60341 .42449 .59708 Mtetra
.42449 .59708 .43119 .60341 .44267 .59999 .43599 .59362 Mtetra
.43599 .59362 .44267 .59999 .45419 .59655 .44755 .59015 Mtetra
.44755 .59015 .45419 .59655 .46577 .59309 .45916 .58667 Mtetra
.45916 .58667 .46577 .59309 .47739 .58962 .47081 .58317 Mtetra
.47081 .58317 .47739 .58962 .48907 .58613 .48252 .57966 Mtetra
.95 .712 .542 r
.48252 .57966 .48907 .58613 .50166 .46064 .49538 .4539 Mtetra
.664 .741 .908 r
.49538 .4539 .50166 .46064 .51301 .45699 .50676 .45023 Mtetra
.50676 .45023 .51301 .45699 .52441 .45334 .5182 .44654 Mtetra
.5182 .44654 .52441 .45334 .53586 .44966 .52968 .44284 Mtetra
.52968 .44284 .53586 .44966 .54736 .44598 .5412 .43913 Mtetra
.5412 .43913 .54736 .44598 .5589 .44227 .55278 .43539 Mtetra
.55278 .43539 .5589 .44227 .57049 .43855 .56441 .43164 Mtetra
.56441 .43164 .57049 .43855 .58214 .43482 .57608 .42788 Mtetra
.57608 .42788 .58214 .43482 .59383 .43107 .5878 .4241 Mtetra
.5878 .4241 .59383 .43107 .60557 .4273 .59958 .4203 Mtetra
.59958 .4203 .60557 .4273 .61736 .42352 .6114 .41649 Mtetra
.6114 .41649 .61736 .42352 .6292 .41972 .62327 .41266 Mtetra
.62327 .41266 .6292 .41972 .64109 .4159 .6352 .40882 Mtetra
.6352 .40882 .64109 .4159 .65303 .41207 .64717 .40496 Mtetra
.64717 .40496 .65303 .41207 .66502 .40823 .6592 .40108 Mtetra
.6592 .40108 .66502 .40823 .67706 .40436 .67128 .39719 Mtetra
.67128 .39719 .67706 .40436 .68915 .40048 .6834 .39327 Mtetra
.6834 .39327 .68915 .40048 .7013 .39659 .69559 .38935 Mtetra
.69559 .38935 .7013 .39659 .7135 .39267 .70782 .3854 Mtetra
.70782 .3854 .7135 .39267 .72575 .38874 .72011 .38144 Mtetra
.72011 .38144 .72575 .38874 .73805 .38479 .73245 .37746 Mtetra
.73245 .37746 .73805 .38479 .75041 .38083 .74484 .37347 Mtetra
.74484 .37347 .75041 .38083 .76282 .37685 .75729 .36945 Mtetra
.75729 .36945 .76282 .37685 .77528 .37285 .76979 .36542 Mtetra
.76979 .36542 .77528 .37285 .7878 .36883 .78235 .36137 Mtetra
.78235 .36137 .7878 .36883 .80037 .3648 .79496 .35731 Mtetra
.79496 .35731 .80037 .3648 .813 .36075 .80763 .35322 Mtetra
.80763 .35322 .813 .36075 .82568 .35668 .82035 .34912 Mtetra
.82035 .34912 .82568 .35668 .83842 .35259 .83313 .345 Mtetra
.83313 .345 .83842 .35259 .85122 .34849 .84597 .34086 Mtetra
.84597 .34086 .85122 .34849 .86407 .34436 .85886 .3367 Mtetra
.85886 .3367 .86407 .34436 .87698 .34022 .87181 .33253 Mtetra
.87181 .33253 .87698 .34022 .88994 .33606 .88482 .32833 Mtetra
.88482 .32833 .88994 .33606 .90297 .33188 .89788 .32412 Mtetra
.654 .753 .923 r
.29397 .62803 .30105 .63412 .31204 .63083 .30499 .6247 Mtetra
.30499 .6247 .31204 .63083 .32307 .62751 .31605 .62136 Mtetra
.31605 .62136 .32307 .62751 .33415 .62419 .32716 .61801 Mtetra
.32716 .61801 .33415 .62419 .34528 .62085 .33831 .61465 Mtetra
.33831 .61465 .34528 .62085 .35645 .6175 .34951 .61127 Mtetra
.34951 .61127 .35645 .6175 .36767 .61413 .36076 .60787 Mtetra
.36076 .60787 .36767 .61413 .37894 .61075 .37206 .60447 Mtetra
.37206 .60447 .37894 .61075 .39025 .60735 .3834 .60104 Mtetra
.3834 .60104 .39025 .60735 .40161 .60394 .3948 .59761 Mtetra
.3948 .59761 .40161 .60394 .41303 .60052 .40624 .59415 Mtetra
.40624 .59415 .41303 .60052 .42449 .59708 .41773 .59069 Mtetra
.41773 .59069 .42449 .59708 .43599 .59362 .42927 .58721 Mtetra
.42927 .58721 .43599 .59362 .44755 .59015 .44086 .58371 Mtetra
.44086 .58371 .44755 .59015 .45916 .58667 .45249 .5802 Mtetra
.45249 .5802 .45916 .58667 .47081 .58317 .46418 .57667 Mtetra
.46418 .57667 .47081 .58317 .48252 .57966 .47592 .57313 Mtetra
.95 .712 .542 r
.47592 .57313 .48252 .57966 .49538 .4539 .48905 .44711 Mtetra
.664 .741 .908 r
.48905 .44711 .49538 .4539 .50676 .45023 .50047 .44341 Mtetra
.50047 .44341 .50676 .45023 .5182 .44654 .51193 .4397 Mtetra
.51193 .4397 .5182 .44654 .52968 .44284 .52344 .43597 Mtetra
.52344 .43597 .52968 .44284 .5412 .43913 .535 .43222 Mtetra
.535 .43222 .5412 .43913 .55278 .43539 .54661 .42846 Mtetra
.54661 .42846 .55278 .43539 .56441 .43164 .55827 .42468 Mtetra
.55827 .42468 .56441 .43164 .57608 .42788 .56998 .42089 Mtetra
.56998 .42089 .57608 .42788 .5878 .4241 .58173 .41708 Mtetra
.58173 .41708 .5878 .4241 .59958 .4203 .59354 .41325 Mtetra
.59354 .41325 .59958 .4203 .6114 .41649 .6054 .40941 Mtetra
.6054 .40941 .6114 .41649 .62327 .41266 .6173 .40555 Mtetra
.6173 .40555 .62327 .41266 .6352 .40882 .62926 .40168 Mtetra
.62926 .40168 .6352 .40882 .64717 .40496 .64127 .39779 Mtetra
.64127 .39779 .64717 .40496 .6592 .40108 .65333 .39388 Mtetra
.65333 .39388 .6592 .40108 .67128 .39719 .66545 .38995 Mtetra
.66545 .38995 .67128 .39719 .6834 .39327 .67761 .38601 Mtetra
.67761 .38601 .6834 .39327 .69559 .38935 .68983 .38205 Mtetra
.68983 .38205 .69559 .38935 .70782 .3854 .7021 .37807 Mtetra
.7021 .37807 .70782 .3854 .72011 .38144 .71442 .37408 Mtetra
.71442 .37408 .72011 .38144 .73245 .37746 .7268 .37007 Mtetra
.7268 .37007 .73245 .37746 .74484 .37347 .73923 .36604 Mtetra
.73923 .36604 .74484 .37347 .75729 .36945 .75172 .362 Mtetra
.75172 .362 .75729 .36945 .76979 .36542 .76426 .35793 Mtetra
.76426 .35793 .76979 .36542 .78235 .36137 .77685 .35385 Mtetra
.77685 .35385 .78235 .36137 .79496 .35731 .78951 .34975 Mtetra
.78951 .34975 .79496 .35731 .80763 .35322 .80221 .34563 Mtetra
.80221 .34563 .80763 .35322 .82035 .34912 .81498 .3415 Mtetra
.81498 .3415 .82035 .34912 .83313 .345 .82779 .33734 Mtetra
.82779 .33734 .83313 .345 .84597 .34086 .84067 .33317 Mtetra
.84067 .33317 .84597 .34086 .85886 .3367 .8536 .32898 Mtetra
.8536 .32898 .85886 .3367 .87181 .33253 .8666 .32477 Mtetra
.8666 .32477 .87181 .33253 .88482 .32833 .87965 .32054 Mtetra
.87965 .32054 .88482 .32833 .89788 .32412 .89275 .31629 Mtetra
.533 .289 .491 r
.28071 .71058 .29397 .62803 .30499 .6247 .29203 .70734 Mtetra
.29203 .70734 .30499 .6247 .31605 .62136 .30339 .70408 Mtetra
.30339 .70408 .31605 .62136 .32716 .61801 .3148 .70081 Mtetra
.3148 .70081 .32716 .61801 .33831 .61465 .32627 .69752 Mtetra
.32627 .69752 .33831 .61465 .34951 .61127 .33778 .69422 Mtetra
.33778 .69422 .34951 .61127 .36076 .60787 .34934 .6909 Mtetra
.34934 .6909 .36076 .60787 .37206 .60447 .36095 .68757 Mtetra
.36095 .68757 .37206 .60447 .3834 .60104 .37261 .68423 Mtetra
.37261 .68423 .3834 .60104 .3948 .59761 .38433 .68087 Mtetra
.38433 .68087 .3948 .59761 .40624 .59415 .39609 .6775 Mtetra
.39609 .6775 .40624 .59415 .41773 .59069 .40791 .67411 Mtetra
.40791 .67411 .41773 .59069 .42927 .58721 .41978 .6707 Mtetra
.41978 .6707 .42927 .58721 .44086 .58371 .4317 .66728 Mtetra
.4317 .66728 .44086 .58371 .45249 .5802 .44368 .66385 Mtetra
.44368 .66385 .45249 .5802 .46418 .57667 .45571 .6604 Mtetra
.45571 .6604 .46418 .57667 .47592 .57313 .46779 .65694 Mtetra
0 0 .161 r
.46779 .65694 .47592 .57313 .48905 .44711 .48122 .5532 Mtetra
.538 .3 .503 r
.48122 .5532 .48905 .44711 .50047 .44341 .49306 .54959 Mtetra
.49306 .54959 .50047 .44341 .51193 .4397 .50495 .54596 Mtetra
.50495 .54596 .51193 .4397 .52344 .43597 .5169 .54232 Mtetra
.5169 .54232 .52344 .43597 .535 .43222 .52889 .53866 Mtetra
.52889 .53866 .535 .43222 .54661 .42846 .54094 .53498 Mtetra
.54094 .53498 .54661 .42846 .55827 .42468 .55304 .53129 Mtetra
.55304 .53129 .55827 .42468 .56998 .42089 .56519 .52758 Mtetra
.56519 .52758 .56998 .42089 .58173 .41708 .5774 .52386 Mtetra
.5774 .52386 .58173 .41708 .59354 .41325 .58966 .52012 Mtetra
.58966 .52012 .59354 .41325 .6054 .40941 .60198 .51636 Mtetra
.60198 .51636 .6054 .40941 .6173 .40555 .61435 .51259 Mtetra
.61435 .51259 .6173 .40555 .62926 .40168 .62678 .50879 Mtetra
.62678 .50879 .62926 .40168 .64127 .39779 .63926 .50499 Mtetra
.63926 .50499 .64127 .39779 .65333 .39388 .65179 .50116 Mtetra
.65179 .50116 .65333 .39388 .66545 .38995 .66439 .49732 Mtetra
.66439 .49732 .66545 .38995 .67761 .38601 .67704 .49346 Mtetra
0 0 .348 r
.67704 .49346 .67761 .38601 .68983 .38205 .68402 .3747 Mtetra
.664 .741 .908 r
.68402 .3747 .68983 .38205 .7021 .37807 .69633 .37069 Mtetra
.69633 .37069 .7021 .37807 .71442 .37408 .70869 .36666 Mtetra
.70869 .36666 .71442 .37408 .7268 .37007 .72111 .36262 Mtetra
.72111 .36262 .7268 .37007 .73923 .36604 .73358 .35856 Mtetra
.73358 .35856 .73923 .36604 .75172 .362 .7461 .35448 Mtetra
.7461 .35448 .75172 .362 .76426 .35793 .75868 .35038 Mtetra
.75868 .35038 .76426 .35793 .77685 .35385 .77131 .34627 Mtetra
.77131 .34627 .77685 .35385 .78951 .34975 .78401 .34213 Mtetra
.78401 .34213 .78951 .34975 .80221 .34563 .79675 .33798 Mtetra
.79675 .33798 .80221 .34563 .81498 .3415 .80955 .33381 Mtetra
.80955 .33381 .81498 .3415 .82779 .33734 .82241 .32963 Mtetra
.82241 .32963 .82779 .33734 .84067 .33317 .83533 .32542 Mtetra
.83533 .32542 .84067 .33317 .8536 .32898 .84831 .32119 Mtetra
.84831 .32119 .8536 .32898 .8666 .32477 .86134 .31695 Mtetra
.86134 .31695 .8666 .32477 .87965 .32054 .87443 .31268 Mtetra
.87443 .31268 .87965 .32054 .89275 .31629 .88758 .3084 Mtetra
.646 .762 .934 r
.27331 .70458 .28071 .71058 .29203 .70734 .28466 .70131 Mtetra
.28466 .70131 .29203 .70734 .30339 .70408 .29605 .69803 Mtetra
.29605 .69803 .30339 .70408 .3148 .70081 .30749 .69473 Mtetra
.30749 .69473 .3148 .70081 .32627 .69752 .31899 .69141 Mtetra
.31899 .69141 .32627 .69752 .33778 .69422 .33053 .68809 Mtetra
.33053 .68809 .33778 .69422 .34934 .6909 .34212 .68474 Mtetra
.34212 .68474 .34934 .6909 .36095 .68757 .35377 .68139 Mtetra
.35377 .68139 .36095 .68757 .37261 .68423 .36546 .67802 Mtetra
.36546 .67802 .37261 .68423 .38433 .68087 .37721 .67463 Mtetra
.37721 .67463 .38433 .68087 .39609 .6775 .389 .67123 Mtetra
.389 .67123 .39609 .6775 .40791 .67411 .40085 .66781 Mtetra
.40085 .66781 .40791 .67411 .41978 .6707 .41276 .66438 Mtetra
.41276 .66438 .41978 .6707 .4317 .66728 .42471 .66093 Mtetra
.42471 .66093 .4317 .66728 .44368 .66385 .43672 .65747 Mtetra
.43672 .65747 .44368 .66385 .45571 .6604 .44878 .65399 Mtetra
.44878 .65399 .45571 .6604 .46779 .65694 .4609 .6505 Mtetra
.949 .718 .555 r
.4609 .6505 .46779 .65694 .48122 .5532 .47457 .54652 Mtetra
.655 .752 .921 r
.47457 .54652 .48122 .5532 .49306 .54959 .48644 .54288 Mtetra
.48644 .54288 .49306 .54959 .50495 .54596 .49837 .53922 Mtetra
.49837 .53922 .50495 .54596 .5169 .54232 .51034 .53555 Mtetra
.51034 .53555 .5169 .54232 .52889 .53866 .52237 .53186 Mtetra
.52237 .53186 .52889 .53866 .54094 .53498 .53446 .52815 Mtetra
.53446 .52815 .54094 .53498 .55304 .53129 .54659 .52443 Mtetra
.54659 .52443 .55304 .53129 .56519 .52758 .55878 .52069 Mtetra
.55878 .52069 .56519 .52758 .5774 .52386 .57103 .51694 Mtetra
.57103 .51694 .5774 .52386 .58966 .52012 .58332 .51317 Mtetra
.58332 .51317 .58966 .52012 .60198 .51636 .59568 .50938 Mtetra
.59568 .50938 .60198 .51636 .61435 .51259 .60808 .50557 Mtetra
.60808 .50557 .61435 .51259 .62678 .50879 .62055 .50175 Mtetra
.62055 .50175 .62678 .50879 .63926 .50499 .63306 .49791 Mtetra
.63306 .49791 .63926 .50499 .65179 .50116 .64564 .49406 Mtetra
.64564 .49406 .65179 .50116 .66439 .49732 .65827 .49018 Mtetra
.65827 .49018 .66439 .49732 .67704 .49346 .67096 .48629 Mtetra
.972 .72 .496 r
.67096 .48629 .67704 .49346 .68402 .3747 .67817 .36728 Mtetra
.664 .741 .908 r
.67817 .36728 .68402 .3747 .69633 .37069 .69052 .36324 Mtetra
.69052 .36324 .69633 .37069 .70869 .36666 .70292 .35918 Mtetra
.70292 .35918 .70869 .36666 .72111 .36262 .71537 .35511 Mtetra
.71537 .35511 .72111 .36262 .73358 .35856 .72788 .35101 Mtetra
.72788 .35101 .73358 .35856 .7461 .35448 .74044 .3469 Mtetra
.74044 .3469 .7461 .35448 .75868 .35038 .75306 .34277 Mtetra
.75306 .34277 .75868 .35038 .77131 .34627 .76573 .33862 Mtetra
.76573 .33862 .77131 .34627 .78401 .34213 .77846 .33446 Mtetra
.77846 .33446 .78401 .34213 .79675 .33798 .79125 .33027 Mtetra
.79125 .33027 .79675 .33798 .80955 .33381 .80409 .32607 Mtetra
.80409 .32607 .80955 .33381 .82241 .32963 .81699 .32184 Mtetra
.81699 .32184 .82241 .32963 .83533 .32542 .82995 .3176 Mtetra
.82995 .3176 .83533 .32542 .84831 .32119 .84297 .31334 Mtetra
.84297 .31334 .84831 .32119 .86134 .31695 .85604 .30906 Mtetra
.85604 .30906 .86134 .31695 .87443 .31268 .86918 .30476 Mtetra
.86918 .30476 .87443 .31268 .88758 .3084 .88237 .30044 Mtetra
.646 .762 .934 r
.26586 .69853 .27331 .70458 .28466 .70131 .27723 .69524 Mtetra
.27723 .69524 .28466 .70131 .29605 .69803 .28865 .69193 Mtetra
.28865 .69193 .29605 .69803 .30749 .69473 .30013 .6886 Mtetra
.30013 .6886 .30749 .69473 .31899 .69141 .31165 .68526 Mtetra
.31165 .68526 .31899 .69141 .33053 .68809 .32322 .6819 Mtetra
.32322 .6819 .33053 .68809 .34212 .68474 .33485 .67854 Mtetra
.33485 .67854 .34212 .68474 .35377 .68139 .34652 .67515 Mtetra
.34652 .67515 .35377 .68139 .36546 .67802 .35825 .67175 Mtetra
.35825 .67175 .36546 .67802 .37721 .67463 .37002 .66834 Mtetra
.37002 .66834 .37721 .67463 .389 .67123 .38185 .66491 Mtetra
.38185 .66491 .389 .67123 .40085 .66781 .39374 .66146 Mtetra
.39374 .66146 .40085 .66781 .41276 .66438 .40567 .658 Mtetra
.40567 .658 .41276 .66438 .42471 .66093 .41766 .65453 Mtetra
.41766 .65453 .42471 .66093 .43672 .65747 .4297 .65104 Mtetra
.4297 .65104 .43672 .65747 .44878 .65399 .4418 .64753 Mtetra
.4418 .64753 .44878 .65399 .4609 .6505 .45395 .64401 Mtetra
.949 .718 .555 r
.45395 .64401 .4609 .6505 .47457 .54652 .46786 .53978 Mtetra
.655 .752 .921 r
.46786 .53978 .47457 .54652 .48644 .54288 .47977 .53611 Mtetra
.47977 .53611 .48644 .54288 .49837 .53922 .49173 .53243 Mtetra
.49173 .53243 .49837 .53922 .51034 .53555 .50374 .52872 Mtetra
.50374 .52872 .51034 .53555 .52237 .53186 .5158 .52501 Mtetra
.5158 .52501 .52237 .53186 .53446 .52815 .52792 .52127 Mtetra
.52792 .52127 .53446 .52815 .54659 .52443 .54009 .51752 Mtetra
.54009 .51752 .54659 .52443 .55878 .52069 .55232 .51375 Mtetra
.55232 .51375 .55878 .52069 .57103 .51694 .5646 .50996 Mtetra
.5646 .50996 .57103 .51694 .58332 .51317 .57693 .50616 Mtetra
.57693 .50616 .58332 .51317 .59568 .50938 .58932 .50234 Mtetra
.58932 .50234 .59568 .50938 .60808 .50557 .60176 .4985 Mtetra
.60176 .4985 .60808 .50557 .62055 .50175 .61426 .49465 Mtetra
.61426 .49465 .62055 .50175 .63306 .49791 .62682 .49078 Mtetra
.62682 .49078 .63306 .49791 .64564 .49406 .63943 .48689 Mtetra
.63943 .48689 .64564 .49406 .65827 .49018 .6521 .48299 Mtetra
.6521 .48299 .65827 .49018 .67096 .48629 .66483 .47906 Mtetra
.972 .72 .496 r
.66483 .47906 .67096 .48629 .67817 .36728 .67228 .35981 Mtetra
.664 .741 .908 r
.67228 .35981 .67817 .36728 .69052 .36324 .68466 .35574 Mtetra
.68466 .35574 .69052 .36324 .70292 .35918 .69709 .35165 Mtetra
.69709 .35165 .70292 .35918 .71537 .35511 .70958 .34754 Mtetra
.70958 .34754 .71537 .35511 .72788 .35101 .72213 .34341 Mtetra
.72213 .34341 .72788 .35101 .74044 .3469 .73473 .33926 Mtetra
.73473 .33926 .74044 .3469 .75306 .34277 .74739 .3351 Mtetra
.74739 .3351 .75306 .34277 .76573 .33862 .7601 .33092 Mtetra
.7601 .33092 .76573 .33862 .77846 .33446 .77287 .32671 Mtetra
.77287 .32671 .77846 .33446 .79125 .33027 .7857 .32249 Mtetra
.7857 .32249 .79125 .33027 .80409 .32607 .79858 .31826 Mtetra
.79858 .31826 .80409 .32607 .81699 .32184 .81152 .314 Mtetra
.81152 .314 .81699 .32184 .82995 .3176 .82452 .30972 Mtetra
.82452 .30972 .82995 .3176 .84297 .31334 .83758 .30543 Mtetra
.83758 .30543 .84297 .31334 .85604 .30906 .8507 .30111 Mtetra
.8507 .30111 .85604 .30906 .86918 .30476 .86387 .29677 Mtetra
.86387 .29677 .86918 .30476 .88237 .30044 .87711 .29242 Mtetra
.646 .762 .934 r
.25834 .69244 .26586 .69853 .27723 .69524 .26974 .68911 Mtetra
.26974 .68911 .27723 .69524 .28865 .69193 .2812 .68577 Mtetra
.2812 .68577 .28865 .69193 .30013 .6886 .2927 .68242 Mtetra
.2927 .68242 .30013 .6886 .31165 .68526 .30425 .67905 Mtetra
.30425 .67905 .31165 .68526 .32322 .6819 .31586 .67567 Mtetra
.31586 .67567 .32322 .6819 .33485 .67854 .32751 .67228 Mtetra
.32751 .67228 .33485 .67854 .34652 .67515 .33922 .66886 Mtetra
.33922 .66886 .34652 .67515 .35825 .67175 .35097 .66544 Mtetra
.35097 .66544 .35825 .67175 .37002 .66834 .36278 .66199 Mtetra
.36278 .66199 .37002 .66834 .38185 .66491 .37465 .65854 Mtetra
.37465 .65854 .38185 .66491 .39374 .66146 .38656 .65506 Mtetra
.38656 .65506 .39374 .66146 .40567 .658 .39853 .65158 Mtetra
.39853 .65158 .40567 .658 .41766 .65453 .41055 .64807 Mtetra
.41055 .64807 .41766 .65453 .4297 .65104 .42263 .64455 Mtetra
.42263 .64455 .4297 .65104 .4418 .64753 .43476 .64102 Mtetra
.43476 .64102 .4418 .64753 .45395 .64401 .44695 .63747 Mtetra
.949 .718 .555 r
.44695 .63747 .45395 .64401 .46786 .53978 .4611 .533 Mtetra
.655 .752 .921 r
.4611 .533 .46786 .53978 .47977 .53611 .47304 .5293 Mtetra
.47304 .5293 .47977 .53611 .49173 .53243 .48504 .52558 Mtetra
.48504 .52558 .49173 .53243 .50374 .52872 .49708 .52185 Mtetra
.49708 .52185 .50374 .52872 .5158 .52501 .50918 .5181 Mtetra
.50918 .5181 .5158 .52501 .52792 .52127 .52133 .51433 Mtetra
.52133 .51433 .52792 .52127 .54009 .51752 .53354 .51055 Mtetra
.53354 .51055 .54009 .51752 .55232 .51375 .5458 .50675 Mtetra
.5458 .50675 .55232 .51375 .5646 .50996 .55811 .50293 Mtetra
.55811 .50293 .5646 .50996 .57693 .50616 .57049 .4991 Mtetra
.57049 .4991 .57693 .50616 .58932 .50234 .58291 .49525 Mtetra
.58291 .49525 .58932 .50234 .60176 .4985 .59539 .49138 Mtetra
.59539 .49138 .60176 .4985 .61426 .49465 .60793 .48749 Mtetra
.60793 .48749 .61426 .49465 .62682 .49078 .62052 .48359 Mtetra
.62052 .48359 .62682 .49078 .63943 .48689 .63318 .47967 Mtetra
.63318 .47967 .63943 .48689 .6521 .48299 .64588 .47573 Mtetra
.64588 .47573 .6521 .48299 .66483 .47906 .65865 .47177 Mtetra
.972 .72 .496 r
.65865 .47177 .66483 .47906 .67228 .35981 .66633 .35228 Mtetra
.664 .741 .908 r
.66633 .35228 .67228 .35981 .68466 .35574 .67875 .34817 Mtetra
.67875 .34817 .68466 .35574 .69709 .35165 .69122 .34404 Mtetra
.69122 .34404 .69709 .35165 .70958 .34754 .70375 .3399 Mtetra
.70375 .3399 .70958 .34754 .72213 .34341 .71633 .33574 Mtetra
.71633 .33574 .72213 .34341 .73473 .33926 .72897 .33156 Mtetra
.72897 .33156 .73473 .33926 .74739 .3351 .74167 .32736 Mtetra
.74167 .32736 .74739 .3351 .7601 .33092 .75442 .32315 Mtetra
.75442 .32315 .7601 .33092 .77287 .32671 .76723 .31891 Mtetra
.76723 .31891 .77287 .32671 .7857 .32249 .7801 .31465 Mtetra
.7801 .31465 .7857 .32249 .79858 .31826 .79302 .31038 Mtetra
.79302 .31038 .79858 .31826 .81152 .314 .80601 .30609 Mtetra
.80601 .30609 .81152 .314 .82452 .30972 .81905 .30177 Mtetra
.81905 .30177 .82452 .30972 .83758 .30543 .83215 .29744 Mtetra
.83215 .29744 .83758 .30543 .8507 .30111 .84531 .29309 Mtetra
.84531 .29309 .8507 .30111 .86387 .29677 .85853 .28872 Mtetra
.85853 .28872 .86387 .29677 .87711 .29242 .87181 .28433 Mtetra
.646 .762 .934 r
.25076 .68629 .25834 .69244 .26974 .68911 .2622 .68294 Mtetra
.2622 .68294 .26974 .68911 .2812 .68577 .27368 .67957 Mtetra
.27368 .67957 .2812 .68577 .2927 .68242 .28521 .67619 Mtetra
.28521 .67619 .2927 .68242 .30425 .67905 .29679 .6728 Mtetra
.29679 .6728 .30425 .67905 .31586 .67567 .30843 .66939 Mtetra
.30843 .66939 .31586 .67567 .32751 .67228 .32012 .66597 Mtetra
.32012 .66597 .32751 .67228 .33922 .66886 .33185 .66253 Mtetra
.33185 .66253 .33922 .66886 .35097 .66544 .34364 .65907 Mtetra
.34364 .65907 .35097 .66544 .36278 .66199 .35548 .6556 Mtetra
.35548 .6556 .36278 .66199 .37465 .65854 .36738 .65211 Mtetra
.36738 .65211 .37465 .65854 .38656 .65506 .37933 .64861 Mtetra
.37933 .64861 .38656 .65506 .39853 .65158 .39133 .64509 Mtetra
.39133 .64509 .39853 .65158 .41055 .64807 .40339 .64156 Mtetra
.40339 .64156 .41055 .64807 .42263 .64455 .4155 .63801 Mtetra
.4155 .63801 .42263 .64455 .43476 .64102 .42766 .63445 Mtetra
.42766 .63445 .43476 .64102 .44695 .63747 .43988 .63087 Mtetra
.949 .718 .555 r
.43988 .63087 .44695 .63747 .4611 .533 .45429 .52615 Mtetra
.655 .752 .921 r
.45429 .52615 .4611 .533 .47304 .5293 .46626 .52242 Mtetra
.46626 .52242 .47304 .5293 .48504 .52558 .47829 .51867 Mtetra
.47829 .51867 .48504 .52558 .49708 .52185 .49037 .51491 Mtetra
.49037 .51491 .49708 .52185 .50918 .5181 .5025 .51113 Mtetra
.5025 .51113 .50918 .5181 .52133 .51433 .51469 .50733 Mtetra
.51469 .50733 .52133 .51433 .53354 .51055 .52693 .50352 Mtetra
.52693 .50352 .53354 .51055 .5458 .50675 .53923 .49969 Mtetra
.53923 .49969 .5458 .50675 .55811 .50293 .55158 .49584 Mtetra
.55158 .49584 .55811 .50293 .57049 .4991 .56399 .49197 Mtetra
.56399 .49197 .57049 .4991 .58291 .49525 .57645 .48809 Mtetra
.57645 .48809 .58291 .49525 .59539 .49138 .58897 .48419 Mtetra
.58897 .48419 .59539 .49138 .60793 .48749 .60154 .48027 Mtetra
.60154 .48027 .60793 .48749 .62052 .48359 .61418 .47634 Mtetra
.61418 .47634 .62052 .48359 .63318 .47967 .62687 .47238 Mtetra
.62687 .47238 .63318 .47967 .64588 .47573 .63961 .46841 Mtetra
.63961 .46841 .64588 .47573 .65865 .47177 .65242 .46442 Mtetra
.972 .72 .496 r
.65242 .46442 .65865 .47177 .66633 .35228 .66033 .34468 Mtetra
.664 .741 .908 r
.66033 .34468 .66633 .35228 .67875 .34817 .67279 .34054 Mtetra
.67279 .34054 .67875 .34817 .69122 .34404 .6853 .33638 Mtetra
.6853 .33638 .69122 .34404 .70375 .3399 .69787 .3322 Mtetra
.69787 .3322 .70375 .3399 .71633 .33574 .71049 .32801 Mtetra
.71049 .32801 .71633 .33574 .72897 .33156 .72317 .3238 Mtetra
.72317 .3238 .72897 .33156 .74167 .32736 .73591 .31956 Mtetra
.73591 .31956 .74167 .32736 .75442 .32315 .7487 .31531 Mtetra
.7487 .31531 .75442 .32315 .76723 .31891 .76155 .31104 Mtetra
.76155 .31104 .76723 .31891 .7801 .31465 .77446 .30675 Mtetra
.77446 .30675 .7801 .31465 .79302 .31038 .78742 .30244 Mtetra
.78742 .30244 .79302 .31038 .80601 .30609 .80045 .29811 Mtetra
.80045 .29811 .80601 .30609 .81905 .30177 .81353 .29376 Mtetra
.81353 .29376 .81905 .30177 .83215 .29744 .82667 .28939 Mtetra
.82667 .28939 .83215 .29744 .84531 .29309 .83988 .285 Mtetra
.83988 .285 .84531 .29309 .85853 .28872 .85314 .2806 Mtetra
.85314 .2806 .85853 .28872 .87181 .28433 .86646 .27617 Mtetra
.646 .762 .934 r
.24313 .68009 .25076 .68629 .2622 .68294 .25459 .67671 Mtetra
.25459 .67671 .2622 .68294 .27368 .67957 .2661 .67332 Mtetra
.2661 .67332 .27368 .67957 .28521 .67619 .27766 .66992 Mtetra
.27766 .66992 .28521 .67619 .29679 .6728 .28928 .66649 Mtetra
.28928 .66649 .29679 .6728 .30843 .66939 .30094 .66306 Mtetra
.30094 .66306 .30843 .66939 .32012 .66597 .31266 .6596 Mtetra
.31266 .6596 .32012 .66597 .33185 .66253 .32443 .65613 Mtetra
.32443 .65613 .33185 .66253 .34364 .65907 .33625 .65265 Mtetra
.33625 .65265 .34364 .65907 .35548 .6556 .34813 .64915 Mtetra
.34813 .64915 .35548 .6556 .36738 .65211 .36005 .64564 Mtetra
.36005 .64564 .36738 .65211 .37933 .64861 .37203 .64211 Mtetra
.37203 .64211 .37933 .64861 .39133 .64509 .38407 .63856 Mtetra
.38407 .63856 .39133 .64509 .40339 .64156 .39616 .635 Mtetra
.39616 .635 .40339 .64156 .4155 .63801 .4083 .63142 Mtetra
.4083 .63142 .4155 .63801 .42766 .63445 .4205 .62782 Mtetra
.4205 .62782 .42766 .63445 .43988 .63087 .43276 .62421 Mtetra
.949 .718 .555 r
.43276 .62421 .43988 .63087 .45429 .52615 .44742 .51925 Mtetra
.655 .752 .921 r
.44742 .51925 .45429 .52615 .46626 .52242 .45943 .51549 Mtetra
.45943 .51549 .46626 .52242 .47829 .51867 .47149 .51171 Mtetra
.47149 .51171 .47829 .51867 .49037 .51491 .4836 .50792 Mtetra
.4836 .50792 .49037 .51491 .5025 .51113 .49577 .50411 Mtetra
.49577 .50411 .5025 .51113 .51469 .50733 .50799 .50028 Mtetra
.50799 .50028 .51469 .50733 .52693 .50352 .52027 .49643 Mtetra
.52027 .49643 .52693 .50352 .53923 .49969 .5326 .49257 Mtetra
.5326 .49257 .53923 .49969 .55158 .49584 .54499 .48869 Mtetra
.54499 .48869 .55158 .49584 .56399 .49197 .55743 .48479 Mtetra
.55743 .48479 .56399 .49197 .57645 .48809 .56993 .48088 Mtetra
.56993 .48088 .57645 .48809 .58897 .48419 .58249 .47694 Mtetra
.58249 .47694 .58897 .48419 .60154 .48027 .5951 .47299 Mtetra
.5951 .47299 .60154 .48027 .61418 .47634 .60777 .46902 Mtetra
.60777 .46902 .61418 .47634 .62687 .47238 .6205 .46504 Mtetra
.6205 .46504 .62687 .47238 .63961 .46841 .63329 .46103 Mtetra
.63329 .46103 .63961 .46841 .65242 .46442 .64614 .45701 Mtetra
.972 .72 .496 r
.64614 .45701 .65242 .46442 .66033 .34468 .65429 .33702 Mtetra
.664 .741 .908 r
.65429 .33702 .66033 .34468 .67279 .34054 .66679 .33285 Mtetra
.66679 .33285 .67279 .34054 .6853 .33638 .67933 .32866 Mtetra
.67933 .32866 .6853 .33638 .69787 .3322 .69194 .32444 Mtetra
.69194 .32444 .69787 .3322 .71049 .32801 .7046 .32021 Mtetra
.7046 .32021 .71049 .32801 .72317 .3238 .71732 .31597 Mtetra
.71732 .31597 .72317 .3238 .73591 .31956 .73009 .3117 Mtetra
.73009 .3117 .73591 .31956 .7487 .31531 .74293 .30741 Mtetra
.74293 .30741 .7487 .31531 .76155 .31104 .75582 .3031 Mtetra
.75582 .3031 .76155 .31104 .77446 .30675 .76877 .29878 Mtetra
.76877 .29878 .77446 .30675 .78742 .30244 .78177 .29443 Mtetra
.78177 .29443 .78742 .30244 .80045 .29811 .79484 .29007 Mtetra
.79484 .29007 .80045 .29811 .81353 .29376 .80797 .28568 Mtetra
.80797 .28568 .81353 .29376 .82667 .28939 .82115 .28128 Mtetra
.82115 .28128 .82667 .28939 .83988 .285 .8344 .27685 Mtetra
.8344 .27685 .83988 .285 .85314 .2806 .8477 .2724 Mtetra
.8477 .2724 .85314 .2806 .86646 .27617 .86107 .26794 Mtetra
.646 .762 .934 r
.23543 .67385 .24313 .68009 .25459 .67671 .24692 .67044 Mtetra
.24692 .67044 .25459 .67671 .2661 .67332 .25846 .66702 Mtetra
.25846 .66702 .2661 .67332 .27766 .66992 .27005 .66359 Mtetra
.27005 .66359 .27766 .66992 .28928 .66649 .2817 .66014 Mtetra
.2817 .66014 .28928 .66649 .30094 .66306 .29339 .65667 Mtetra
.29339 .65667 .30094 .66306 .31266 .6596 .30514 .65319 Mtetra
.30514 .65319 .31266 .6596 .32443 .65613 .31694 .64969 Mtetra
.31694 .64969 .32443 .65613 .33625 .65265 .3288 .64618 Mtetra
.3288 .64618 .33625 .65265 .34813 .64915 .3407 .64265 Mtetra
.3407 .64265 .34813 .64915 .36005 .64564 .35267 .63911 Mtetra
.35267 .63911 .36005 .64564 .37203 .64211 .36468 .63555 Mtetra
.36468 .63555 .37203 .64211 .38407 .63856 .37675 .63197 Mtetra
.37675 .63197 .38407 .63856 .39616 .635 .38887 .62838 Mtetra
.38887 .62838 .39616 .635 .4083 .63142 .40105 .62477 Mtetra
.40105 .62477 .4083 .63142 .4205 .62782 .41329 .62114 Mtetra
.41329 .62114 .4205 .62782 .43276 .62421 .42558 .6175 Mtetra
.949 .718 .555 r
.42558 .6175 .43276 .62421 .44742 .51925 .44049 .51229 Mtetra
.655 .752 .921 r
.44049 .51229 .44742 .51925 .45943 .51549 .45253 .5085 Mtetra
.45253 .5085 .45943 .51549 .47149 .51171 .46463 .50469 Mtetra
.46463 .50469 .47149 .51171 .4836 .50792 .47678 .50087 Mtetra
.47678 .50087 .4836 .50792 .49577 .50411 .48898 .49702 Mtetra
.48898 .49702 .49577 .50411 .50799 .50028 .50124 .49316 Mtetra
.50124 .49316 .50799 .50028 .52027 .49643 .51355 .48929 Mtetra
.51355 .48929 .52027 .49643 .5326 .49257 .52592 .48539 Mtetra
.52592 .48539 .5326 .49257 .54499 .48869 .53834 .48148 Mtetra
.53834 .48148 .54499 .48869 .55743 .48479 .55082 .47755 Mtetra
.55082 .47755 .55743 .48479 .56993 .48088 .56336 .4736 Mtetra
.56336 .4736 .56993 .48088 .58249 .47694 .57596 .46963 Mtetra
.57596 .46963 .58249 .47694 .5951 .47299 .58861 .46565 Mtetra
.58861 .46565 .5951 .47299 .60777 .46902 .60132 .46165 Mtetra
.60132 .46165 .60777 .46902 .6205 .46504 .61409 .45763 Mtetra
.61409 .45763 .6205 .46504 .63329 .46103 .62691 .45359 Mtetra
.62691 .45359 .63329 .46103 .64614 .45701 .6398 .44953 Mtetra
.972 .72 .496 r
.6398 .44953 .64614 .45701 .65429 .33702 .6482 .3293 Mtetra
.664 .741 .908 r
.6482 .3293 .65429 .33702 .66679 .33285 .66073 .32509 Mtetra
.66073 .32509 .66679 .33285 .67933 .32866 .67332 .32087 Mtetra
.67332 .32087 .67933 .32866 .69194 .32444 .68596 .31662 Mtetra
.68596 .31662 .69194 .32444 .7046 .32021 .69866 .31236 Mtetra
.69866 .31236 .7046 .32021 .71732 .31597 .71142 .30807 Mtetra
.71142 .30807 .71732 .31597 .73009 .3117 .72423 .30377 Mtetra
.72423 .30377 .73009 .3117 .74293 .30741 .73711 .29944 Mtetra
.73711 .29944 .74293 .30741 .75582 .3031 .75004 .2951 Mtetra
.75004 .2951 .75582 .3031 .76877 .29878 .76303 .29074 Mtetra
.76303 .29074 .76877 .29878 .78177 .29443 .77608 .28636 Mtetra
.77608 .28636 .78177 .29443 .79484 .29007 .78919 .28195 Mtetra
.78919 .28195 .79484 .29007 .80797 .28568 .80235 .27753 Mtetra
.80235 .27753 .80797 .28568 .82115 .28128 .81558 .27309 Mtetra
.81558 .27309 .82115 .28128 .8344 .27685 .82887 .26863 Mtetra
.82887 .26863 .8344 .27685 .8477 .2724 .84222 .26414 Mtetra
.84222 .26414 .8477 .2724 .86107 .26794 .85563 .25964 Mtetra
.646 .762 .934 r
.22766 .66755 .23543 .67385 .24692 .67044 .23918 .66411 Mtetra
.23918 .66411 .24692 .67044 .25846 .66702 .25076 .66067 Mtetra
.25076 .66067 .25846 .66702 .27005 .66359 .26238 .6572 Mtetra
.26238 .6572 .27005 .66359 .2817 .66014 .27406 .65372 Mtetra
.27406 .65372 .2817 .66014 .29339 .65667 .28578 .65023 Mtetra
.28578 .65023 .29339 .65667 .30514 .65319 .29756 .64672 Mtetra
.29756 .64672 .30514 .65319 .31694 .64969 .3094 .64319 Mtetra
.3094 .64319 .31694 .64969 .3288 .64618 .32128 .63965 Mtetra
.32128 .63965 .3288 .64618 .3407 .64265 .33322 .6361 Mtetra
.33322 .6361 .3407 .64265 .35267 .63911 .34522 .63252 Mtetra
.34522 .63252 .35267 .63911 .36468 .63555 .35726 .62893 Mtetra
.35726 .62893 .36468 .63555 .37675 .63197 .36937 .62533 Mtetra
.36937 .62533 .37675 .63197 .38887 .62838 .38152 .6217 Mtetra
.38152 .6217 .38887 .62838 .40105 .62477 .39374 .61806 Mtetra
.39374 .61806 .40105 .62477 .41329 .62114 .40601 .61441 Mtetra
.40601 .61441 .41329 .62114 .42558 .6175 .41833 .61074 Mtetra
.949 .718 .555 r
.41833 .61074 .42558 .6175 .44049 .51229 .43351 .50528 Mtetra
.655 .752 .921 r
.43351 .50528 .44049 .51229 .45253 .5085 .44558 .50146 Mtetra
.44558 .50146 .45253 .5085 .46463 .50469 .45771 .49762 Mtetra
.45771 .49762 .46463 .50469 .47678 .50087 .4699 .49376 Mtetra
.4699 .49376 .47678 .50087 .48898 .49702 .48213 .48988 Mtetra
.48213 .48988 .48898 .49702 .50124 .49316 .49443 .48599 Mtetra
.49443 .48599 .50124 .49316 .51355 .48929 .50678 .48208 Mtetra
.50678 .48208 .51355 .48929 .52592 .48539 .51918 .47815 Mtetra
.51918 .47815 .52592 .48539 .53834 .48148 .53164 .47421 Mtetra
.53164 .47421 .53834 .48148 .55082 .47755 .54416 .47025 Mtetra
.54416 .47025 .55082 .47755 .56336 .4736 .55674 .46626 Mtetra
.55674 .46626 .56336 .4736 .57596 .46963 .56937 .46226 Mtetra
.56937 .46226 .57596 .46963 .58861 .46565 .58206 .45825 Mtetra
.58206 .45825 .58861 .46565 .60132 .46165 .59481 .45421 Mtetra
.59481 .45421 .60132 .46165 .61409 .45763 .60761 .45015 Mtetra
.60761 .45015 .61409 .45763 .62691 .45359 .62048 .44608 Mtetra
.62048 .44608 .62691 .45359 .6398 .44953 .63341 .44199 Mtetra
.972 .72 .496 r
.63341 .44199 .6398 .44953 .6482 .3293 .64206 .32152 Mtetra
.664 .741 .908 r
.64206 .32152 .6482 .3293 .66073 .32509 .65462 .31728 Mtetra
.65462 .31728 .66073 .32509 .67332 .32087 .66725 .31301 Mtetra
.66725 .31301 .67332 .32087 .68596 .31662 .67993 .30873 Mtetra
.67993 .30873 .68596 .31662 .69866 .31236 .69267 .30443 Mtetra
.69267 .30443 .69866 .31236 .71142 .30807 .70547 .30011 Mtetra
.70547 .30011 .71142 .30807 .72423 .30377 .71832 .29577 Mtetra
.71832 .29577 .72423 .30377 .73711 .29944 .73124 .29141 Mtetra
.73124 .29141 .73711 .29944 .75004 .2951 .74421 .28703 Mtetra
.74421 .28703 .75004 .2951 .76303 .29074 .75724 .28263 Mtetra
.75724 .28263 .76303 .29074 .77608 .28636 .77033 .27821 Mtetra
.77033 .27821 .77608 .28636 .78919 .28195 .78348 .27377 Mtetra
.78348 .27377 .78919 .28195 .80235 .27753 .79669 .26932 Mtetra
.79669 .26932 .80235 .27753 .81558 .27309 .80997 .26483 Mtetra
.80997 .26483 .81558 .27309 .82887 .26863 .8233 .26033 Mtetra
.8233 .26033 .82887 .26863 .84222 .26414 .83669 .25581 Mtetra
.83669 .25581 .84222 .26414 .85563 .25964 .85015 .25127 Mtetra
.646 .762 .934 r
.21984 .6612 .22766 .66755 .23918 .66411 .23139 .65774 Mtetra
.23139 .65774 .23918 .66411 .25076 .66067 .24299 .65426 Mtetra
.24299 .65426 .25076 .66067 .26238 .6572 .25464 .65077 Mtetra
.25464 .65077 .26238 .6572 .27406 .65372 .26635 .64726 Mtetra
.26635 .64726 .27406 .65372 .28578 .65023 .27811 .64374 Mtetra
.27811 .64374 .28578 .65023 .29756 .64672 .28992 .6402 Mtetra
.28992 .6402 .29756 .64672 .3094 .64319 .30179 .63664 Mtetra
.30179 .63664 .3094 .64319 .32128 .63965 .3137 .63307 Mtetra
.3137 .63307 .32128 .63965 .33322 .6361 .32568 .62949 Mtetra
.32568 .62949 .33322 .6361 .34522 .63252 .3377 .62588 Mtetra
.3377 .62588 .34522 .63252 .35726 .62893 .34979 .62226 Mtetra
.34979 .62226 .35726 .62893 .36937 .62533 .36192 .61862 Mtetra
.36192 .61862 .36937 .62533 .38152 .6217 .37411 .61497 Mtetra
.37411 .61497 .38152 .6217 .39374 .61806 .38636 .6113 Mtetra
.38636 .6113 .39374 .61806 .40601 .61441 .39867 .60762 Mtetra
.39867 .60762 .40601 .61441 .41833 .61074 .41103 .60391 Mtetra
.949 .718 .555 r
.41103 .60391 .41833 .61074 .43351 .50528 .42647 .49821 Mtetra
.655 .752 .921 r
.42647 .49821 .43351 .50528 .44558 .50146 .43858 .49435 Mtetra
.43858 .49435 .44558 .50146 .45771 .49762 .45074 .49048 Mtetra
.45074 .49048 .45771 .49762 .4699 .49376 .46296 .48659 Mtetra
.46296 .48659 .4699 .49376 .48213 .48988 .47523 .48268 Mtetra
.47523 .48268 .48213 .48988 .49443 .48599 .48756 .47876 Mtetra
.48756 .47876 .49443 .48599 .50678 .48208 .49995 .47482 Mtetra
.49995 .47482 .50678 .48208 .51918 .47815 .51239 .47086 Mtetra
.51239 .47086 .51918 .47815 .53164 .47421 .52489 .46688 Mtetra
.52489 .46688 .53164 .47421 .54416 .47025 .53744 .46288 Mtetra
.53744 .46288 .54416 .47025 .55674 .46626 .55005 .45887 Mtetra
.55005 .45887 .55674 .46626 .56937 .46226 .56273 .45483 Mtetra
.56273 .45483 .56937 .46226 .58206 .45825 .57545 .45078 Mtetra
.57545 .45078 .58206 .45825 .59481 .45421 .58824 .44671 Mtetra
.58824 .44671 .59481 .45421 .60761 .45015 .60109 .44262 Mtetra
.60109 .44262 .60761 .45015 .62048 .44608 .61399 .43851 Mtetra
.61399 .43851 .62048 .44608 .63341 .44199 .62696 .43438 Mtetra
.972 .72 .496 r
.62696 .43438 .63341 .44199 .64206 .32152 .63586 .31367 Mtetra
.664 .741 .908 r
.63586 .31367 .64206 .32152 .65462 .31728 .64847 .30939 Mtetra
.64847 .30939 .65462 .31728 .66725 .31301 .66113 .30509 Mtetra
.66113 .30509 .66725 .31301 .67993 .30873 .67385 .30078 Mtetra
.67385 .30078 .67993 .30873 .69267 .30443 .68663 .29644 Mtetra
.68663 .29644 .69267 .30443 .70547 .30011 .69947 .29208 Mtetra
.69947 .29208 .70547 .30011 .71832 .29577 .71237 .28771 Mtetra
.71237 .28771 .71832 .29577 .73124 .29141 .72532 .28331 Mtetra
.72532 .28331 .73124 .29141 .74421 .28703 .73833 .2789 Mtetra
.73833 .2789 .74421 .28703 .75724 .28263 .75141 .27446 Mtetra
.75141 .27446 .75724 .28263 .77033 .27821 .76454 .27 Mtetra
.76454 .27 .77033 .27821 .78348 .27377 .77773 .26553 Mtetra
.77773 .26553 .78348 .27377 .79669 .26932 .79099 .26103 Mtetra
.79099 .26103 .79669 .26932 .80997 .26483 .8043 .25651 Mtetra
.8043 .25651 .80997 .26483 .8233 .26033 .81768 .25197 Mtetra
.81768 .25197 .8233 .26033 .83669 .25581 .83112 .24741 Mtetra
.83112 .24741 .83669 .25581 .85015 .25127 .84462 .24283 Mtetra
.646 .762 .934 r
.21194 .6548 .21984 .6612 .23139 .65774 .22353 .65131 Mtetra
.22353 .65131 .23139 .65774 .24299 .65426 .23516 .6478 Mtetra
.23516 .6478 .24299 .65426 .25464 .65077 .24684 .64428 Mtetra
.24684 .64428 .25464 .65077 .26635 .64726 .25858 .64074 Mtetra
.25858 .64074 .26635 .64726 .27811 .64374 .27037 .63719 Mtetra
.27037 .63719 .27811 .64374 .28992 .6402 .28221 .63362 Mtetra
.28221 .63362 .28992 .6402 .30179 .63664 .29411 .63004 Mtetra
.29411 .63004 .30179 .63664 .3137 .63307 .30606 .62644 Mtetra
.30606 .62644 .3137 .63307 .32568 .62949 .31807 .62282 Mtetra
.31807 .62282 .32568 .62949 .3377 .62588 .33013 .61919 Mtetra
.33013 .61919 .3377 .62588 .34979 .62226 .34224 .61553 Mtetra
.34224 .61553 .34979 .62226 .36192 .61862 .35441 .61187 Mtetra
.35441 .61187 .36192 .61862 .37411 .61497 .36664 .60818 Mtetra
.36664 .60818 .37411 .61497 .38636 .6113 .37892 .60448 Mtetra
.37892 .60448 .38636 .6113 .39867 .60762 .39126 .60076 Mtetra
.39126 .60076 .39867 .60762 .41103 .60391 .40366 .59703 Mtetra
.949 .718 .555 r
.40366 .59703 .41103 .60391 .42647 .49821 .41937 .49108 Mtetra
.655 .752 .921 r
.41937 .49108 .42647 .49821 .43858 .49435 .43151 .48719 Mtetra
.43151 .48719 .43858 .49435 .45074 .49048 .44371 .48329 Mtetra
.44371 .48329 .45074 .49048 .46296 .48659 .45596 .47936 Mtetra
.45596 .47936 .46296 .48659 .47523 .48268 .46827 .47542 Mtetra
.46827 .47542 .47523 .48268 .48756 .47876 .48064 .47147 Mtetra
.48064 .47147 .48756 .47876 .49995 .47482 .49306 .46749 Mtetra
.49306 .46749 .49995 .47482 .51239 .47086 .50554 .4635 Mtetra
.50554 .4635 .51239 .47086 .52489 .46688 .51807 .45948 Mtetra
.51807 .45948 .52489 .46688 .53744 .46288 .53067 .45545 Mtetra
.53067 .45545 .53744 .46288 .55005 .45887 .54332 .4514 Mtetra
.54332 .4514 .55005 .45887 .56273 .45483 .55603 .44734 Mtetra
.55603 .44734 .56273 .45483 .57545 .45078 .56879 .44325 Mtetra
.56879 .44325 .57545 .45078 .58824 .44671 .58162 .43914 Mtetra
.58162 .43914 .58824 .44671 .60109 .44262 .59451 .43502 Mtetra
.59451 .43502 .60109 .44262 .61399 .43851 .60745 .43088 Mtetra
.60745 .43088 .61399 .43851 .62696 .43438 .62046 .42671 Mtetra
.972 .72 .496 r
.62046 .42671 .62696 .43438 .63586 .31367 .62962 .30576 Mtetra
.664 .741 .908 r
.62962 .30576 .63586 .31367 .64847 .30939 .64226 .30144 Mtetra
.64226 .30144 .64847 .30939 .66113 .30509 .65497 .29711 Mtetra
.65497 .29711 .66113 .30509 .67385 .30078 .66773 .29276 Mtetra
.66773 .29276 .67385 .30078 .68663 .29644 .68054 .28838 Mtetra
.68054 .28838 .68663 .29644 .69947 .29208 .69342 .28399 Mtetra
.69342 .28399 .69947 .29208 .71237 .28771 .70636 .27958 Mtetra
.70636 .27958 .71237 .28771 .72532 .28331 .71935 .27514 Mtetra
.71935 .27514 .72532 .28331 .73833 .2789 .73241 .27069 Mtetra
.73241 .27069 .73833 .2789 .75141 .27446 .74552 .26622 Mtetra
.74552 .26622 .75141 .27446 .76454 .27 .7587 .26172 Mtetra
.7587 .26172 .76454 .27 .77773 .26553 .77193 .25721 Mtetra
.77193 .25721 .77773 .26553 .79099 .26103 .78523 .25267 Mtetra
.78523 .25267 .79099 .26103 .8043 .25651 .79859 .24811 Mtetra
.79859 .24811 .8043 .25651 .81768 .25197 .81201 .24353 Mtetra
.81201 .24353 .81768 .25197 .83112 .24741 .82549 .23893 Mtetra
.82549 .23893 .83112 .24741 .84462 .24283 .83904 .23431 Mtetra
.646 .762 .934 r
.20399 .64834 .21194 .6548 .22353 .65131 .2156 .64482 Mtetra
.2156 .64482 .22353 .65131 .23516 .6478 .22726 .64129 Mtetra
.22726 .64129 .23516 .6478 .24684 .64428 .23898 .63774 Mtetra
.23898 .63774 .24684 .64428 .25858 .64074 .25075 .63417 Mtetra
.25075 .63417 .25858 .64074 .27037 .63719 .26257 .63059 Mtetra
.26257 .63059 .27037 .63719 .28221 .63362 .27444 .62699 Mtetra
.27444 .62699 .28221 .63362 .29411 .63004 .28637 .62338 Mtetra
.28637 .62338 .29411 .63004 .30606 .62644 .29836 .61975 Mtetra
.29836 .61975 .30606 .62644 .31807 .62282 .3104 .6161 Mtetra
.3104 .6161 .31807 .62282 .33013 .61919 .32249 .61243 Mtetra
.32249 .61243 .33013 .61919 .34224 .61553 .33464 .60875 Mtetra
.33464 .60875 .34224 .61553 .35441 .61187 .34684 .60505 Mtetra
.34684 .60505 .35441 .61187 .36664 .60818 .3591 .60134 Mtetra
.3591 .60134 .36664 .60818 .37892 .60448 .37142 .5976 Mtetra
.37142 .5976 .37892 .60448 .39126 .60076 .3838 .59385 Mtetra
.3838 .59385 .39126 .60076 .40366 .59703 .39623 .59009 Mtetra
.949 .718 .555 r
.39623 .59009 .40366 .59703 .41937 .49108 .41221 .48389 Mtetra
.655 .752 .921 r
.41221 .48389 .41937 .49108 .43151 .48719 .42439 .47997 Mtetra
.42439 .47997 .43151 .48719 .44371 .48329 .43662 .47603 Mtetra
.43662 .47603 .44371 .48329 .45596 .47936 .44891 .47208 Mtetra
.44891 .47208 .45596 .47936 .46827 .47542 .46125 .4681 Mtetra
.46125 .4681 .46827 .47542 .48064 .47147 .47366 .46411 Mtetra
.47366 .46411 .48064 .47147 .49306 .46749 .48611 .4601 Mtetra
.48611 .4601 .49306 .46749 .50554 .4635 .49863 .45607 Mtetra
.49863 .45607 .50554 .4635 .51807 .45948 .5112 .45203 Mtetra
.5112 .45203 .51807 .45948 .53067 .45545 .52383 .44796 Mtetra
.52383 .44796 .53067 .45545 .54332 .4514 .53652 .44388 Mtetra
.53652 .44388 .54332 .4514 .55603 .44734 .54927 .43978 Mtetra
.54927 .43978 .55603 .44734 .56879 .44325 .56207 .43566 Mtetra
.56207 .43566 .56879 .44325 .58162 .43914 .57494 .43151 Mtetra
.57494 .43151 .58162 .43914 .59451 .43502 .58787 .42735 Mtetra
.58787 .42735 .59451 .43502 .60745 .43088 .60085 .42317 Mtetra
.60085 .42317 .60745 .43088 .62046 .42671 .6139 .41898 Mtetra
.972 .72 .496 r
.6139 .41898 .62046 .42671 .62962 .30576 .62332 .29778 Mtetra
.664 .741 .908 r
.62332 .29778 .62962 .30576 .64226 .30144 .636 .29343 Mtetra
.636 .29343 .64226 .30144 .65497 .29711 .64874 .28906 Mtetra
.64874 .28906 .65497 .29711 .66773 .29276 .66155 .28467 Mtetra
.66155 .28467 .66773 .29276 .68054 .28838 .6744 .28026 Mtetra
.6744 .28026 .68054 .28838 .69342 .28399 .68732 .27583 Mtetra
.68732 .27583 .69342 .28399 .70636 .27958 .7003 .27138 Mtetra
.7003 .27138 .70636 .27958 .71935 .27514 .71333 .26691 Mtetra
.71333 .26691 .71935 .27514 .73241 .27069 .72643 .26241 Mtetra
.72643 .26241 .73241 .27069 .74552 .26622 .73959 .2579 Mtetra
.73959 .2579 .74552 .26622 .7587 .26172 .7528 .25337 Mtetra
.7528 .25337 .7587 .26172 .77193 .25721 .76608 .24881 Mtetra
.76608 .24881 .77193 .25721 .78523 .25267 .77942 .24424 Mtetra
.77942 .24424 .78523 .25267 .79859 .24811 .79283 .23964 Mtetra
.79283 .23964 .79859 .24811 .81201 .24353 .80629 .23502 Mtetra
.80629 .23502 .81201 .24353 .82549 .23893 .81982 .23039 Mtetra
.81982 .23039 .82549 .23893 .83904 .23431 .83341 .22572 Mtetra
.646 .762 .934 r
.19597 .64183 .20399 .64834 .2156 .64482 .20761 .63829 Mtetra
.20761 .63829 .2156 .64482 .22726 .64129 .2193 .63472 Mtetra
.2193 .63472 .22726 .64129 .23898 .63774 .23105 .63114 Mtetra
.23105 .63114 .23898 .63774 .25075 .63417 .24285 .62755 Mtetra
.24285 .62755 .25075 .63417 .26257 .63059 .2547 .62393 Mtetra
.2547 .62393 .26257 .63059 .27444 .62699 .26661 .62031 Mtetra
.26661 .62031 .27444 .62699 .28637 .62338 .27857 .61666 Mtetra
.27857 .61666 .28637 .62338 .29836 .61975 .29059 .613 Mtetra
.29059 .613 .29836 .61975 .3104 .6161 .30266 .60932 Mtetra
.30266 .60932 .3104 .6161 .32249 .61243 .31479 .60562 Mtetra
.31479 .60562 .32249 .61243 .33464 .60875 .32697 .60191 Mtetra
.32697 .60191 .33464 .60875 .34684 .60505 .33921 .59818 Mtetra
.33921 .59818 .34684 .60505 .3591 .60134 .3515 .59443 Mtetra
.3515 .59443 .3591 .60134 .37142 .5976 .36386 .59067 Mtetra
.36386 .59067 .37142 .5976 .3838 .59385 .37627 .58689 Mtetra
.37627 .58689 .3838 .59385 .39623 .59009 .38873 .58309 Mtetra
.949 .718 .555 r
.38873 .58309 .39623 .59009 .41221 .48389 .40499 .47664 Mtetra
.655 .752 .921 r
.40499 .47664 .41221 .48389 .42439 .47997 .4172 .47269 Mtetra
.4172 .47269 .42439 .47997 .43662 .47603 .42947 .46872 Mtetra
.42947 .46872 .43662 .47603 .44891 .47208 .4418 .46473 Mtetra
.4418 .46473 .44891 .47208 .46125 .4681 .45418 .46072 Mtetra
.45418 .46072 .46125 .4681 .47366 .46411 .46661 .4567 Mtetra
.46661 .4567 .47366 .46411 .48611 .4601 .47911 .45265 Mtetra
.47911 .45265 .48611 .4601 .49863 .45607 .49166 .44859 Mtetra
.49166 .44859 .49863 .45607 .5112 .45203 .50427 .44451 Mtetra
.50427 .44451 .5112 .45203 .52383 .44796 .51694 .44041 Mtetra
.51694 .44041 .52383 .44796 .53652 .44388 .52967 .43629 Mtetra
.52967 .43629 .53652 .44388 .54927 .43978 .54245 .43215 Mtetra
.54245 .43215 .54927 .43978 .56207 .43566 .5553 .428 Mtetra
.5553 .428 .56207 .43566 .57494 .43151 .5682 .42382 Mtetra
.5682 .42382 .57494 .43151 .58787 .42735 .58117 .41962 Mtetra
.58117 .41962 .58787 .42735 .60085 .42317 .5942 .41541 Mtetra
.5942 .41541 .60085 .42317 .6139 .41898 .60729 .41117 Mtetra
.972 .72 .496 r
.60729 .41117 .6139 .41898 .62332 .29778 .61697 .28973 Mtetra
.664 .741 .908 r
.61697 .28973 .62332 .29778 .636 .29343 .62969 .28534 Mtetra
.62969 .28534 .636 .29343 .64874 .28906 .64247 .28094 Mtetra
.64247 .28094 .64874 .28906 .66155 .28467 .65531 .27651 Mtetra
.65531 .27651 .66155 .28467 .6744 .28026 .66821 .27206 Mtetra
.66821 .27206 .6744 .28026 .68732 .27583 .68117 .26759 Mtetra
.68117 .26759 .68732 .27583 .7003 .27138 .69419 .26311 Mtetra
.69419 .26311 .7003 .27138 .71333 .26691 .70726 .2586 Mtetra
.70726 .2586 .71333 .26691 .72643 .26241 .7204 .25407 Mtetra
.7204 .25407 .72643 .26241 .73959 .2579 .7336 .24952 Mtetra
.7336 .24952 .73959 .2579 .7528 .25337 .74686 .24494 Mtetra
.74686 .24494 .7528 .25337 .76608 .24881 .76018 .24035 Mtetra
.76018 .24035 .76608 .24881 .77942 .24424 .77357 .23574 Mtetra
.77357 .23574 .77942 .24424 .79283 .23964 .78702 .2311 Mtetra
.78702 .2311 .79283 .23964 .80629 .23502 .80053 .22644 Mtetra
.80053 .22644 .80629 .23502 .81982 .23039 .8141 .22176 Mtetra
.8141 .22176 .81982 .23039 .83341 .22572 .82774 .21706 Mtetra
.646 .762 .934 r
.18788 .63527 .19597 .64183 .20761 .63829 .19955 .63169 Mtetra
.19955 .63169 .20761 .63829 .2193 .63472 .21127 .6281 Mtetra
.21127 .6281 .2193 .63472 .23105 .63114 .22305 .62449 Mtetra
.22305 .62449 .23105 .63114 .24285 .62755 .23488 .62086 Mtetra
.23488 .62086 .24285 .62755 .2547 .62393 .24677 .61722 Mtetra
.24677 .61722 .2547 .62393 .26661 .62031 .25871 .61356 Mtetra
.25871 .61356 .26661 .62031 .27857 .61666 .2707 .60989 Mtetra
.2707 .60989 .27857 .61666 .29059 .613 .28275 .60619 Mtetra
.28275 .60619 .29059 .613 .30266 .60932 .29485 .60248 Mtetra
.29485 .60248 .30266 .60932 .31479 .60562 .30702 .59875 Mtetra
.30702 .59875 .31479 .60562 .32697 .60191 .31923 .59501 Mtetra
.31923 .59501 .32697 .60191 .33921 .59818 .33151 .59125 Mtetra
.33151 .59125 .33921 .59818 .3515 .59443 .34384 .58747 Mtetra
.34384 .58747 .3515 .59443 .36386 .59067 .35622 .58367 Mtetra
.35622 .58367 .36386 .59067 .37627 .58689 .36867 .57986 Mtetra
.36867 .57986 .37627 .58689 .38873 .58309 .38117 .57602 Mtetra
.949 .718 .555 r
.38117 .57602 .38873 .58309 .40499 .47664 .39771 .46933 Mtetra
.655 .752 .921 r
.39771 .46933 .40499 .47664 .4172 .47269 .40996 .46534 Mtetra
.40996 .46534 .4172 .47269 .42947 .46872 .42226 .46134 Mtetra
.42226 .46134 .42947 .46872 .4418 .46473 .43462 .45732 Mtetra
.43462 .45732 .4418 .46473 .45418 .46072 .44704 .45328 Mtetra
.44704 .45328 .45418 .46072 .46661 .4567 .45951 .44922 Mtetra
.45951 .44922 .46661 .4567 .47911 .45265 .47204 .44514 Mtetra
.47204 .44514 .47911 .45265 .49166 .44859 .48463 .44104 Mtetra
.48463 .44104 .49166 .44859 .50427 .44451 .49728 .43693 Mtetra
.49728 .43693 .50427 .44451 .51694 .44041 .50999 .43279 Mtetra
.50999 .43279 .51694 .44041 .52967 .43629 .52275 .42864 Mtetra
.52275 .42864 .52967 .43629 .54245 .43215 .53558 .42446 Mtetra
.53558 .42446 .54245 .43215 .5553 .428 .54846 .42027 Mtetra
.54846 .42027 .5553 .428 .5682 .42382 .56141 .41606 Mtetra
.56141 .41606 .5682 .42382 .58117 .41962 .57442 .41182 Mtetra
.57442 .41182 .58117 .41962 .5942 .41541 .58748 .40757 Mtetra
.58748 .40757 .5942 .41541 .60729 .41117 .60061 .4033 Mtetra
.972 .72 .496 r
.60061 .4033 .60729 .41117 .61697 .28973 .61056 .28162 Mtetra
.664 .741 .908 r
.61056 .28162 .61697 .28973 .62969 .28534 .62333 .27719 Mtetra
.62333 .27719 .62969 .28534 .64247 .28094 .63615 .27275 Mtetra
.63615 .27275 .64247 .28094 .65531 .27651 .64903 .26828 Mtetra
.64903 .26828 .65531 .27651 .66821 .27206 .66197 .2638 Mtetra
.66197 .2638 .66821 .27206 .68117 .26759 .67496 .25929 Mtetra
.67496 .25929 .68117 .26759 .69419 .26311 .68802 .25477 Mtetra
.68802 .25477 .69419 .26311 .70726 .2586 .70114 .25022 Mtetra
.70114 .25022 .70726 .2586 .7204 .25407 .71432 .24565 Mtetra
.71432 .24565 .7204 .25407 .7336 .24952 .72756 .24106 Mtetra
.72756 .24106 .7336 .24952 .74686 .24494 .74087 .23645 Mtetra
.74087 .23645 .74686 .24494 .76018 .24035 .75423 .23182 Mtetra
.75423 .23182 .76018 .24035 .77357 .23574 .76766 .22716 Mtetra
.76766 .22716 .77357 .23574 .78702 .2311 .78115 .22248 Mtetra
.78115 .22248 .78702 .2311 .80053 .22644 .79471 .21779 Mtetra
.79471 .21779 .80053 .22644 .8141 .22176 .80833 .21306 Mtetra
.80833 .21306 .8141 .22176 .82774 .21706 .82201 .20832 Mtetra
.646 .762 .934 r
.17972 .62865 .18788 .63527 .19955 .63169 .19142 .62505 Mtetra
.19142 .62505 .19955 .63169 .21127 .6281 .20318 .62142 Mtetra
.20318 .62142 .21127 .6281 .22305 .62449 .21499 .61778 Mtetra
.21499 .61778 .22305 .62449 .23488 .62086 .22685 .61413 Mtetra
.22685 .61413 .23488 .62086 .24677 .61722 .23877 .61045 Mtetra
.23877 .61045 .24677 .61722 .25871 .61356 .25074 .60676 Mtetra
.25074 .60676 .25871 .61356 .2707 .60989 .26276 .60305 Mtetra
.26276 .60305 .2707 .60989 .28275 .60619 .27485 .59933 Mtetra
.27485 .59933 .28275 .60619 .29485 .60248 .28698 .59559 Mtetra
.28698 .59559 .29485 .60248 .30702 .59875 .29918 .59183 Mtetra
.29918 .59183 .30702 .59875 .31923 .59501 .31143 .58805 Mtetra
.31143 .58805 .31923 .59501 .33151 .59125 .32374 .58426 Mtetra
.32374 .58426 .33151 .59125 .34384 .58747 .3361 .58045 Mtetra
.3361 .58045 .34384 .58747 .35622 .58367 .34853 .57662 Mtetra
.34853 .57662 .35622 .58367 .36867 .57986 .36101 .57277 Mtetra
.36101 .57277 .36867 .57986 .38117 .57602 .37355 .5689 Mtetra
.949 .718 .555 r
.37355 .5689 .38117 .57602 .39771 .46933 .39037 .46196 Mtetra
.655 .752 .921 r
.39037 .46196 .39771 .46933 .40996 .46534 .40265 .45794 Mtetra
.40265 .45794 .40996 .46534 .42226 .46134 .41499 .4539 Mtetra
.41499 .4539 .42226 .46134 .43462 .45732 .42739 .44984 Mtetra
.42739 .44984 .43462 .45732 .44704 .45328 .43984 .44577 Mtetra
.43984 .44577 .44704 .45328 .45951 .44922 .45235 .44167 Mtetra
.45235 .44167 .45951 .44922 .47204 .44514 .46492 .43756 Mtetra
.46492 .43756 .47204 .44514 .48463 .44104 .47755 .43343 Mtetra
.47755 .43343 .48463 .44104 .49728 .43693 .49023 .42928 Mtetra
.49023 .42928 .49728 .43693 .50999 .43279 .50298 .42511 Mtetra
.50298 .42511 .50999 .43279 .52275 .42864 .51578 .42092 Mtetra
.51578 .42092 .52275 .42864 .53558 .42446 .52865 .41671 Mtetra
.52865 .41671 .53558 .42446 .54846 .42027 .54157 .41248 Mtetra
.54157 .41248 .54846 .42027 .56141 .41606 .55456 .40823 Mtetra
.55456 .40823 .56141 .41606 .57442 .41182 .5676 .40396 Mtetra
.5676 .40396 .57442 .41182 .58748 .40757 .58071 .39967 Mtetra
.58071 .39967 .58748 .40757 .60061 .4033 .59388 .39536 Mtetra
.972 .72 .496 r
.59388 .39536 .60061 .4033 .61056 .28162 .60411 .27343 Mtetra
.664 .741 .908 r
.60411 .27343 .61056 .28162 .62333 .27719 .61691 .26897 Mtetra
.61691 .26897 .62333 .27719 .63615 .27275 .62977 .26449 Mtetra
.62977 .26449 .63615 .27275 .64903 .26828 .64269 .25999 Mtetra
.64269 .25999 .64903 .26828 .66197 .2638 .65567 .25546 Mtetra
.65567 .25546 .66197 .2638 .67496 .25929 .66871 .25092 Mtetra
.66871 .25092 .67496 .25929 .68802 .25477 .68181 .24635 Mtetra
.68181 .24635 .68802 .25477 .70114 .25022 .69497 .24177 Mtetra
.69497 .24177 .70114 .25022 .71432 .24565 .70819 .23716 Mtetra
.70819 .23716 .71432 .24565 .72756 .24106 .72148 .23253 Mtetra
.72148 .23253 .72756 .24106 .74087 .23645 .73482 .22788 Mtetra
.73482 .22788 .74087 .23645 .75423 .23182 .74823 .2232 Mtetra
.74823 .2232 .75423 .23182 .76766 .22716 .7617 .21851 Mtetra
.7617 .21851 .76766 .22716 .78115 .22248 .77524 .21379 Mtetra
.77524 .21379 .78115 .22248 .79471 .21779 .78884 .20905 Mtetra
.78884 .20905 .79471 .21779 .80833 .21306 .80251 .20429 Mtetra
.80251 .20429 .80833 .21306 .82201 .20832 .81623 .19951 Mtetra
.646 .762 .934 r
.17149 .62198 .17972 .62865 .19142 .62505 .18323 .61834 Mtetra
.18323 .61834 .19142 .62505 .20318 .62142 .19501 .61469 Mtetra
.19501 .61469 .20318 .62142 .21499 .61778 .20685 .61102 Mtetra
.20685 .61102 .21499 .61778 .22685 .61413 .21875 .60733 Mtetra
.21875 .60733 .22685 .61413 .23877 .61045 .2307 .60363 Mtetra
.2307 .60363 .23877 .61045 .25074 .60676 .2427 .5999 Mtetra
.2427 .5999 .25074 .60676 .26276 .60305 .25476 .59616 Mtetra
.25476 .59616 .26276 .60305 .27485 .59933 .26688 .59241 Mtetra
.26688 .59241 .27485 .59933 .28698 .59559 .27905 .58863 Mtetra
.27905 .58863 .28698 .59559 .29918 .59183 .29128 .58484 Mtetra
.29128 .58484 .29918 .59183 .31143 .58805 .30356 .58103 Mtetra
.30356 .58103 .31143 .58805 .32374 .58426 .3159 .57721 Mtetra
.3159 .57721 .32374 .58426 .3361 .58045 .3283 .57336 Mtetra
.3283 .57336 .3361 .58045 .34853 .57662 .34076 .5695 Mtetra
.34076 .5695 .34853 .57662 .36101 .57277 .35328 .56562 Mtetra
.35328 .56562 .36101 .57277 .37355 .5689 .36586 .56172 Mtetra
.949 .718 .555 r
.36586 .56172 .37355 .5689 .39037 .46196 .38297 .45452 Mtetra
.655 .752 .921 r
.38297 .45452 .39037 .46196 .40265 .45794 .39529 .45047 Mtetra
.39529 .45047 .40265 .45794 .41499 .4539 .40766 .44639 Mtetra
.40766 .44639 .41499 .4539 .42739 .44984 .42009 .4423 Mtetra
.42009 .4423 .42739 .44984 .43984 .44577 .43258 .43819 Mtetra
.43258 .43819 .43984 .44577 .45235 .44167 .44513 .43406 Mtetra
.44513 .43406 .45235 .44167 .46492 .43756 .45773 .42992 Mtetra
.45773 .42992 .46492 .43756 .47755 .43343 .4704 .42575 Mtetra
.4704 .42575 .47755 .43343 .49023 .42928 .48312 .42156 Mtetra
.48312 .42156 .49023 .42928 .50298 .42511 .4959 .41735 Mtetra
.4959 .41735 .50298 .42511 .51578 .42092 .50875 .41313 Mtetra
.50875 .41313 .51578 .42092 .52865 .41671 .52165 .40888 Mtetra
.52165 .40888 .52865 .41671 .54157 .41248 .53462 .40462 Mtetra
.53462 .40462 .54157 .41248 .55456 .40823 .54764 .40033 Mtetra
.54764 .40033 .55456 .40823 .5676 .40396 .56073 .39602 Mtetra
.56073 .39602 .5676 .40396 .58071 .39967 .57388 .39169 Mtetra
.57388 .39169 .58071 .39967 .59388 .39536 .58709 .38735 Mtetra
.972 .72 .496 r
.58709 .38735 .59388 .39536 .60411 .27343 .59759 .26518 Mtetra
.664 .741 .908 r
.59759 .26518 .60411 .27343 .61691 .26897 .61043 .26068 Mtetra
.61043 .26068 .61691 .26897 .62977 .26449 .62333 .25616 Mtetra
.62333 .25616 .62977 .26449 .64269 .25999 .63629 .25162 Mtetra
.63629 .25162 .64269 .25999 .65567 .25546 .64932 .24706 Mtetra
.64932 .24706 .65567 .25546 .66871 .25092 .6624 .24247 Mtetra
.6624 .24247 .66871 .25092 .68181 .24635 .67554 .23787 Mtetra
.67554 .23787 .68181 .24635 .69497 .24177 .68874 .23324 Mtetra
.68874 .23324 .69497 .24177 .70819 .23716 .70201 .22859 Mtetra
.70201 .22859 .70819 .23716 .72148 .23253 .71533 .22393 Mtetra
.71533 .22393 .72148 .23253 .73482 .22788 .72872 .21923 Mtetra
.72872 .21923 .73482 .22788 .74823 .2232 .74218 .21452 Mtetra
.74218 .21452 .74823 .2232 .7617 .21851 .75569 .20978 Mtetra
.75569 .20978 .7617 .21851 .77524 .21379 .76928 .20502 Mtetra
.76928 .20502 .77524 .21379 .78884 .20905 .78292 .20024 Mtetra
.78292 .20024 .78884 .20905 .80251 .20429 .79663 .19544 Mtetra
.79663 .19544 .80251 .20429 .81623 .19951 .81041 .19061 Mtetra
.646 .762 .934 r
.1632 .61525 .17149 .62198 .18323 .61834 .17496 .61158 Mtetra
.17496 .61158 .18323 .61834 .19501 .61469 .18678 .6079 Mtetra
.18678 .6079 .19501 .61469 .20685 .61102 .19865 .6042 Mtetra
.19865 .6042 .20685 .61102 .21875 .60733 .21058 .60048 Mtetra
.21058 .60048 .21875 .60733 .2307 .60363 .22256 .59674 Mtetra
.22256 .59674 .2307 .60363 .2427 .5999 .23459 .59299 Mtetra
.23459 .59299 .2427 .5999 .25476 .59616 .24669 .58922 Mtetra
.24669 .58922 .25476 .59616 .26688 .59241 .25884 .58543 Mtetra
.25884 .58543 .26688 .59241 .27905 .58863 .27104 .58162 Mtetra
.27104 .58162 .27905 .58863 .29128 .58484 .2833 .5778 Mtetra
.2833 .5778 .29128 .58484 .30356 .58103 .29562 .57395 Mtetra
.29562 .57395 .30356 .58103 .3159 .57721 .308 .57009 Mtetra
.308 .57009 .3159 .57721 .3283 .57336 .32044 .56621 Mtetra
.32044 .56621 .3283 .57336 .34076 .5695 .33293 .56232 Mtetra
.33293 .56232 .34076 .5695 .35328 .56562 .34549 .5584 Mtetra
.34549 .5584 .35328 .56562 .36586 .56172 .3581 .55447 Mtetra
.949 .718 .555 r
.3581 .55447 .36586 .56172 .38297 .45452 .3755 .44702 Mtetra
.655 .752 .921 r
.3755 .44702 .38297 .45452 .39529 .45047 .38785 .44293 Mtetra
.38785 .44293 .39529 .45047 .40766 .44639 .40027 .43883 Mtetra
.40027 .43883 .40766 .44639 .42009 .4423 .41273 .4347 Mtetra
.41273 .4347 .42009 .4423 .43258 .43819 .42526 .43056 Mtetra
.42526 .43056 .43258 .43819 .44513 .43406 .43784 .42639 Mtetra
.43784 .42639 .44513 .43406 .45773 .42992 .45049 .42221 Mtetra
.45049 .42221 .45773 .42992 .4704 .42575 .46319 .418 Mtetra
.46319 .418 .4704 .42575 .48312 .42156 .47595 .41378 Mtetra
.47595 .41378 .48312 .42156 .4959 .41735 .48877 .40954 Mtetra
.48877 .40954 .4959 .41735 .50875 .41313 .50165 .40527 Mtetra
.50165 .40527 .50875 .41313 .52165 .40888 .5146 .40099 Mtetra
.5146 .40099 .52165 .40888 .53462 .40462 .5276 .39669 Mtetra
.5276 .39669 .53462 .40462 .54764 .40033 .54067 .39236 Mtetra
.54067 .39236 .54764 .40033 .56073 .39602 .5538 .38802 Mtetra
.5538 .38802 .56073 .39602 .57388 .39169 .56699 .38365 Mtetra
.56699 .38365 .57388 .39169 .58709 .38735 .58024 .37927 Mtetra
.972 .72 .496 r
.58024 .37927 .58709 .38735 .59759 .26518 .59102 .25686 Mtetra
.664 .741 .908 r
.59102 .25686 .59759 .26518 .61043 .26068 .60391 .25232 Mtetra
.60391 .25232 .61043 .26068 .62333 .25616 .61685 .24776 Mtetra
.61685 .24776 .62333 .25616 .63629 .25162 .62985 .24318 Mtetra
.62985 .24318 .63629 .25162 .64932 .24706 .64291 .23858 Mtetra
.64291 .23858 .64932 .24706 .6624 .24247 .65603 .23396 Mtetra
.65603 .23396 .6624 .24247 .67554 .23787 .66921 .22931 Mtetra
.66921 .22931 .67554 .23787 .68874 .23324 .68246 .22464 Mtetra
.68246 .22464 .68874 .23324 .70201 .22859 .69577 .21996 Mtetra
.69577 .21996 .70201 .22859 .71533 .22393 .70914 .21525 Mtetra
.70914 .21525 .71533 .22393 .72872 .21923 .72257 .21051 Mtetra
.72257 .21051 .72872 .21923 .74218 .21452 .73607 .20576 Mtetra
.73607 .20576 .74218 .21452 .75569 .20978 .74963 .20098 Mtetra
.74963 .20098 .75569 .20978 .76928 .20502 .76326 .19618 Mtetra
.76326 .19618 .76928 .20502 .78292 .20024 .77695 .19136 Mtetra
.77695 .19136 .78292 .20024 .79663 .19544 .79071 .18651 Mtetra
.79071 .18651 .79663 .19544 .81041 .19061 .80453 .18164 Mtetra
.646 .762 .934 r
.15484 .60847 .1632 .61525 .17496 .61158 .16663 .60477 Mtetra
.16663 .60477 .17496 .61158 .18678 .6079 .17848 .60105 Mtetra
.17848 .60105 .18678 .6079 .19865 .6042 .19038 .59732 Mtetra
.19038 .59732 .19865 .6042 .21058 .60048 .20234 .59357 Mtetra
.20234 .59357 .21058 .60048 .22256 .59674 .21435 .5898 Mtetra
.21435 .5898 .22256 .59674 .23459 .59299 .22642 .58601 Mtetra
.22642 .58601 .23459 .59299 .24669 .58922 .23855 .58221 Mtetra
.23855 .58221 .24669 .58922 .25884 .58543 .25073 .57839 Mtetra
.25073 .57839 .25884 .58543 .27104 .58162 .26297 .57455 Mtetra
.26297 .57455 .27104 .58162 .2833 .5778 .27526 .57069 Mtetra
.27526 .57069 .2833 .5778 .29562 .57395 .28762 .56681 Mtetra
.28762 .56681 .29562 .57395 .308 .57009 .30003 .56292 Mtetra
.30003 .56292 .308 .57009 .32044 .56621 .3125 .55901 Mtetra
.3125 .55901 .32044 .56621 .33293 .56232 .32503 .55507 Mtetra
.32503 .55507 .33293 .56232 .34549 .5584 .33762 .55113 Mtetra
.33762 .55113 .34549 .5584 .3581 .55447 .35027 .54716 Mtetra
.949 .718 .555 r
.35027 .54716 .3581 .55447 .3755 .44702 .36797 .43946 Mtetra
.655 .752 .921 r
.36797 .43946 .3755 .44702 .38785 .44293 .38036 .43534 Mtetra
.38036 .43534 .38785 .44293 .40027 .43883 .39281 .43119 Mtetra
.39281 .43119 .40027 .43883 .41273 .4347 .40531 .42703 Mtetra
.40531 .42703 .41273 .4347 .42526 .43056 .41787 .42285 Mtetra
.41787 .42285 .42526 .43056 .43784 .42639 .43049 .41865 Mtetra
.43049 .41865 .43784 .42639 .45049 .42221 .44318 .41443 Mtetra
.44318 .41443 .45049 .42221 .46319 .418 .45592 .41019 Mtetra
.45592 .41019 .46319 .418 .47595 .41378 .46872 .40593 Mtetra
.46872 .40593 .47595 .41378 .48877 .40954 .48158 .40165 Mtetra
.48158 .40165 .48877 .40954 .50165 .40527 .4945 .39735 Mtetra
.4945 .39735 .50165 .40527 .5146 .40099 .50748 .39303 Mtetra
.50748 .39303 .5146 .40099 .5276 .39669 .52052 .38869 Mtetra
.52052 .38869 .5276 .39669 .54067 .39236 .53363 .38432 Mtetra
.53363 .38432 .54067 .39236 .5538 .38802 .5468 .37994 Mtetra
.5468 .37994 .5538 .38802 .56699 .38365 .56003 .37554 Mtetra
.56003 .37554 .56699 .38365 .58024 .37927 .57333 .37111 Mtetra
.972 .72 .496 r
.57333 .37111 .58024 .37927 .59102 .25686 .5844 .24846 Mtetra
.664 .741 .908 r
.5844 .24846 .59102 .25686 .60391 .25232 .59732 .24389 Mtetra
.59732 .24389 .60391 .25232 .61685 .24776 .6103 .23929 Mtetra
.6103 .23929 .61685 .24776 .62985 .24318 .62334 .23467 Mtetra
.62334 .23467 .62985 .24318 .64291 .23858 .63645 .23003 Mtetra
.63645 .23003 .64291 .23858 .65603 .23396 .64961 .22536 Mtetra
.64961 .22536 .65603 .23396 .66921 .22931 .66284 .22068 Mtetra
.66284 .22068 .66921 .22931 .68246 .22464 .67612 .21597 Mtetra
.67612 .21597 .68246 .22464 .69577 .21996 .68948 .21124 Mtetra
.68948 .21124 .69577 .21996 .70914 .21525 .70289 .20649 Mtetra
.70289 .20649 .70914 .21525 .72257 .21051 .71637 .20172 Mtetra
.71637 .20172 .72257 .21051 .73607 .20576 .72991 .19692 Mtetra
.72991 .19692 .73607 .20576 .74963 .20098 .74352 .1921 Mtetra
.74352 .1921 .74963 .20098 .76326 .19618 .75719 .18726 Mtetra
.75719 .18726 .76326 .19618 .77695 .19136 .77093 .18239 Mtetra
.77093 .18239 .77695 .19136 .79071 .18651 .78473 .1775 Mtetra
.78473 .1775 .79071 .18651 .80453 .18164 .7986 .17259 Mtetra
.574 .41 .621 r
.15099 .56011 .15484 .60847 .16663 .60477 .16268 .55633 Mtetra
.16268 .55633 .16663 .60477 .17848 .60105 .17442 .55253 Mtetra
.17442 .55253 .17848 .60105 .19038 .59732 .18622 .54871 Mtetra
.18622 .54871 .19038 .59732 .20234 .59357 .19807 .54488 Mtetra
.19807 .54488 .20234 .59357 .21435 .5898 .20998 .54103 Mtetra
.20998 .54103 .21435 .5898 .22642 .58601 .22194 .53716 Mtetra
.22194 .53716 .22642 .58601 .23855 .58221 .23396 .53328 Mtetra
.23396 .53328 .23855 .58221 .25073 .57839 .24603 .52937 Mtetra
.24603 .52937 .25073 .57839 .26297 .57455 .25816 .52545 Mtetra
.25816 .52545 .26297 .57455 .27526 .57069 .27035 .52151 Mtetra
.27035 .52151 .27526 .57069 .28762 .56681 .28259 .51755 Mtetra
.28259 .51755 .28762 .56681 .30003 .56292 .29489 .51357 Mtetra
.29489 .51357 .30003 .56292 .3125 .55901 .30725 .50958 Mtetra
.30725 .50958 .3125 .55901 .32503 .55507 .31967 .50556 Mtetra
.31967 .50556 .32503 .55507 .33762 .55113 .33214 .50153 Mtetra
.33214 .50153 .33762 .55113 .35027 .54716 .34467 .49747 Mtetra
0 0 .484 r
.34467 .49747 .35027 .54716 .36797 .43946 .35512 .53576 Mtetra
.503 .247 .459 r
.35512 .53576 .36797 .43946 .38036 .43534 .36793 .53172 Mtetra
.36793 .53172 .38036 .43534 .39281 .43119 .3808 .52765 Mtetra
.3808 .52765 .39281 .43119 .40531 .42703 .39374 .52357 Mtetra
.39374 .52357 .40531 .42703 .41787 .42285 .40673 .51947 Mtetra
.40673 .51947 .41787 .42285 .43049 .41865 .41979 .51535 Mtetra
.41979 .51535 .43049 .41865 .44318 .41443 .43291 .51121 Mtetra
.43291 .51121 .44318 .41443 .45592 .41019 .4461 .50705 Mtetra
.4461 .50705 .45592 .41019 .46872 .40593 .45935 .50287 Mtetra
.45935 .50287 .46872 .40593 .48158 .40165 .47267 .49867 Mtetra
.47267 .49867 .48158 .40165 .4945 .39735 .48605 .49444 Mtetra
.48605 .49444 .4945 .39735 .50748 .39303 .49949 .4902 Mtetra
.49949 .4902 .50748 .39303 .52052 .38869 .51301 .48594 Mtetra
.51301 .48594 .52052 .38869 .53363 .38432 .52659 .48165 Mtetra
.52659 .48165 .53363 .38432 .5468 .37994 .54024 .47734 Mtetra
.54024 .47734 .5468 .37994 .56003 .37554 .55395 .47302 Mtetra
.55395 .47302 .56003 .37554 .57333 .37111 .56773 .46867 Mtetra
0 0 .269 r
.56773 .46867 .57333 .37111 .5844 .24846 .57994 .36868 Mtetra
.509 .259 .471 r
.57994 .36868 .5844 .24846 .59732 .24389 .59345 .36418 Mtetra
.59345 .36418 .59732 .24389 .6103 .23929 .60703 .35966 Mtetra
.60703 .35966 .6103 .23929 .62334 .23467 .62067 .35512 Mtetra
.62067 .35512 .62334 .23467 .63645 .23003 .63438 .35056 Mtetra
.63438 .35056 .63645 .23003 .64961 .22536 .64816 .34597 Mtetra
.64816 .34597 .64961 .22536 .66284 .22068 .66201 .34136 Mtetra
.66201 .34136 .66284 .22068 .67612 .21597 .67592 .33673 Mtetra
.67592 .33673 .67612 .21597 .68948 .21124 .68991 .33208 Mtetra
.68991 .33208 .68948 .21124 .70289 .20649 .70396 .3274 Mtetra
.70396 .3274 .70289 .20649 .71637 .20172 .71808 .3227 Mtetra
.71808 .3227 .71637 .20172 .72991 .19692 .73228 .31797 Mtetra
.73228 .31797 .72991 .19692 .74352 .1921 .74654 .31322 Mtetra
.74654 .31322 .74352 .1921 .75719 .18726 .76088 .30845 Mtetra
.76088 .30845 .75719 .18726 .77093 .18239 .77529 .30366 Mtetra
.77529 .30366 .77093 .18239 .78473 .1775 .78977 .29884 Mtetra
.78977 .29884 .78473 .1775 .7986 .17259 .80432 .29399 Mtetra
.65 .758 .929 r
.1426 .55311 .15099 .56011 .16268 .55633 .15432 .5493 Mtetra
.15432 .5493 .16268 .55633 .17442 .55253 .1661 .54547 Mtetra
.1661 .54547 .17442 .55253 .18622 .54871 .17793 .54162 Mtetra
.17793 .54162 .18622 .54871 .19807 .54488 .18981 .53776 Mtetra
.18981 .53776 .19807 .54488 .20998 .54103 .20175 .53387 Mtetra
.20175 .53387 .20998 .54103 .22194 .53716 .21375 .52997 Mtetra
.21375 .52997 .22194 .53716 .23396 .53328 .2258 .52605 Mtetra
.2258 .52605 .23396 .53328 .24603 .52937 .2379 .52212 Mtetra
.2379 .52212 .24603 .52937 .25816 .52545 .25006 .51816 Mtetra
.25006 .51816 .25816 .52545 .27035 .52151 .26228 .51418 Mtetra
.26228 .51418 .27035 .52151 .28259 .51755 .27456 .51019 Mtetra
.27456 .51019 .28259 .51755 .29489 .51357 .2869 .50618 Mtetra
.2869 .50618 .29489 .51357 .30725 .50958 .29929 .50215 Mtetra
.29929 .50215 .30725 .50958 .31967 .50556 .31174 .4981 Mtetra
.31174 .4981 .31967 .50556 .33214 .50153 .32425 .49403 Mtetra
.32425 .49403 .33214 .50153 .34467 .49747 .33682 .48994 Mtetra
.928 .543 .216 r
.33682 .48994 .34467 .49747 .35512 .53576 .3472 .52828 Mtetra
.646 .762 .934 r
.3472 .52828 .35512 .53576 .36793 .53172 .36004 .5242 Mtetra
.36004 .5242 .36793 .53172 .3808 .52765 .37295 .5201 Mtetra
.37295 .5201 .3808 .52765 .39374 .52357 .38592 .51599 Mtetra
.38592 .51599 .39374 .52357 .40673 .51947 .39896 .51185 Mtetra
.39896 .51185 .40673 .51947 .41979 .51535 .41206 .50769 Mtetra
.41206 .50769 .41979 .51535 .43291 .51121 .42522 .50351 Mtetra
.42522 .50351 .43291 .51121 .4461 .50705 .43845 .49931 Mtetra
.43845 .49931 .4461 .50705 .45935 .50287 .45174 .49509 Mtetra
.45174 .49509 .45935 .50287 .47267 .49867 .4651 .49085 Mtetra
.4651 .49085 .47267 .49867 .48605 .49444 .47852 .48659 Mtetra
.47852 .48659 .48605 .49444 .49949 .4902 .49201 .48231 Mtetra
.49201 .48231 .49949 .4902 .51301 .48594 .50557 .47801 Mtetra
.50557 .47801 .51301 .48594 .52659 .48165 .51919 .47368 Mtetra
.51919 .47368 .52659 .48165 .54024 .47734 .53288 .46934 Mtetra
.53288 .46934 .54024 .47734 .55395 .47302 .54664 .46497 Mtetra
.54664 .46497 .55395 .47302 .56773 .46867 .56047 .46058 Mtetra
.971 .73 .515 r
.56047 .46058 .56773 .46867 .57994 .36868 .57292 .36036 Mtetra
.654 .753 .923 r
.57292 .36036 .57994 .36868 .59345 .36418 .58648 .35582 Mtetra
.58648 .35582 .59345 .36418 .60703 .35966 .6001 .35126 Mtetra
.6001 .35126 .60703 .35966 .62067 .35512 .61379 .34668 Mtetra
.61379 .34668 .62067 .35512 .63438 .35056 .62755 .34207 Mtetra
.62755 .34207 .63438 .35056 .64816 .34597 .64137 .33744 Mtetra
.64137 .33744 .64816 .34597 .66201 .34136 .65527 .33279 Mtetra
.65527 .33279 .66201 .34136 .67592 .33673 .66923 .32812 Mtetra
.66923 .32812 .67592 .33673 .68991 .33208 .68326 .32342 Mtetra
.68326 .32342 .68991 .33208 .70396 .3274 .69736 .3187 Mtetra
.69736 .3187 .70396 .3274 .71808 .3227 .71153 .31396 Mtetra
.71153 .31396 .71808 .3227 .73228 .31797 .72577 .30919 Mtetra
.72577 .30919 .73228 .31797 .74654 .31322 .74009 .3044 Mtetra
.74009 .3044 .74654 .31322 .76088 .30845 .75447 .29958 Mtetra
.75447 .29958 .76088 .30845 .77529 .30366 .76893 .29474 Mtetra
.76893 .29474 .77529 .30366 .78977 .29884 .78347 .28987 Mtetra
.78347 .28987 .78977 .29884 .80432 .29399 .79807 .28498 Mtetra
.65 .758 .929 r
.13415 .54606 .1426 .55311 .15432 .5493 .1459 .54222 Mtetra
.1459 .54222 .15432 .5493 .1661 .54547 .1577 .53835 Mtetra
.1577 .53835 .1661 .54547 .17793 .54162 .16956 .53447 Mtetra
.16956 .53447 .17793 .54162 .18981 .53776 .18148 .53057 Mtetra
.18148 .53057 .18981 .53776 .20175 .53387 .19345 .52666 Mtetra
.19345 .52666 .20175 .53387 .21375 .52997 .20548 .52272 Mtetra
.20548 .52272 .21375 .52997 .2258 .52605 .21756 .51877 Mtetra
.21756 .51877 .2258 .52605 .2379 .52212 .2297 .5148 Mtetra
.2297 .5148 .2379 .52212 .25006 .51816 .24189 .51081 Mtetra
.24189 .51081 .25006 .51816 .26228 .51418 .25415 .5068 Mtetra
.25415 .5068 .26228 .51418 .27456 .51019 .26646 .50277 Mtetra
.26646 .50277 .27456 .51019 .2869 .50618 .27883 .49872 Mtetra
.27883 .49872 .2869 .50618 .29929 .50215 .29126 .49466 Mtetra
.29126 .49466 .29929 .50215 .31174 .4981 .30374 .49057 Mtetra
.30374 .49057 .31174 .4981 .32425 .49403 .31629 .48647 Mtetra
.31629 .48647 .32425 .49403 .33682 .48994 .32889 .48234 Mtetra
.928 .543 .216 r
.32889 .48234 .33682 .48994 .3472 .52828 .3392 .52074 Mtetra
.646 .762 .934 r
.3392 .52074 .3472 .52828 .36004 .5242 .35208 .51662 Mtetra
.35208 .51662 .36004 .5242 .37295 .5201 .36503 .51249 Mtetra
.36503 .51249 .37295 .5201 .38592 .51599 .37804 .50833 Mtetra
.37804 .50833 .38592 .51599 .39896 .51185 .39112 .50416 Mtetra
.39112 .50416 .39896 .51185 .41206 .50769 .40425 .49996 Mtetra
.40425 .49996 .41206 .50769 .42522 .50351 .41746 .49575 Mtetra
.41746 .49575 .42522 .50351 .43845 .49931 .43072 .49151 Mtetra
.43072 .49151 .43845 .49931 .45174 .49509 .44406 .48725 Mtetra
.44406 .48725 .45174 .49509 .4651 .49085 .45746 .48297 Mtetra
.45746 .48297 .4651 .49085 .47852 .48659 .47092 .47867 Mtetra
.47092 .47867 .47852 .48659 .49201 .48231 .48446 .47435 Mtetra
.48446 .47435 .49201 .48231 .50557 .47801 .49806 .47001 Mtetra
.49806 .47001 .50557 .47801 .51919 .47368 .51172 .46564 Mtetra
.51172 .46564 .51919 .47368 .53288 .46934 .52546 .46126 Mtetra
.52546 .46126 .53288 .46934 .54664 .46497 .53927 .45685 Mtetra
.53927 .45685 .54664 .46497 .56047 .46058 .55314 .45242 Mtetra
.971 .73 .515 r
.55314 .45242 .56047 .46058 .57292 .36036 .56585 .35196 Mtetra
.654 .753 .923 r
.56585 .35196 .57292 .36036 .58648 .35582 .57945 .34739 Mtetra
.57945 .34739 .58648 .35582 .6001 .35126 .59311 .34278 Mtetra
.59311 .34278 .6001 .35126 .61379 .34668 .60685 .33816 Mtetra
.60685 .33816 .61379 .34668 .62755 .34207 .62065 .33351 Mtetra
.62065 .33351 .62755 .34207 .64137 .33744 .63452 .32884 Mtetra
.63452 .32884 .64137 .33744 .65527 .33279 .64846 .32415 Mtetra
.64846 .32415 .65527 .33279 .66923 .32812 .66247 .31943 Mtetra
.66247 .31943 .66923 .32812 .68326 .32342 .67655 .31469 Mtetra
.67655 .31469 .68326 .32342 .69736 .3187 .6907 .30992 Mtetra
.6907 .30992 .69736 .3187 .71153 .31396 .70492 .30513 Mtetra
.70492 .30513 .71153 .31396 .72577 .30919 .71921 .30032 Mtetra
.71921 .30032 .72577 .30919 .74009 .3044 .73358 .29549 Mtetra
.73358 .29549 .74009 .3044 .75447 .29958 .74801 .29062 Mtetra
.74801 .29062 .75447 .29958 .76893 .29474 .76252 .28574 Mtetra
.76252 .28574 .76893 .29474 .78347 .28987 .77711 .28083 Mtetra
.77711 .28083 .78347 .28987 .79807 .28498 .79176 .27589 Mtetra
.65 .758 .929 r
.12562 .53895 .13415 .54606 .1459 .54222 .1374 .53507 Mtetra
.1374 .53507 .1459 .54222 .1577 .53835 .14924 .53118 Mtetra
.14924 .53118 .1577 .53835 .16956 .53447 .16113 .52726 Mtetra
.16113 .52726 .16956 .53447 .18148 .53057 .17308 .52333 Mtetra
.17308 .52333 .18148 .53057 .19345 .52666 .18508 .51938 Mtetra
.18508 .51938 .19345 .52666 .20548 .52272 .19714 .51541 Mtetra
.19714 .51541 .20548 .52272 .21756 .51877 .20925 .51142 Mtetra
.20925 .51142 .21756 .51877 .2297 .5148 .22142 .50742 Mtetra
.22142 .50742 .2297 .5148 .24189 .51081 .23365 .50339 Mtetra
.23365 .50339 .24189 .51081 .25415 .5068 .24594 .49935 Mtetra
.24594 .49935 .25415 .5068 .26646 .50277 .25829 .49528 Mtetra
.25829 .49528 .26646 .50277 .27883 .49872 .27069 .4912 Mtetra
.27069 .4912 .27883 .49872 .29126 .49466 .28315 .4871 Mtetra
.28315 .4871 .29126 .49466 .30374 .49057 .29568 .48298 Mtetra
.29568 .48298 .30374 .49057 .31629 .48647 .30826 .47884 Mtetra
.30826 .47884 .31629 .48647 .32889 .48234 .3209 .47468 Mtetra
.928 .543 .216 r
.3209 .47468 .32889 .48234 .3392 .52074 .33113 .51312 Mtetra
.646 .762 .934 r
.33113 .51312 .3392 .52074 .35208 .51662 .34405 .50897 Mtetra
.34405 .50897 .35208 .51662 .36503 .51249 .35704 .5048 Mtetra
.35704 .5048 .36503 .51249 .37804 .50833 .37009 .50061 Mtetra
.37009 .50061 .37804 .50833 .39112 .50416 .3832 .4964 Mtetra
.3832 .4964 .39112 .50416 .40425 .49996 .39638 .49216 Mtetra
.39638 .49216 .40425 .49996 .41746 .49575 .40962 .48791 Mtetra
.40962 .48791 .41746 .49575 .43072 .49151 .42293 .48363 Mtetra
.42293 .48363 .43072 .49151 .44406 .48725 .43631 .47933 Mtetra
.43631 .47933 .44406 .48725 .45746 .48297 .44975 .47502 Mtetra
.44975 .47502 .45746 .48297 .47092 .47867 .46326 .47068 Mtetra
.46326 .47068 .47092 .47867 .48446 .47435 .47683 .46632 Mtetra
.47683 .46632 .48446 .47435 .49806 .47001 .49048 .46193 Mtetra
.49048 .46193 .49806 .47001 .51172 .46564 .50419 .45753 Mtetra
.50419 .45753 .51172 .46564 .52546 .46126 .51797 .4531 Mtetra
.51797 .4531 .52546 .46126 .53927 .45685 .53182 .44865 Mtetra
.53182 .44865 .53927 .45685 .55314 .45242 .54574 .44418 Mtetra
.971 .73 .515 r
.54574 .44418 .55314 .45242 .56585 .35196 .55871 .34349 Mtetra
.654 .753 .923 r
.55871 .34349 .56585 .35196 .57945 .34739 .57235 .33887 Mtetra
.57235 .33887 .57945 .34739 .59311 .34278 .58606 .33423 Mtetra
.58606 .33423 .59311 .34278 .60685 .33816 .59984 .32956 Mtetra
.59984 .32956 .60685 .33816 .62065 .33351 .61369 .32487 Mtetra
.61369 .32487 .62065 .33351 .63452 .32884 .62761 .32016 Mtetra
.62761 .32016 .63452 .32884 .64846 .32415 .64159 .31542 Mtetra
.64159 .31542 .64846 .32415 .66247 .31943 .65565 .31066 Mtetra
.65565 .31066 .66247 .31943 .67655 .31469 .66978 .30587 Mtetra
.66978 .30587 .67655 .31469 .6907 .30992 .68398 .30106 Mtetra
.68398 .30106 .6907 .30992 .70492 .30513 .69825 .29623 Mtetra
.69825 .29623 .70492 .30513 .71921 .30032 .71259 .29137 Mtetra
.71259 .29137 .71921 .30032 .73358 .29549 .727 .28649 Mtetra
.727 .28649 .73358 .29549 .74801 .29062 .74149 .28158 Mtetra
.74149 .28158 .74801 .29062 .76252 .28574 .75605 .27665 Mtetra
.75605 .27665 .76252 .28574 .77711 .28083 .77069 .27169 Mtetra
.77069 .27169 .77711 .28083 .79176 .27589 .7854 .26671 Mtetra
.65 .758 .929 r
.11702 .53178 .12562 .53895 .1374 .53507 .12883 .52786 Mtetra
.12883 .52786 .1374 .53507 .14924 .53118 .1407 .52394 Mtetra
.1407 .52394 .14924 .53118 .16113 .52726 .15262 .51999 Mtetra
.15262 .51999 .16113 .52726 .17308 .52333 .1646 .51602 Mtetra
.1646 .51602 .17308 .52333 .18508 .51938 .17663 .51204 Mtetra
.17663 .51204 .18508 .51938 .19714 .51541 .18872 .50803 Mtetra
.18872 .50803 .19714 .51541 .20925 .51142 .20087 .50401 Mtetra
.20087 .50401 .20925 .51142 .22142 .50742 .21308 .49997 Mtetra
.21308 .49997 .22142 .50742 .23365 .50339 .22534 .49591 Mtetra
.22534 .49591 .23365 .50339 .24594 .49935 .23766 .49183 Mtetra
.23766 .49183 .24594 .49935 .25829 .49528 .25004 .48773 Mtetra
.25004 .48773 .25829 .49528 .27069 .4912 .26248 .48361 Mtetra
.26248 .48361 .27069 .4912 .28315 .4871 .27498 .47947 Mtetra
.27498 .47947 .28315 .4871 .29568 .48298 .28754 .47532 Mtetra
.28754 .47532 .29568 .48298 .30826 .47884 .30016 .47114 Mtetra
.30016 .47114 .30826 .47884 .3209 .47468 .31283 .46694 Mtetra
.928 .543 .216 r
.31283 .46694 .3209 .47468 .33113 .51312 .32298 .50544 Mtetra
.646 .762 .934 r
.32298 .50544 .33113 .51312 .34405 .50897 .33594 .50125 Mtetra
.33594 .50125 .34405 .50897 .35704 .5048 .34897 .49704 Mtetra
.34897 .49704 .35704 .5048 .37009 .50061 .36206 .49281 Mtetra
.36206 .49281 .37009 .50061 .3832 .4964 .37521 .48856 Mtetra
.37521 .48856 .3832 .4964 .39638 .49216 .38843 .48429 Mtetra
.38843 .48429 .39638 .49216 .40962 .48791 .40172 .48 Mtetra
.40172 .48 .40962 .48791 .42293 .48363 .41507 .47568 Mtetra
.41507 .47568 .42293 .48363 .43631 .47933 .42848 .47135 Mtetra
.42848 .47135 .43631 .47933 .44975 .47502 .44197 .46699 Mtetra
.44197 .46699 .44975 .47502 .46326 .47068 .45552 .46261 Mtetra
.45552 .46261 .46326 .47068 .47683 .46632 .46914 .45821 Mtetra
.46914 .45821 .47683 .46632 .49048 .46193 .48283 .45378 Mtetra
.48283 .45378 .49048 .46193 .50419 .45753 .49658 .44934 Mtetra
.49658 .44934 .50419 .45753 .51797 .4531 .51041 .44487 Mtetra
.51041 .44487 .51797 .4531 .53182 .44865 .52431 .44038 Mtetra
.52431 .44038 .53182 .44865 .54574 .44418 .53827 .43586 Mtetra
.971 .73 .515 r
.53827 .43586 .54574 .44418 .55871 .34349 .5515 .33494 Mtetra
.654 .753 .923 r
.5515 .33494 .55871 .34349 .57235 .33887 .56519 .33028 Mtetra
.56519 .33028 .57235 .33887 .58606 .33423 .57894 .32559 Mtetra
.57894 .32559 .58606 .33423 .59984 .32956 .59277 .32088 Mtetra
.59277 .32088 .59984 .32956 .61369 .32487 .60666 .31615 Mtetra
.60666 .31615 .61369 .32487 .62761 .32016 .62063 .31139 Mtetra
.62063 .31139 .62761 .32016 .64159 .31542 .63466 .30661 Mtetra
.63466 .30661 .64159 .31542 .65565 .31066 .64877 .30181 Mtetra
.64877 .30181 .65565 .31066 .66978 .30587 .66294 .29698 Mtetra
.66294 .29698 .66978 .30587 .68398 .30106 .67719 .29212 Mtetra
.67719 .29212 .68398 .30106 .69825 .29623 .69151 .28724 Mtetra
.69151 .28724 .69825 .29623 .71259 .29137 .7059 .28234 Mtetra
.7059 .28234 .71259 .29137 .727 .28649 .72037 .27741 Mtetra
.72037 .27741 .727 .28649 .74149 .28158 .73491 .27246 Mtetra
.73491 .27246 .74149 .28158 .75605 .27665 .74952 .26748 Mtetra
.74952 .26748 .75605 .27665 .77069 .27169 .76421 .26248 Mtetra
.76421 .26248 .77069 .27169 .7854 .26671 .77897 .25745 Mtetra
.65 .758 .929 r
.10834 .52454 .11702 .53178 .12883 .52786 .12019 .5206 Mtetra
.12019 .5206 .12883 .52786 .1407 .52394 .13208 .51663 Mtetra
.13208 .51663 .1407 .52394 .15262 .51999 .14404 .51265 Mtetra
.14404 .51265 .15262 .51999 .1646 .51602 .15605 .50865 Mtetra
.15605 .50865 .1646 .51602 .17663 .51204 .16812 .50463 Mtetra
.16812 .50463 .17663 .51204 .18872 .50803 .18024 .50059 Mtetra
.18024 .50059 .18872 .50803 .20087 .50401 .19242 .49654 Mtetra
.19242 .49654 .20087 .50401 .21308 .49997 .20466 .49246 Mtetra
.20466 .49246 .21308 .49997 .22534 .49591 .21696 .48836 Mtetra
.21696 .48836 .22534 .49591 .23766 .49183 .22931 .48425 Mtetra
.22931 .48425 .23766 .49183 .25004 .48773 .24173 .48011 Mtetra
.24173 .48011 .25004 .48773 .26248 .48361 .2542 .47596 Mtetra
.2542 .47596 .26248 .48361 .27498 .47947 .26673 .47178 Mtetra
.26673 .47178 .27498 .47947 .28754 .47532 .27933 .46759 Mtetra
.27933 .46759 .28754 .47532 .30016 .47114 .29198 .46337 Mtetra
.29198 .46337 .30016 .47114 .31283 .46694 .3047 .45914 Mtetra
.928 .543 .216 r
.3047 .45914 .31283 .46694 .32298 .50544 .31476 .49769 Mtetra
.646 .762 .934 r
.31476 .49769 .32298 .50544 .33594 .50125 .32777 .49347 Mtetra
.32777 .49347 .33594 .50125 .34897 .49704 .34083 .48922 Mtetra
.34083 .48922 .34897 .49704 .36206 .49281 .35396 .48495 Mtetra
.35396 .48495 .36206 .49281 .37521 .48856 .36715 .48066 Mtetra
.36715 .48066 .37521 .48856 .38843 .48429 .38041 .47635 Mtetra
.38041 .47635 .38843 .48429 .40172 .48 .39374 .47201 Mtetra
.39374 .47201 .40172 .48 .41507 .47568 .40713 .46766 Mtetra
.40713 .46766 .41507 .47568 .42848 .47135 .42059 .46328 Mtetra
.42059 .46328 .42848 .47135 .44197 .46699 .43412 .45888 Mtetra
.43412 .45888 .44197 .46699 .45552 .46261 .44771 .45446 Mtetra
.44771 .45446 .45552 .46261 .46914 .45821 .46137 .45002 Mtetra
.46137 .45002 .46914 .45821 .48283 .45378 .47511 .44556 Mtetra
.47511 .44556 .48283 .45378 .49658 .44934 .48891 .44107 Mtetra
.48891 .44107 .49658 .44934 .51041 .44487 .50278 .43656 Mtetra
.50278 .43656 .51041 .44487 .52431 .44038 .51672 .43202 Mtetra
.51672 .43202 .52431 .44038 .53827 .43586 .53073 .42747 Mtetra
.971 .73 .515 r
.53073 .42747 .53827 .43586 .5515 .33494 .54423 .32632 Mtetra
.654 .753 .923 r
.54423 .32632 .5515 .33494 .56519 .33028 .55796 .32161 Mtetra
.55796 .32161 .56519 .33028 .57894 .32559 .57176 .31688 Mtetra
.57176 .31688 .57894 .32559 .59277 .32088 .58563 .31213 Mtetra
.58563 .31213 .59277 .32088 .60666 .31615 .59957 .30735 Mtetra
.59957 .30735 .60666 .31615 .62063 .31139 .61359 .30255 Mtetra
.61359 .30255 .62063 .31139 .63466 .30661 .62767 .29772 Mtetra
.62767 .29772 .63466 .30661 .64877 .30181 .64182 .29287 Mtetra
.64182 .29287 .64877 .30181 .66294 .29698 .65604 .288 Mtetra
.65604 .288 .66294 .29698 .67719 .29212 .67034 .2831 Mtetra
.67034 .2831 .67719 .29212 .69151 .28724 .68471 .27817 Mtetra
.68471 .27817 .69151 .28724 .7059 .28234 .69915 .27322 Mtetra
.69915 .27322 .7059 .28234 .72037 .27741 .71367 .26825 Mtetra
.71367 .26825 .72037 .27741 .73491 .27246 .72826 .26325 Mtetra
.72826 .26325 .73491 .27246 .74952 .26748 .74292 .25822 Mtetra
.74292 .25822 .74952 .26748 .76421 .26248 .75767 .25317 Mtetra
.75767 .25317 .76421 .26248 .77897 .25745 .77248 .24809 Mtetra
.65 .758 .929 r
.09959 .51724 .10834 .52454 .12019 .5206 .11147 .51327 Mtetra
.11147 .51327 .12019 .5206 .13208 .51663 .1234 .50927 Mtetra
.1234 .50927 .13208 .51663 .14404 .51265 .13538 .50525 Mtetra
.13538 .50525 .14404 .51265 .15605 .50865 .14742 .50122 Mtetra
.14742 .50122 .15605 .50865 .16812 .50463 .15952 .49716 Mtetra
.15952 .49716 .16812 .50463 .18024 .50059 .17168 .49309 Mtetra
.17168 .49309 .18024 .50059 .19242 .49654 .18389 .48899 Mtetra
.18389 .48899 .19242 .49654 .20466 .49246 .19617 .48488 Mtetra
.19617 .48488 .20466 .49246 .21696 .48836 .2085 .48075 Mtetra
.2085 .48075 .21696 .48836 .22931 .48425 .22089 .4766 Mtetra
.22089 .4766 .22931 .48425 .24173 .48011 .23334 .47243 Mtetra
.23334 .47243 .24173 .48011 .2542 .47596 .24584 .46823 Mtetra
.24584 .46823 .2542 .47596 .26673 .47178 .25841 .46402 Mtetra
.25841 .46402 .26673 .47178 .27933 .46759 .27104 .45979 Mtetra
.27104 .45979 .27933 .46759 .29198 .46337 .28373 .45554 Mtetra
.28373 .45554 .29198 .46337 .3047 .45914 .29649 .45126 Mtetra
.928 .543 .216 r
.29649 .45126 .3047 .45914 .31476 .49769 .30647 .48987 Mtetra
.646 .762 .934 r
.30647 .48987 .31476 .49769 .32777 .49347 .31951 .48561 Mtetra
.31951 .48561 .32777 .49347 .34083 .48922 .33262 .48132 Mtetra
.33262 .48132 .34083 .48922 .35396 .48495 .34578 .47701 Mtetra
.34578 .47701 .35396 .48495 .36715 .48066 .35902 .47268 Mtetra
.35902 .47268 .36715 .48066 .38041 .47635 .37232 .46833 Mtetra
.37232 .46833 .38041 .47635 .39374 .47201 .38569 .46396 Mtetra
.38569 .46396 .39374 .47201 .40713 .46766 .39912 .45956 Mtetra
.39912 .45956 .40713 .46766 .42059 .46328 .41262 .45515 Mtetra
.41262 .45515 .42059 .46328 .43412 .45888 .42619 .45071 Mtetra
.42619 .45071 .43412 .45888 .44771 .45446 .43983 .44624 Mtetra
.43983 .44624 .44771 .45446 .46137 .45002 .45354 .44176 Mtetra
.45354 .44176 .46137 .45002 .47511 .44556 .46731 .43725 Mtetra
.46731 .43725 .47511 .44556 .48891 .44107 .48116 .43272 Mtetra
.48116 .43272 .48891 .44107 .50278 .43656 .49508 .42817 Mtetra
.49508 .42817 .50278 .43656 .51672 .43202 .50906 .42359 Mtetra
.50906 .42359 .51672 .43202 .53073 .42747 .52312 .41899 Mtetra
.971 .73 .515 r
.52312 .41899 .53073 .42747 .54423 .32632 .53689 .31761 Mtetra
.654 .753 .923 r
.53689 .31761 .54423 .32632 .55796 .32161 .55067 .31286 Mtetra
.55067 .31286 .55796 .32161 .57176 .31688 .56451 .30808 Mtetra
.56451 .30808 .57176 .31688 .58563 .31213 .57843 .30329 Mtetra
.57843 .30329 .58563 .31213 .59957 .30735 .59242 .29846 Mtetra
.59242 .29846 .59957 .30735 .61359 .30255 .60648 .29362 Mtetra
.60648 .29362 .61359 .30255 .62767 .29772 .62061 .28875 Mtetra
.62061 .28875 .62767 .29772 .64182 .29287 .63481 .28385 Mtetra
.63481 .28385 .64182 .29287 .65604 .288 .64908 .27893 Mtetra
.64908 .27893 .65604 .288 .67034 .2831 .66343 .27399 Mtetra
.66343 .27399 .67034 .2831 .68471 .27817 .67784 .26902 Mtetra
.67784 .26902 .68471 .27817 .69915 .27322 .69234 .26402 Mtetra
.69234 .26402 .69915 .27322 .71367 .26825 .70691 .259 Mtetra
.70691 .259 .71367 .26825 .72826 .26325 .72155 .25395 Mtetra
.72155 .25395 .72826 .26325 .74292 .25822 .73627 .24887 Mtetra
.73627 .24887 .74292 .25822 .75767 .25317 .75106 .24377 Mtetra
.75106 .24377 .75767 .25317 .77248 .24809 .76593 .23865 Mtetra
.65 .758 .929 r
.09077 .50988 .09959 .51724 .11147 .51327 .10267 .50587 Mtetra
.10267 .50587 .11147 .51327 .1234 .50927 .11463 .50184 Mtetra
.11463 .50184 .1234 .50927 .13538 .50525 .12665 .49779 Mtetra
.12665 .49779 .13538 .50525 .14742 .50122 .13872 .49372 Mtetra
.13872 .49372 .14742 .50122 .15952 .49716 .15086 .48963 Mtetra
.15086 .48963 .15952 .49716 .17168 .49309 .16304 .48552 Mtetra
.16304 .48552 .17168 .49309 .18389 .48899 .17529 .48139 Mtetra
.17529 .48139 .18389 .48899 .19617 .48488 .1876 .47724 Mtetra
.1876 .47724 .19617 .48488 .2085 .48075 .19996 .47307 Mtetra
.19996 .47307 .2085 .48075 .22089 .4766 .21239 .46888 Mtetra
.21239 .46888 .22089 .4766 .23334 .47243 .22487 .46467 Mtetra
.22487 .46467 .23334 .47243 .24584 .46823 .23741 .46044 Mtetra
.23741 .46044 .24584 .46823 .25841 .46402 .25002 .45619 Mtetra
.25002 .45619 .25841 .46402 .27104 .45979 .26269 .45192 Mtetra
.26269 .45192 .27104 .45979 .28373 .45554 .27541 .44763 Mtetra
.27541 .44763 .28373 .45554 .29649 .45126 .2882 .44332 Mtetra
.928 .543 .216 r
.2882 .44332 .29649 .45126 .30647 .48987 .2981 .48198 Mtetra
.646 .762 .934 r
.2981 .48198 .30647 .48987 .31951 .48561 .31118 .47768 Mtetra
.31118 .47768 .31951 .48561 .33262 .48132 .32433 .47335 Mtetra
.32433 .47335 .33262 .48132 .34578 .47701 .33753 .469 Mtetra
.33753 .469 .34578 .47701 .35902 .47268 .35081 .46463 Mtetra
.35081 .46463 .35902 .47268 .37232 .46833 .36415 .46024 Mtetra
.36415 .46024 .37232 .46833 .38569 .46396 .37756 .45583 Mtetra
.37756 .45583 .38569 .46396 .39912 .45956 .39103 .45139 Mtetra
.39103 .45139 .39912 .45956 .41262 .45515 .40458 .44693 Mtetra
.40458 .44693 .41262 .45515 .42619 .45071 .41819 .44245 Mtetra
.41819 .44245 .42619 .45071 .43983 .44624 .43187 .43795 Mtetra
.43187 .43795 .43983 .44624 .45354 .44176 .44562 .43342 Mtetra
.44562 .43342 .45354 .44176 .46731 .43725 .45944 .42887 Mtetra
.45944 .42887 .46731 .43725 .48116 .43272 .47334 .4243 Mtetra
.47334 .4243 .48116 .43272 .49508 .42817 .4873 .4197 Mtetra
.4873 .4197 .49508 .42817 .50906 .42359 .50133 .41508 Mtetra
.50133 .41508 .50906 .42359 .52312 .41899 .51544 .41044 Mtetra
.971 .73 .515 r
.51544 .41044 .52312 .41899 .53689 .31761 .52948 .30882 Mtetra
.654 .753 .923 r
.52948 .30882 .53689 .31761 .55067 .31286 .5433 .30403 Mtetra
.5433 .30403 .55067 .31286 .56451 .30808 .5572 .29921 Mtetra
.5572 .29921 .56451 .30808 .57843 .30329 .57116 .29437 Mtetra
.57116 .29437 .57843 .30329 .59242 .29846 .5852 .2895 Mtetra
.5852 .2895 .59242 .29846 .60648 .29362 .5993 .28461 Mtetra
.5993 .28461 .60648 .29362 .62061 .28875 .61348 .27969 Mtetra
.61348 .27969 .62061 .28875 .63481 .28385 .62773 .27475 Mtetra
.62773 .27475 .63481 .28385 .64908 .27893 .64205 .26978 Mtetra
.64205 .26978 .64908 .27893 .66343 .27399 .65645 .26479 Mtetra
.65645 .26479 .66343 .27399 .67784 .26902 .67092 .25977 Mtetra
.67092 .25977 .67784 .26902 .69234 .26402 .68546 .25473 Mtetra
.68546 .25473 .69234 .26402 .70691 .259 .70008 .24966 Mtetra
.70008 .24966 .70691 .259 .72155 .25395 .71477 .24456 Mtetra
.71477 .24456 .72155 .25395 .73627 .24887 .72955 .23944 Mtetra
.72955 .23944 .73627 .24887 .75106 .24377 .74439 .23429 Mtetra
.74439 .23429 .75106 .24377 .76593 .23865 .75932 .22911 Mtetra
.65 .758 .929 r
.08186 .50246 .09077 .50988 .10267 .50587 .0938 .49841 Mtetra
.0938 .49841 .10267 .50587 .11463 .50184 .10579 .49434 Mtetra
.10579 .49434 .11463 .50184 .12665 .49779 .11784 .49026 Mtetra
.11784 .49026 .12665 .49779 .13872 .49372 .12995 .48615 Mtetra
.12995 .48615 .13872 .49372 .15086 .48963 .14211 .48202 Mtetra
.14211 .48202 .15086 .48963 .16304 .48552 .15433 .47788 Mtetra
.15433 .47788 .16304 .48552 .17529 .48139 .16661 .47371 Mtetra
.16661 .47371 .17529 .48139 .1876 .47724 .17895 .46953 Mtetra
.17895 .46953 .1876 .47724 .19996 .47307 .19135 .46532 Mtetra
.19135 .46532 .19996 .47307 .21239 .46888 .20381 .4611 Mtetra
.20381 .4611 .21239 .46888 .22487 .46467 .21633 .45685 Mtetra
.21633 .45685 .22487 .46467 .23741 .46044 .22891 .45258 Mtetra
.22891 .45258 .23741 .46044 .25002 .45619 .24155 .44829 Mtetra
.24155 .44829 .25002 .45619 .26269 .45192 .25425 .44399 Mtetra
.25425 .44399 .26269 .45192 .27541 .44763 .26702 .43966 Mtetra
.26702 .43966 .27541 .44763 .2882 .44332 .27984 .43531 Mtetra
.928 .543 .216 r
.27984 .43531 .2882 .44332 .2981 .48198 .28966 .47402 Mtetra
.646 .762 .934 r
.28966 .47402 .2981 .48198 .31118 .47768 .30278 .46967 Mtetra
.30278 .46967 .31118 .47768 .32433 .47335 .31596 .46531 Mtetra
.31596 .46531 .32433 .47335 .33753 .469 .32921 .46092 Mtetra
.32921 .46092 .33753 .469 .35081 .46463 .34252 .45651 Mtetra
.34252 .45651 .35081 .46463 .36415 .46024 .35591 .45207 Mtetra
.35591 .45207 .36415 .46024 .37756 .45583 .36936 .44762 Mtetra
.36936 .44762 .37756 .45583 .39103 .45139 .38287 .44314 Mtetra
.38287 .44314 .39103 .45139 .40458 .44693 .39646 .43864 Mtetra
.39646 .43864 .40458 .44693 .41819 .44245 .41012 .43412 Mtetra
.41012 .43412 .41819 .44245 .43187 .43795 .42384 .42957 Mtetra
.42384 .42957 .43187 .43795 .44562 .43342 .43764 .425 Mtetra
.43764 .425 .44562 .43342 .45944 .42887 .4515 .42041 Mtetra
.4515 .42041 .45944 .42887 .47334 .4243 .46544 .4158 Mtetra
.46544 .4158 .47334 .4243 .4873 .4197 .47945 .41116 Mtetra
.47945 .41116 .4873 .4197 .50133 .41508 .49353 .40649 Mtetra
.49353 .40649 .50133 .41508 .51544 .41044 .50769 .4018 Mtetra
.971 .73 .515 r
.50769 .4018 .51544 .41044 .52948 .30882 .522 .29995 Mtetra
.654 .753 .923 r
.522 .29995 .52948 .30882 .5433 .30403 .53587 .29511 Mtetra
.53587 .29511 .5433 .30403 .5572 .29921 .54981 .29025 Mtetra
.54981 .29025 .5572 .29921 .57116 .29437 .56382 .28536 Mtetra
.56382 .28536 .57116 .29437 .5852 .2895 .5779 .28045 Mtetra
.5779 .28045 .5852 .2895 .5993 .28461 .59206 .27551 Mtetra
.59206 .27551 .5993 .28461 .61348 .27969 .60628 .27055 Mtetra
.60628 .27055 .61348 .27969 .62773 .27475 .62058 .26556 Mtetra
.62058 .26556 .62773 .27475 .64205 .26978 .63495 .26054 Mtetra
.63495 .26054 .64205 .26978 .65645 .26479 .6494 .2555 Mtetra
.6494 .2555 .65645 .26479 .67092 .25977 .66392 .25044 Mtetra
.66392 .25044 .67092 .25977 .68546 .25473 .67852 .24535 Mtetra
.67852 .24535 .68546 .25473 .70008 .24966 .69319 .24023 Mtetra
.69319 .24023 .70008 .24966 .71477 .24456 .70794 .23508 Mtetra
.70794 .23508 .71477 .24456 .72955 .23944 .72276 .22991 Mtetra
.72276 .22991 .72955 .23944 .74439 .23429 .73766 .22471 Mtetra
.73766 .22471 .74439 .23429 .75932 .22911 .75264 .21949 Mtetra
.65 .758 .929 r
.07288 .49497 .08186 .50246 .0938 .49841 .08485 .49089 Mtetra
.08485 .49089 .0938 .49841 .10579 .49434 .09687 .48678 Mtetra
.09687 .48678 .10579 .49434 .11784 .49026 .10896 .48266 Mtetra
.10896 .48266 .11784 .49026 .12995 .48615 .12109 .47852 Mtetra
.12109 .47852 .12995 .48615 .14211 .48202 .13329 .47435 Mtetra
.13329 .47435 .14211 .48202 .15433 .47788 .14555 .47017 Mtetra
.14555 .47017 .15433 .47788 .16661 .47371 .15786 .46597 Mtetra
.15786 .46597 .16661 .47371 .17895 .46953 .17023 .46175 Mtetra
.17023 .46175 .17895 .46953 .19135 .46532 .18267 .4575 Mtetra
.18267 .4575 .19135 .46532 .20381 .4611 .19516 .45324 Mtetra
.19516 .45324 .20381 .4611 .21633 .45685 .20771 .44896 Mtetra
.20771 .44896 .21633 .45685 .22891 .45258 .22033 .44465 Mtetra
.22033 .44465 .22891 .45258 .24155 .44829 .23301 .44032 Mtetra
.23301 .44032 .24155 .44829 .25425 .44399 .24574 .43598 Mtetra
.24574 .43598 .25425 .44399 .26702 .43966 .25855 .43161 Mtetra
.25855 .43161 .26702 .43966 .27984 .43531 .27141 .42722 Mtetra
.928 .543 .216 r
.27141 .42722 .27984 .43531 .28966 .47402 .28114 .46598 Mtetra
.646 .762 .934 r
.28114 .46598 .28966 .47402 .30278 .46967 .29429 .46159 Mtetra
.29429 .46159 .30278 .46967 .31596 .46531 .30752 .45719 Mtetra
.30752 .45719 .31596 .46531 .32921 .46092 .32081 .45276 Mtetra
.32081 .45276 .32921 .46092 .34252 .45651 .33416 .44831 Mtetra
.33416 .44831 .34252 .45651 .35591 .45207 .34759 .44383 Mtetra
.34759 .44383 .35591 .45207 .36936 .44762 .36108 .43934 Mtetra
.36108 .43934 .36936 .44762 .38287 .44314 .37464 .43482 Mtetra
.37464 .43482 .38287 .44314 .39646 .43864 .38827 .43027 Mtetra
.38827 .43027 .39646 .43864 .41012 .43412 .40197 .42571 Mtetra
.40197 .42571 .41012 .43412 .42384 .42957 .41574 .42112 Mtetra
.41574 .42112 .42384 .42957 .43764 .425 .42958 .41651 Mtetra
.42958 .41651 .43764 .425 .4515 .42041 .44349 .41187 Mtetra
.44349 .41187 .4515 .42041 .46544 .4158 .45747 .40721 Mtetra
.45747 .40721 .46544 .4158 .47945 .41116 .47153 .40253 Mtetra
.47153 .40253 .47945 .41116 .49353 .40649 .48565 .39782 Mtetra
.48565 .39782 .49353 .40649 .50769 .4018 .49986 .39308 Mtetra
.971 .73 .515 r
.49986 .39308 .50769 .4018 .522 .29995 .51446 .291 Mtetra
.654 .753 .923 r
.51446 .291 .522 .29995 .53587 .29511 .52837 .28611 Mtetra
.52837 .28611 .53587 .29511 .54981 .29025 .54236 .28121 Mtetra
.54236 .28121 .54981 .29025 .56382 .28536 .55642 .27627 Mtetra
.55642 .27627 .56382 .28536 .5779 .28045 .57054 .27131 Mtetra
.57054 .27131 .5779 .28045 .59206 .27551 .58475 .26633 Mtetra
.58475 .26633 .59206 .27551 .60628 .27055 .59902 .26132 Mtetra
.59902 .26132 .60628 .27055 .62058 .26556 .61337 .25628 Mtetra
.61337 .25628 .62058 .26556 .63495 .26054 .62779 .25122 Mtetra
.62779 .25122 .63495 .26054 .6494 .2555 .64229 .24613 Mtetra
.64229 .24613 .6494 .2555 .66392 .25044 .65686 .24102 Mtetra
.65686 .24102 .66392 .25044 .67852 .24535 .67151 .23588 Mtetra
.67151 .23588 .67852 .24535 .69319 .24023 .68623 .23071 Mtetra
.68623 .23071 .69319 .24023 .70794 .23508 .70103 .22551 Mtetra
.70103 .22551 .70794 .23508 .72276 .22991 .71591 .22029 Mtetra
.71591 .22029 .72276 .22991 .73766 .22471 .73087 .21504 Mtetra
.73087 .21504 .73766 .22471 .75264 .21949 .7459 .20976 Mtetra
.65 .758 .929 r
.06383 .48742 .07288 .49497 .08485 .49089 .07582 .4833 Mtetra
.07582 .4833 .08485 .49089 .09687 .48678 .08788 .47916 Mtetra
.08788 .47916 .09687 .48678 .10896 .48266 .09999 .475 Mtetra
.09999 .475 .10896 .48266 .12109 .47852 .11216 .47082 Mtetra
.11216 .47082 .12109 .47852 .13329 .47435 .12439 .46662 Mtetra
.12439 .46662 .13329 .47435 .14555 .47017 .13668 .4624 Mtetra
.13668 .4624 .14555 .47017 .15786 .46597 .14903 .45816 Mtetra
.14903 .45816 .15786 .46597 .17023 .46175 .16143 .4539 Mtetra
.16143 .4539 .17023 .46175 .18267 .4575 .1739 .44962 Mtetra
.1739 .44962 .18267 .4575 .19516 .45324 .18643 .44531 Mtetra
.18643 .44531 .19516 .45324 .20771 .44896 .19902 .44099 Mtetra
.19902 .44099 .20771 .44896 .22033 .44465 .21167 .43665 Mtetra
.21167 .43665 .22033 .44465 .23301 .44032 .22438 .43228 Mtetra
.22438 .43228 .23301 .44032 .24574 .43598 .23716 .42789 Mtetra
.23716 .42789 .24574 .43598 .25855 .43161 .25 .42348 Mtetra
.25 .42348 .25855 .43161 .27141 .42722 .2629 .41905 Mtetra
.928 .543 .216 r
.2629 .41905 .27141 .42722 .28114 .46598 .27254 .45787 Mtetra
.646 .762 .934 r
.27254 .45787 .28114 .46598 .29429 .46159 .28573 .45344 Mtetra
.28573 .45344 .29429 .46159 .30752 .45719 .29899 .44899 Mtetra
.29899 .44899 .30752 .45719 .32081 .45276 .31232 .44452 Mtetra
.31232 .44452 .32081 .45276 .33416 .44831 .32572 .44003 Mtetra
.32572 .44003 .33416 .44831 .34759 .44383 .33919 .43551 Mtetra
.33919 .43551 .34759 .44383 .36108 .43934 .35272 .43097 Mtetra
.35272 .43097 .36108 .43934 .37464 .43482 .36632 .42641 Mtetra
.36632 .42641 .37464 .43482 .38827 .43027 .38 .42183 Mtetra
.38 .42183 .38827 .43027 .40197 .42571 .39374 .41722 Mtetra
.39374 .41722 .40197 .42571 .41574 .42112 .40755 .41259 Mtetra
.40755 .41259 .41574 .42112 .42958 .41651 .42144 .40793 Mtetra
.42144 .40793 .42958 .41651 .44349 .41187 .43539 .40325 Mtetra
.43539 .40325 .44349 .41187 .45747 .40721 .44942 .39854 Mtetra
.44942 .39854 .45747 .40721 .47153 .40253 .46352 .39381 Mtetra
.46352 .39381 .47153 .40253 .48565 .39782 .4777 .38906 Mtetra
.4777 .38906 .48565 .39782 .49986 .39308 .49195 .38428 Mtetra
.971 .73 .515 r
.49195 .38428 .49986 .39308 .51446 .291 .50684 .28196 Mtetra
.654 .753 .923 r
.50684 .28196 .51446 .291 .52837 .28611 .5208 .27703 Mtetra
.5208 .27703 .52837 .28611 .54236 .28121 .53483 .27208 Mtetra
.53483 .27208 .54236 .28121 .55642 .27627 .54894 .2671 Mtetra
.54894 .2671 .55642 .27627 .57054 .27131 .56312 .26209 Mtetra
.56312 .26209 .57054 .27131 .58475 .26633 .57737 .25706 Mtetra
.57737 .25706 .58475 .26633 .59902 .26132 .59169 .252 Mtetra
.59169 .252 .59902 .26132 .61337 .25628 .60609 .24692 Mtetra
.60609 .24692 .61337 .25628 .62779 .25122 .62056 .24181 Mtetra
.62056 .24181 .62779 .25122 .64229 .24613 .63511 .23667 Mtetra
.63511 .23667 .64229 .24613 .65686 .24102 .64973 .2315 Mtetra
.64973 .2315 .65686 .24102 .67151 .23588 .66443 .22631 Mtetra
.66443 .22631 .67151 .23588 .68623 .23071 .6792 .2211 Mtetra
.6792 .2211 .68623 .23071 .70103 .22551 .69406 .21585 Mtetra
.69406 .21585 .70103 .22551 .71591 .22029 .70899 .21058 Mtetra
.70899 .21058 .71591 .22029 .73087 .21504 .724 .20528 Mtetra
.724 .20528 .73087 .21504 .7459 .20976 .73909 .19995 Mtetra
.65 .758 .929 r
.05469 .47979 .06383 .48742 .07582 .4833 .06672 .47564 Mtetra
.06672 .47564 .07582 .4833 .08788 .47916 .0788 .47146 Mtetra
.0788 .47146 .08788 .47916 .09999 .475 .09095 .46726 Mtetra
.09095 .46726 .09999 .475 .11216 .47082 .10315 .46305 Mtetra
.10315 .46305 .11216 .47082 .12439 .46662 .11541 .45881 Mtetra
.11541 .45881 .12439 .46662 .13668 .4624 .12773 .45455 Mtetra
.12773 .45455 .13668 .4624 .14903 .45816 .14011 .45028 Mtetra
.14011 .45028 .14903 .45816 .16143 .4539 .15256 .44598 Mtetra
.15256 .44598 .16143 .4539 .1739 .44962 .16506 .44166 Mtetra
.16506 .44166 .1739 .44962 .18643 .44531 .17762 .43732 Mtetra
.17762 .43732 .18643 .44531 .19902 .44099 .19025 .43295 Mtetra
.19025 .43295 .19902 .44099 .21167 .43665 .20293 .42857 Mtetra
.20293 .42857 .21167 .43665 .22438 .43228 .21568 .42416 Mtetra
.21568 .42416 .22438 .43228 .23716 .42789 .22849 .41974 Mtetra
.22849 .41974 .23716 .42789 .25 .42348 .24137 .41529 Mtetra
.24137 .41529 .25 .42348 .2629 .41905 .25431 .41082 Mtetra
.928 .543 .216 r
.25431 .41082 .2629 .41905 .27254 .45787 .26385 .44968 Mtetra
.646 .762 .934 r
.26385 .44968 .27254 .45787 .28573 .45344 .27709 .44521 Mtetra
.27709 .44521 .28573 .45344 .29899 .44899 .29039 .44072 Mtetra
.29039 .44072 .29899 .44899 .31232 .44452 .30376 .43621 Mtetra
.30376 .43621 .31232 .44452 .32572 .44003 .3172 .43167 Mtetra
.3172 .43167 .32572 .44003 .33919 .43551 .33071 .42712 Mtetra
.33071 .42712 .33919 .43551 .35272 .43097 .34428 .42253 Mtetra
.34428 .42253 .35272 .43097 .36632 .42641 .35793 .41793 Mtetra
.35793 .41793 .36632 .42641 .38 .42183 .37165 .4133 Mtetra
.37165 .4133 .38 .42183 .39374 .41722 .38543 .40865 Mtetra
.38543 .40865 .39374 .41722 .40755 .41259 .39929 .40397 Mtetra
.39929 .40397 .40755 .41259 .42144 .40793 .41322 .39927 Mtetra
.41322 .39927 .42144 .40793 .43539 .40325 .42722 .39454 Mtetra
.42722 .39454 .43539 .40325 .44942 .39854 .4413 .38979 Mtetra
.4413 .38979 .44942 .39854 .46352 .39381 .45545 .38502 Mtetra
.45545 .38502 .46352 .39381 .4777 .38906 .46967 .38022 Mtetra
.46967 .38022 .4777 .38906 .49195 .38428 .48397 .37539 Mtetra
.971 .73 .515 r
.48397 .37539 .49195 .38428 .50684 .28196 .49915 .27284 Mtetra
.654 .753 .923 r
.49915 .27284 .50684 .28196 .5208 .27703 .51316 .26786 Mtetra
.51316 .26786 .5208 .27703 .53483 .27208 .52724 .26286 Mtetra
.52724 .26286 .53483 .27208 .54894 .2671 .54139 .25783 Mtetra
.54139 .25783 .54894 .2671 .56312 .26209 .55562 .25278 Mtetra
.55562 .25278 .56312 .26209 .57737 .25706 .56991 .2477 Mtetra
.56991 .2477 .57737 .25706 .59169 .252 .58429 .24259 Mtetra
.58429 .24259 .59169 .252 .60609 .24692 .59873 .23746 Mtetra
.59873 .23746 .60609 .24692 .62056 .24181 .61326 .2323 Mtetra
.61326 .2323 .62056 .24181 .63511 .23667 .62785 .22711 Mtetra
.62785 .22711 .63511 .23667 .64973 .2315 .64253 .2219 Mtetra
.64253 .2219 .64973 .2315 .66443 .22631 .65728 .21666 Mtetra
.65728 .21666 .66443 .22631 .6792 .2211 .67211 .21139 Mtetra
.67211 .21139 .6792 .2211 .69406 .21585 .68702 .20609 Mtetra
.68702 .20609 .69406 .21585 .70899 .21058 .70201 .20077 Mtetra
.70201 .20077 .70899 .21058 .724 .20528 .71707 .19542 Mtetra
.71707 .19542 .724 .20528 .73909 .19995 .73222 .19004 Mtetra
.65 .758 .929 r
.04547 .4721 .05469 .47979 .06672 .47564 .05753 .46791 Mtetra
.05753 .46791 .06672 .47564 .0788 .47146 .06965 .4637 Mtetra
.06965 .4637 .0788 .47146 .09095 .46726 .08182 .45946 Mtetra
.08182 .45946 .09095 .46726 .10315 .46305 .09406 .45521 Mtetra
.09406 .45521 .10315 .46305 .11541 .45881 .10635 .45094 Mtetra
.10635 .45094 .11541 .45881 .12773 .45455 .11871 .44664 Mtetra
.11871 .44664 .12773 .45455 .14011 .45028 .13112 .44232 Mtetra
.13112 .44232 .14011 .45028 .15256 .44598 .1436 .43798 Mtetra
.1436 .43798 .15256 .44598 .16506 .44166 .15613 .43363 Mtetra
.15613 .43363 .16506 .44166 .17762 .43732 .16873 .42925 Mtetra
.16873 .42925 .17762 .43732 .19025 .43295 .18139 .42484 Mtetra
.18139 .42484 .19025 .43295 .20293 .42857 .19412 .42042 Mtetra
.19412 .42042 .20293 .42857 .21568 .42416 .2069 .41597 Mtetra
.2069 .41597 .21568 .42416 .22849 .41974 .21975 .41151 Mtetra
.21975 .41151 .22849 .41974 .24137 .41529 .23266 .40702 Mtetra
.23266 .40702 .24137 .41529 .25431 .41082 .24564 .4025 Mtetra
.928 .543 .216 r
.24564 .4025 .25431 .41082 .26385 .44968 .25509 .44141 Mtetra
.646 .762 .934 r
.25509 .44141 .26385 .44968 .27709 .44521 .26837 .43691 Mtetra
.26837 .43691 .27709 .44521 .29039 .44072 .28171 .43237 Mtetra
.28171 .43237 .29039 .44072 .30376 .43621 .29512 .42782 Mtetra
.29512 .42782 .30376 .43621 .3172 .43167 .3086 .42324 Mtetra
.3086 .42324 .3172 .43167 .33071 .42712 .32215 .41864 Mtetra
.32215 .41864 .33071 .42712 .34428 .42253 .33577 .41401 Mtetra
.33577 .41401 .34428 .42253 .35793 .41793 .34946 .40936 Mtetra
.34946 .40936 .35793 .41793 .37165 .4133 .36322 .40469 Mtetra
.36322 .40469 .37165 .4133 .38543 .40865 .37705 .39999 Mtetra
.37705 .39999 .38543 .40865 .39929 .40397 .39095 .39527 Mtetra
.39095 .39527 .39929 .40397 .41322 .39927 .40492 .39053 Mtetra
.40492 .39053 .41322 .39927 .42722 .39454 .41897 .38575 Mtetra
.41897 .38575 .42722 .39454 .4413 .38979 .43309 .38096 Mtetra
.43309 .38096 .4413 .38979 .45545 .38502 .44729 .37614 Mtetra
.44729 .37614 .45545 .38502 .46967 .38022 .46156 .37129 Mtetra
.46156 .37129 .46967 .38022 .48397 .37539 .47591 .36642 Mtetra
.971 .73 .515 r
.47591 .36642 .48397 .37539 .49915 .27284 .49139 .26363 Mtetra
.654 .753 .923 r
.49139 .26363 .49915 .27284 .51316 .26786 .50544 .25861 Mtetra
.50544 .25861 .51316 .26786 .52724 .26286 .51957 .25356 Mtetra
.51957 .25356 .52724 .26286 .54139 .25783 .53377 .24848 Mtetra
.53377 .24848 .54139 .25783 .55562 .25278 .54804 .24338 Mtetra
.54804 .24338 .55562 .25278 .56991 .2477 .56239 .23825 Mtetra
.56239 .23825 .56991 .2477 .58429 .24259 .57681 .2331 Mtetra
.57681 .2331 .58429 .24259 .59873 .23746 .59131 .22791 Mtetra
.59131 .22791 .59873 .23746 .61326 .2323 .60588 .2227 Mtetra
.60588 .2227 .61326 .2323 .62785 .22711 .62053 .21747 Mtetra
.62053 .21747 .62785 .22711 .64253 .2219 .63526 .2122 Mtetra
.63526 .2122 .64253 .2219 .65728 .21666 .65006 .20691 Mtetra
.65006 .20691 .65728 .21666 .67211 .21139 .66495 .20159 Mtetra
.66495 .20159 .67211 .21139 .68702 .20609 .67991 .19624 Mtetra
.67991 .19624 .68702 .20609 .70201 .20077 .69495 .19086 Mtetra
.69495 .19086 .70201 .20077 .71707 .19542 .71007 .18546 Mtetra
.71007 .18546 .71707 .19542 .73222 .19004 .72528 .18002 Mtetra
.65 .758 .929 r
.03617 .46435 .04547 .4721 .05753 .46791 .04826 .46012 Mtetra
.04826 .46012 .05753 .46791 .06965 .4637 .06041 .45587 Mtetra
.06041 .45587 .06965 .4637 .08182 .45946 .07262 .45159 Mtetra
.07262 .45159 .08182 .45946 .09406 .45521 .08488 .4473 Mtetra
.08488 .4473 .09406 .45521 .10635 .45094 .09721 .44299 Mtetra
.09721 .44299 .10635 .45094 .11871 .44664 .1096 .43865 Mtetra
.1096 .43865 .11871 .44664 .13112 .44232 .12205 .4343 Mtetra
.12205 .4343 .13112 .44232 .1436 .43798 .13456 .42992 Mtetra
.13456 .42992 .1436 .43798 .15613 .43363 .14713 .42552 Mtetra
.14713 .42552 .15613 .43363 .16873 .42925 .15976 .4211 Mtetra
.15976 .4211 .16873 .42925 .18139 .42484 .17246 .41666 Mtetra
.17246 .41666 .18139 .42484 .19412 .42042 .18522 .4122 Mtetra
.18522 .4122 .19412 .42042 .2069 .41597 .19804 .40771 Mtetra
.19804 .40771 .2069 .41597 .21975 .41151 .21093 .4032 Mtetra
.21093 .4032 .21975 .41151 .23266 .40702 .22388 .39867 Mtetra
.22388 .39867 .23266 .40702 .24564 .4025 .23689 .39412 Mtetra
.928 .543 .216 r
.23689 .39412 .24564 .4025 .25509 .44141 .24625 .43307 Mtetra
.646 .762 .934 r
.24625 .43307 .25509 .44141 .26837 .43691 .25956 .42852 Mtetra
.25956 .42852 .26837 .43691 .28171 .43237 .27294 .42395 Mtetra
.27294 .42395 .28171 .43237 .29512 .42782 .2864 .41935 Mtetra
.2864 .41935 .29512 .42782 .3086 .42324 .29992 .41473 Mtetra
.29992 .41473 .3086 .42324 .32215 .41864 .31351 .41008 Mtetra
.31351 .41008 .32215 .41864 .33577 .41401 .32717 .40541 Mtetra
.32717 .40541 .33577 .41401 .34946 .40936 .3409 .40072 Mtetra
.3409 .40072 .34946 .40936 .36322 .40469 .35471 .396 Mtetra
.35471 .396 .36322 .40469 .37705 .39999 .36858 .39126 Mtetra
.36858 .39126 .37705 .39999 .39095 .39527 .38253 .38649 Mtetra
.38253 .38649 .39095 .39527 .40492 .39053 .39655 .3817 Mtetra
.39655 .3817 .40492 .39053 .41897 .38575 .41064 .37688 Mtetra
.41064 .37688 .41897 .38575 .43309 .38096 .42481 .37204 Mtetra
.42481 .37204 .43309 .38096 .44729 .37614 .43905 .36717 Mtetra
.43905 .36717 .44729 .37614 .46156 .37129 .45337 .36227 Mtetra
.45337 .36227 .46156 .37129 .47591 .36642 .46777 .35735 Mtetra
.971 .73 .515 r
.46777 .35735 .47591 .36642 .49139 .26363 .48355 .25434 Mtetra
.654 .753 .923 r
.48355 .25434 .49139 .26363 .50544 .25861 .49766 .24927 Mtetra
.49766 .24927 .50544 .25861 .51957 .25356 .51183 .24417 Mtetra
.51183 .24417 .51957 .25356 .53377 .24848 .52608 .23904 Mtetra
.52608 .23904 .53377 .24848 .54804 .24338 .5404 .23389 Mtetra
.5404 .23389 .54804 .24338 .56239 .23825 .5548 .22871 Mtetra
.5548 .22871 .56239 .23825 .57681 .2331 .56927 .22351 Mtetra
.56927 .22351 .57681 .2331 .59131 .22791 .58381 .21828 Mtetra
.58381 .21828 .59131 .22791 .60588 .2227 .59844 .21301 Mtetra
.59844 .21301 .60588 .2227 .62053 .21747 .61314 .20773 Mtetra
.61314 .20773 .62053 .21747 .63526 .2122 .62792 .20241 Mtetra
.62792 .20241 .63526 .2122 .65006 .20691 .64278 .19707 Mtetra
.64278 .19707 .65006 .20691 .66495 .20159 .65771 .19169 Mtetra
.65771 .19169 .66495 .20159 .67991 .19624 .67273 .18629 Mtetra
.67273 .18629 .67991 .19624 .69495 .19086 .68783 .18086 Mtetra
.68783 .18086 .69495 .19086 .71007 .18546 .703 .1754 Mtetra
.703 .1754 .71007 .18546 .72528 .18002 .71826 .16991 Mtetra
.65 .758 .929 r
.02678 .45652 .03617 .46435 .04826 .46012 .03891 .45225 Mtetra
.03891 .45225 .04826 .46012 .06041 .45587 .05109 .44796 Mtetra
.05109 .44796 .06041 .45587 .07262 .45159 .06333 .44365 Mtetra
.06333 .44365 .07262 .45159 .08488 .4473 .07563 .43932 Mtetra
.07563 .43932 .08488 .4473 .09721 .44299 .08799 .43497 Mtetra
.08799 .43497 .09721 .44299 .1096 .43865 .10041 .4306 Mtetra
.10041 .4306 .1096 .43865 .12205 .4343 .11289 .4262 Mtetra
.11289 .4262 .12205 .4343 .13456 .42992 .12544 .42178 Mtetra
.12544 .42178 .13456 .42992 .14713 .42552 .13804 .41734 Mtetra
.13804 .41734 .14713 .42552 .15976 .4211 .15071 .41288 Mtetra
.15071 .41288 .15976 .4211 .17246 .41666 .16344 .4084 Mtetra
.16344 .4084 .17246 .41666 .18522 .4122 .17624 .4039 Mtetra
.17624 .4039 .18522 .4122 .19804 .40771 .1891 .39937 Mtetra
.1891 .39937 .19804 .40771 .21093 .4032 .20202 .39482 Mtetra
.20202 .39482 .21093 .4032 .22388 .39867 .21501 .39024 Mtetra
.21501 .39024 .22388 .39867 .23689 .39412 .22806 .38565 Mtetra
.928 .543 .216 r
.22806 .38565 .23689 .39412 .24625 .43307 .23732 .42465 Mtetra
.646 .762 .934 r
.23732 .42465 .24625 .43307 .25956 .42852 .25067 .42006 Mtetra
.25067 .42006 .25956 .42852 .27294 .42395 .2641 .41544 Mtetra
.2641 .41544 .27294 .42395 .2864 .41935 .27759 .4108 Mtetra
.27759 .4108 .2864 .41935 .29992 .41473 .29115 .40613 Mtetra
.29115 .40613 .29992 .41473 .31351 .41008 .30479 .40144 Mtetra
.30479 .40144 .31351 .41008 .32717 .40541 .31849 .39673 Mtetra
.31849 .39673 .32717 .40541 .3409 .40072 .33227 .39199 Mtetra
.33227 .39199 .3409 .40072 .35471 .396 .34611 .38723 Mtetra
.34611 .38723 .35471 .396 .36858 .39126 .36003 .38244 Mtetra
.36003 .38244 .36858 .39126 .38253 .38649 .37402 .37762 Mtetra
.37402 .37762 .38253 .38649 .39655 .3817 .38809 .37278 Mtetra
.38809 .37278 .39655 .3817 .41064 .37688 .40223 .36792 Mtetra
.40223 .36792 .41064 .37688 .42481 .37204 .41645 .36303 Mtetra
.41645 .36303 .42481 .37204 .43905 .36717 .43074 .35811 Mtetra
.43074 .35811 .43905 .36717 .45337 .36227 .4451 .35317 Mtetra
.4451 .35317 .45337 .36227 .46777 .35735 .45955 .3482 Mtetra
.971 .73 .515 r
.45955 .3482 .46777 .35735 .48355 .25434 .47564 .24495 Mtetra
.654 .753 .923 r
.47564 .24495 .48355 .25434 .49766 .24927 .48979 .23983 Mtetra
.48979 .23983 .49766 .24927 .51183 .24417 .50401 .23469 Mtetra
.50401 .23469 .51183 .24417 .52608 .23904 .51831 .22951 Mtetra
.51831 .22951 .52608 .23904 .5404 .23389 .53268 .22431 Mtetra
.53268 .22431 .5404 .23389 .5548 .22871 .54713 .21908 Mtetra
.54713 .21908 .5548 .22871 .56927 .22351 .56165 .21383 Mtetra
.56165 .21383 .56927 .22351 .58381 .21828 .57625 .20854 Mtetra
.57625 .20854 .58381 .21828 .59844 .21301 .59092 .20323 Mtetra
.59092 .20323 .59844 .21301 .61314 .20773 .60568 .19789 Mtetra
.60568 .19789 .61314 .20773 .62792 .20241 .62051 .19252 Mtetra
.62051 .19252 .62792 .20241 .64278 .19707 .63542 .18713 Mtetra
.63542 .18713 .64278 .19707 .65771 .19169 .65041 .1817 Mtetra
.65041 .1817 .65771 .19169 .67273 .18629 .66548 .17625 Mtetra
.66548 .17625 .67273 .18629 .68783 .18086 .68063 .17076 Mtetra
.68063 .17076 .68783 .18086 .703 .1754 .69587 .16525 Mtetra
.69587 .16525 .703 .1754 .71826 .16991 .71118 .1597 Mtetra
.65 .758 .929 r
.01731 .44862 .02678 .45652 .03891 .45225 .02947 .44432 Mtetra
.02947 .44432 .03891 .45225 .05109 .44796 .04168 .43999 Mtetra
.04168 .43999 .05109 .44796 .06333 .44365 .05395 .43564 Mtetra
.05395 .43564 .06333 .44365 .07563 .43932 .06629 .43127 Mtetra
.06629 .43127 .07563 .43932 .08799 .43497 .07868 .42688 Mtetra
.07868 .42688 .08799 .43497 .10041 .4306 .09114 .42246 Mtetra
.09114 .42246 .10041 .4306 .11289 .4262 .10365 .41803 Mtetra
.10365 .41803 .11289 .4262 .12544 .42178 .11623 .41357 Mtetra
.11623 .41357 .12544 .42178 .13804 .41734 .12887 .40909 Mtetra
.12887 .40909 .13804 .41734 .15071 .41288 .14158 .40459 Mtetra
.14158 .40459 .15071 .41288 .16344 .4084 .15434 .40007 Mtetra
.15434 .40007 .16344 .4084 .17624 .4039 .16718 .39552 Mtetra
.16718 .39552 .17624 .4039 .1891 .39937 .18007 .39095 Mtetra
.18007 .39095 .1891 .39937 .20202 .39482 .19303 .38636 Mtetra
.19303 .38636 .20202 .39482 .21501 .39024 .20606 .38174 Mtetra
.20606 .38174 .21501 .39024 .22806 .38565 .21915 .3771 Mtetra
.928 .543 .216 r
.21915 .3771 .22806 .38565 .23732 .42465 .2283 .41615 Mtetra
.646 .762 .934 r
.2283 .41615 .23732 .42465 .25067 .42006 .2417 .41151 Mtetra
.2417 .41151 .25067 .42006 .2641 .41544 .25516 .40685 Mtetra
.25516 .40685 .2641 .41544 .27759 .4108 .2687 .40216 Mtetra
.2687 .40216 .27759 .4108 .29115 .40613 .2823 .39745 Mtetra
.2823 .39745 .29115 .40613 .30479 .40144 .29598 .39272 Mtetra
.29598 .39272 .30479 .40144 .31849 .39673 .30973 .38796 Mtetra
.30973 .38796 .31849 .39673 .33227 .39199 .32355 .38317 Mtetra
.32355 .38317 .33227 .39199 .34611 .38723 .33744 .37837 Mtetra
.33744 .37837 .34611 .38723 .36003 .38244 .3514 .37353 Mtetra
.3514 .37353 .36003 .38244 .37402 .37762 .36544 .36867 Mtetra
.36544 .36867 .37402 .37762 .38809 .37278 .37955 .36378 Mtetra
.37955 .36378 .38809 .37278 .40223 .36792 .39374 .35887 Mtetra
.39374 .35887 .40223 .36792 .41645 .36303 .408 .35393 Mtetra
.408 .35393 .41645 .36303 .43074 .35811 .42234 .34897 Mtetra
.42234 .34897 .43074 .35811 .4451 .35317 .43675 .34398 Mtetra
.43675 .34398 .4451 .35317 .45955 .3482 .45125 .33896 Mtetra
.971 .73 .515 r
.45125 .33896 .45955 .3482 .47564 .24495 .46766 .23548 Mtetra
.654 .753 .923 r
.46766 .23548 .47564 .24495 .48979 .23983 .48185 .23031 Mtetra
.48185 .23031 .48979 .23983 .50401 .23469 .49612 .22511 Mtetra
.49612 .22511 .50401 .23469 .51831 .22951 .51047 .21989 Mtetra
.51047 .21989 .51831 .22951 .53268 .22431 .52489 .21464 Mtetra
.52489 .21464 .53268 .22431 .54713 .21908 .53938 .20936 Mtetra
.53938 .20936 .54713 .21908 .56165 .21383 .55395 .20405 Mtetra
.55395 .20405 .56165 .21383 .57625 .20854 .5686 .19871 Mtetra
.5686 .19871 .57625 .20854 .59092 .20323 .58333 .19335 Mtetra
.58333 .19335 .59092 .20323 .60568 .19789 .59814 .18796 Mtetra
.59814 .18796 .60568 .19789 .62051 .19252 .61302 .18254 Mtetra
.61302 .18254 .62051 .19252 .63542 .18713 .62799 .17709 Mtetra
.62799 .17709 .63542 .18713 .65041 .1817 .64303 .17161 Mtetra
.64303 .17161 .65041 .1817 .66548 .17625 .65816 .1661 Mtetra
.65816 .1661 .66548 .17625 .68063 .17076 .67337 .16056 Mtetra
.67337 .16056 .68063 .17076 .69587 .16525 .68866 .15499 Mtetra
.68866 .15499 .69587 .16525 .71118 .1597 .70403 .14939 Mtetra
.65 .758 .929 r
.00776 .44066 .01731 .44862 .02947 .44432 .01995 .43631 Mtetra
.01995 .43631 .02947 .44432 .04168 .43999 .03219 .43194 Mtetra
.03219 .43194 .04168 .43999 .05395 .43564 .0445 .42756 Mtetra
.0445 .42756 .05395 .43564 .06629 .43127 .05686 .42314 Mtetra
.05686 .42314 .06629 .43127 .07868 .42688 .06929 .41871 Mtetra
.06929 .41871 .07868 .42688 .09114 .42246 .08178 .41426 Mtetra
.08178 .41426 .09114 .42246 .10365 .41803 .09433 .40978 Mtetra
.09433 .40978 .10365 .41803 .11623 .41357 .10694 .40528 Mtetra
.10694 .40528 .11623 .41357 .12887 .40909 .11962 .40076 Mtetra
.11962 .40076 .12887 .40909 .14158 .40459 .13236 .39622 Mtetra
.13236 .39622 .14158 .40459 .15434 .40007 .14516 .39165 Mtetra
.14516 .39165 .15434 .40007 .16718 .39552 .15803 .38706 Mtetra
.15803 .38706 .16718 .39552 .18007 .39095 .17096 .38245 Mtetra
.17096 .38245 .18007 .39095 .19303 .38636 .18396 .37782 Mtetra
.18396 .37782 .19303 .38636 .20606 .38174 .19702 .37316 Mtetra
.19702 .37316 .20606 .38174 .21915 .3771 .21015 .36847 Mtetra
.928 .543 .216 r
.21015 .36847 .21915 .3771 .2283 .41615 .2192 .40757 Mtetra
.646 .762 .934 r
.2192 .40757 .2283 .41615 .2417 .41151 .23264 .40289 Mtetra
.23264 .40289 .2417 .41151 .25516 .40685 .24615 .39818 Mtetra
.24615 .39818 .25516 .40685 .2687 .40216 .25972 .39345 Mtetra
.25972 .39345 .2687 .40216 .2823 .39745 .27337 .38869 Mtetra
.27337 .38869 .2823 .39745 .29598 .39272 .28709 .38391 Mtetra
.28709 .38391 .29598 .39272 .30973 .38796 .30088 .37911 Mtetra
.30088 .37911 .30973 .38796 .32355 .38317 .31474 .37428 Mtetra
.31474 .37428 .32355 .38317 .33744 .37837 .32868 .36942 Mtetra
.32868 .36942 .33744 .37837 .3514 .37353 .34269 .36454 Mtetra
.34269 .36454 .3514 .37353 .36544 .36867 .35677 .35963 Mtetra
.35677 .35963 .36544 .36867 .37955 .36378 .37093 .35469 Mtetra
.37093 .35469 .37955 .36378 .39374 .35887 .38516 .34973 Mtetra
.38516 .34973 .39374 .35887 .408 .35393 .39947 .34475 Mtetra
.39947 .34475 .408 .35393 .42234 .34897 .41386 .33973 Mtetra
.41386 .33973 .42234 .34897 .43675 .34398 .42832 .33469 Mtetra
.42832 .33469 .43675 .34398 .45125 .33896 .44286 .32963 Mtetra
.971 .73 .515 r
.44286 .32963 .45125 .33896 .46766 .23548 .45959 .22591 Mtetra
.654 .753 .923 r
.45959 .22591 .46766 .23548 .48185 .23031 .47384 .22069 Mtetra
.47384 .22069 .48185 .23031 .49612 .22511 .48816 .21545 Mtetra
.48816 .21545 .49612 .22511 .51047 .21989 .50255 .21017 Mtetra
.50255 .21017 .51047 .21989 .52489 .21464 .51702 .20487 Mtetra
.51702 .20487 .52489 .21464 .53938 .20936 .53156 .19954 Mtetra
.53156 .19954 .53938 .20936 .55395 .20405 .54619 .19418 Mtetra
.54619 .19418 .55395 .20405 .5686 .19871 .56089 .18879 Mtetra
.56089 .18879 .5686 .19871 .58333 .19335 .57567 .18337 Mtetra
.57567 .18337 .58333 .19335 .59814 .18796 .59052 .17793 Mtetra
.59052 .17793 .59814 .18796 .61302 .18254 .60546 .17245 Mtetra
.60546 .17245 .61302 .18254 .62799 .17709 .62048 .16695 Mtetra
.62048 .16695 .62799 .17709 .64303 .17161 .63558 .16141 Mtetra
.63558 .16141 .64303 .17161 .65816 .1661 .65076 .15585 Mtetra
.65076 .15585 .65816 .1661 .67337 .16056 .66603 .15025 Mtetra
.66603 .15025 .67337 .16056 .68866 .15499 .68137 .14463 Mtetra
.68137 .14463 .68866 .15499 .70403 .14939 .6968 .13897 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 154.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000VR000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Q@3oool2o`000<@0oooo0_l0
00130?ooo`00PP3oool3o`0000030?ooool00000oooo0<00oooo0ol000000`3ooooo00000?ooo`12
0?ooo`00P03oool2o`0000@0oooo0_l0002n0?ooo`;o0000103oool2o`000480oooo001m0?ooo`?o
00001P3oool00ol00000ooooo`00002j0?ooo`?o00001P3oool00ol00000ooooo`0000110?ooo`00
NP3oool3o`0000T0oooo00?o00000?ooool00000^03oool2o`0000T0oooo00?o00000?ooool00000
@@3oool007P0oooo0_l0000<0?ooo`04o`00003oool0ooooo`000;@0oooo0ol0000;0?ooo`04o`00
003oool0ooooo`000400oooo001e0?ooo`?o00003P3oool01Ol00000oooo0?ooo`3ooooo00000;00
oooo0ol0000>0?ooo`05o`00003oool0oooo0?ooool00000?`3oool007<0oooo0_l0000A0?ooo`05
o`00003oool0oooo0?ooool00000[P3oool2o`000140oooo00Go00000?ooo`3oool0ooooo`00000o
0?ooo`00L03oool3o`0001<0oooo00?o00000?ooo`3oool00P3oool00ol00000oooo0?ooo`2X0?oo
o`?o0000503oool01Ol00000oooo0?ooo`3ooooo000003h0oooo001^0?ooo`;o00005P3oool00ol0
0000oooo0?ooo`030?ooo`03o`00003oool0oooo0:D0oooo0_l0000G0?ooo`03o`00003oool0oooo
0080oooo00?o00000?ooo`3oool0>`3oool006/0oooo0ol0000H0?ooo`03o`00003oool0oooo00<0
oooo00?o00000?ooo`3oool0XP3oool3o`0001T0oooo00?o00000?ooo`3oool00P3oool00ol00000
oooo0?ooo`0k0?ooo`00J03oool3o`0001/0oooo00?o00000?ooo`3oool0103oool00ol00000oooo
0?ooo`2O0?ooo`;o0000703oool00ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo03X0oooo
001V0?ooo`;o00007`3oool00ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo09`0oooo0ol0
000N0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0>@3oool006<0oooo0ol0000Q
0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0V@3oool2o`000240oooo00?o0000
0?ooo`3oool0103oool00ol00000oooo0?ooo`0i0?ooo`00H@3oool2o`0002@0oooo00?o00000?oo
o`3oool01@3oool00ol00000oooo0?ooo`2E0?ooo`?o00008`3oool00ol00000oooo0?ooo`050?oo
o`03o`00003oool0oooo03P0oooo001N0?ooo`?o00009P3oool00ol00000oooo0?ooo`050?ooo`03
o`00003oool0oooo09<0oooo0_l0000V0?ooo`03o`00003oool0oooo00H0oooo00?o00000?ooo`3o
ool0=`3oool005`0oooo0_l0000Y0?ooo`03o`00003oool0oooo00H0oooo00?o00000?ooo`3oool0
S`3oool3o`0002P0oooo00?o00000?ooo`3oool01P3oool00ol00000oooo0?ooo`0g0?ooo`00F@3o
ool3o`0002/0oooo00?o00000?ooo`3oool01`3oool00ol00000oooo0?ooo`2;0?ooo`?o0000:`3o
ool00ol00000oooo0?ooo`070?ooo`03o`00003oool0oooo03H0oooo001G0?ooo`;o0000;P3oool0
0ol00000oooo0?ooo`070?ooo`03o`00003oool0oooo08T0oooo0_l0000^0?ooo`03o`00003oool0
oooo00P0oooo00?o00000?ooo`3oool0=@3oool005@0oooo0ol000030?ooo`030:Vmj03eWDL0oooo
02X0oooo00?o00000?ooo`3oool0203oool00ol00000oooo0?ooo`250?ooo`?o0000<03oool00ol0
0000oooo0?ooo`080?ooo`03o`00003oool0oooo03D0oooo001A0?ooo`?o000000<0oooo0:Vmj02Y
_NP0102Y_NP00`3eWDL0oooo0?ooo`0X0?ooo`030:O0jol00000oooo00X0oooo00?o00000?ooo`3o
ool0PP3oool2o`0003<0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`0d0?ooo`00
C`3oool2o`0000030?ooo`2Y_NP0ZKgX00L0ZKgX0P3eWDLV0?ooo`@0Yl3[00?o00000?ooo`3oool0
2@3oool00ol00000oooo0?ooo`1o0?ooo`?o0000=@3oool00ol00000oooo0?ooo`0:0?ooo`03o`00
003oool0oooo03<0oooo001<0?ooo`?o000000<0oooo0:Vmj02Y_NP02@2Y_NP30?FMAb<0oooo1P2W
`>/00ol00000Yl3[0?ooo`0:0?ooo`03o`00003oool0oooo07`0oooo0_l0000h0?ooo`03o`00003o
ool0oooo00X0oooo00?o00000?ooo`3oool0<`3oool004X0oooo0_l000020?ooo`h0ZKgX0`3eWDLO
0?ooo`T0Yl3[00?o00000:O0j`2W`>/02`3oool00ol00000oooo0?ooo`1h0?ooo`?o0000>`3oool0
0ol00000oooo0?ooo`0:0?ooo`03o`00003oool0oooo0380oooo00170?ooo`?o000000<0oooo0:Vm
j02Y_NP03`2Y_NP40?FMAa/0oooo302W`>/00ol00000Yl3[0:O0j`0;0?ooo`03o`00003oool0oooo
07H0oooo0_l0000n0?ooo`03o`00003oool0oooo00/0oooo00?o00000?ooo`3oool0<@3oool004D0
oooo0_l000020?oooa<0ZKgX103eWDLH0?ooo`l0Yl3[00Co00000:O0j`2W`>/0Yl3[2`3oool00ol0
0000oooo0?ooo`1b0?ooo`?o0000@03oool00ol00000oooo0?ooo`0;0?ooo`03o`00003oool0oooo
0340oooo00120?ooo`?o00000P3ooolE0:Vmj0D0mIe75@3ooolA0:O0j`04o`00002W`>/0Yl3[0:O0
j``0oooo00?o00000?ooo`3oool0K`3oool2o`000480oooo00?oYl3/o`00003oool03@3oool00ol0
0000oooo0?ooo`0`0?ooo`00?`3oool3o`000080oooo602Y_NP60?FMAa40oooo502W`>/00ol00000
Yl3[0:O0j`020:O0j`/0oooo00?o00000?ooo`3oool0K03oool3o`000440oooo1?nW`>`00ol00000
oooo0?ooo`0=0?ooo`03o`00003oool0oooo02l0oooo000m0?ooo`;o00000`3ooolJ0:Vmj0L0mIe7
3@3ooolG0:O0j`03o`00002W`>/0Yl3[0080Yl3[303oool00ol00000oooo0?ooo`1Y0?ooo`;o0000
@@3oool7ojO0k003o`000?nW`>`0oooo00d0oooo00?o00000?ooo`3oool0;`3oool003X0oooo0ol0
00030?oooa`0ZKgX203eWDL:0?oooaT0Yl3[00?o00000:O0j`2W`>/00`2W`>/<0?ooo`03o`00003o
ool0oooo06D0oooo0ol000100?ooo`[oYl3/00?o0000ojO0k03oool03P3oool00ol00000oooo0?oo
o`0^0?ooo`00>03oool2o`0000<0oooo7`2Y_NP80?FMA`L0oooo702W`>/00ol00000Yl3[0:O0j`05
0:O0j`X0oooo00?o00000?ooo`3oool0HP3oool3o`000440oooo3?nW`>`00ol0003oYl3/ojO0k00?
0?ooo`03o`00003oool0oooo02d0oooo000e0?ooo`?o000000<0oooo0:Vmj02Y_NP08@2Y_NP90?FM
A`@0oooo7P2W`>/00ol00000Yl3[0:O0j`050:O0j`/0oooo00?o00000?ooo`3oool0G`3oool2o`00
0440oooo3onW`>`01?l0003oYl3/ojO0k?nW`>`>0?ooo`03o`00003oool0oooo02d0oooo000c0?oo
o`;o000000<0oooo0:Vmj02Y_NP09@2Y_NP90?FMAb40Yl3[00?o00000:O0j`2W`>/01P2W`>/:0?oo
o`03o`00003oool0oooo05`0oooo0ol000100?oooa;oYl3/00?o0000ojO0k?nW`>`00_nW`>`<0?oo
o`03oh92N?nY_NSo000002h0oooo000`0?ooo`?o000000<0oooo0:Vmj02Y_NP09`2Y_NP60?FMAb@0
Yl3[00?o00000:O0j`2W`>/01P2W`>/;0?ooo`03o`00003oool0oooo05T0oooo0_l000100?oooaGo
Yl3/00?o0000ojO0k?nW`>`00_nW`>`90?ooo`CoPT9h00?oZKgX0?ooool00000;@3oool002d0oooo
0ol000020?ooob/0ZKgX103eWDLW0:O0j`03o`00002W`>/0Yl3[00H0Yl3[2`3oool00ol00000oooo
0?ooo`1E0?ooo`?o0000@03ooolGojO0k003o`000?nW`>coYl3/00?oYl3/0`3oool9oh92N0;oZKgX
00?o00000?ooo`3oool0:`3oool002/0oooo0_l000030?ooobd0ZKgX00<0mIe70:O0j`2W`>/0:02W
`>/00ol00000Yl3[0:O0j`060:O0j`/0oooo00?o00000?ooo`3oool0D`3oool2o`000400oooo6_nW
`>`00ol0003oYl3/ojO0k003ojO0k0030?oooon2@WSoPT9h00WoPT9h00CoZKgX0:Vmj03ooooo0000
;03oool002P0oooo0ol000020?oooc00ZKgX:`2W`>/00ol00000Yl3[0:O0j`070:O0j`/0oooo00?o
00000?ooo`3oool0C`3oool3o`0003l0oooo7OnW`>`00ol0003oYl3/ojO0k004ojO0k0_oPT9h0`2Y
_NP00`3ooooo00000?ooo`0Z0?ooo`009P3oool2o`0000<0oooo<`2Y_NPZ0:O0j`03o`00002W`>/0
Yl3[00P0Yl3[2`3oool00ol00000oooo0?ooo`1<0?ooo`;o0000@03ooolOojO0k003o`000?nW`>co
Yl3/00GoYl3/2_n2@WP40:Vmj003o`00003oool0oooo02T0oooo000S0?ooo`?o000000<0oooo0:Vm
j02Y_NP0=`2Y_NPX0:O0j`03o`00002W`>/0Yl3[00T0Yl3[2P3oool00ol00000oooo0?ooo`190?oo
o`?o0000?`3ooolSojO0k003o`000?nW`>coYl3/00GoYl3/2On2@WP40:Vmj0030?ooool00000oooo
02T0oooo000Q0?ooo`;o00000P3ooolk0:Vmj2P0Yl3[00?o00000:O0j`2W`>/02P2W`>/:0?ooo`03
o`00003oool0oooo04H0oooo0_l000100?ooobGoYl3/00?o0000ojO0k?nW`>`01_nW`>`8oh92N0D0
ZKgX00<0ooooo`00003oool0:03oool001h0oooo0ol000000`3oool0ZKgX0:Vmj00m0:Vmj2L0Yl3[
00?o00000:O0j`2W`>/02P2W`>/;0?ooo`03o`00003oool0oooo0480oooo0ol0000l0?ooob_oYl3/
00?o0000ojO0k?nW`>`01_nW`>`8oh92N0H0ZKgX00?o00000?ooo`3oool09`3oool001`0oooo0_l0
00020?oood40ZKgX9`2W`>/00ol00000Yl3[0:O0j`0;0:O0j`X0oooo00?o00000?ooo`3oool0?`3o
ool3o`0003h0oooo;?nW`>`00ol0003oYl3/ojO0k007ojO0k0OoPT9h1P2Y_NP00`3ooooo00000?oo
o`0W0?ooo`006@3oool3o`000080ooooA02Y_NPV0:O0j`03o`00002W`>/0Yl3[00`0Yl3[2P3oool0
0ol00000oooo0?ooo`0l0?ooo`;o0000@@3oool00ooh^X?oYl3/ojO0k00YojO0k003o`000?nW`>co
Yl3/00OoYl3/1on2@WP70:Vmj003o`00003oool0oooo02H0oooo000F0?ooo`?o000000<0oooo0:Vm
j02Y_NP0A`2Y_NPU0:O0j`03o`00002W`>/0Yl3[00`0Yl3[2`3oool00ol00000oooo0?ooo`0h0?oo
o`?o0000@`3oool2ooRjPb[oYl3/00?o0000ojO0k?nW`>`02?nW`>`7oh92N0L0ZKgX00?o00000?oo
o`3oool09@3oool001@0oooo0_l000020?oood`0ZKgX8`2W`>/2o`0000l0Yl3[2P3oool00ol00000
oooo0?ooo`0f0?ooo`;o0000AP3oool3ooRjPbSoYl3/0_l0000;ojO0k0KoPT9h1`2Y_NP00`3ooooo
00000?ooo`0U0?ooo`004@3oool3o`000080ooooC`2Y_NPO0:O0j`?o000000<0Yl3[o`00002W`>/0
3P2W`>/;0?ooo`03o`00003oool0oooo0380oooo0ol000170?ooo`Con;Z39OnW`>`3o`000003ojO0
k?l0003oYl3/00[oYl3/1_n2@WP80:Vmj003o`00003oool0oooo02@0oooo000@0?ooo`;o000000<0
oooo0:Vmj02Y_NP0D02Y_NPL0:O0j`?o00001@2W`>/00ol00000Yl3[0:O0j`0=0:O0j`/0oooo00?o
00000?ooo`3oool0<03oool2o`0004T0oooo1Ooh^X<QojO0k0?o00001OnW`>`00ol0003oYl3/ojO0
k009ojO0k0GoPT9h2@2Y_NP00ol00000oooo0?ooo`0S0?ooo`00403oool00ol00000ZKgX0:Vmj01C
0:Vmj1P0Yl3[0ol000090:O0j`03o`00002W`>/0Yl3[00d0Yl3[2P3oool00ol00000oooo0?ooo`0`
0?ooo`03o`00003ooooo000004P0oooo1ooh^X<LojO0k0?o00002OnW`>`00ol0003oYl3/ojO0k009
ojO0k0CoPT9h2@2Y_NP00`3ooooo00000?ooo`0S0?ooo`00403oool00ol00000oooo0:Vmj01B0:Vm
j0<0SUbC4`2W`>/3o`0000d0Yl3[00?o00000:O0j`2W`>/02`2W`>/00`2<F8h0oooo0?ooo`090?oo
o`03o`00003oool0oooo02l0oooo00Co00000?ooo`3ooooo0000A`3oool7ooRjPaWoYl3/0ol0000=
ojO0k003o`000?nW`>coYl3/00WoYl3/0on2@WP:0:Vmj003o`00003oool0oooo0280oooo000@0?oo
o`03o`00003oool0ZKgX0500ZKgX1@2>G9<@0:O0j`?o0000402W`>/00ol00000Yl3[0:O0j`090:O0
j`<0S5R>2`3oool00ol00000oooo0?ooo`0_0?ooo`05o`00003oool0oooo0?ooool00000AP3oool8
ooRjPaGoYl3/0ol0000@ojO0k003o`000?nW`>coYl3/00[oYl3/0_n2@WP;0:Vmj003o`00003oool0
oooo0240oooo000?0?ooo`04o`00003oool0oooo0?oood`0ZKgX2P2>G9<<0:O0j`?o0000502W`>/0
0ol00000Yl3[0:O0j`050:O0j`H0S5R>303oool00ol00000oooo0?ooo`0]0?ooo`03o`00003oool0
oooo00<0oooo00?o00000?ooo`3oool0@`3oool8ooRjPa;oYl3/0ol0000DojO0k003o`000?nW`>co
Yl3/00WoYl3/0_n2@WP;0:Vmj0030?ooool00000oooo0240oooo000?0?ooo`03o`00003oool0oooo
00<0ooooA`2Y_NP=08iLT`X0Yl3[0_l0000H0:O0j`04o`00002W`>/0Yl3[0:O0j`T0S5R>3@3oool0
0ol00000oooo0?ooo`0/0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0@@3oool:
ooRjP`koYl3/0ol0000HojO0k003o`000?nW`>coYl3/00WoYl3/00?oPT9h0:Vmj02Y_NP02P2Y_NP0
0ol00000oooo0?ooo`0P0?ooo`003`3oool00ol00000oooo0?ooo`040?oood@0ZKgX402>G9<60:O0
j`?o00006`2W`>/00ol00000S5R>08aHSP0:08aHSP`0oooo00?o00000?ooo`3oool0;03oool00ol0
0000oooo0?ooo`050?ooo`03o`00003oool0oooo0400oooo3?oh^X<9ojO0k0?o00006onW`>`00ol0
003oYl3/ojO0k009ojO0k003oh92N02Y_NP0ZKgX00/0ZKgX00?o00000?ooo`3oool07`3oool000l0
oooo00?o00000?ooo`3oool01@3ooom10:Vmj1@0SUbC00@0Yl3[o`000?l0003o0000702W`>/208aH
SP03o`00002<F8h0S5R>00X0S5R>3@3oool00ol00000oooo0?ooo`0[0?ooo`03o`00003oool0oooo
00H0oooo00?o00000?ooo`3oool0?`3oool<ooRjP`OoYl3/0_l0000OojO0k003o`000?nW`>coYl3/
00WoYl3/3@2Y_NP00`3ooooo00000?ooo`0O0?ooo`003`3oool00ol00000oooo0?ooo`060?oooc/0
ZKgX5`2>G9<3o`0001X0Yl3[202<F8h00ol00000S5R>08aHSP0908aHSPh0oooo00?o00000?ooo`3o
ool0:P3oool00ol00000oooo0?ooo`070?ooo`03o`00003oool0oooo03h0oooo3Ooh^X<3ojO0k0?o
00008_nW`>`00ol0003oYl3/ojO0k007ojO0k0l0ZKgX00?o00000?ooo`3oool07P3oool000l0oooo
00?o00000?ooo`3oool0203ooolg0:Vmj1H0SUbC0ol0000308iLTaP0Yl3[2`2<F8h00ol00000S5R>
08aHSP0808aHSPh0oooo00?o00000?ooo`3oool0:P3oool00ol00000oooo0?ooo`080?ooo`03o`00
003oool0oooo03d0oooo3Ooh^X<3o`0002KoYl3/00Co0000ojO0k?nW`>coYl3/5@2Y_NP00ol00000
oooo0?ooo`0M0?ooo`003`3oool00ol00000oooo0?ooo`080?ooocD0ZKgX5@2>G9<3o`0000L0SUbC
502W`>/?08aHSP03o`00002<F8h0S5R>00L0S5R>3`3oool00ol00000oooo0?ooo`0X0?ooo`03o`00
003oool0oooo00X0oooo00?o00000?ooo`3oool0?03oool:ooRjP`?o00000_oh^X<WojO0k003o`00
002Y_NP0ZKgX01H0ZKgX00<0ooooo`00003oool07@3oool000h0oooo00?o00000?ooo`3oool02P3o
oolb0:Vmj1@0SUbC0ol0000;08iLTa40Yl3[4@2<F8h00ol00000S5R>08aHSP0708aHSQ00oooo00?o
00000?ooo`3oool09`3oool00ol00000oooo0?ooo`0;0?ooo`03o`00003oool0oooo03/0oooo1ooh
^X<3o`0000Kon;Z39OnW`>`20:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o00000?ooo`3oool0703o
ool000h0oooo00?o00000?ooo`3oool0303oool_0:Vmj180SUbC0ol0000?08iLT`d0Yl3[5@2<F8h0
0ol00000S5R>08aHSP0608aHSQ00oooo00?o00000?ooo`3oool09`3oool00ol00000oooo0?ooo`0<
0?ooo`03o`00003oool0oooo03T0oooo1Ooh^X<3o`0000[on;Z38OnW`>`60:Vmj003o`00002Y_NP0
ZKgX01H0ZKgX00?o00000?ooo`3oool06`3oool000h0oooo00?o00000?ooo`3oool0303oool_0:Vm
j100SUbC0_l0000C08iLT`L0Yl3[6`2<F8h00ol00000S5R>08aHSP0508aHSQ40oooo00?o00000?oo
o`3oool09P3oool00ol00000oooo0?ooo`0=0?ooo`03o`00003oool0oooo03P0oooo0_oh^X<3o`00
00gon;Z37_nW`>`:0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00<0ooooo`00003oool06`3oool000h0
oooo00?o00000?ooo`3oool03@3oool^0:Vmj0d0SUbC0ol0000E08iLT`D0Yl3[7@2<F8h00ol00000
S5R>08aHSP0608aHSQ40oooo00?o00000?ooo`3oool09@3oool00ol00000oooo0?ooo`0>0?ooo`03
o`00003oool0oooo03H0oooo0ol0000AooRjPa_oYl3/302Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003
o`00003oool0oooo01X0oooo000>0?ooo`03o`00003oool0oooo00l0oooo;02Y_NP:08iLT`?o0000
5`2>G9<0102X_nX0001U0:O0j`2W`>/P08aHSP03o`00002<F8h0S5R>00D0S5R>4@3oool00ol00000
oooo0?ooo`0U0?ooo`03o`00003oool0oooo00l0oooo0_l0000c0?ooo`?o00000_nU`nlCooRjPaGo
Yl3/4P2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`00003oool0oooo01T0oooo000>0?ooo`03o`00
003oool0oooo0100oooo:`2Y_NP708iLT`?o0000602>G9<30:RojP030000I@2<F8h0S5R>0240S5R>
00?o000008aHSP2<F8h0102<F8hB0?ooo`03o`00003oool0oooo02<0oooo00?o00000?ooo`3oool0
4P3oool00ol00000oooo0?ooo`0^0?ooo`;o00001onU`nlBooRjPa7oYl3/00<0n;Qn0:Vmj02Y_NP0
4`2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`00003oool0oooo01P0oooo000>0?ooo`03o`00003o
ool0oooo0140oooo:P2Y_NP408iLT`?o0000602>G9<60:RojP030000I@2<F8h0S5R>0280S5R>00?o
000008aHSP2<F8h00`2<F8hC0?ooo`03o`00003oool0oooo0280oooo00?o00000?ooo`3oool04`3o
ool00ol00000oooo0?ooo`0Z0?ooo`?o00002OnU`nlCooRjP`koYl3/103h^7hD0:Vmj003o`00002Y
_NP0ZKgX01H0ZKgX00?o00000?ooo`3oool0603oool000d0oooo00?o00000?ooo`3oool04`3ooolY
0:Vmj00408iLTol0003o0000o`0001L0SUbC2P2X_nX00`0006D0S5R>08aHSP0R08aHSP03o`00002<
F8h0S5R>00<0S5R>4`3oool00ol00000oooo0?ooo`0R0?ooo`03o`00003oool0oooo01@0oooo00?o
00000?ooo`3oool09P3oool3o`0000goYL?_4_oh^X<;ojO0k0L0n;Qn5@2Y_NP00ol00000ZKgX0:Vm
j00E0:Vmj0030?ooool00000oooo01P0oooo000=0?ooo`03o`00003oool0oooo01@0oooo9P2Y_NP3
o`0001L0SUbC3P2X_nXU08aHSP03o`00002<F8h0S5R>0080S5R>503oool00ol00000oooo0?ooo`0Q
0?ooo`03o`00003oool0oooo01D0oooo00?o00000?ooo`3oool08P3oool3o`00017oYL?_4_oh^X<8
ojO0k0X0n;Qn5@2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj0030?ooool00000oooo01L0oooo000=0?oo
o`03o`00003oool0oooo01H0oooo8P2Y_NP2o`000080ZKgX5P2>G9<@0:RojRH0S5R>00Co000008aH
SP2<F8h0S5R>5@3oool00ol00000oooo0?ooo`0P0?ooo`03o`00003oool0oooo01H0oooo00?o0000
0?ooo`3oool07@3oool01?nU`noo0000o`000?l0000EojG3ka;on;Z30_nW`>`@0?RhOQD0ZKgX00?o
00000:Vmj02Y_NP05@2Y_NP00ol00000oooo0?ooo`0F0?ooo`003@3oool00ol00000oooo0?ooo`0F
0?oooal0ZKgX0ol000040:Vmj140SUbC5@2X_nXW08aHSP03o`00002<F8h0S5R>01D0oooo00?o0000
0?ooo`3oool0803oool00ol00000oooo0?ooo`0G0?ooo`03o`00003oool0oooo00@0oooo00?oY/;]
0?ooo`3oool04P3oool01?nU`noo0000o`000?l0000IojG3ka7on;Z300?on;Qn0?RhOP3h^7h0403h
^7hD0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00<0ooooo`00003oool05P3oool000d0oooo00?o0000
0?ooo`3oool05`3ooolK0:Vmj0?o00001`2Y_NP?08iLTaL0Z;oZ00<0001U08aHSP2<F8h0902<F8h0
0ol00000S5R>08aHSP0F0?ooo`03o`00003oool0oooo01h0oooo00?o00000?ooo`3oool06@3oool0
1?l00000oooo0?ooo`3oool3ojK2k@03onf;=`3oool0oooo00l0oooo0ol0000MojG3ka3on;Z300?o
Yl3[0?RhOP3h^7h0403h^7hE0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00<0ooooo`00003oool05@3o
ool000d0oooo00?o00000?ooo`3oool0603ooolG0:Vmj0?o00002P2Y_NP=08iLTaT0Z;oZ00<0001U
08aHSP2<F8h09@2<F8h00ol00000S5R>08aHSP0E0?ooo`03o`00003oool0oooo01h0oooo00?o0000
0?ooo`3oool06P3oool6ojK2k@?okH/g303oool3o`00027oYL?_3ooh^X<20:O0ja40n;Qn00<0001I
0:Vmj02Y_NP04`2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003o`00003oool0oooo01@0oooo000=0?oo
o`03o`00003oool0oooo01X0oooo4P2Y_NP3o`0000d0ZKgX2`2>G9<K0:RojP030000I@2<F8h0S5R>
02H0S5R>00?o000008aHSP3oool05@3oool00ol00000oooo0?ooo`0M0?ooo`03o`00003oool0oooo
01D0oooo3?nV`^d3onf;=`T0oooo0_l0000TojG3k`oon;Z30P2W`>/A0?RhOQL0ZKgX00?o00000:Vm
j02Y_NP05@2Y_NP00ol00000oooo0?ooo`0C0?ooo`00303oool00ol00000oooo0?ooo`0K0?ooo`l0
ZKgX0ol0000@0:Vmj0H0SUbC802X_nX00`0006D0S5R>08aHSP0W08aHSP03o`00003oool0oooo01D0
oooo00?o00000?ooo`3oool0703oool00ol00000oooo0?ooo`0C0?ooo`koY/;]1?o]RcL50?ooo`?o
00009onU`nl>ooRjP`<0Yl3[403h^7hG0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00<0ooooo`00003o
ool04`3oool000`0oooo00?o00000?ooo`3oool0703oool;0:Vmj0?o00004`2Y_NP408iLTb80Z;oZ
00<0001U08aHSP2<F8h09`2<F8h00ol00000oooo0?ooo`0E0?ooo`03o`00003oool0oooo01`0oooo
00?o00000?ooo`3oool04@3oool@ojK2k@CokH/g0_nU`nl3o`0002_oYL?_3?oh^X<50:O0j`l0n;Qn
602Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003o`00003oool0oooo0180oooo000<0?ooo`03o`00003o
ool0oooo01h0oooo1`2Y_NP2o`0001H0ZKgX0P2>G9<U0:RojRT0S5R>00<0YL?_o`00002U`nl05P3o
ool00ol00000oooo0?ooo`0K0?ooo`03o`00003oool0oooo00l0oooo4_nV`^d2onf;=`04ojG3kol0
003o0000o`0002ooYL?_2ooh^X<50:O0j`l0n;Qn6@2Y_NP00ol00000ZKgX0:Vmj00D0:Vmj0030?oo
ool00000oooo0180oooo000<0?ooo`03o`00003oool0oooo01l0oooo0`2Y_NP3o`0001X0ZKgX9@2X
_nXT08aHSPL0YL?_00?o00000?ooo`3oool05@3oool00ol00000oooo0?ooo`0I0?ooo`03o`00003o
ool0oooo00d0oooo5OnV`^d3o`0003?oYL?_2_oh^X<60:O0j`h0n;Qn6@2Y_NP00ol00000ZKgX0:Vm
j00E0:Vmj0030?ooool00000oooo0140oooo000<0?ooo`03o`00003oool0oooo01l0oooo0ol0000N
0:Vmj2@0Z;oZ8@2<F8h;0:G3k`03o`00003oool0oooo01@0oooo00?o00000?ooo`3oool06@3oool0
0ol00000oooo0?ooo`090?oooaKoY/;]0ol00002ojK2kCGoYL?_2Ooh^X<80:O0j``0n;Qn6P2Y_NP0
0ol00000ZKgX0:Vmj00E0:Vmj003o`00003oool0oooo0100oooo000<0?ooo`03o`00003oool0oooo
01`0oooo0ol000000`3oool0ZKgX0:Vmj00N0:Vmj2@0Z;oZ7`2<F8h=0:G3k`03o`00002U`nl0oooo
01D0oooo00?o00000?ooo`3oool0603oool00ol00000oooo0?ooo`060?oooaKoY/;]0ol00007ojK2
kCCoYL?_2?oh^X<80:O0j``0n;Qn6`2Y_NP00ol00000ZKgX0:Vmj00D0:Vmj0030?ooool00000oooo
0100oooo000<0?ooo`03o`00003oool0oooo01T0oooo0ol000060?oooal0ZKgX8`2X_nXL08aHSQ40
YL?_00?o00000?ooo`3oool04`3oool3o`0001T0oooo00?o00000?ooo`3oool0103ooolEojK2k@?o
00002_nV`^deojG3k`Oon;Z32@2W`>/;0?RhOQ`0ZKgX00?o00000:Vmj02Y_NP0502Y_NP2o`000100
oooo000;0?ooo`03o`00003oool0oooo01L0oooo0ol0000:0?ooob00ZKgX8@2X_nXI08aHSQD0YL?_
00?o00000?ooo`3oool03`3oool3o`000080oooo00?o00000?ooo`3oool05`3oool00ol00000oooo
0?ooo`020?oooaCoY/;]0ol0000>ojK2kCGoYL?_1_oh^X<:0:O0j`X0n;Qn702Y_NP00ol00000ZKgX
0:Vmj00E0:Vmj003o`00003oool0oooo00h0oooo000;0?ooo`03o`00003oool0oooo01@0oooo0ol0
000>0?ooob00ZKgX802X_nXD08aHSQ/0YL?_00?o00000?ooo`3oool02`3oool3o`0000D0oooo00?o
00000?ooo`3oool05`3oool00ol0003oY/;]ojK2k@0DojK2k@;o00004onV`^dcojG3k`Kon;Z32`2W
`>/90?RhOQd0ZKgX00?o00000:Vmj02Y_NP04`2Y_NP00`3ooooo00000?ooo`0?0?ooo`002`3oool0
0ol00000oooo0?ooo`0A0?ooo`?o00004P3ooolO0:Vmj200Z;oZ00<0001U08aHSP2<F8h03`2<F8hM
0:G3k`03o`00003oool0oooo00P0oooo0ol000080?ooo`03o`00003oool0oooo01H0oooo00?o0000
ojK2kOnV`^d04_nV`^d3o`0001KoY/;]<onU`nl5ooRjP`/0Yl3[203h^7hO0:Vmj003o`00002Y_NP0
ZKgX00d0ZKgX1P3oool00ol00000oooo0?ooo`0>0?ooo`002`3oool00ol00000oooo0?ooo`0?0?oo
o`;o00005P3ooolO0:Vmj1l0Z;oZ00<0001U08aHSP2<F8h0302<F8hQ0:G3k`03o`00003oool0oooo
00<0oooo1?l0000<0?ooo`03o`00003oool0oooo01D0oooo00?o00000?oooonV`^d03onV`^d3o`00
01[oY/;]=?nU`nl2ooRjP`d0Yl3[1`3h^7hP0:Vmj003o`00002Y_NP0ZKgX00X0ZKgX203oool00ol0
0000oooo0?ooo`0>0?ooo`002`3oool00ol00000oooo0?ooo`0<0?ooo`?o00006@3ooolP0:Vmj1h0
Z;oZ2`2<F8hU0:G3k`03o`00003ooooo000000;o0000403oool00ol00000oooo0?ooo`0E0?ooo`04
o`00003oool0oooo0?ooo`_oY/;]0ol0000NojK2kC?oYL?_0_oh^X<>0:O0j`H0n;Qn802Y_NP00ol0
0000ZKgX0:Vmj0060:Vmj0d0oooo00?o00000?ooo`3oool03@3oool000/0oooo00?o00000?ooo`3o
ool02@3oool3o`0001d0oooo7`2Y_NP00`2BHID0Z;oZ0:RojP0K0:RojPH0S5R>:P2U`nl2o`0001<0
oooo00?o00000?ooo`3oool05@3oool00ol00000oooo0?ooo`030?ooo`KoY/;]0ol0000RojK2kC?o
YL?_00?on;Z30:O0j`2W`>/03P2W`>/40?RhOR40ZKgX00?o00000:Vmj02Y_NP00P2Y_NP@0?ooo`03
o`00003oool0oooo00d0oooo000;0?ooo`03o`00003oool0oooo00H0oooo0ol0000R0?oooa/0ZKgX
0`2BHIDM0:RojP@0S5R>;@2U`nl00ol00000oooo0?ooo`0A0?ooo`03o`00003oool0oooo01D0oooo
00?o00000?ooo`3oool00`3oool3ojK2k@?o00009_nV`^dcojG3ka00Yl3[103h^7hR0:Vmj003o`00
003oool0oooo0140oooo00?o00000?ooo`3oool03@3oool000X0oooo00?o00000?ooo`3oool0103o
ool3o`0002H0oooo5P2Y_NP00`2BHIGoTV6Eoi9QU@05099QUA`0Z;oZ00<0S5R>0:G3k`2U`nl0;`2U
`nl01?l00000oooo0?ooo`3oool408I5N0030:K1k03oool0oooo00P0oooo00?o00000?ooo`3oool0
5@3oool00ol00000oooo0?ooo`030?ooo`?o0000:_nV`^daojG3ka80Yl3[0`3h^7hP0:Vmj080oooo
00?o00000?ooo`3oool04@3oool00ol00000oooo0?ooo`0=0?ooo`002P3oool01?l00000oooo0?oo
o`3oool3o`0002T0oooo502Y_NP3099QU@;oTV6E1P2BHIDL0:RojS80YL?_00?o000008I5N026AGP0
1026AGP20:K1k0T0oooo00?o00000?ooo`3oool0503oool01?l00000oooo0?ooo`3oool3o`0000<0
oooo:onV`^d^ojG3kaD0Yl3[0P3h^7hL0:Vmj0L0oooo00?o00000?ooo`3oool0403oool00ol00000
oooo0?ooo`0=0?ooo`002P3oool4o`0002d0oooo3`2Y_NP00`2BHIGoTV6Eoi9QU@04099QU@;oTV6E
202BHIDJ0:RojS80YL?_00?o000008I5N026AGP01026AGP20:K1k0T0oooo00?o00000?ooo`3oool0
503oool4o`0000L0oooo:onV`^dXojG3ka/0Yl3[00<0n;Qn0:Vmj02Y_NP05@2Y_NP=0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool03@3oool000X0oooo0_l0000`0?ooo``0ZKgX0`2B
HID2oi9QU@@0TV6E0_nBHID9099QUAL0Z;oZ0`2BHIDb0:G3k`03o`000026AGP0QTEh00<0QTEh0`2V
`N`90?ooo`03o`00003oool0oooo01<0oooo0_l0000:0?ooob_oY/;]9?nU`nlN0:O0j`030?RhOP2Y
_NP0ZKgX01<0ZKgX403oool00ol00000oooo0?ooo`0>0?ooo`03o`00003oool0oooo00d0oooo000<
0?ooo`03o`00003oool0oooo02l0oooo1P2Y_NP00`2BHIGoTV6Eoi9QU@04099QU@;oTV6E102BHID2
oi9QU@T0TV6E5@2X_nX7099QUC40YL?_00?o000008I5N026AGP00P26AGP40:K1k0P0oooo00?o0000
0?ooo`3oool05@3oool00ol00000oooo0?ooo`080?ooobcoY/;]8?nU`nlQ0:O0ja40ZKgX503oool0
0ol00000oooo0?ooo`0>0?ooo`03o`00003oool0oooo00d0oooo000=0?ooo`03o`00003oool0oooo
02l0oooo00@0ZKgX099QUOnBHIGoTV6E0P2BHID2oi9QU@@0TV6E0_nBHID4099QU@;oTV6E2P2BHID?
0:RojPd0TV6E<@2U`nl01?l00000QTEh08I5N026AGP40:K1k0P0oooo00?o00000?ooo`3oool05P3o
ool00ol00000oooo0?ooo`090?ooob[oY/;]7_nU`nlP0:O0ja80ZKgX5`3oool00ol00000oooo0?oo
o`0>0?ooo`03o`00003oool0oooo00`0oooo000>0?ooo`03o`00003oool0oooo02h0oooo0P2BHID2
oi9QU@80TV6E0_nBHID4099QU@;oTV6E102BHID2oi9QU@/0TV6E302X_nX?099QUC40YL?_00Co0000
08I5N026AGP0QTEh102V`N`80?ooo`03o`00003oool0oooo01L0oooo00?o00000?ooo`3oool0203o
ool[ojK2kASoYL?_8P2W`>/A0:Vmj1`0oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?oo
o`0<0?ooo`003`3oool2o`0002h0oooo0P2BHID2oi9QU@80TV6E0_nBHID4099QU@;oTV6E102BHID2
oi9QU@`0TV6E1`2X_nXD099QUC40YL?_00?o000008I5N026AGP01@2V`N`70?ooo`03o`00003oool0
oooo01P0oooo0_l000090?ooobWoY/;]0onBJ9hCojG3kb40Yl3[4`2Y_NPN0?ooo`03o`00003oool0
oooo00d0oooo00?o00000?ooo`3oool0303oool00140oooo00?o00000?ooo`3oool0:`3oool2099Q
U@;oTV6E0P2BHID2oi9QU@@0TV6E0_nBHID4099QU@;oTV6E3@2BHID0100Q37d0Z;oZ0:RojP2X_nXG
099QUC40YL?_00?o000008I5N02V`N`01@2V`N`60?ooo`03o`00003oool0oooo01X0oooo00?o0000
0?ooo`3oool0203ooolRojK2k@SoTVRN4OnU`nl40?:gSQd0Yl3[402Y_NPT0?ooo`03o`00003oool0
oooo00`0oooo00?o00000?ooo`3oool0303oool00180oooo00?o00000?ooo`3oool0:P3oool2099Q
U@;oTV6E0P2BHID2oi9QU@@0TV6E0_nBHID4099QU@;oTV6E3@2BHID00`0Q37d0TV6E099QU@0I099Q
UC40YL?_00?o00000:K1k02V`N`01@2V`N`50?ooo`03o`00003oool0oooo01/0oooo00?o00000?oo
o`3oool02@3ooolNojK2k@_oTVRN2onU`nl90?:gSQP0Yl3[4@2Y_NPY0?ooo`03o`00003oool0oooo
00/0oooo00?o00000?ooo`3oool0303oool001<0oooo00?o00000?ooo`3oool0:@3oool2099QU@;o
TV6E0P2BHID2oi9QU@@0TV6E0_nBHID4099QU@;oTV6E3@2BHID00`0Q37d0TV6E099QU@0J099QUC00
YL?_00?o00000:K1k02V`N`01P2V`N`50?ooo`03o`00003oool0oooo01/0oooo00?o00000?ooo`3o
ool0203ooolJojK2kA7oTVRN1onU`nl<0?:gSQD0Yl3[4@2Y_NP/0?ooo`03o`00003oool0oooo00X0
oooo00?o00000?ooo`3oool0303oool001@0oooo00?o00000?ooo`3oool0:03oool2099QU@;oTV6E
0P2BHID2oi9QU@@0TV6E0_nBHID4099QU@;oTV6E3@2BHID00`0Q37d0TV6E099QU@0K099QUBl0YL?_
00<0Y/7/o`00002V`N`01P2V`N`50?ooo`03o`00003oool0oooo01`0oooo0_l000090?oooaKoY/;]
5?nBJ9h00ol007_oYL?_ojG3k`02ojG3k`l0l[N>402W`>/30?>fRPh0ZKgX<03oool00ol00000oooo
0?ooo`0:0?ooo`03o`00003oool0oooo00`0oooo000E0?ooo`;o0000:03oool2099QU@;oTV6E0P2B
HID2oi9QU@@0TV6E0_nBHID4099QU@;oTV6E3@2BHID00`0Q37d0TV6E099QU@0L099QUB`0YL?_102V
`N`00ol00000Y/7/0:K1k0050:K1k0@0oooo00?o00000?ooo`3oool07P3oool00ol00000oooo0?oo
o`080?oooa3oY/;]6?nBJ9h3oo:gSQ80l[N>302W`>/70?>fRPT0ZKgX=@3oool00ol00000oooo0?oo
o`090?ooo`03o`00003oool0oooo00`0oooo000G0?ooo`03o`00003oool0oooo02D0oooo0P2BHID2
oi9QU@80TV6E0_nBHID4099QU@;oTV6E102BHID2oi9QU@d0TV6E00<08@am099QU@2BHID0702BHIDW
0:G3k`X0Y/7/00?o00000:K1k02V`N`01@2V`N`30?ooo`03o`00003oool0oooo01l0oooo00?o0000
0?ooo`3oool0203oool=ojK2kA[oTVRN0oob]hhD0?:gSPH0Yl3[303c]XX60:Vmj3P0oooo00?o0000
0?ooo`3oool02@3oool00ol00000oooo0?ooo`0;0?ooo`00603oool00ol00000oooo0?ooo`0T0?oo
o`80TV6E0_nBHID2099QU@;oTV6E102BHID2oi9QU@@0TV6E0_nBHID<099QU@030:O0j`0Q37d0TV6E
01h0TV6E8`2U`nl=0:K1k003o`00002V`N`0Y/7/00H0Y/7/0P3oool00ol00000oooo0?ooo`0P0?oo
o`03o`00003oool0oooo00T0oooo2OnV`^dKoi9XWP;oYL?_00?ol[N>0?:gSP3b]hh0503b]hh30:O0
j`l0lkJ:00<0ZKgX0?ooo`3oool0>`3oool00ol00000oooo0?ooo`080?ooo`03o`00003oool0oooo
00/0oooo000I0?ooo`03o`00003oool0oooo02<0oooo0P2BHID2oi9QU@80TV6E0_nBHID4099QU@;o
TV6E102BHID2oi9QU@L0TV6E1P2W`>/00`0Q37d0TV6E099QU@0N099QUAd0YL?_4`2V`N`00ol00000
Y/7/0:K1k0060:K1k0030?ooool00000oooo0280oooo0_l000090?ooo`CoY/;]7_nBJ9h5ojG3kaH0
l[N>4P3c]XXn0?ooo`03o`00003oool0oooo00P0oooo00?o00000?ooo`3oool02`3oool001X0oooo
0_l0000S0?ooo`80TV6E0_nBHID2099QU@;oTV6E102BHID2oi9QU@@0TV6E0_nBHID5099QU@P0Yl3[
00<08@am099QU@2BHID07`2BHIDJ0:G3kaH0Y/7/00?o00000:K1k02V`N`01@2V`N`20?ooo`03o`00
003oool0oooo0280oooo00?o00000?ooo`3oool01`3oool00onV`^goTVRNoi9XWP0Ioi9XWPKoYL?_
1@2U`nlE0?:gSQ80lkJ:?`3oool00ol00000oooo0?ooo`070?ooo`03o`00003oool0oooo00/0oooo
000L0?ooo`03o`00003oool0oooo0200oooo0P2BHID2oi9QU@80TV6E0_nBHID4099QU@;oTV6E102B
HID2oi9QU@03099QU@2W`>/0Yl3[00/0Yl3[8P2BHIDF0:G3kaX0Y/7/00?o00000:K1k02V`N`0102V
`N`20?ooo`03o`00003oool0oooo02<0oooo00?o00000?ooo`3oool01P3ooolJoi9XWPKoYL?_202U
`nlD0?:gSQ80lkJ:@03oool00ol00000oooo0?ooo`060?ooo`03o`00003oool0oooo00/0oooo000M
0?ooo`03o`00003oool0oooo01l0oooo0P2BHID2oi9QU@80TV6E0_nBHID4099QU@;oTV6E0`2BHIDA
0:O0j`03024<O@2BHID0TV6E0200TV6E402U`nlO0:K1k003o`00002V`N`0Y/7/00D0Y/7/00<0oooo
o`00003oool09@3oool00ol00000oooo0?ooo`050?oooaSoTVRN1?nU`nl>0:G3ka80l[N>4P3c]XY0
0?ooo`03o`00003oool0oooo00H0oooo00?o00000?ooo`3oool02`3oool001h0oooo00?o00000?oo
o`3oool07P3oool2099QU@;oTV6E0P2BHID2oi9QU@@0TV6E0_nBHID00`2BHID0Yl3[0:O0j`0A0:O0
j`03024<O@2BHID0TV6E01`0TV6E1@2V`^d=0:G3kb80Y/7/00?o00000:K1k02V`N`01@2V`N`00ol0
0000oooo0?ooo`0U0?ooo`03o`00003oool0oooo00@0oooo4onBJ9h6ojG3ka40YL?_4@3b]hh00`2W
`>`0lkJ:0?>fRP0@0?>fRT40oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`0;0?oo
o`007`3oool00ol00000oooo0?ooo`0M0?ooo`80TV6E0_nBHID2099QU@;oTV6E0`2BHIDG0:O0j`03
024<O@2BHID0TV6E01T0TV6E2@2V`^d70:G3k`<0l/FQ9@2V`N`00ol00000Y/7/0:K1k0030:K1k003
0?ooool00000oooo02L0oooo0_l000040?oooa7oTVRN1_nU`nlD0:G3ka00l[N>0P2W`>`A0?>fRT80
oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`0;0?ooo`00803oool2o`0001d0oooo
0P2BHID2oi9QU@80TV6E0_nBHID00`2BHID0Yl3[0:O0j`0G0:O0j`03024<O@2BHID0TV6E01D0TV6E
3P2V`^d40:G3k`H0l/FQ902V`N`00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo02P0oooo
00?o00000?ooo`3oool00P3oool<oi9XWPKoYL?_6@2U`nl?0?:gSP<0Yl3/403c]XY30?ooo`03o`00
003oool0oooo00@0oooo00?o00000?ooo`3oool02P3oool00280oooo00?o00000?ooo`3oool06P3o
ool2099QU@;oTV6E00<0TV6E0:O0j`2W`>/06`2W`>/00`0Q37d0TV6E099QU@0C099QUA<0Y/;]203b
aJ4R0:K1k080oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`0Y0?ooo`04o`00003o
ool0oooo0?ooo`[oTVRN1OnU`nlN0:G3k`d0l[N>0`2W`>`@0?>fRT<0oooo00?o00000?ooo`3oool0
103oool00ol00000oooo0?ooo`0:0?ooo`008`3oool00ol00000oooo0?ooo`0I0?ooo`03099QU@2W
`>/0Yl3[01l0Yl3[00<08@am099QU@2BHID03P2BHIDI0:K2k@P0l/FQ702V`N`80?ooo`03o`00003o
ool0oooo00<0oooo00?o00000?ooo`3oool0:@3oool00ol00000oooo0?ooo`05oi9XWPKoYL?_8P2U
`nl=0?:gSP@0Yl3/3`3c]XY40?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool02P3o
ool002@0oooo00?o00000?ooo`3oool06@3ooolR0:O0j`h0TV6E702V`^d70?;5XAX0Y/7/2`3oool0
0ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo02X0oooo0_l00003oi9XWPKoYL?_9@2U`nl<
0?:gSPH0Yl3/3@3c]XY50?ooo`03o`00003oool0oooo0080oooo00?o00000?ooo`3oool02P3oool0
02D0oooo0_l0000K0?ooob00Yl3[2@2BHIDR0:K2k@L0l/FQ5@2V`N`?0?ooo`03o`00003oool0oooo
0080oooo00?o00000?ooo`3oool0;03oool5ojG3kbX0YL?_2P3b]hh80:O0k0`0lkJ:AP3oool01Ol0
0000oooo0?ooo`3ooooo000000`0oooo000W0?ooo`03o`00003oool0oooo01T0oooo7`2W`>/5099Q
UBH0Y/;]203baJ4?0:K1k1D0oooo00Go00000?ooo`3oool0ooooo`00000_0?ooo`;oYL?_;P2U`nl8
0?:gSPT0Yl3/2`3c]XY60?ooo`05o`00003oool0oooo0?ooool00000303oool002P0oooo00?o0000
0?ooo`3oool06@3ooolN0:O0j`<0TV6E:@2V`^d80?;5X@`0Y/7/603oool01?l00000oooo0?ooool0
000`0?ooo`03o`00002U`nl0YL?_02d0YL?_1`3b]hh:0:O0k0T0lkJ:B03oool01?l00000oooo0?oo
ool0000<0?ooo`00:@3oool00ol00000oooo0?ooo`0I0?oooad0Yl3[;@2V`^d80?;5X@H0Y/7/7P3o
ool00ol00000ooooo`00000a0?ooo`03o`00002U`nl0YL?_02d0YL?_1P3b]hh;0:O0k0P0lkJ:B@3o
ool00ol00000ooooo`00000<0?ooo`00:P3oool00ol00000oooo0?ooo`0H0?oooah0Yl3[;@2V`^d8
0?;5X@030:K1k03oool0oooo0200oooo00?o00000?ooool00000<`3oool00ol00000YL?_0:G3k`0/
0:G3k`D0l[N>302W`>`70?>fRTT0oooo00Co00000?ooo`3ooooo00002`3oool002/0oooo0_l0000I
0?oooah0Yl3[;@2V`^d70?;5XB@0oooo00?o00000?ooool00000<`3oool00ol00000YL?_0:G3k`0/
0:G3k`@0l[N>3@2W`>`60?>fRTX0oooo00?o00000?ooool000002`3oool002d0oooo00?o00000?oo
o`3oool0603ooolM0:O0jbd0Y/;]1P3baJ4U0?ooo`;o0000=03oool00ol00000YL?_0:G3k`0/0:G3
k`<0l[N>3P2W`>`50?>fRT/0oooo0_l0000;0?ooo`00;P3oool00ol00000oooo0?ooo`0H0?oooad0
Yl3[;@2V`^d50?;5XB@0oooo0ol0000e0?ooo`03o`00002U`nl0YL?_02`0YL?_00<0l[N>0:O0k02W
`>`03P2W`>`40?>fRTX0oooo0ol0000;0?ooo`00;`3oool00ol00000oooo0?ooo`0H0?oooad0Yl3[
;@2V`^d30?;5XB40oooo1?l0000j0?ooobh0YL?_4@2W`>`30?>fRTH0oooo1?l0000>0?ooo`00<03o
ool2o`0001T0oooo7@2W`>/00`3oool0Y/;]0:K2k@0Y0:K2k@<0l/FQ7P3oool3o`0003l0oooo00?o
00000:G3k`2U`nl0:@2U`nlC0:O0k080lkJ:@`3oool3o`000180oooo000b0?ooo`03o`00003oool0
oooo01L0oooo602W`>/60?ooob/0Y/;]0P3baJ4J0?ooo`Co0000@`3oool00ol00000YL?_0:G3k`0T
0:G3kaP0Yl3/00<0lkJ:0?ooo`3oool0?@3oool4o`0001D0oooo000c0?ooo`03o`00003oool0oooo
01P0oooo4`2W`>/:0?ooob/0Y/;]5`3oool4o`0004P0oooo00?o00000:G3k`2U`nl08@2U`nlK0:O0
k3/0oooo1?l0000I0?ooo`00=03oool00ol00000oooo0?ooo`0H0?oooa00Yl3[3@3ooolW0:K2kAH0
oooo1?l0001>0?ooo`03o`00002U`nl0YL?_01/0YL?_702W`>`k0?ooo`?o00007@3oool003D0oooo
00?o00000?ooo`3oool0603oool;0:O0ja40oooo8P2V`^dH0?ooo`?o0000D`3oool00ol00000YL?_
0:G3k`0E0:G3kad0Yl3/>`3oool4o`000200oooo000f0?ooo`;o00006@3oool60:O0jaH0oooo7`2V
`^dF0?ooo`Co0000E`3oool00ol00000oooo0:G3k`0B0:G3kad0Yl3/>@3oool4o`0002@0oooo000h
0?ooo`03o`00003oool0oooo01L0oooo00<0Yl3[0?ooo`3oool06@3ooolJ0:K2kAH0oooo1?l0001L
0?ooo`03o`00002U`nl0YL?_00d0YL?_103ooolI0:O0k3T0oooo1?l0000X0?ooo`00>@3oool00ol0
0000oooo0?ooo`0F0?ooo`03o`00003oool0oooo01X0oooo502V`^dG0?ooo`Co0000HP3oool:0:G3
k`X0oooo4`2W`>`j0?ooo`?o0000;03oool003X0oooo00?o00000?ooo`3oool05@3oool00ol00000
oooo0?ooo`0K0?ooo`l0Y/;]603oool3o`0006L0oooo1`2U`nl=0?ooo`h0Yl3/>P3oool4o`0002l0
oooo000k0?ooo`;o00005@3oool00ol00000oooo0?ooo`0M0?ooo`/0Y/;]5P3oool4o`0006/0oooo
00?o00000:G3k`3oool04@3oool90:O0k3X0oooo1?l0000c0?ooo`00?@3oool00ol00000oooo0?oo
o`0B0?ooo`03o`00003oool0oooo01h0oooo1P2V`^dF0?ooo`Co0000L03oool2o`000180oooo102W
`>`j0?ooo`Co0000=`3oool003h0oooo00?o00000?ooo`3oool04@3oool00ol00000oooo0?ooo`0O
0?ooo`030:K2k@3oool0oooo01@0oooo1?l0001f0?ooo`03o`00003oool0oooo0100oooo00?o0000
0?ooo`3oool0=`3oool3o`0003/0oooo000o0?ooo`03o`00003oool0oooo0100oooo00?o00000?oo
o`3oool0<P3oool4o`0007/0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0c0?oo
o`Co0000?P3oool00400oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0_0?ooo`?o
0000P03oool00ol00000oooo0?ooo`0>0?ooo`03o`00003oool0oooo02l0oooo1?l000120?ooo`00
@@3oool2o`0000l0oooo00?o00000?ooo`3oool0:`3oool4o`0008@0oooo00?o00000?ooo`3oool0
3@3oool00ol00000oooo0?ooo`0/0?ooo`?o0000AP3oool004<0oooo00?o00000?ooo`3oool0303o
ool00ol00000oooo0?ooo`0W0?ooo`Co0000R@3oool2o`0000d0oooo00?o00000?ooo`3oool0:03o
ool4o`0004T0oooo00140?ooo`03o`00003oool0oooo00/0oooo00?o00000?ooo`3oool08`3oool4
o`0008l0oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0T0?ooo`Co0000C@3oool0
04D0oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0P0?ooo`?o0000U03oool00ol0
0000oooo0?ooo`090?ooo`03o`00003oool0oooo0200oooo1?l0001A0?ooo`00AP3oool2o`0000T0
oooo00?o00000?ooo`3oool07@3oool4o`0009P0oooo00?o00000?ooo`3oool0203oool00ol00000
oooo0?ooo`0M0?ooo`?o0000E@3oool004P0oooo00?o00000?ooo`3oool01P3oool00ol00000oooo
0?ooo`0I0?ooo`Co0000W@3oool2o`0000P0oooo00?o00000?ooo`3oool06@3oool4o`0005P0oooo
00190?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool05@3oool4o`000:<0oooo00?o
00000?ooo`3oool01@3oool00ol00000oooo0?ooo`0E0?ooo`Co0000G03oool004X0oooo00?o0000
0?ooo`3oool0103oool00ol00000oooo0?ooo`0B0?ooo`?o0000Z03oool00ol00000oooo0?ooo`04
0?ooo`03o`00003oool0oooo0140oooo1?l0001P0?ooo`00B`3oool00ol00000oooo0?ooo`030?oo
o`03o`00003oool0oooo00h0oooo1?l0002/0?ooo`03o`00003oool0oooo00<0oooo00?o00000?oo
o`3oool03P3oool3o`0006@0oooo001<0?ooo`;o00000`3oool00ol00000oooo0?ooo`0:0?ooo`Co
0000/@3oool2o`0000<0oooo00?o00000?ooo`3oool02P3oool4o`0006L0oooo001>0?ooo`04o`00
003oool0ooooo`0000P0oooo1?l0002g0?ooo`04o`00003oool0ooooo`0000P0oooo1?l0001[0?oo
o`00C`3oool00ol00000ooooo`0000050?ooo`?o0000_03oool00ol00000ooooo`0000050?ooo`?o
0000K`3oool00500oooo0_l000000`3ooooo0000o`000002o`000<00oooo0_l000000`3ooooo0000
o`000002o`000780oooo001A0?ooo`;o0000a@3oool2o`0007H0oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {153.5, 0}} -> {-0.0542361, -0.0193168, \
0.0052844, 0.0052844}, {{10.25, 190.438}, {149.812, 3.625}} -> {-0.0541935, \
0.0451583, 0.00528671, 0.00528671}, {{208.5, 388.688}, {149.812, 3.625}} -> \
{-1.10228, 0.0451583, 0.00528671, 0.00528671}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gdnoFrame\  = \ 
        Show[gd, \ Frame \[Rule] False, \ nS];\)\), "\[IndentingNewLine]", 
    \(\(gclass\  = \ 
        DrawHistogramClass[{h1, h2}, \ {class1Color, class2Color}, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gdnoFrame, gclass}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.38973 .69023 Mdot
.92797 .74704 Mdot
.60864 .83117 Mdot
.22047 .96051 Mdot
.82579 .27522 Mdot
.53863 .60265 Mdot
.2968 .87133 Mdot
.91144 .59112 Mdot
.45575 .76095 Mdot
.63715 .44613 Mdot
.5605 .811 Mdot
.59119 .67109 Mdot
.91839 .36981 Mdot
.97032 .45441 Mdot
.34058 .80496 Mdot
.80078 .8659 Mdot
.32506 .79524 Mdot
.46199 .55758 Mdot
.84323 .39312 Mdot
.8189 .4495 Mdot
.48331 .98672 Mdot
.87106 .43289 Mdot
.80054 .44265 Mdot
.74015 .4626 Mdot
.97669 .98821 Mdot
.52307 .54708 Mdot
.83911 .21721 Mdot
.64299 .97918 Mdot
.76698 .55124 Mdot
.14661 .8664 Mdot
.73915 .51147 Mdot
.99405 .05383 Mdot
.61824 .79364 Mdot
.83145 .88351 Mdot
.77418 .58138 Mdot
.79168 .33306 Mdot
.43444 .89351 Mdot
.62011 .53453 Mdot
.94673 .59841 Mdot
.62112 .48566 Mdot
.75581 .27935 Mdot
.95918 .94134 Mdot
.72835 .46244 Mdot
.11319 .92296 Mdot
.48425 .75023 Mdot
.93225 .97514 Mdot
.96812 .03875 Mdot
.44338 .98102 Mdot
.43463 .67366 Mdot
.20648 .9603 Mdot
.32639 .74575 Mdot
.91135 .54294 Mdot
.83432 .30845 Mdot
.09948 .90378 Mdot
.92659 .76768 Mdot
.86467 .28858 Mdot
.74685 .77544 Mdot
.52852 .49195 Mdot
.97622 .48654 Mdot
.88169 .57781 Mdot
.92943 .90906 Mdot
.95015 .80517 Mdot
.45819 .71115 Mdot
.64981 .52667 Mdot
.94653 .32803 Mdot
.96536 .83654 Mdot
.87391 .84616 Mdot
.93952 .93214 Mdot
.87477 .31165 Mdot
.67038 .73746 Mdot
.82334 .47792 Mdot
.70204 .44321 Mdot
.82319 .5921 Mdot
.38218 .94137 Mdot
.87871 .65501 Mdot
.57828 .75035 Mdot
.69755 .86085 Mdot
.75446 .33419 Mdot
.99056 .42259 Mdot
.90643 .18282 Mdot
.65778 .68512 Mdot
.28471 .82223 Mdot
.08445 .92982 Mdot
.75392 .48346 Mdot
.88392 .55404 Mdot
.88854 .36953 Mdot
.92451 .91285 Mdot
.5662 .88341 Mdot
.30331 .73892 Mdot
.55549 .70115 Mdot
.94571 .50711 Mdot
.93968 .97501 Mdot
.54954 .97624 Mdot
.47242 .71703 Mdot
.10551 .90556 Mdot
.73586 .78802 Mdot
.59442 .69731 Mdot
.604 .51509 Mdot
.96388 .56201 Mdot
.65936 .53513 Mdot
0 0 1 r
.02299 .29904 Mdot
.35992 .33389 Mdot
.25936 .42337 Mdot
.40621 .28343 Mdot
.70933 .21896 Mdot
.11987 .5167 Mdot
.40204 .44024 Mdot
.24158 .63961 Mdot
.384 .14616 Mdot
.43216 .28566 Mdot
.7931 .1566 Mdot
.64702 .20191 Mdot
.30332 .37959 Mdot
.41039 .55735 Mdot
.52873 .25163 Mdot
.08591 .66928 Mdot
.20036 .53938 Mdot
.18657 .77355 Mdot
.54839 .34242 Mdot
.14294 .78012 Mdot
.70283 .17407 Mdot
.23417 .10762 Mdot
.34719 .5093 Mdot
.16557 .7308 Mdot
.28232 .33684 Mdot
.31841 .17631 Mdot
.21833 .28273 Mdot
.51055 .1136 Mdot
.20623 .57744 Mdot
.85409 .0731 Mdot
.28721 .69184 Mdot
.32164 .1005 Mdot
.41609 .00546 Mdot
.49405 .28432 Mdot
.10263 .8242 Mdot
.28067 .00655 Mdot
.66224 .14903 Mdot
.36504 .47006 Mdot
.49237 .16559 Mdot
.39469 .33645 Mdot
.59032 .18909 Mdot
.7275 .19236 Mdot
.27148 .62077 Mdot
.85126 .0387 Mdot
.6646 .12722 Mdot
.17449 .46815 Mdot
.34813 .62327 Mdot
.14654 .27662 Mdot
.52297 .33208 Mdot
.66676 .29833 Mdot
.21045 .52863 Mdot
.18559 .76703 Mdot
.74933 .02469 Mdot
.31155 .30794 Mdot
.40615 .39646 Mdot
.16996 .03627 Mdot
.87823 .06933 Mdot
.2949 .38042 Mdot
.21641 .76605 Mdot
.0894 .84684 Mdot
.63509 .28429 Mdot
.03141 .11367 Mdot
.45445 .51231 Mdot
.27713 .09394 Mdot
.14785 .20932 Mdot
.0621 .91632 Mdot
.03564 .8076 Mdot
.50901 .15413 Mdot
.88259 .03104 Mdot
.12835 .53587 Mdot
.10667 .03337 Mdot
.07121 .6146 Mdot
.1432 .36693 Mdot
.04052 .80205 Mdot
.62924 .21775 Mdot
.282 .08838 Mdot
.26808 .27294 Mdot
.39447 .06229 Mdot
.1796 .52697 Mdot
.37133 .12846 Mdot
.07788 .49855 Mdot
.30508 .50891 Mdot
.26951 .70192 Mdot
.04231 .64587 Mdot
.16244 .14965 Mdot
.42685 .26934 Mdot
.16229 .56247 Mdot
.66979 .07369 Mdot
.5768 .38284 Mdot
.47495 .27817 Mdot
.47849 .48108 Mdot
.32466 .43845 Mdot
.30476 .06209 Mdot
.41573 .54915 Mdot
.3377 .12844 Mdot
.19069 .36524 Mdot
.14852 .04338 Mdot
.69872 .05577 Mdot
.21133 .55842 Mdot
.70619 .12378 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.0238095 0.0186741 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
153 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00>`3oool3o`00oaD0oooo0ol00?oo0?oooc/0oooo000k0?ooo`?o003o5@3oool3o`00ool0
oooo>`3oool008l0oooo0ol00?on0?ooo`00S`3oool3o`00oaH0oooo0ol00?oU0?ooo`00703oool3
o`00o`P0oooo0ol00?mU0?ooo`?o003o5P3oool3o`00obT0oooo[Ol00?l?0?ooo`00703oool3o`00
o`P0oooo0ol00?mh0?ooo`?o003o0`3oool3o`00o``0oooo0ooo000J0?ooojgo003o3`3oool001`0
oooo0ol00?l40?ooo`?o003o00@0ooooo`00ool00?oo003oN03oool3o`00oa80oooo0ooo000J0?oo
ojgo003o3`3oool002<0oooo0ol00?ml0?ooo`?o003o4P3oool3ool001X0oooo[Ol00?l?0?ooo`00
8`3oool3o`00of00oooo0ol00?lc0?ooo`;oo`005P3ooon]o`00o`l0oooo000o0?ooo`?o003o3@3o
ool3o`00oc@0oooo0ol00?lc0?ooo`;oo`005P3ooon]o`00o`l0oooo000o0?ooo`?o003o3@3oool3
o`00oc@0oooo0ol00?lN0?ooo`?o003o4P3oool2ool001H0oooo[Ol00?l?0?ooo`00?`3oool3o`00
o`d0oooo0ol00?l_0?ooo`?o003o7P3oool3o`00o`80oooo0ol00?lZ0?ooojgo003o3`3oool00840
oooo0ol00?lN0?ooo`?o003o0P3oool3o`00obX0oooo[Ol00?l?0?ooo`00P@3oool3o`00oah0oooo
0ol00?l_0?ooojgo003o3`3oool003/0oooo0ol00?nF0?ooojgo003o3`3oool003X0oooo1?l00?nF
0?ooojgo003o3`3oool003X0oooo1?l00?l40?ooo`?o003oS`3ooon]o`00o`l0oooo000c0?ooo`?o
003o103oool3o`00o`D0oooo0ol00?n?0?ooojgo003o3`3oool000h0oooo0ol00?lR0?ooo`?o003o
303oool3o`00oal0oooo0ol00?m]0?ooojgo003o3`3oool000h0oooo0ol00?lR0?ooo`?o003o;P3o
ool3o`00ofd0oooo[Ol00?l?0?ooo`003P3oool3o`00oe<0oooo0ol00?lQ0?ooo`?o003oB@3ooon]
o`00o`l0oooo00150?ooo`?o003o0`3oool3o`00oc80oooo0ol00?l50?ooo`?o003oB@3ooon]o`00
o`l0oooo00150?ooo`?o003o0`3oool3o`00oc80oooo0ol00?l50?ooo`?o003oB@3ooon]o`00o`l0
oooo00150?ooo`?o003o0`3oool3o`00oc80oooo0ol00?mA0?ooojgo003o3`3oool004h0oooo0ol0
0?n30?ooojgo003o3`3oool002H0oooo0ol00?lU0?ooo`?o003o;`3oool3o`00oe40oooo[Ol00?l?
0?ooo`009P3oool3o`00obD0oooo0ol00?lC0?ooo`?o003o6@3oool3o`00oa@0oooo0ol00?lj0?oo
ojgo003o3`3oool002H0oooo0ol00?lk0?ooo`?o003o6@3oool3o`00oa@0oooo0ol00?lj0?ooojgo
003o3`3oool00640oooo1_l00?l`0?ooo`?o003o>P3ooon]o`00o`l0oooo001Q0?ooo`?o003o8`3o
ool3o`00odX0oooo[Ol00?l?0?ooo`00@P3oool3o`00oa`0oooo0ol00?lS0?ooo`?o003oBP3ooon]
o`00o`l0oooo00120?ooo`?o003o@P3oool3o`00ob80oooo0ooo000U0?ooojgo003o3`3oool00480
oooo0ol00?l^0?ooo`?o003o=P3oool3ool002D0oooo[Ol00?l?0?ooo`00L`3oool3o`00oaH0oooo
0ol00?lM0?ooo`?oo`009@3ooon]o`00o`l0oooo001c0?ooo`?o003o1`3oool3o`00o``0oooo0ol0
0?m50?ooojgo003o3`3oool007d0oooo0ol00?l<0?ooo`?o003oA@3ooon]o`00o`l0oooo000S0?oo
o`?o003oE`3oool3o`00oe@0oooo[Ol00?l?0?ooo`008`3oool3o`00oe@0oooo0ol00?l;0?ooo`?o
003o5@3oool3ool00340oooo[Ol00?l?0?ooo`008`3oool3o`00oe@0oooo0ol00?l;0?ooo`?o003o
5@3oool3ool00340oooo[Ol00?l?0?ooo`00NP3oool3o`00o`/0oooo0ol00?lE0?ooo`?oo`00<@3o
oon]o`00o`l0oooo003D0?ooojgo003o3`3oool00=@0oooo[Ol00?l?0?ooo`00e03ooon]o`00o`l0
oooo001X0?ooo`?o003oJ@3ooon]o`00o`l0oooo001X0?ooo`?o003oJ@3ooon]o`00o`l0oooo001X
0?ooo`?o003oJ@3ooon]o`00o`l0oooo001E0?ooo`?o003oO03ooon]o`00o`l0oooo000i0?ooo`?o
003o6@3oool3o`00og`0oooo[Ol00?l?0?ooo`008`3oool3o`00oa<0oooo0ol00?lI0?ooo`?o003o
1P3oool3o`00oc00oooo0ooo00090?ooo`?oo`00=03ooon]o`00o`l0oooo000S0?ooo`?o003o2P3o
ool3o`00o`H0oooo0ol00?lF0?ooo`?o003o00@0ooooo`00ool00?oo003o1@3oool6o`00oaL0oooo
0ol00?lC0?ooo`?oo`002@3oool3ool003@0oooo[Ol00?l?0?ooo`008`3oool3o`00o`X0oooo0ol0
0?lO0?ooo`?o003o00@0ooooo`00ool00?oo003o1@3oool6o`00oaL0oooo0ol00?lC0?ooo`?oo`00
2@3oool3ool000@0oooo0ooo000]0?ooojgo003o3`3oool00300oooo0ol00?lO0?ooo`?o003o00@0
ooooo`00ool00?oo003o203oool3o`00oaL0oooo0ol00?lV0?ooo`?oo`00;@3ooon]o`00o`l0oooo
000<0?ooo`?o003oLP3oool3o`00ob00oooo0ooo000]0?ooojgo003o3`3oool000`0oooo0ol00?lb
0?ooo`?o003o?@3oool3o`00oe00oooo[Ol00?l?0?ooo`00303oool3o`00oc80oooo0ol00?lm0?oo
o`?o003o6`3oool3ool000@0oooo0ooo000[0?ooojgo003o3`3oool00440oooo0ol00?mK0?ooo`?o
o`00103oool3ool002/0oooo[Ol00?l?0?ooo`00W`3oool3ool000@0oooo0ooo000[0?ooojgo003o
3`3oool00;<0oooo0ooo000N0?ooojgo003o3`3oool004T0oooo0ol00?lK0?ooo`?o003o9P3oool3
ool000@0oooo0ooo000I0?ooo`?oo`007P3ooon]o`00o`l0oooo000k0?ooo`?o003o2`3oool3o`00
o`@0oooo0ol00?lD0?ooo`?o003o9P3oool3ool000@0oooo0ooo000I0?ooo`?oo`007P3ooon]o`00
o`l0oooo000k0?ooo`?o003o2`3oool3o`00o`@0oooo0ol00?lD0?ooo`?o003o00@0ooooo`00ool0
0?oo003o8P3oool3ool000@0oooo0ooo000j0?ooojgo003o3`3oool003/0oooo0ol00?lB0?ooo`?o
003o603oool3o`00ofH0ooooLol00?ljool000l0oooo001[0?ooo`?o003oIP3ooomco`00oc[oo`00
3`3oool00=@0ooooLol00?ljool000l0oooo000R0?ooo`?o003o1P3oool3o`00ojH0ooooLol00?lj
ool000l0oooo000R0?ooo`?o003o1P3oool3o`00og/0oooo0ooo00020?ooo`?oo`008`3ooomco`00
oc[oo`003`3oool00280oooo0ol00?l60?ooo`?o003o403oool4o`00ofL0oooo0ooo00020?ooo`?o
o`008`3ooomco`00oc[oo`003`3oool003h0oooo1?l00?l^0?ooo`?o003o=P3oool3ool00080oooo
0ooo000S0?ooog?o003o>_oo000?0?ooo`00?P3oool4o`00obh0oooo0ol00?mQ0?ooog?o003o>_oo
000?0?ooo`00DP3oool3o`00oa/0oooo0ol00?l]0?ooo`?oo`00<@3ooomco`00oc[oo`003`3oool0
0580oooo0ol00?m;0?ooo`?oo`00<@3ooomco`00oc[oo`003`3oool00580oooo0ol00?m;0?ooo`?o
o`00<@3ooomco`00oc[oo`003`3oool00=@0ooooLol00?ljool000l0oooo003D0?ooog?o003o>_oo
000?0?ooo`00=`3oool3o`00oh40oooo0ooo000F0?ooog?o003o>_oo000?0?ooo`00=`3oool3o`00
oh40oooo0ooo000F0?ooog?o003o>_oo000?0?ooo`00=`3oool3o`00of/0oooo0ooo000C0?ooo`?o
o`005P3ooomco`00oc[oo`003`3oool004<0oooo0ol00?l;0?ooo`?o003oD@3oool3ool002`0oooo
Lol00?ljool000l0oooo00130?ooo`?o003o2`3oool3o`00obL0oooo0ooo00090?ooo`?oo`003`3o
ool3ool000T0oooo0ooo000/0?ooog?o003o>_oo000?0?ooo`00@`3oool3o`00o`/0oooo0ol00?lW
0?ooo`?oo`002@3oool3ool000l0oooo1_oo000e0?ooog?o003o>_oo000?0?ooo`00N`3oool3ool0
00T0oooo0ooo000?0?ooo`Koo`00603oool3ool001X0ooooLol00?ljool000l0oooo002<0?ooo`Go
o`002`3oool3ool001P0oooo0ooo000J0?ooog?o003o>_oo000?0?ooo`00:03oool3o`00of40oooo
1Ooo000V0?ooo`?oo`006P3ooomco`00oc[oo`003`3oool002P0oooo0ol00?lO0?ooo`?o003o?`3o
ool5ool004<0ooooLol00?ljool000l0oooo000X0?ooo`?o003o7`3oool3o`00oe00oooo0ooo000d
0?ooog?o003o>_oo000?0?ooo`00BP3oool3o`00oa80oooo0ol00?lF0?ooo`?oo`005@3oool3ool0
00X0oooo0ooo000d0?ooog?o003o>_oo000?0?ooo`00G`3oool3o`00oaH0oooo0ooo000E0?ooo`?o
o`002P3oool3ool001P0oooo0ooo000I0?ooog?o003o>_oo000?0?ooo`00G`3oool3o`00o`H0oooo
0ooo000=0?ooo`?oo`005@3oool3ool002D0oooo0ooo000I0?ooog?o003o>_oo000?0?ooo`005P3o
ool3o`00odl0oooo0ooo001=0?ooo`?oo`006@3ooomco`00oc[oo`003`3oool001H0oooo0ol00?m?
0?ooo`?oo`00B03oool3ool001h0ooooLol00?ljool000l0oooo000F0?ooo`?o003o9P3oool3o`00
o`D0oooo0ol00?l@0?ooo`?o003o<@3oool3ool00280oooo0ooo000N0?ooog?o003o>_oo000?0?oo
o`007P3oool3o`00oah0oooo0ol00?l50?ooo`?o003o403oool3o`00oaP0oooo0ooo000F0?ooo`?o
o`008P3oool3ool001h0ooooLol00?ljool000l0oooo000N0?ooo`?o003o7P3oool3o`00o`D0oooo
0ol00?l@0?ooo`?o003o603oool3ool001H0oooo0ooo00130?ooog?o003o>_oo000?0?ooo`007P3o
ool3o`00o`P0oooo0ol00?l20?ooo`?o003oA03oool3ool000H0oooo0ooo001C0?ooog?o003o>_oo
000?0?ooo`00:@3oool3o`00o`80oooo0ol00?m70?ooo`?oo`000`3oool4ool00580ooooLol00?lj
ool000l0oooo000O0?ooo`?o003o1`3oool8o`00odL0oooo0ooo00030?ooo`Coo`00DP3ooomco`00
oc[oo`003`3oool001l0oooo0ol00?l:0?ooo`?o003oB@3oool3ool000@0oooo0ooo000[0?ooo`?o
o`00903ooomco`00oc[oo`003`3oool001l0oooo0ol00?l:0?ooo`?o003o903oool3o`00oa40oooo
0ooo000Y0?ooo`?oo`005`3oool3ool002@0ooooLol00?ljool000l0oooo001B0?ooo`Co003o1P3o
ool3ool000P0oooo0ooo000Y0?ooo`?oo`004P3oool3ool00080oooo0ooo000T0?ooog?o003o>_oo
000?0?ooo`009P3oool3o`00o`D0oooo0ol00?lQ0?ooo`Co003o1P3oool3ool000P0oooo0ooo000Y
0?ooo`?oo`004P3oool3ool000/0oooo0ooo000K0?ooog?o003o>_oo000?0?ooo`009P3oool3o`00
o`D0oooo0ol00?lQ0?ooo`?o003o1`3oool3ool004T0oooo0ooo000;0?ooo`?oo`006`3ooomco`00
oc[oo`003`3oool002H0oooo0ol00?l50?ooo`?o003oQ@3oool3ool001/0ooooLol00?ljool000l0
oooo000^0?ooo`?o003oMP3oool3ool002X0ooooLol00?ljool000l0oooo000^0?ooo`?o003oH`3o
ool3ool00100oooo0ooo000Z0?ooog?o003o>_oo000?0?ooo`00;P3oool3o`00of<0oooo0ooo000@
0?ooo`?oo`000`3oool3ool002@0ooooLol00?ljool000l0oooo002D0?ooo`?oo`001P3oool3ool0
00d0oooo0ooo000T0?ooog?o003o>_oo000?0?ooo`00W@3oool3ool000d0oooo0ooo00030?ooo`?o
o`007P3ooomco`00oc[oo`003`3oool006T0oooo0ooo000a0?ooo`?oo`004`3oool3ool001h0oooo
Lol00?ljool000l0oooo001Y0?ooo`?oo`00A`3oool3ool001h0ooooLol00?ljool000l0oooo000E
0?ooo`?o003oD@3oool3ool006P0ooooLol00?ljool000l0oooo000E0?ooo`?o003o8@3oool3o`00
o`/0oooo0ol00?n:0?ooog?o003o>_oo000?0?ooo`005@3oool3o`00ob40oooo0ol00?l;0?ooo`?o
003oRP3ooomco`00oc[oo`003`3oool003T0oooo0ol00?l;0?ooo`?o003oRP3ooomco`00oc[oo`00
3`3oool003@0oooo0ol00?nM0?ooog?o003o>_oo000?0?ooo`00403oool3o`00ob40oooo0ol00?nM
0?ooog?o003o>_oo000?0?ooo`00403oool3o`00ob40oooo0ol00?nM0?ooog?o003o>_oo000?0?oo
o`00403oool3o`00oi@0oooo0ooo000Z0?ooog?o003o>_oo000?0?ooo`00Y`3oool3ool002X0oooo
Lol00?ljool000l0oooo002W0?ooo`?oo`00:P3oooljo`00og?oo`003`3oool001P0oooo0ol00?ll
0?ooo`?oo`006@3oool3ool005h0oooo>_l00?mcool000l0oooo000H0?ooo`?o003o?03oool3ool0
01T0oooo0ooo001N0?oooc[o003oLooo000?0?ooo`00603oool3o`00oc`0oooo0ooo000I0?ooo`?o
o`002@3oool3ool00580oooo>_l00?mcool000l0oooo001?0?ooo`?oo`00;@3oool3ool00580oooo
>_l00?mcool000l0oooo000l0?ooo`?o003o403oool3ool002d0oooo0ooo001B0?oooc[o003oLooo
000?0?ooo`00>@3oool6o`00oa00oooo0ooo000K0?ooo`?oo`00103oool3ool005d0oooo>_l00?mc
ool000l0oooo000i0?ooo`Ko003o;P3oool3ool000@0oooo0ooo001M0?oooc[o003oLooo000?0?oo
o`00>@3oool3o`00oal0oooo0ooo000?0?ooo`?oo`00103oool3ool005d0oooo>_l00?mcool000l0
oooo001K0?ooo`Koo`00L`3oooljo`00og?oo`003`3oool005/0oooo1_oo001c0?oooc[o003oLooo
000?0?ooo`00GP3oool3ool007<0oooo>_l00?mcool000l0oooo000V0?ooo`?o003oZ`3oooljo`00
og?oo`003`3oool002H0oooo0ol00?lF0?ooo`?oo`00?`3oool3ool00500oooo>_l00?mcool000l0
oooo000V0?ooo`?o003o5P3oool3ool000040?oooooo003oo`00ool003/0oooo0ooo001@0?oooc[o
003oLooo000?0?ooo`00?`3oool3ool000040?oooooo003oo`00ool001X0oooo0ooo000>0?ooo`?o
o`003@3oool3ool002`0oooo0ooo000Q0?oooc[o003oLooo000?0?ooo`00@`3oool3ool001X0oooo
0ooo000>0?ooo`?oo`00?03oool3ool00240oooo>_l00?mcool000l0oooo001K0?ooo`?oo`000P3o
ool3ool000h0oooo0ooo000l0?ooo`?oo`008@3oooljo`00og?oo`003`3oool002X0oooo0ol00?l2
0?ooo`?o003o:@3oool3ool00540oooo0ooo000R0?oooc[o003oLooo000?0?ooo`00:P3oool3o`00
o`80oooo0ol00?lY0?ooo`?oo`00D@3oool3ool00280oooo>_l00?mcool000l0oooo000Z0?ooo`?o
003o0P3oool3o`00oed0oooo0ooo000M0?ooo`?oo`008P3oooljo`00og?oo`003`3oool00280oooo
0ol00?l50?ooo`?o003oHP3oool3ool00480oooo>_l00?mcool000l0oooo000R0?ooo`?o003oJ03o
ool5ool00480oooo>_l00?mcool000l0oooo000R0?ooo`?o003o7P3oool3ool00380oooo0ooo000B
0?ooo`?oo`00A03oooljo`00og?oo`003`3oool004<0oooo0ooo000b0?ooo`?oo`004P3oool3ool0
04@0oooo>_l00?mcool000l0oooo000@0?ooo`?o003o<03oool6ool002l0oooo0ooo000i0?ooo`?o
o`007@3oooljo`00og?oo`003`3oool000l0oooo1?l00?lc0?ooo`?oo`00903oool3ool004@0oooo
0ooo000M0?oooc[o003oLooo000?0?ooo`003`3oool4o`00oc<0oooo0ooo000T0?ooo`?oo`00A03o
ool3ool001d0oooo>_l00?mcool000l0oooo000?0?ooo`?o003o:P3oool3ool002h0oooo0ooo001T
0?oooc[o003oLooo000?0?ooo`006`3oool3o`00oah0oooo0ooo002E0?oooc[o003oLooo000?0?oo
o`006`3oool3o`00oah0oooo0ooo000g0?ooo`?oo`00F`3oooljo`00og?oo`003`3oool001/0oooo
0ol00?mH0?ooo`?oo`00?@3oool3ool001/0oooo>_l00?mcool000l0oooo001f0?ooo`?oo`00;@3o
ool3ool000d0oooo0ooo000K0?oooc[o003oLooo000?0?ooo`00603oool3o`00oh/0oooo0ooo000=
0?ooo`?oo`006`3oooljo`00og?oo`003`3oool001P0oooo0ol00?n;0?ooo`?oo`00:`3oooljo`00
og?oo`003`3oool001P0oooo0ol00?m[0?ooo`?oo`00B`3oooljo`00og?oo`003`3oool002<0oooo
0ooo001P0?ooo`?oo`00403oool3ool003P0oooo>_l00?mcool000l0oooo000S0?ooo`?oo`00603o
ool3ool004D0oooo0ooo000@0?ooo`?oo`00>03oooljo`00og?oo`003`3oool002<0oooo0ooo000H
0?ooo`?oo`00F03oool3ool003P0oooo>_l00?mcool000l0oooo000n0?ooo`?oo`00;@3oool3ool0
02d0oooo0ooo000c0?oooc[o003oLooo000?0?ooo`00KP3oool3ool002d0oooo0ooo000c0?oooc[o
003oLooo000?0?ooo`00E`3oool3ool001@0oooo0ooo000]0?ooo`?oo`00<`3oooljo`00og?oo`00
3`3oool005L0oooo0ooo001j0?oooc[o003oLooo000?0?ooo`006P3oool4ool003T0oooo0ooo001j
0?oooc[o003oLooo000?0?ooo`006P3oool4ool00980oooo0ooo000Q0?oooc[o003oLooo000?0?oo
o`00503oool3o`00o`<0oooo1?oo002A0?ooo`Coo`008@3oooljo`00og?oo`003`3oool001@0oooo
0ol00?l60?ooo`?oo`00S`3oool4ool00240oooo>_l00?mcool000l0oooo000D0?ooo`?o003o1P3o
ool3ool008l0oooo0ooo000R0?oooc[o003oLooo000?0?ooo`00603oool3ool00080oooo0ooo002B
0?ooo`?oo`007`3oooljo`00og?oo`003`3oool001P0oooo0ooo002G0?ooo`?oo`007`3oooljo`00
og?oo`003`3oool001P0oooo0ooo000b0?ooo`?oo`00HP3oool6ool001`0oooo>_l00?mcool000l0
oooo001=0?ooo`?oo`00I@3oool3ool001`0oooo>_l00?mcool000l0oooo001=0?ooo`?oo`00I@3o
ool3ool001`0oooo>_l00?mcool000l0oooo000^0?ooo`Goo`00X@3oooljo`00og?oo`003`3oool0
02h0oooo1Ooo002Q0?oooc[o003oLooo000?0?ooo`00;P3oool5ool00:40oooo>_l00?mcool000l0
oooo001[0?ooo`?oo`003P3oool3ool00340oooo1Ooo000O0?oooc[o003oLooo000?0?ooo`00F03o
ool3ool00100oooo0ooo000>0?ooo`?oo`00<@3oool5ool00=/0oooo001H0?ooo`?oo`00103oool3
ool000T0oooo0ooo000>0?ooo`?oo`00<@3oool5ool000<0oooo0ooo003E0?ooo`00F03oool3ool0
00@0oooo0ooo001F0?ooo`?oo`00e@3oool005l0oooo0ooo001F0?ooo`?oo`00e@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-1.1227, \
-1.0611, 0.011199, 0.011199}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-63.1851, -2.62981, 0.296885, 0.296885}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data-dependent quantization (vector quantization)", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Number of centroids for each class (",
  Cell[BoxData[
      \(TraditionalForm\`2\^m\)]],
  ")"
}], "Subsubsection"],

Cell[BoxData[
    \(\(m\  = \ 2;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute data-dependent centroids", "Subsubsection"],

Cell[BoxData[{
    \(\(vqCentroids1 = \ VQ[data1, m];\)\), "\n", 
    \(\(vqCentroids2\  = VQ[data2, m];\)\), "\n", 
    \(\(vqCentroids\  = \ vqCentroids1~Join~vqCentroids2;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gCentroids = \ 
        PlotData2D[vqCentroids, pr, \ centroidStyle, \ 
          FrameTicks \[Rule] None];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 1 r
.02 w
.89641 .85907 Mdot
.83098 .42334 Mdot
.54524 .74212 Mdot
.24524 .87668 Mdot
.13907 .7486 Mdot
.28192 .4726 Mdot
.65629 .17873 Mdot
.26441 .14646 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`17ooooo`?oo`3odOooool1o`00
007ooooo00000ol0003oooooooooo`16ooooo`Goo`3od?ooool1o`00007ooooo00000ol0003ooooo
ooooo`16ooooo`Goo`3od?ooool1o`00007ooooo00000ol0003oooooooooo`16ooooo`Goo`3od?oo
ool1o`00007ooooo00000ol0003oooooooooo`17ooooo`?oo`3odOooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0^?ooool3ool0of3ooooo0Ol00001
ooooo`0000?o0000ooooooooool0]oooool5ool0oeoooooo0Ol00001ooooo`0000?o0000oooooooo
ool0]oooool5ool0oeoooooo0Ol00001ooooo`0000?o0000ooooooooool0]oooool5ool0oeoooooo
0Ol00001ooooo`0000?o0000ooooooooool0^?ooool3ool0of3ooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3Zooooo`?oo`3o;_ooool1o`00007ooooo00000ol0003oooooooooo`3Yoooo
o`Goo`3o;Oooool1o`00007ooooo00000ol0003oooooooooo`3Yooooo`Goo`3o;Oooool1o`00007o
oooo00000ol0003oooooooooo`3Yooooo`Goo`3o;Oooool1o`00007ooooo00000ol0003ooooooooo
o`3Zooooo`?oo`3o;_ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`1<ooooo`?oo`3oc?ooool1o`00007ooooo00000ol0003oooooooooo`1;
ooooo`Goo`3oboooool1o`00007ooooo00000ol0003oooooooooo`1;ooooo`Goo`3oboooool1o`00
007ooooo00000ol0003oooooooooo`1;ooooo`Goo`3oboooool1o`00007ooooo00000ol0003ooooo
ooooo`1<ooooo`?oo`3oc?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool3ool0oh3o
oooo0Ol00001ooooo`0000?o0000ooooooooool0Uoooool5ool0ogoooooo0Ol00001ooooo`0000?o
0000ooooooooool08oooool3ool0og7ooooo1Ooo0?moooooo`7o00000Oooool00003o`000?oooooo
oooo02;ooooo1Ooo0?m`ooooo`Goo`3oOoooool1o`00007ooooo00000ol0003oooooooooo`0Roooo
o`Goo`3oLOooool3ool0oh3ooooo0Ol00001ooooo`0000?o0000ooooooooool08_ooool5ool0ooCo
oooo0Ol00001ooooo`0000?o0000ooooooooool08oooool3ool0ooGooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3looooo`?oo`3o7?ooool1o`00007ooooo00000ol0003oooooooooo`3koooo
o`Goo`3o6oooool1o`00007ooooo00000ol0003oooooooooo`3kooooo`Goo`3o6oooool1o`00007o
oooo00000ol0003oooooooooo`3kooooo`Goo`3o6oooool1o`00007ooooo00000ol0003ooooooooo
o`3looooo`?oo`3o7?ooool1o`00007ooooo00000ol0003oooooooooo`12ooooo`?oo`3oe_ooool1
o`00007ooooo00000ol0003oooooooooo`11ooooo`Goo`3oeOooool1o`00007ooooo00000ol0003o
ooooooooo`11ooooo`Goo`3oeOooool1o`00007ooooo00000ol0003oooooooooo`11ooooo`Goo`3o
eOooool1o`00007ooooo00000ol0003oooooooooo`12ooooo`?oo`3oe_ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00?oo00008?l00001ooooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize resultant partitioning of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gpart1\  = \ 
        DrawPartitioning[vqCentroids, \ pr, nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[gpart1, gCentroids, yS, \ 
        FrameTicks \[Rule] None];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.012 w
.90037 .86266 Mdot
.83429 .42257 Mdot
.54569 .74455 Mdot
.24269 .88044 Mdot
.13546 .75109 Mdot
.27974 .47233 Mdot
.65785 .17552 Mdot
.26206 .14293 Mdot
.33949 .67997 Mdot
.33967 .69093 Mdot
.44852 .29809 Mdot
.55589 .43487 Mdot
.55867 .46585 Mdot
.77187 .65695 Mdot
.003 w
.77187 .65695 m
0 0 rlineto s
.77187 .65695 m
1 .62269 L
s
.55589 .43487 m
.99312 .12261 L
s
.33967 .69093 m
.05972 .923 L
s
.44852 .29809 m
0 0 rlineto s
.44852 .29809 m
.47307 0 L
s
.65763 1 m
.77187 .65695 L
s
.77187 .65695 m
.55867 .46585 L
.55589 .43487 L
s
.33967 .69093 m
.33949 .67997 L
.55867 .46585 L
.77187 .65695 L
s
.77187 .65695 m
.65763 1 L
s
.47829 1 m
.33967 .69093 L
s
.33967 .69093 m
0 0 rlineto s
.33967 .69093 m
.47829 1 L
s
0 .50426 m
.33949 .67997 L
.33967 .69093 L
s
0 .32217 m
.44852 .29809 L
.55589 .43487 L
.55867 .46585 L
.33949 .67997 L
s
.33949 .67997 m
0 .50426 L
s
.55589 .43487 m
.44852 .29809 L
s
.44852 .29809 m
0 0 rlineto s
.44852 .29809 m
0 .32217 L
s
1 0 1 r
.02 w
.90037 .86266 Mdot
.83429 .42257 Mdot
.54569 .74455 Mdot
.24269 .88044 Mdot
.13546 .75109 Mdot
.27974 .47233 Mdot
.65785 .17552 Mdot
.26206 .14293 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`24ooooo`0300000?oooooooooo09Co
oooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool00`00003oooooooooo`2Dooooo`7o0000
0Oooool00003o`000?oooooooooo08Cooooo00<00000ooooooooool0U?ooool1o`00007ooooo0000
0ol0003oooooooooo`24ooooo`0300000?oooooooooo09Cooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Q?ooool00`00003oooooooooo`2Dooooo`7o00000Oooool00003o`000?oooooooooo08Co
oooo00<00000ooooooooool0U?ooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`030000
0?oooooooooo09Gooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool00`00003ooooooooo
o`2Eooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo00<00000ooooooooool0UOooool1
o`00007ooooo00000ol0003oooooooooo`23ooooo`0300000?oooooooooo09Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0Poooool00`00003oooooooooo`2Eooooo`7o00000Oooool00003o`00
0?oooooooooo08?ooooo00<00000ooooooooool0UOooool1o`00007ooooo00000ol0003ooooooooo
o`23ooooo`0300000?oooooooooo09Gooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool0
0`00003oooooooooo`2Eooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo00<00000oooo
ooooool0UOooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`0300000?oooooooooo09Go
oooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool00`00003oooooooooo`2Eooooo`7o0000
0Oooool00003o`000?oooooooooo08?ooooo00<00000ooooooooool0UOooool1o`00007ooooo0000
0ol0003oooooooooo`22ooooo`0300000?oooooooooo09Kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0P_ooool00`00003oooooooooo`2Fooooo`7o00000Oooool00003o`000?oooooooooo08;o
oooo00<00000ooooooooool0U_ooool1o`00007ooooo00000ol0003oooooooooo`22ooooo`030000
0?oooooooooo09Kooooo0Ol00001ooooo`0000?o0000ooooooooool0P_ooool00`00003ooooooooo
o`2Fooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo00<00000ooooooooool0U_ooool1
o`00007ooooo00000ol0003oooooooooo`22ooooo`0300000?oooooooooo09Kooooo0Ol00001oooo
o`0000?o0000ooooooooool0P_ooool00`00003oooooooooo`2Fooooo`7o00000Oooool00003o`00
0?oooooooooo08;ooooo00<00000ooooooooool0U_ooool1o`00007ooooo00000ol0003ooooooooo
o`22ooooo`0300000?oooooooooo09Kooooo0Ol00001ooooo`0000?o0000ooooooooool0P_ooool0
0`00003oooooooooo`2Fooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo00<00000oooo
ooooool0U_ooool1o`00007ooooo00000ol0003oooooooooo`21ooooo`0300000?oooooooooo09Oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0POooool00`00003oooooooooo`2Gooooo`7o0000
0Oooool00003o`000?oooooooooo087ooooo00<00000ooooooooool0Uoooool1o`00007ooooo0000
0ol0003oooooooooo`21ooooo`0300000?oooooooooo09Oooooo0Ol00001ooooo`0000?o0000oooo
ooooool0POooool00`00003oooooooooo`2Dooooo`8000000Oooool1o`00007ooooo00000ol0003o
ooooooooo`21ooooo`0300000?oooooooooo09?ooooo00D00000ooooooooooooooooo`000001oooo
o`0000?o0000ooooooooool0POooool00`00003oooooooooo`2Aooooo`8000001?ooool1o`00007o
oooo00000ol0003oooooooooo`21ooooo`0300000?oooooooooo093ooooo00<00000ooooooooool0
1?ooool1o`00007ooooo00000ol0003oooooooooo`16ooooo`?oo`3o>?ooool00`00003ooooooooo
o`2?ooooo`0300000?oooooooooo00Gooooo0Ol00001ooooo`0000?o0000ooooooooool0AOooool5
ool0ocOooooo00<00000ooooooooool0SOooool2000000Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool0AOooool5ool0ocOooooo00<00000ooooooooool0S?ooool00`00003oooooooooo`08oooo
o`7o00000Oooool00003o`000?oooooooooo04Gooooo1Ooo0?lgooooo`0300000?oooooooooo08[o
oooo0P00000;ooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo0ooo0?lgooooo`030000
0?oooooooooo08[ooooo00<00000ooooooooool02oooool1o`00007ooooo00000ol0003ooooooooo
o`20ooooo`0300000?oooooooooo08Wooooo00<00000ooooooooool03?ooool1o`00007ooooo0000
0ol0003oooooooooo`20ooooo`0300000?oooooooooo08Oooooo0P00000?ooooo`7o00000Oooool0
0003o`000?oooooooooo083ooooo00<00000ooooooooool0Q_ooool00`00003oooooooooo`0?oooo
o`7o00000Oooool00003o`000?oooooooooo083ooooo00<00000ooooooooool0Q?ooool2000001;o
oooo0Ol00001ooooo`0000?o0000ooooooooool0P?ooool00`00003oooooooooo`0eooooo`?oo`3o
Boooool00`00003oooooooooo`0Booooo`7o00000Oooool00003o`000?oooooooooo083ooooo00<0
0000ooooooooool0=?ooool5ool0odWooooo00<00000ooooooooool04oooool1o`00007ooooo0000
0ol0003oooooooooo`20ooooo`0300000?oooooooooo03Cooooo1Ooo0?m7ooooo`8000005_ooool1
o`00007ooooo00000ol0003oooooooooo`20ooooo`0300000?oooooooooo03Cooooo1Ooo0?m6oooo
o`0300000?oooooooooo01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0P?ooool00`00003o
ooooooooo`0eooooo`?oo`3oAOooool2000001Wooooo0Ol00001ooooo`0000?o0000ooooooooool0
P?ooool00`00003oooooooooo`1looooo`0300000?oooooooooo01Wooooo0Ol00001ooooo`0000?o
0000ooooooooool0P?ooool00`00003oooooooooo`1kooooo`0300000?oooooooooo01[ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0P?ooool00`00003oooooooooo`1iooooo`8000007Oooool1
o`00007ooooo00000ol0003oooooooooo`1oooooo`0300000?oooooooooo07Wooooo00<00000oooo
ooooool07Oooool1o`00007ooooo00000ol0003oooooooooo`1oooooo`0300000?oooooooooo07Oo
oooo0P00000Pooooo`7o00000Oooool00003o`000?oooooooooo07oooooo00<00000ooooooooool0
M_ooool00`00003oooooooooo`0Pooooo`7o00000Oooool00003o`000?oooooooooo07oooooo00<0
0000ooooooooool0MOooool00`00003oooooooooo`0Qooooo`7o00000Oooool00003o`000?oooooo
oooo07oooooo00<00000ooooooooool0Loooool2000002Cooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Ooooool00`00003oooooooooo`1booooo`0300000?oooooooooo02Cooooo0Ol00001oooo
o`0000?o0000ooooooooool0Ooooool00`00003oooooooooo`1`ooooo`8000009oooool1o`00007o
oooo00000ol0003oooooooooo`1oooooo`0300000?oooooooooo06oooooo00<00000ooooooooool0
9oooool1o`00007ooooo00000ol0003oooooooooo`1oooooo`0300000?oooooooooo06kooooo00<0
0000ooooooooool0:?ooool1o`00007ooooo00000ol0003oooooooooo`1oooooo`0300000?oooooo
oooo06cooooo0P00000[ooooo`7o00000Oooool00003o`000?oooooooooo07oooooo00<00000oooo
ooooool0Joooool00`00003oooooooooo`0[ooooo`7o00000Oooool00003o`000?oooooooooo07oo
oooo00<00000ooooooooool0JOooool2000002kooooo0Ol00001ooooo`0000?o0000ooooooooool0
O_ooool00`00003oooooooooo`1Yooooo`0300000?oooooooooo02kooooo0Ol00001ooooo`0000?o
0000ooooooooool0O_ooool00`00003oooooooooo`1Xooooo`0300000?oooooooooo02oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0O_ooool00`00003oooooooooo`1Vooooo`800000<_ooool1
o`00007ooooo00000ol0003oooooooooo`1nooooo`0300000?oooooooooo06Gooooo00<00000oooo
ooooool0<_ooool1o`00007ooooo00000ol0003oooooooooo`1nooooo`0300000?oooooooooo06?o
oooo0P00000eooooo`7o00000Oooool00003o`000?oooooooooo07kooooo00<00000ooooooooool0
H_ooool00`00003oooooooooo`0eooooo`7o00000Oooool00003o`000?oooooooooo07kooooo00<0
0000ooooooooool0HOooool00`00003oooooooooo`0fooooo`7o00000Oooool00003o`000?oooooo
oooo07kooooo00<00000ooooooooool0Goooool2000003Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0O_ooool00`00003oooooooooo`1Nooooo`0300000?oooooooooo03Wooooo0Ol00001oooo
o`0000?o0000ooooooooool0O_ooool00`00003oooooooooo`1Looooo`800000??ooool1o`00007o
oooo00000ol0003oooooooooo`1nooooo`0300000?oooooooooo05_ooooo00<00000ooooooooool0
??ooool1o`00007ooooo00000ol0003oooooooooo`1nooooo`0300000?oooooooooo05Wooooo0P00
000oooooo`7o00000Oooool00003o`000?oooooooooo07gooooo00<00000ooooooooool0FOooool0
0`00003oooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo07gooooo00<00000oooo
ooooool0F?ooool00`00003oooooooooo`10ooooo`7o00000Oooool00003o`000?oooooooooo07go
oooo00<00000ooooooooool0E_ooool2000004?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
OOooool00`00003oooooooooo`1Eooooo`0300000?oooooooooo04?ooooo0Ol00001ooooo`0000?o
0000ooooooooool0O?ooool00ol000000000o`00001Dooooo`800000A_ooool1o`00007ooooo0000
0ol0003oooooooooo`1dooooo`X0000000?o0000ooooooooool0DOooool00`00003oooooooooo`16
ooooo`7o00000Oooool00003o`000?oooooooooo06;ooooo4P000008ooooo`03o`000000003o0000
05;ooooo00<00000ooooooooool0Aoooool1o`00007ooooo00000ol0003oooooooooo`1?oooooa<0
00007?ooool00`00003oooooooooo`1>ooooo`800000B_ooool1o`00007ooooo00000ol0003ooooo
ooooo`0moooooa800000<?ooool00`00003oooooooooo`1<ooooo`0300000?oooooooooo04[ooooo
0Ol00001ooooo`0000?o0000ooooooooool0:ooooolB000004?ooooo00<00000ooooooooool0BOoo
ool2000004gooooo0Ol00001ooooo`0000?o0000ooooooooool06?oooolC000005Kooooo00<00000
ooooooooool0Aoooool00`00003oooooooooo`1=ooooo`7o00000Oooool00003o`000?oooooooooo
00Kooooo4P00001Yooooo`0300000?oooooooooo04Kooooo00<00000ooooooooool0C_ooool1o`00
007ooooo0009000007cooooo00<00000ooooooooool0@oooool20000057ooooo0Ol00001ooooo`00
00?o0000ooooooooool0Poooool00`00003oooooooooo`11ooooo`0300000?oooooooooo057ooooo
0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool00`00003oooooooooo`0nooooo`800000E?oo
ool1o`00007ooooo00000ol0003oooooooooo`25ooooo`0300000?oooooooooo03cooooo00<00000
ooooooooool0E?ooool1o`00007ooooo00000ol0003oooooooooo`25ooooo`0300000?oooooooooo
03_ooooo00<00000ooooooooool0EOooool1o`00007ooooo00000ol0003oooooooooo`26ooooo`03
00000?oooooooooo03Sooooo0P00001Hooooo`7o00000Oooool00003o`000?oooooooooo08Oooooo
00<00000ooooooooool0=_ooool00`00003oooooooooo`1Hooooo`7o00000Oooool00003o`000?oo
oooooooo08Sooooo00<00000ooooooooool0<oooool2000005_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0ROooool00`00003oooooooooo`0aooooo`0300000?oooooooooo05_ooooo0Ol00001
ooooo`0000?o0000ooooooooool0ROooool00`00003oooooooooo`0`ooooo`0300000?oooooooooo
05cooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool00`00003oooooooooo`0]ooooo`80
0000Goooool1o`00007ooooo00000ol0003oooooooooo`2;ooooo`0300000?oooooooooo02_ooooo
00<00000ooooooooool0Goooool1o`00007ooooo00000ol0003oooooooooo`2<ooooo`0300000?oo
oooooooo02Sooooo0P00001Rooooo`7o00000Oooool00003o`000?oooooooooo08gooooo00<00000
ooooooooool09_ooool00`00003oooooooooo`1Rooooo`7o00000Oooool00003o`000?oooooooooo
08gooooo00<00000ooooooooool09Oooool00`00003oooooooooo`1Sooooo`7o00000Oooool00003
o`000?oooooooooo08kooooo00<00000ooooooooool08_ooool2000006Kooooo0Ol00001ooooo`00
00?o0000ooooooooool0Soooool00`00003oooooooooo`0Pooooo`0300000?oooooooooo06Kooooo
0Ol00001ooooo`0000?o0000ooooooooool0T?ooool00`00003oooooooooo`0Mooooo`800000JOoo
ool1o`00007ooooo00000ol0003oooooooooo`2@ooooo`0300000?oooooooooo01cooooo00<00000
ooooooooool0JOooool1o`00007ooooo00000ol0003oooooooooo`2Aooooo`0300000?oooooooooo
01[ooooo00<00000ooooooooool0J_ooool1o`00007ooooo00000ol0003oooooooooo`2Booooo`03
00000?oooooooooo01Oooooo0P00001]ooooo`7o00000Oooool00003o`000?oooooooooo09?ooooo
00<00000ooooooooool05Oooool00`00003oooooooooo`1]ooooo`7o00000Oooool00003o`000?oo
oooooooo09Cooooo00<00000ooooooooool04_ooool20000073ooooo0Ol00001ooooo`0000?o0000
ooooooooool0U?ooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo073ooooo0Ol00001
ooooo`0000?o0000ooooooooool0UOooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
077ooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool00`00003oooooooooo`0<ooooo`80
0000M?ooool1o`00007ooooo00000ol0003oooooooooo`2Gooooo`0300000?oooooooooo00[ooooo
00<00000ooooooooool0M?ooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`0300000?oo
oooooooo00Oooooo0P000017ooooo`?oo`3o;Oooool1o`00007ooooo00000ol0003oooooooooo`2H
ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0A_ooool5ool0obcooooo0Ol00001
ooooo`0000?o0000ooooooooool0VOooool00`00003oooooooooo`04ooooo`0300000?oooooooooo
04Oooooo1Ooo0?l/ooooo`7o00000Oooool00003o`000?oooooooooo09[ooooo00@00000oooooooo
oooooooo0P00001:ooooo`Goo`3o;?ooool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03
00000?ooool0000004gooooo0ooo0?l]ooooo`7o00000Oooool00003o`000?oooooooooo09_ooooo
00?o000000000?l00000OOooool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`000000
003o000007gooooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool00ol000000000o`00001m
ooooo`7o00000Oooool00003o`000?oooooooooo09cooooo00<00000ooooooooool0O?ooool1o`00
007ooooo00000ol0003oooooooooo`2Looooo`0300000?oooooooooo07cooooo0Ol00001ooooo`00
00?o0000ooooooooool0WOooool00`00003oooooooooo`1kooooo`7o00000Oooool00003o`000?oo
oooooooo09gooooo00<00000ooooooooool0Noooool1o`00007ooooo00000ol0003oooooooooo`2M
ooooo`0300000?oooooooooo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0W?ooool00ol0
00000000o`00001looooo`7o00000Oooool00003o`000?oooooooooo04cooooo0ooo0?m=ooooo`<0
0000O?ooool1o`00007ooooo00000ol0003oooooooooo`1;ooooo`Goo`3oBoooool01@00003o0000
o`000?l00000000007_ooooo0Ol00001ooooo`0000?o0000ooooooooool0Boooool5ool0od[ooooo
00<00000ooooooooool00oooool00`00003oooooooooo`1hooooo`7o00000Oooool00003o`000?oo
oooooooo04_ooooo1Ooo0?m9ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0Mooo
ool1o`00007ooooo00000ol0003oooooooooo`1<ooooo`?oo`3oBOooool00`00003oooooooooo`07
ooooo`0300000?oooooooooo07Kooooo0Ol00001ooooo`0000?o0000ooooooooool0Uoooool00`00
003oooooooooo`09ooooo`0300000?oooooooooo07Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo07Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0UOooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo07?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00`00003oooooooooo`0?ooooo`0300000?oo
oooooooo07;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Toooool00`00003oooooooooo`0A
ooooo`800000L_ooool1o`00007ooooo00000ol0003oooooooooo`2Booooo`0300000?oooooooooo
01Cooooo00<00000ooooooooool0Koooool1o`00007ooooo0002000009;ooooo00<00000oooooooo
ool05_ooool00`00003oooooooooo`1^ooooo`7o00000Oooool00004o`000?ooool00000000008oo
oooo00<00000ooooooooool06?ooool00`00003oooooooooo`1]ooooo`7o00000Oooool00004o`00
0?ooooooooooooooo`800000S?ooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo06co
oooo0Ol00001ooooo`0000?o0000ooooooooool00oooool2000008Wooooo00<00000ooooooooool0
7?ooool00`00003oooooooooo`1[ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo0P00
0026ooooo`0300000?oooooooooo01kooooo00<00000ooooooooool0J_ooool1o`00007ooooo0000
0ol0003oooooooooo`07ooooo`0300000?oooooooooo08;ooooo00<00000ooooooooool08?ooool0
0`00003oooooooooo`1Yooooo`7o00000Oooool00003o`000?oooooooooo00Sooooo0P000021oooo
o`0300000?oooooooooo02;ooooo00<00000ooooooooool0J?ooool1o`00007ooooo00000ol0003o
ooooooooo`0:ooooo`800000O_ooool00`00003oooooooooo`0Tooooo`800000J?ooool1o`00007o
oooo00000ol0003oooooooooo`0<ooooo`800000Noooool00`00003oooooooooo`0Wooooo`030000
0?oooooooooo06Gooooo0Ol00001ooooo`0000?o0000ooooooooool03_ooool2000007Sooooo00<0
0000ooooooooool0:Oooool00`00003oooooooooo`1Tooooo`7o00000Oooool00003o`000?oooooo
oooo013ooooo0P00001eooooo`0300000?oooooooooo02_ooooo00<00000ooooooooool0Hoooool1
o`00007ooooo00000ol0003oooooooooo`0Booooo`800000L_ooool00`00003oooooooooo`0]oooo
o`0300000?oooooooooo06;ooooo0Ol00001ooooo`0000?o0000ooooooooool05?ooool2000006oo
oooo00<00000ooooooooool0;oooool00`00003oooooooooo`1Qooooo`7o00000Oooool00003o`00
0?oooooooooo01Kooooo0P00001/ooooo`0300000?oooooooooo037ooooo00<00000ooooooooool0
H?ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`800000JOooool00`00003ooooooooo
o`0cooooo`0300000?oooooooooo05oooooo0Ol00001ooooo`0000?o0000ooooooooool06_ooool0
0`00003oooooooooo`1Uooooo`0300000?oooooooooo03Gooooo00<00000ooooooooool0G_ooool1
o`00007ooooo00000ol0003oooooooooo`0Kooooo`800000I?ooool00`00003oooooooooo`0goooo
o`800000G_ooool1o`00007ooooo00000ol0003oooooooooo`0Mooooo`800000HOooool00`00003o
ooooooooo`0jooooo`0300000?oooooooooo05_ooooo0Ol00001ooooo`0000?o0000ooooooooool0
7oooool2000005kooooo00<00000ooooooooool0??ooool00`00003oooooooooo`1Jooooo`7o0000
0Oooool00003o`000?oooooooooo027ooooo0P00001Kooooo`0300000?oooooooooo03kooooo00<0
0000ooooooooool0FOooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`800000F?ooool0
0`00003oooooooooo`10ooooo`0300000?oooooooooo05Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool09Oooool2000005Gooooo00<00000ooooooooool0@_ooool00`00003oooooooooo`1Goooo
o`7o00000Oooool00003o`000?oooooooooo02Oooooo0P00001Booooo`0300000?oooooooooo04Co
oooo00<00000ooooooooool0E_ooool1o`00007ooooo00000ol0003oooooooooo`0Yooooo`800000
Coooool00`00003oooooooooo`16ooooo`0300000?oooooooooo05Gooooo0Ol00001ooooo`0000?o
0000ooooooooool0:oooool2000004cooooo00<00000ooooooooool0B?ooool00`00003ooooooooo
o`1Dooooo`7o00000Oooool00003o`000?oooooooooo02gooooo0P000019ooooo`0300000?oooooo
oooo04[ooooo00<00000ooooooooool0Doooool1o`00007ooooo00000ol0003oooooooooo`0_oooo
o`0300000?oooooooooo04Gooooo00<00000ooooooooool0C?ooool2000005?ooooo0Ol00001oooo
o`0000?o0000ooooooooool0<?ooool2000004Cooooo00<00000ooooooooool0Coooool00`00003o
ooooooooo`1@ooooo`7o00000Oooool00003o`000?oooooooooo03;ooooo0P000011ooooo`030000
0?oooooooooo057ooooo00<00000ooooooooool0Coooool1o`00007ooooo00000ol0003ooooooooo
o`0dooooo`800000?_ooool00`00003oooooooooo`1Cooooo`0300000?oooooooooo04kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0=_ooool2000003_ooooo00<00000ooooooooool0EOooool0
0`00003oooooooooo`1=ooooo`7o00000Oooool00003o`000?oooooooooo03Sooooo0P00000hoooo
o`0300000?oooooooooo05Oooooo00<00000ooooooooool0C?ooool1o`00007ooooo00000ol0003o
ooooooooo`0jooooo`800000=Oooool00`00003oooooooooo`1Iooooo`0300000?oooooooooo04_o
oooo0Ol00001ooooo`0000?o0000ooooooooool0??ooool2000003;ooooo00<00000ooooooooool0
Foooool00`00003oooooooooo`1:ooooo`7o00000Oooool00003o`000?oooooooooo03kooooo0P00
000_ooooo`0300000?oooooooooo05gooooo00<00000ooooooooool0A_ooool30000007o00000Ooo
ool00003o`000?oooooooooo043ooooo0P00000/ooooo`0300000?oooooooooo05oooooo0P00000o
ooooo`L000000oooool1o`00007ooooo00000ol0003oooooooooo`12ooooo`0300000?oooooooooo
02Sooooo00<00000ooooooooool0H_ooool00`00003oooooooooo`0fooooo`H000002_ooool1o`00
007ooooo00000ol0003oooooooooo`13ooooo`8000009oooool00`00003oooooooooo`1Tooooo`03
00000?oooooooooo02kooooo1`00000@ooooo`7o00000Oooool00003o`000?oooooooooo04Gooooo
0P00000Tooooo`0300000?oooooooooo06Kooooo00<00000ooooooooool09oooool6000001Oooooo
0Ol00001ooooo`0000?o0000ooooooooool0Aoooool20000027ooooo00<00000ooooooooool0J?oo
ool00`00003oooooooooo`0Oooooo`L000007Oooool1o`00007ooooo00000ol0003oooooooooo`19
ooooo`8000007_ooool00`00003oooooooooo`1Zooooo`0300000?oooooooooo01Sooooo1P00000T
ooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo0P00000Kooooo`0300000?oooooooooo
06cooooo00<00000ooooooooool04?ooool7000002[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0COooool2000001Sooooo00<00000ooooooooool0K_ooool00`00003oooooooooo`09ooooo`H0
0000<Oooool1o`00007ooooo00000ol0003oooooooooo`1?ooooo`8000005Oooool00`00003ooooo
ooooo`1`ooooo`0400000?l0003o0000ooooo`L00000=oooool1o`00007ooooo00000ol0003ooooo
ooooo`1Aooooo`8000004_ooool00`00003oooooooooo`1aooooo`04o`00000000000000000003ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0Doooool2000000oooooo00<00000ooooooooool0
L_ooool00ol000000000o`00000oooooo`7o00000Oooool00003o`000?oooooooooo05Gooooo00<0
0000ooooooooool02oooool00`00003oooooooooo`1cooooo`0300000?oooooooooo03oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0E_ooool2000000[ooooo00<00000ooooooooool0M?ooool0
0`00003oooooooooo`0oooooo`7o00000Oooool00003o`000?oooooooooo05Sooooo0P000007oooo
o`0300000?oooooooooo07Gooooo00<00000ooooooooool0?oooool1o`00007ooooo00000ol0003o
ooooooooo`1Jooooo`8000001?ooool00`00003oooooooooo`1eooooo`0300000?oooooooooo043o
oooo0Ol00001ooooo`0000?o0000ooooooooool0G?ooool200000003o`000000003ooooo07Oooooo
00<00000ooooooooool0@?ooool1o`00007ooooo00000ol0003oooooooooo`1Mooooo`03o`000000
003o000007Sooooo00<00000ooooooooool0@?ooool1o`00007ooooo00000ol0003oooooooooo`1M
ooooo`03o`000000003o000007Oooooo00<00000ooooooooool0@Oooool1o`00007ooooo00000ol0
003oooooooooo`1Mooooo`03o`000000003o000007Oooooo00<00000ooooooooool0@Oooool1o`00
007ooooo00000ol0003oooooooooo`1Mooooo`80000000?o0000ooooooooool0MOooool00`00003o
ooooooooo`11ooooo`7o00000Oooool00003o`000?oooooooooo05cooooo00@00000o`000000003o
0000M_ooool00`00003oooooooooo`12ooooo`7o00000Oooool00003o`000?oooooooooo05_ooooo
00D00000oooooooooooooooo0000001fooooo`0300000?oooooooooo04;ooooo0Ol00001ooooo`00
00?o0000ooooooooool0F_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo07Cooooo
00<00000ooooooooool0@_ooool1o`00007ooooo00000ol0003oooooooooo`1Iooooo`0300000?oo
oooooooo00Cooooo00<00000ooooooooool0L_ooool00`00003oooooooooo`13ooooo`7o00000Ooo
ool00003o`000?oooooooooo05Oooooo0P000007ooooo`0300000?oooooooooo07;ooooo00<00000
ooooooooool0@oooool1o`00007ooooo00000ol0003oooooooooo`1Fooooo`0300000?oooooooooo
00Sooooo00<00000ooooooooool0LOooool00`00003oooooooooo`13ooooo`7o00000Oooool00003
o`000?oooooooooo05Gooooo00<00000ooooooooool02Oooool00`00003oooooooooo`1`ooooo`03
00000?oooooooooo04Cooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool00`00003ooooo
ooooo`0:ooooo`0300000?oooooooooo073ooooo00<00000ooooooooool0A?ooool1o`00007ooooo
00000ol0003oooooooooo`1Booooo`8000003_ooool00`00003oooooooooo`1_ooooo`0300000?oo
oooooooo04Cooooo0Ol00001ooooo`0000?o0000ooooooooool0DOooool00`00003oooooooooo`0>
ooooo`0300000?oooooooooo06kooooo00<00000ooooooooool0AOooool1o`00007ooooo00000ol0
003oooooooooo`1@ooooo`0300000?oooooooooo013ooooo00<00000ooooooooool0KOooool00`00
003oooooooooo`15ooooo`7o00000Oooool00003o`000?oooooooooo04oooooo00<00000oooooooo
ool04Oooool00`00003oooooooooo`1]ooooo`0300000?oooooooooo04Gooooo0Ol00001ooooo`00
00?o0000ooooooooool0C_ooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo037ooooo
0ooo0?lgooooo`0300000?oooooooooo04Kooooo0Ol00001ooooo`0000?o0000ooooooooool0C?oo
ool2000001Kooooo00<00000ooooooooool0<?ooool5ool0ocKooooo00<00000ooooooooool0A_oo
ool1o`00007ooooo00000ol0003oooooooooo`0Rooooo`?oo`3o9_ooool00`00003oooooooooo`0G
ooooo`0300000?oooooooooo02oooooo1Ooo0?lfooooo`0300000?oooooooooo04Kooooo0Ol00001
ooooo`0000?o0000ooooooooool08Oooool5ool0obCooooo00<00000ooooooooool06?ooool00`00
003oooooooooo`0_ooooo`Goo`3o=Oooool00`00003oooooooooo`17ooooo`7o00000Oooool00003
o`000?oooooooooo027ooooo1Ooo0?lSooooo`0300000?oooooooooo01[ooooo00<00000oooooooo
ool0;oooool3ool0ocKooooo00<00000ooooooooool0Aoooool1o`00007ooooo00000ol0003ooooo
ooooo`0Qooooo`Goo`3o8_ooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo06Sooooo
00<00000ooooooooool0Aoooool1o`00007ooooo00000ol0003oooooooooo`0Rooooo`?oo`3o8Ooo
ool2000001kooooo00<00000ooooooooool0Ioooool00`00003oooooooooo`18ooooo`7o00000Ooo
ool00003o`000?oooooooooo04Gooooo00<00000ooooooooool07oooool00`00003oooooooooo`1V
ooooo`0300000?oooooooooo04Sooooo0Ol00001ooooo`0000?o0000ooooooooool0A?ooool00`00
003oooooooooo`0Pooooo`0300000?oooooooooo06Kooooo00<00000ooooooooool0B?ooool1o`00
007ooooo00000ol0003oooooooooo`13ooooo`0300000?oooooooooo02;ooooo00<00000oooooooo
ool0I?ooool00`00003oooooooooo`19ooooo`7o00000Oooool00003o`000?oooooooooo04;ooooo
00<00000ooooooooool08oooool00`00003oooooooooo`1Tooooo`0300000?oooooooooo04Wooooo
0Ol00001ooooo`0000?o0000ooooooooool0@?ooool2000002Oooooo00<00000ooooooooool0Hooo
ool00`00003oooooooooo`19ooooo`7o00000Oooool00003o`000?oooooooooo03oooooo00<00000
ooooooooool09oooool00`00003oooooooooo`1Rooooo`0300000?oooooooooo04[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0?_ooool00`00003oooooooooo`0Yooooo`0300000?oooooooooo
067ooooo00<00000ooooooooool0B_ooool1o`00007ooooo00000ol0003oooooooooo`0mooooo`03
00000?oooooooooo02[ooooo00<00000ooooooooool0HOooool00`00003oooooooooo`1:ooooo`7o
00000Oooool00003o`000?oooooooooo03_ooooo0P00000^ooooo`0300000?oooooooooo05oooooo
00<00000ooooooooool0Boooool1o`00007ooooo00000ol0003oooooooooo`0jooooo`0300000?oo
oooooooo02kooooo00<00000ooooooooool0Goooool00`00003oooooooooo`1;ooooo`7o00000Ooo
ool00003o`000?oooooooooo03Wooooo00<00000ooooooooool0;oooool00`00003oooooooooo`1O
ooooo`0300000?oooooooooo04_ooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool00`00
003oooooooooo`0aooooo`0300000?oooooooooo05gooooo00<00000ooooooooool0C?ooool1o`00
007ooooo00000ol0003oooooooooo`0gooooo`0300000?oooooooooo03;ooooo00<00000oooooooo
ool0GOooool00`00003oooooooooo`1<ooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo
0P00000fooooo`0300000?oooooooooo05cooooo00<00000ooooooooool0C?ooool1o`00007ooooo
00000ol0003oooooooooo`0dooooo`0300000?oooooooooo03Kooooo00<00000ooooooooool0Fooo
ool00`00003oooooooooo`1=ooooo`7o00000Oooool00003o`000?oooooooooo03?ooooo00<00000
ooooooooool0>?ooool00`00003oooooooooo`1Jooooo`0300000?oooooooooo04gooooo0Ol00001
ooooo`0000?o0000ooooooooool0<_ooool00`00003oooooooooo`0iooooo`0300000?oooooooooo
05[ooooo00<00000ooooooooool0COooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`03
00000?oooooooooo03_ooooo00<00000ooooooooool0F?ooool00`00003oooooooooo`1>ooooo`7o
00000Oooool00003o`000?oooooooooo02oooooo0P00000nooooo`0300000?oooooooooo05Sooooo
00<00000ooooooooool0C_ooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`0300000?oo
oooooooo03oooooo00<00000ooooooooool0Eoooool00`00003oooooooooo`1>ooooo`7o00000Ooo
ool00003o`000?oooooooooo02gooooo00<00000ooooooooool0@?ooool00`00003oooooooooo`1F
ooooo`0300000?oooooooooo04oooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`00
003oooooooooo`11ooooo`0300000?oooooooooo05Kooooo00<00000ooooooooool0Coooool1o`00
007ooooo00000ol0003oooooooooo`0Zooooo`800000AOooool00`00003oooooooooo`1Eooooo`03
00000?oooooooooo04oooooo0Ol00001ooooo`0000?o0000ooooooooool0:Oooool00`00003ooooo
ooooo`15ooooo`0300000?oooooooooo05Cooooo00<00000ooooooooool0D?ooool1o`00007ooooo
00000ol0003oooooooooo`0Xooooo`0300000?oooooooooo04Oooooo00<00000ooooooooool0Dooo
ool00`00003oooooooooo`1@ooooo`7o00000Oooool00003o`000?oooooooooo02Oooooo00<00000
ooooooooool0B?ooool00`00003oooooooooo`1Cooooo`0300000?oooooooooo053ooooo0Ol00001
ooooo`0000?o0000ooooooooool09_ooool00`00003oooooooooo`1:ooooo`0300000?oooooooooo
057ooooo00<00000ooooooooool0DOooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`80
0000COooool00`00003oooooooooo`1Aooooo`0300000?oooooooooo03?ooooo0ooo0?lKooooo`7o
00000Oooool00003o`000?oooooooooo02?ooooo00<00000ooooooooool0C_ooool00`00003ooooo
ooooo`1@ooooo`0300000?oooooooooo03;ooooo1Ooo0?lJooooo`7o00000Oooool00003o`000?oo
oooooooo02;ooooo00<00000ooooooooool0Coooool00`00003oooooooooo`1?ooooo`0300000?oo
oooooooo03?ooooo1Ooo0?lJooooo`7o00000Oooool00003o`000?oooooooooo027ooooo00<00000
ooooooooool0DOooool00`00003oooooooooo`1>ooooo`0300000?oooooooooo03?ooooo1Ooo0?lJ
ooooo`7o00000Oooool00003o`000?oooooooooo023ooooo00<00000ooooooooool0D_ooool00`00
003oooooooooo`1>ooooo`0300000?oooooooooo03Cooooo0ooo0?lKooooo`7o00000Oooool00003
o`000?oooooooooo01kooooo0P00000Qooooo`?oo`3o<Oooool00`00003oooooooooo`1=ooooo`03
00000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000ooooooooool07Oooool00`00003ooooo
ooooo`0Pooooo`Goo`3o<Oooool00`00003oooooooooo`1<ooooo`0300000?oooooooooo05?ooooo
0Ol00001ooooo`0000?o0000ooooooooool07?ooool00`00003oooooooooo`0Qooooo`Goo`3o<Ooo
ool00`00003oooooooooo`1<ooooo`0300000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000
ooooooooool06oooool00`00003oooooooooo`0Rooooo`Goo`3o<_ooool00`00003oooooooooo`1:
ooooo`0300000?oooooooooo05Cooooo0Ol00001ooooo`0000?o0000ooooooooool06_ooool00`00
003oooooooooo`0Tooooo`?oo`3o<oooool00`00003oooooooooo`1:ooooo`0300000?oooooooooo
05Cooooo0Ol00001ooooo`0000?o0000ooooooooool06?ooool2000005kooooo00<00000oooooooo
ool0BOooool00`00003oooooooooo`1Dooooo`7o00000Oooool00003o`000?oooooooooo01Oooooo
00<00000ooooooooool0G_ooool00`00003oooooooooo`18ooooo`0300000?oooooooooo05Gooooo
0Ol00001ooooo`0000?o0000ooooooooool05_ooool00`00003oooooooooo`1Pooooo`0300000?oo
oooooooo04Oooooo00<00000ooooooooool0EOooool1o`00007ooooo00000ol0003oooooooooo`0E
ooooo`0300000?oooooooooo067ooooo00<00000ooooooooool0Aoooool00`00003oooooooooo`1E
ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo0P00001Uooooo`0300000?oooooooooo
04Gooooo00<00000ooooooooool0E_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03
00000?oooooooooo06Gooooo00<00000ooooooooool0AOooool00`00003oooooooooo`1Fooooo`7o
00000Oooool00003o`000?oooooooooo017ooooo00<00000ooooooooool0I_ooool00`00003ooooo
ooooo`15ooooo`0300000?oooooooooo05Kooooo0Ol00001ooooo`0000?o0000ooooooooool04?oo
ool00`00003oooooooooo`1Xooooo`0300000?oooooooooo04?ooooo00<00000ooooooooool0Eooo
ool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`0300000?oooooooooo06Wooooo00<00000
ooooooooool0@oooool00`00003oooooooooo`1Gooooo`7o00000Oooool00003o`000?oooooooooo
00kooooo00<00000ooooooooool0Joooool00`00003oooooooooo`12ooooo`0300000?oooooooooo
05Oooooo0Ol00001ooooo`0000?o0000ooooooooool0O?ooool00`00003oooooooooo`11ooooo`03
00000?oooooooooo05Sooooo0Ol00001ooooo`0000?o0000ooooooooool0OOooool00`00003ooooo
ooooo`10ooooo`0300000?oooooooooo05Sooooo0Ol00001ooooo`0000?o0000ooooooooool0OOoo
ool00`00003oooooooooo`10ooooo`0300000?oooooooooo05Sooooo0Ol00001ooooo`0000?o0000
ooooooooool0O_ooool00`00003oooooooooo`0nooooo`0300000?oooooooooo05Wooooo0Ol00001
ooooo`0000?o0000ooooooooool0O_ooool00`00003oooooooooo`0nooooo`0300000?oooooooooo
05Wooooo0Ol00001ooooo`0000?o0000ooooooooool0Ooooool00`00003oooooooooo`0mooooo`03
00000?oooooooooo05Wooooo0Ol00001ooooo`0000?o0000ooooooooool0Ooooool00`00003ooooo
ooooo`0looooo`0300000?oooooooooo05[ooooo0Ol00001ooooo`0000?o0000ooooooooool0Oooo
ool00`00003oooooooooo`0looooo`0300000?oooooooooo05[ooooo0Ol00001ooooo`0000?o0000
ooooooooool0P?ooool00`00003oooooooooo`0kooooo`0300000?oooooooooo05[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0P?ooool00`00003oooooooooo`0jooooo`0300000?oooooooooo
05_ooooo0Ol00001ooooo`0000?o0000ooooooooool0POooool00`00003oooooooooo`0iooooo`03
00000?oooooooooo05_ooooo0Ol00001ooooo`0000?o0000ooooooooool0POooool00`00003ooooo
ooooo`0iooooo`0300000?oooooooooo05_ooooo0Ol00001ooooo`0000?o0000ooooooooool0P_oo
ool00`00003oooooooooo`0gooooo`0300000?oooooooooo05cooooo0Ol00001ooooo`0000?o0000
ooooooooool0P_ooool00`00003oooooooooo`0gooooo`0300000?oooooooooo05cooooo0Ol00001
ooooo`0000?o0000ooooooooool0Poooool00`00003oooooooooo`0fooooo`0300000?oooooooooo
05cooooo0Ol00001ooooo`0000?o0000ooooooooool0Poooool00`00003oooooooooo`0eooooo`03
00000?oooooooooo05gooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?ooool00`00003ooooo
ooooo`0dooooo`0300000?oooooooooo05gooooo0Ol00001ooooo`0000?o0000ooooooooool0Q?oo
ool00`00003oooooooooo`0dooooo`0300000?oooooooooo05gooooo0Ol00001ooooo`0000?o0000
ooooooooool0Q?ooool00`00003oooooooooo`0cooooo`0300000?oooooooooo05kooooo0Ol00001
ooooo`0000?o0000ooooooooool0QOooool00`00003oooooooooo`0booooo`0300000?oooooooooo
05kooooo0Ol00001ooooo`0000?o0000ooooooooool0QOooool00`00003oooooooooo`0booooo`03
00000?oooooooooo05kooooo0Ol00001ooooo`00ROl000000`00003o0000o`00000`o`0000030000
0?l0003o0000063o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.00088, -1.00088, 0.00697479, \
0.00697479}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New histograms for two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Compute histograms based on data-dependent centroids", "Subsubsection"],

Cell[BoxData[{
    \(\(h1\  = Histogram[data1, vqCentroids, pr, 50];\)\), "\n", 
    \(\(h2\  = Histogram[data2, vqCentroids, pr, 50];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize two histograms", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gh1\  = 
        DrawHistogram[h1, pr, \ nS, \ 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(gh2\  = 
        DrawHistogram[h2, pr, \ nS, \ 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gh1, gh2}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
%%ImageSize: 400 154.502 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.657 .75 .918 r
.39602 .67958 .40228 .68511 .41276 .68212 .40653 .67657 Mtetra
.40653 .67657 .41276 .68212 .42328 .67912 .41707 .67355 Mtetra
.41707 .67355 .42328 .67912 .43385 .67611 .42767 .67052 Mtetra
.42767 .67052 .43385 .67611 .44445 .67309 .4383 .66747 Mtetra
.4383 .66747 .44445 .67309 .4551 .67005 .44897 .66442 Mtetra
.44897 .66442 .4551 .67005 .46579 .667 .45969 .66135 Mtetra
.45969 .66135 .46579 .667 .47652 .66395 .47045 .65827 Mtetra
.47045 .65827 .47652 .66395 .4873 .66087 .48125 .65517 Mtetra
.48125 .65517 .4873 .66087 .49811 .65779 .49209 .65207 Mtetra
.49209 .65207 .49811 .65779 .50897 .6547 .50298 .64895 Mtetra
.50298 .64895 .50897 .6547 .51988 .65159 .51391 .64582 Mtetra
.51391 .64582 .51988 .65159 .53082 .64847 .52489 .64268 Mtetra
.52489 .64268 .53082 .64847 .54181 .64534 .53591 .63952 Mtetra
.53591 .63952 .54181 .64534 .55285 .64219 .54697 .63635 Mtetra
.54697 .63635 .55285 .64219 .56392 .63903 .55808 .63317 Mtetra
.55808 .63317 .56392 .63903 .57505 .63586 .56923 .62998 Mtetra
.56923 .62998 .57505 .63586 .58621 .63268 .58043 .62677 Mtetra
.58043 .62677 .58621 .63268 .59743 .62949 .59167 .62355 Mtetra
.59167 .62355 .59743 .62949 .60868 .62628 .60296 .62032 Mtetra
.60296 .62032 .60868 .62628 .61999 .62305 .61429 .61707 Mtetra
.61429 .61707 .61999 .62305 .63134 .61982 .62567 .61381 Mtetra
.62567 .61381 .63134 .61982 .64273 .61657 .6371 .61054 Mtetra
.6371 .61054 .64273 .61657 .65417 .61331 .64857 .60726 Mtetra
.948 .591 .27 r
.64857 .60726 .65417 .61331 .66804 .66803 .66238 .66206 Mtetra
.652 .756 .925 r
.66238 .66206 .66804 .66803 .67978 .6648 .67415 .65882 Mtetra
.67415 .65882 .67978 .6648 .69156 .66157 .68597 .65556 Mtetra
.68597 .65556 .69156 .66157 .70339 .65832 .69784 .65228 Mtetra
.69784 .65228 .70339 .65832 .71528 .65505 .70976 .64899 Mtetra
.70976 .64899 .71528 .65505 .72721 .65178 .72173 .64569 Mtetra
.72173 .64569 .72721 .65178 .73919 .64848 .73374 .64237 Mtetra
.73374 .64237 .73919 .64848 .75123 .64518 .74581 .63904 Mtetra
.74581 .63904 .75123 .64518 .76331 .64186 .75793 .6357 Mtetra
.75793 .6357 .76331 .64186 .77205 .59151 .77011 .63234 Mtetra
0 0 .316 r
.77011 .63234 .77205 .59151 .78406 .58811 .77881 .5818 Mtetra
.656 .751 .92 r
.77881 .5818 .78406 .58811 .79612 .5847 .79091 .57836 Mtetra
.79091 .57836 .79612 .5847 .80824 .58127 .80306 .5749 Mtetra
.80306 .5749 .80824 .58127 .82041 .57783 .81527 .57143 Mtetra
.81527 .57143 .82041 .57783 .83262 .57437 .82752 .56795 Mtetra
.82752 .56795 .83262 .57437 .84489 .5709 .83983 .56445 Mtetra
.83983 .56445 .84489 .5709 .85721 .56741 .85219 .56093 Mtetra
.85219 .56093 .85721 .56741 .86959 .56391 .8646 .55741 Mtetra
.8646 .55741 .86959 .56391 .88201 .56039 .87706 .55386 Mtetra
.87706 .55386 .88201 .56039 .89449 .55686 .88958 .5503 Mtetra
.88958 .5503 .89449 .55686 .90702 .55332 .90215 .54673 Mtetra
.90215 .54673 .90702 .55332 .91961 .54975 .91477 .54314 Mtetra
.91477 .54314 .91961 .54975 .93225 .54618 .92745 .53953 Mtetra
.92745 .53953 .93225 .54618 .94494 .54258 .94019 .53591 Mtetra
.94019 .53591 .94494 .54258 .95769 .53898 .95298 .53228 Mtetra
.95298 .53228 .95769 .53898 .9705 .53535 .96582 .52862 Mtetra
.96582 .52862 .9705 .53535 .98335 .53172 .97872 .52496 Mtetra
0 0 .444 r
.39287 .59231 .39602 .67958 .40653 .67657 .40025 .67099 Mtetra
.657 .75 .918 r
.40025 .67099 .40653 .67657 .41707 .67355 .41082 .66794 Mtetra
.41082 .66794 .41707 .67355 .42767 .67052 .42144 .66489 Mtetra
.42144 .66489 .42767 .67052 .4383 .66747 .4321 .66182 Mtetra
.4321 .66182 .4383 .66747 .44897 .66442 .4428 .65874 Mtetra
.4428 .65874 .44897 .66442 .45969 .66135 .45354 .65565 Mtetra
.45354 .65565 .45969 .66135 .47045 .65827 .46433 .65255 Mtetra
.46433 .65255 .47045 .65827 .48125 .65517 .47516 .64943 Mtetra
.47516 .64943 .48125 .65517 .49209 .65207 .48603 .6463 Mtetra
.48603 .6463 .49209 .65207 .50298 .64895 .49695 .64316 Mtetra
.49695 .64316 .50298 .64895 .51391 .64582 .5079 .64001 Mtetra
.5079 .64001 .51391 .64582 .52489 .64268 .51891 .63684 Mtetra
.51891 .63684 .52489 .64268 .53591 .63952 .52996 .63366 Mtetra
.52996 .63366 .53591 .63952 .54697 .63635 .54105 .63047 Mtetra
.54105 .63047 .54697 .63635 .55808 .63317 .55219 .62727 Mtetra
.55219 .62727 .55808 .63317 .56923 .62998 .56337 .62405 Mtetra
.56337 .62405 .56923 .62998 .58043 .62677 .57459 .62082 Mtetra
.57459 .62082 .58043 .62677 .59167 .62355 .58587 .61757 Mtetra
.58587 .61757 .59167 .62355 .60296 .62032 .59719 .61432 Mtetra
.59719 .61432 .60296 .62032 .61429 .61707 .60855 .61105 Mtetra
.60855 .61105 .61429 .61707 .62567 .61381 .61996 .60776 Mtetra
.61996 .60776 .62567 .61381 .6371 .61054 .63142 .60446 Mtetra
.63142 .60446 .6371 .61054 .64857 .60726 .64293 .60115 Mtetra
.948 .591 .27 r
.64293 .60115 .64857 .60726 .66238 .66206 .65669 .65606 Mtetra
.652 .756 .925 r
.65669 .65606 .66238 .66206 .67415 .65882 .66849 .65279 Mtetra
.66849 .65279 .67415 .65882 .68597 .65556 .68034 .6495 Mtetra
.68034 .6495 .68597 .65556 .69784 .65228 .69224 .6462 Mtetra
.69224 .6462 .69784 .65228 .70976 .64899 .70419 .64288 Mtetra
.70419 .64288 .70976 .64899 .72173 .64569 .7162 .63956 Mtetra
.7162 .63956 .72173 .64569 .73374 .64237 .72825 .63621 Mtetra
.72825 .63621 .73374 .64237 .74581 .63904 .74036 .63286 Mtetra
.74036 .63286 .74581 .63904 .75793 .6357 .75251 .62949 Mtetra
.75251 .62949 .75793 .6357 .77011 .63234 .76472 .6261 Mtetra
.959 .755 .583 r
.76472 .6261 .77011 .63234 .77881 .5818 .77352 .57543 Mtetra
.656 .751 .92 r
.77352 .57543 .77881 .5818 .79091 .57836 .78566 .57197 Mtetra
.78566 .57197 .79091 .57836 .80306 .5749 .79785 .56848 Mtetra
.79785 .56848 .80306 .5749 .81527 .57143 .81009 .56499 Mtetra
.81009 .56499 .81527 .57143 .82752 .56795 .82238 .56148 Mtetra
.82238 .56148 .82752 .56795 .83983 .56445 .83472 .55795 Mtetra
.83472 .55795 .83983 .56445 .85219 .56093 .84712 .55441 Mtetra
.84712 .55441 .85219 .56093 .8646 .55741 .85957 .55085 Mtetra
.85957 .55085 .8646 .55741 .87706 .55386 .87207 .54728 Mtetra
.87207 .54728 .87706 .55386 .88958 .5503 .88463 .54369 Mtetra
.88463 .54369 .88958 .5503 .90215 .54673 .89724 .54009 Mtetra
.89724 .54009 .90215 .54673 .91477 .54314 .9099 .53647 Mtetra
.9099 .53647 .91477 .54314 .92745 .53953 .92262 .53284 Mtetra
.92262 .53284 .92745 .53953 .94019 .53591 .9354 .52919 Mtetra
.9354 .52919 .94019 .53591 .95298 .53228 .94823 .52552 Mtetra
.94823 .52552 .95298 .53228 .96582 .52862 .96111 .52184 Mtetra
.96111 .52184 .96582 .52862 .97872 .52496 .97405 .51814 Mtetra
.664 .741 .908 r
.38668 .58654 .39287 .59231 .40025 .67099 .397 .5834 Mtetra
0 0 .444 r
.397 .5834 .40025 .67099 .41082 .66794 .40452 .66229 Mtetra
.657 .75 .918 r
.40452 .66229 .41082 .66794 .42144 .66489 .41517 .65922 Mtetra
.41517 .65922 .42144 .66489 .4321 .66182 .42585 .65613 Mtetra
.42585 .65613 .4321 .66182 .4428 .65874 .43658 .65302 Mtetra
.43658 .65302 .4428 .65874 .45354 .65565 .44735 .64991 Mtetra
.44735 .64991 .45354 .65565 .46433 .65255 .45816 .64678 Mtetra
.45816 .64678 .46433 .65255 .47516 .64943 .46902 .64364 Mtetra
.46902 .64364 .47516 .64943 .48603 .6463 .47992 .64049 Mtetra
.47992 .64049 .48603 .6463 .49695 .64316 .49087 .63733 Mtetra
.49087 .63733 .49695 .64316 .5079 .64001 .50185 .63415 Mtetra
.50185 .63415 .5079 .64001 .51891 .63684 .51289 .63096 Mtetra
.51289 .63096 .51891 .63684 .52996 .63366 .52396 .62776 Mtetra
.52396 .62776 .52996 .63366 .54105 .63047 .53508 .62454 Mtetra
.53508 .62454 .54105 .63047 .55219 .62727 .54625 .62131 Mtetra
.54625 .62131 .55219 .62727 .56337 .62405 .55746 .61807 Mtetra
.55746 .61807 .56337 .62405 .57459 .62082 .56872 .61482 Mtetra
.56872 .61482 .57459 .62082 .58587 .61757 .58002 .61155 Mtetra
.58002 .61155 .58587 .61757 .59719 .61432 .59137 .60827 Mtetra
.59137 .60827 .59719 .61432 .60855 .61105 .60277 .60497 Mtetra
.60277 .60497 .60855 .61105 .61996 .60776 .61421 .60166 Mtetra
.61421 .60166 .61996 .60776 .63142 .60446 .6257 .59834 Mtetra
.948 .593 .277 r
.6257 .59834 .63142 .60446 .64293 .60115 .63915 .65329 Mtetra
.542 .294 .489 r
.63915 .65329 .64293 .60115 .65669 .65606 .65094 .65001 Mtetra
.652 .756 .925 r
.65094 .65001 .65669 .65606 .66849 .65279 .66278 .64671 Mtetra
.66278 .64671 .66849 .65279 .68034 .6495 .67466 .64339 Mtetra
.67466 .64339 .68034 .6495 .69224 .6462 .6866 .64007 Mtetra
.6866 .64007 .69224 .6462 .70419 .64288 .69859 .63673 Mtetra
.69859 .63673 .70419 .64288 .7162 .63956 .71063 .63337 Mtetra
.71063 .63337 .7162 .63956 .72825 .63621 .72272 .63 Mtetra
.72272 .63 .72825 .63621 .74036 .63286 .73486 .62662 Mtetra
.73486 .62662 .74036 .63286 .75251 .62949 .74705 .62322 Mtetra
.74705 .62322 .75251 .62949 .76472 .6261 .75929 .61981 Mtetra
.959 .755 .583 r
.75929 .61981 .76472 .6261 .77352 .57543 .76819 .56902 Mtetra
.656 .751 .92 r
.76819 .56902 .77352 .57543 .78566 .57197 .78037 .56553 Mtetra
.78037 .56553 .78566 .57197 .79785 .56848 .79259 .56202 Mtetra
.79259 .56202 .79785 .56848 .81009 .56499 .80487 .55849 Mtetra
.80487 .55849 .81009 .56499 .82238 .56148 .81719 .55495 Mtetra
.81719 .55495 .82238 .56148 .83472 .55795 .82958 .5514 Mtetra
.82958 .5514 .83472 .55795 .84712 .55441 .84201 .54783 Mtetra
.84201 .54783 .84712 .55441 .85957 .55085 .8545 .54424 Mtetra
.8545 .54424 .85957 .55085 .87207 .54728 .86704 .54064 Mtetra
.86704 .54064 .87207 .54728 .88463 .54369 .87964 .53703 Mtetra
.87964 .53703 .88463 .54369 .89724 .54009 .89229 .5334 Mtetra
.89229 .5334 .89724 .54009 .9099 .53647 .90499 .52975 Mtetra
.90499 .52975 .9099 .53647 .92262 .53284 .91775 .52609 Mtetra
.91775 .52609 .92262 .53284 .9354 .52919 .93057 .52241 Mtetra
.93057 .52241 .9354 .52919 .94823 .52552 .94344 .51871 Mtetra
.94344 .51871 .94823 .52552 .96111 .52184 .95636 .515 Mtetra
.95636 .515 .96111 .52184 .97405 .51814 .96935 .51127 Mtetra
.664 .741 .908 r
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40452 .66229 .40117 .5744 Mtetra
.586 .402 .599 r
.40117 .5744 .40452 .66229 .41517 .65922 .4116 .57122 Mtetra
0 0 .449 r
.4116 .57122 .41517 .65922 .42585 .65613 .41956 .65039 Mtetra
.657 .75 .918 r
.41956 .65039 .42585 .65613 .43658 .65302 .43032 .64727 Mtetra
.43032 .64727 .43658 .65302 .44735 .64991 .44111 .64413 Mtetra
.44111 .64413 .44735 .64991 .45816 .64678 .45195 .64098 Mtetra
.45195 .64098 .45816 .64678 .46902 .64364 .46284 .63782 Mtetra
.46284 .63782 .46902 .64364 .47992 .64049 .47377 .63464 Mtetra
.47377 .63464 .47992 .64049 .49087 .63733 .48474 .63145 Mtetra
.48474 .63145 .49087 .63733 .50185 .63415 .49576 .62825 Mtetra
.49576 .62825 .50185 .63415 .51289 .63096 .50682 .62504 Mtetra
.50682 .62504 .51289 .63096 .52396 .62776 .51792 .62181 Mtetra
.51792 .62181 .52396 .62776 .53508 .62454 .52907 .61857 Mtetra
.52907 .61857 .53508 .62454 .54625 .62131 .54027 .61532 Mtetra
.54027 .61532 .54625 .62131 .55746 .61807 .55151 .61205 Mtetra
.55151 .61205 .55746 .61807 .56872 .61482 .5628 .60877 Mtetra
.5628 .60877 .56872 .61482 .58002 .61155 .57413 .60548 Mtetra
.57413 .60548 .58002 .61155 .59137 .60827 .58551 .60217 Mtetra
.58551 .60217 .59137 .60827 .60277 .60497 .59694 .59885 Mtetra
.59694 .59885 .60277 .60497 .61421 .60166 .60842 .59552 Mtetra
.60842 .59552 .61421 .60166 .6257 .59834 .61994 .59217 Mtetra
.948 .593 .277 r
.61994 .59217 .6257 .59834 .63915 .65329 .63333 .64722 Mtetra
.652 .756 .925 r
.63333 .64722 .63915 .65329 .65094 .65001 .64515 .64391 Mtetra
.64515 .64391 .65094 .65001 .66278 .64671 .65702 .64058 Mtetra
.65702 .64058 .66278 .64671 .67466 .64339 .66894 .63724 Mtetra
.66894 .63724 .67466 .64339 .6866 .64007 .68092 .63389 Mtetra
.68092 .63389 .6866 .64007 .69859 .63673 .69294 .63052 Mtetra
.69294 .63052 .69859 .63673 .71063 .63337 .70501 .62714 Mtetra
.70501 .62714 .71063 .63337 .72272 .63 .71714 .62375 Mtetra
.71714 .62375 .72272 .63 .73486 .62662 .72931 .62034 Mtetra
.72931 .62034 .73486 .62662 .74705 .62322 .74154 .61691 Mtetra
.74154 .61691 .74705 .62322 .75929 .61981 .75382 .61347 Mtetra
.75382 .61347 .75929 .61981 .76819 .56902 .76616 .61002 Mtetra
0 0 .305 r
.76616 .61002 .76819 .56902 .78037 .56553 .77503 .55904 Mtetra
.656 .751 .92 r
.77503 .55904 .78037 .56553 .79259 .56202 .78729 .5555 Mtetra
.78729 .5555 .79259 .56202 .80487 .55849 .7996 .55195 Mtetra
.7996 .55195 .80487 .55849 .81719 .55495 .81197 .54838 Mtetra
.81197 .54838 .81719 .55495 .82958 .5514 .82439 .5448 Mtetra
.82439 .5448 .82958 .5514 .84201 .54783 .83686 .5412 Mtetra
.83686 .5412 .84201 .54783 .8545 .54424 .84939 .53759 Mtetra
.84939 .53759 .8545 .54424 .86704 .54064 .86197 .53396 Mtetra
.86197 .53396 .86704 .54064 .87964 .53703 .8746 .53031 Mtetra
.8746 .53031 .87964 .53703 .89229 .5334 .88729 .52665 Mtetra
.88729 .52665 .89229 .5334 .90499 .52975 .90004 .52297 Mtetra
.90004 .52297 .90499 .52975 .91775 .52609 .91284 .51928 Mtetra
.91284 .51928 .91775 .52609 .93057 .52241 .9257 .51557 Mtetra
.9257 .51557 .93057 .52241 .94344 .51871 .93861 .51185 Mtetra
.93861 .51185 .94344 .51871 .95636 .515 .95158 .50811 Mtetra
.95158 .50811 .95636 .515 .96935 .51127 .9646 .50435 Mtetra
.664 .741 .908 r
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .41956 .65039 .41588 .56208 Mtetra
0 0 .449 r
.41588 .56208 .41956 .65039 .43032 .64727 .42401 .64146 Mtetra
.657 .75 .918 r
.42401 .64146 .43032 .64727 .44111 .64413 .43483 .6383 Mtetra
.43483 .6383 .44111 .64413 .45195 .64098 .4457 .63513 Mtetra
.4457 .63513 .45195 .64098 .46284 .63782 .45661 .63194 Mtetra
.45661 .63194 .46284 .63782 .47377 .63464 .46757 .62875 Mtetra
.46757 .62875 .47377 .63464 .48474 .63145 .47857 .62553 Mtetra
.47857 .62553 .48474 .63145 .49576 .62825 .48961 .62231 Mtetra
.48961 .62231 .49576 .62825 .50682 .62504 .5007 .61907 Mtetra
.5007 .61907 .50682 .62504 .51792 .62181 .51184 .61582 Mtetra
.51184 .61582 .51792 .62181 .52907 .61857 .52302 .61256 Mtetra
.52302 .61256 .52907 .61857 .54027 .61532 .53425 .60928 Mtetra
.53425 .60928 .54027 .61532 .55151 .61205 .54552 .60599 Mtetra
.54552 .60599 .55151 .61205 .5628 .60877 .55684 .60268 Mtetra
.55684 .60268 .5628 .60877 .57413 .60548 .5682 .59937 Mtetra
.5682 .59937 .57413 .60548 .58551 .60217 .57961 .59603 Mtetra
.57961 .59603 .58551 .60217 .59694 .59885 .59107 .59269 Mtetra
.59107 .59269 .59694 .59885 .60842 .59552 .60258 .58933 Mtetra
.949 .595 .284 r
.60258 .58933 .60842 .59552 .61994 .59217 .61566 .64442 Mtetra
.539 .289 .485 r
.61566 .64442 .61994 .59217 .63333 .64722 .62747 .64109 Mtetra
.652 .756 .925 r
.62747 .64109 .63333 .64722 .64515 .64391 .63932 .63776 Mtetra
.63932 .63776 .64515 .64391 .65702 .64058 .65122 .63441 Mtetra
.65122 .63441 .65702 .64058 .66894 .63724 .66318 .63104 Mtetra
.66318 .63104 .66894 .63724 .68092 .63389 .67519 .62766 Mtetra
.67519 .62766 .68092 .63389 .69294 .63052 .68724 .62427 Mtetra
.68724 .62427 .69294 .63052 .70501 .62714 .69935 .62086 Mtetra
.69935 .62086 .70501 .62714 .71714 .62375 .71151 .61744 Mtetra
.71151 .61744 .71714 .62375 .72931 .62034 .72372 .614 Mtetra
.72372 .614 .72931 .62034 .74154 .61691 .73599 .61055 Mtetra
.73599 .61055 .74154 .61691 .75382 .61347 .74831 .60709 Mtetra
.74831 .60709 .75382 .61347 .76616 .61002 .76068 .6036 Mtetra
.961 .755 .581 r
.76068 .6036 .76616 .61002 .77503 .55904 .76965 .55249 Mtetra
.656 .751 .92 r
.76965 .55249 .77503 .55904 .78729 .5555 .78195 .54893 Mtetra
.78195 .54893 .78729 .5555 .7996 .55195 .7943 .54535 Mtetra
.7943 .54535 .7996 .55195 .81197 .54838 .80671 .54175 Mtetra
.80671 .54175 .81197 .54838 .82439 .5448 .81916 .53814 Mtetra
.81916 .53814 .82439 .5448 .83686 .5412 .83167 .53452 Mtetra
.83167 .53452 .83686 .5412 .84939 .53759 .84424 .53087 Mtetra
.84424 .53087 .84939 .53759 .86197 .53396 .85686 .52722 Mtetra
.85686 .52722 .86197 .53396 .8746 .53031 .86953 .52354 Mtetra
.86953 .52354 .8746 .53031 .88729 .52665 .88226 .51985 Mtetra
.88226 .51985 .88729 .52665 .90004 .52297 .89505 .51615 Mtetra
.89505 .51615 .90004 .52297 .91284 .51928 .90789 .51242 Mtetra
.90789 .51242 .91284 .51928 .9257 .51557 .92079 .50868 Mtetra
.92079 .50868 .9257 .51557 .93861 .51185 .93374 .50493 Mtetra
.93374 .50493 .93861 .51185 .95158 .50811 .94675 .50116 Mtetra
.94675 .50116 .95158 .50811 .9646 .50435 .95982 .49737 Mtetra
.664 .741 .908 r
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.40966 .5561 .41588 .56208 .42401 .64146 .42022 .55284 Mtetra
0 0 .449 r
.42022 .55284 .42401 .64146 .43483 .6383 .4285 .63244 Mtetra
.657 .75 .918 r
.4285 .63244 .43483 .6383 .4457 .63513 .4394 .62924 Mtetra
.4394 .62924 .4457 .63513 .45661 .63194 .45034 .62603 Mtetra
.45034 .62603 .45661 .63194 .46757 .62875 .46132 .62281 Mtetra
.46132 .62281 .46757 .62875 .47857 .62553 .47235 .61957 Mtetra
.47235 .61957 .47857 .62553 .48961 .62231 .48342 .61632 Mtetra
.48342 .61632 .48961 .62231 .5007 .61907 .49454 .61306 Mtetra
.49454 .61306 .5007 .61907 .51184 .61582 .50571 .60978 Mtetra
.50571 .60978 .51184 .61582 .52302 .61256 .51692 .6065 Mtetra
.51692 .6065 .52302 .61256 .53425 .60928 .52817 .60319 Mtetra
.52817 .60319 .53425 .60928 .54552 .60599 .53948 .59988 Mtetra
.53948 .59988 .54552 .60599 .55684 .60268 .55083 .59655 Mtetra
.55083 .59655 .55684 .60268 .5682 .59937 .56222 .5932 Mtetra
.56222 .5932 .5682 .59937 .57961 .59603 .57366 .58985 Mtetra
.57366 .58985 .57961 .59603 .59107 .59269 .58515 .58648 Mtetra
.58515 .58648 .59107 .59269 .60258 .58933 .59669 .58309 Mtetra
.949 .595 .284 r
.59669 .58309 .60258 .58933 .61566 .64442 .60971 .63827 Mtetra
.652 .756 .925 r
.60971 .63827 .61566 .64442 .62747 .64109 .62155 .63492 Mtetra
.62155 .63492 .62747 .64109 .63932 .63776 .63344 .63156 Mtetra
.63344 .63156 .63932 .63776 .65122 .63441 .64538 .62818 Mtetra
.64538 .62818 .65122 .63441 .66318 .63104 .65737 .62479 Mtetra
.65737 .62479 .66318 .63104 .67519 .62766 .66941 .62139 Mtetra
.66941 .62139 .67519 .62766 .68724 .62427 .6815 .61797 Mtetra
.6815 .61797 .68724 .62427 .69935 .62086 .69365 .61453 Mtetra
.69365 .61453 .69935 .62086 .71151 .61744 .70584 .61108 Mtetra
.70584 .61108 .71151 .61744 .72372 .614 .71809 .60762 Mtetra
.71809 .60762 .72372 .614 .73599 .61055 .73039 .60414 Mtetra
.73039 .60414 .73599 .61055 .74831 .60709 .74275 .60065 Mtetra
.74275 .60065 .74831 .60709 .76068 .6036 .75516 .59714 Mtetra
.961 .755 .581 r
.75516 .59714 .76068 .6036 .76965 .55249 .76423 .5459 Mtetra
.656 .751 .92 r
.76423 .5459 .76965 .55249 .78195 .54893 .77657 .54231 Mtetra
.77657 .54231 .78195 .54893 .7943 .54535 .78896 .5387 Mtetra
.78896 .5387 .7943 .54535 .80671 .54175 .8014 .53508 Mtetra
.8014 .53508 .80671 .54175 .81916 .53814 .81389 .53144 Mtetra
.81389 .53144 .81916 .53814 .83167 .53452 .82644 .52778 Mtetra
.82644 .52778 .83167 .53452 .84424 .53087 .83905 .52411 Mtetra
.83905 .52411 .84424 .53087 .85686 .52722 .85171 .52042 Mtetra
.85171 .52042 .85686 .52722 .86953 .52354 .86442 .51672 Mtetra
.86442 .51672 .86953 .52354 .88226 .51985 .87719 .513 Mtetra
.87719 .513 .88226 .51985 .89505 .51615 .89002 .50926 Mtetra
.89002 .50926 .89505 .51615 .90789 .51242 .9029 .50551 Mtetra
.9029 .50551 .90789 .51242 .92079 .50868 .91584 .50174 Mtetra
.91584 .50174 .92079 .50868 .93374 .50493 .92883 .49795 Mtetra
.92883 .49795 .93374 .50493 .94675 .50116 .94189 .49415 Mtetra
.94189 .49415 .94675 .50116 .95982 .49737 .955 .49033 Mtetra
.664 .741 .908 r
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55984 Mtetra
.37189 .55984 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55284 .41397 .5468 Mtetra
.41397 .5468 .42022 .55284 .4285 .63244 .4246 .5435 Mtetra
0 0 .449 r
.4246 .5435 .4285 .63244 .4394 .62924 .43305 .6233 Mtetra
.657 .75 .918 r
.43305 .6233 .4394 .62924 .45034 .62603 .44402 .62007 Mtetra
.44402 .62007 .45034 .62603 .46132 .62281 .45503 .61682 Mtetra
.45503 .61682 .46132 .62281 .47235 .61957 .46609 .61356 Mtetra
.46609 .61356 .47235 .61957 .48342 .61632 .47719 .61029 Mtetra
.47719 .61029 .48342 .61632 .49454 .61306 .48834 .607 Mtetra
.48834 .607 .49454 .61306 .50571 .60978 .49953 .6037 Mtetra
.49953 .6037 .50571 .60978 .51692 .6065 .51077 .60039 Mtetra
.51077 .60039 .51692 .6065 .52817 .60319 .52206 .59706 Mtetra
.52206 .59706 .52817 .60319 .53948 .59988 .53339 .59372 Mtetra
.53339 .59372 .53948 .59988 .55083 .59655 .54477 .59036 Mtetra
.54477 .59036 .55083 .59655 .56222 .5932 .5562 .587 Mtetra
.5562 .587 .56222 .5932 .57366 .58985 .56767 .58361 Mtetra
.56767 .58361 .57366 .58985 .58515 .58648 .57919 .58022 Mtetra
.949 .598 .291 r
.57919 .58022 .58515 .58648 .59669 .58309 .5919 .63544 Mtetra
.536 .284 .481 r
.5919 .63544 .59669 .58309 .60971 .63827 .60372 .63208 Mtetra
.652 .756 .925 r
.60372 .63208 .60971 .63827 .62155 .63492 .61559 .62871 Mtetra
.61559 .62871 .62155 .63492 .63344 .63156 .62751 .62532 Mtetra
.62751 .62532 .63344 .63156 .64538 .62818 .63949 .62191 Mtetra
.63949 .62191 .64538 .62818 .65737 .62479 .65151 .6185 Mtetra
.65151 .6185 .65737 .62479 .66941 .62139 .66359 .61506 Mtetra
.66359 .61506 .66941 .62139 .6815 .61797 .67572 .61162 Mtetra
.67572 .61162 .6815 .61797 .69365 .61453 .6879 .60815 Mtetra
.6879 .60815 .69365 .61453 .70584 .61108 .70013 .60468 Mtetra
.70013 .60468 .70584 .61108 .71809 .60762 .71242 .60118 Mtetra
.71242 .60118 .71809 .60762 .73039 .60414 .72475 .59768 Mtetra
.72475 .59768 .73039 .60414 .74275 .60065 .73715 .59415 Mtetra
.73715 .59415 .74275 .60065 .75516 .59714 .74959 .59062 Mtetra
.74959 .59062 .75516 .59714 .76423 .5459 .7621 .58706 Mtetra
0 0 .295 r
.7621 .58706 .76423 .5459 .77657 .54231 .77114 .53563 Mtetra
.656 .751 .92 r
.77114 .53563 .77657 .54231 .78896 .5387 .78357 .532 Mtetra
.78357 .532 .78896 .5387 .8014 .53508 .79605 .52834 Mtetra
.79605 .52834 .8014 .53508 .81389 .53144 .80858 .52467 Mtetra
.80858 .52467 .81389 .53144 .82644 .52778 .82117 .52099 Mtetra
.82117 .52099 .82644 .52778 .83905 .52411 .83381 .51729 Mtetra
.83381 .51729 .83905 .52411 .85171 .52042 .84651 .51357 Mtetra
.84651 .51357 .85171 .52042 .86442 .51672 .85927 .50984 Mtetra
.85927 .50984 .86442 .51672 .87719 .513 .87208 .50609 Mtetra
.87208 .50609 .87719 .513 .89002 .50926 .88494 .50232 Mtetra
.88494 .50232 .89002 .50926 .9029 .50551 .89787 .49854 Mtetra
.89787 .49854 .9029 .50551 .91584 .50174 .91085 .49474 Mtetra
.91085 .49474 .91584 .50174 .92883 .49795 .92389 .49092 Mtetra
.92389 .49092 .92883 .49795 .94189 .49415 .93698 .48709 Mtetra
.93698 .48709 .94189 .49415 .955 .49033 .95014 .48324 Mtetra
.664 .741 .908 r
.35506 .5571 .36148 .56307 .37189 .55984 .3655 .55385 Mtetra
.3655 .55385 .37189 .55984 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .5435 .41834 .53739 Mtetra
.41834 .53739 .4246 .5435 .43305 .6233 .42903 .53406 Mtetra
0 0 .449 r
.42903 .53406 .43305 .6233 .44402 .62007 .43765 .61406 Mtetra
.657 .75 .918 r
.43765 .61406 .44402 .62007 .45503 .61682 .44869 .61079 Mtetra
.44869 .61079 .45503 .61682 .46609 .61356 .45978 .60751 Mtetra
.45978 .60751 .46609 .61356 .47719 .61029 .47091 .60421 Mtetra
.47091 .60421 .47719 .61029 .48834 .607 .48208 .6009 Mtetra
.48208 .6009 .48834 .607 .49953 .6037 .49331 .59757 Mtetra
.49331 .59757 .49953 .6037 .51077 .60039 .50458 .59423 Mtetra
.50458 .59423 .51077 .60039 .52206 .59706 .51589 .59088 Mtetra
.51589 .59088 .52206 .59706 .53339 .59372 .52726 .58751 Mtetra
.52726 .58751 .53339 .59372 .54477 .59036 .53867 .58413 Mtetra
.53867 .58413 .54477 .59036 .5562 .587 .55013 .58074 Mtetra
.55013 .58074 .5562 .587 .56767 .58361 .56163 .57733 Mtetra
.56163 .57733 .56767 .58361 .57919 .58022 .57319 .57391 Mtetra
.949 .598 .291 r
.57319 .57391 .57919 .58022 .5919 .63544 .58582 .62923 Mtetra
.652 .756 .925 r
.58582 .62923 .5919 .63544 .60372 .63208 .59768 .62584 Mtetra
.59768 .62584 .60372 .63208 .61559 .62871 .60959 .62244 Mtetra
.60959 .62244 .61559 .62871 .62751 .62532 .62154 .61902 Mtetra
.62154 .61902 .62751 .62532 .63949 .62191 .63355 .61559 Mtetra
.63355 .61559 .63949 .62191 .65151 .6185 .64561 .61215 Mtetra
.64561 .61215 .65151 .6185 .66359 .61506 .65772 .60869 Mtetra
.65772 .60869 .66359 .61506 .67572 .61162 .66988 .60521 Mtetra
.66988 .60521 .67572 .61162 .6879 .60815 .6821 .60172 Mtetra
.6821 .60172 .6879 .60815 .70013 .60468 .69437 .59822 Mtetra
.69437 .59822 .70013 .60468 .71242 .60118 .70669 .5947 Mtetra
.70669 .5947 .71242 .60118 .72475 .59768 .71907 .59116 Mtetra
.71907 .59116 .72475 .59768 .73715 .59415 .7315 .58761 Mtetra
.7315 .58761 .73715 .59415 .74959 .59062 .74398 .58404 Mtetra
.74398 .58404 .74959 .59062 .7621 .58706 .75652 .58046 Mtetra
.962 .756 .579 r
.75652 .58046 .7621 .58706 .77114 .53563 .76567 .52891 Mtetra
.656 .751 .92 r
.76567 .52891 .77114 .53563 .78357 .532 .77814 .52524 Mtetra
.77814 .52524 .78357 .532 .79605 .52834 .79066 .52156 Mtetra
.79066 .52156 .79605 .52834 .80858 .52467 .80323 .51786 Mtetra
.80323 .51786 .80858 .52467 .82117 .52099 .81586 .51414 Mtetra
.81586 .51414 .82117 .52099 .83381 .51729 .82854 .51041 Mtetra
.82854 .51041 .83381 .51729 .84651 .51357 .84128 .50666 Mtetra
.84128 .50666 .84651 .51357 .85927 .50984 .85407 .5029 Mtetra
.85407 .5029 .85927 .50984 .87208 .50609 .86692 .49912 Mtetra
.86692 .49912 .87208 .50609 .88494 .50232 .87983 .49532 Mtetra
.87983 .49532 .88494 .50232 .89787 .49854 .8928 .49151 Mtetra
.8928 .49151 .89787 .49854 .91085 .49474 .90582 .48768 Mtetra
.90582 .48768 .91085 .49474 .92389 .49092 .9189 .48383 Mtetra
.9189 .48383 .92389 .49092 .93698 .48709 .93204 .47996 Mtetra
.93204 .47996 .93698 .48709 .95014 .48324 .94524 .47608 Mtetra
.664 .741 .908 r
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53457 Mtetra
.40135 .53457 .40769 .54071 .41834 .53739 .41203 .53123 Mtetra
.41203 .53123 .41834 .53739 .42903 .53406 .42275 .52787 Mtetra
.42275 .52787 .42903 .53406 .43765 .61406 .43351 .5245 Mtetra
.582 .396 .595 r
.43351 .5245 .43765 .61406 .44869 .61079 .44432 .52112 Mtetra
.007 0 .453 r
.44432 .52112 .44869 .61079 .45978 .60751 .45342 .60141 Mtetra
.657 .75 .918 r
.45342 .60141 .45978 .60751 .47091 .60421 .46458 .59809 Mtetra
.46458 .59809 .47091 .60421 .48208 .6009 .47578 .59475 Mtetra
.47578 .59475 .48208 .6009 .49331 .59757 .48704 .5914 Mtetra
.48704 .5914 .49331 .59757 .50458 .59423 .49834 .58803 Mtetra
.49834 .58803 .50458 .59423 .51589 .59088 .50968 .58465 Mtetra
.50968 .58465 .51589 .59088 .52726 .58751 .52108 .58126 Mtetra
.52108 .58126 .52726 .58751 .53867 .58413 .53252 .57786 Mtetra
.53252 .57786 .53867 .58413 .55013 .58074 .54401 .57443 Mtetra
.54401 .57443 .55013 .58074 .56163 .57733 .55555 .571 Mtetra
.949 .6 .298 r
.55555 .571 .56163 .57733 .57319 .57391 .56786 .62636 Mtetra
.533 .279 .477 r
.56786 .62636 .57319 .57391 .58582 .62923 .5797 .62296 Mtetra
.652 .756 .925 r
.5797 .62296 .58582 .62923 .59768 .62584 .59159 .61955 Mtetra
.59159 .61955 .59768 .62584 .60959 .62244 .60353 .61612 Mtetra
.60353 .61612 .60959 .62244 .62154 .61902 .61552 .61268 Mtetra
.61552 .61268 .62154 .61902 .63355 .61559 .62756 .60922 Mtetra
.62756 .60922 .63355 .61559 .64561 .61215 .63966 .60575 Mtetra
.63966 .60575 .64561 .61215 .65772 .60869 .65181 .60226 Mtetra
.65181 .60226 .65772 .60869 .66988 .60521 .66401 .59876 Mtetra
.66401 .59876 .66988 .60521 .6821 .60172 .67626 .59524 Mtetra
.67626 .59524 .6821 .60172 .69437 .59822 .68856 .59171 Mtetra
.68856 .59171 .69437 .59822 .70669 .5947 .70092 .58816 Mtetra
.70092 .58816 .70669 .5947 .71907 .59116 .71334 .58459 Mtetra
.71334 .58459 .71907 .59116 .7315 .58761 .72581 .58102 Mtetra
.72581 .58102 .7315 .58761 .74398 .58404 .73833 .57742 Mtetra
.73833 .57742 .74398 .58404 .75652 .58046 .75091 .57381 Mtetra
.962 .756 .579 r
.75091 .57381 .75652 .58046 .76567 .52891 .76016 .52212 Mtetra
.656 .751 .92 r
.76016 .52212 .76567 .52891 .77814 .52524 .77266 .51843 Mtetra
.77266 .51843 .77814 .52524 .79066 .52156 .78522 .51472 Mtetra
.78522 .51472 .79066 .52156 .80323 .51786 .79783 .51099 Mtetra
.79783 .51099 .80323 .51786 .81586 .51414 .8105 .50724 Mtetra
.8105 .50724 .81586 .51414 .82854 .51041 .82322 .50348 Mtetra
.82322 .50348 .82854 .51041 .84128 .50666 .836 .4997 Mtetra
.836 .4997 .84128 .50666 .85407 .5029 .84883 .49591 Mtetra
.84883 .49591 .85407 .5029 .86692 .49912 .86173 .4921 Mtetra
.86173 .4921 .86692 .49912 .87983 .49532 .87468 .48827 Mtetra
.87468 .48827 .87983 .49532 .8928 .49151 .88768 .48442 Mtetra
.88768 .48442 .8928 .49151 .90582 .48768 .90075 .48056 Mtetra
.90075 .48056 .90582 .48768 .9189 .48383 .91387 .47668 Mtetra
.91387 .47668 .9189 .48383 .93204 .47996 .92705 .47278 Mtetra
.92705 .47278 .93204 .47996 .94524 .47608 .94029 .46887 Mtetra
.664 .741 .908 r
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53508 Mtetra
.3737 .53508 .38013 .54122 .39072 .5379 .38431 .53174 Mtetra
.38431 .53174 .39072 .5379 .40135 .53457 .39497 .52839 Mtetra
.39497 .52839 .40135 .53457 .41203 .53123 .40568 .52502 Mtetra
.40568 .52502 .41203 .53123 .42275 .52787 .41642 .52164 Mtetra
.41642 .52164 .42275 .52787 .43351 .5245 .42721 .51825 Mtetra
.42721 .51825 .43351 .5245 .44432 .52112 .43804 .51484 Mtetra
.43804 .51484 .44432 .52112 .45342 .60141 .44892 .51142 Mtetra
.007 0 .453 r
.44892 .51142 .45342 .60141 .46458 .59809 .4582 .59191 Mtetra
.657 .75 .918 r
.4582 .59191 .46458 .59809 .47578 .59475 .46944 .58855 Mtetra
.46944 .58855 .47578 .59475 .48704 .5914 .48072 .58518 Mtetra
.48072 .58518 .48704 .5914 .49834 .58803 .49205 .58179 Mtetra
.49205 .58179 .49834 .58803 .50968 .58465 .50343 .57838 Mtetra
.50343 .57838 .50968 .58465 .52108 .58126 .51485 .57496 Mtetra
.51485 .57496 .52108 .58126 .53252 .57786 .52632 .57153 Mtetra
.52632 .57153 .53252 .57786 .54401 .57443 .53784 .56808 Mtetra
.53784 .56808 .54401 .57443 .55555 .571 .54941 .56462 Mtetra
.949 .6 .298 r
.54941 .56462 .55555 .571 .56786 .62636 .56166 .62007 Mtetra
.652 .756 .925 r
.56166 .62007 .56786 .62636 .5797 .62296 .57353 .61665 Mtetra
.57353 .61665 .5797 .62296 .59159 .61955 .58545 .61321 Mtetra
.58545 .61321 .59159 .61955 .60353 .61612 .59743 .60975 Mtetra
.59743 .60975 .60353 .61612 .61552 .61268 .60945 .60628 Mtetra
.60945 .60628 .61552 .61268 .62756 .60922 .62153 .6028 Mtetra
.62153 .6028 .62756 .60922 .63966 .60575 .63366 .5993 Mtetra
.63366 .5993 .63966 .60575 .65181 .60226 .64584 .59578 Mtetra
.64584 .59578 .65181 .60226 .66401 .59876 .65808 .59225 Mtetra
.65808 .59225 .66401 .59876 .67626 .59524 .67037 .58871 Mtetra
.67037 .58871 .67626 .59524 .68856 .59171 .68271 .58514 Mtetra
.68271 .58514 .68856 .59171 .70092 .58816 .69511 .58157 Mtetra
.69511 .58157 .70092 .58816 .71334 .58459 .70756 .57797 Mtetra
.70756 .57797 .71334 .58459 .72581 .58102 .72007 .57436 Mtetra
.72007 .57436 .72581 .58102 .73833 .57742 .73263 .57074 Mtetra
.73263 .57074 .73833 .57742 .75091 .57381 .74524 .5671 Mtetra
.74524 .5671 .75091 .57381 .76016 .52212 .75792 .56344 Mtetra
0 0 .283 r
.75792 .56344 .76016 .52212 .77266 .51843 .76714 .51156 Mtetra
.656 .751 .92 r
.76714 .51156 .77266 .51843 .78522 .51472 .77974 .50782 Mtetra
.77974 .50782 .78522 .51472 .79783 .51099 .79239 .50406 Mtetra
.79239 .50406 .79783 .51099 .8105 .50724 .8051 .50028 Mtetra
.8051 .50028 .8105 .50724 .82322 .50348 .81786 .49649 Mtetra
.81786 .49649 .82322 .50348 .836 .4997 .83068 .49268 Mtetra
.83068 .49268 .836 .4997 .84883 .49591 .84355 .48886 Mtetra
.84355 .48886 .84883 .49591 .86173 .4921 .85649 .48501 Mtetra
.85649 .48501 .86173 .4921 .87468 .48827 .86948 .48115 Mtetra
.86948 .48115 .87468 .48827 .88768 .48442 .88253 .47728 Mtetra
.88253 .47728 .88768 .48442 .90075 .48056 .89563 .47338 Mtetra
.89563 .47338 .90075 .48056 .91387 .47668 .9088 .46947 Mtetra
.9088 .46947 .91387 .47668 .92705 .47278 .92202 .46554 Mtetra
.92202 .46554 .92705 .47278 .94029 .46887 .93531 .46159 Mtetra
.664 .741 .908 r
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53508 .36722 .52891 Mtetra
.36722 .52891 .3737 .53508 .38431 .53174 .37786 .52554 Mtetra
.37786 .52554 .38431 .53174 .39497 .52839 .38855 .52216 Mtetra
.38855 .52216 .39497 .52839 .40568 .52502 .39928 .51877 Mtetra
.39928 .51877 .40568 .52502 .41642 .52164 .41005 .51537 Mtetra
.41005 .51537 .41642 .52164 .42721 .51825 .42087 .51195 Mtetra
.42087 .51195 .42721 .51825 .43804 .51484 .43173 .50851 Mtetra
.43173 .50851 .43804 .51484 .44892 .51142 .44263 .50507 Mtetra
.44263 .50507 .44892 .51142 .4582 .59191 .45358 .50161 Mtetra
.007 0 .453 r
.45358 .50161 .4582 .59191 .46944 .58855 .46304 .58231 Mtetra
.657 .75 .918 r
.46304 .58231 .46944 .58855 .48072 .58518 .47435 .57891 Mtetra
.47435 .57891 .48072 .58518 .49205 .58179 .48571 .57549 Mtetra
.48571 .57549 .49205 .58179 .50343 .57838 .49712 .57206 Mtetra
.49712 .57206 .50343 .57838 .51485 .57496 .50858 .56861 Mtetra
.50858 .56861 .51485 .57496 .52632 .57153 .52008 .56515 Mtetra
.52008 .56515 .52632 .57153 .53784 .56808 .53163 .56168 Mtetra
.95 .602 .305 r
.53163 .56168 .53784 .56808 .54941 .56462 .54355 .61718 Mtetra
.529 .274 .473 r
.54355 .61718 .54941 .56462 .56166 .62007 .55541 .61374 Mtetra
.652 .756 .925 r
.55541 .61374 .56166 .62007 .57353 .61665 .56731 .61029 Mtetra
.56731 .61029 .57353 .61665 .58545 .61321 .57927 .60682 Mtetra
.57927 .60682 .58545 .61321 .59743 .60975 .59128 .60334 Mtetra
.59128 .60334 .59743 .60975 .60945 .60628 .60334 .59984 Mtetra
.60334 .59984 .60945 .60628 .62153 .6028 .61545 .59632 Mtetra
.61545 .59632 .62153 .6028 .63366 .5993 .62762 .5928 Mtetra
.62762 .5928 .63366 .5993 .64584 .59578 .63983 .58925 Mtetra
.63983 .58925 .64584 .59578 .65808 .59225 .65211 .58569 Mtetra
.65211 .58569 .65808 .59225 .67037 .58871 .66443 .58212 Mtetra
.66443 .58212 .67037 .58871 .68271 .58514 .67681 .57853 Mtetra
.67681 .57853 .68271 .58514 .69511 .58157 .68925 .57492 Mtetra
.68925 .57492 .69511 .58157 .70756 .57797 .70173 .5713 Mtetra
.70173 .5713 .70756 .57797 .72007 .57436 .71428 .56766 Mtetra
.71428 .56766 .72007 .57436 .73263 .57074 .72688 .56401 Mtetra
.72688 .56401 .73263 .57074 .74524 .5671 .73953 .56034 Mtetra
.73953 .56034 .74524 .5671 .75792 .56344 .75225 .55665 Mtetra
.964 .757 .576 r
.75225 .55665 .75792 .56344 .76714 .51156 .76158 .50464 Mtetra
.656 .751 .92 r
.76158 .50464 .76714 .51156 .77974 .50782 .77421 .50087 Mtetra
.77421 .50087 .77974 .50782 .79239 .50406 .7869 .49708 Mtetra
.7869 .49708 .79239 .50406 .8051 .50028 .79965 .49327 Mtetra
.79965 .49327 .8051 .50028 .81786 .49649 .81245 .48945 Mtetra
.81245 .48945 .81786 .49649 .83068 .49268 .82531 .48561 Mtetra
.82531 .48561 .83068 .49268 .84355 .48886 .83823 .48175 Mtetra
.83823 .48175 .84355 .48886 .85649 .48501 .8512 .47788 Mtetra
.8512 .47788 .85649 .48501 .86948 .48115 .86424 .47398 Mtetra
.86424 .47398 .86948 .48115 .88253 .47728 .87733 .47007 Mtetra
.87733 .47007 .88253 .47728 .89563 .47338 .89048 .46615 Mtetra
.89048 .46615 .89563 .47338 .9088 .46947 .90369 .4622 Mtetra
.90369 .4622 .9088 .46947 .92202 .46554 .91695 .45824 Mtetra
.91695 .45824 .92202 .46554 .93531 .46159 .93028 .45426 Mtetra
.664 .741 .908 r
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52268 Mtetra
.36069 .52268 .36722 .52891 .37786 .52554 .37136 .51929 Mtetra
.37136 .51929 .37786 .52554 .38855 .52216 .38207 .51589 Mtetra
.38207 .51589 .38855 .52216 .39928 .51877 .39283 .51247 Mtetra
.39283 .51247 .39928 .51877 .41005 .51537 .40363 .50904 Mtetra
.40363 .50904 .41005 .51537 .42087 .51195 .41447 .5056 Mtetra
.41447 .5056 .42087 .51195 .43173 .50851 .42536 .50214 Mtetra
.42536 .50214 .43173 .50851 .44263 .50507 .43629 .49867 Mtetra
.43629 .49867 .44263 .50507 .45358 .50161 .44727 .49518 Mtetra
.44727 .49518 .45358 .50161 .46304 .58231 .45829 .49168 Mtetra
.007 0 .453 r
.45829 .49168 .46304 .58231 .47435 .57891 .46793 .57259 Mtetra
.657 .75 .918 r
.46793 .57259 .47435 .57891 .48571 .57549 .47933 .56914 Mtetra
.47933 .56914 .48571 .57549 .49712 .57206 .49076 .56569 Mtetra
.49076 .56569 .49712 .57206 .50858 .56861 .50225 .56221 Mtetra
.50225 .56221 .50858 .56861 .52008 .56515 .51379 .55873 Mtetra
.51379 .55873 .52008 .56515 .53163 .56168 .52537 .55523 Mtetra
.95 .602 .305 r
.52537 .55523 .53163 .56168 .54355 .61718 .53722 .61082 Mtetra
.652 .756 .925 r
.53722 .61082 .54355 .61718 .55541 .61374 .5491 .60735 Mtetra
.5491 .60735 .55541 .61374 .56731 .61029 .56104 .60387 Mtetra
.56104 .60387 .56731 .61029 .57927 .60682 .57303 .60038 Mtetra
.57303 .60038 .57927 .60682 .59128 .60334 .58508 .59687 Mtetra
.58508 .59687 .59128 .60334 .60334 .59984 .59717 .59334 Mtetra
.59717 .59334 .60334 .59984 .61545 .59632 .60932 .5898 Mtetra
.60932 .5898 .61545 .59632 .62762 .5928 .62152 .58624 Mtetra
.62152 .58624 .62762 .5928 .63983 .58925 .63378 .58267 Mtetra
.63378 .58267 .63983 .58925 .65211 .58569 .64608 .57908 Mtetra
.64608 .57908 .65211 .58569 .66443 .58212 .65845 .57548 Mtetra
.65845 .57548 .66443 .58212 .67681 .57853 .67086 .57186 Mtetra
.67086 .57186 .67681 .57853 .68925 .57492 .68333 .56822 Mtetra
.68333 .56822 .68925 .57492 .70173 .5713 .69586 .56457 Mtetra
.69586 .56457 .70173 .5713 .71428 .56766 .70844 .5609 Mtetra
.70844 .5609 .71428 .56766 .72688 .56401 .72108 .55722 Mtetra
.72108 .55722 .72688 .56401 .73953 .56034 .73378 .55352 Mtetra
.73378 .55352 .73953 .56034 .75225 .55665 .74653 .5498 Mtetra
.964 .757 .576 r
.74653 .5498 .75225 .55665 .76158 .50464 .75597 .49766 Mtetra
.656 .751 .92 r
.75597 .49766 .76158 .50464 .77421 .50087 .76864 .49386 Mtetra
.76864 .49386 .77421 .50087 .7869 .49708 .78137 .49004 Mtetra
.78137 .49004 .7869 .49708 .79965 .49327 .79416 .4862 Mtetra
.79416 .4862 .79965 .49327 .81245 .48945 .807 .48234 Mtetra
.807 .48234 .81245 .48945 .82531 .48561 .8199 .47847 Mtetra
.8199 .47847 .82531 .48561 .83823 .48175 .83286 .47458 Mtetra
.83286 .47458 .83823 .48175 .8512 .47788 .84588 .47068 Mtetra
.84588 .47068 .8512 .47788 .86424 .47398 .85895 .46675 Mtetra
.85895 .46675 .86424 .47398 .87733 .47007 .87209 .46281 Mtetra
.87209 .46281 .87733 .47007 .89048 .46615 .88528 .45885 Mtetra
.88528 .45885 .89048 .46615 .90369 .4622 .89853 .45487 Mtetra
.89853 .45487 .90369 .4622 .91695 .45824 .91184 .45088 Mtetra
.91184 .45088 .91695 .45824 .93028 .45426 .92522 .44686 Mtetra
.664 .741 .908 r
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .5232 Mtetra
.33285 .5232 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52268 .35411 .51641 Mtetra
.35411 .51641 .36069 .52268 .37136 .51929 .36481 .513 Mtetra
.36481 .513 .37136 .51929 .38207 .51589 .37555 .50957 Mtetra
.37555 .50957 .38207 .51589 .39283 .51247 .38633 .50613 Mtetra
.38633 .50613 .39283 .51247 .40363 .50904 .39716 .50267 Mtetra
.39716 .50267 .40363 .50904 .41447 .5056 .40803 .4992 Mtetra
.40803 .4992 .41447 .5056 .42536 .50214 .41895 .49572 Mtetra
.41895 .49572 .42536 .50214 .43629 .49867 .42991 .49222 Mtetra
.42991 .49222 .43629 .49867 .44727 .49518 .44091 .48871 Mtetra
.44091 .48871 .44727 .49518 .45829 .49168 .45196 .48518 Mtetra
.45196 .48518 .45829 .49168 .46793 .57259 .46305 .48164 Mtetra
.578 .391 .592 r
.46305 .48164 .46793 .57259 .47933 .56914 .47419 .47808 Mtetra
.015 0 .457 r
.47419 .47808 .47933 .56914 .49076 .56569 .48436 .55927 Mtetra
.657 .75 .918 r
.48436 .55927 .49076 .56569 .50225 .56221 .49588 .55577 Mtetra
.49588 .55577 .50225 .56221 .51379 .55873 .50744 .55225 Mtetra
.50744 .55225 .51379 .55873 .52537 .55523 .51906 .54872 Mtetra
.95 .602 .305 r
.51906 .54872 .52537 .55523 .53722 .61082 .53083 .60441 Mtetra
.652 .756 .925 r
.53083 .60441 .53722 .61082 .5491 .60735 .54275 .60092 Mtetra
.54275 .60092 .5491 .60735 .56104 .60387 .55472 .59741 Mtetra
.55472 .59741 .56104 .60387 .57303 .60038 .56675 .59388 Mtetra
.56675 .59388 .57303 .60038 .58508 .59687 .57883 .59034 Mtetra
.57883 .59034 .58508 .59687 .59717 .59334 .59096 .58679 Mtetra
.59096 .58679 .59717 .59334 .60932 .5898 .60314 .58322 Mtetra
.60314 .58322 .60932 .5898 .62152 .58624 .61538 .57963 Mtetra
.61538 .57963 .62152 .58624 .63378 .58267 .62767 .57603 Mtetra
.62767 .57603 .63378 .58267 .64608 .57908 .64001 .57242 Mtetra
.64001 .57242 .64608 .57908 .65845 .57548 .65241 .56878 Mtetra
.65241 .56878 .65845 .57548 .67086 .57186 .66487 .56513 Mtetra
.66487 .56513 .67086 .57186 .68333 .56822 .67738 .56147 Mtetra
.67738 .56147 .68333 .56822 .69586 .56457 .68994 .55779 Mtetra
.68994 .55779 .69586 .56457 .70844 .5609 .70256 .55409 Mtetra
.70256 .55409 .70844 .5609 .72108 .55722 .71524 .55037 Mtetra
.71524 .55037 .72108 .55722 .73378 .55352 .72797 .54664 Mtetra
.72797 .54664 .73378 .55352 .74653 .5498 .74077 .54289 Mtetra
.74077 .54289 .74653 .5498 .75597 .49766 .75361 .53913 Mtetra
0 0 .272 r
.75361 .53913 .75597 .49766 .76864 .49386 .76303 .48679 Mtetra
.656 .751 .92 r
.76303 .48679 .76864 .49386 .78137 .49004 .7758 .48294 Mtetra
.7758 .48294 .78137 .49004 .79416 .4862 .78862 .47907 Mtetra
.78862 .47907 .79416 .4862 .807 .48234 .80151 .47518 Mtetra
.80151 .47518 .807 .48234 .8199 .47847 .81445 .47128 Mtetra
.81445 .47128 .8199 .47847 .83286 .47458 .82745 .46736 Mtetra
.82745 .46736 .83286 .47458 .84588 .47068 .84051 .46342 Mtetra
.84051 .46342 .84588 .47068 .85895 .46675 .85362 .45946 Mtetra
.85362 .45946 .85895 .46675 .87209 .46281 .8668 .45549 Mtetra
.8668 .45549 .87209 .46281 .88528 .45885 .88004 .45149 Mtetra
.88004 .45149 .88528 .45885 .89853 .45487 .89333 .44748 Mtetra
.89333 .44748 .89853 .45487 .91184 .45088 .90669 .44345 Mtetra
.90669 .44345 .91184 .45088 .92522 .44686 .92011 .43941 Mtetra
.664 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .34346 .51982 .33681 .51353 Mtetra
.33681 .51353 .34346 .51982 .35411 .51641 .34749 .5101 Mtetra
.34749 .5101 .35411 .51641 .36481 .513 .35821 .50666 Mtetra
.35821 .50666 .36481 .513 .37555 .50957 .36898 .5032 Mtetra
.36898 .5032 .37555 .50957 .38633 .50613 .37979 .49974 Mtetra
.37979 .49974 .38633 .50613 .39716 .50267 .39065 .49625 Mtetra
.39065 .49625 .39716 .50267 .40803 .4992 .40154 .49276 Mtetra
.40154 .49276 .40803 .4992 .41895 .49572 .41249 .48925 Mtetra
.41249 .48925 .41895 .49572 .42991 .49222 .42347 .48572 Mtetra
.42347 .48572 .42991 .49222 .44091 .48871 .4345 .48218 Mtetra
.4345 .48218 .44091 .48871 .45196 .48518 .44558 .47863 Mtetra
.44558 .47863 .45196 .48518 .46305 .48164 .4567 .47506 Mtetra
.4567 .47506 .46305 .48164 .47419 .47808 .46787 .47148 Mtetra
.46787 .47148 .47419 .47808 .48436 .55927 .47909 .46788 Mtetra
.015 0 .457 r
.47909 .46788 .48436 .55927 .49588 .55577 .48945 .54927 Mtetra
.657 .75 .918 r
.48945 .54927 .49588 .55577 .50744 .55225 .50105 .54573 Mtetra
.95 .603 .312 r
.50105 .54573 .50744 .55225 .51906 .54872 .51249 .60145 Mtetra
.524 .266 .466 r
.51249 .60145 .51906 .54872 .53083 .60441 .52439 .59795 Mtetra
.652 .756 .925 r
.52439 .59795 .53083 .60441 .54275 .60092 .53635 .59443 Mtetra
.53635 .59443 .54275 .60092 .55472 .59741 .54835 .59089 Mtetra
.54835 .59089 .55472 .59741 .56675 .59388 .56041 .58734 Mtetra
.56041 .58734 .56675 .59388 .57883 .59034 .57252 .58377 Mtetra
.57252 .58377 .57883 .59034 .59096 .58679 .58469 .58019 Mtetra
.58469 .58019 .59096 .58679 .60314 .58322 .59691 .57659 Mtetra
.59691 .57659 .60314 .58322 .61538 .57963 .60918 .57297 Mtetra
.60918 .57297 .61538 .57963 .62767 .57603 .62151 .56934 Mtetra
.62151 .56934 .62767 .57603 .64001 .57242 .63389 .56569 Mtetra
.63389 .56569 .64001 .57242 .65241 .56878 .64633 .56203 Mtetra
.64633 .56203 .65241 .56878 .66487 .56513 .65882 .55835 Mtetra
.65882 .55835 .66487 .56513 .67738 .56147 .67137 .55466 Mtetra
.67137 .55466 .67738 .56147 .68994 .55779 .68397 .55094 Mtetra
.68397 .55094 .68994 .55779 .70256 .55409 .69663 .54722 Mtetra
.69663 .54722 .70256 .55409 .71524 .55037 .70935 .54347 Mtetra
.70935 .54347 .71524 .55037 .72797 .54664 .72212 .53971 Mtetra
.72212 .53971 .72797 .54664 .74077 .54289 .73495 .53593 Mtetra
.73495 .53593 .74077 .54289 .75361 .53913 .74784 .53213 Mtetra
.965 .758 .574 r
.74784 .53213 .75361 .53913 .76303 .48679 .75737 .47967 Mtetra
.656 .751 .92 r
.75737 .47967 .76303 .48679 .7758 .48294 .77017 .47578 Mtetra
.77017 .47578 .7758 .48294 .78862 .47907 .78304 .47188 Mtetra
.78304 .47188 .78862 .47907 .80151 .47518 .79597 .46796 Mtetra
.79597 .46796 .80151 .47518 .81445 .47128 .80895 .46403 Mtetra
.80895 .46403 .81445 .47128 .82745 .46736 .82199 .46007 Mtetra
.82199 .46007 .82745 .46736 .84051 .46342 .83509 .4561 Mtetra
.83509 .4561 .84051 .46342 .85362 .45946 .84825 .45211 Mtetra
.84825 .45211 .85362 .45946 .8668 .45549 .86147 .4481 Mtetra
.86147 .4481 .8668 .45549 .88004 .45149 .87475 .44407 Mtetra
.87475 .44407 .88004 .45149 .89333 .44748 .88809 .44003 Mtetra
.88809 .44003 .89333 .44748 .90669 .44345 .90149 .43597 Mtetra
.90149 .43597 .90669 .44345 .92011 .43941 .91495 .43188 Mtetra
.664 .741 .908 r
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.34082 .50374 .34749 .5101 .35821 .50666 .35157 .50027 Mtetra
.35157 .50027 .35821 .50666 .36898 .5032 .36236 .49679 Mtetra
.36236 .49679 .36898 .5032 .37979 .49974 .3732 .4933 Mtetra
.3732 .4933 .37979 .49974 .39065 .49625 .38408 .48979 Mtetra
.38408 .48979 .39065 .49625 .40154 .49276 .39501 .48626 Mtetra
.39501 .48626 .40154 .49276 .41249 .48925 .40598 .48273 Mtetra
.40598 .48273 .41249 .48925 .42347 .48572 .41699 .47918 Mtetra
.41699 .47918 .42347 .48572 .4345 .48218 .42805 .47561 Mtetra
.42805 .47561 .4345 .48218 .44558 .47863 .43916 .47203 Mtetra
.43916 .47203 .44558 .47863 .4567 .47506 .45031 .46843 Mtetra
.45031 .46843 .4567 .47506 .46787 .47148 .46151 .46482 Mtetra
.46151 .46482 .46787 .47148 .47909 .46788 .47275 .4612 Mtetra
.47275 .4612 .47909 .46788 .48945 .54927 .48404 .45756 Mtetra
.015 0 .457 r
.48404 .45756 .48945 .54927 .50105 .54573 .49461 .53915 Mtetra
.95 .603 .312 r
.49461 .53915 .50105 .54573 .51249 .60145 .50596 .59497 Mtetra
.652 .756 .925 r
.50596 .59497 .51249 .60145 .52439 .59795 .5179 .59143 Mtetra
.5179 .59143 .52439 .59795 .53635 .59443 .52989 .58789 Mtetra
.52989 .58789 .53635 .59443 .54835 .59089 .54193 .58432 Mtetra
.54193 .58432 .54835 .59089 .56041 .58734 .55403 .58074 Mtetra
.55403 .58074 .56041 .58734 .57252 .58377 .56617 .57714 Mtetra
.56617 .57714 .57252 .58377 .58469 .58019 .57837 .57353 Mtetra
.57837 .57353 .58469 .58019 .59691 .57659 .59063 .5699 Mtetra
.59063 .5699 .59691 .57659 .60918 .57297 .60294 .56626 Mtetra
.60294 .56626 .60918 .57297 .62151 .56934 .6153 .5626 Mtetra
.6153 .5626 .62151 .56934 .63389 .56569 .62772 .55892 Mtetra
.62772 .55892 .63389 .56569 .64633 .56203 .64019 .55523 Mtetra
.64019 .55523 .64633 .56203 .65882 .55835 .65272 .55152 Mtetra
.65272 .55152 .65882 .55835 .67137 .55466 .66531 .54779 Mtetra
.66531 .54779 .67137 .55466 .68397 .55094 .67795 .54405 Mtetra
.67795 .54405 .68397 .55094 .69663 .54722 .69065 .54029 Mtetra
.69065 .54029 .69663 .54722 .70935 .54347 .70341 .53651 Mtetra
.70341 .53651 .70935 .54347 .72212 .53971 .71622 .53272 Mtetra
.71622 .53272 .72212 .53971 .73495 .53593 .72909 .52891 Mtetra
.72909 .52891 .73495 .53593 .74784 .53213 .74202 .52508 Mtetra
.965 .758 .574 r
.74202 .52508 .74784 .53213 .75737 .47967 .75166 .47248 Mtetra
.656 .751 .92 r
.75166 .47248 .75737 .47967 .77017 .47578 .76451 .46857 Mtetra
.76451 .46857 .77017 .47578 .78304 .47188 .77741 .46463 Mtetra
.77741 .46463 .78304 .47188 .79597 .46796 .79038 .46068 Mtetra
.79038 .46068 .79597 .46796 .80895 .46403 .8034 .45671 Mtetra
.8034 .45671 .80895 .46403 .82199 .46007 .81649 .45272 Mtetra
.81649 .45272 .82199 .46007 .83509 .4561 .82963 .44872 Mtetra
.82963 .44872 .83509 .4561 .84825 .45211 .84283 .44469 Mtetra
.84283 .44469 .84825 .45211 .86147 .4481 .8561 .44065 Mtetra
.8561 .44065 .86147 .4481 .87475 .44407 .86942 .43659 Mtetra
.86942 .43659 .87475 .44407 .88809 .44003 .8828 .43251 Mtetra
.8828 .43251 .88809 .44003 .90149 .43597 .89625 .42842 Mtetra
.89625 .42842 .90149 .43597 .91495 .43188 .90976 .4243 Mtetra
.664 .741 .908 r
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .5008 Mtetra
.32336 .5008 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49383 Mtetra
.34487 .49383 .35157 .50027 .36236 .49679 .35569 .49033 Mtetra
.35569 .49033 .36236 .49679 .3732 .4933 .36656 .48681 Mtetra
.36656 .48681 .3732 .4933 .38408 .48979 .37746 .48327 Mtetra
.37746 .48327 .38408 .48979 .39501 .48626 .38842 .47972 Mtetra
.38842 .47972 .39501 .48626 .40598 .48273 .39942 .47616 Mtetra
.39942 .47616 .40598 .48273 .41699 .47918 .41046 .47258 Mtetra
.41046 .47258 .41699 .47918 .42805 .47561 .42155 .46899 Mtetra
.42155 .46899 .42805 .47561 .43916 .47203 .43268 .46538 Mtetra
.43268 .46538 .43916 .47203 .45031 .46843 .44386 .46176 Mtetra
.44386 .46176 .45031 .46843 .46151 .46482 .45509 .45812 Mtetra
.45509 .45812 .46151 .46482 .47275 .4612 .46637 .45446 Mtetra
.46637 .45446 .47275 .4612 .48404 .45756 .47769 .4508 Mtetra
.959 .661 .425 r
.47769 .4508 .48404 .45756 .49461 .53915 .48747 .59198 Mtetra
.52 .261 .462 r
.48747 .59198 .49461 .53915 .50596 .59497 .49939 .58843 Mtetra
.652 .756 .925 r
.49939 .58843 .50596 .59497 .5179 .59143 .51136 .58487 Mtetra
.51136 .58487 .5179 .59143 .52989 .58789 .52338 .58129 Mtetra
.52338 .58129 .52989 .58789 .54193 .58432 .53546 .5777 Mtetra
.53546 .5777 .54193 .58432 .55403 .58074 .54759 .57409 Mtetra
.54759 .57409 .55403 .58074 .56617 .57714 .55977 .57046 Mtetra
.55977 .57046 .56617 .57714 .57837 .57353 .57201 .56682 Mtetra
.57201 .56682 .57837 .57353 .59063 .5699 .5843 .56316 Mtetra
.5843 .56316 .59063 .5699 .60294 .56626 .59664 .55949 Mtetra
.59664 .55949 .60294 .56626 .6153 .5626 .60904 .5558 Mtetra
.60904 .5558 .6153 .5626 .62772 .55892 .6215 .55209 Mtetra
.6215 .55209 .62772 .55892 .64019 .55523 .63401 .54836 Mtetra
.63401 .54836 .64019 .55523 .65272 .55152 .64658 .54462 Mtetra
.64658 .54462 .65272 .55152 .66531 .54779 .6592 .54087 Mtetra
.6592 .54087 .66531 .54779 .67795 .54405 .67188 .53709 Mtetra
.67188 .53709 .67795 .54405 .69065 .54029 .68462 .5333 Mtetra
.68462 .5333 .69065 .54029 .70341 .53651 .69742 .52949 Mtetra
.69742 .52949 .70341 .53651 .71622 .53272 .71027 .52567 Mtetra
.71027 .52567 .71622 .53272 .72909 .52891 .72318 .52182 Mtetra
.72318 .52182 .72909 .52891 .74202 .52508 .73615 .51796 Mtetra
.73615 .51796 .74202 .52508 .75166 .47248 .74918 .51409 Mtetra
0 0 .259 r
.74918 .51409 .75166 .47248 .76451 .46857 .75879 .46129 Mtetra
.656 .751 .92 r
.75879 .46129 .76451 .46857 .77741 .46463 .77174 .45732 Mtetra
.77174 .45732 .77741 .46463 .79038 .46068 .78475 .45334 Mtetra
.78475 .45334 .79038 .46068 .8034 .45671 .79781 .44934 Mtetra
.79781 .44934 .8034 .45671 .81649 .45272 .81094 .44532 Mtetra
.81094 .44532 .81649 .45272 .82963 .44872 .82412 .44128 Mtetra
.82412 .44128 .82963 .44872 .84283 .44469 .83737 .43722 Mtetra
.83737 .43722 .84283 .44469 .8561 .44065 .85067 .43314 Mtetra
.85067 .43314 .8561 .44065 .86942 .43659 .86404 .42905 Mtetra
.86404 .42905 .86942 .43659 .8828 .43251 .87747 .42493 Mtetra
.87747 .42493 .8828 .43251 .89625 .42842 .89096 .4208 Mtetra
.89096 .4208 .89625 .42842 .90976 .4243 .90451 .41665 Mtetra
.664 .741 .908 r
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49786 Mtetra
.30585 .49786 .31267 .50427 .32336 .5008 .31656 .49437 Mtetra
.31656 .49437 .32336 .5008 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49383 .33812 .48735 Mtetra
.33812 .48735 .34487 .49383 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36656 .48681 .35986 .48027 Mtetra
.35986 .48027 .36656 .48681 .37746 .48327 .3708 .47671 Mtetra
.3708 .47671 .37746 .48327 .38842 .47972 .38178 .47313 Mtetra
.38178 .47313 .38842 .47972 .39942 .47616 .39281 .46954 Mtetra
.39281 .46954 .39942 .47616 .41046 .47258 .40388 .46593 Mtetra
.40388 .46593 .41046 .47258 .42155 .46899 .415 .46231 Mtetra
.415 .46231 .42155 .46899 .43268 .46538 .42616 .45868 Mtetra
.42616 .45868 .43268 .46538 .44386 .46176 .43737 .45503 Mtetra
.43737 .45503 .44386 .46176 .45509 .45812 .44863 .45136 Mtetra
.44863 .45136 .45509 .45812 .46637 .45446 .45993 .44768 Mtetra
0 .287 .772 r
.45993 .44768 .46637 .45446 .47769 .4508 .4711 .45513 Mtetra
.016 0 0 r
.4711 .45513 .47769 .4508 .48747 .59198 .48254 .45143 Mtetra
0 0 .418 r
.48254 .45143 .48747 .59198 .49939 .58843 .49276 .58184 Mtetra
.652 .756 .925 r
.49276 .58184 .49939 .58843 .51136 .58487 .50476 .57825 Mtetra
.50476 .57825 .51136 .58487 .52338 .58129 .51682 .57464 Mtetra
.51682 .57464 .52338 .58129 .53546 .5777 .52893 .57102 Mtetra
.52893 .57102 .53546 .5777 .54759 .57409 .54109 .56738 Mtetra
.54109 .56738 .54759 .57409 .55977 .57046 .55331 .56372 Mtetra
.55331 .56372 .55977 .57046 .57201 .56682 .56559 .56005 Mtetra
.56559 .56005 .57201 .56682 .5843 .56316 .57791 .55636 Mtetra
.57791 .55636 .5843 .56316 .59664 .55949 .59029 .55266 Mtetra
.59029 .55266 .59664 .55949 .60904 .5558 .60273 .54894 Mtetra
.60273 .54894 .60904 .5558 .6215 .55209 .61523 .5452 Mtetra
.61523 .5452 .6215 .55209 .63401 .54836 .62778 .54145 Mtetra
.62778 .54145 .63401 .54836 .64658 .54462 .64038 .53767 Mtetra
.64038 .53767 .64658 .54462 .6592 .54087 .65304 .53389 Mtetra
.65304 .53389 .6592 .54087 .67188 .53709 .66576 .53008 Mtetra
.66576 .53008 .67188 .53709 .68462 .5333 .67854 .52626 Mtetra
.67854 .52626 .68462 .5333 .69742 .52949 .69138 .52242 Mtetra
.69138 .52242 .69742 .52949 .71027 .52567 .70427 .51856 Mtetra
.70427 .51856 .71027 .52567 .72318 .52182 .71722 .51468 Mtetra
.71722 .51468 .72318 .52182 .73615 .51796 .73024 .51079 Mtetra
.73024 .51079 .73615 .51796 .74918 .51409 .74331 .50688 Mtetra
.967 .759 .572 r
.74331 .50688 .74918 .51409 .75879 .46129 .75303 .45395 Mtetra
.656 .751 .92 r
.75303 .45395 .75879 .46129 .77174 .45732 .76602 .44995 Mtetra
.76602 .44995 .77174 .45732 .78475 .45334 .77907 .44593 Mtetra
.77907 .44593 .78475 .45334 .79781 .44934 .79217 .4419 Mtetra
.79217 .4419 .79781 .44934 .81094 .44532 .80534 .43784 Mtetra
.80534 .43784 .81094 .44532 .82412 .44128 .81857 .43377 Mtetra
.81857 .43377 .82412 .44128 .83737 .43722 .83186 .42968 Mtetra
.83186 .42968 .83737 .43722 .85067 .43314 .84521 .42557 Mtetra
.84521 .42557 .85067 .43314 .86404 .42905 .85862 .42144 Mtetra
.85862 .42144 .86404 .42905 .87747 .42493 .87209 .41729 Mtetra
.87209 .41729 .87747 .42493 .89096 .4208 .88563 .41312 Mtetra
.88563 .41312 .89096 .4208 .90451 .41665 .89923 .40893 Mtetra
.664 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .3708 .47671 .36408 .47009 Mtetra
.36408 .47009 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.37509 .46649 .38178 .47313 .39281 .46954 .38615 .46287 Mtetra
.38615 .46287 .39281 .46954 .40388 .46593 .39725 .45924 Mtetra
.39725 .45924 .40388 .46593 .415 .46231 .4084 .45559 Mtetra
.4084 .45559 .415 .46231 .42616 .45868 .41959 .45193 Mtetra
.41959 .45193 .42616 .45868 .43737 .45503 .43083 .44825 Mtetra
0 .274 .76 r
.43083 .44825 .43737 .45503 .44863 .45136 .44183 .4557 Mtetra
.007 0 0 r
.44183 .4557 .44863 .45136 .45993 .44768 .4532 .452 Mtetra
.4532 .452 .45993 .44768 .4711 .45513 .46462 .44828 Mtetra
.663 .742 .909 r
.46462 .44828 .4711 .45513 .48254 .45143 .47609 .44455 Mtetra
.47609 .44455 .48254 .45143 .49276 .58184 .48761 .44081 Mtetra
.567 .369 .573 r
.48761 .44081 .49276 .58184 .50476 .57825 .49917 .43704 Mtetra
0 0 .423 r
.49917 .43704 .50476 .57825 .51682 .57464 .5102 .56794 Mtetra
.652 .756 .925 r
.5102 .56794 .51682 .57464 .52893 .57102 .52235 .56429 Mtetra
.52235 .56429 .52893 .57102 .54109 .56738 .53455 .56062 Mtetra
.53455 .56062 .54109 .56738 .55331 .56372 .5468 .55693 Mtetra
.5468 .55693 .55331 .56372 .56559 .56005 .55911 .55323 Mtetra
.55911 .55323 .56559 .56005 .57791 .55636 .57148 .54951 Mtetra
.57148 .54951 .57791 .55636 .59029 .55266 .58389 .54578 Mtetra
.58389 .54578 .59029 .55266 .60273 .54894 .59637 .54202 Mtetra
.59637 .54202 .60273 .54894 .61523 .5452 .6089 .53826 Mtetra
.6089 .53826 .61523 .5452 .62778 .54145 .62149 .53447 Mtetra
.62149 .53447 .62778 .54145 .64038 .53767 .63413 .53067 Mtetra
.63413 .53067 .64038 .53767 .65304 .53389 .64683 .52685 Mtetra
.64683 .52685 .65304 .53389 .66576 .53008 .65959 .52301 Mtetra
.65959 .52301 .66576 .53008 .67854 .52626 .67241 .51915 Mtetra
.67241 .51915 .67854 .52626 .69138 .52242 .68529 .51528 Mtetra
.68529 .51528 .69138 .52242 .70427 .51856 .69822 .51139 Mtetra
.69822 .51139 .70427 .51856 .71722 .51468 .71121 .50748 Mtetra
.71121 .50748 .71722 .51468 .73024 .51079 .72427 .50356 Mtetra
.934 .564 .18 r
.72427 .50356 .73024 .51079 .74331 .50688 .74185 .5695 Mtetra
.522 .266 .468 r
.74185 .5695 .74331 .50688 .75303 .45395 .75531 .56562 Mtetra
.537 .299 .502 r
.75531 .56562 .75303 .45395 .76602 .44995 .76884 .56172 Mtetra
.76884 .56172 .76602 .44995 .77907 .44593 .78243 .5578 Mtetra
.78243 .5578 .77907 .44593 .79217 .4419 .79608 .55386 Mtetra
.79608 .55386 .79217 .4419 .80534 .43784 .8098 .54991 Mtetra
.8098 .54991 .80534 .43784 .81857 .43377 .82359 .54593 Mtetra
.03 0 .396 r
.82359 .54593 .81857 .43377 .83186 .42968 .8263 .42207 Mtetra
.656 .751 .92 r
.8263 .42207 .83186 .42968 .84521 .42557 .8397 .41793 Mtetra
.8397 .41793 .84521 .42557 .85862 .42144 .85315 .41376 Mtetra
.85315 .41376 .85862 .42144 .87209 .41729 .86667 .40958 Mtetra
.86667 .40958 .87209 .41729 .88563 .41312 .88025 .40538 Mtetra
.88025 .40538 .88563 .41312 .89923 .40893 .8939 .40115 Mtetra
.664 .741 .908 r
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.34633 .46705 .35312 .47368 .36408 .47009 .35732 .46343 Mtetra
.35732 .46343 .36408 .47009 .37509 .46649 .36835 .4598 Mtetra
.36835 .4598 .37509 .46649 .38615 .46287 .37944 .45615 Mtetra
.37944 .45615 .38615 .46287 .39725 .45924 .39057 .45249 Mtetra
.39057 .45249 .39725 .45924 .4084 .45559 .40174 .44881 Mtetra
0 .261 .748 r
.40174 .44881 .4084 .45559 .41959 .45193 .41258 .45626 Mtetra
0 0 0 r
.41258 .45626 .41959 .45193 .43083 .44825 .42389 .45257 Mtetra
.42389 .45257 .43083 .44825 .44183 .4557 .43524 .44885 Mtetra
.663 .742 .909 r
.43524 .44885 .44183 .4557 .4532 .452 .44665 .44513 Mtetra
.44665 .44513 .4532 .452 .46462 .44828 .4581 .44138 Mtetra
.4581 .44138 .46462 .44828 .47609 .44455 .4696 .43762 Mtetra
.4696 .43762 .47609 .44455 .48761 .44081 .48114 .43385 Mtetra
.48114 .43385 .48761 .44081 .49917 .43704 .49274 .43006 Mtetra
.49274 .43006 .49917 .43704 .5102 .56794 .50439 .42625 Mtetra
0 0 .423 r
.50439 .42625 .5102 .56794 .52235 .56429 .51572 .5575 Mtetra
.652 .756 .925 r
.51572 .5575 .52235 .56429 .53455 .56062 .52795 .5538 Mtetra
.52795 .5538 .53455 .56062 .5468 .55693 .54024 .55009 Mtetra
.54024 .55009 .5468 .55693 .55911 .55323 .55259 .54635 Mtetra
.55259 .54635 .55911 .55323 .57148 .54951 .56499 .5426 Mtetra
.56499 .5426 .57148 .54951 .58389 .54578 .57744 .53884 Mtetra
.57744 .53884 .58389 .54578 .59637 .54202 .58995 .53505 Mtetra
.58995 .53505 .59637 .54202 .6089 .53826 .60252 .53125 Mtetra
.60252 .53125 .6089 .53826 .62149 .53447 .61515 .52744 Mtetra
.61515 .52744 .62149 .53447 .63413 .53067 .62783 .5236 Mtetra
.62783 .5236 .63413 .53067 .64683 .52685 .64057 .51975 Mtetra
.64057 .51975 .64683 .52685 .65959 .52301 .65337 .51588 Mtetra
.65337 .51588 .65959 .52301 .67241 .51915 .66623 .51199 Mtetra
.66623 .51199 .67241 .51915 .68529 .51528 .67914 .50809 Mtetra
.67914 .50809 .68529 .51528 .69822 .51139 .69212 .50416 Mtetra
.69212 .50416 .69822 .51139 .71121 .50748 .70515 .50022 Mtetra
.937 .568 .189 r
.70515 .50022 .71121 .50748 .72427 .50356 .72232 .56621 Mtetra
.521 .264 .466 r
.72232 .56621 .72427 .50356 .74185 .5695 .73577 .56232 Mtetra
.646 .762 .934 r
.73577 .56232 .74185 .5695 .75531 .56562 .74927 .5584 Mtetra
.74927 .5584 .75531 .56562 .76884 .56172 .76284 .55447 Mtetra
.76284 .55447 .76884 .56172 .78243 .5578 .77648 .55052 Mtetra
.77648 .55052 .78243 .5578 .79608 .55386 .79018 .54654 Mtetra
.79018 .54654 .79608 .55386 .8098 .54991 .80394 .54255 Mtetra
.80394 .54255 .8098 .54991 .82359 .54593 .81778 .53854 Mtetra
.81778 .53854 .82359 .54593 .8263 .42207 .83167 .53452 Mtetra
.535 .296 .5 r
.83167 .53452 .8263 .42207 .8397 .41793 .84564 .53047 Mtetra
.84564 .53047 .8397 .41793 .85315 .41376 .85967 .5264 Mtetra
.85967 .5264 .85315 .41376 .86667 .40958 .87377 .52231 Mtetra
.87377 .52231 .86667 .40958 .88025 .40538 .88794 .51821 Mtetra
.88794 .51821 .88025 .40538 .8939 .40115 .90218 .51408 Mtetra
.664 .741 .908 r
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.3285 .46399 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45671 Mtetra
.3505 .45671 .35732 .46343 .36835 .4598 .36156 .45306 Mtetra
.36156 .45306 .36835 .4598 .37944 .45615 .37268 .44938 Mtetra
0 .247 .735 r
.37268 .44938 .37944 .45615 .39057 .45249 .38335 .45683 Mtetra
0 0 0 r
.38335 .45683 .39057 .45249 .40174 .44881 .39459 .45314 Mtetra
.39459 .45314 .40174 .44881 .41258 .45626 .40588 .44943 Mtetra
.663 .742 .909 r
.40588 .44943 .41258 .45626 .42389 .45257 .41722 .4457 Mtetra
.41722 .4457 .42389 .45257 .43524 .44885 .4286 .44196 Mtetra
.4286 .44196 .43524 .44885 .44665 .44513 .44004 .4382 Mtetra
.44004 .4382 .44665 .44513 .4581 .44138 .45152 .43443 Mtetra
.45152 .43443 .4581 .44138 .4696 .43762 .46305 .43064 Mtetra
.46305 .43064 .4696 .43762 .48114 .43385 .47463 .42683 Mtetra
.47463 .42683 .48114 .43385 .49274 .43006 .48626 .42301 Mtetra
.48626 .42301 .49274 .43006 .50439 .42625 .49793 .41918 Mtetra
.49793 .41918 .50439 .42625 .51572 .5575 .50966 .41532 Mtetra
0 0 .423 r
.50966 .41532 .51572 .5575 .52795 .5538 .5213 .54693 Mtetra
.652 .756 .925 r
.5213 .54693 .52795 .5538 .54024 .55009 .53362 .54318 Mtetra
.53362 .54318 .54024 .55009 .55259 .54635 .546 .53942 Mtetra
.546 .53942 .55259 .54635 .56499 .5426 .55844 .53564 Mtetra
.55844 .53564 .56499 .5426 .57744 .53884 .57093 .53184 Mtetra
.57093 .53184 .57744 .53884 .58995 .53505 .58348 .52802 Mtetra
.58348 .52802 .58995 .53505 .60252 .53125 .59609 .52419 Mtetra
.59609 .52419 .60252 .53125 .61515 .52744 .60875 .52034 Mtetra
.60875 .52034 .61515 .52744 .62783 .5236 .62148 .51647 Mtetra
.62148 .51647 .62783 .5236 .64057 .51975 .63426 .51259 Mtetra
.63426 .51259 .64057 .51975 .65337 .51588 .64709 .50869 Mtetra
.64709 .50869 .65337 .51588 .66623 .51199 .65999 .50477 Mtetra
.65999 .50477 .66623 .51199 .67914 .50809 .67295 .50083 Mtetra
.67295 .50083 .67914 .50809 .69212 .50416 .68596 .49687 Mtetra
.939 .571 .199 r
.68596 .49687 .69212 .50416 .70515 .50022 .70272 .56292 Mtetra
.519 .261 .464 r
.70272 .56292 .70515 .50022 .72232 .56621 .71614 .55901 Mtetra
.646 .762 .934 r
.71614 .55901 .72232 .56621 .73577 .56232 .72963 .55507 Mtetra
.72963 .55507 .73577 .56232 .74927 .5584 .74318 .55113 Mtetra
.74318 .55113 .74927 .5584 .76284 .55447 .7568 .54716 Mtetra
.7568 .54716 .76284 .55447 .77648 .55052 .77048 .54317 Mtetra
.77048 .54317 .77648 .55052 .79018 .54654 .78422 .53916 Mtetra
.78422 .53916 .79018 .54654 .80394 .54255 .79804 .53514 Mtetra
.79804 .53514 .80394 .54255 .81778 .53854 .81191 .53109 Mtetra
.81191 .53109 .81778 .53854 .83167 .53452 .82586 .52703 Mtetra
.82586 .52703 .83167 .53452 .84564 .53047 .83987 .52294 Mtetra
.83987 .52294 .84564 .53047 .85967 .5264 .85395 .51884 Mtetra
.85395 .51884 .85967 .5264 .87377 .52231 .8681 .51472 Mtetra
.8681 .51472 .87377 .52231 .88794 .51821 .88232 .51057 Mtetra
.88232 .51057 .88794 .51821 .90218 .51408 .89661 .50641 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.33258 .45362 .33948 .46036 .3505 .45671 .34363 .44995 Mtetra
0 .233 .721 r
.34363 .44995 .3505 .45671 .36156 .45306 .35414 .4574 Mtetra
0 0 0 r
.35414 .4574 .36156 .45306 .37268 .44938 .36532 .45371 Mtetra
.36532 .45371 .37268 .44938 .38335 .45683 .37654 .45 Mtetra
.663 .742 .909 r
.37654 .45 .38335 .45683 .39459 .45314 .38781 .44627 Mtetra
.38781 .44627 .39459 .45314 .40588 .44943 .39913 .44254 Mtetra
.39913 .44254 .40588 .44943 .41722 .4457 .4105 .43878 Mtetra
.4105 .43878 .41722 .4457 .4286 .44196 .42191 .43501 Mtetra
.42191 .43501 .4286 .44196 .44004 .4382 .43338 .43122 Mtetra
.43338 .43122 .44004 .4382 .45152 .43443 .44489 .42742 Mtetra
.44489 .42742 .45152 .43443 .46305 .43064 .45645 .4236 Mtetra
.45645 .4236 .46305 .43064 .47463 .42683 .46806 .41977 Mtetra
.46806 .41977 .47463 .42683 .48626 .42301 .47972 .41592 Mtetra
.47972 .41592 .48626 .42301 .49793 .41918 .49143 .41205 Mtetra
.49143 .41205 .49793 .41918 .50966 .41532 .50319 .40816 Mtetra
.50319 .40816 .50966 .41532 .5213 .54693 .515 .40426 Mtetra
0 0 .423 r
.515 .40426 .5213 .54693 .53362 .54318 .52695 .53622 Mtetra
.652 .756 .925 r
.52695 .53622 .53362 .54318 .546 .53942 .53937 .53242 Mtetra
.53937 .53242 .546 .53942 .55844 .53564 .55184 .52861 Mtetra
.55184 .52861 .55844 .53564 .57093 .53184 .56437 .52478 Mtetra
.56437 .52478 .57093 .53184 .58348 .52802 .57696 .52094 Mtetra
.57696 .52094 .58348 .52802 .59609 .52419 .58961 .51707 Mtetra
.58961 .51707 .59609 .52419 .60875 .52034 .60231 .51319 Mtetra
.60231 .51319 .60875 .52034 .62148 .51647 .61507 .50929 Mtetra
.61507 .50929 .62148 .51647 .63426 .51259 .62789 .50537 Mtetra
.62789 .50537 .63426 .51259 .64709 .50869 .64077 .50144 Mtetra
.64077 .50144 .64709 .50869 .65999 .50477 .6537 .49748 Mtetra
.6537 .49748 .65999 .50477 .67295 .50083 .6667 .49351 Mtetra
.941 .575 .208 r
.6667 .49351 .67295 .50083 .68596 .49687 .68303 .55961 Mtetra
.517 .258 .461 r
.68303 .55961 .68596 .49687 .70272 .56292 .69644 .55568 Mtetra
.646 .762 .934 r
.69644 .55568 .70272 .56292 .71614 .55901 .70991 .55173 Mtetra
.70991 .55173 .71614 .55901 .72963 .55507 .72344 .54777 Mtetra
.72344 .54777 .72963 .55507 .74318 .55113 .73703 .54378 Mtetra
.73703 .54378 .74318 .55113 .7568 .54716 .75069 .53978 Mtetra
.75069 .53978 .7568 .54716 .77048 .54317 .76442 .53576 Mtetra
.76442 .53576 .77048 .54317 .78422 .53916 .77821 .53172 Mtetra
.77821 .53172 .78422 .53916 .79804 .53514 .79207 .52765 Mtetra
.79207 .52765 .79804 .53514 .81191 .53109 .806 .52357 Mtetra
.806 .52357 .81191 .53109 .82586 .52703 .81999 .51947 Mtetra
.81999 .51947 .82586 .52703 .83987 .52294 .83405 .51535 Mtetra
.83405 .51535 .83987 .52294 .85395 .51884 .84818 .51121 Mtetra
.84818 .51121 .85395 .51884 .8681 .51472 .86238 .50705 Mtetra
.86238 .50705 .8681 .51472 .88232 .51057 .87665 .50287 Mtetra
.87665 .50287 .88232 .51057 .89661 .50641 .89099 .49867 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
0 .218 .707 r
.3146 .45051 .32158 .45728 .33258 .45362 .32495 .45796 Mtetra
0 0 0 r
.32495 .45796 .33258 .45362 .34363 .44995 .33606 .45427 Mtetra
.33606 .45427 .34363 .44995 .35414 .4574 .34722 .45057 Mtetra
.663 .742 .909 r
.34722 .45057 .35414 .4574 .36532 .45371 .35843 .44685 Mtetra
.35843 .44685 .36532 .45371 .37654 .45 .36968 .44311 Mtetra
.36968 .44311 .37654 .45 .38781 .44627 .38098 .43936 Mtetra
.38098 .43936 .38781 .44627 .39913 .44254 .39233 .43559 Mtetra
.39233 .43559 .39913 .44254 .4105 .43878 .40372 .43181 Mtetra
.40372 .43181 .4105 .43878 .42191 .43501 .41517 .42801 Mtetra
.41517 .42801 .42191 .43501 .43338 .43122 .42666 .42419 Mtetra
.42666 .42419 .43338 .43122 .44489 .42742 .43821 .42036 Mtetra
.43821 .42036 .44489 .42742 .45645 .4236 .4498 .41651 Mtetra
.4498 .41651 .45645 .4236 .46806 .41977 .46144 .41264 Mtetra
.46144 .41264 .46806 .41977 .47972 .41592 .47314 .40876 Mtetra
.47314 .40876 .47972 .41592 .49143 .41205 .48488 .40486 Mtetra
.48488 .40486 .49143 .41205 .50319 .40816 .49667 .40095 Mtetra
.49667 .40095 .50319 .40816 .515 .40426 .50852 .39701 Mtetra
.50852 .39701 .515 .40426 .52695 .53622 .52041 .39306 Mtetra
0 0 .423 r
.52041 .39306 .52695 .53622 .53937 .53242 .53268 .52537 Mtetra
.652 .756 .925 r
.53268 .52537 .53937 .53242 .55184 .52861 .54519 .52153 Mtetra
.54519 .52153 .55184 .52861 .56437 .52478 .55776 .51767 Mtetra
.55776 .51767 .56437 .52478 .57696 .52094 .57038 .51379 Mtetra
.57038 .51379 .57696 .52094 .58961 .51707 .58306 .50989 Mtetra
.58306 .50989 .58961 .51707 .60231 .51319 .59581 .50598 Mtetra
.59581 .50598 .60231 .51319 .61507 .50929 .60861 .50204 Mtetra
.60861 .50204 .61507 .50929 .62789 .50537 .62146 .49809 Mtetra
.62146 .49809 .62789 .50537 .64077 .50144 .63438 .49412 Mtetra
.63438 .49412 .64077 .50144 .6537 .49748 .64736 .49013 Mtetra
.943 .578 .217 r
.64736 .49013 .6537 .49748 .6667 .49351 .66327 .55629 Mtetra
.515 .255 .459 r
.66327 .55629 .6667 .49351 .68303 .55961 .67666 .55234 Mtetra
.646 .762 .934 r
.67666 .55234 .68303 .55961 .69644 .55568 .6901 .54838 Mtetra
.6901 .54838 .69644 .55568 .70991 .55173 .70361 .5444 Mtetra
.70361 .5444 .70991 .55173 .72344 .54777 .71719 .5404 Mtetra
.71719 .5404 .72344 .54777 .73703 .54378 .73083 .53638 Mtetra
.73083 .53638 .73703 .54378 .75069 .53978 .74454 .53234 Mtetra
.74454 .53234 .75069 .53978 .76442 .53576 .75831 .52828 Mtetra
.75831 .52828 .76442 .53576 .77821 .53172 .77215 .5242 Mtetra
.77215 .5242 .77821 .53172 .79207 .52765 .78606 .5201 Mtetra
.78606 .5201 .79207 .52765 .806 .52357 .80003 .51599 Mtetra
.80003 .51599 .806 .52357 .81999 .51947 .81407 .51185 Mtetra
.81407 .51185 .81999 .51947 .83405 .51535 .82818 .50769 Mtetra
.82818 .50769 .83405 .51535 .84818 .51121 .84236 .50351 Mtetra
.84236 .50351 .84818 .51121 .86238 .50705 .85661 .49931 Mtetra
.85661 .49931 .86238 .50705 .87665 .50287 .87093 .49509 Mtetra
.87093 .49509 .87665 .50287 .89099 .49867 .88532 .49085 Mtetra
.664 .741 .908 r
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
0 .203 .692 r
.28559 .45108 .29268 .45784 .30361 .45418 .29577 .45853 Mtetra
0 0 0 r
.29577 .45853 .30361 .45418 .3146 .45051 .30682 .45484 Mtetra
.30682 .45484 .3146 .45051 .32495 .45796 .31792 .45114 Mtetra
.663 .742 .909 r
.31792 .45114 .32495 .45796 .33606 .45427 .32906 .44742 Mtetra
.32906 .44742 .33606 .45427 .34722 .45057 .34024 .44369 Mtetra
.34024 .44369 .34722 .45057 .35843 .44685 .35148 .43994 Mtetra
.35148 .43994 .35843 .44685 .36968 .44311 .36276 .43617 Mtetra
.36276 .43617 .36968 .44311 .38098 .43936 .37409 .43239 Mtetra
.37409 .43239 .38098 .43936 .39233 .43559 .38547 .42859 Mtetra
.38547 .42859 .39233 .43559 .40372 .43181 .3969 .42478 Mtetra
.3969 .42478 .40372 .43181 .41517 .42801 .40837 .42095 Mtetra
.40837 .42095 .41517 .42801 .42666 .42419 .4199 .4171 Mtetra
.4199 .4171 .42666 .42419 .43821 .42036 .43147 .41324 Mtetra
.43147 .41324 .43821 .42036 .4498 .41651 .4431 .40936 Mtetra
.4431 .40936 .4498 .41651 .46144 .41264 .45477 .40546 Mtetra
.45477 .40546 .46144 .41264 .47314 .40876 .4665 .40155 Mtetra
.4665 .40155 .47314 .40876 .48488 .40486 .47827 .39762 Mtetra
.47827 .39762 .48488 .40486 .49667 .40095 .4901 .39367 Mtetra
.4901 .39367 .49667 .40095 .50852 .39701 .50198 .38971 Mtetra
.50198 .38971 .50852 .39701 .52041 .39306 .51391 .38573 Mtetra
.51391 .38573 .52041 .39306 .53268 .52537 .52589 .38173 Mtetra
0 0 .423 r
.52589 .38173 .53268 .52537 .54519 .52153 .53848 .51439 Mtetra
.652 .756 .925 r
.53848 .51439 .54519 .52153 .55776 .51767 .55108 .51049 Mtetra
.55108 .51049 .55776 .51767 .57038 .51379 .56375 .50658 Mtetra
.56375 .50658 .57038 .51379 .58306 .50989 .57647 .50265 Mtetra
.57647 .50265 .58306 .50989 .59581 .50598 .58925 .4987 Mtetra
.58925 .4987 .59581 .50598 .60861 .50204 .60209 .49473 Mtetra
.60209 .49473 .60861 .50204 .62146 .49809 .61499 .49075 Mtetra
.61499 .49075 .62146 .49809 .63438 .49412 .62795 .48675 Mtetra
.944 .581 .226 r
.62795 .48675 .63438 .49412 .64736 .49013 .64343 .55295 Mtetra
.513 .252 .456 r
.64343 .55295 .64736 .49013 .66327 .55629 .65679 .54899 Mtetra
.646 .762 .934 r
.65679 .54899 .66327 .55629 .67666 .55234 .67022 .54501 Mtetra
.67022 .54501 .67666 .55234 .6901 .54838 .68371 .54101 Mtetra
.68371 .54101 .6901 .54838 .70361 .5444 .69727 .537 Mtetra
.69727 .537 .70361 .5444 .71719 .5404 .71089 .53296 Mtetra
.71089 .53296 .71719 .5404 .73083 .53638 .72458 .52891 Mtetra
.72458 .52891 .73083 .53638 .74454 .53234 .73833 .52483 Mtetra
.73833 .52483 .74454 .53234 .75831 .52828 .75215 .52074 Mtetra
.75215 .52074 .75831 .52828 .77215 .5242 .76604 .51662 Mtetra
.76604 .51662 .77215 .5242 .78606 .5201 .77999 .51249 Mtetra
.77999 .51249 .78606 .5201 .80003 .51599 .79401 .50833 Mtetra
.79401 .50833 .80003 .51599 .81407 .51185 .8081 .50416 Mtetra
.8081 .50416 .81407 .51185 .82818 .50769 .82226 .49996 Mtetra
.82226 .49996 .82818 .50769 .84236 .50351 .83649 .49575 Mtetra
.83649 .49575 .84236 .50351 .85661 .49931 .85079 .49151 Mtetra
.85079 .49151 .85661 .49931 .87093 .49509 .86516 .48725 Mtetra
.86516 .48725 .87093 .49509 .88532 .49085 .8796 .48297 Mtetra
.664 .741 .908 r
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
0 .188 .676 r
.25659 .45164 .26379 .4584 .27467 .45475 .26662 .4591 Mtetra
0 0 0 r
.26662 .4591 .27467 .45475 .28559 .45108 .2776 .45541 Mtetra
.2776 .45541 .28559 .45108 .29577 .45853 .28863 .45171 Mtetra
.663 .742 .909 r
.28863 .45171 .29577 .45853 .30682 .45484 .29971 .448 Mtetra
.29971 .448 .30682 .45484 .31792 .45114 .31083 .44426 Mtetra
.31083 .44426 .31792 .45114 .32906 .44742 .322 .44052 Mtetra
.322 .44052 .32906 .44742 .34024 .44369 .33321 .43675 Mtetra
.33321 .43675 .34024 .44369 .35148 .43994 .34448 .43297 Mtetra
.34448 .43297 .35148 .43994 .36276 .43617 .35579 .42918 Mtetra
.35579 .42918 .36276 .43617 .37409 .43239 .36715 .42537 Mtetra
.36715 .42537 .37409 .43239 .38547 .42859 .37856 .42154 Mtetra
.37856 .42154 .38547 .42859 .3969 .42478 .39002 .4177 Mtetra
.39002 .4177 .3969 .42478 .40837 .42095 .40152 .41383 Mtetra
.40152 .41383 .40837 .42095 .4199 .4171 .41308 .40996 Mtetra
.41308 .40996 .4199 .4171 .43147 .41324 .42468 .40606 Mtetra
.42468 .40606 .43147 .41324 .4431 .40936 .43634 .40215 Mtetra
.43634 .40215 .4431 .40936 .45477 .40546 .44805 .39822 Mtetra
.44805 .39822 .45477 .40546 .4665 .40155 .4598 .39428 Mtetra
.4598 .39428 .4665 .40155 .47827 .39762 .47161 .39032 Mtetra
.47161 .39032 .47827 .39762 .4901 .39367 .48347 .38634 Mtetra
.48347 .38634 .4901 .39367 .50198 .38971 .49538 .38234 Mtetra
.49538 .38234 .50198 .38971 .51391 .38573 .50735 .37833 Mtetra
.50735 .37833 .51391 .38573 .52589 .38173 .51936 .3743 Mtetra
.51936 .3743 .52589 .38173 .53848 .51439 .53143 .37025 Mtetra
0 0 .423 r
.53143 .37025 .53848 .51439 .55108 .51049 .54435 .50325 Mtetra
.652 .756 .925 r
.54435 .50325 .55108 .51049 .56375 .50658 .55706 .49931 Mtetra
.55706 .49931 .56375 .50658 .57647 .50265 .56982 .49534 Mtetra
.56982 .49534 .57647 .50265 .58925 .4987 .58264 .49136 Mtetra
.58264 .49136 .58925 .4987 .60209 .49473 .59552 .48736 Mtetra
.947 .587 .243 r
.59552 .48736 .60209 .49473 .61499 .49075 .61023 .55356 Mtetra
.511 .249 .454 r
.61023 .55356 .61499 .49075 .62795 .48675 .62351 .5496 Mtetra
.62351 .5496 .62795 .48675 .64343 .55295 .63685 .54563 Mtetra
.646 .762 .934 r
.63685 .54563 .64343 .55295 .65679 .54899 .65026 .54163 Mtetra
.65026 .54163 .65679 .54899 .67022 .54501 .66373 .53762 Mtetra
.66373 .53762 .67022 .54501 .68371 .54101 .67726 .53358 Mtetra
.67726 .53358 .68371 .54101 .69727 .537 .69087 .52953 Mtetra
.69087 .52953 .69727 .537 .71089 .53296 .70453 .52546 Mtetra
.70453 .52546 .71089 .53296 .72458 .52891 .71826 .52137 Mtetra
.71826 .52137 .72458 .52891 .73833 .52483 .73206 .51726 Mtetra
.73206 .51726 .73833 .52483 .75215 .52074 .74593 .51312 Mtetra
.74593 .51312 .75215 .52074 .76604 .51662 .75986 .50897 Mtetra
.75986 .50897 .76604 .51662 .77999 .51249 .77387 .5048 Mtetra
.77387 .5048 .77999 .51249 .79401 .50833 .78794 .50061 Mtetra
.78794 .50061 .79401 .50833 .8081 .50416 .80208 .4964 Mtetra
.80208 .4964 .8081 .50416 .82226 .49996 .81628 .49216 Mtetra
.81628 .49216 .82226 .49996 .83649 .49575 .83056 .48791 Mtetra
.83056 .48791 .83649 .49575 .85079 .49151 .84491 .48363 Mtetra
.84491 .48363 .85079 .49151 .86516 .48725 .85933 .47933 Mtetra
.85933 .47933 .86516 .48725 .8796 .48297 .87383 .47502 Mtetra
0 0 0 r
.23748 .45966 .24574 .45531 .25659 .45164 .2484 .45598 Mtetra
.2484 .45598 .25659 .45164 .26662 .4591 .25937 .45228 Mtetra
.663 .742 .909 r
.25937 .45228 .26662 .4591 .2776 .45541 .27038 .44857 Mtetra
.27038 .44857 .2776 .45541 .28863 .45171 .28143 .44484 Mtetra
.28143 .44484 .28863 .45171 .29971 .448 .29254 .44109 Mtetra
.29254 .44109 .29971 .448 .31083 .44426 .30369 .43733 Mtetra
.30369 .43733 .31083 .44426 .322 .44052 .31488 .43356 Mtetra
.31488 .43356 .322 .44052 .33321 .43675 .32613 .42976 Mtetra
.32613 .42976 .33321 .43675 .34448 .43297 .33742 .42595 Mtetra
.33742 .42595 .34448 .43297 .35579 .42918 .34876 .42213 Mtetra
.34876 .42213 .35579 .42918 .36715 .42537 .36015 .41829 Mtetra
.36015 .41829 .36715 .42537 .37856 .42154 .37159 .41443 Mtetra
.37159 .41443 .37856 .42154 .39002 .4177 .38308 .41055 Mtetra
.38308 .41055 .39002 .4177 .40152 .41383 .39462 .40666 Mtetra
.39462 .40666 .40152 .41383 .41308 .40996 .4062 .40276 Mtetra
.4062 .40276 .41308 .40996 .42468 .40606 .41784 .39883 Mtetra
.41784 .39883 .42468 .40606 .43634 .40215 .42953 .39489 Mtetra
.42953 .39489 .43634 .40215 .44805 .39822 .44127 .39093 Mtetra
.44127 .39093 .44805 .39822 .4598 .39428 .45306 .38695 Mtetra
.45306 .38695 .4598 .39428 .47161 .39032 .4649 .38296 Mtetra
.4649 .38296 .47161 .39032 .48347 .38634 .47679 .37895 Mtetra
.47679 .37895 .48347 .38634 .49538 .38234 .48874 .37492 Mtetra
.48874 .37492 .49538 .38234 .50735 .37833 .50073 .37087 Mtetra
.50073 .37087 .50735 .37833 .51936 .3743 .51278 .36681 Mtetra
.51278 .36681 .51936 .3743 .53143 .37025 .52489 .36273 Mtetra
.52489 .36273 .53143 .37025 .54435 .50325 .53704 .35863 Mtetra
0 0 .423 r
.53704 .35863 .54435 .50325 .55706 .49931 .55031 .49198 Mtetra
.652 .756 .925 r
.55031 .49198 .55706 .49931 .56982 .49534 .56311 .48798 Mtetra
.56311 .48798 .56982 .49534 .58264 .49136 .57597 .48396 Mtetra
.948 .59 .251 r
.57597 .48396 .58264 .49136 .59552 .48736 .59025 .55021 Mtetra
.509 .246 .451 r
.59025 .55021 .59552 .48736 .61023 .55356 .60351 .54624 Mtetra
.646 .762 .934 r
.60351 .54624 .61023 .55356 .62351 .5496 .61683 .54225 Mtetra
.61683 .54225 .62351 .5496 .63685 .54563 .63021 .53824 Mtetra
.63021 .53824 .63685 .54563 .65026 .54163 .64366 .53421 Mtetra
.64366 .53421 .65026 .54163 .66373 .53762 .65718 .53016 Mtetra
.65718 .53016 .66373 .53762 .67726 .53358 .67076 .52609 Mtetra
.67076 .52609 .67726 .53358 .69087 .52953 .68441 .522 Mtetra
.68441 .522 .69087 .52953 .70453 .52546 .69812 .51789 Mtetra
.69812 .51789 .70453 .52546 .71826 .52137 .7119 .51376 Mtetra
.7119 .51376 .71826 .52137 .73206 .51726 .72574 .50961 Mtetra
.72574 .50961 .73206 .51726 .74593 .51312 .73966 .50544 Mtetra
.73966 .50544 .74593 .51312 .75986 .50897 .75364 .50125 Mtetra
.75364 .50125 .75986 .50897 .77387 .5048 .76769 .49704 Mtetra
.76769 .49704 .77387 .5048 .78794 .50061 .78181 .49281 Mtetra
.78181 .49281 .78794 .50061 .80208 .4964 .79599 .48856 Mtetra
.79599 .48856 .80208 .4964 .81628 .49216 .81025 .48429 Mtetra
.81025 .48429 .81628 .49216 .83056 .48791 .82458 .48 Mtetra
.82458 .48 .83056 .48791 .84491 .48363 .83898 .47568 Mtetra
.83898 .47568 .84491 .48363 .85933 .47933 .85345 .47135 Mtetra
.85345 .47135 .85933 .47933 .87383 .47502 .868 .46699 Mtetra
.663 .742 .909 r
.23012 .45285 .23748 .45966 .2484 .45598 .24106 .44914 Mtetra
.24106 .44914 .2484 .45598 .25937 .45228 .25206 .44541 Mtetra
.25206 .44541 .25937 .45228 .27038 .44857 .26309 .44167 Mtetra
.26309 .44167 .27038 .44857 .28143 .44484 .27418 .43791 Mtetra
.27418 .43791 .28143 .44484 .29254 .44109 .28531 .43414 Mtetra
.28531 .43414 .29254 .44109 .30369 .43733 .29649 .43035 Mtetra
.29649 .43035 .30369 .43733 .31488 .43356 .30771 .42654 Mtetra
.30771 .42654 .31488 .43356 .32613 .42976 .31899 .42272 Mtetra
.31899 .42272 .32613 .42976 .33742 .42595 .33031 .41888 Mtetra
.33031 .41888 .33742 .42595 .34876 .42213 .34168 .41502 Mtetra
.34168 .41502 .34876 .42213 .36015 .41829 .3531 .41115 Mtetra
.3531 .41115 .36015 .41829 .37159 .41443 .36457 .40726 Mtetra
.36457 .40726 .37159 .41443 .38308 .41055 .37609 .40336 Mtetra
.37609 .40336 .38308 .41055 .39462 .40666 .38766 .39944 Mtetra
.38766 .39944 .39462 .40666 .4062 .40276 .39928 .3955 Mtetra
.39928 .3955 .4062 .40276 .41784 .39883 .41094 .39154 Mtetra
.41094 .39154 .41784 .39883 .42953 .39489 .42266 .38757 Mtetra
.42266 .38757 .42953 .39489 .44127 .39093 .43443 .38357 Mtetra
.43443 .38357 .44127 .39093 .45306 .38695 .44626 .37957 Mtetra
.44626 .37957 .45306 .38695 .4649 .38296 .45813 .37554 Mtetra
.45813 .37554 .4649 .38296 .47679 .37895 .47006 .3715 Mtetra
.47006 .3715 .47679 .37895 .48874 .37492 .48204 .36743 Mtetra
.48204 .36743 .48874 .37492 .50073 .37087 .49407 .36335 Mtetra
.49407 .36335 .50073 .37087 .51278 .36681 .50615 .35926 Mtetra
.50615 .35926 .51278 .36681 .52489 .36273 .51829 .35514 Mtetra
.51829 .35514 .52489 .36273 .53704 .35863 .53048 .35101 Mtetra
.53048 .35101 .53704 .35863 .55031 .49198 .54273 .34686 Mtetra
0 0 .423 r
.54273 .34686 .55031 .49198 .56311 .48798 .55634 .48055 Mtetra
.949 .593 .259 r
.55634 .48055 .56311 .48798 .57597 .48396 .57019 .54685 Mtetra
.507 .243 .449 r
.57019 .54685 .57597 .48396 .59025 .55021 .58342 .54286 Mtetra
.646 .762 .934 r
.58342 .54286 .59025 .55021 .60351 .54624 .59672 .53885 Mtetra
.59672 .53885 .60351 .54624 .61683 .54225 .61009 .53483 Mtetra
.61009 .53483 .61683 .54225 .63021 .53824 .62352 .53078 Mtetra
.62352 .53078 .63021 .53824 .64366 .53421 .63701 .52671 Mtetra
.63701 .52671 .64366 .53421 .65718 .53016 .65057 .52263 Mtetra
.65057 .52263 .65718 .53016 .67076 .52609 .6642 .51852 Mtetra
.6642 .51852 .67076 .52609 .68441 .522 .67789 .5144 Mtetra
.67789 .5144 .68441 .522 .69812 .51789 .69165 .51025 Mtetra
.69165 .51025 .69812 .51789 .7119 .51376 .70547 .50609 Mtetra
.70547 .50609 .7119 .51376 .72574 .50961 .71936 .5019 Mtetra
.71936 .5019 .72574 .50961 .73966 .50544 .73332 .49769 Mtetra
.73332 .49769 .73966 .50544 .75364 .50125 .74735 .49347 Mtetra
.74735 .49347 .75364 .50125 .76769 .49704 .76145 .48922 Mtetra
.76145 .48922 .76769 .49704 .78181 .49281 .77562 .48495 Mtetra
.77562 .48495 .78181 .49281 .79599 .48856 .78986 .48066 Mtetra
.78986 .48066 .79599 .48856 .81025 .48429 .80417 .47635 Mtetra
.80417 .47635 .81025 .48429 .82458 .48 .81855 .47201 Mtetra
.81855 .47201 .82458 .48 .83898 .47568 .833 .46766 Mtetra
.833 .46766 .83898 .47568 .85345 .47135 .84752 .46328 Mtetra
.84752 .46328 .85345 .47135 .868 .46699 .86212 .45888 Mtetra
.663 .742 .909 r
.2227 .44599 .23012 .45285 .24106 .44914 .23367 .44225 Mtetra
.23367 .44225 .24106 .44914 .25206 .44541 .24469 .43849 Mtetra
.24469 .43849 .25206 .44541 .26309 .44167 .25575 .43472 Mtetra
.25575 .43472 .26309 .44167 .27418 .43791 .26686 .43093 Mtetra
.26686 .43093 .27418 .43791 .28531 .43414 .27802 .42713 Mtetra
.27802 .42713 .28531 .43414 .29649 .43035 .28923 .42331 Mtetra
.28923 .42331 .29649 .43035 .30771 .42654 .30049 .41947 Mtetra
.30049 .41947 .30771 .42654 .31899 .42272 .31179 .41562 Mtetra
.31179 .41562 .31899 .42272 .33031 .41888 .32314 .41175 Mtetra
.32314 .41175 .33031 .41888 .34168 .41502 .33454 .40786 Mtetra
.33454 .40786 .34168 .41502 .3531 .41115 .34599 .40396 Mtetra
.34599 .40396 .3531 .41115 .36457 .40726 .35749 .40004 Mtetra
.35749 .40004 .36457 .40726 .37609 .40336 .36904 .3961 Mtetra
.36904 .3961 .37609 .40336 .38766 .39944 .38064 .39215 Mtetra
.38064 .39215 .38766 .39944 .39928 .3955 .39229 .38818 Mtetra
.39229 .38818 .39928 .3955 .41094 .39154 .40399 .38419 Mtetra
.40399 .38419 .41094 .39154 .42266 .38757 .41574 .38018 Mtetra
.41574 .38018 .42266 .38757 .43443 .38357 .42755 .37616 Mtetra
.42755 .37616 .43443 .38357 .44626 .37957 .4394 .37212 Mtetra
.4394 .37212 .44626 .37957 .45813 .37554 .45131 .36806 Mtetra
.45131 .36806 .45813 .37554 .47006 .3715 .46327 .36398 Mtetra
.46327 .36398 .47006 .3715 .48204 .36743 .47528 .35989 Mtetra
.47528 .35989 .48204 .36743 .49407 .36335 .48735 .35578 Mtetra
.48735 .35578 .49407 .36335 .50615 .35926 .49947 .35165 Mtetra
.49947 .35165 .50615 .35926 .51829 .35514 .51164 .3475 Mtetra
.51164 .3475 .51829 .35514 .53048 .35101 .52387 .34333 Mtetra
.52387 .34333 .53048 .35101 .54273 .34686 .53615 .33914 Mtetra
.967 .662 .39 r
.53615 .33914 .54273 .34686 .55634 .48055 .55004 .54348 Mtetra
.505 .24 .446 r
.55004 .54348 .55634 .48055 .57019 .54685 .56326 .53947 Mtetra
.646 .762 .934 r
.56326 .53947 .57019 .54685 .58342 .54286 .57654 .53545 Mtetra
.57654 .53545 .58342 .54286 .59672 .53885 .58988 .5314 Mtetra
.58988 .5314 .59672 .53885 .61009 .53483 .60329 .52734 Mtetra
.60329 .52734 .61009 .53483 .62352 .53078 .61676 .52326 Mtetra
.61676 .52326 .62352 .53078 .63701 .52671 .6303 .51916 Mtetra
.6303 .51916 .63701 .52671 .65057 .52263 .64391 .51503 Mtetra
.64391 .51503 .65057 .52263 .6642 .51852 .65758 .51089 Mtetra
.65758 .51089 .6642 .51852 .67789 .5144 .67131 .50673 Mtetra
.67131 .50673 .67789 .5144 .69165 .51025 .68512 .50255 Mtetra
.68512 .50255 .69165 .51025 .70547 .50609 .69899 .49834 Mtetra
.69899 .49834 .70547 .50609 .71936 .5019 .71293 .49412 Mtetra
.71293 .49412 .71936 .5019 .73332 .49769 .72693 .48987 Mtetra
.72693 .48987 .73332 .49769 .74735 .49347 .74101 .48561 Mtetra
.74101 .48561 .74735 .49347 .76145 .48922 .75516 .48132 Mtetra
.75516 .48132 .76145 .48922 .77562 .48495 .76938 .47701 Mtetra
.76938 .47701 .77562 .48495 .78986 .48066 .78366 .47268 Mtetra
.78366 .47268 .78986 .48066 .80417 .47635 .79802 .46833 Mtetra
.79802 .46833 .80417 .47635 .81855 .47201 .81245 .46396 Mtetra
.81245 .46396 .81855 .47201 .833 .46766 .82696 .45956 Mtetra
.82696 .45956 .833 .46766 .84752 .46328 .84153 .45515 Mtetra
.84153 .45515 .84752 .46328 .86212 .45888 .85618 .45071 Mtetra
.663 .742 .909 r
.21522 .43907 .2227 .44599 .23367 .44225 .22622 .4353 Mtetra
.22622 .4353 .23367 .44225 .24469 .43849 .23726 .43152 Mtetra
.23726 .43152 .24469 .43849 .25575 .43472 .24836 .42771 Mtetra
.24836 .42771 .25575 .43472 .26686 .43093 .2595 .4239 Mtetra
.2595 .4239 .26686 .43093 .27802 .42713 .27068 .42006 Mtetra
.27068 .42006 .27802 .42713 .28923 .42331 .28192 .41621 Mtetra
.28192 .41621 .28923 .42331 .30049 .41947 .2932 .41235 Mtetra
.2932 .41235 .30049 .41947 .31179 .41562 .30454 .40846 Mtetra
.30454 .40846 .31179 .41562 .32314 .41175 .31592 .40456 Mtetra
.31592 .40456 .32314 .41175 .33454 .40786 .32735 .40064 Mtetra
.32735 .40064 .33454 .40786 .34599 .40396 .33883 .39671 Mtetra
.33883 .39671 .34599 .40396 .35749 .40004 .35036 .39276 Mtetra
.35036 .39276 .35749 .40004 .36904 .3961 .36194 .38879 Mtetra
.36194 .38879 .36904 .3961 .38064 .39215 .37357 .3848 Mtetra
.37357 .3848 .38064 .39215 .39229 .38818 .38525 .3808 Mtetra
.38525 .3808 .39229 .38818 .40399 .38419 .39698 .37678 Mtetra
.39698 .37678 .40399 .38419 .41574 .38018 .40877 .37274 Mtetra
.40877 .37274 .41574 .38018 .42755 .37616 .4206 .36869 Mtetra
.4206 .36869 .42755 .37616 .4394 .37212 .43249 .36461 Mtetra
.43249 .36461 .4394 .37212 .45131 .36806 .44443 .36052 Mtetra
.44443 .36052 .45131 .36806 .46327 .36398 .45642 .35641 Mtetra
.45642 .35641 .46327 .36398 .47528 .35989 .46847 .35228 Mtetra
.46847 .35228 .47528 .35989 .48735 .35578 .48057 .34814 Mtetra
.48057 .34814 .48735 .35578 .49947 .35165 .49272 .34397 Mtetra
.49272 .34397 .49947 .35165 .51164 .3475 .50493 .33979 Mtetra
.50493 .33979 .51164 .3475 .52387 .34333 .51719 .33558 Mtetra
.51719 .33558 .52387 .34333 .53615 .33914 .52951 .33136 Mtetra
.967 .662 .39 r
.52951 .33136 .53615 .33914 .55004 .54348 .54301 .53607 Mtetra
.646 .762 .934 r
.54301 .53607 .55004 .54348 .56326 .53947 .55627 .53203 Mtetra
.55627 .53203 .56326 .53947 .57654 .53545 .56959 .52797 Mtetra
.56959 .52797 .57654 .53545 .58988 .5314 .58298 .52389 Mtetra
.58298 .52389 .58988 .5314 .60329 .52734 .59643 .51979 Mtetra
.59643 .51979 .60329 .52734 .61676 .52326 .60995 .51567 Mtetra
.60995 .51567 .61676 .52326 .6303 .51916 .62353 .51153 Mtetra
.62353 .51153 .6303 .51916 .64391 .51503 .63718 .50737 Mtetra
.63718 .50737 .64391 .51503 .65758 .51089 .65089 .50319 Mtetra
.65089 .50319 .65758 .51089 .67131 .50673 .66468 .49899 Mtetra
.66468 .49899 .67131 .50673 .68512 .50255 .67853 .49477 Mtetra
.67853 .49477 .68512 .50255 .69899 .49834 .69244 .49053 Mtetra
.69244 .49053 .69899 .49834 .71293 .49412 .70643 .48626 Mtetra
.70643 .48626 .71293 .49412 .72693 .48987 .72049 .48198 Mtetra
.72049 .48198 .72693 .48987 .74101 .48561 .73461 .47768 Mtetra
.73461 .47768 .74101 .48561 .75516 .48132 .74881 .47335 Mtetra
.74881 .47335 .75516 .48132 .76938 .47701 .76308 .469 Mtetra
.76308 .469 .76938 .47701 .78366 .47268 .77741 .46463 Mtetra
.77741 .46463 .78366 .47268 .79802 .46833 .79182 .46024 Mtetra
.79182 .46024 .79802 .46833 .81245 .46396 .80631 .45583 Mtetra
.80631 .45583 .81245 .46396 .82696 .45956 .82086 .45139 Mtetra
.82086 .45139 .82696 .45956 .84153 .45515 .83549 .44693 Mtetra
.83549 .44693 .84153 .45515 .85618 .45071 .85019 .44245 Mtetra
.663 .742 .909 r
.20768 .4321 .21522 .43907 .22622 .4353 .2187 .4283 Mtetra
.2187 .4283 .22622 .4353 .23726 .43152 .22978 .42449 Mtetra
.22978 .42449 .23726 .43152 .24836 .42771 .2409 .42065 Mtetra
.2409 .42065 .24836 .42771 .2595 .4239 .25207 .41681 Mtetra
.25207 .41681 .2595 .4239 .27068 .42006 .26328 .41294 Mtetra
.26328 .41294 .27068 .42006 .28192 .41621 .27455 .40906 Mtetra
.27455 .40906 .28192 .41621 .2932 .41235 .28586 .40516 Mtetra
.28586 .40516 .2932 .41235 .30454 .40846 .29722 .40125 Mtetra
.29722 .40125 .30454 .40846 .31592 .40456 .30863 .39732 Mtetra
.30863 .39732 .31592 .40456 .32735 .40064 .32009 .39337 Mtetra
.32009 .39337 .32735 .40064 .33883 .39671 .3316 .3894 Mtetra
.3316 .3894 .33883 .39671 .35036 .39276 .34317 .38542 Mtetra
.34317 .38542 .35036 .39276 .36194 .38879 .35478 .38142 Mtetra
.35478 .38142 .36194 .38879 .37357 .3848 .36644 .3774 Mtetra
.36644 .3774 .37357 .3848 .38525 .3808 .37815 .37336 Mtetra
.37815 .37336 .38525 .3808 .39698 .37678 .38992 .36931 Mtetra
.38992 .36931 .39698 .37678 .40877 .37274 .40173 .36524 Mtetra
.40173 .36524 .40877 .37274 .4206 .36869 .4136 .36115 Mtetra
.4136 .36115 .4206 .36869 .43249 .36461 .42552 .35704 Mtetra
.42552 .35704 .43249 .36461 .44443 .36052 .4375 .35292 Mtetra
.4375 .35292 .44443 .36052 .45642 .35641 .44952 .34877 Mtetra
.44952 .34877 .45642 .35641 .46847 .35228 .4616 .34461 Mtetra
.4616 .34461 .46847 .35228 .48057 .34814 .47374 .34043 Mtetra
.47374 .34043 .48057 .34814 .49272 .34397 .48593 .33623 Mtetra
.48593 .33623 .49272 .34397 .50493 .33979 .49817 .33201 Mtetra
.49817 .33201 .50493 .33979 .51719 .33558 .51047 .32778 Mtetra
.51047 .32778 .51719 .33558 .52951 .33136 .52282 .32352 Mtetra
0 .008 .534 r
.52282 .32352 .52951 .33136 .54301 .53607 .53529 .33666 Mtetra
0 0 .395 r
.53529 .33666 .54301 .53607 .55627 .53203 .54922 .52452 Mtetra
.646 .762 .934 r
.54922 .52452 .55627 .53203 .56959 .52797 .56259 .52042 Mtetra
.56259 .52042 .56959 .52797 .58298 .52389 .57602 .5163 Mtetra
.57602 .5163 .58298 .52389 .59643 .51979 .58951 .51217 Mtetra
.58951 .51217 .59643 .51979 .60995 .51567 .60307 .50801 Mtetra
.60307 .50801 .60995 .51567 .62353 .51153 .6167 .50383 Mtetra
.6167 .50383 .62353 .51153 .63718 .50737 .63039 .49964 Mtetra
.63039 .49964 .63718 .50737 .65089 .50319 .64415 .49542 Mtetra
.64415 .49542 .65089 .50319 .66468 .49899 .65798 .49118 Mtetra
.65798 .49118 .66468 .49899 .67853 .49477 .67188 .48692 Mtetra
.67188 .48692 .67853 .49477 .69244 .49053 .68584 .48264 Mtetra
.68584 .48264 .69244 .49053 .70643 .48626 .69988 .47834 Mtetra
.69988 .47834 .70643 .48626 .72049 .48198 .71398 .47402 Mtetra
.71398 .47402 .72049 .48198 .73461 .47768 .72815 .46967 Mtetra
.72815 .46967 .73461 .47768 .74881 .47335 .7424 .46531 Mtetra
.7424 .46531 .74881 .47335 .76308 .469 .75672 .46092 Mtetra
.75672 .46092 .76308 .469 .77741 .46463 .77111 .45651 Mtetra
.77111 .45651 .77741 .46463 .79182 .46024 .78557 .45207 Mtetra
.78557 .45207 .79182 .46024 .80631 .45583 .8001 .44762 Mtetra
.8001 .44762 .80631 .45583 .82086 .45139 .81471 .44314 Mtetra
.81471 .44314 .82086 .45139 .83549 .44693 .82939 .43864 Mtetra
.82939 .43864 .83549 .44693 .85019 .44245 .84415 .43412 Mtetra
.663 .742 .909 r
.20008 .42507 .20768 .4321 .2187 .4283 .21113 .42124 Mtetra
.21113 .42124 .2187 .4283 .22978 .42449 .22224 .4174 Mtetra
.22224 .4174 .22978 .42449 .2409 .42065 .23338 .41354 Mtetra
.23338 .41354 .2409 .42065 .25207 .41681 .24458 .40966 Mtetra
.24458 .40966 .25207 .41681 .26328 .41294 .25583 .40576 Mtetra
.25583 .40576 .26328 .41294 .27455 .40906 .26712 .40185 Mtetra
.26712 .40185 .27455 .40906 .28586 .40516 .27846 .39792 Mtetra
.27846 .39792 .28586 .40516 .29722 .40125 .28985 .39398 Mtetra
.28985 .39398 .29722 .40125 .30863 .39732 .30129 .39001 Mtetra
.30129 .39001 .30863 .39732 .32009 .39337 .31278 .38603 Mtetra
.31278 .38603 .32009 .39337 .3316 .3894 .32432 .38203 Mtetra
.32432 .38203 .3316 .3894 .34317 .38542 .33592 .37802 Mtetra
.33592 .37802 .34317 .38542 .35478 .38142 .34756 .37399 Mtetra
.34756 .37399 .35478 .38142 .36644 .3774 .35925 .36994 Mtetra
.35925 .36994 .36644 .3774 .37815 .37336 .371 .36587 Mtetra
.371 .36587 .37815 .37336 .38992 .36931 .38279 .36178 Mtetra
.38279 .36178 .38992 .36931 .40173 .36524 .39464 .35768 Mtetra
.39464 .35768 .40173 .36524 .4136 .36115 .40654 .35355 Mtetra
.40654 .35355 .4136 .36115 .42552 .35704 .4185 .34941 Mtetra
.4185 .34941 .42552 .35704 .4375 .35292 .4305 .34525 Mtetra
.4305 .34525 .4375 .35292 .44952 .34877 .44256 .34108 Mtetra
.44256 .34108 .44952 .34877 .4616 .34461 .45468 .33688 Mtetra
.45468 .33688 .4616 .34461 .47374 .34043 .46685 .33266 Mtetra
.46685 .33266 .47374 .34043 .48593 .33623 .47907 .32843 Mtetra
.47907 .32843 .48593 .33623 .49817 .33201 .49135 .32418 Mtetra
.49135 .32418 .49817 .33201 .51047 .32778 .50369 .3199 Mtetra
0 0 .523 r
.50369 .3199 .51047 .32778 .52282 .32352 .51603 .33304 Mtetra
.228 0 0 r
.51603 .33304 .52282 .32352 .53529 .33666 .52854 .32874 Mtetra
.662 .744 .911 r
.52854 .32874 .53529 .33666 .54922 .52452 .54112 .32443 Mtetra
.548 .34 .55 r
.54112 .32443 .54922 .52452 .56259 .52042 .55375 .32009 Mtetra
0 0 .4 r
.55375 .32009 .56259 .52042 .57602 .5163 .56899 .50865 Mtetra
.646 .762 .934 r
.56899 .50865 .57602 .5163 .58951 .51217 .58253 .50448 Mtetra
.58253 .50448 .58951 .51217 .60307 .50801 .59613 .50028 Mtetra
.59613 .50028 .60307 .50801 .6167 .50383 .6098 .49607 Mtetra
.6098 .49607 .6167 .50383 .63039 .49964 .62354 .49183 Mtetra
.62354 .49183 .63039 .49964 .64415 .49542 .63735 .48758 Mtetra
.63735 .48758 .64415 .49542 .65798 .49118 .65122 .4833 Mtetra
.65122 .4833 .65798 .49118 .67188 .48692 .66517 .479 Mtetra
.66517 .479 .67188 .48692 .68584 .48264 .67918 .47468 Mtetra
.67918 .47468 .68584 .48264 .69988 .47834 .69326 .47034 Mtetra
.69326 .47034 .69988 .47834 .71398 .47402 .70741 .46598 Mtetra
.70741 .46598 .71398 .47402 .72815 .46967 .72164 .46159 Mtetra
.72164 .46159 .72815 .46967 .7424 .46531 .73593 .45719 Mtetra
.73593 .45719 .7424 .46531 .75672 .46092 .7503 .45276 Mtetra
.7503 .45276 .75672 .46092 .77111 .45651 .76474 .44831 Mtetra
.76474 .44831 .77111 .45651 .78557 .45207 .77925 .44383 Mtetra
.77925 .44383 .78557 .45207 .8001 .44762 .79384 .43934 Mtetra
.79384 .43934 .8001 .44762 .81471 .44314 .8085 .43482 Mtetra
.8085 .43482 .81471 .44314 .82939 .43864 .82323 .43027 Mtetra
.82323 .43027 .82939 .43864 .84415 .43412 .83804 .42571 Mtetra
.663 .742 .909 r
.19242 .41799 .20008 .42507 .21113 .42124 .2035 .41413 Mtetra
.2035 .41413 .21113 .42124 .22224 .4174 .21463 .41026 Mtetra
.21463 .41026 .22224 .4174 .23338 .41354 .22581 .40636 Mtetra
.22581 .40636 .23338 .41354 .24458 .40966 .23703 .40245 Mtetra
.23703 .40245 .24458 .40966 .25583 .40576 .24831 .39853 Mtetra
.24831 .39853 .25583 .40576 .26712 .40185 .25963 .39458 Mtetra
.25963 .39458 .26712 .40185 .27846 .39792 .271 .39062 Mtetra
.271 .39062 .27846 .39792 .28985 .39398 .28242 .38665 Mtetra
.28242 .38665 .28985 .39398 .30129 .39001 .29389 .38265 Mtetra
.29389 .38265 .30129 .39001 .31278 .38603 .30541 .37864 Mtetra
.30541 .37864 .31278 .38603 .32432 .38203 .31698 .37461 Mtetra
.31698 .37461 .32432 .38203 .33592 .37802 .32861 .37056 Mtetra
.32861 .37056 .33592 .37802 .34756 .37399 .34028 .36649 Mtetra
.34028 .36649 .34756 .37399 .35925 .36994 .352 .36241 Mtetra
.352 .36241 .35925 .36994 .371 .36587 .36378 .35831 Mtetra
.36378 .35831 .371 .36587 .38279 .36178 .37561 .35419 Mtetra
.37561 .35419 .38279 .36178 .39464 .35768 .38749 .35005 Mtetra
.38749 .35005 .39464 .35768 .40654 .35355 .39943 .34589 Mtetra
.39943 .34589 .40654 .35355 .4185 .34941 .41141 .34172 Mtetra
.41141 .34172 .4185 .34941 .4305 .34525 .42345 .33753 Mtetra
.42345 .33753 .4305 .34525 .44256 .34108 .43555 .33331 Mtetra
.43555 .33331 .44256 .34108 .45468 .33688 .4477 .32908 Mtetra
.4477 .32908 .45468 .33688 .46685 .33266 .4599 .32483 Mtetra
.4599 .32483 .46685 .33266 .47907 .32843 .47216 .32056 Mtetra
.47216 .32056 .47907 .32843 .49135 .32418 .48448 .31627 Mtetra
0 0 .512 r
.48448 .31627 .49135 .32418 .50369 .3199 .49669 .3294 Mtetra
.22 0 0 r
.49669 .3294 .50369 .3199 .51603 .33304 .50919 .32509 Mtetra
.662 .744 .911 r
.50919 .32509 .51603 .33304 .52854 .32874 .52174 .32076 Mtetra
.52174 .32076 .52854 .32874 .54112 .32443 .53435 .31641 Mtetra
.53435 .31641 .54112 .32443 .55375 .32009 .54702 .31204 Mtetra
.54702 .31204 .55375 .32009 .56899 .50865 .55975 .30764 Mtetra
0 0 .4 r
.55975 .30764 .56899 .50865 .58253 .50448 .57548 .49672 Mtetra
.646 .762 .934 r
.57548 .49672 .58253 .50448 .59613 .50028 .58913 .49249 Mtetra
.58913 .49249 .59613 .50028 .6098 .49607 .60285 .48823 Mtetra
.60285 .48823 .6098 .49607 .62354 .49183 .61663 .48396 Mtetra
.61663 .48396 .62354 .49183 .63735 .48758 .63048 .47967 Mtetra
.63048 .47967 .63735 .48758 .65122 .4833 .6444 .47535 Mtetra
.6444 .47535 .65122 .4833 .66517 .479 .65839 .47101 Mtetra
.65839 .47101 .66517 .479 .67918 .47468 .67245 .46665 Mtetra
.67245 .46665 .67918 .47468 .69326 .47034 .68658 .46227 Mtetra
.68658 .46227 .69326 .47034 .70741 .46598 .70079 .45787 Mtetra
.70079 .45787 .70741 .46598 .72164 .46159 .71506 .45344 Mtetra
.71506 .45344 .72164 .46159 .73593 .45719 .7294 .44899 Mtetra
.7294 .44899 .73593 .45719 .7503 .45276 .74382 .44452 Mtetra
.74382 .44452 .7503 .45276 .76474 .44831 .75831 .44003 Mtetra
.75831 .44003 .76474 .44831 .77925 .44383 .77288 .43551 Mtetra
.77288 .43551 .77925 .44383 .79384 .43934 .78751 .43097 Mtetra
.78751 .43097 .79384 .43934 .8085 .43482 .80223 .42641 Mtetra
.80223 .42641 .8085 .43482 .82323 .43027 .81702 .42183 Mtetra
.81702 .42183 .82323 .43027 .83804 .42571 .83188 .41722 Mtetra
.663 .742 .909 r
.1847 .41085 .19242 .41799 .2035 .41413 .19581 .40696 Mtetra
.19581 .40696 .2035 .41413 .21463 .41026 .20697 .40306 Mtetra
.20697 .40306 .21463 .41026 .22581 .40636 .21817 .39913 Mtetra
.21817 .39913 .22581 .40636 .23703 .40245 .22943 .39519 Mtetra
.22943 .39519 .23703 .40245 .24831 .39853 .24073 .39123 Mtetra
.24073 .39123 .24831 .39853 .25963 .39458 .25208 .38726 Mtetra
.25208 .38726 .25963 .39458 .271 .39062 .26348 .38327 Mtetra
.26348 .38327 .271 .39062 .28242 .38665 .27493 .37926 Mtetra
.27493 .37926 .28242 .38665 .29389 .38265 .28643 .37523 Mtetra
.28643 .37523 .29389 .38265 .30541 .37864 .29798 .37118 Mtetra
.29798 .37118 .30541 .37864 .31698 .37461 .30959 .36712 Mtetra
.30959 .36712 .31698 .37461 .32861 .37056 .32124 .36304 Mtetra
.32124 .36304 .32861 .37056 .34028 .36649 .33294 .35894 Mtetra
.33294 .35894 .34028 .36649 .352 .36241 .3447 .35482 Mtetra
.3447 .35482 .352 .36241 .36378 .35831 .35651 .35069 Mtetra
.35651 .35069 .36378 .35831 .37561 .35419 .36837 .34654 Mtetra
.36837 .34654 .37561 .35419 .38749 .35005 .38028 .34236 Mtetra
.38028 .34236 .38749 .35005 .39943 .34589 .39225 .33817 Mtetra
.39225 .33817 .39943 .34589 .41141 .34172 .40427 .33396 Mtetra
.40427 .33396 .41141 .34172 .42345 .33753 .41635 .32973 Mtetra
.41635 .32973 .42345 .33753 .43555 .33331 .42848 .32549 Mtetra
.42848 .32549 .43555 .33331 .4477 .32908 .44066 .32122 Mtetra
.44066 .32122 .4477 .32908 .4599 .32483 .4529 .31693 Mtetra
.4529 .31693 .4599 .32483 .47216 .32056 .46519 .31263 Mtetra
0 0 .5 r
.46519 .31263 .47216 .32056 .48448 .31627 .47728 .32576 Mtetra
.212 0 0 r
.47728 .32576 .48448 .31627 .49669 .3294 .48976 .32143 Mtetra
.662 .744 .911 r
.48976 .32143 .49669 .3294 .50919 .32509 .50229 .31708 Mtetra
.50229 .31708 .50919 .32509 .52174 .32076 .51488 .31271 Mtetra
.51488 .31271 .52174 .32076 .53435 .31641 .52753 .30832 Mtetra
.52753 .30832 .53435 .31641 .54702 .31204 .54023 .30391 Mtetra
.54023 .30391 .54702 .31204 .55975 .30764 .553 .29948 Mtetra
.553 .29948 .55975 .30764 .57548 .49672 .56582 .29503 Mtetra
.545 .336 .547 r
.56582 .29503 .57548 .49672 .58913 .49249 .57871 .29056 Mtetra
0 0 .405 r
.57871 .29056 .58913 .49249 .60285 .48823 .59582 .48033 Mtetra
.646 .762 .934 r
.59582 .48033 .60285 .48823 .61663 .48396 .60965 .47601 Mtetra
.60965 .47601 .61663 .48396 .63048 .47967 .62355 .47168 Mtetra
.62355 .47168 .63048 .47967 .6444 .47535 .63752 .46732 Mtetra
.63752 .46732 .6444 .47535 .65839 .47101 .65156 .46295 Mtetra
.65156 .46295 .65839 .47101 .67245 .46665 .66567 .45855 Mtetra
.66567 .45855 .67245 .46665 .68658 .46227 .67985 .45412 Mtetra
.67985 .45412 .68658 .46227 .70079 .45787 .6941 .44968 Mtetra
.6941 .44968 .70079 .45787 .71506 .45344 .70842 .44521 Mtetra
.70842 .44521 .71506 .45344 .7294 .44899 .72281 .44072 Mtetra
.72281 .44072 .7294 .44899 .74382 .44452 .73728 .43621 Mtetra
.73728 .43621 .74382 .44452 .75831 .44003 .75183 .43167 Mtetra
.75183 .43167 .75831 .44003 .77288 .43551 .76644 .42712 Mtetra
.76644 .42712 .77288 .43551 .78751 .43097 .78113 .42253 Mtetra
.78113 .42253 .78751 .43097 .80223 .42641 .7959 .41793 Mtetra
.7959 .41793 .80223 .42641 .81702 .42183 .81074 .4133 Mtetra
.81074 .4133 .81702 .42183 .83188 .41722 .82566 .40865 Mtetra
.663 .742 .909 r
.17692 .40366 .1847 .41085 .19581 .40696 .18806 .39974 Mtetra
.18806 .39974 .19581 .40696 .20697 .40306 .19924 .3958 Mtetra
.19924 .3958 .20697 .40306 .21817 .39913 .21048 .39184 Mtetra
.21048 .39184 .21817 .39913 .22943 .39519 .22176 .38787 Mtetra
.22176 .38787 .22943 .39519 .24073 .39123 .23309 .38388 Mtetra
.23309 .38388 .24073 .39123 .25208 .38726 .24447 .37987 Mtetra
.24447 .37987 .25208 .38726 .26348 .38327 .2559 .37585 Mtetra
.2559 .37585 .26348 .38327 .27493 .37926 .26738 .37181 Mtetra
.26738 .37181 .27493 .37926 .28643 .37523 .27891 .36775 Mtetra
.27891 .36775 .28643 .37523 .29798 .37118 .29049 .36367 Mtetra
.29049 .36367 .29798 .37118 .30959 .36712 .30213 .35957 Mtetra
.30213 .35957 .30959 .36712 .32124 .36304 .31381 .35546 Mtetra
.31381 .35546 .32124 .36304 .33294 .35894 .32555 .35133 Mtetra
.32555 .35133 .33294 .35894 .3447 .35482 .33733 .34718 Mtetra
.33733 .34718 .3447 .35482 .35651 .35069 .34918 .34301 Mtetra
.34918 .34301 .35651 .35069 .36837 .34654 .36107 .33882 Mtetra
.36107 .33882 .36837 .34654 .38028 .34236 .37302 .33461 Mtetra
.37302 .33461 .38028 .34236 .39225 .33817 .38502 .33039 Mtetra
.38502 .33039 .39225 .33817 .40427 .33396 .39707 .32614 Mtetra
.39707 .32614 .40427 .33396 .41635 .32973 .40918 .32188 Mtetra
.40918 .32188 .41635 .32973 .42848 .32549 .42134 .31759 Mtetra
.42134 .31759 .42848 .32549 .44066 .32122 .43356 .31329 Mtetra
.43356 .31329 .44066 .32122 .4529 .31693 .44584 .30897 Mtetra
.44584 .30897 .4529 .31693 .46519 .31263 .45817 .30463 Mtetra
0 0 .5 r
.45817 .30463 .46519 .31263 .47728 .32576 .47025 .31775 Mtetra
.662 .744 .911 r
.47025 .31775 .47728 .32576 .48976 .32143 .48276 .31338 Mtetra
.48276 .31338 .48976 .32143 .50229 .31708 .49533 .309 Mtetra
.49533 .309 .50229 .31708 .51488 .31271 .50796 .30459 Mtetra
.50796 .30459 .51488 .31271 .52753 .30832 .52065 .30017 Mtetra
.52065 .30017 .52753 .30832 .54023 .30391 .53339 .29572 Mtetra
.53339 .29572 .54023 .30391 .553 .29948 .54619 .29125 Mtetra
.54619 .29125 .553 .29948 .56582 .29503 .55906 .28676 Mtetra
.55906 .28676 .56582 .29503 .57871 .29056 .57198 .28225 Mtetra
.57198 .28225 .57871 .29056 .59582 .48033 .58497 .27772 Mtetra
0 0 .405 r
.58497 .27772 .59582 .48033 .60965 .47601 .60261 .468 Mtetra
.646 .762 .934 r
.60261 .468 .60965 .47601 .62355 .47168 .61656 .46362 Mtetra
.61656 .46362 .62355 .47168 .63752 .46732 .63057 .45922 Mtetra
.63057 .45922 .63752 .46732 .65156 .46295 .64466 .45481 Mtetra
.64466 .45481 .65156 .46295 .66567 .45855 .65882 .45036 Mtetra
.65882 .45036 .66567 .45855 .67985 .45412 .67304 .4459 Mtetra
.67304 .4459 .67985 .45412 .6941 .44968 .68734 .44141 Mtetra
.68734 .44141 .6941 .44968 .70842 .44521 .70172 .43691 Mtetra
.70172 .43691 .70842 .44521 .72281 .44072 .71616 .43237 Mtetra
.71616 .43237 .72281 .44072 .73728 .43621 .73068 .42782 Mtetra
.73068 .42782 .73728 .43621 .75183 .43167 .74528 .42324 Mtetra
.74528 .42324 .75183 .43167 .76644 .42712 .75995 .41864 Mtetra
.75995 .41864 .76644 .42712 .78113 .42253 .77469 .41401 Mtetra
.77469 .41401 .78113 .42253 .7959 .41793 .78951 .40936 Mtetra
.78951 .40936 .7959 .41793 .81074 .4133 .80441 .40469 Mtetra
.80441 .40469 .81074 .4133 .82566 .40865 .81938 .39999 Mtetra
.624 .542 .741 r
.17033 .3851 .17692 .40366 .18806 .39974 .18146 .38114 Mtetra
.18146 .38114 .18806 .39974 .19924 .3958 .19263 .37715 Mtetra
.285 .336 .74 r
.19263 .37715 .19924 .3958 .21048 .39184 .20272 .3845 Mtetra
.663 .742 .909 r
.20272 .3845 .21048 .39184 .22176 .38787 .21403 .38049 Mtetra
.21403 .38049 .22176 .38787 .23309 .38388 .22539 .37647 Mtetra
.22539 .37647 .23309 .38388 .24447 .37987 .2368 .37243 Mtetra
.2368 .37243 .24447 .37987 .2559 .37585 .24826 .36837 Mtetra
.24826 .36837 .2559 .37585 .26738 .37181 .25977 .3643 Mtetra
.25977 .3643 .26738 .37181 .27891 .36775 .27133 .3602 Mtetra
.27133 .3602 .27891 .36775 .29049 .36367 .28294 .35609 Mtetra
.28294 .35609 .29049 .36367 .30213 .35957 .2946 .35196 Mtetra
.2946 .35196 .30213 .35957 .31381 .35546 .30632 .34782 Mtetra
.30632 .34782 .31381 .35546 .32555 .35133 .31809 .34365 Mtetra
.31809 .34365 .32555 .35133 .33733 .34718 .32991 .33946 Mtetra
.32991 .33946 .33733 .34718 .34918 .34301 .34178 .33526 Mtetra
.34178 .33526 .34918 .34301 .36107 .33882 .35371 .33104 Mtetra
.35371 .33104 .36107 .33882 .37302 .33461 .36569 .3268 Mtetra
.36569 .3268 .37302 .33461 .38502 .33039 .37772 .32253 Mtetra
.37772 .32253 .38502 .33039 .39707 .32614 .38981 .31825 Mtetra
.38981 .31825 .39707 .32614 .40918 .32188 .40195 .31396 Mtetra
.40195 .31396 .40918 .32188 .42134 .31759 .41415 .30964 Mtetra
.41415 .30964 .42134 .31759 .43356 .31329 .42641 .3053 Mtetra
.42641 .3053 .43356 .31329 .44584 .30897 .43872 .30094 Mtetra
0 0 .488 r
.43872 .30094 .44584 .30897 .45817 .30463 .45067 .31406 Mtetra
.196 0 0 r
.45067 .31406 .45817 .30463 .47025 .31775 .46316 .30967 Mtetra
.662 .744 .911 r
.46316 .30967 .47025 .31775 .48276 .31338 .47571 .30527 Mtetra
.47571 .30527 .48276 .31338 .49533 .309 .48831 .30085 Mtetra
.48831 .30085 .49533 .309 .50796 .30459 .50098 .2964 Mtetra
.50098 .2964 .50796 .30459 .52065 .30017 .5137 .29194 Mtetra
.5137 .29194 .52065 .30017 .53339 .29572 .52649 .28745 Mtetra
.52649 .28745 .53339 .29572 .54619 .29125 .53933 .28295 Mtetra
.53933 .28295 .54619 .29125 .55906 .28676 .55223 .27842 Mtetra
.55223 .27842 .55906 .28676 .57198 .28225 .5652 .27387 Mtetra
.5652 .27387 .57198 .28225 .58497 .27772 .57822 .2693 Mtetra
.57822 .2693 .58497 .27772 .60261 .468 .59131 .26471 Mtetra
0 0 .405 r
.59131 .26471 .60261 .468 .61656 .46362 .6095 .45549 Mtetra
.646 .762 .934 r
.6095 .45549 .61656 .46362 .63057 .45922 .62356 .45105 Mtetra
.62356 .45105 .63057 .45922 .64466 .45481 .6377 .44659 Mtetra
.6377 .44659 .64466 .45481 .65882 .45036 .6519 .44211 Mtetra
.6519 .44211 .65882 .45036 .67304 .4459 .66618 .4376 Mtetra
.66618 .4376 .67304 .4459 .68734 .44141 .68053 .43307 Mtetra
.68053 .43307 .68734 .44141 .70172 .43691 .69495 .42852 Mtetra
.69495 .42852 .70172 .43691 .71616 .43237 .70945 .42395 Mtetra
.70945 .42395 .71616 .43237 .73068 .42782 .72402 .41935 Mtetra
.72402 .41935 .73068 .42782 .74528 .42324 .73867 .41473 Mtetra
.73867 .41473 .74528 .42324 .75995 .41864 .75339 .41008 Mtetra
.75339 .41008 .75995 .41864 .77469 .41401 .76819 .40541 Mtetra
.76819 .40541 .77469 .41401 .78951 .40936 .78306 .40072 Mtetra
.78306 .40072 .78951 .40936 .80441 .40469 .79801 .396 Mtetra
.79801 .396 .80441 .40469 .81938 .39999 .81304 .39126 Mtetra
.664 .741 .908 r
.16246 .37777 .17033 .3851 .18146 .38114 .17361 .37377 Mtetra
.17361 .37377 .18146 .38114 .19263 .37715 .18482 .36976 Mtetra
.18482 .36976 .19263 .37715 .20272 .3845 .19607 .36573 Mtetra
.623 .542 .741 r
.19607 .36573 .20272 .3845 .21403 .38049 .20737 .36168 Mtetra
.20737 .36168 .21403 .38049 .22539 .37647 .21872 .35762 Mtetra
.21872 .35762 .22539 .37647 .2368 .37243 .23012 .35354 Mtetra
.23012 .35354 .2368 .37243 .24826 .36837 .24157 .34943 Mtetra
.24157 .34943 .24826 .36837 .25977 .3643 .25307 .34532 Mtetra
.25307 .34532 .25977 .3643 .27133 .3602 .26462 .34118 Mtetra
.26462 .34118 .27133 .3602 .28294 .35609 .27623 .33702 Mtetra
.27623 .33702 .28294 .35609 .2946 .35196 .28788 .33285 Mtetra
.28788 .33285 .2946 .35196 .30632 .34782 .29959 .32866 Mtetra
.29959 .32866 .30632 .34782 .31809 .34365 .31135 .32444 Mtetra
.31135 .32444 .31809 .34365 .32991 .33946 .32316 .32021 Mtetra
.32316 .32021 .32991 .33946 .34178 .33526 .33502 .31597 Mtetra
.33502 .31597 .34178 .33526 .35371 .33104 .34694 .3117 Mtetra
.34694 .3117 .35371 .33104 .36569 .3268 .35891 .30741 Mtetra
.35891 .30741 .36569 .3268 .37772 .32253 .37093 .3031 Mtetra
.37093 .3031 .37772 .32253 .38981 .31825 .38301 .29878 Mtetra
.38301 .29878 .38981 .31825 .40195 .31396 .39515 .29443 Mtetra
.333 .366 .746 r
.39515 .29443 .40195 .31396 .41415 .30964 .4069 .30161 Mtetra
.663 .742 .909 r
.4069 .30161 .41415 .30964 .42641 .3053 .41919 .29724 Mtetra
0 0 .476 r
.41919 .29724 .42641 .3053 .43872 .30094 .43101 .31035 Mtetra
.188 0 0 r
.43101 .31035 .43872 .30094 .45067 .31406 .44348 .30595 Mtetra
.662 .744 .911 r
.44348 .30595 .45067 .31406 .46316 .30967 .45601 .30153 Mtetra
.45601 .30153 .46316 .30967 .47571 .30527 .46859 .29709 Mtetra
.46859 .29709 .47571 .30527 .48831 .30085 .48124 .29263 Mtetra
.48124 .29263 .48831 .30085 .50098 .2964 .49394 .28815 Mtetra
.49394 .28815 .50098 .2964 .5137 .29194 .5067 .28364 Mtetra
.5067 .28364 .5137 .29194 .52649 .28745 .51953 .27912 Mtetra
.51953 .27912 .52649 .28745 .53933 .28295 .53241 .27457 Mtetra
.53241 .27457 .53933 .28295 .55223 .27842 .54535 .27001 Mtetra
.54535 .27001 .55223 .27842 .5652 .27387 .55836 .26542 Mtetra
.55836 .26542 .5652 .27387 .57822 .2693 .57142 .26081 Mtetra
.57142 .26081 .57822 .2693 .59131 .26471 .58455 .25618 Mtetra
.58455 .25618 .59131 .26471 .6095 .45549 .59774 .25152 Mtetra
.541 .329 .542 r
.59774 .25152 .6095 .45549 .62356 .45105 .61099 .24685 Mtetra
0 0 .409 r
.61099 .24685 .62356 .45105 .6377 .44659 .63067 .4383 Mtetra
.646 .762 .934 r
.63067 .4383 .6377 .44659 .6519 .44211 .64492 .43377 Mtetra
.64492 .43377 .6519 .44211 .66618 .4376 .65925 .42922 Mtetra
.65925 .42922 .66618 .4376 .68053 .43307 .67365 .42465 Mtetra
.67365 .42465 .68053 .43307 .69495 .42852 .68812 .42006 Mtetra
.68812 .42006 .69495 .42852 .70945 .42395 .70267 .41544 Mtetra
.70267 .41544 .70945 .42395 .72402 .41935 .71729 .4108 Mtetra
.71729 .4108 .72402 .41935 .73867 .41473 .73199 .40613 Mtetra
.73199 .40613 .73867 .41473 .75339 .41008 .74677 .40144 Mtetra
.74677 .40144 .75339 .41008 .76819 .40541 .76162 .39673 Mtetra
.76162 .39673 .76819 .40541 .78306 .40072 .77655 .39199 Mtetra
.77655 .39199 .78306 .40072 .79801 .396 .79155 .38723 Mtetra
.79155 .38723 .79801 .396 .81304 .39126 .80664 .38244 Mtetra
.664 .741 .908 r
.15452 .37038 .16246 .37777 .17361 .37377 .16571 .36635 Mtetra
.16571 .36635 .17361 .37377 .18482 .36976 .17694 .36231 Mtetra
.17694 .36231 .18482 .36976 .19607 .36573 .18822 .35825 Mtetra
.18822 .35825 .19607 .36573 .20737 .36168 .19955 .35416 Mtetra
.19955 .35416 .20737 .36168 .21872 .35762 .21093 .35007 Mtetra
.21093 .35007 .21872 .35762 .23012 .35354 .22236 .34595 Mtetra
.22236 .34595 .23012 .35354 .24157 .34943 .23384 .34182 Mtetra
.23384 .34182 .24157 .34943 .25307 .34532 .24537 .33766 Mtetra
.24537 .33766 .25307 .34532 .26462 .34118 .25695 .33349 Mtetra
.25695 .33349 .26462 .34118 .27623 .33702 .26858 .3293 Mtetra
.26858 .3293 .27623 .33702 .28788 .33285 .28027 .32509 Mtetra
.28027 .32509 .28788 .33285 .29959 .32866 .292 .32087 Mtetra
.292 .32087 .29959 .32866 .31135 .32444 .30379 .31662 Mtetra
.30379 .31662 .31135 .32444 .32316 .32021 .31564 .31236 Mtetra
.31564 .31236 .32316 .32021 .33502 .31597 .32753 .30807 Mtetra
.32753 .30807 .33502 .31597 .34694 .3117 .33948 .30377 Mtetra
.33948 .30377 .34694 .3117 .35891 .30741 .35149 .29944 Mtetra
.35149 .29944 .35891 .30741 .37093 .3031 .36355 .2951 Mtetra
.36355 .2951 .37093 .3031 .38301 .29878 .37566 .29074 Mtetra
.37566 .29074 .38301 .29878 .39515 .29443 .38783 .28636 Mtetra
.38783 .28636 .39515 .29443 .4069 .30161 .40005 .28195 Mtetra
.623 .541 .742 r
.40005 .28195 .4069 .30161 .41919 .29724 .41233 .27753 Mtetra
0 0 .429 r
.41233 .27753 .41919 .29724 .43101 .31035 .42372 .30221 Mtetra
.662 .744 .911 r
.42372 .30221 .43101 .31035 .44348 .30595 .43623 .29777 Mtetra
.43623 .29777 .44348 .30595 .45601 .30153 .44879 .29331 Mtetra
.44879 .29331 .45601 .30153 .46859 .29709 .46142 .28884 Mtetra
.46142 .28884 .46859 .29709 .48124 .29263 .4741 .28434 Mtetra
.4741 .28434 .48124 .29263 .49394 .28815 .48684 .27982 Mtetra
.48684 .27982 .49394 .28815 .5067 .28364 .49964 .27527 Mtetra
.49964 .27527 .5067 .28364 .51953 .27912 .5125 .27071 Mtetra
.5125 .27071 .51953 .27912 .53241 .27457 .52543 .26612 Mtetra
.52543 .26612 .53241 .27457 .54535 .27001 .53841 .26152 Mtetra
.53841 .26152 .54535 .27001 .55836 .26542 .55145 .25689 Mtetra
.55145 .25689 .55836 .26542 .57142 .26081 .56456 .25224 Mtetra
.56456 .25224 .57142 .26081 .58455 .25618 .57773 .24757 Mtetra
.57773 .24757 .58455 .25618 .59774 .25152 .59096 .24287 Mtetra
.59096 .24287 .59774 .25152 .61099 .24685 .60426 .23816 Mtetra
.60426 .23816 .61099 .24685 .63067 .4383 .61761 .23342 Mtetra
0 0 .409 r
.61761 .23342 .63067 .4383 .64492 .43377 .63788 .42536 Mtetra
.646 .762 .934 r
.63788 .42536 .64492 .43377 .65925 .42922 .65226 .42077 Mtetra
.65226 .42077 .65925 .42922 .67365 .42465 .66671 .41615 Mtetra
.66671 .41615 .67365 .42465 .68812 .42006 .68123 .41151 Mtetra
.68123 .41151 .68812 .42006 .70267 .41544 .69583 .40685 Mtetra
.69583 .40685 .70267 .41544 .71729 .4108 .7105 .40216 Mtetra
.7105 .40216 .71729 .4108 .73199 .40613 .72526 .39745 Mtetra
.72526 .39745 .73199 .40613 .74677 .40144 .74008 .39272 Mtetra
.74008 .39272 .74677 .40144 .76162 .39673 .75499 .38796 Mtetra
.75499 .38796 .76162 .39673 .77655 .39199 .76997 .38317 Mtetra
.76997 .38317 .77655 .39199 .79155 .38723 .78503 .37837 Mtetra
.78503 .37837 .79155 .38723 .80664 .38244 .80017 .37353 Mtetra
.664 .741 .908 r
.14652 .36293 .15452 .37038 .16571 .36635 .15773 .35887 Mtetra
.15773 .35887 .16571 .36635 .17694 .36231 .16899 .35479 Mtetra
.16899 .35479 .17694 .36231 .18822 .35825 .1803 .3507 Mtetra
.1803 .3507 .18822 .35825 .19955 .35416 .19166 .34658 Mtetra
.19166 .34658 .19955 .35416 .21093 .35007 .20307 .34245 Mtetra
.20307 .34245 .21093 .35007 .22236 .34595 .21453 .3383 Mtetra
.21453 .3383 .22236 .34595 .23384 .34182 .22604 .33414 Mtetra
.22604 .33414 .23384 .34182 .24537 .33766 .2376 .32995 Mtetra
.2376 .32995 .24537 .33766 .25695 .33349 .24921 .32574 Mtetra
.24921 .32574 .25695 .33349 .26858 .3293 .26087 .32152 Mtetra
.26087 .32152 .26858 .3293 .28027 .32509 .27259 .31728 Mtetra
.27259 .31728 .28027 .32509 .292 .32087 .28436 .31301 Mtetra
.28436 .31301 .292 .32087 .30379 .31662 .29618 .30873 Mtetra
.29618 .30873 .30379 .31662 .31564 .31236 .30806 .30443 Mtetra
.30806 .30443 .31564 .31236 .32753 .30807 .31998 .30011 Mtetra
.31998 .30011 .32753 .30807 .33948 .30377 .33197 .29577 Mtetra
.33197 .29577 .33948 .30377 .35149 .29944 .344 .29141 Mtetra
.344 .29141 .35149 .29944 .36355 .2951 .3561 .28703 Mtetra
.3561 .28703 .36355 .2951 .37566 .29074 .36824 .28263 Mtetra
.36824 .28263 .37566 .29074 .38783 .28636 .38045 .27821 Mtetra
.38045 .27821 .38783 .28636 .40005 .28195 .3927 .27377 Mtetra
.3927 .27377 .40005 .28195 .41233 .27753 .40502 .26932 Mtetra
.843 .402 0 r
.40502 .26932 .41233 .27753 .42372 .30221 .41637 .294 Mtetra
.662 .744 .911 r
.41637 .294 .42372 .30221 .43623 .29777 .42892 .28953 Mtetra
.42892 .28953 .43623 .29777 .44879 .29331 .44152 .28503 Mtetra
.44152 .28503 .44879 .29331 .46142 .28884 .45418 .28051 Mtetra
.45418 .28051 .46142 .28884 .4741 .28434 .4669 .27597 Mtetra
.4669 .27597 .4741 .28434 .48684 .27982 .47968 .27141 Mtetra
.47968 .27141 .48684 .27982 .49964 .27527 .49252 .26683 Mtetra
.49252 .26683 .49964 .27527 .5125 .27071 .50542 .26223 Mtetra
.50542 .26223 .5125 .27071 .52543 .26612 .51838 .2576 Mtetra
.51838 .2576 .52543 .26612 .53841 .26152 .53141 .25296 Mtetra
.53141 .25296 .53841 .26152 .55145 .25689 .54449 .24829 Mtetra
.54449 .24829 .55145 .25689 .56456 .25224 .55764 .2436 Mtetra
.55764 .2436 .56456 .25224 .57773 .24757 .57085 .23888 Mtetra
.57085 .23888 .57773 .24757 .59096 .24287 .58412 .23415 Mtetra
.58412 .23415 .59096 .24287 .60426 .23816 .59746 .22939 Mtetra
.59746 .22939 .60426 .23816 .61761 .23342 .61086 .22461 Mtetra
.61086 .22461 .61761 .23342 .63788 .42536 .62433 .2198 Mtetra
.538 .325 .539 r
.62433 .2198 .63788 .42536 .65226 .42077 .63786 .21497 Mtetra
0 0 .414 r
.63786 .21497 .65226 .42077 .66671 .41615 .65969 .40757 Mtetra
.646 .762 .934 r
.65969 .40757 .66671 .41615 .68123 .41151 .67427 .40289 Mtetra
.67427 .40289 .68123 .41151 .69583 .40685 .68892 .39818 Mtetra
.68892 .39818 .69583 .40685 .7105 .40216 .70365 .39345 Mtetra
.70365 .39345 .7105 .40216 .72526 .39745 .71845 .38869 Mtetra
.71845 .38869 .72526 .39745 .74008 .39272 .73334 .38391 Mtetra
.73334 .38391 .74008 .39272 .75499 .38796 .74829 .37911 Mtetra
.74829 .37911 .75499 .38796 .76997 .38317 .76333 .37428 Mtetra
.76333 .37428 .76997 .38317 .78503 .37837 .77845 .36942 Mtetra
.77845 .36942 .78503 .37837 .80017 .37353 .79365 .36454 Mtetra
.664 .741 .908 r
.13846 .35542 .14652 .36293 .15773 .35887 .1497 .35133 Mtetra
.1497 .35133 .15773 .35887 .16899 .35479 .16098 .34722 Mtetra
.16098 .34722 .16899 .35479 .1803 .3507 .17232 .34309 Mtetra
.17232 .34309 .1803 .3507 .19166 .34658 .18371 .33894 Mtetra
.18371 .33894 .19166 .34658 .20307 .34245 .19515 .33478 Mtetra
.19515 .33478 .20307 .34245 .21453 .3383 .20663 .33059 Mtetra
.20663 .33059 .21453 .3383 .22604 .33414 .21817 .32639 Mtetra
.21817 .32639 .22604 .33414 .2376 .32995 .22976 .32217 Mtetra
.22976 .32217 .2376 .32995 .24921 .32574 .24141 .31793 Mtetra
.24141 .31793 .24921 .32574 .26087 .32152 .2531 .31367 Mtetra
.2531 .31367 .26087 .32152 .27259 .31728 .26485 .30939 Mtetra
.26485 .30939 .27259 .31728 .28436 .31301 .27665 .30509 Mtetra
.27665 .30509 .28436 .31301 .29618 .30873 .2885 .30078 Mtetra
.2885 .30078 .29618 .30873 .30806 .30443 .30041 .29644 Mtetra
.30041 .29644 .30806 .30443 .31998 .30011 .31237 .29208 Mtetra
.31237 .29208 .31998 .30011 .33197 .29577 .32439 .28771 Mtetra
.32439 .28771 .33197 .29577 .344 .29141 .33646 .28331 Mtetra
.33646 .28331 .344 .29141 .3561 .28703 .34858 .2789 Mtetra
.34858 .2789 .3561 .28703 .36824 .28263 .36077 .27446 Mtetra
.36077 .27446 .36824 .28263 .38045 .27821 .373 .27 Mtetra
.373 .27 .38045 .27821 .3927 .27377 .3853 .26553 Mtetra
.3853 .26553 .3927 .27377 .40502 .26932 .39764 .26103 Mtetra
.843 .402 0 r
.39764 .26103 .40502 .26932 .41637 .294 .40896 .28572 Mtetra
.662 .744 .911 r
.40896 .28572 .41637 .294 .42892 .28953 .42154 .28121 Mtetra
.42154 .28121 .42892 .28953 .44152 .28503 .43418 .27667 Mtetra
.43418 .27667 .44152 .28503 .45418 .28051 .44688 .27212 Mtetra
.44688 .27212 .45418 .28051 .4669 .27597 .45964 .26754 Mtetra
.45964 .26754 .4669 .27597 .47968 .27141 .47246 .26294 Mtetra
.47246 .26294 .47968 .27141 .49252 .26683 .48534 .25832 Mtetra
.48534 .25832 .49252 .26683 .50542 .26223 .49828 .25367 Mtetra
.49828 .25367 .50542 .26223 .51838 .2576 .51128 .24901 Mtetra
.51128 .24901 .51838 .2576 .53141 .25296 .52434 .24432 Mtetra
.52434 .24432 .53141 .25296 .54449 .24829 .53747 .23961 Mtetra
.53747 .23961 .54449 .24829 .55764 .2436 .55066 .23488 Mtetra
.55066 .23488 .55764 .2436 .57085 .23888 .56391 .23012 Mtetra
.56391 .23012 .57085 .23888 .58412 .23415 .57722 .22534 Mtetra
.57722 .22534 .58412 .23415 .59746 .22939 .5906 .22054 Mtetra
.5906 .22054 .59746 .22939 .61086 .22461 .60405 .21572 Mtetra
.60405 .21572 .61086 .22461 .62433 .2198 .61756 .21087 Mtetra
.61756 .21087 .62433 .2198 .63786 .21497 .63113 .206 Mtetra
.63113 .206 .63786 .21497 .65969 .40757 .64477 .2011 Mtetra
0 0 .414 r
.64477 .2011 .65969 .40757 .67427 .40289 .66724 .39418 Mtetra
.646 .762 .934 r
.66724 .39418 .67427 .40289 .68892 .39818 .68195 .38943 Mtetra
.68195 .38943 .68892 .39818 .70365 .39345 .69673 .38465 Mtetra
.69673 .38465 .70365 .39345 .71845 .38869 .71159 .37985 Mtetra
.71159 .37985 .71845 .38869 .73334 .38391 .72652 .37502 Mtetra
.72652 .37502 .73334 .38391 .74829 .37911 .74154 .37017 Mtetra
.74154 .37017 .74829 .37911 .76333 .37428 .75663 .36529 Mtetra
.75663 .36529 .76333 .37428 .77845 .36942 .7718 .36039 Mtetra
.7718 .36039 .77845 .36942 .79365 .36454 .78706 .35546 Mtetra
.664 .741 .908 r
.13033 .34785 .13846 .35542 .1497 .35133 .1416 .34373 Mtetra
.1416 .34373 .1497 .35133 .16098 .34722 .15291 .33958 Mtetra
.15291 .33958 .16098 .34722 .17232 .34309 .16428 .33542 Mtetra
.16428 .33542 .17232 .34309 .18371 .33894 .17569 .33124 Mtetra
.17569 .33124 .18371 .33894 .19515 .33478 .18716 .32704 Mtetra
.18716 .32704 .19515 .33478 .20663 .33059 .19868 .32282 Mtetra
.19868 .32282 .20663 .33059 .21817 .32639 .21025 .31858 Mtetra
.21025 .31858 .21817 .32639 .22976 .32217 .22187 .31433 Mtetra
.22187 .31433 .22976 .32217 .24141 .31793 .23354 .31005 Mtetra
.23354 .31005 .24141 .31793 .2531 .31367 .24527 .30576 Mtetra
.24527 .30576 .2531 .31367 .26485 .30939 .25704 .30144 Mtetra
.25704 .30144 .26485 .30939 .27665 .30509 .26888 .29711 Mtetra
.26888 .29711 .27665 .30509 .2885 .30078 .28076 .29276 Mtetra
.28076 .29276 .2885 .30078 .30041 .29644 .2927 .28838 Mtetra
.2927 .28838 .30041 .29644 .31237 .29208 .3047 .28399 Mtetra
.3047 .28399 .31237 .29208 .32439 .28771 .31674 .27958 Mtetra
.31674 .27958 .32439 .28771 .33646 .28331 .32885 .27514 Mtetra
.32885 .27514 .33646 .28331 .34858 .2789 .34101 .27069 Mtetra
.34101 .27069 .34858 .2789 .36077 .27446 .35322 .26622 Mtetra
.35322 .26622 .36077 .27446 .373 .27 .36549 .26172 Mtetra
.36549 .26172 .373 .27 .3853 .26553 .37782 .25721 Mtetra
.37782 .25721 .3853 .26553 .39764 .26103 .39021 .25267 Mtetra
.843 .402 0 r
.39021 .25267 .39764 .26103 .40896 .28572 .40149 .27737 Mtetra
.662 .744 .911 r
.40149 .27737 .40896 .28572 .42154 .28121 .4141 .27282 Mtetra
.4141 .27282 .42154 .28121 .43418 .27667 .42678 .26824 Mtetra
.42678 .26824 .43418 .27667 .44688 .27212 .43952 .26365 Mtetra
.43952 .26365 .44688 .27212 .45964 .26754 .45231 .25903 Mtetra
.45231 .25903 .45964 .26754 .47246 .26294 .46517 .25439 Mtetra
.46517 .25439 .47246 .26294 .48534 .25832 .47809 .24973 Mtetra
.47809 .24973 .48534 .25832 .49828 .25367 .49107 .24504 Mtetra
.49107 .24504 .49828 .25367 .51128 .24901 .50411 .24034 Mtetra
.50411 .24034 .51128 .24901 .52434 .24432 .51721 .23561 Mtetra
.51721 .23561 .52434 .24432 .53747 .23961 .53038 .23085 Mtetra
.53038 .23085 .53747 .23961 .55066 .23488 .54361 .22608 Mtetra
.54361 .22608 .55066 .23488 .56391 .23012 .5569 .22128 Mtetra
.5569 .22128 .56391 .23012 .57722 .22534 .57026 .21646 Mtetra
.57026 .21646 .57722 .22534 .5906 .22054 .58369 .21162 Mtetra
.58369 .21162 .5906 .22054 .60405 .21572 .59717 .20675 Mtetra
.59717 .20675 .60405 .21572 .61756 .21087 .61073 .20186 Mtetra
.61073 .20186 .61756 .21087 .63113 .206 .62435 .19694 Mtetra
.62435 .19694 .63113 .206 .64477 .2011 .63803 .192 Mtetra
.63803 .192 .64477 .2011 .66724 .39418 .65179 .18704 Mtetra
0 0 .414 r
.65179 .18704 .66724 .39418 .68195 .38943 .67491 .38059 Mtetra
.646 .762 .934 r
.67491 .38059 .68195 .38943 .69673 .38465 .68974 .37576 Mtetra
.68974 .37576 .69673 .38465 .71159 .37985 .70465 .37092 Mtetra
.70465 .37092 .71159 .37985 .72652 .37502 .71964 .36604 Mtetra
.71964 .36604 .72652 .37502 .74154 .37017 .73471 .36114 Mtetra
.73471 .36114 .74154 .37017 .75663 .36529 .74986 .35622 Mtetra
.74986 .35622 .75663 .36529 .7718 .36039 .76509 .35126 Mtetra
.76509 .35126 .7718 .36039 .78706 .35546 .7804 .34628 Mtetra
.664 .741 .908 r
.12213 .34022 .13033 .34785 .1416 .34373 .13343 .33606 Mtetra
.13343 .33606 .1416 .34373 .15291 .33958 .14477 .33188 Mtetra
.14477 .33188 .15291 .33958 .16428 .33542 .15616 .32769 Mtetra
.15616 .32769 .16428 .33542 .17569 .33124 .16761 .32347 Mtetra
.16761 .32347 .17569 .33124 .18716 .32704 .17911 .31924 Mtetra
.17911 .31924 .18716 .32704 .19868 .32282 .19065 .31498 Mtetra
.19065 .31498 .19868 .32282 .21025 .31858 .20225 .31071 Mtetra
.20225 .31071 .21025 .31858 .22187 .31433 .2139 .30642 Mtetra
.2139 .30642 .22187 .31433 .23354 .31005 .22561 .30211 Mtetra
.22561 .30211 .23354 .31005 .24527 .30576 .23736 .29778 Mtetra
.23736 .29778 .24527 .30576 .25704 .30144 .24917 .29343 Mtetra
.24917 .29343 .25704 .30144 .26888 .29711 .26104 .28906 Mtetra
.26104 .28906 .26888 .29711 .28076 .29276 .27296 .28467 Mtetra
.27296 .28467 .28076 .29276 .2927 .28838 .28493 .28026 Mtetra
.28493 .28026 .2927 .28838 .3047 .28399 .29695 .27583 Mtetra
.29695 .27583 .3047 .28399 .31674 .27958 .30904 .27138 Mtetra
.30904 .27138 .31674 .27958 .32885 .27514 .32117 .26691 Mtetra
.32117 .26691 .32885 .27514 .34101 .27069 .33337 .26241 Mtetra
.33337 .26241 .34101 .27069 .35322 .26622 .34562 .2579 Mtetra
.34562 .2579 .35322 .26622 .36549 .26172 .35792 .25337 Mtetra
.35792 .25337 .36549 .26172 .37782 .25721 .37029 .24881 Mtetra
.37029 .24881 .37782 .25721 .39021 .25267 .38271 .24424 Mtetra
.843 .402 0 r
.38271 .24424 .39021 .25267 .40149 .27737 .39395 .26895 Mtetra
.662 .744 .911 r
.39395 .26895 .40149 .27737 .4141 .27282 .4066 .26436 Mtetra
.4066 .26436 .4141 .27282 .42678 .26824 .41931 .25974 Mtetra
.41931 .25974 .42678 .26824 .43952 .26365 .43209 .2551 Mtetra
.43209 .2551 .43952 .26365 .45231 .25903 .44492 .25045 Mtetra
.44492 .25045 .45231 .25903 .46517 .25439 .45782 .24576 Mtetra
.45782 .24576 .46517 .25439 .47809 .24973 .47078 .24106 Mtetra
.47078 .24106 .47809 .24973 .49107 .24504 .4838 .23634 Mtetra
.4838 .23634 .49107 .24504 .50411 .24034 .49688 .23159 Mtetra
.49688 .23159 .50411 .24034 .51721 .23561 .51002 .22682 Mtetra
.51002 .22682 .51721 .23561 .53038 .23085 .52323 .22202 Mtetra
.52323 .22202 .53038 .23085 .54361 .22608 .5365 .2172 Mtetra
.5365 .2172 .54361 .22608 .5569 .22128 .54984 .21236 Mtetra
.54984 .21236 .5569 .22128 .57026 .21646 .56324 .2075 Mtetra
.56324 .2075 .57026 .21646 .58369 .21162 .57671 .20261 Mtetra
.57671 .20261 .58369 .21162 .59717 .20675 .59024 .1977 Mtetra
.59024 .1977 .59717 .20675 .61073 .20186 .60384 .19276 Mtetra
.60384 .19276 .61073 .20186 .62435 .19694 .6175 .1878 Mtetra
.6175 .1878 .62435 .19694 .63803 .192 .63123 .18282 Mtetra
.63123 .18282 .63803 .192 .65179 .18704 .64503 .17781 Mtetra
.64503 .17781 .65179 .18704 .67491 .38059 .6589 .17278 Mtetra
.533 .318 .534 r
.6589 .17278 .67491 .38059 .68974 .37576 .67283 .16772 Mtetra
0 0 .418 r
.67283 .16772 .68974 .37576 .70465 .37092 .69765 .3619 Mtetra
.646 .762 .934 r
.69765 .3619 .70465 .37092 .71964 .36604 .71269 .35698 Mtetra
.71269 .35698 .71964 .36604 .73471 .36114 .72782 .35203 Mtetra
.72782 .35203 .73471 .36114 .74986 .35622 .74302 .34705 Mtetra
.74302 .34705 .74986 .35622 .76509 .35126 .75831 .34205 Mtetra
.75831 .34205 .76509 .35126 .7804 .34628 .77368 .33702 Mtetra
.664 .741 .908 r
.11387 .33253 .12213 .34022 .13343 .33606 .12519 .32833 Mtetra
.12519 .32833 .13343 .33606 .14477 .33188 .13656 .32412 Mtetra
.13656 .32412 .14477 .33188 .15616 .32769 .14799 .31989 Mtetra
.14799 .31989 .15616 .32769 .16761 .32347 .15946 .31564 Mtetra
.15946 .31564 .16761 .32347 .17911 .31924 .17099 .31137 Mtetra
.17099 .31137 .17911 .31924 .19065 .31498 .18256 .30708 Mtetra
.18256 .30708 .19065 .31498 .20225 .31071 .19419 .30277 Mtetra
.19419 .30277 .20225 .31071 .2139 .30642 .20587 .29844 Mtetra
.20587 .29844 .2139 .30642 .22561 .30211 .21761 .2941 Mtetra
.21761 .2941 .22561 .30211 .23736 .29778 .2294 .28973 Mtetra
.2294 .28973 .23736 .29778 .24917 .29343 .24124 .28534 Mtetra
.24124 .28534 .24917 .29343 .26104 .28906 .25313 .28094 Mtetra
.25313 .28094 .26104 .28906 .27296 .28467 .26508 .27651 Mtetra
.26508 .27651 .27296 .28467 .28493 .28026 .27709 .27206 Mtetra
.27709 .27206 .28493 .28026 .29695 .27583 .28915 .26759 Mtetra
.28915 .26759 .29695 .27583 .30904 .27138 .30126 .26311 Mtetra
.30126 .26311 .30904 .27138 .32117 .26691 .31343 .2586 Mtetra
.31343 .2586 .32117 .26691 .33337 .26241 .32566 .25407 Mtetra
.32566 .25407 .33337 .26241 .34562 .2579 .33795 .24952 Mtetra
.33795 .24952 .34562 .2579 .35792 .25337 .35029 .24494 Mtetra
.35029 .24494 .35792 .25337 .37029 .24881 .36269 .24035 Mtetra
.36269 .24035 .37029 .24881 .38271 .24424 .37514 .23574 Mtetra
.843 .402 0 r
.37514 .23574 .38271 .24424 .39395 .26895 .38634 .26045 Mtetra
.662 .744 .911 r
.38634 .26045 .39395 .26895 .4066 .26436 .39903 .25582 Mtetra
.39903 .25582 .4066 .26436 .41931 .25974 .41178 .25116 Mtetra
.41178 .25116 .41931 .25974 .43209 .2551 .42459 .24649 Mtetra
.42459 .24649 .43209 .2551 .44492 .25045 .43747 .24179 Mtetra
.43747 .24179 .44492 .25045 .45782 .24576 .4504 .23706 Mtetra
.4504 .23706 .45782 .24576 .47078 .24106 .4634 .23232 Mtetra
.4634 .23232 .47078 .24106 .4838 .23634 .47646 .22755 Mtetra
.47646 .22755 .4838 .23634 .49688 .23159 .48958 .22276 Mtetra
.48958 .22276 .49688 .23159 .51002 .22682 .50277 .21795 Mtetra
.50277 .21795 .51002 .22682 .52323 .22202 .51602 .21311 Mtetra
.51602 .21311 .52323 .22202 .5365 .2172 .52933 .20825 Mtetra
.52933 .20825 .5365 .2172 .54984 .21236 .54271 .20336 Mtetra
.54271 .20336 .54984 .21236 .56324 .2075 .55615 .19846 Mtetra
.55615 .19846 .56324 .2075 .57671 .20261 .56966 .19353 Mtetra
.56966 .19353 .57671 .20261 .59024 .1977 .58324 .18857 Mtetra
.58324 .18857 .59024 .1977 .60384 .19276 .59688 .18359 Mtetra
.59688 .18359 .60384 .19276 .6175 .1878 .61059 .17858 Mtetra
.61059 .17858 .6175 .1878 .63123 .18282 .62437 .17355 Mtetra
.62437 .17355 .63123 .18282 .64503 .17781 .63821 .1685 Mtetra
.63821 .1685 .64503 .17781 .6589 .17278 .65213 .16342 Mtetra
.65213 .16342 .6589 .17278 .67283 .16772 .66611 .15832 Mtetra
.66611 .15832 .67283 .16772 .69765 .3619 .68016 .15318 Mtetra
0 0 .418 r
.68016 .15318 .69765 .3619 .71269 .35698 .70568 .34782 Mtetra
.646 .762 .934 r
.70568 .34782 .71269 .35698 .72782 .35203 .72086 .34282 Mtetra
.72086 .34282 .72782 .35203 .74302 .34705 .73612 .3378 Mtetra
.73612 .3378 .74302 .34705 .75831 .34205 .75147 .33275 Mtetra
.75147 .33275 .75831 .34205 .77368 .33702 .76689 .32767 Mtetra
.664 .741 .908 r
.10554 .32477 .11387 .33253 .12519 .32833 .11689 .32054 Mtetra
.11689 .32054 .12519 .32833 .13656 .32412 .12829 .31629 Mtetra
.12829 .31629 .13656 .32412 .14799 .31989 .13974 .31203 Mtetra
.13974 .31203 .14799 .31989 .15946 .31564 .15124 .30774 Mtetra
.15124 .30774 .15946 .31564 .17099 .31137 .1628 .30344 Mtetra
.1628 .30344 .17099 .31137 .18256 .30708 .1744 .29911 Mtetra
.1744 .29911 .18256 .30708 .19419 .30277 .18606 .29477 Mtetra
.18606 .29477 .19419 .30277 .20587 .29844 .19778 .2904 Mtetra
.19778 .2904 .20587 .29844 .21761 .2941 .20954 .28602 Mtetra
.20954 .28602 .21761 .2941 .2294 .28973 .22136 .28162 Mtetra
.22136 .28162 .2294 .28973 .24124 .28534 .23323 .27719 Mtetra
.23323 .27719 .24124 .28534 .25313 .28094 .24516 .27275 Mtetra
.24516 .27275 .25313 .28094 .26508 .27651 .25714 .26828 Mtetra
.25714 .26828 .26508 .27651 .27709 .27206 .26918 .2638 Mtetra
.26918 .2638 .27709 .27206 .28915 .26759 .28127 .25929 Mtetra
.28127 .25929 .28915 .26759 .30126 .26311 .29342 .25477 Mtetra
.29342 .25477 .30126 .26311 .31343 .2586 .30563 .25022 Mtetra
.30563 .25022 .31343 .2586 .32566 .25407 .31789 .24565 Mtetra
.31789 .24565 .32566 .25407 .33795 .24952 .33021 .24106 Mtetra
.33021 .24106 .33795 .24952 .35029 .24494 .34259 .23645 Mtetra
.34259 .23645 .35029 .24494 .36269 .24035 .35502 .23182 Mtetra
.35502 .23182 .36269 .24035 .37514 .23574 .36751 .22716 Mtetra
.843 .402 0 r
.36751 .22716 .37514 .23574 .38634 .26045 .37867 .25188 Mtetra
.662 .744 .911 r
.37867 .25188 .38634 .26045 .39903 .25582 .39139 .24721 Mtetra
.39139 .24721 .39903 .25582 .41178 .25116 .40418 .24251 Mtetra
.40418 .24251 .41178 .25116 .42459 .24649 .41704 .23779 Mtetra
.41704 .23779 .42459 .24649 .43747 .24179 .42995 .23305 Mtetra
.42995 .23305 .43747 .24179 .4504 .23706 .44292 .22829 Mtetra
.44292 .22829 .4504 .23706 .4634 .23232 .45596 .2235 Mtetra
.45596 .2235 .4634 .23232 .47646 .22755 .46906 .21869 Mtetra
.46906 .21869 .47646 .22755 .48958 .22276 .48222 .21386 Mtetra
.48222 .21386 .48958 .22276 .50277 .21795 .49545 .209 Mtetra
.49545 .209 .50277 .21795 .51602 .21311 .50874 .20412 Mtetra
.50874 .20412 .51602 .21311 .52933 .20825 .5221 .19921 Mtetra
.5221 .19921 .52933 .20825 .54271 .20336 .53552 .19429 Mtetra
.53552 .19429 .54271 .20336 .55615 .19846 .549 .18933 Mtetra
.549 .18933 .55615 .19846 .56966 .19353 .56256 .18436 Mtetra
.56256 .18436 .56966 .19353 .58324 .18857 .57618 .17936 Mtetra
.57618 .17936 .58324 .18857 .59688 .18359 .58986 .17433 Mtetra
.58986 .17433 .59688 .18359 .61059 .17858 .60362 .16928 Mtetra
.60362 .16928 .61059 .17858 .62437 .17355 .61744 .1642 Mtetra
.61744 .1642 .62437 .17355 .63821 .1685 .63133 .1591 Mtetra
.63133 .1591 .63821 .1685 .65213 .16342 .64529 .15398 Mtetra
.64529 .15398 .65213 .16342 .66611 .15832 .65932 .14882 Mtetra
.65932 .14882 .66611 .15832 .68016 .15318 .67342 .14365 Mtetra
.67342 .14365 .68016 .15318 .70568 .34782 .68759 .13844 Mtetra
.529 .313 .531 r
.68759 .13844 .70568 .34782 .72086 .34282 .70184 .13321 Mtetra
0 0 .423 r
.70184 .13321 .72086 .34282 .73612 .3378 .72915 .32845 Mtetra
.646 .762 .934 r
.72915 .32845 .73612 .3378 .75147 .33275 .74455 .32335 Mtetra
.74455 .32335 .75147 .33275 .76689 .32767 .76004 .31822 Mtetra
.664 .741 .908 r
.09714 .31695 .10554 .32477 .11689 .32054 .10852 .31268 Mtetra
.10852 .31268 .11689 .32054 .12829 .31629 .11995 .3084 Mtetra
.11995 .3084 .12829 .31629 .13974 .31203 .13143 .3041 Mtetra
.13143 .3041 .13974 .31203 .15124 .30774 .14296 .29978 Mtetra
.14296 .29978 .15124 .30774 .1628 .30344 .15454 .29544 Mtetra
.15454 .29544 .1628 .30344 .1744 .29911 .16618 .29108 Mtetra
.16618 .29108 .1744 .29911 .18606 .29477 .17787 .28669 Mtetra
.17787 .28669 .18606 .29477 .19778 .2904 .18961 .28229 Mtetra
.18961 .28229 .19778 .2904 .20954 .28602 .20141 .27787 Mtetra
.20141 .27787 .20954 .28602 .22136 .28162 .21326 .27343 Mtetra
.21326 .27343 .22136 .28162 .23323 .27719 .22516 .26897 Mtetra
.22516 .26897 .23323 .27719 .24516 .27275 .23712 .26449 Mtetra
.23712 .26449 .24516 .27275 .25714 .26828 .24914 .25999 Mtetra
.24914 .25999 .25714 .26828 .26918 .2638 .26121 .25546 Mtetra
.26121 .25546 .26918 .2638 .28127 .25929 .27333 .25092 Mtetra
.27333 .25092 .28127 .25929 .29342 .25477 .28552 .24635 Mtetra
.28552 .24635 .29342 .25477 .30563 .25022 .29776 .24177 Mtetra
.29776 .24177 .30563 .25022 .31789 .24565 .31005 .23716 Mtetra
.31005 .23716 .31789 .24565 .33021 .24106 .32241 .23253 Mtetra
.32241 .23253 .33021 .24106 .34259 .23645 .33482 .22788 Mtetra
.33482 .22788 .34259 .23645 .35502 .23182 .34729 .2232 Mtetra
.34729 .2232 .35502 .23182 .36751 .22716 .35982 .21851 Mtetra
.35982 .21851 .36751 .22716 .37867 .25188 .3724 .21379 Mtetra
.06 .068 .552 r
.3724 .21379 .37867 .25188 .39139 .24721 .38369 .23852 Mtetra
.662 .744 .911 r
.38369 .23852 .39139 .24721 .40418 .24251 .39652 .23378 Mtetra
.39652 .23378 .40418 .24251 .41704 .23779 .40941 .22902 Mtetra
.40941 .22902 .41704 .23779 .42995 .23305 .42236 .22424 Mtetra
.42236 .22424 .42995 .23305 .44292 .22829 .43537 .21943 Mtetra
.43537 .21943 .44292 .22829 .45596 .2235 .44845 .2146 Mtetra
.44845 .2146 .45596 .2235 .46906 .21869 .46159 .20975 Mtetra
.46159 .20975 .46906 .21869 .48222 .21386 .4748 .20487 Mtetra
.4748 .20487 .48222 .21386 .49545 .209 .48806 .19997 Mtetra
.48806 .19997 .49545 .209 .50874 .20412 .5014 .19505 Mtetra
.5014 .19505 .50874 .20412 .5221 .19921 .5148 .1901 Mtetra
.5148 .1901 .5221 .19921 .53552 .19429 .52826 .18512 Mtetra
.52826 .18512 .53552 .19429 .549 .18933 .54179 .18013 Mtetra
.54179 .18013 .549 .18933 .56256 .18436 .55539 .1751 Mtetra
.55539 .1751 .56256 .18436 .57618 .17936 .56905 .17006 Mtetra
.56905 .17006 .57618 .17936 .58986 .17433 .58278 .16499 Mtetra
.58278 .16499 .58986 .17433 .60362 .16928 .59658 .15989 Mtetra
.59658 .15989 .60362 .16928 .61744 .1642 .61045 .15477 Mtetra
.61045 .15477 .61744 .1642 .63133 .1591 .62439 .14962 Mtetra
.62439 .14962 .63133 .1591 .64529 .15398 .6384 .14444 Mtetra
.6384 .14444 .64529 .15398 .65932 .14882 .65247 .13924 Mtetra
.65247 .13924 .65932 .14882 .67342 .14365 .66662 .13402 Mtetra
.66662 .13402 .67342 .14365 .68759 .13844 .68084 .12877 Mtetra
.68084 .12877 .68759 .13844 .70184 .13321 .69513 .12349 Mtetra
.69513 .12349 .70184 .13321 .72915 .32845 .7095 .11818 Mtetra
0 0 .423 r
.7095 .11818 .72915 .32845 .74455 .32335 .73757 .31386 Mtetra
.646 .762 .934 r
.73757 .31386 .74455 .32335 .76004 .31822 .75311 .30868 Mtetra
.664 .741 .908 r
.08867 .30906 .09714 .31695 .10852 .31268 .10008 .30476 Mtetra
.10008 .30476 .10852 .31268 .11995 .3084 .11153 .30044 Mtetra
.11153 .30044 .11995 .3084 .13143 .3041 .12304 .29611 Mtetra
.12304 .29611 .13143 .3041 .14296 .29978 .1346 .29175 Mtetra
.1346 .29175 .14296 .29978 .15454 .29544 .14622 .28737 Mtetra
.14622 .28737 .15454 .29544 .16618 .29108 .15788 .28297 Mtetra
.15788 .28297 .16618 .29108 .17787 .28669 .1696 .27855 Mtetra
.1696 .27855 .17787 .28669 .18961 .28229 .18138 .27412 Mtetra
.18138 .27412 .18961 .28229 .20141 .27787 .1932 .26966 Mtetra
.1932 .26966 .20141 .27787 .21326 .27343 .20509 .26518 Mtetra
.20509 .26518 .21326 .27343 .22516 .26897 .21702 .26068 Mtetra
.21702 .26068 .22516 .26897 .23712 .26449 .22901 .25616 Mtetra
.22901 .25616 .23712 .26449 .24914 .25999 .24106 .25162 Mtetra
.24106 .25162 .24914 .25999 .26121 .25546 .25317 .24706 Mtetra
.25317 .24706 .26121 .25546 .27333 .25092 .26532 .24247 Mtetra
.26532 .24247 .27333 .25092 .28552 .24635 .27754 .23787 Mtetra
.27754 .23787 .28552 .24635 .29776 .24177 .28981 .23324 Mtetra
.28981 .23324 .29776 .24177 .31005 .23716 .30215 .22859 Mtetra
.30215 .22859 .31005 .23716 .32241 .23253 .31453 .22393 Mtetra
.31453 .22393 .32241 .23253 .33482 .22788 .32698 .21923 Mtetra
.32698 .21923 .33482 .22788 .34729 .2232 .33949 .21452 Mtetra
.33949 .21452 .34729 .2232 .35982 .21851 .35205 .20978 Mtetra
.35205 .20978 .35982 .21851 .3724 .21379 .36468 .20502 Mtetra
.838 .396 0 r
.36468 .20502 .3724 .21379 .38369 .23852 .37592 .22975 Mtetra
.662 .744 .911 r
.37592 .22975 .38369 .23852 .39652 .23378 .38879 .22497 Mtetra
.38879 .22497 .39652 .23378 .40941 .22902 .40171 .22017 Mtetra
.40171 .22017 .40941 .22902 .42236 .22424 .41471 .21535 Mtetra
.41471 .21535 .42236 .22424 .43537 .21943 .42776 .2105 Mtetra
.42776 .2105 .43537 .21943 .44845 .2146 .44088 .20562 Mtetra
.44088 .20562 .44845 .2146 .46159 .20975 .45406 .20073 Mtetra
.45406 .20073 .46159 .20975 .4748 .20487 .4673 .1958 Mtetra
.4673 .1958 .4748 .20487 .48806 .19997 .48061 .19086 Mtetra
.48061 .19086 .48806 .19997 .5014 .19505 .49399 .18589 Mtetra
.49399 .18589 .5014 .19505 .5148 .1901 .50743 .1809 Mtetra
.50743 .1809 .5148 .1901 .52826 .18512 .52093 .17588 Mtetra
.52093 .17588 .52826 .18512 .54179 .18013 .53451 .17084 Mtetra
.53451 .17084 .54179 .18013 .55539 .1751 .54815 .16577 Mtetra
.54815 .16577 .55539 .1751 .56905 .17006 .56186 .16067 Mtetra
.56186 .16067 .56905 .17006 .58278 .16499 .57564 .15556 Mtetra
.57564 .15556 .58278 .16499 .59658 .15989 .58948 .15041 Mtetra
.58948 .15041 .59658 .15989 .61045 .15477 .6034 .14524 Mtetra
.6034 .14524 .61045 .15477 .62439 .14962 .61738 .14005 Mtetra
.61738 .14005 .62439 .14962 .6384 .14444 .63144 .13482 Mtetra
.63144 .13482 .6384 .14444 .65247 .13924 .64556 .12958 Mtetra
.64556 .12958 .65247 .13924 .66662 .13402 .65976 .1243 Mtetra
.65976 .1243 .66662 .13402 .68084 .12877 .67403 .119 Mtetra
.67403 .119 .68084 .12877 .69513 .12349 .68837 .11367 Mtetra
.68837 .11367 .69513 .12349 .7095 .11818 .70278 .10832 Mtetra
.70278 .10832 .7095 .11818 .73757 .31386 .71727 .10293 Mtetra
0 0 .423 r
.71727 .10293 .73757 .31386 .75311 .30868 .74612 .29904 Mtetra
.664 .741 .908 r
.08013 .30111 .08867 .30906 .10008 .30476 .09156 .29677 Mtetra
.09156 .29677 .10008 .30476 .11153 .30044 .10305 .29242 Mtetra
.10305 .29242 .11153 .30044 .12304 .29611 .11459 .28804 Mtetra
.11459 .28804 .12304 .29611 .1346 .29175 .12618 .28365 Mtetra
.12618 .28365 .1346 .29175 .14622 .28737 .13782 .27924 Mtetra
.13782 .27924 .14622 .28737 .15788 .28297 .14952 .2748 Mtetra
.14952 .2748 .15788 .28297 .1696 .27855 .16127 .27035 Mtetra
.16127 .27035 .1696 .27855 .18138 .27412 .17307 .26587 Mtetra
.17307 .26587 .18138 .27412 .1932 .26966 .18493 .26137 Mtetra
.18493 .26137 .1932 .26966 .20509 .26518 .19684 .25686 Mtetra
.19684 .25686 .20509 .26518 .21702 .26068 .20881 .25232 Mtetra
.20881 .25232 .21702 .26068 .22901 .25616 .22084 .24776 Mtetra
.22084 .24776 .22901 .25616 .24106 .25162 .23292 .24318 Mtetra
.23292 .24318 .24106 .25162 .25317 .24706 .24505 .23858 Mtetra
.24505 .23858 .25317 .24706 .26532 .24247 .25725 .23396 Mtetra
.25725 .23396 .26532 .24247 .27754 .23787 .2695 .22931 Mtetra
.2695 .22931 .27754 .23787 .28981 .23324 .2818 .22464 Mtetra
.2818 .22464 .28981 .23324 .30215 .22859 .29417 .21996 Mtetra
.29417 .21996 .30215 .22859 .31453 .22393 .30659 .21525 Mtetra
.30659 .21525 .31453 .22393 .32698 .21923 .31908 .21051 Mtetra
.31908 .21051 .32698 .21923 .33949 .21452 .33162 .20576 Mtetra
.33162 .20576 .33949 .21452 .35205 .20978 .34422 .20098 Mtetra
.34422 .20098 .35205 .20978 .36468 .20502 .35688 .19618 Mtetra
.838 .396 0 r
.35688 .19618 .36468 .20502 .37592 .22975 .36808 .22091 Mtetra
.662 .744 .911 r
.36808 .22091 .37592 .22975 .38879 .22497 .38098 .21609 Mtetra
.38098 .21609 .38879 .22497 .40171 .22017 .39395 .21124 Mtetra
.39395 .21124 .40171 .22017 .41471 .21535 .40698 .20637 Mtetra
.40698 .20637 .41471 .21535 .42776 .2105 .42008 .20148 Mtetra
.42008 .20148 .42776 .2105 .44088 .20562 .43323 .19656 Mtetra
.43323 .19656 .44088 .20562 .45406 .20073 .44645 .19162 Mtetra
.44645 .19162 .45406 .20073 .4673 .1958 .45974 .18666 Mtetra
.45974 .18666 .4673 .1958 .48061 .19086 .47309 .18167 Mtetra
.47309 .18167 .48061 .19086 .49399 .18589 .48651 .17665 Mtetra
.48651 .17665 .49399 .18589 .50743 .1809 .49999 .17161 Mtetra
.49999 .17161 .50743 .1809 .52093 .17588 .51354 .16655 Mtetra
.51354 .16655 .52093 .17588 .53451 .17084 .52716 .16146 Mtetra
.52716 .16146 .53451 .17084 .54815 .16577 .54085 .15635 Mtetra
.54085 .15635 .54815 .16577 .56186 .16067 .5546 .1512 Mtetra
.5546 .1512 .56186 .16067 .57564 .15556 .56842 .14604 Mtetra
.56842 .14604 .57564 .15556 .58948 .15041 .58231 .14085 Mtetra
.58231 .14085 .58948 .15041 .6034 .14524 .59628 .13563 Mtetra
.59628 .13563 .6034 .14524 .61738 .14005 .61031 .13039 Mtetra
.61031 .13039 .61738 .14005 .63144 .13482 .62441 .12512 Mtetra
.62441 .12512 .63144 .13482 .64556 .12958 .63858 .11982 Mtetra
.63858 .11982 .64556 .12958 .65976 .1243 .65283 .11449 Mtetra
.65283 .11449 .65976 .1243 .67403 .119 .66715 .10914 Mtetra
.66715 .10914 .67403 .119 .68837 .11367 .68154 .10376 Mtetra
.68154 .10376 .68837 .11367 .70278 .10832 .69601 .09836 Mtetra
.69601 .09836 .70278 .10832 .71727 .10293 .71054 .09292 Mtetra
.71054 .09292 .71727 .10293 .74612 .29904 .72516 .08746 Mtetra
.664 .741 .908 r
.07152 .29309 .08013 .30111 .09156 .29677 .08298 .28872 Mtetra
.08298 .28872 .09156 .29677 .10305 .29242 .09449 .28433 Mtetra
.09449 .28433 .10305 .29242 .11459 .28804 .10606 .27992 Mtetra
.10606 .27992 .11459 .28804 .12618 .28365 .11768 .27548 Mtetra
.11768 .27548 .12618 .28365 .13782 .27924 .12935 .27103 Mtetra
.12935 .27103 .13782 .27924 .14952 .2748 .14108 .26656 Mtetra
.14108 .26656 .14952 .2748 .16127 .27035 .15286 .26207 Mtetra
.15286 .26207 .16127 .27035 .17307 .26587 .1647 .25755 Mtetra
.1647 .25755 .17307 .26587 .18493 .26137 .17659 .25302 Mtetra
.17659 .25302 .18493 .26137 .19684 .25686 .18853 .24846 Mtetra
.18853 .24846 .19684 .25686 .20881 .25232 .20053 .24389 Mtetra
.20053 .24389 .20881 .25232 .22084 .24776 .21259 .23929 Mtetra
.21259 .23929 .22084 .24776 .23292 .24318 .2247 .23467 Mtetra
.2247 .23467 .23292 .24318 .24505 .23858 .23687 .23003 Mtetra
.23687 .23003 .24505 .23858 .25725 .23396 .2491 .22536 Mtetra
.2491 .22536 .25725 .23396 .2695 .22931 .26138 .22068 Mtetra
.26138 .22068 .2695 .22931 .2818 .22464 .27373 .21597 Mtetra
.27373 .21597 .2818 .22464 .29417 .21996 .28613 .21124 Mtetra
.28613 .21124 .29417 .21996 .30659 .21525 .29858 .20649 Mtetra
.29858 .20649 .30659 .21525 .31908 .21051 .3111 .20172 Mtetra
.3111 .20172 .31908 .21051 .33162 .20576 .32368 .19692 Mtetra
.32368 .19692 .33162 .20576 .34422 .20098 .33632 .1921 Mtetra
.33632 .1921 .34422 .20098 .35688 .19618 .34902 .18726 Mtetra
.838 .396 0 r
.34902 .18726 .35688 .19618 .36808 .22091 .36017 .21199 Mtetra
.662 .744 .911 r
.36017 .21199 .36808 .22091 .38098 .21609 .37311 .20712 Mtetra
.37311 .20712 .38098 .21609 .39395 .21124 .38612 .20223 Mtetra
.38612 .20223 .39395 .21124 .40698 .20637 .39919 .19732 Mtetra
.39919 .19732 .40698 .20637 .42008 .20148 .41232 .19238 Mtetra
.41232 .19238 .42008 .20148 .43323 .19656 .42552 .18742 Mtetra
.42552 .18742 .43323 .19656 .44645 .19162 .43878 .18244 Mtetra
.43878 .18244 .44645 .19162 .45974 .18666 .45211 .17743 Mtetra
.45211 .17743 .45974 .18666 .47309 .18167 .4655 .17239 Mtetra
.4655 .17239 .47309 .18167 .48651 .17665 .47896 .16733 Mtetra
.47896 .16733 .48651 .17665 .49999 .17161 .49249 .16224 Mtetra
.49249 .16224 .49999 .17161 .51354 .16655 .50608 .15713 Mtetra
.50608 .15713 .51354 .16655 .52716 .16146 .51975 .152 Mtetra
.51975 .152 .52716 .16146 .54085 .15635 .53348 .14684 Mtetra
.53348 .14684 .54085 .15635 .5546 .1512 .54727 .14165 Mtetra
.54727 .14165 .5546 .1512 .56842 .14604 .56114 .13643 Mtetra
.56114 .13643 .56842 .14604 .58231 .14085 .57508 .13119 Mtetra
.57508 .13119 .58231 .14085 .59628 .13563 .58909 .12593 Mtetra
.58909 .12593 .59628 .13563 .61031 .13039 .60317 .12063 Mtetra
.60317 .12063 .61031 .13039 .62441 .12512 .61732 .11531 Mtetra
.61732 .11531 .62441 .12512 .63858 .11982 .63154 .10997 Mtetra
.63154 .10997 .63858 .11982 .65283 .11449 .64584 .10459 Mtetra
.64584 .10459 .65283 .11449 .66715 .10914 .6602 .09919 Mtetra
.6602 .09919 .66715 .10914 .68154 .10376 .67465 .09376 Mtetra
.67465 .09376 .68154 .10376 .69601 .09836 .68916 .08831 Mtetra
.68916 .08831 .69601 .09836 .71054 .09292 .70375 .08282 Mtetra
.70375 .08282 .71054 .09292 .72516 .08746 .71842 .07731 Mtetra
.664 .741 .908 r
.06283 .285 .07152 .29309 .08298 .28872 .07432 .2806 Mtetra
.07432 .2806 .08298 .28872 .09449 .28433 .08587 .27617 Mtetra
.08587 .27617 .09449 .28433 .10606 .27992 .09746 .27172 Mtetra
.09746 .27172 .10606 .27992 .11768 .27548 .10911 .26725 Mtetra
.10911 .26725 .11768 .27548 .12935 .27103 .12082 .26276 Mtetra
.12082 .26276 .12935 .27103 .14108 .26656 .13257 .25825 Mtetra
.13257 .25825 .14108 .26656 .15286 .26207 .14438 .25372 Mtetra
.14438 .25372 .15286 .26207 .1647 .25755 .15625 .24917 Mtetra
.15625 .24917 .1647 .25755 .17659 .25302 .16817 .24459 Mtetra
.16817 .24459 .17659 .25302 .18853 .24846 .18015 .24 Mtetra
.18015 .24 .18853 .24846 .20053 .24389 .19218 .23538 Mtetra
.19218 .23538 .20053 .24389 .21259 .23929 .20427 .23074 Mtetra
.20427 .23074 .21259 .23929 .2247 .23467 .21642 .22608 Mtetra
.21642 .22608 .2247 .23467 .23687 .23003 .22862 .2214 Mtetra
.22862 .2214 .23687 .23003 .2491 .22536 .24088 .2167 Mtetra
.24088 .2167 .2491 .22536 .26138 .22068 .2532 .21197 Mtetra
.2532 .21197 .26138 .22068 .27373 .21597 .26558 .20722 Mtetra
.26558 .20722 .27373 .21597 .28613 .21124 .27801 .20245 Mtetra
.27801 .20245 .28613 .21124 .29858 .20649 .29051 .19766 Mtetra
.29051 .19766 .29858 .20649 .3111 .20172 .30306 .19284 Mtetra
.30306 .19284 .3111 .20172 .32368 .19692 .31567 .188 Mtetra
.31567 .188 .32368 .19692 .33632 .1921 .32835 .18314 Mtetra
.32835 .18314 .33632 .1921 .34902 .18726 .34108 .17826 Mtetra
.838 .396 0 r
.34108 .17826 .34902 .18726 .36017 .21199 .35219 .20299 Mtetra
.662 .744 .911 r
.35219 .20299 .36017 .21199 .37311 .20712 .36517 .19808 Mtetra
.36517 .19808 .37311 .20712 .38612 .20223 .37822 .19314 Mtetra
.37822 .19314 .38612 .20223 .39919 .19732 .39132 .18819 Mtetra
.39132 .18819 .39919 .19732 .41232 .19238 .4045 .1832 Mtetra
.4045 .1832 .41232 .19238 .42552 .18742 .41774 .1782 Mtetra
.41774 .1782 .42552 .18742 .43878 .18244 .43104 .17317 Mtetra
.43104 .17317 .43878 .18244 .45211 .17743 .44441 .16811 Mtetra
.44441 .16811 .45211 .17743 .4655 .17239 .45785 .16303 Mtetra
.45785 .16303 .4655 .17239 .47896 .16733 .47135 .15792 Mtetra
.47135 .15792 .47896 .16733 .49249 .16224 .48492 .15279 Mtetra
.48492 .15279 .49249 .16224 .50608 .15713 .49856 .14763 Mtetra
.49856 .14763 .50608 .15713 .51975 .152 .51226 .14245 Mtetra
.51226 .14245 .51975 .152 .53348 .14684 .52604 .13724 Mtetra
.52604 .13724 .53348 .14684 .54727 .14165 .53988 .132 Mtetra
.53988 .132 .54727 .14165 .56114 .13643 .5538 .12674 Mtetra
.5538 .12674 .56114 .13643 .57508 .13119 .56778 .12145 Mtetra
.56778 .12145 .57508 .13119 .58909 .12593 .58184 .11614 Mtetra
.58184 .11614 .58909 .12593 .60317 .12063 .59596 .11079 Mtetra
.59596 .11079 .60317 .12063 .61732 .11531 .61016 .10542 Mtetra
.61016 .10542 .61732 .11531 .63154 .10997 .62443 .10002 Mtetra
.62443 .10002 .63154 .10997 .64584 .10459 .63878 .0946 Mtetra
.63878 .0946 .64584 .10459 .6602 .09919 .6532 .08915 Mtetra
.6532 .08915 .6602 .09919 .67465 .09376 .66769 .08367 Mtetra
.66769 .08367 .67465 .09376 .68916 .08831 .68225 .07816 Mtetra
.68225 .07816 .68916 .08831 .70375 .08282 .6969 .07262 Mtetra
.6969 .07262 .70375 .08282 .71842 .07731 .71162 .06705 Mtetra
.664 .741 .908 r
.05408 .27685 .06283 .285 .07432 .2806 .06559 .2724 Mtetra
.06559 .2724 .07432 .2806 .08587 .27617 .07717 .26794 Mtetra
.07717 .26794 .08587 .27617 .09746 .27172 .08879 .26345 Mtetra
.08879 .26345 .09746 .27172 .10911 .26725 .10047 .25894 Mtetra
.10047 .25894 .10911 .26725 .12082 .26276 .1122 .25442 Mtetra
.1122 .25442 .12082 .26276 .13257 .25825 .12399 .24987 Mtetra
.12399 .24987 .13257 .25825 .14438 .25372 .13583 .2453 Mtetra
.13583 .2453 .14438 .25372 .15625 .24917 .14773 .24071 Mtetra
.14773 .24071 .15625 .24917 .16817 .24459 .15968 .23609 Mtetra
.15968 .23609 .16817 .24459 .18015 .24 .17169 .23146 Mtetra
.17169 .23146 .18015 .24 .19218 .23538 .18376 .2268 Mtetra
.18376 .2268 .19218 .23538 .20427 .23074 .19588 .22212 Mtetra
.19588 .22212 .20427 .23074 .21642 .22608 .20806 .21742 Mtetra
.20806 .21742 .21642 .22608 .22862 .2214 .2203 .2127 Mtetra
.2203 .2127 .22862 .2214 .24088 .2167 .23259 .20796 Mtetra
.23259 .20796 .24088 .2167 .2532 .21197 .24494 .20319 Mtetra
.24494 .20319 .2532 .21197 .26558 .20722 .25735 .1984 Mtetra
.25735 .1984 .26558 .20722 .27801 .20245 .26982 .19359 Mtetra
.26982 .19359 .27801 .20245 .29051 .19766 .28235 .18875 Mtetra
.28235 .18875 .29051 .19766 .30306 .19284 .29494 .18389 Mtetra
.29494 .18389 .30306 .19284 .31567 .188 .30759 .17901 Mtetra
.30759 .17901 .31567 .188 .32835 .18314 .32031 .1741 Mtetra
.32031 .1741 .32835 .18314 .34108 .17826 .33308 .16917 Mtetra
.838 .396 0 r
.33308 .16917 .34108 .17826 .35219 .20299 .34413 .19391 Mtetra
.662 .744 .911 r
.34413 .19391 .35219 .20299 .36517 .19808 .35716 .18895 Mtetra
.35716 .18895 .36517 .19808 .37822 .19314 .37024 .18397 Mtetra
.37024 .18397 .37822 .19314 .39132 .18819 .38339 .17897 Mtetra
.38339 .17897 .39132 .18819 .4045 .1832 .3966 .17394 Mtetra
.3966 .17394 .4045 .1832 .41774 .1782 .40988 .16889 Mtetra
.40988 .16889 .41774 .1782 .43104 .17317 .42323 .16381 Mtetra
.42323 .16381 .43104 .17317 .44441 .16811 .43664 .15871 Mtetra
.43664 .15871 .44441 .16811 .45785 .16303 .45012 .15358 Mtetra
.45012 .15358 .45785 .16303 .47135 .15792 .46366 .14843 Mtetra
.46366 .14843 .47135 .15792 .48492 .15279 .47728 .14325 Mtetra
.47728 .14325 .48492 .15279 .49856 .14763 .49096 .13804 Mtetra
.49096 .13804 .49856 .14763 .51226 .14245 .50471 .13281 Mtetra
.50471 .13281 .51226 .14245 .52604 .13724 .51853 .12755 Mtetra
.51853 .12755 .52604 .13724 .53988 .132 .53242 .12227 Mtetra
.53242 .12227 .53988 .132 .5538 .12674 .54638 .11695 Mtetra
.54638 .11695 .5538 .12674 .56778 .12145 .56041 .11162 Mtetra
.56041 .11162 .56778 .12145 .58184 .11614 .57451 .10625 Mtetra
.57451 .10625 .58184 .11614 .59596 .11079 .58869 .10086 Mtetra
.58869 .10086 .59596 .11079 .61016 .10542 .60294 .09544 Mtetra
.60294 .09544 .61016 .10542 .62443 .10002 .61726 .08999 Mtetra
.61726 .08999 .62443 .10002 .63878 .0946 .63165 .08451 Mtetra
.63165 .08451 .63878 .0946 .6532 .08915 .64612 .07901 Mtetra
.64612 .07901 .6532 .08915 .66769 .08367 .66066 .07347 Mtetra
.66066 .07347 .66769 .08367 .68225 .07816 .67528 .06791 Mtetra
.67528 .06791 .68225 .07816 .6969 .07262 .68998 .06232 Mtetra
.68998 .06232 .6969 .07262 .71162 .06705 .70475 .0567 Mtetra
.664 .741 .908 r
.04524 .26863 .05408 .27685 .06559 .2724 .05679 .26414 Mtetra
.05679 .26414 .06559 .2724 .07717 .26794 .06839 .25964 Mtetra
.06839 .25964 .07717 .26794 .08879 .26345 .08005 .25511 Mtetra
.08005 .25511 .08879 .26345 .10047 .25894 .09176 .25057 Mtetra
.09176 .25057 .10047 .25894 .1122 .25442 .10352 .246 Mtetra
.10352 .246 .1122 .25442 .12399 .24987 .11534 .24141 Mtetra
.11534 .24141 .12399 .24987 .13583 .2453 .12721 .2368 Mtetra
.12721 .2368 .13583 .2453 .14773 .24071 .13914 .23217 Mtetra
.13914 .23217 .14773 .24071 .15968 .23609 .15112 .22752 Mtetra
.15112 .22752 .15968 .23609 .17169 .23146 .16316 .22284 Mtetra
.16316 .22284 .17169 .23146 .18376 .2268 .17526 .21815 Mtetra
.17526 .21815 .18376 .2268 .19588 .22212 .18742 .21343 Mtetra
.18742 .21343 .19588 .22212 .20806 .21742 .19963 .20869 Mtetra
.19963 .20869 .20806 .21742 .2203 .2127 .2119 .20392 Mtetra
.2119 .20392 .2203 .2127 .23259 .20796 .22423 .19914 Mtetra
.22423 .19914 .23259 .20796 .24494 .20319 .23661 .19433 Mtetra
.23661 .19433 .24494 .20319 .25735 .1984 .24906 .1895 Mtetra
.24906 .1895 .25735 .1984 .26982 .19359 .26157 .18464 Mtetra
.26157 .18464 .26982 .19359 .28235 .18875 .27413 .17976 Mtetra
.27413 .17976 .28235 .18875 .29494 .18389 .28676 .17486 Mtetra
.28676 .17486 .29494 .18389 .30759 .17901 .29944 .16993 Mtetra
.29944 .16993 .30759 .17901 .32031 .1741 .31219 .16498 Mtetra
.31219 .16498 .32031 .1741 .33308 .16917 .325 .16001 Mtetra
.838 .396 0 r
.325 .16001 .33308 .16917 .34413 .19391 .33601 .18474 Mtetra
.662 .744 .911 r
.33601 .18474 .34413 .19391 .35716 .18895 .34907 .17974 Mtetra
.34907 .17974 .35716 .18895 .37024 .18397 .36219 .17472 Mtetra
.36219 .17472 .37024 .18397 .38339 .17897 .37538 .16967 Mtetra
.37538 .16967 .38339 .17897 .3966 .17394 .38864 .16459 Mtetra
.38864 .16459 .3966 .17394 .40988 .16889 .40196 .1595 Mtetra
.40196 .1595 .40988 .16889 .42323 .16381 .41534 .15437 Mtetra
.41534 .15437 .42323 .16381 .43664 .15871 .4288 .14922 Mtetra
.4288 .14922 .43664 .15871 .45012 .15358 .44232 .14405 Mtetra
.44232 .14405 .45012 .15358 .46366 .14843 .45591 .13884 Mtetra
.45591 .13884 .46366 .14843 .47728 .14325 .46956 .13362 Mtetra
.46956 .13362 .47728 .14325 .49096 .13804 .48329 .12836 Mtetra
.48329 .12836 .49096 .13804 .50471 .13281 .49709 .12308 Mtetra
.49709 .12308 .50471 .13281 .51853 .12755 .51095 .11777 Mtetra
.51095 .11777 .51853 .12755 .53242 .12227 .52489 .11244 Mtetra
.52489 .11244 .53242 .12227 .54638 .11695 .53889 .10708 Mtetra
.53889 .10708 .54638 .11695 .56041 .11162 .55297 .10169 Mtetra
.55297 .10169 .56041 .11162 .57451 .10625 .56712 .09627 Mtetra
.56712 .09627 .57451 .10625 .58869 .10086 .58135 .09083 Mtetra
.58135 .09083 .58869 .10086 .60294 .09544 .59564 .08536 Mtetra
.59564 .08536 .60294 .09544 .61726 .08999 .61001 .07985 Mtetra
.61001 .07985 .61726 .08999 .63165 .08451 .62446 .07433 Mtetra
.62446 .07433 .63165 .08451 .64612 .07901 .63897 .06877 Mtetra
.63897 .06877 .64612 .07901 .66066 .07347 .65357 .06318 Mtetra
.65357 .06318 .66066 .07347 .67528 .06791 .66824 .05757 Mtetra
.66824 .05757 .67528 .06791 .68998 .06232 .68299 .05192 Mtetra
.68299 .05192 .68998 .06232 .70475 .0567 .69781 .04625 Mtetra
.664 .741 .908 r
.03634 .26033 .04524 .26863 .05679 .26414 .04791 .25581 Mtetra
.04791 .25581 .05679 .26414 .06839 .25964 .05954 .25127 Mtetra
.05954 .25127 .06839 .25964 .08005 .25511 .07123 .24671 Mtetra
.07123 .24671 .08005 .25511 .09176 .25057 .08297 .24212 Mtetra
.08297 .24212 .09176 .25057 .10352 .246 .09476 .23751 Mtetra
.09476 .23751 .10352 .246 .11534 .24141 .10661 .23289 Mtetra
.10661 .23289 .11534 .24141 .12721 .2368 .11851 .22824 Mtetra
.11851 .22824 .12721 .2368 .13914 .23217 .13047 .22356 Mtetra
.13047 .22356 .13914 .23217 .15112 .22752 .14249 .21887 Mtetra
.14249 .21887 .15112 .22752 .16316 .22284 .15456 .21416 Mtetra
.15456 .21416 .16316 .22284 .17526 .21815 .16669 .20942 Mtetra
.16669 .20942 .17526 .21815 .18742 .21343 .17888 .20466 Mtetra
.17888 .20466 .18742 .21343 .19963 .20869 .19112 .19987 Mtetra
.19112 .19987 .19963 .20869 .2119 .20392 .20343 .19507 Mtetra
.20343 .19507 .2119 .20392 .22423 .19914 .21579 .19024 Mtetra
.21579 .19024 .22423 .19914 .23661 .19433 .22821 .18539 Mtetra
.22821 .18539 .23661 .19433 .24906 .1895 .24069 .18051 Mtetra
.24069 .18051 .24906 .1895 .26157 .18464 .25323 .17561 Mtetra
.25323 .17561 .26157 .18464 .27413 .17976 .26583 .17069 Mtetra
.26583 .17069 .27413 .17976 .28676 .17486 .2785 .16575 Mtetra
.2785 .16575 .28676 .17486 .29944 .16993 .29122 .16078 Mtetra
.29122 .16078 .29944 .16993 .31219 .16498 .30401 .15578 Mtetra
.30401 .15578 .31219 .16498 .325 .16001 .31685 .15076 Mtetra
.838 .396 0 r
.31685 .15076 .325 .16001 .33601 .18474 .32781 .17549 Mtetra
.662 .744 .911 r
.32781 .17549 .33601 .18474 .34907 .17974 .34091 .17045 Mtetra
.34091 .17045 .34907 .17974 .36219 .17472 .35407 .16538 Mtetra
.35407 .16538 .36219 .17472 .37538 .16967 .3673 .16028 Mtetra
.3673 .16028 .37538 .16967 .38864 .16459 .3806 .15516 Mtetra
.3806 .15516 .38864 .16459 .40196 .1595 .39396 .15002 Mtetra
.39396 .15002 .40196 .1595 .41534 .15437 .40739 .14484 Mtetra
.40739 .14484 .41534 .15437 .4288 .14922 .42088 .13965 Mtetra
.42088 .13965 .4288 .14922 .44232 .14405 .43445 .13442 Mtetra
.43445 .13442 .44232 .14405 .45591 .13884 .44808 .12917 Mtetra
.44808 .12917 .45591 .13884 .46956 .13362 .46178 .1239 Mtetra
.46178 .1239 .46956 .13362 .48329 .12836 .47555 .11859 Mtetra
.47555 .11859 .48329 .12836 .49709 .12308 .48939 .11326 Mtetra
.48939 .11326 .49709 .12308 .51095 .11777 .5033 .1079 Mtetra
.5033 .1079 .51095 .11777 .52489 .11244 .51728 .10252 Mtetra
.51728 .10252 .52489 .11244 .53889 .10708 .53134 .09711 Mtetra
.53134 .09711 .53889 .10708 .55297 .10169 .54546 .09167 Mtetra
.54546 .09167 .55297 .10169 .56712 .09627 .55966 .0862 Mtetra
.55966 .0862 .56712 .09627 .58135 .09083 .57393 .0807 Mtetra
.57393 .0807 .58135 .09083 .59564 .08536 .58828 .07518 Mtetra
.58828 .07518 .59564 .08536 .61001 .07985 .6027 .06962 Mtetra
.6027 .06962 .61001 .07985 .62446 .07433 .61719 .06404 Mtetra
.61719 .06404 .62446 .07433 .63897 .06877 .63176 .05843 Mtetra
.63176 .05843 .63897 .06877 .65357 .06318 .64641 .05279 Mtetra
.64641 .05279 .65357 .06318 .66824 .05757 .66113 .04712 Mtetra
.66113 .04712 .66824 .05757 .68299 .05192 .67593 .04142 Mtetra
.67593 .04142 .68299 .05192 .69781 .04625 .69081 .03569 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .57879 .48228 .57294 Mtetra
.48228 .57294 .48818 .57879 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57244 .5035 .56654 Mtetra
.5035 .56654 .50935 .57244 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .56009 Mtetra
.52489 .56009 .53068 .56605 .54141 .56283 .53564 .55685 Mtetra
.53564 .55685 .54141 .56283 .55218 .5596 .54644 .5536 Mtetra
.54644 .5536 .55218 .5596 .56299 .55635 .55728 .55033 Mtetra
.55728 .55033 .56299 .55635 .57385 .5531 .56816 .54705 Mtetra
.56816 .54705 .57385 .5531 .58474 .54983 .57909 .54376 Mtetra
.57909 .54376 .58474 .54983 .59568 .54654 .59006 .54045 Mtetra
.59006 .54045 .59568 .54654 .60667 .54325 .60107 .53713 Mtetra
.60107 .53713 .60667 .54325 .61769 .53994 .61213 .5338 Mtetra
.61213 .5338 .61769 .53994 .62876 .53662 .62323 .53045 Mtetra
.62323 .53045 .62876 .53662 .63988 .53329 .63437 .5271 Mtetra
.63437 .5271 .63988 .53329 .65104 .52994 .64556 .52372 Mtetra
.64556 .52372 .65104 .52994 .66224 .52658 .65679 .52034 Mtetra
.65679 .52034 .66224 .52658 .67349 .5232 .66807 .51694 Mtetra
.66807 .51694 .67349 .5232 .68478 .51982 .67939 .51353 Mtetra
.67939 .51353 .68478 .51982 .69612 .51641 .69076 .5101 Mtetra
.69076 .5101 .69612 .51641 .7075 .513 .70218 .50666 Mtetra
.70218 .50666 .7075 .513 .71893 .50957 .71364 .5032 Mtetra
.71364 .5032 .71893 .50957 .73041 .50613 .72515 .49974 Mtetra
.72515 .49974 .73041 .50613 .74193 .50267 .7367 .49625 Mtetra
.7367 .49625 .74193 .50267 .7535 .4992 .7483 .49276 Mtetra
.7483 .49276 .7535 .4992 .76511 .49572 .75995 .48925 Mtetra
.75995 .48925 .76511 .49572 .77677 .49222 .77165 .48572 Mtetra
.77165 .48572 .77677 .49222 .78848 .48871 .78339 .48218 Mtetra
.78339 .48218 .78848 .48871 .80024 .48518 .79518 .47863 Mtetra
.79518 .47863 .80024 .48518 .81205 .48164 .80702 .47506 Mtetra
.80702 .47506 .81205 .48164 .8239 .47808 .81891 .47148 Mtetra
.81891 .47148 .8239 .47808 .8358 .47451 .83085 .46788 Mtetra
.83085 .46788 .8358 .47451 .84775 .47092 .84283 .46427 Mtetra
.84283 .46427 .84775 .47092 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .45699 Mtetra
.86696 .45699 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
0 0 .232 r
.38894 .6941 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.664 .741 .908 r
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57342 Mtetra
.45523 .57342 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55735 Mtetra
.50831 .55735 .51417 .56332 .52489 .56009 .51905 .5541 Mtetra
.51905 .5541 .52489 .56009 .53564 .55685 .52983 .55083 Mtetra
.52983 .55083 .53564 .55685 .54644 .5536 .54066 .54756 Mtetra
.54066 .54756 .54644 .5536 .55728 .55033 .55153 .54426 Mtetra
.55153 .54426 .55728 .55033 .56816 .54705 .56244 .54096 Mtetra
.56244 .54096 .56816 .54705 .57909 .54376 .57339 .53764 Mtetra
.57339 .53764 .57909 .54376 .59006 .54045 .58439 .53431 Mtetra
.58439 .53431 .59006 .54045 .60107 .53713 .59543 .53097 Mtetra
.59543 .53097 .60107 .53713 .61213 .5338 .60652 .52761 Mtetra
.60652 .52761 .61213 .5338 .62323 .53045 .61765 .52424 Mtetra
.61765 .52424 .62323 .53045 .63437 .5271 .62882 .52086 Mtetra
.62882 .52086 .63437 .5271 .64556 .52372 .64004 .51746 Mtetra
.64004 .51746 .64556 .52372 .65679 .52034 .6513 .51405 Mtetra
.6513 .51405 .65679 .52034 .66807 .51694 .66261 .51063 Mtetra
.66261 .51063 .66807 .51694 .67939 .51353 .67397 .50719 Mtetra
.67397 .50719 .67939 .51353 .69076 .5101 .68537 .50374 Mtetra
.68537 .50374 .69076 .5101 .70218 .50666 .69682 .50027 Mtetra
.69682 .50027 .70218 .50666 .71364 .5032 .70831 .49679 Mtetra
.70831 .49679 .71364 .5032 .72515 .49974 .71985 .4933 Mtetra
.71985 .4933 .72515 .49974 .7367 .49625 .73144 .48979 Mtetra
.73144 .48979 .7367 .49625 .7483 .49276 .74307 .48626 Mtetra
.74307 .48626 .7483 .49276 .75995 .48925 .75475 .48273 Mtetra
.75475 .48273 .75995 .48925 .77165 .48572 .76648 .47918 Mtetra
.76648 .47918 .77165 .48572 .78339 .48218 .77826 .47561 Mtetra
.77826 .47561 .78339 .48218 .79518 .47863 .79008 .47203 Mtetra
.79008 .47203 .79518 .47863 .80702 .47506 .80196 .46843 Mtetra
.80196 .46843 .80702 .47506 .81891 .47148 .81388 .46482 Mtetra
.81388 .46482 .81891 .47148 .83085 .46788 .82585 .4612 Mtetra
.82585 .4612 .83085 .46788 .84283 .46427 .83788 .45756 Mtetra
.83788 .45756 .84283 .46427 .85487 .46064 .84995 .4539 Mtetra
.84995 .4539 .85487 .46064 .86696 .45699 .86207 .45023 Mtetra
.86207 .45023 .86696 .45699 .87909 .45334 .87424 .44654 Mtetra
.87424 .44654 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.655 .752 .921 r
.38255 .68854 .38894 .6941 .40317 .58919 .39317 .68551 Mtetra
0 0 .232 r
.39317 .68551 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.664 .741 .908 r
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57342 .44919 .56753 Mtetra
.44919 .56753 .45523 .57342 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .5546 Mtetra
.49168 .5546 .49761 .56059 .50831 .55735 .5024 .55134 Mtetra
.5024 .55134 .50831 .55735 .51905 .5541 .51317 .54806 Mtetra
.51317 .54806 .51905 .5541 .52983 .55083 .52398 .54477 Mtetra
.52398 .54477 .52983 .55083 .54066 .54756 .53484 .54147 Mtetra
.53484 .54147 .54066 .54756 .55153 .54426 .54573 .53815 Mtetra
.54573 .53815 .55153 .54426 .56244 .54096 .55667 .53483 Mtetra
.55667 .53483 .56244 .54096 .57339 .53764 .56766 .53149 Mtetra
.56766 .53149 .57339 .53764 .58439 .53431 .57868 .52813 Mtetra
.57868 .52813 .58439 .53431 .59543 .53097 .58975 .52476 Mtetra
.58975 .52476 .59543 .53097 .60652 .52761 .60087 .52138 Mtetra
.60087 .52138 .60652 .52761 .61765 .52424 .61203 .51799 Mtetra
.61203 .51799 .61765 .52424 .62882 .52086 .62323 .51458 Mtetra
.62323 .51458 .62882 .52086 .64004 .51746 .63448 .51115 Mtetra
.63448 .51115 .64004 .51746 .6513 .51405 .64578 .50772 Mtetra
.64578 .50772 .6513 .51405 .66261 .51063 .65712 .50427 Mtetra
.65712 .50427 .66261 .51063 .67397 .50719 .6685 .5008 Mtetra
.6685 .5008 .67397 .50719 .68537 .50374 .67993 .49733 Mtetra
.67993 .49733 .68537 .50374 .69682 .50027 .69141 .49383 Mtetra
.69141 .49383 .69682 .50027 .70831 .49679 .70294 .49033 Mtetra
.70294 .49033 .70831 .49679 .71985 .4933 .71451 .48681 Mtetra
.71451 .48681 .71985 .4933 .73144 .48979 .72613 .48327 Mtetra
.72613 .48327 .73144 .48979 .74307 .48626 .7378 .47972 Mtetra
.7378 .47972 .74307 .48626 .75475 .48273 .74951 .47616 Mtetra
.74951 .47616 .75475 .48273 .76648 .47918 .76127 .47258 Mtetra
.76127 .47258 .76648 .47918 .77826 .47561 .77309 .46899 Mtetra
.77309 .46899 .77826 .47561 .79008 .47203 .78495 .46538 Mtetra
.78495 .46538 .79008 .47203 .80196 .46843 .79686 .46176 Mtetra
.79686 .46176 .80196 .46843 .81388 .46482 .80881 .45812 Mtetra
.80881 .45812 .81388 .46482 .82585 .4612 .82082 .45446 Mtetra
.82082 .45446 .82585 .4612 .83788 .45756 .83288 .4508 Mtetra
.83288 .4508 .83788 .45756 .84995 .4539 .84499 .44711 Mtetra
.84499 .44711 .84995 .4539 .86207 .45023 .85715 .44341 Mtetra
.85715 .44341 .86207 .45023 .87424 .44654 .86936 .4397 Mtetra
.86936 .4397 .87424 .44654 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.655 .752 .921 r
.37611 .68293 .38255 .68854 .39317 .68551 .38676 .67988 Mtetra
.38676 .67988 .39317 .68551 .40736 .58025 .39744 .67682 Mtetra
.555 .326 .523 r
.39744 .67682 .40736 .58025 .41776 .57709 .40817 .67374 Mtetra
0 0 .239 r
.40817 .67374 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.664 .741 .908 r
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .5551 Mtetra
.46432 .5551 .47035 .56109 .48099 .55785 .47499 .55184 Mtetra
.47499 .55184 .48099 .55785 .49168 .5546 .4857 .54857 Mtetra
.4857 .54857 .49168 .5546 .5024 .55134 .49646 .54528 Mtetra
.49646 .54528 .5024 .55134 .51317 .54806 .50725 .54198 Mtetra
.50725 .54198 .51317 .54806 .52398 .54477 .51809 .53867 Mtetra
.51809 .53867 .52398 .54477 .53484 .54147 .52897 .53534 Mtetra
.52897 .53534 .53484 .54147 .54573 .53815 .5399 .532 Mtetra
.5399 .532 .54573 .53815 .55667 .53483 .55087 .52865 Mtetra
.55087 .52865 .55667 .53483 .56766 .53149 .56188 .52528 Mtetra
.56188 .52528 .56766 .53149 .57868 .52813 .57293 .5219 Mtetra
.57293 .5219 .57868 .52813 .58975 .52476 .58403 .51851 Mtetra
.58403 .51851 .58975 .52476 .60087 .52138 .59518 .5151 Mtetra
.59518 .5151 .60087 .52138 .61203 .51799 .60637 .51168 Mtetra
.60637 .51168 .61203 .51799 .62323 .51458 .6176 .50825 Mtetra
.6176 .50825 .62323 .51458 .63448 .51115 .62888 .5048 Mtetra
.62888 .5048 .63448 .51115 .64578 .50772 .64021 .50134 Mtetra
.64021 .50134 .64578 .50772 .65712 .50427 .65158 .49786 Mtetra
.65158 .49786 .65712 .50427 .6685 .5008 .663 .49437 Mtetra
.663 .49437 .6685 .5008 .67993 .49733 .67446 .49087 Mtetra
.67446 .49087 .67993 .49733 .69141 .49383 .68597 .48735 Mtetra
.68597 .48735 .69141 .49383 .70294 .49033 .69753 .48382 Mtetra
.69753 .48382 .70294 .49033 .71451 .48681 .70913 .48027 Mtetra
.70913 .48027 .71451 .48681 .72613 .48327 .72078 .47671 Mtetra
.72078 .47671 .72613 .48327 .7378 .47972 .73248 .47313 Mtetra
.73248 .47313 .7378 .47972 .74951 .47616 .74423 .46954 Mtetra
.74423 .46954 .74951 .47616 .76127 .47258 .75603 .46593 Mtetra
.75603 .46593 .76127 .47258 .77309 .46899 .76788 .46231 Mtetra
.76788 .46231 .77309 .46899 .78495 .46538 .77977 .45868 Mtetra
.77977 .45868 .78495 .46538 .79686 .46176 .79171 .45503 Mtetra
.79171 .45503 .79686 .46176 .80881 .45812 .80371 .45136 Mtetra
.80371 .45136 .80881 .45812 .82082 .45446 .81575 .44768 Mtetra
.81575 .44768 .82082 .45446 .83288 .4508 .82785 .44398 Mtetra
.82785 .44398 .83288 .4508 .84499 .44711 .83999 .44027 Mtetra
.83999 .44027 .84499 .44711 .85715 .44341 .85219 .43654 Mtetra
.85219 .43654 .85715 .44341 .86936 .4397 .86443 .4328 Mtetra
.86443 .4328 .86936 .4397 .88162 .43597 .87673 .42904 Mtetra
.87673 .42904 .88162 .43597 .89393 .43222 .88908 .42526 Mtetra
.88908 .42526 .89393 .43222 .9063 .42846 .90148 .42147 Mtetra
.90148 .42147 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.655 .752 .921 r
.36963 .67729 .37611 .68293 .38676 .67988 .3803 .67421 Mtetra
.3803 .67421 .38676 .67988 .39744 .67682 .39101 .67112 Mtetra
.39101 .67112 .39744 .67682 .40817 .67374 .40177 .66802 Mtetra
.40177 .66802 .40817 .67374 .42206 .56802 .41257 .66491 Mtetra
0 0 .239 r
.41257 .66491 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.664 .741 .908 r
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .5556 Mtetra
.43698 .5556 .44311 .56159 .45369 .55835 .4476 .55234 Mtetra
.4476 .55234 .45369 .55835 .46432 .5551 .45825 .54907 Mtetra
.45825 .54907 .46432 .5551 .47499 .55184 .46895 .54579 Mtetra
.46895 .54579 .47499 .55184 .4857 .54857 .47968 .54249 Mtetra
.47968 .54249 .4857 .54857 .49646 .54528 .49046 .53918 Mtetra
.49046 .53918 .49646 .54528 .50725 .54198 .50129 .53585 Mtetra
.50129 .53585 .50725 .54198 .51809 .53867 .51215 .53251 Mtetra
.51215 .53251 .51809 .53867 .52897 .53534 .52306 .52916 Mtetra
.52306 .52916 .52897 .53534 .5399 .532 .53402 .5258 Mtetra
.53402 .5258 .5399 .532 .55087 .52865 .54501 .52242 Mtetra
.54501 .52242 .55087 .52865 .56188 .52528 .55606 .51903 Mtetra
.55606 .51903 .56188 .52528 .57293 .5219 .56714 .51563 Mtetra
.56714 .51563 .57293 .5219 .58403 .51851 .57827 .51221 Mtetra
.57827 .51221 .58403 .51851 .59518 .5151 .58944 .50878 Mtetra
.58944 .50878 .59518 .5151 .60637 .51168 .60066 .50533 Mtetra
.60066 .50533 .60637 .51168 .6176 .50825 .61193 .50187 Mtetra
.61193 .50187 .6176 .50825 .62888 .5048 .62324 .4984 Mtetra
.62324 .4984 .62888 .5048 .64021 .50134 .6346 .49491 Mtetra
.6346 .49491 .64021 .50134 .65158 .49786 .646 .49141 Mtetra
.646 .49141 .65158 .49786 .663 .49437 .65745 .48789 Mtetra
.65745 .48789 .663 .49437 .67446 .49087 .66894 .48436 Mtetra
.66894 .48436 .67446 .49087 .68597 .48735 .68049 .48082 Mtetra
.68049 .48082 .68597 .48735 .69753 .48382 .69208 .47726 Mtetra
.69208 .47726 .69753 .48382 .70913 .48027 .70371 .47368 Mtetra
.70371 .47368 .70913 .48027 .72078 .47671 .7154 .47009 Mtetra
.7154 .47009 .72078 .47671 .73248 .47313 .72713 .46649 Mtetra
.72713 .46649 .73248 .47313 .74423 .46954 .73891 .46287 Mtetra
.73891 .46287 .74423 .46954 .75603 .46593 .75075 .45924 Mtetra
.75075 .45924 .75603 .46593 .76788 .46231 .76263 .45559 Mtetra
.76263 .45559 .76788 .46231 .77977 .45868 .77455 .45193 Mtetra
.77455 .45193 .77977 .45868 .79171 .45503 .78653 .44825 Mtetra
.78653 .44825 .79171 .45503 .80371 .45136 .79856 .44455 Mtetra
.79856 .44455 .80371 .45136 .81575 .44768 .81064 .44084 Mtetra
.81064 .44084 .81575 .44768 .82785 .44398 .82277 .43712 Mtetra
.82277 .43712 .82785 .44398 .83999 .44027 .83495 .43338 Mtetra
.83495 .43338 .83999 .44027 .85219 .43654 .84719 .42962 Mtetra
.84719 .42962 .85219 .43654 .86443 .4328 .85947 .42585 Mtetra
.85947 .42585 .86443 .4328 .87673 .42904 .87181 .42206 Mtetra
.87181 .42206 .87673 .42904 .88908 .42526 .88419 .41825 Mtetra
.88419 .41825 .88908 .42526 .90148 .42147 .89664 .41443 Mtetra
.89664 .41443 .90148 .42147 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.655 .752 .921 r
.3631 .6716 .36963 .67729 .3803 .67421 .37379 .6685 Mtetra
.37379 .6685 .3803 .67421 .39101 .67112 .38453 .66539 Mtetra
.38453 .66539 .39101 .67112 .40177 .66802 .39532 .66227 Mtetra
.39532 .66227 .40177 .66802 .41257 .66491 .40615 .65913 Mtetra
.40615 .65913 .41257 .66491 .42641 .55885 .41702 .65598 Mtetra
0 0 .239 r
.41702 .65598 .42641 .55885 .43698 .5556 .43081 .54957 Mtetra
.664 .741 .908 r
.43081 .54957 .43698 .5556 .4476 .55234 .44145 .54629 Mtetra
.44145 .54629 .4476 .55234 .45825 .54907 .45213 .543 Mtetra
.45213 .543 .45825 .54907 .46895 .54579 .46286 .53969 Mtetra
.46286 .53969 .46895 .54579 .47968 .54249 .47362 .53636 Mtetra
.47362 .53636 .47968 .54249 .49046 .53918 .48443 .53303 Mtetra
.48443 .53303 .49046 .53918 .50129 .53585 .49528 .52968 Mtetra
.49528 .52968 .50129 .53585 .51215 .53251 .50617 .52632 Mtetra
.50617 .52632 .51215 .53251 .52306 .52916 .51711 .52294 Mtetra
.51711 .52294 .52306 .52916 .53402 .5258 .52809 .51955 Mtetra
.52809 .51955 .53402 .5258 .54501 .52242 .53912 .51615 Mtetra
.53912 .51615 .54501 .52242 .55606 .51903 .55019 .51274 Mtetra
.55019 .51274 .55606 .51903 .56714 .51563 .5613 .50931 Mtetra
.5613 .50931 .56714 .51563 .57827 .51221 .57246 .50586 Mtetra
.57246 .50586 .57827 .51221 .58944 .50878 .58367 .50241 Mtetra
.58367 .50241 .58944 .50878 .60066 .50533 .59492 .49893 Mtetra
.59492 .49893 .60066 .50533 .61193 .50187 .60621 .49545 Mtetra
.60621 .49545 .61193 .50187 .62324 .4984 .61755 .49195 Mtetra
.61755 .49195 .62324 .4984 .6346 .49491 .62894 .48843 Mtetra
.62894 .48843 .6346 .49491 .646 .49141 .64038 .48491 Mtetra
.64038 .48491 .646 .49141 .65745 .48789 .65186 .48136 Mtetra
.65186 .48136 .65745 .48789 .66894 .48436 .66338 .47781 Mtetra
.66338 .47781 .66894 .48436 .68049 .48082 .67496 .47423 Mtetra
.67496 .47423 .68049 .48082 .69208 .47726 .68658 .47065 Mtetra
.68658 .47065 .69208 .47726 .70371 .47368 .69825 .46705 Mtetra
.69825 .46705 .70371 .47368 .7154 .47009 .70997 .46343 Mtetra
.70997 .46343 .7154 .47009 .72713 .46649 .72174 .4598 Mtetra
.72174 .4598 .72713 .46649 .73891 .46287 .73355 .45615 Mtetra
.73355 .45615 .73891 .46287 .75075 .45924 .74542 .45249 Mtetra
.74542 .45249 .75075 .45924 .76263 .45559 .75733 .44881 Mtetra
.75733 .44881 .76263 .45559 .77455 .45193 .7693 .44512 Mtetra
.7693 .44512 .77455 .45193 .78653 .44825 .78131 .44141 Mtetra
.78131 .44141 .78653 .44825 .79856 .44455 .79338 .43769 Mtetra
.79338 .43769 .79856 .44455 .81064 .44084 .80549 .43395 Mtetra
.80549 .43395 .81064 .44084 .82277 .43712 .81766 .4302 Mtetra
.81766 .4302 .82277 .43712 .83495 .43338 .82988 .42643 Mtetra
.82988 .42643 .83495 .43338 .84719 .42962 .84215 .42264 Mtetra
.84215 .42264 .84719 .42962 .85947 .42585 .85447 .41884 Mtetra
.85447 .41884 .85947 .42585 .87181 .42206 .86684 .41502 Mtetra
.86684 .41502 .87181 .42206 .88419 .41825 .87927 .41119 Mtetra
.87927 .41119 .88419 .41825 .89664 .41443 .89175 .40734 Mtetra
.89175 .40734 .89664 .41443 .90913 .4106 .90428 .40347 Mtetra
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39958 Mtetra
.91687 .39958 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.655 .752 .921 r
.35652 .66587 .3631 .6716 .37379 .6685 .36724 .66275 Mtetra
.36724 .66275 .37379 .6685 .38453 .66539 .37801 .65961 Mtetra
.37801 .65961 .38453 .66539 .39532 .66227 .38882 .65647 Mtetra
.38882 .65647 .39532 .66227 .40615 .65913 .39967 .65331 Mtetra
.39967 .65331 .40615 .65913 .41702 .65598 .41057 .65014 Mtetra
.41057 .65014 .41702 .65598 .43081 .54957 .42152 .64695 Mtetra
0 0 .239 r
.42152 .64695 .43081 .54957 .44145 .54629 .43526 .5402 Mtetra
.664 .741 .908 r
.43526 .5402 .44145 .54629 .45213 .543 .44597 .53688 Mtetra
.44597 .53688 .45213 .543 .46286 .53969 .45672 .53354 Mtetra
.45672 .53354 .46286 .53969 .47362 .53636 .46751 .5302 Mtetra
.46751 .5302 .47362 .53636 .48443 .53303 .47835 .52684 Mtetra
.47835 .52684 .48443 .53303 .49528 .52968 .48923 .52346 Mtetra
.48923 .52346 .49528 .52968 .50617 .52632 .50015 .52008 Mtetra
.50015 .52008 .50617 .52632 .51711 .52294 .51112 .51668 Mtetra
.51112 .51668 .51711 .52294 .52809 .51955 .52213 .51326 Mtetra
.52213 .51326 .52809 .51955 .53912 .51615 .53318 .50983 Mtetra
.53318 .50983 .53912 .51615 .55019 .51274 .54428 .50639 Mtetra
.54428 .50639 .55019 .51274 .5613 .50931 .55543 .50294 Mtetra
.55543 .50294 .5613 .50931 .57246 .50586 .56661 .49947 Mtetra
.56661 .49947 .57246 .50586 .58367 .50241 .57785 .49599 Mtetra
.57785 .49599 .58367 .50241 .59492 .49893 .58913 .49249 Mtetra
.58913 .49249 .59492 .49893 .60621 .49545 .60045 .48898 Mtetra
.60045 .48898 .60621 .49545 .61755 .49195 .61183 .48545 Mtetra
.61183 .48545 .61755 .49195 .62894 .48843 .62325 .48191 Mtetra
.62325 .48191 .62894 .48843 .64038 .48491 .63471 .47835 Mtetra
.63471 .47835 .64038 .48491 .65186 .48136 .64622 .47478 Mtetra
.64622 .47478 .65186 .48136 .66338 .47781 .65778 .4712 Mtetra
.65778 .4712 .66338 .47781 .67496 .47423 .66939 .4676 Mtetra
.66939 .4676 .67496 .47423 .68658 .47065 .68105 .46399 Mtetra
.68105 .46399 .68658 .47065 .69825 .46705 .69275 .46036 Mtetra
.69275 .46036 .69825 .46705 .70997 .46343 .7045 .45671 Mtetra
.7045 .45671 .70997 .46343 .72174 .4598 .7163 .45306 Mtetra
.7163 .45306 .72174 .4598 .73355 .45615 .72815 .44938 Mtetra
.72815 .44938 .73355 .45615 .74542 .45249 .74005 .44569 Mtetra
.74005 .44569 .74542 .45249 .75733 .44881 .752 .44199 Mtetra
.752 .44199 .75733 .44881 .7693 .44512 .764 .43827 Mtetra
.764 .43827 .7693 .44512 .78131 .44141 .77605 .43453 Mtetra
.77605 .43453 .78131 .44141 .79338 .43769 .78815 .43078 Mtetra
.78815 .43078 .79338 .43769 .80549 .43395 .8003 .42701 Mtetra
.8003 .42701 .80549 .43395 .81766 .4302 .81251 .42323 Mtetra
.81251 .42323 .81766 .4302 .82988 .42643 .82476 .41943 Mtetra
.82476 .41943 .82988 .42643 .84215 .42264 .83707 .41561 Mtetra
.83707 .41561 .84215 .42264 .85447 .41884 .84943 .41178 Mtetra
.84943 .41178 .85447 .41884 .86684 .41502 .86184 .40793 Mtetra
.86184 .40793 .86684 .41502 .87927 .41119 .8743 .40406 Mtetra
.8743 .40406 .87927 .41119 .89175 .40734 .88682 .40018 Mtetra
.88682 .40018 .89175 .40734 .90428 .40347 .89939 .39628 Mtetra
.89939 .39628 .90428 .40347 .91687 .39958 .91202 .39237 Mtetra
.91202 .39237 .91687 .39958 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.655 .752 .921 r
.34989 .6601 .35652 .66587 .36724 .66275 .36064 .65695 Mtetra
.36064 .65695 .36724 .66275 .37801 .65961 .37143 .65379 Mtetra
.37143 .65379 .37801 .65961 .38882 .65647 .38227 .65062 Mtetra
.38227 .65062 .38882 .65647 .39967 .65331 .39315 .64744 Mtetra
.39315 .64744 .39967 .65331 .41057 .65014 .40408 .64425 Mtetra
.40408 .64425 .41057 .65014 .42152 .64695 .41505 .64104 Mtetra
.41505 .64104 .42152 .64695 .43526 .5402 .42607 .63781 Mtetra
0 0 .239 r
.42607 .63781 .43526 .5402 .44597 .53688 .43976 .53071 Mtetra
.664 .741 .908 r
.43976 .53071 .44597 .53688 .45672 .53354 .45054 .52735 Mtetra
.45054 .52735 .45672 .53354 .46751 .5302 .46136 .52398 Mtetra
.46136 .52398 .46751 .5302 .47835 .52684 .47222 .5206 Mtetra
.47222 .5206 .47835 .52684 .48923 .52346 .48313 .5172 Mtetra
.48313 .5172 .48923 .52346 .50015 .52008 .49408 .51379 Mtetra
.49408 .51379 .50015 .52008 .51112 .51668 .50508 .51036 Mtetra
.50508 .51036 .51112 .51668 .52213 .51326 .51612 .50692 Mtetra
.51612 .50692 .52213 .51326 .53318 .50983 .5272 .50347 Mtetra
.5272 .50347 .53318 .50983 .54428 .50639 .53833 .5 Mtetra
.53833 .5 .54428 .50639 .55543 .50294 .5495 .49652 Mtetra
.5495 .49652 .55543 .50294 .56661 .49947 .56072 .49303 Mtetra
.56072 .49303 .56661 .49947 .57785 .49599 .57199 .48952 Mtetra
.57199 .48952 .57785 .49599 .58913 .49249 .5833 .48599 Mtetra
.5833 .48599 .58913 .49249 .60045 .48898 .59465 .48245 Mtetra
.59465 .48245 .60045 .48898 .61183 .48545 .60606 .4789 Mtetra
.60606 .4789 .61183 .48545 .62325 .48191 .61751 .47533 Mtetra
.61751 .47533 .62325 .48191 .63471 .47835 .629 .47175 Mtetra
.629 .47175 .63471 .47835 .64622 .47478 .64055 .46816 Mtetra
.64055 .46816 .64622 .47478 .65778 .4712 .65214 .46454 Mtetra
.65214 .46454 .65778 .4712 .66939 .4676 .66378 .46092 Mtetra
.66378 .46092 .66939 .4676 .68105 .46399 .67547 .45728 Mtetra
.67547 .45728 .68105 .46399 .69275 .46036 .68721 .45362 Mtetra
.68721 .45362 .69275 .46036 .7045 .45671 .69899 .44995 Mtetra
.69899 .44995 .7045 .45671 .7163 .45306 .71083 .44626 Mtetra
.71083 .44626 .7163 .45306 .72815 .44938 .72271 .44256 Mtetra
.72271 .44256 .72815 .44938 .74005 .44569 .73465 .43884 Mtetra
.73465 .43884 .74005 .44569 .752 .44199 .74663 .4351 Mtetra
.74663 .4351 .752 .44199 .764 .43827 .75866 .43136 Mtetra
.75866 .43136 .764 .43827 .77605 .43453 .77075 .42759 Mtetra
.77075 .42759 .77605 .43453 .78815 .43078 .78289 .42381 Mtetra
.78289 .42381 .78815 .43078 .8003 .42701 .79507 .42001 Mtetra
.79507 .42001 .8003 .42701 .81251 .42323 .80731 .4162 Mtetra
.80731 .4162 .81251 .42323 .82476 .41943 .81961 .41237 Mtetra
.81961 .41237 .82476 .41943 .83707 .41561 .83195 .40852 Mtetra
.83195 .40852 .83707 .41561 .84943 .41178 .84435 .40466 Mtetra
.84435 .40466 .84943 .41178 .86184 .40793 .8568 .40078 Mtetra
.8568 .40078 .86184 .40793 .8743 .40406 .8693 .39689 Mtetra
.8693 .39689 .8743 .40406 .88682 .40018 .88186 .39297 Mtetra
.88186 .39297 .88682 .40018 .89939 .39628 .89447 .38904 Mtetra
.89447 .38904 .89939 .39628 .91202 .39237 .90713 .3851 Mtetra
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37715 Mtetra
.655 .752 .921 r
.34321 .65428 .34989 .6601 .36064 .65695 .35399 .65111 Mtetra
.35399 .65111 .36064 .65695 .37143 .65379 .36481 .64793 Mtetra
.36481 .64793 .37143 .65379 .38227 .65062 .37567 .64474 Mtetra
.37567 .64474 .38227 .65062 .39315 .64744 .38658 .64153 Mtetra
.38658 .64153 .39315 .64744 .40408 .64425 .39754 .63831 Mtetra
.39754 .63831 .40408 .64425 .41505 .64104 .40854 .63508 Mtetra
.40854 .63508 .41505 .64104 .42607 .63781 .41958 .63183 Mtetra
.41958 .63183 .42607 .63781 .43976 .53071 .43067 .62857 Mtetra
.548 .316 .515 r
.43067 .62857 .43976 .53071 .45054 .52735 .4418 .6253 Mtetra
0 0 .246 r
.4418 .6253 .45054 .52735 .46136 .52398 .45516 .51772 Mtetra
.664 .741 .908 r
.45516 .51772 .46136 .52398 .47222 .5206 .46605 .51431 Mtetra
.46605 .51431 .47222 .5206 .48313 .5172 .47699 .51089 Mtetra
.47699 .51089 .48313 .5172 .49408 .51379 .48797 .50745 Mtetra
.48797 .50745 .49408 .51379 .50508 .51036 .49899 .504 Mtetra
.49899 .504 .50508 .51036 .51612 .50692 .51006 .50054 Mtetra
.51006 .50054 .51612 .50692 .5272 .50347 .52117 .49706 Mtetra
.52117 .49706 .5272 .50347 .53833 .5 .53233 .49357 Mtetra
.53233 .49357 .53833 .5 .5495 .49652 .54353 .49006 Mtetra
.54353 .49006 .5495 .49652 .56072 .49303 .55478 .48654 Mtetra
.55478 .48654 .56072 .49303 .57199 .48952 .56608 .483 Mtetra
.56608 .483 .57199 .48952 .5833 .48599 .57742 .47945 Mtetra
.57742 .47945 .5833 .48599 .59465 .48245 .58881 .47588 Mtetra
.58881 .47588 .59465 .48245 .60606 .4789 .60024 .4723 Mtetra
.60024 .4723 .60606 .4789 .61751 .47533 .61172 .46871 Mtetra
.61172 .46871 .61751 .47533 .629 .47175 .62325 .4651 Mtetra
.62325 .4651 .629 .47175 .64055 .46816 .63483 .46148 Mtetra
.63483 .46148 .64055 .46816 .65214 .46454 .64645 .45784 Mtetra
.64645 .45784 .65214 .46454 .66378 .46092 .65813 .45418 Mtetra
.65813 .45418 .66378 .46092 .67547 .45728 .66985 .45051 Mtetra
.66985 .45051 .67547 .45728 .68721 .45362 .68162 .44683 Mtetra
.68162 .44683 .68721 .45362 .69899 .44995 .69344 .44313 Mtetra
.69344 .44313 .69899 .44995 .71083 .44626 .70531 .43941 Mtetra
.70531 .43941 .71083 .44626 .72271 .44256 .71723 .43568 Mtetra
.71723 .43568 .72271 .44256 .73465 .43884 .7292 .43193 Mtetra
.7292 .43193 .73465 .43884 .74663 .4351 .74122 .42817 Mtetra
.74122 .42817 .74663 .4351 .75866 .43136 .75329 .42439 Mtetra
.75329 .42439 .75866 .43136 .77075 .42759 .76541 .4206 Mtetra
.76541 .4206 .77075 .42759 .78289 .42381 .77758 .41679 Mtetra
.77758 .41679 .78289 .42381 .79507 .42001 .7898 .41296 Mtetra
.7898 .41296 .79507 .42001 .80731 .4162 .80208 .40912 Mtetra
.80208 .40912 .80731 .4162 .81961 .41237 .81441 .40526 Mtetra
.81441 .40526 .81961 .41237 .83195 .40852 .82679 .40138 Mtetra
.82679 .40138 .83195 .40852 .84435 .40466 .83923 .39749 Mtetra
.83923 .39749 .84435 .40466 .8568 .40078 .85171 .39358 Mtetra
.85171 .39358 .8568 .40078 .8693 .39689 .86426 .38965 Mtetra
.86426 .38965 .8693 .39689 .88186 .39297 .87685 .38571 Mtetra
.87685 .38571 .88186 .39297 .89447 .38904 .8895 .38175 Mtetra
.8895 .38175 .89447 .38904 .90713 .3851 .90221 .37777 Mtetra
.90221 .37777 .90713 .3851 .91985 .38114 .91497 .37377 Mtetra
.91497 .37377 .91985 .38114 .93263 .37715 .92778 .36976 Mtetra
.655 .752 .921 r
.33648 .64842 .34321 .65428 .35399 .65111 .34728 .64523 Mtetra
.34728 .64523 .35399 .65111 .36481 .64793 .35813 .64202 Mtetra
.35813 .64202 .36481 .64793 .37567 .64474 .36903 .63881 Mtetra
.36903 .63881 .37567 .64474 .38658 .64153 .37996 .63557 Mtetra
.37996 .63557 .38658 .64153 .39754 .63831 .39094 .63233 Mtetra
.39094 .63233 .39754 .63831 .40854 .63508 .40197 .62907 Mtetra
.40197 .62907 .40854 .63508 .41958 .63183 .41304 .6258 Mtetra
.41304 .6258 .41958 .63183 .43067 .62857 .42416 .62252 Mtetra
.42416 .62252 .43067 .62857 .4418 .6253 .43533 .61922 Mtetra
.43533 .61922 .4418 .6253 .45516 .51772 .44654 .6159 Mtetra
0 0 .246 r
.44654 .6159 .45516 .51772 .46605 .51431 .45984 .50798 Mtetra
.664 .741 .908 r
.45984 .50798 .46605 .51431 .47699 .51089 .4708 .50453 Mtetra
.4708 .50453 .47699 .51089 .48797 .50745 .48181 .50107 Mtetra
.48181 .50107 .48797 .50745 .49899 .504 .49286 .49759 Mtetra
.49286 .49759 .49899 .504 .51006 .50054 .50396 .4941 Mtetra
.50396 .4941 .51006 .50054 .52117 .49706 .5151 .4906 Mtetra
.5151 .4906 .52117 .49706 .53233 .49357 .52629 .48708 Mtetra
.52629 .48708 .53233 .49357 .54353 .49006 .53752 .48355 Mtetra
.53752 .48355 .54353 .49006 .55478 .48654 .5488 .48 Mtetra
.5488 .48 .55478 .48654 .56608 .483 .56013 .47643 Mtetra
.56013 .47643 .56608 .483 .57742 .47945 .5715 .47286 Mtetra
.5715 .47286 .57742 .47945 .58881 .47588 .58292 .46926 Mtetra
.58292 .46926 .58881 .47588 .60024 .4723 .59438 .46566 Mtetra
.59438 .46566 .60024 .4723 .61172 .46871 .6059 .46203 Mtetra
.6059 .46203 .61172 .46871 .62325 .4651 .61746 .4584 Mtetra
.61746 .4584 .62325 .4651 .63483 .46148 .62907 .45475 Mtetra
.62907 .45475 .63483 .46148 .64645 .45784 .64072 .45108 Mtetra
.64072 .45108 .64645 .45784 .65813 .45418 .65243 .4474 Mtetra
.65243 .4474 .65813 .45418 .66985 .45051 .66418 .4437 Mtetra
.66418 .4437 .66985 .45051 .68162 .44683 .67599 .43998 Mtetra
.67599 .43998 .68162 .44683 .69344 .44313 .68784 .43626 Mtetra
.68784 .43626 .69344 .44313 .70531 .43941 .69975 .43251 Mtetra
.69975 .43251 .70531 .43941 .71723 .43568 .7117 .42875 Mtetra
.7117 .42875 .71723 .43568 .7292 .43193 .7237 .42497 Mtetra
.7237 .42497 .7292 .43193 .74122 .42817 .73576 .42118 Mtetra
.73576 .42118 .74122 .42817 .75329 .42439 .74786 .41737 Mtetra
.74786 .41737 .75329 .42439 .76541 .4206 .76002 .41355 Mtetra
.76002 .41355 .76541 .4206 .77758 .41679 .77223 .40971 Mtetra
.77223 .40971 .77758 .41679 .7898 .41296 .78449 .40585 Mtetra
.78449 .40585 .7898 .41296 .80208 .40912 .79681 .40198 Mtetra
.79681 .40198 .80208 .40912 .81441 .40526 .80917 .39809 Mtetra
.80917 .39809 .81441 .40526 .82679 .40138 .82159 .39418 Mtetra
.82159 .39418 .82679 .40138 .83923 .39749 .83406 .39025 Mtetra
.83406 .39025 .83923 .39749 .85171 .39358 .84659 .38631 Mtetra
.84659 .38631 .85171 .39358 .86426 .38965 .85917 .38236 Mtetra
.85917 .38236 .86426 .38965 .87685 .38571 .87181 .37838 Mtetra
.87181 .37838 .87685 .38571 .8895 .38175 .8845 .37439 Mtetra
.8845 .37439 .8895 .38175 .90221 .37777 .89724 .37038 Mtetra
.89724 .37038 .90221 .37777 .91497 .37377 .91004 .36635 Mtetra
.91004 .36635 .91497 .37377 .92778 .36976 .9229 .36231 Mtetra
.655 .752 .921 r
.3297 .64252 .33648 .64842 .34728 .64523 .34053 .6393 Mtetra
.34053 .6393 .34728 .64523 .35813 .64202 .35141 .63607 Mtetra
.35141 .63607 .35813 .64202 .36903 .63881 .36233 .63283 Mtetra
.36233 .63283 .36903 .63881 .37996 .63557 .37329 .62957 Mtetra
.37329 .62957 .37996 .63557 .39094 .63233 .3843 .6263 Mtetra
.3843 .6263 .39094 .63233 .40197 .62907 .39536 .62302 Mtetra
.39536 .62302 .40197 .62907 .41304 .6258 .40646 .61973 Mtetra
.40646 .61973 .41304 .6258 .42416 .62252 .41761 .61642 Mtetra
.41761 .61642 .42416 .62252 .43533 .61922 .4288 .61309 Mtetra
.4288 .61309 .43533 .61922 .44654 .6159 .44004 .60975 Mtetra
.44004 .60975 .44654 .6159 .45984 .50798 .45133 .6064 Mtetra
0 0 .246 r
.45133 .6064 .45984 .50798 .4708 .50453 .46457 .49813 Mtetra
.664 .741 .908 r
.46457 .49813 .4708 .50453 .48181 .50107 .4756 .49464 Mtetra
.4756 .49464 .48181 .50107 .49286 .49759 .48668 .49114 Mtetra
.48668 .49114 .49286 .49759 .50396 .4941 .49781 .48762 Mtetra
.49781 .48762 .50396 .4941 .5151 .4906 .50898 .48409 Mtetra
.50898 .48409 .5151 .4906 .52629 .48708 .5202 .48054 Mtetra
.5202 .48054 .52629 .48708 .53752 .48355 .53146 .47698 Mtetra
.53146 .47698 .53752 .48355 .5488 .48 .54277 .47341 Mtetra
.54277 .47341 .5488 .48 .56013 .47643 .55413 .46982 Mtetra
.55413 .46982 .56013 .47643 .5715 .47286 .56553 .46621 Mtetra
.56553 .46621 .5715 .47286 .58292 .46926 .57698 .46259 Mtetra
.57698 .46259 .58292 .46926 .59438 .46566 .58848 .45896 Mtetra
.58848 .45896 .59438 .46566 .6059 .46203 .60002 .45531 Mtetra
.60002 .45531 .6059 .46203 .61746 .4584 .61162 .45164 Mtetra
.61162 .45164 .61746 .4584 .62907 .45475 .62326 .44796 Mtetra
.62326 .44796 .62907 .45475 .64072 .45108 .63495 .44427 Mtetra
.63495 .44427 .64072 .45108 .65243 .4474 .64669 .44056 Mtetra
.64669 .44056 .65243 .4474 .66418 .4437 .65848 .43683 Mtetra
.65848 .43683 .66418 .4437 .67599 .43998 .67031 .43309 Mtetra
.67031 .43309 .67599 .43998 .68784 .43626 .6822 .42933 Mtetra
.6822 .42933 .68784 .43626 .69975 .43251 .69414 .42556 Mtetra
.69414 .42556 .69975 .43251 .7117 .42875 .70613 .42177 Mtetra
.70613 .42177 .7117 .42875 .7237 .42497 .71817 .41796 Mtetra
.71817 .41796 .7237 .42497 .73576 .42118 .73026 .41414 Mtetra
.73026 .41414 .73576 .42118 .74786 .41737 .7424 .4103 Mtetra
.7424 .4103 .74786 .41737 .76002 .41355 .75459 .40644 Mtetra
.75459 .40644 .76002 .41355 .77223 .40971 .76684 .40257 Mtetra
.76684 .40257 .77223 .40971 .78449 .40585 .77914 .39869 Mtetra
.77914 .39869 .78449 .40585 .79681 .40198 .79149 .39478 Mtetra
.79149 .39478 .79681 .40198 .80917 .39809 .80389 .39086 Mtetra
.80389 .39086 .80917 .39809 .82159 .39418 .81635 .38692 Mtetra
.81635 .38692 .82159 .39418 .83406 .39025 .82886 .38297 Mtetra
.82886 .38297 .83406 .39025 .84659 .38631 .84143 .37899 Mtetra
.84143 .37899 .84659 .38631 .85917 .38236 .85405 .375 Mtetra
.85405 .375 .85917 .38236 .87181 .37838 .86672 .371 Mtetra
.86672 .371 .87181 .37838 .8845 .37439 .87945 .36697 Mtetra
.87945 .36697 .8845 .37439 .89724 .37038 .89224 .36293 Mtetra
.89224 .36293 .89724 .37038 .91004 .36635 .90508 .35887 Mtetra
.90508 .35887 .91004 .36635 .9229 .36231 .91798 .35479 Mtetra
.655 .752 .921 r
.32287 .63657 .3297 .64252 .34053 .6393 .33373 .63333 Mtetra
.33373 .63333 .34053 .6393 .35141 .63607 .34463 .63008 Mtetra
.34463 .63008 .35141 .63607 .36233 .63283 .35558 .62681 Mtetra
.35558 .62681 .36233 .63283 .37329 .62957 .36657 .62353 Mtetra
.36657 .62353 .37329 .62957 .3843 .6263 .37761 .62023 Mtetra
.37761 .62023 .3843 .6263 .39536 .62302 .38869 .61693 Mtetra
.38869 .61693 .39536 .62302 .40646 .61973 .39982 .6136 Mtetra
.39982 .6136 .40646 .61973 .41761 .61642 .411 .61027 Mtetra
.411 .61027 .41761 .61642 .4288 .61309 .42222 .60692 Mtetra
.42222 .60692 .4288 .61309 .44004 .60975 .43349 .60355 Mtetra
.43349 .60355 .44004 .60975 .45133 .6064 .44481 .60018 Mtetra
.44481 .60018 .45133 .6064 .46457 .49813 .45617 .59679 Mtetra
0 0 .246 r
.45617 .59679 .46457 .49813 .4756 .49464 .46935 .48816 Mtetra
.664 .741 .908 r
.46935 .48816 .4756 .49464 .48668 .49114 .48046 .48463 Mtetra
.48046 .48463 .48668 .49114 .49781 .48762 .49162 .48109 Mtetra
.49162 .48109 .49781 .48762 .50898 .48409 .50282 .47753 Mtetra
.50282 .47753 .50898 .48409 .5202 .48054 .51406 .47396 Mtetra
.51406 .47396 .5202 .48054 .53146 .47698 .52536 .47037 Mtetra
.52536 .47037 .53146 .47698 .54277 .47341 .5367 .46677 Mtetra
.5367 .46677 .54277 .47341 .55413 .46982 .54809 .46315 Mtetra
.54809 .46315 .55413 .46982 .56553 .46621 .55952 .45952 Mtetra
.55952 .45952 .56553 .46621 .57698 .46259 .571 .45587 Mtetra
.571 .45587 .57698 .46259 .58848 .45896 .58253 .45221 Mtetra
.58253 .45221 .58848 .45896 .60002 .45531 .59411 .44853 Mtetra
.59411 .44853 .60002 .45531 .61162 .45164 .60573 .44484 Mtetra
.60573 .44484 .61162 .45164 .62326 .44796 .61741 .44113 Mtetra
.61741 .44113 .62326 .44796 .63495 .44427 .62913 .4374 Mtetra
.62913 .4374 .63495 .44427 .64669 .44056 .6409 .43366 Mtetra
.6409 .43366 .64669 .44056 .65848 .43683 .65272 .42991 Mtetra
.65272 .42991 .65848 .43683 .67031 .43309 .6646 .42614 Mtetra
.6646 .42614 .67031 .43309 .6822 .42933 .67652 .42235 Mtetra
.67652 .42235 .6822 .42933 .69414 .42556 .68849 .41855 Mtetra
.68849 .41855 .69414 .42556 .70613 .42177 .70051 .41473 Mtetra
.70051 .41473 .70613 .42177 .71817 .41796 .71259 .41089 Mtetra
.71259 .41089 .71817 .41796 .73026 .41414 .72471 .40704 Mtetra
.72471 .40704 .73026 .41414 .7424 .4103 .73689 .40317 Mtetra
.73689 .40317 .7424 .4103 .75459 .40644 .74912 .39928 Mtetra
.74912 .39928 .75459 .40644 .76684 .40257 .76141 .39538 Mtetra
.76141 .39538 .76684 .40257 .77914 .39869 .77374 .39146 Mtetra
.77374 .39146 .77914 .39869 .79149 .39478 .78613 .38753 Mtetra
.78613 .38753 .79149 .39478 .80389 .39086 .79857 .38358 Mtetra
.79857 .38358 .80389 .39086 .81635 .38692 .81107 .37961 Mtetra
.81107 .37961 .81635 .38692 .82886 .38297 .82362 .37562 Mtetra
.82362 .37562 .82886 .38297 .84143 .37899 .83622 .37161 Mtetra
.83622 .37161 .84143 .37899 .85405 .375 .84888 .36759 Mtetra
.84888 .36759 .85405 .375 .86672 .371 .8616 .36355 Mtetra
.8616 .36355 .86672 .371 .87945 .36697 .87437 .3595 Mtetra
.87437 .3595 .87945 .36697 .89224 .36293 .88719 .35542 Mtetra
.88719 .35542 .89224 .36293 .90508 .35887 .90008 .35133 Mtetra
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.655 .752 .921 r
.31599 .63058 .32287 .63657 .33373 .63333 .32687 .62731 Mtetra
.32687 .62731 .33373 .63333 .34463 .63008 .3378 .62403 Mtetra
.3378 .62403 .34463 .63008 .35558 .62681 .34878 .62074 Mtetra
.34878 .62074 .35558 .62681 .36657 .62353 .3598 .61744 Mtetra
.3598 .61744 .36657 .62353 .37761 .62023 .37087 .61412 Mtetra
.37087 .61412 .37761 .62023 .38869 .61693 .38198 .61078 Mtetra
.38198 .61078 .38869 .61693 .39982 .6136 .39314 .60743 Mtetra
.39314 .60743 .39982 .6136 .411 .61027 .40434 .60407 Mtetra
.40434 .60407 .411 .61027 .42222 .60692 .4156 .6007 Mtetra
.4156 .6007 .42222 .60692 .43349 .60355 .42689 .59731 Mtetra
.42689 .59731 .43349 .60355 .44481 .60018 .43824 .5939 Mtetra
.43824 .5939 .44481 .60018 .45617 .59679 .44964 .59049 Mtetra
.44964 .59049 .45617 .59679 .46935 .48816 .46108 .58705 Mtetra
.543 .307 .508 r
.46108 .58705 .46935 .48816 .48046 .48463 .47257 .58361 Mtetra
0 0 .253 r
.47257 .58361 .48046 .48463 .49162 .48109 .48538 .47451 Mtetra
.664 .741 .908 r
.48538 .47451 .49162 .48109 .50282 .47753 .49661 .47092 Mtetra
.49661 .47092 .50282 .47753 .51406 .47396 .50788 .46732 Mtetra
.50788 .46732 .51406 .47396 .52536 .47037 .51921 .46371 Mtetra
.51921 .46371 .52536 .47037 .5367 .46677 .53058 .46008 Mtetra
.53058 .46008 .5367 .46677 .54809 .46315 .542 .45643 Mtetra
.542 .45643 .54809 .46315 .55952 .45952 .55346 .45277 Mtetra
.55346 .45277 .55952 .45952 .571 .45587 .56497 .4491 Mtetra
.56497 .4491 .571 .45587 .58253 .45221 .57654 .44541 Mtetra
.57654 .44541 .58253 .45221 .59411 .44853 .58814 .4417 Mtetra
.58814 .4417 .59411 .44853 .60573 .44484 .5998 .43798 Mtetra
.5998 .43798 .60573 .44484 .61741 .44113 .61151 .43424 Mtetra
.61151 .43424 .61741 .44113 .62913 .4374 .62327 .43049 Mtetra
.62327 .43049 .62913 .4374 .6409 .43366 .63507 .42672 Mtetra
.63507 .42672 .6409 .43366 .65272 .42991 .64693 .42293 Mtetra
.64693 .42293 .65272 .42991 .6646 .42614 .65883 .41913 Mtetra
.65883 .41913 .6646 .42614 .67652 .42235 .67079 .41532 Mtetra
.67079 .41532 .67652 .42235 .68849 .41855 .6828 .41148 Mtetra
.6828 .41148 .68849 .41855 .70051 .41473 .69486 .40763 Mtetra
.69486 .40763 .70051 .41473 .71259 .41089 .70697 .40377 Mtetra
.70697 .40377 .71259 .41089 .72471 .40704 .71913 .39988 Mtetra
.71913 .39988 .72471 .40704 .73689 .40317 .73134 .39598 Mtetra
.73134 .39598 .73689 .40317 .74912 .39928 .74361 .39207 Mtetra
.74361 .39207 .74912 .39928 .76141 .39538 .75593 .38814 Mtetra
.75593 .38814 .76141 .39538 .77374 .39146 .7683 .38419 Mtetra
.7683 .38419 .77374 .39146 .78613 .38753 .78073 .38022 Mtetra
.78073 .38022 .78613 .38753 .79857 .38358 .79321 .37623 Mtetra
.79321 .37623 .79857 .38358 .81107 .37961 .80574 .37223 Mtetra
.80574 .37223 .81107 .37961 .82362 .37562 .81833 .36821 Mtetra
.81833 .36821 .82362 .37562 .83622 .37161 .83097 .36418 Mtetra
.83097 .36418 .83622 .37161 .84888 .36759 .84367 .36012 Mtetra
.84367 .36012 .84888 .36759 .8616 .36355 .85643 .35605 Mtetra
.85643 .35605 .8616 .36355 .87437 .3595 .86924 .35196 Mtetra
.86924 .35196 .87437 .3595 .88719 .35542 .88211 .34785 Mtetra
.88211 .34785 .88719 .35542 .90008 .35133 .89503 .34373 Mtetra
.89503 .34373 .90008 .35133 .91302 .34722 .90801 .33958 Mtetra
.655 .752 .921 r
.30905 .62454 .31599 .63058 .32687 .62731 .31997 .62125 Mtetra
.31997 .62125 .32687 .62731 .3378 .62403 .33092 .61794 Mtetra
.33092 .61794 .3378 .62403 .34878 .62074 .34193 .61463 Mtetra
.34193 .61463 .34878 .62074 .3598 .61744 .35298 .6113 Mtetra
.35298 .6113 .3598 .61744 .37087 .61412 .36407 .60795 Mtetra
.36407 .60795 .37087 .61412 .38198 .61078 .37521 .60459 Mtetra
.37521 .60459 .38198 .61078 .39314 .60743 .3864 .60122 Mtetra
.3864 .60122 .39314 .60743 .40434 .60407 .39763 .59783 Mtetra
.39763 .59783 .40434 .60407 .4156 .6007 .40892 .59443 Mtetra
.40892 .59443 .4156 .6007 .42689 .59731 .42025 .59101 Mtetra
.42025 .59101 .42689 .59731 .43824 .5939 .43162 .58758 Mtetra
.43162 .58758 .43824 .5939 .44964 .59049 .44305 .58414 Mtetra
.44305 .58414 .44964 .59049 .46108 .58705 .45452 .58068 Mtetra
.45452 .58068 .46108 .58705 .47257 .58361 .46604 .5772 Mtetra
.46604 .5772 .47257 .58361 .48538 .47451 .47761 .57372 Mtetra
0 0 .253 r
.47761 .57372 .48538 .47451 .49661 .47092 .49035 .46427 Mtetra
.664 .741 .908 r
.49035 .46427 .49661 .47092 .50788 .46732 .50166 .46064 Mtetra
.50166 .46064 .50788 .46732 .51921 .46371 .51301 .45699 Mtetra
.51301 .45699 .51921 .46371 .53058 .46008 .52441 .45334 Mtetra
.52441 .45334 .53058 .46008 .542 .45643 .53586 .44966 Mtetra
.53586 .44966 .542 .45643 .55346 .45277 .54736 .44598 Mtetra
.54736 .44598 .55346 .45277 .56497 .4491 .5589 .44227 Mtetra
.5589 .44227 .56497 .4491 .57654 .44541 .57049 .43855 Mtetra
.57049 .43855 .57654 .44541 .58814 .4417 .58214 .43482 Mtetra
.58214 .43482 .58814 .4417 .5998 .43798 .59383 .43107 Mtetra
.59383 .43107 .5998 .43798 .61151 .43424 .60557 .4273 Mtetra
.60557 .4273 .61151 .43424 .62327 .43049 .61736 .42352 Mtetra
.61736 .42352 .62327 .43049 .63507 .42672 .6292 .41972 Mtetra
.6292 .41972 .63507 .42672 .64693 .42293 .64109 .4159 Mtetra
.64109 .4159 .64693 .42293 .65883 .41913 .65303 .41207 Mtetra
.65303 .41207 .65883 .41913 .67079 .41532 .66502 .40823 Mtetra
.66502 .40823 .67079 .41532 .6828 .41148 .67706 .40436 Mtetra
.67706 .40436 .6828 .41148 .69486 .40763 .68915 .40048 Mtetra
.68915 .40048 .69486 .40763 .70697 .40377 .7013 .39659 Mtetra
.7013 .39659 .70697 .40377 .71913 .39988 .7135 .39267 Mtetra
.7135 .39267 .71913 .39988 .73134 .39598 .72575 .38874 Mtetra
.72575 .38874 .73134 .39598 .74361 .39207 .73805 .38479 Mtetra
.73805 .38479 .74361 .39207 .75593 .38814 .75041 .38083 Mtetra
.75041 .38083 .75593 .38814 .7683 .38419 .76282 .37685 Mtetra
.76282 .37685 .7683 .38419 .78073 .38022 .77528 .37285 Mtetra
.77528 .37285 .78073 .38022 .79321 .37623 .7878 .36883 Mtetra
.7878 .36883 .79321 .37623 .80574 .37223 .80037 .3648 Mtetra
.80037 .3648 .80574 .37223 .81833 .36821 .813 .36075 Mtetra
.813 .36075 .81833 .36821 .83097 .36418 .82568 .35668 Mtetra
.82568 .35668 .83097 .36418 .84367 .36012 .83842 .35259 Mtetra
.83842 .35259 .84367 .36012 .85643 .35605 .85122 .34849 Mtetra
.85122 .34849 .85643 .35605 .86924 .35196 .86407 .34436 Mtetra
.86407 .34436 .86924 .35196 .88211 .34785 .87698 .34022 Mtetra
.87698 .34022 .88211 .34785 .89503 .34373 .88994 .33606 Mtetra
.88994 .33606 .89503 .34373 .90801 .33958 .90297 .33188 Mtetra
.655 .752 .921 r
.30207 .61845 .30905 .62454 .31997 .62125 .31301 .61514 Mtetra
.31301 .61514 .31997 .62125 .33092 .61794 .32399 .61181 Mtetra
.32399 .61181 .33092 .61794 .34193 .61463 .33502 .60847 Mtetra
.33502 .60847 .34193 .61463 .35298 .6113 .3461 .60511 Mtetra
.3461 .60511 .35298 .6113 .36407 .60795 .35722 .60174 Mtetra
.35722 .60174 .36407 .60795 .37521 .60459 .36839 .59835 Mtetra
.36839 .59835 .37521 .60459 .3864 .60122 .37961 .59495 Mtetra
.37961 .59495 .3864 .60122 .39763 .59783 .39087 .59154 Mtetra
.39087 .59154 .39763 .59783 .40892 .59443 .40218 .58811 Mtetra
.40218 .58811 .40892 .59443 .42025 .59101 .41354 .58467 Mtetra
.41354 .58467 .42025 .59101 .43162 .58758 .42495 .58121 Mtetra
.42495 .58121 .43162 .58758 .44305 .58414 .43641 .57774 Mtetra
.43641 .57774 .44305 .58414 .45452 .58068 .44791 .57425 Mtetra
.44791 .57425 .45452 .58068 .46604 .5772 .45946 .57075 Mtetra
.45946 .57075 .46604 .5772 .47761 .57372 .47107 .56724 Mtetra
.47107 .56724 .47761 .57372 .49035 .46427 .48272 .5637 Mtetra
0 0 .253 r
.48272 .5637 .49035 .46427 .50166 .46064 .49538 .4539 Mtetra
.664 .741 .908 r
.49538 .4539 .50166 .46064 .51301 .45699 .50676 .45023 Mtetra
.50676 .45023 .51301 .45699 .52441 .45334 .5182 .44654 Mtetra
.5182 .44654 .52441 .45334 .53586 .44966 .52968 .44284 Mtetra
.52968 .44284 .53586 .44966 .54736 .44598 .5412 .43913 Mtetra
.5412 .43913 .54736 .44598 .5589 .44227 .55278 .43539 Mtetra
.55278 .43539 .5589 .44227 .57049 .43855 .56441 .43164 Mtetra
.56441 .43164 .57049 .43855 .58214 .43482 .57608 .42788 Mtetra
.57608 .42788 .58214 .43482 .59383 .43107 .5878 .4241 Mtetra
.5878 .4241 .59383 .43107 .60557 .4273 .59958 .4203 Mtetra
.59958 .4203 .60557 .4273 .61736 .42352 .6114 .41649 Mtetra
.6114 .41649 .61736 .42352 .6292 .41972 .62327 .41266 Mtetra
.62327 .41266 .6292 .41972 .64109 .4159 .6352 .40882 Mtetra
.6352 .40882 .64109 .4159 .65303 .41207 .64717 .40496 Mtetra
.64717 .40496 .65303 .41207 .66502 .40823 .6592 .40108 Mtetra
.6592 .40108 .66502 .40823 .67706 .40436 .67128 .39719 Mtetra
.67128 .39719 .67706 .40436 .68915 .40048 .6834 .39327 Mtetra
.6834 .39327 .68915 .40048 .7013 .39659 .69559 .38935 Mtetra
.69559 .38935 .7013 .39659 .7135 .39267 .70782 .3854 Mtetra
.70782 .3854 .7135 .39267 .72575 .38874 .72011 .38144 Mtetra
.72011 .38144 .72575 .38874 .73805 .38479 .73245 .37746 Mtetra
.73245 .37746 .73805 .38479 .75041 .38083 .74484 .37347 Mtetra
.74484 .37347 .75041 .38083 .76282 .37685 .75729 .36945 Mtetra
.75729 .36945 .76282 .37685 .77528 .37285 .76979 .36542 Mtetra
.76979 .36542 .77528 .37285 .7878 .36883 .78235 .36137 Mtetra
.78235 .36137 .7878 .36883 .80037 .3648 .79496 .35731 Mtetra
.79496 .35731 .80037 .3648 .813 .36075 .80763 .35322 Mtetra
.80763 .35322 .813 .36075 .82568 .35668 .82035 .34912 Mtetra
.82035 .34912 .82568 .35668 .83842 .35259 .83313 .345 Mtetra
.83313 .345 .83842 .35259 .85122 .34849 .84597 .34086 Mtetra
.84597 .34086 .85122 .34849 .86407 .34436 .85886 .3367 Mtetra
.85886 .3367 .86407 .34436 .87698 .34022 .87181 .33253 Mtetra
.87181 .33253 .87698 .34022 .88994 .33606 .88482 .32833 Mtetra
.88482 .32833 .88994 .33606 .90297 .33188 .89788 .32412 Mtetra
.655 .752 .921 r
.29503 .61232 .30207 .61845 .31301 .61514 .30599 .60898 Mtetra
.30599 .60898 .31301 .61514 .32399 .61181 .31701 .60563 Mtetra
.31701 .60563 .32399 .61181 .33502 .60847 .32806 .60226 Mtetra
.32806 .60226 .33502 .60847 .3461 .60511 .33917 .59887 Mtetra
.33917 .59887 .3461 .60511 .35722 .60174 .35032 .59548 Mtetra
.35032 .59548 .35722 .60174 .36839 .59835 .36152 .59207 Mtetra
.36152 .59207 .36839 .59835 .37961 .59495 .37277 .58864 Mtetra
.37277 .58864 .37961 .59495 .39087 .59154 .38406 .5852 Mtetra
.38406 .5852 .39087 .59154 .40218 .58811 .3954 .58174 Mtetra
.3954 .58174 .40218 .58811 .41354 .58467 .40679 .57828 Mtetra
.40679 .57828 .41354 .58467 .42495 .58121 .41823 .57479 Mtetra
.41823 .57479 .42495 .58121 .43641 .57774 .42971 .57129 Mtetra
.42971 .57129 .43641 .57774 .44791 .57425 .44125 .56778 Mtetra
.44125 .56778 .44791 .57425 .45946 .57075 .45283 .56425 Mtetra
.45283 .56425 .45946 .57075 .47107 .56724 .46447 .5607 Mtetra
.46447 .5607 .47107 .56724 .48272 .5637 .47615 .55714 Mtetra
.949 .714 .549 r
.47615 .55714 .48272 .5637 .49538 .4539 .48905 .44711 Mtetra
.664 .741 .908 r
.48905 .44711 .49538 .4539 .50676 .45023 .50047 .44341 Mtetra
.50047 .44341 .50676 .45023 .5182 .44654 .51193 .4397 Mtetra
.51193 .4397 .5182 .44654 .52968 .44284 .52344 .43597 Mtetra
.52344 .43597 .52968 .44284 .5412 .43913 .535 .43222 Mtetra
.535 .43222 .5412 .43913 .55278 .43539 .54661 .42846 Mtetra
.54661 .42846 .55278 .43539 .56441 .43164 .55827 .42468 Mtetra
.55827 .42468 .56441 .43164 .57608 .42788 .56998 .42089 Mtetra
.56998 .42089 .57608 .42788 .5878 .4241 .58173 .41708 Mtetra
.58173 .41708 .5878 .4241 .59958 .4203 .59354 .41325 Mtetra
.59354 .41325 .59958 .4203 .6114 .41649 .6054 .40941 Mtetra
.6054 .40941 .6114 .41649 .62327 .41266 .6173 .40555 Mtetra
.6173 .40555 .62327 .41266 .6352 .40882 .62926 .40168 Mtetra
.62926 .40168 .6352 .40882 .64717 .40496 .64127 .39779 Mtetra
.64127 .39779 .64717 .40496 .6592 .40108 .65333 .39388 Mtetra
.65333 .39388 .6592 .40108 .67128 .39719 .66545 .38995 Mtetra
.66545 .38995 .67128 .39719 .6834 .39327 .67761 .38601 Mtetra
.67761 .38601 .6834 .39327 .69559 .38935 .68983 .38205 Mtetra
.68983 .38205 .69559 .38935 .70782 .3854 .7021 .37807 Mtetra
.7021 .37807 .70782 .3854 .72011 .38144 .71442 .37408 Mtetra
.71442 .37408 .72011 .38144 .73245 .37746 .7268 .37007 Mtetra
.7268 .37007 .73245 .37746 .74484 .37347 .73923 .36604 Mtetra
.73923 .36604 .74484 .37347 .75729 .36945 .75172 .362 Mtetra
.75172 .362 .75729 .36945 .76979 .36542 .76426 .35793 Mtetra
.76426 .35793 .76979 .36542 .78235 .36137 .77685 .35385 Mtetra
.77685 .35385 .78235 .36137 .79496 .35731 .78951 .34975 Mtetra
.78951 .34975 .79496 .35731 .80763 .35322 .80221 .34563 Mtetra
.80221 .34563 .80763 .35322 .82035 .34912 .81498 .3415 Mtetra
.81498 .3415 .82035 .34912 .83313 .345 .82779 .33734 Mtetra
.82779 .33734 .83313 .345 .84597 .34086 .84067 .33317 Mtetra
.84067 .33317 .84597 .34086 .85886 .3367 .8536 .32898 Mtetra
.8536 .32898 .85886 .3367 .87181 .33253 .8666 .32477 Mtetra
.8666 .32477 .87181 .33253 .88482 .32833 .87965 .32054 Mtetra
.87965 .32054 .88482 .32833 .89788 .32412 .89275 .31629 Mtetra
.655 .752 .921 r
.28793 .60614 .29503 .61232 .30599 .60898 .29892 .60278 Mtetra
.29892 .60278 .30599 .60898 .31701 .60563 .30997 .5994 Mtetra
.30997 .5994 .31701 .60563 .32806 .60226 .32105 .596 Mtetra
.32105 .596 .32806 .60226 .33917 .59887 .33219 .59259 Mtetra
.33219 .59259 .33917 .59887 .35032 .59548 .34337 .58917 Mtetra
.34337 .58917 .35032 .59548 .36152 .59207 .35459 .58573 Mtetra
.35459 .58573 .36152 .59207 .37277 .58864 .36587 .58228 Mtetra
.36587 .58228 .37277 .58864 .38406 .5852 .37719 .57881 Mtetra
.37719 .57881 .38406 .5852 .3954 .58174 .38856 .57533 Mtetra
.38856 .57533 .3954 .58174 .40679 .57828 .39998 .57183 Mtetra
.39998 .57183 .40679 .57828 .41823 .57479 .41145 .56832 Mtetra
.41145 .56832 .41823 .57479 .42971 .57129 .42297 .56479 Mtetra
.42297 .56479 .42971 .57129 .44125 .56778 .43453 .56125 Mtetra
.43453 .56125 .44125 .56778 .45283 .56425 .44615 .55769 Mtetra
.44615 .55769 .45283 .56425 .46447 .5607 .45782 .55412 Mtetra
.956 .648 .404 r
.45782 .55412 .46447 .5607 .47615 .55714 .46779 .65694 Mtetra
.537 .297 .5 r
.46779 .65694 .47615 .55714 .48905 .44711 .47992 .65346 Mtetra
0 0 .299 r
.47992 .65346 .48905 .44711 .50047 .44341 .49413 .43654 Mtetra
.664 .741 .908 r
.49413 .43654 .50047 .44341 .51193 .4397 .50562 .4328 Mtetra
.50562 .4328 .51193 .4397 .52344 .43597 .51716 .42904 Mtetra
.51716 .42904 .52344 .43597 .535 .43222 .52876 .42526 Mtetra
.52876 .42526 .535 .43222 .54661 .42846 .5404 .42147 Mtetra
.5404 .42147 .54661 .42846 .55827 .42468 .55209 .41767 Mtetra
.55209 .41767 .55827 .42468 .56998 .42089 .56383 .41384 Mtetra
.56383 .41384 .56998 .42089 .58173 .41708 .57562 .41 Mtetra
.57562 .41 .58173 .41708 .59354 .41325 .58746 .40615 Mtetra
.58746 .40615 .59354 .41325 .6054 .40941 .59935 .40227 Mtetra
.59935 .40227 .6054 .40941 .6173 .40555 .61129 .39839 Mtetra
.61129 .39839 .6173 .40555 .62926 .40168 .62328 .39448 Mtetra
.62328 .39448 .62926 .40168 .64127 .39779 .63532 .39056 Mtetra
.63532 .39056 .64127 .39779 .65333 .39388 .64742 .38662 Mtetra
.64742 .38662 .65333 .39388 .66545 .38995 .65957 .38266 Mtetra
.65957 .38266 .66545 .38995 .67761 .38601 .67177 .37869 Mtetra
.67177 .37869 .67761 .38601 .68983 .38205 .68402 .3747 Mtetra
.68402 .3747 .68983 .38205 .7021 .37807 .69633 .37069 Mtetra
.69633 .37069 .7021 .37807 .71442 .37408 .70869 .36666 Mtetra
.70869 .36666 .71442 .37408 .7268 .37007 .72111 .36262 Mtetra
.72111 .36262 .7268 .37007 .73923 .36604 .73358 .35856 Mtetra
.73358 .35856 .73923 .36604 .75172 .362 .7461 .35448 Mtetra
.7461 .35448 .75172 .362 .76426 .35793 .75868 .35038 Mtetra
.75868 .35038 .76426 .35793 .77685 .35385 .77131 .34627 Mtetra
.77131 .34627 .77685 .35385 .78951 .34975 .78401 .34213 Mtetra
.78401 .34213 .78951 .34975 .80221 .34563 .79675 .33798 Mtetra
.79675 .33798 .80221 .34563 .81498 .3415 .80955 .33381 Mtetra
.80955 .33381 .81498 .3415 .82779 .33734 .82241 .32963 Mtetra
.82241 .32963 .82779 .33734 .84067 .33317 .83533 .32542 Mtetra
.83533 .32542 .84067 .33317 .8536 .32898 .84831 .32119 Mtetra
.84831 .32119 .8536 .32898 .8666 .32477 .86134 .31695 Mtetra
.86134 .31695 .8666 .32477 .87965 .32054 .87443 .31268 Mtetra
.87443 .31268 .87965 .32054 .89275 .31629 .88758 .3084 Mtetra
.655 .752 .921 r
.28078 .59992 .28793 .60614 .29892 .60278 .2918 .59652 Mtetra
.2918 .59652 .29892 .60278 .30997 .5994 .30287 .59312 Mtetra
.30287 .59312 .30997 .5994 .32105 .596 .31399 .5897 Mtetra
.31399 .5897 .32105 .596 .33219 .59259 .32515 .58626 Mtetra
.32515 .58626 .33219 .59259 .34337 .58917 .33636 .58281 Mtetra
.33636 .58281 .34337 .58917 .35459 .58573 .34761 .57934 Mtetra
.34761 .57934 .35459 .58573 .36587 .58228 .35892 .57586 Mtetra
.35892 .57586 .36587 .58228 .37719 .57881 .37027 .57237 Mtetra
.37027 .57237 .37719 .57881 .38856 .57533 .38167 .56886 Mtetra
.38167 .56886 .38856 .57533 .39998 .57183 .39312 .56534 Mtetra
.39312 .56534 .39998 .57183 .41145 .56832 .40462 .5618 Mtetra
.40462 .5618 .41145 .56832 .42297 .56479 .41617 .55824 Mtetra
.41617 .55824 .42297 .56479 .43453 .56125 .42777 .55467 Mtetra
.955 .649 .414 r
.42777 .55467 .43453 .56125 .44615 .55769 .43672 .65747 Mtetra
.535 .295 .498 r
.43672 .65747 .44615 .55769 .45782 .55412 .44878 .65399 Mtetra
.44878 .65399 .45782 .55412 .46779 .65694 .4609 .6505 Mtetra
.646 .762 .934 r
.4609 .6505 .46779 .65694 .47992 .65346 .47307 .64699 Mtetra
.47307 .64699 .47992 .65346 .49413 .43654 .48529 .64347 Mtetra
.545 .318 .521 r
.48529 .64347 .49413 .43654 .50562 .4328 .49757 .63993 Mtetra
0 0 .306 r
.49757 .63993 .50562 .4328 .51716 .42904 .51084 .42206 Mtetra
.664 .741 .908 r
.51084 .42206 .51716 .42904 .52876 .42526 .52246 .41825 Mtetra
.52246 .41825 .52876 .42526 .5404 .42147 .53413 .41443 Mtetra
.53413 .41443 .5404 .42147 .55209 .41767 .54585 .4106 Mtetra
.54585 .4106 .55209 .41767 .56383 .41384 .55763 .40674 Mtetra
.55763 .40674 .56383 .41384 .57562 .41 .56945 .40287 Mtetra
.56945 .40287 .57562 .41 .58746 .40615 .58132 .39899 Mtetra
.58132 .39899 .58746 .40615 .59935 .40227 .59325 .39508 Mtetra
.59325 .39508 .59935 .40227 .61129 .39839 .60522 .39116 Mtetra
.60522 .39116 .61129 .39839 .62328 .39448 .61725 .38723 Mtetra
.61725 .38723 .62328 .39448 .63532 .39056 .62933 .38327 Mtetra
.62933 .38327 .63532 .39056 .64742 .38662 .64146 .3793 Mtetra
.64146 .3793 .64742 .38662 .65957 .38266 .65365 .37531 Mtetra
.65365 .37531 .65957 .38266 .67177 .37869 .66588 .37131 Mtetra
.66588 .37131 .67177 .37869 .68402 .3747 .67817 .36728 Mtetra
.67817 .36728 .68402 .3747 .69633 .37069 .69052 .36324 Mtetra
.69052 .36324 .69633 .37069 .70869 .36666 .70292 .35918 Mtetra
.70292 .35918 .70869 .36666 .72111 .36262 .71537 .35511 Mtetra
.71537 .35511 .72111 .36262 .73358 .35856 .72788 .35101 Mtetra
.72788 .35101 .73358 .35856 .7461 .35448 .74044 .3469 Mtetra
.74044 .3469 .7461 .35448 .75868 .35038 .75306 .34277 Mtetra
.75306 .34277 .75868 .35038 .77131 .34627 .76573 .33862 Mtetra
.76573 .33862 .77131 .34627 .78401 .34213 .77846 .33446 Mtetra
.77846 .33446 .78401 .34213 .79675 .33798 .79125 .33027 Mtetra
.79125 .33027 .79675 .33798 .80955 .33381 .80409 .32607 Mtetra
.80409 .32607 .80955 .33381 .82241 .32963 .81699 .32184 Mtetra
.81699 .32184 .82241 .32963 .83533 .32542 .82995 .3176 Mtetra
.82995 .3176 .83533 .32542 .84831 .32119 .84297 .31334 Mtetra
.84297 .31334 .84831 .32119 .86134 .31695 .85604 .30906 Mtetra
.85604 .30906 .86134 .31695 .87443 .31268 .86918 .30476 Mtetra
.86918 .30476 .87443 .31268 .88758 .3084 .88237 .30044 Mtetra
.655 .752 .921 r
.27357 .59364 .28078 .59992 .2918 .59652 .28462 .59022 Mtetra
.28462 .59022 .2918 .59652 .30287 .59312 .29572 .58679 Mtetra
.29572 .58679 .30287 .59312 .31399 .5897 .30686 .58334 Mtetra
.30686 .58334 .31399 .5897 .32515 .58626 .31805 .57988 Mtetra
.31805 .57988 .32515 .58626 .33636 .58281 .32929 .5764 Mtetra
.32929 .5764 .33636 .58281 .34761 .57934 .34058 .57291 Mtetra
.34058 .57291 .34761 .57934 .35892 .57586 .35191 .5694 Mtetra
.35191 .5694 .35892 .57586 .37027 .57237 .3633 .56588 Mtetra
.3633 .56588 .37027 .57237 .38167 .56886 .37473 .56234 Mtetra
.37473 .56234 .38167 .56886 .39312 .56534 .38621 .55879 Mtetra
.38621 .55879 .39312 .56534 .40462 .5618 .39774 .55522 Mtetra
.953 .65 .423 r
.39774 .55522 .40462 .5618 .41617 .55824 .40567 .658 Mtetra
.534 .292 .496 r
.40567 .658 .41617 .55824 .42777 .55467 .41766 .65453 Mtetra
.41766 .65453 .42777 .55467 .43672 .65747 .4297 .65104 Mtetra
.646 .762 .934 r
.4297 .65104 .43672 .65747 .44878 .65399 .4418 .64753 Mtetra
.4418 .64753 .44878 .65399 .4609 .6505 .45395 .64401 Mtetra
.45395 .64401 .4609 .6505 .47307 .64699 .46616 .64047 Mtetra
.46616 .64047 .47307 .64699 .48529 .64347 .47842 .63692 Mtetra
.47842 .63692 .48529 .64347 .49757 .63993 .49073 .63335 Mtetra
.49073 .63335 .49757 .63993 .51084 .42206 .5031 .62976 Mtetra
0 0 .306 r
.5031 .62976 .51084 .42206 .52246 .41825 .51611 .41119 Mtetra
.664 .741 .908 r
.51611 .41119 .52246 .41825 .53413 .41443 .52782 .40734 Mtetra
.52782 .40734 .53413 .41443 .54585 .4106 .53957 .40347 Mtetra
.53957 .40347 .54585 .4106 .55763 .40674 .55138 .39958 Mtetra
.55138 .39958 .55763 .40674 .56945 .40287 .56323 .39568 Mtetra
.56323 .39568 .56945 .40287 .58132 .39899 .57514 .39177 Mtetra
.57514 .39177 .58132 .39899 .59325 .39508 .5871 .38783 Mtetra
.5871 .38783 .59325 .39508 .60522 .39116 .59911 .38388 Mtetra
.59911 .38388 .60522 .39116 .61725 .38723 .61117 .37991 Mtetra
.61117 .37991 .61725 .38723 .62933 .38327 .62329 .37593 Mtetra
.62329 .37593 .62933 .38327 .64146 .3793 .63545 .37192 Mtetra
.63545 .37192 .64146 .3793 .65365 .37531 .64767 .3679 Mtetra
.64767 .3679 .65365 .37531 .66588 .37131 .65995 .36387 Mtetra
.65995 .36387 .66588 .37131 .67817 .36728 .67228 .35981 Mtetra
.67228 .35981 .67817 .36728 .69052 .36324 .68466 .35574 Mtetra
.68466 .35574 .69052 .36324 .70292 .35918 .69709 .35165 Mtetra
.69709 .35165 .70292 .35918 .71537 .35511 .70958 .34754 Mtetra
.70958 .34754 .71537 .35511 .72788 .35101 .72213 .34341 Mtetra
.72213 .34341 .72788 .35101 .74044 .3469 .73473 .33926 Mtetra
.73473 .33926 .74044 .3469 .75306 .34277 .74739 .3351 Mtetra
.74739 .3351 .75306 .34277 .76573 .33862 .7601 .33092 Mtetra
.7601 .33092 .76573 .33862 .77846 .33446 .77287 .32671 Mtetra
.77287 .32671 .77846 .33446 .79125 .33027 .7857 .32249 Mtetra
.7857 .32249 .79125 .33027 .80409 .32607 .79858 .31826 Mtetra
.79858 .31826 .80409 .32607 .81699 .32184 .81152 .314 Mtetra
.81152 .314 .81699 .32184 .82995 .3176 .82452 .30972 Mtetra
.82452 .30972 .82995 .3176 .84297 .31334 .83758 .30543 Mtetra
.83758 .30543 .84297 .31334 .85604 .30906 .8507 .30111 Mtetra
.8507 .30111 .85604 .30906 .86918 .30476 .86387 .29677 Mtetra
.86387 .29677 .86918 .30476 .88237 .30044 .87711 .29242 Mtetra
.655 .752 .921 r
.26631 .58732 .27357 .59364 .28462 .59022 .27739 .58387 Mtetra
.27739 .58387 .28462 .59022 .29572 .58679 .28852 .58041 Mtetra
.28852 .58041 .29572 .58679 .30686 .58334 .29969 .57694 Mtetra
.29969 .57694 .30686 .58334 .31805 .57988 .31091 .57345 Mtetra
.31091 .57345 .31805 .57988 .32929 .5764 .32217 .56994 Mtetra
.32217 .56994 .32929 .5764 .34058 .57291 .33349 .56642 Mtetra
.33349 .56642 .34058 .57291 .35191 .5694 .34485 .56289 Mtetra
.34485 .56289 .35191 .5694 .3633 .56588 .35626 .55934 Mtetra
.35626 .55934 .3633 .56588 .37473 .56234 .36773 .55577 Mtetra
.951 .651 .431 r
.36773 .55577 .37473 .56234 .38621 .55879 .37465 .65854 Mtetra
.532 .29 .494 r
.37465 .65854 .38621 .55879 .39774 .55522 .38656 .65506 Mtetra
.38656 .65506 .39774 .55522 .40567 .658 .39853 .65158 Mtetra
.646 .762 .934 r
.39853 .65158 .40567 .658 .41766 .65453 .41055 .64807 Mtetra
.41055 .64807 .41766 .65453 .4297 .65104 .42263 .64455 Mtetra
.42263 .64455 .4297 .65104 .4418 .64753 .43476 .64102 Mtetra
.43476 .64102 .4418 .64753 .45395 .64401 .44695 .63747 Mtetra
.44695 .63747 .45395 .64401 .46616 .64047 .45919 .6339 Mtetra
.45919 .6339 .46616 .64047 .47842 .63692 .47148 .63031 Mtetra
.47148 .63031 .47842 .63692 .49073 .63335 .48383 .62671 Mtetra
.48383 .62671 .49073 .63335 .5031 .62976 .49624 .6231 Mtetra
.49624 .6231 .5031 .62976 .51611 .41119 .5087 .61947 Mtetra
0 0 .306 r
.5087 .61947 .51611 .41119 .52782 .40734 .52145 .40018 Mtetra
.664 .741 .908 r
.52145 .40018 .52782 .40734 .53957 .40347 .53324 .39628 Mtetra
.53324 .39628 .53957 .40347 .55138 .39958 .54508 .39237 Mtetra
.54508 .39237 .55138 .39958 .56323 .39568 .55697 .38844 Mtetra
.55697 .38844 .56323 .39568 .57514 .39177 .56891 .38449 Mtetra
.56891 .38449 .57514 .39177 .5871 .38783 .5809 .38052 Mtetra
.5809 .38052 .5871 .38783 .59911 .38388 .59295 .37654 Mtetra
.59295 .37654 .59911 .38388 .61117 .37991 .60505 .37254 Mtetra
.60505 .37254 .61117 .37991 .62329 .37593 .6172 .36852 Mtetra
.6172 .36852 .62329 .37593 .63545 .37192 .6294 .36449 Mtetra
.6294 .36449 .63545 .37192 .64767 .3679 .64166 .36043 Mtetra
.64166 .36043 .64767 .3679 .65995 .36387 .65397 .35636 Mtetra
.65397 .35636 .65995 .36387 .67228 .35981 .66633 .35228 Mtetra
.66633 .35228 .67228 .35981 .68466 .35574 .67875 .34817 Mtetra
.67875 .34817 .68466 .35574 .69709 .35165 .69122 .34404 Mtetra
.69122 .34404 .69709 .35165 .70958 .34754 .70375 .3399 Mtetra
.70375 .3399 .70958 .34754 .72213 .34341 .71633 .33574 Mtetra
.71633 .33574 .72213 .34341 .73473 .33926 .72897 .33156 Mtetra
.72897 .33156 .73473 .33926 .74739 .3351 .74167 .32736 Mtetra
.74167 .32736 .74739 .3351 .7601 .33092 .75442 .32315 Mtetra
.75442 .32315 .7601 .33092 .77287 .32671 .76723 .31891 Mtetra
.76723 .31891 .77287 .32671 .7857 .32249 .7801 .31465 Mtetra
.7801 .31465 .7857 .32249 .79858 .31826 .79302 .31038 Mtetra
.79302 .31038 .79858 .31826 .81152 .314 .80601 .30609 Mtetra
.80601 .30609 .81152 .314 .82452 .30972 .81905 .30177 Mtetra
.81905 .30177 .82452 .30972 .83758 .30543 .83215 .29744 Mtetra
.83215 .29744 .83758 .30543 .8507 .30111 .84531 .29309 Mtetra
.84531 .29309 .8507 .30111 .86387 .29677 .85853 .28872 Mtetra
.85853 .28872 .86387 .29677 .87711 .29242 .87181 .28433 Mtetra
.655 .752 .921 r
.25899 .58095 .26631 .58732 .27739 .58387 .2701 .57747 Mtetra
.2701 .57747 .27739 .58387 .28852 .58041 .28125 .57398 Mtetra
.28125 .57398 .28852 .58041 .29969 .57694 .29245 .57048 Mtetra
.29245 .57048 .29969 .57694 .31091 .57345 .3037 .56696 Mtetra
.3037 .56696 .31091 .57345 .32217 .56994 .315 .56343 Mtetra
.315 .56343 .32217 .56994 .33349 .56642 .32634 .55988 Mtetra
.32634 .55988 .33349 .56642 .34485 .56289 .33774 .55632 Mtetra
.949 .652 .439 r
.33774 .55632 .34485 .56289 .35626 .55934 .34364 .65907 Mtetra
.53 .287 .492 r
.34364 .65907 .35626 .55934 .36773 .55577 .35548 .6556 Mtetra
.35548 .6556 .36773 .55577 .37465 .65854 .36738 .65211 Mtetra
.646 .762 .934 r
.36738 .65211 .37465 .65854 .38656 .65506 .37933 .64861 Mtetra
.37933 .64861 .38656 .65506 .39853 .65158 .39133 .64509 Mtetra
.39133 .64509 .39853 .65158 .41055 .64807 .40339 .64156 Mtetra
.40339 .64156 .41055 .64807 .42263 .64455 .4155 .63801 Mtetra
.4155 .63801 .42263 .64455 .43476 .64102 .42766 .63445 Mtetra
.42766 .63445 .43476 .64102 .44695 .63747 .43988 .63087 Mtetra
.43988 .63087 .44695 .63747 .45919 .6339 .45216 .62727 Mtetra
.45216 .62727 .45919 .6339 .47148 .63031 .46449 .62366 Mtetra
.46449 .62366 .47148 .63031 .48383 .62671 .47688 .62003 Mtetra
.47688 .62003 .48383 .62671 .49624 .6231 .48932 .61638 Mtetra
.48932 .61638 .49624 .6231 .5087 .61947 .50182 .61272 Mtetra
.50182 .61272 .5087 .61947 .52145 .40018 .51438 .60904 Mtetra
0 0 .306 r
.51438 .60904 .52145 .40018 .53324 .39628 .52686 .38904 Mtetra
.664 .741 .908 r
.52686 .38904 .53324 .39628 .54508 .39237 .53873 .3851 Mtetra
.53873 .3851 .54508 .39237 .55697 .38844 .55066 .38114 Mtetra
.55066 .38114 .55697 .38844 .56891 .38449 .56263 .37715 Mtetra
.56263 .37715 .56891 .38449 .5809 .38052 .57466 .37316 Mtetra
.57466 .37316 .5809 .38052 .59295 .37654 .58674 .36914 Mtetra
.58674 .36914 .59295 .37654 .60505 .37254 .59887 .36511 Mtetra
.59887 .36511 .60505 .37254 .6172 .36852 .61106 .36106 Mtetra
.61106 .36106 .6172 .36852 .6294 .36449 .62329 .35699 Mtetra
.62329 .35699 .6294 .36449 .64166 .36043 .63559 .35291 Mtetra
.63559 .35291 .64166 .36043 .65397 .35636 .64793 .3488 Mtetra
.64793 .3488 .65397 .35636 .66633 .35228 .66033 .34468 Mtetra
.66033 .34468 .66633 .35228 .67875 .34817 .67279 .34054 Mtetra
.67279 .34054 .67875 .34817 .69122 .34404 .6853 .33638 Mtetra
.6853 .33638 .69122 .34404 .70375 .3399 .69787 .3322 Mtetra
.69787 .3322 .70375 .3399 .71633 .33574 .71049 .32801 Mtetra
.71049 .32801 .71633 .33574 .72897 .33156 .72317 .3238 Mtetra
.72317 .3238 .72897 .33156 .74167 .32736 .73591 .31956 Mtetra
.73591 .31956 .74167 .32736 .75442 .32315 .7487 .31531 Mtetra
.7487 .31531 .75442 .32315 .76723 .31891 .76155 .31104 Mtetra
.76155 .31104 .76723 .31891 .7801 .31465 .77446 .30675 Mtetra
.77446 .30675 .7801 .31465 .79302 .31038 .78742 .30244 Mtetra
.78742 .30244 .79302 .31038 .80601 .30609 .80045 .29811 Mtetra
.80045 .29811 .80601 .30609 .81905 .30177 .81353 .29376 Mtetra
.81353 .29376 .81905 .30177 .83215 .29744 .82667 .28939 Mtetra
.82667 .28939 .83215 .29744 .84531 .29309 .83988 .285 Mtetra
.83988 .285 .84531 .29309 .85853 .28872 .85314 .2806 Mtetra
.85314 .2806 .85853 .28872 .87181 .28433 .86646 .27617 Mtetra
.655 .752 .921 r
.25162 .57452 .25899 .58095 .2701 .57747 .26275 .57102 Mtetra
.26275 .57102 .2701 .57747 .28125 .57398 .27393 .56751 Mtetra
.27393 .56751 .28125 .57398 .29245 .57048 .28516 .56398 Mtetra
.28516 .56398 .29245 .57048 .3037 .56696 .29644 .56043 Mtetra
.29644 .56043 .3037 .56696 .315 .56343 .30776 .55687 Mtetra
.947 .653 .447 r
.30776 .55687 .315 .56343 .32634 .55988 .31266 .6596 Mtetra
.528 .285 .49 r
.31266 .6596 .32634 .55988 .33774 .55632 .32443 .65613 Mtetra
.32443 .65613 .33774 .55632 .34364 .65907 .33625 .65265 Mtetra
.646 .762 .934 r
.33625 .65265 .34364 .65907 .35548 .6556 .34813 .64915 Mtetra
.34813 .64915 .35548 .6556 .36738 .65211 .36005 .64564 Mtetra
.36005 .64564 .36738 .65211 .37933 .64861 .37203 .64211 Mtetra
.37203 .64211 .37933 .64861 .39133 .64509 .38407 .63856 Mtetra
.38407 .63856 .39133 .64509 .40339 .64156 .39616 .635 Mtetra
.39616 .635 .40339 .64156 .4155 .63801 .4083 .63142 Mtetra
.4083 .63142 .4155 .63801 .42766 .63445 .4205 .62782 Mtetra
.4205 .62782 .42766 .63445 .43988 .63087 .43276 .62421 Mtetra
.43276 .62421 .43988 .63087 .45216 .62727 .44507 .62059 Mtetra
.44507 .62059 .45216 .62727 .46449 .62366 .45744 .61694 Mtetra
.45744 .61694 .46449 .62366 .47688 .62003 .46986 .61328 Mtetra
.46986 .61328 .47688 .62003 .48932 .61638 .48234 .6096 Mtetra
.48234 .6096 .48932 .61638 .50182 .61272 .49488 .60591 Mtetra
.49488 .60591 .50182 .61272 .51438 .60904 .50747 .6022 Mtetra
.50747 .6022 .51438 .60904 .52686 .38904 .52013 .59847 Mtetra
0 0 .306 r
.52013 .59847 .52686 .38904 .53873 .3851 .53233 .37777 Mtetra
.664 .741 .908 r
.53233 .37777 .53873 .3851 .55066 .38114 .54429 .37377 Mtetra
.54429 .37377 .55066 .38114 .56263 .37715 .5563 .36976 Mtetra
.5563 .36976 .56263 .37715 .57466 .37316 .56836 .36573 Mtetra
.56836 .36573 .57466 .37316 .58674 .36914 .58048 .36168 Mtetra
.58048 .36168 .58674 .36914 .59887 .36511 .59265 .35762 Mtetra
.59265 .35762 .59887 .36511 .61106 .36106 .60487 .35354 Mtetra
.60487 .35354 .61106 .36106 .62329 .35699 .61714 .34943 Mtetra
.61714 .34943 .62329 .35699 .63559 .35291 .62947 .34532 Mtetra
.62947 .34532 .63559 .35291 .64793 .3488 .64185 .34118 Mtetra
.64185 .34118 .64793 .3488 .66033 .34468 .65429 .33702 Mtetra
.65429 .33702 .66033 .34468 .67279 .34054 .66679 .33285 Mtetra
.66679 .33285 .67279 .34054 .6853 .33638 .67933 .32866 Mtetra
.67933 .32866 .6853 .33638 .69787 .3322 .69194 .32444 Mtetra
.69194 .32444 .69787 .3322 .71049 .32801 .7046 .32021 Mtetra
.7046 .32021 .71049 .32801 .72317 .3238 .71732 .31597 Mtetra
.71732 .31597 .72317 .3238 .73591 .31956 .73009 .3117 Mtetra
.73009 .3117 .73591 .31956 .7487 .31531 .74293 .30741 Mtetra
.74293 .30741 .7487 .31531 .76155 .31104 .75582 .3031 Mtetra
.75582 .3031 .76155 .31104 .77446 .30675 .76877 .29878 Mtetra
.76877 .29878 .77446 .30675 .78742 .30244 .78177 .29443 Mtetra
.78177 .29443 .78742 .30244 .80045 .29811 .79484 .29007 Mtetra
.79484 .29007 .80045 .29811 .81353 .29376 .80797 .28568 Mtetra
.80797 .28568 .81353 .29376 .82667 .28939 .82115 .28128 Mtetra
.82115 .28128 .82667 .28939 .83988 .285 .8344 .27685 Mtetra
.8344 .27685 .83988 .285 .85314 .2806 .8477 .2724 Mtetra
.8477 .2724 .85314 .2806 .86646 .27617 .86107 .26794 Mtetra
.655 .752 .921 r
.24418 .56805 .25162 .57452 .26275 .57102 .25535 .56452 Mtetra
.25535 .56452 .26275 .57102 .27393 .56751 .26656 .56098 Mtetra
.26656 .56098 .27393 .56751 .28516 .56398 .27781 .55742 Mtetra
.945 .653 .454 r
.27781 .55742 .28516 .56398 .29644 .56043 .2817 .66014 Mtetra
.527 .282 .488 r
.2817 .66014 .29644 .56043 .30776 .55687 .29339 .65667 Mtetra
.29339 .65667 .30776 .55687 .31266 .6596 .30514 .65319 Mtetra
.646 .762 .934 r
.30514 .65319 .31266 .6596 .32443 .65613 .31694 .64969 Mtetra
.31694 .64969 .32443 .65613 .33625 .65265 .3288 .64618 Mtetra
.3288 .64618 .33625 .65265 .34813 .64915 .3407 .64265 Mtetra
.3407 .64265 .34813 .64915 .36005 .64564 .35267 .63911 Mtetra
.35267 .63911 .36005 .64564 .37203 .64211 .36468 .63555 Mtetra
.36468 .63555 .37203 .64211 .38407 .63856 .37675 .63197 Mtetra
.37675 .63197 .38407 .63856 .39616 .635 .38887 .62838 Mtetra
.38887 .62838 .39616 .635 .4083 .63142 .40105 .62477 Mtetra
.40105 .62477 .4083 .63142 .4205 .62782 .41329 .62114 Mtetra
.41329 .62114 .4205 .62782 .43276 .62421 .42558 .6175 Mtetra
.42558 .6175 .43276 .62421 .44507 .62059 .43792 .61384 Mtetra
.43792 .61384 .44507 .62059 .45744 .61694 .45032 .61017 Mtetra
.45032 .61017 .45744 .61694 .46986 .61328 .46278 .60648 Mtetra
.46278 .60648 .46986 .61328 .48234 .6096 .4753 .60277 Mtetra
.4753 .60277 .48234 .6096 .49488 .60591 .48788 .59904 Mtetra
.48788 .59904 .49488 .60591 .50747 .6022 .50051 .5953 Mtetra
.50051 .5953 .50747 .6022 .52013 .59847 .5132 .59154 Mtetra
.5132 .59154 .52013 .59847 .53233 .37777 .52595 .58776 Mtetra
0 0 .306 r
.52595 .58776 .53233 .37777 .54429 .37377 .53788 .36635 Mtetra
.664 .741 .908 r
.53788 .36635 .54429 .37377 .5563 .36976 .54992 .36231 Mtetra
.54992 .36231 .5563 .36976 .56836 .36573 .56202 .35825 Mtetra
.56202 .35825 .56836 .36573 .58048 .36168 .57417 .35416 Mtetra
.57417 .35416 .58048 .36168 .59265 .35762 .58637 .35007 Mtetra
.58637 .35007 .59265 .35762 .60487 .35354 .59863 .34595 Mtetra
.59863 .34595 .60487 .35354 .61714 .34943 .61094 .34182 Mtetra
.61094 .34182 .61714 .34943 .62947 .34532 .6233 .33766 Mtetra
.6233 .33766 .62947 .34532 .64185 .34118 .63572 .33349 Mtetra
.63572 .33349 .64185 .34118 .65429 .33702 .6482 .3293 Mtetra
.6482 .3293 .65429 .33702 .66679 .33285 .66073 .32509 Mtetra
.66073 .32509 .66679 .33285 .67933 .32866 .67332 .32087 Mtetra
.67332 .32087 .67933 .32866 .69194 .32444 .68596 .31662 Mtetra
.68596 .31662 .69194 .32444 .7046 .32021 .69866 .31236 Mtetra
.69866 .31236 .7046 .32021 .71732 .31597 .71142 .30807 Mtetra
.71142 .30807 .71732 .31597 .73009 .3117 .72423 .30377 Mtetra
.72423 .30377 .73009 .3117 .74293 .30741 .73711 .29944 Mtetra
.73711 .29944 .74293 .30741 .75582 .3031 .75004 .2951 Mtetra
.75004 .2951 .75582 .3031 .76877 .29878 .76303 .29074 Mtetra
.76303 .29074 .76877 .29878 .78177 .29443 .77608 .28636 Mtetra
.77608 .28636 .78177 .29443 .79484 .29007 .78919 .28195 Mtetra
.78919 .28195 .79484 .29007 .80797 .28568 .80235 .27753 Mtetra
.80235 .27753 .80797 .28568 .82115 .28128 .81558 .27309 Mtetra
.81558 .27309 .82115 .28128 .8344 .27685 .82887 .26863 Mtetra
.82887 .26863 .8344 .27685 .8477 .2724 .84222 .26414 Mtetra
.84222 .26414 .8477 .2724 .86107 .26794 .85563 .25964 Mtetra
.655 .752 .921 r
.23669 .56152 .24418 .56805 .25535 .56452 .24788 .55797 Mtetra
.943 .654 .461 r
.24788 .55797 .25535 .56452 .26656 .56098 .25076 .66067 Mtetra
.525 .28 .486 r
.25076 .66067 .26656 .56098 .27781 .55742 .26238 .6572 Mtetra
.26238 .6572 .27781 .55742 .2817 .66014 .27406 .65372 Mtetra
.646 .762 .934 r
.27406 .65372 .2817 .66014 .29339 .65667 .28578 .65023 Mtetra
.28578 .65023 .29339 .65667 .30514 .65319 .29756 .64672 Mtetra
.29756 .64672 .30514 .65319 .31694 .64969 .3094 .64319 Mtetra
.3094 .64319 .31694 .64969 .3288 .64618 .32128 .63965 Mtetra
.32128 .63965 .3288 .64618 .3407 .64265 .33322 .6361 Mtetra
.33322 .6361 .3407 .64265 .35267 .63911 .34522 .63252 Mtetra
.34522 .63252 .35267 .63911 .36468 .63555 .35726 .62893 Mtetra
.35726 .62893 .36468 .63555 .37675 .63197 .36937 .62533 Mtetra
.36937 .62533 .37675 .63197 .38887 .62838 .38152 .6217 Mtetra
.38152 .6217 .38887 .62838 .40105 .62477 .39374 .61806 Mtetra
.39374 .61806 .40105 .62477 .41329 .62114 .40601 .61441 Mtetra
.40601 .61441 .41329 .62114 .42558 .6175 .41833 .61074 Mtetra
.41833 .61074 .42558 .6175 .43792 .61384 .43071 .60705 Mtetra
.43071 .60705 .43792 .61384 .45032 .61017 .44315 .60334 Mtetra
.44315 .60334 .45032 .61017 .46278 .60648 .45565 .59962 Mtetra
.45565 .59962 .46278 .60648 .4753 .60277 .4682 .59588 Mtetra
.4682 .59588 .4753 .60277 .48788 .59904 .48082 .59212 Mtetra
.48082 .59212 .48788 .59904 .50051 .5953 .49349 .58834 Mtetra
.49349 .58834 .50051 .5953 .5132 .59154 .50622 .58455 Mtetra
.50622 .58455 .5132 .59154 .52595 .58776 .51901 .58074 Mtetra
.51901 .58074 .52595 .58776 .53788 .36635 .53185 .57691 Mtetra
0 0 .306 r
.53185 .57691 .53788 .36635 .54992 .36231 .54349 .35479 Mtetra
.664 .741 .908 r
.54349 .35479 .54992 .36231 .56202 .35825 .55562 .3507 Mtetra
.55562 .3507 .56202 .35825 .57417 .35416 .5678 .34658 Mtetra
.5678 .34658 .57417 .35416 .58637 .35007 .58004 .34245 Mtetra
.58004 .34245 .58637 .35007 .59863 .34595 .59233 .3383 Mtetra
.59233 .3383 .59863 .34595 .61094 .34182 .60468 .33414 Mtetra
.60468 .33414 .61094 .34182 .6233 .33766 .61708 .32995 Mtetra
.61708 .32995 .6233 .33766 .63572 .33349 .62954 .32574 Mtetra
.62954 .32574 .63572 .33349 .6482 .3293 .64206 .32152 Mtetra
.64206 .32152 .6482 .3293 .66073 .32509 .65462 .31728 Mtetra
.65462 .31728 .66073 .32509 .67332 .32087 .66725 .31301 Mtetra
.66725 .31301 .67332 .32087 .68596 .31662 .67993 .30873 Mtetra
.67993 .30873 .68596 .31662 .69866 .31236 .69267 .30443 Mtetra
.69267 .30443 .69866 .31236 .71142 .30807 .70547 .30011 Mtetra
.70547 .30011 .71142 .30807 .72423 .30377 .71832 .29577 Mtetra
.71832 .29577 .72423 .30377 .73711 .29944 .73124 .29141 Mtetra
.73124 .29141 .73711 .29944 .75004 .2951 .74421 .28703 Mtetra
.74421 .28703 .75004 .2951 .76303 .29074 .75724 .28263 Mtetra
.75724 .28263 .76303 .29074 .77608 .28636 .77033 .27821 Mtetra
.77033 .27821 .77608 .28636 .78919 .28195 .78348 .27377 Mtetra
.78348 .27377 .78919 .28195 .80235 .27753 .79669 .26932 Mtetra
.79669 .26932 .80235 .27753 .81558 .27309 .80997 .26483 Mtetra
.80997 .26483 .81558 .27309 .82887 .26863 .8233 .26033 Mtetra
.8233 .26033 .82887 .26863 .84222 .26414 .83669 .25581 Mtetra
.83669 .25581 .84222 .26414 .85563 .25964 .85015 .25127 Mtetra
.523 .277 .483 r
.21984 .6612 .23669 .56152 .24788 .55797 .23139 .65774 Mtetra
.23139 .65774 .24788 .55797 .25076 .66067 .24299 .65426 Mtetra
.646 .762 .934 r
.24299 .65426 .25076 .66067 .26238 .6572 .25464 .65077 Mtetra
.25464 .65077 .26238 .6572 .27406 .65372 .26635 .64726 Mtetra
.26635 .64726 .27406 .65372 .28578 .65023 .27811 .64374 Mtetra
.27811 .64374 .28578 .65023 .29756 .64672 .28992 .6402 Mtetra
.28992 .6402 .29756 .64672 .3094 .64319 .30179 .63664 Mtetra
.30179 .63664 .3094 .64319 .32128 .63965 .3137 .63307 Mtetra
.3137 .63307 .32128 .63965 .33322 .6361 .32568 .62949 Mtetra
.32568 .62949 .33322 .6361 .34522 .63252 .3377 .62588 Mtetra
.3377 .62588 .34522 .63252 .35726 .62893 .34979 .62226 Mtetra
.34979 .62226 .35726 .62893 .36937 .62533 .36192 .61862 Mtetra
.36192 .61862 .36937 .62533 .38152 .6217 .37411 .61497 Mtetra
.37411 .61497 .38152 .6217 .39374 .61806 .38636 .6113 Mtetra
.38636 .6113 .39374 .61806 .40601 .61441 .39867 .60762 Mtetra
.39867 .60762 .40601 .61441 .41833 .61074 .41103 .60391 Mtetra
.41103 .60391 .41833 .61074 .43071 .60705 .42344 .60019 Mtetra
.42344 .60019 .43071 .60705 .44315 .60334 .43592 .59645 Mtetra
.43592 .59645 .44315 .60334 .45565 .59962 .44845 .5927 Mtetra
.44845 .5927 .45565 .59962 .4682 .59588 .46104 .58892 Mtetra
.46104 .58892 .4682 .59588 .48082 .59212 .47369 .58513 Mtetra
.47369 .58513 .48082 .59212 .49349 .58834 .4864 .58133 Mtetra
.4864 .58133 .49349 .58834 .50622 .58455 .49917 .5775 Mtetra
.49917 .5775 .50622 .58455 .51901 .58074 .512 .57366 Mtetra
.512 .57366 .51901 .58074 .53185 .57691 .52489 .5698 Mtetra
.52489 .5698 .53185 .57691 .54349 .35479 .53784 .56592 Mtetra
0 0 .306 r
.53784 .56592 .54349 .35479 .55562 .3507 .54917 .34309 Mtetra
.664 .741 .908 r
.54917 .34309 .55562 .3507 .5678 .34658 .56139 .33894 Mtetra
.56139 .33894 .5678 .34658 .58004 .34245 .57366 .33478 Mtetra
.57366 .33478 .58004 .34245 .59233 .3383 .58599 .33059 Mtetra
.58599 .33059 .59233 .3383 .60468 .33414 .59838 .32639 Mtetra
.59838 .32639 .60468 .33414 .61708 .32995 .61082 .32217 Mtetra
.61082 .32217 .61708 .32995 .62954 .32574 .62331 .31793 Mtetra
.62331 .31793 .62954 .32574 .64206 .32152 .63586 .31367 Mtetra
.63586 .31367 .64206 .32152 .65462 .31728 .64847 .30939 Mtetra
.64847 .30939 .65462 .31728 .66725 .31301 .66113 .30509 Mtetra
.66113 .30509 .66725 .31301 .67993 .30873 .67385 .30078 Mtetra
.67385 .30078 .67993 .30873 .69267 .30443 .68663 .29644 Mtetra
.68663 .29644 .69267 .30443 .70547 .30011 .69947 .29208 Mtetra
.69947 .29208 .70547 .30011 .71832 .29577 .71237 .28771 Mtetra
.71237 .28771 .71832 .29577 .73124 .29141 .72532 .28331 Mtetra
.72532 .28331 .73124 .29141 .74421 .28703 .73833 .2789 Mtetra
.73833 .2789 .74421 .28703 .75724 .28263 .75141 .27446 Mtetra
.75141 .27446 .75724 .28263 .77033 .27821 .76454 .27 Mtetra
.76454 .27 .77033 .27821 .78348 .27377 .77773 .26553 Mtetra
.77773 .26553 .78348 .27377 .79669 .26932 .79099 .26103 Mtetra
.79099 .26103 .79669 .26932 .80997 .26483 .8043 .25651 Mtetra
.8043 .25651 .80997 .26483 .8233 .26033 .81768 .25197 Mtetra
.81768 .25197 .8233 .26033 .83669 .25581 .83112 .24741 Mtetra
.83112 .24741 .83669 .25581 .85015 .25127 .84462 .24283 Mtetra
.646 .762 .934 r
.21194 .6548 .21984 .6612 .23139 .65774 .22353 .65131 Mtetra
.22353 .65131 .23139 .65774 .24299 .65426 .23516 .6478 Mtetra
.23516 .6478 .24299 .65426 .25464 .65077 .24684 .64428 Mtetra
.24684 .64428 .25464 .65077 .26635 .64726 .25858 .64074 Mtetra
.25858 .64074 .26635 .64726 .27811 .64374 .27037 .63719 Mtetra
.27037 .63719 .27811 .64374 .28992 .6402 .28221 .63362 Mtetra
.28221 .63362 .28992 .6402 .30179 .63664 .29411 .63004 Mtetra
.29411 .63004 .30179 .63664 .3137 .63307 .30606 .62644 Mtetra
.30606 .62644 .3137 .63307 .32568 .62949 .31807 .62282 Mtetra
.31807 .62282 .32568 .62949 .3377 .62588 .33013 .61919 Mtetra
.33013 .61919 .3377 .62588 .34979 .62226 .34224 .61553 Mtetra
.34224 .61553 .34979 .62226 .36192 .61862 .35441 .61187 Mtetra
.35441 .61187 .36192 .61862 .37411 .61497 .36664 .60818 Mtetra
.36664 .60818 .37411 .61497 .38636 .6113 .37892 .60448 Mtetra
.37892 .60448 .38636 .6113 .39867 .60762 .39126 .60076 Mtetra
.39126 .60076 .39867 .60762 .41103 .60391 .40366 .59703 Mtetra
.40366 .59703 .41103 .60391 .42344 .60019 .41611 .59328 Mtetra
.41611 .59328 .42344 .60019 .43592 .59645 .42862 .58951 Mtetra
.42862 .58951 .43592 .59645 .44845 .5927 .44119 .58572 Mtetra
.44119 .58572 .44845 .5927 .46104 .58892 .45382 .58191 Mtetra
.45382 .58191 .46104 .58892 .47369 .58513 .46651 .57809 Mtetra
.46651 .57809 .47369 .58513 .4864 .58133 .47926 .57425 Mtetra
.47926 .57425 .4864 .58133 .49917 .5775 .49206 .57039 Mtetra
.49206 .57039 .49917 .5775 .512 .57366 .50493 .56651 Mtetra
.50493 .56651 .512 .57366 .52489 .5698 .51786 .56262 Mtetra
.51786 .56262 .52489 .5698 .53784 .56592 .53085 .5587 Mtetra
.53085 .5587 .53784 .56592 .54917 .34309 .5439 .55477 Mtetra
0 0 .306 r
.5439 .55477 .54917 .34309 .56139 .33894 .55492 .33124 Mtetra
.664 .741 .908 r
.55492 .33124 .56139 .33894 .57366 .33478 .56723 .32704 Mtetra
.56723 .32704 .57366 .33478 .58599 .33059 .5796 .32282 Mtetra
.5796 .32282 .58599 .33059 .59838 .32639 .59202 .31858 Mtetra
.59202 .31858 .59838 .32639 .61082 .32217 .60449 .31433 Mtetra
.60449 .31433 .61082 .32217 .62331 .31793 .61703 .31005 Mtetra
.61703 .31005 .62331 .31793 .63586 .31367 .62962 .30576 Mtetra
.62962 .30576 .63586 .31367 .64847 .30939 .64226 .30144 Mtetra
.64226 .30144 .64847 .30939 .66113 .30509 .65497 .29711 Mtetra
.65497 .29711 .66113 .30509 .67385 .30078 .66773 .29276 Mtetra
.66773 .29276 .67385 .30078 .68663 .29644 .68054 .28838 Mtetra
.68054 .28838 .68663 .29644 .69947 .29208 .69342 .28399 Mtetra
.69342 .28399 .69947 .29208 .71237 .28771 .70636 .27958 Mtetra
.70636 .27958 .71237 .28771 .72532 .28331 .71935 .27514 Mtetra
.71935 .27514 .72532 .28331 .73833 .2789 .73241 .27069 Mtetra
.73241 .27069 .73833 .2789 .75141 .27446 .74552 .26622 Mtetra
.74552 .26622 .75141 .27446 .76454 .27 .7587 .26172 Mtetra
.7587 .26172 .76454 .27 .77773 .26553 .77193 .25721 Mtetra
.77193 .25721 .77773 .26553 .79099 .26103 .78523 .25267 Mtetra
.78523 .25267 .79099 .26103 .8043 .25651 .79859 .24811 Mtetra
.79859 .24811 .8043 .25651 .81768 .25197 .81201 .24353 Mtetra
.81201 .24353 .81768 .25197 .83112 .24741 .82549 .23893 Mtetra
.82549 .23893 .83112 .24741 .84462 .24283 .83904 .23431 Mtetra
.646 .762 .934 r
.20399 .64834 .21194 .6548 .22353 .65131 .2156 .64482 Mtetra
.2156 .64482 .22353 .65131 .23516 .6478 .22726 .64129 Mtetra
.22726 .64129 .23516 .6478 .24684 .64428 .23898 .63774 Mtetra
.23898 .63774 .24684 .64428 .25858 .64074 .25075 .63417 Mtetra
.25075 .63417 .25858 .64074 .27037 .63719 .26257 .63059 Mtetra
.26257 .63059 .27037 .63719 .28221 .63362 .27444 .62699 Mtetra
.27444 .62699 .28221 .63362 .29411 .63004 .28637 .62338 Mtetra
.28637 .62338 .29411 .63004 .30606 .62644 .29836 .61975 Mtetra
.29836 .61975 .30606 .62644 .31807 .62282 .3104 .6161 Mtetra
.3104 .6161 .31807 .62282 .33013 .61919 .32249 .61243 Mtetra
.32249 .61243 .33013 .61919 .34224 .61553 .33464 .60875 Mtetra
.33464 .60875 .34224 .61553 .35441 .61187 .34684 .60505 Mtetra
.34684 .60505 .35441 .61187 .36664 .60818 .3591 .60134 Mtetra
.3591 .60134 .36664 .60818 .37892 .60448 .37142 .5976 Mtetra
.37142 .5976 .37892 .60448 .39126 .60076 .3838 .59385 Mtetra
.3838 .59385 .39126 .60076 .40366 .59703 .39623 .59009 Mtetra
.39623 .59009 .40366 .59703 .41611 .59328 .40872 .5863 Mtetra
.40872 .5863 .41611 .59328 .42862 .58951 .42127 .5825 Mtetra
.42127 .5825 .42862 .58951 .44119 .58572 .43387 .57868 Mtetra
.43387 .57868 .44119 .58572 .45382 .58191 .44654 .57484 Mtetra
.44654 .57484 .45382 .58191 .46651 .57809 .45926 .57099 Mtetra
.45926 .57099 .46651 .57809 .47926 .57425 .47205 .56711 Mtetra
.47205 .56711 .47926 .57425 .49206 .57039 .4849 .56322 Mtetra
.4849 .56322 .49206 .57039 .50493 .56651 .4978 .55931 Mtetra
.4978 .55931 .50493 .56651 .51786 .56262 .51077 .55538 Mtetra
.51077 .55538 .51786 .56262 .53085 .5587 .5238 .55143 Mtetra
.5238 .55143 .53085 .5587 .5439 .55477 .53689 .54746 Mtetra
.968 .705 .483 r
.53689 .54746 .5439 .55477 .55492 .33124 .5484 .32347 Mtetra
.664 .741 .908 r
.5484 .32347 .55492 .33124 .56723 .32704 .56075 .31924 Mtetra
.56075 .31924 .56723 .32704 .5796 .32282 .57315 .31498 Mtetra
.57315 .31498 .5796 .32282 .59202 .31858 .58561 .31071 Mtetra
.58561 .31071 .59202 .31858 .60449 .31433 .59812 .30642 Mtetra
.59812 .30642 .60449 .31433 .61703 .31005 .61069 .30211 Mtetra
.61069 .30211 .61703 .31005 .62962 .30576 .62332 .29778 Mtetra
.62332 .29778 .62962 .30576 .64226 .30144 .636 .29343 Mtetra
.636 .29343 .64226 .30144 .65497 .29711 .64874 .28906 Mtetra
.64874 .28906 .65497 .29711 .66773 .29276 .66155 .28467 Mtetra
.66155 .28467 .66773 .29276 .68054 .28838 .6744 .28026 Mtetra
.6744 .28026 .68054 .28838 .69342 .28399 .68732 .27583 Mtetra
.68732 .27583 .69342 .28399 .70636 .27958 .7003 .27138 Mtetra
.7003 .27138 .70636 .27958 .71935 .27514 .71333 .26691 Mtetra
.71333 .26691 .71935 .27514 .73241 .27069 .72643 .26241 Mtetra
.72643 .26241 .73241 .27069 .74552 .26622 .73959 .2579 Mtetra
.73959 .2579 .74552 .26622 .7587 .26172 .7528 .25337 Mtetra
.7528 .25337 .7587 .26172 .77193 .25721 .76608 .24881 Mtetra
.76608 .24881 .77193 .25721 .78523 .25267 .77942 .24424 Mtetra
.77942 .24424 .78523 .25267 .79859 .24811 .79283 .23964 Mtetra
.79283 .23964 .79859 .24811 .81201 .24353 .80629 .23502 Mtetra
.80629 .23502 .81201 .24353 .82549 .23893 .81982 .23039 Mtetra
.81982 .23039 .82549 .23893 .83904 .23431 .83341 .22572 Mtetra
.646 .762 .934 r
.19597 .64183 .20399 .64834 .2156 .64482 .20761 .63829 Mtetra
.20761 .63829 .2156 .64482 .22726 .64129 .2193 .63472 Mtetra
.2193 .63472 .22726 .64129 .23898 .63774 .23105 .63114 Mtetra
.23105 .63114 .23898 .63774 .25075 .63417 .24285 .62755 Mtetra
.24285 .62755 .25075 .63417 .26257 .63059 .2547 .62393 Mtetra
.2547 .62393 .26257 .63059 .27444 .62699 .26661 .62031 Mtetra
.26661 .62031 .27444 .62699 .28637 .62338 .27857 .61666 Mtetra
.27857 .61666 .28637 .62338 .29836 .61975 .29059 .613 Mtetra
.29059 .613 .29836 .61975 .3104 .6161 .30266 .60932 Mtetra
.30266 .60932 .3104 .6161 .32249 .61243 .31479 .60562 Mtetra
.31479 .60562 .32249 .61243 .33464 .60875 .32697 .60191 Mtetra
.32697 .60191 .33464 .60875 .34684 .60505 .33921 .59818 Mtetra
.33921 .59818 .34684 .60505 .3591 .60134 .3515 .59443 Mtetra
.3515 .59443 .3591 .60134 .37142 .5976 .36386 .59067 Mtetra
.36386 .59067 .37142 .5976 .3838 .59385 .37627 .58689 Mtetra
.37627 .58689 .3838 .59385 .39623 .59009 .38873 .58309 Mtetra
.38873 .58309 .39623 .59009 .40872 .5863 .40126 .57927 Mtetra
.40126 .57927 .40872 .5863 .42127 .5825 .41385 .57543 Mtetra
.41385 .57543 .42127 .5825 .43387 .57868 .42649 .57158 Mtetra
.42649 .57158 .43387 .57868 .44654 .57484 .43919 .56771 Mtetra
.43919 .56771 .44654 .57484 .45926 .57099 .45196 .56382 Mtetra
.45196 .56382 .45926 .57099 .47205 .56711 .46478 .55991 Mtetra
.46478 .55991 .47205 .56711 .4849 .56322 .47766 .55598 Mtetra
.47766 .55598 .4849 .56322 .4978 .55931 .49061 .55204 Mtetra
.49061 .55204 .4978 .55931 .51077 .55538 .50362 .54807 Mtetra
.50362 .54807 .51077 .55538 .5238 .55143 .51669 .54409 Mtetra
.51669 .54409 .5238 .55143 .53689 .54746 .52982 .54009 Mtetra
.968 .705 .483 r
.52982 .54009 .53689 .54746 .5484 .32347 .54182 .31564 Mtetra
.664 .741 .908 r
.54182 .31564 .5484 .32347 .56075 .31924 .55421 .31137 Mtetra
.55421 .31137 .56075 .31924 .57315 .31498 .56665 .30708 Mtetra
.56665 .30708 .57315 .31498 .58561 .31071 .57914 .30277 Mtetra
.57914 .30277 .58561 .31071 .59812 .30642 .59169 .29844 Mtetra
.59169 .29844 .59812 .30642 .61069 .30211 .6043 .2941 Mtetra
.6043 .2941 .61069 .30211 .62332 .29778 .61697 .28973 Mtetra
.61697 .28973 .62332 .29778 .636 .29343 .62969 .28534 Mtetra
.62969 .28534 .636 .29343 .64874 .28906 .64247 .28094 Mtetra
.64247 .28094 .64874 .28906 .66155 .28467 .65531 .27651 Mtetra
.65531 .27651 .66155 .28467 .6744 .28026 .66821 .27206 Mtetra
.66821 .27206 .6744 .28026 .68732 .27583 .68117 .26759 Mtetra
.68117 .26759 .68732 .27583 .7003 .27138 .69419 .26311 Mtetra
.69419 .26311 .7003 .27138 .71333 .26691 .70726 .2586 Mtetra
.70726 .2586 .71333 .26691 .72643 .26241 .7204 .25407 Mtetra
.7204 .25407 .72643 .26241 .73959 .2579 .7336 .24952 Mtetra
.7336 .24952 .73959 .2579 .7528 .25337 .74686 .24494 Mtetra
.74686 .24494 .7528 .25337 .76608 .24881 .76018 .24035 Mtetra
.76018 .24035 .76608 .24881 .77942 .24424 .77357 .23574 Mtetra
.77357 .23574 .77942 .24424 .79283 .23964 .78702 .2311 Mtetra
.78702 .2311 .79283 .23964 .80629 .23502 .80053 .22644 Mtetra
.80053 .22644 .80629 .23502 .81982 .23039 .8141 .22176 Mtetra
.8141 .22176 .81982 .23039 .83341 .22572 .82774 .21706 Mtetra
.646 .762 .934 r
.18788 .63527 .19597 .64183 .20761 .63829 .19955 .63169 Mtetra
.19955 .63169 .20761 .63829 .2193 .63472 .21127 .6281 Mtetra
.21127 .6281 .2193 .63472 .23105 .63114 .22305 .62449 Mtetra
.22305 .62449 .23105 .63114 .24285 .62755 .23488 .62086 Mtetra
.23488 .62086 .24285 .62755 .2547 .62393 .24677 .61722 Mtetra
.24677 .61722 .2547 .62393 .26661 .62031 .25871 .61356 Mtetra
.25871 .61356 .26661 .62031 .27857 .61666 .2707 .60989 Mtetra
.2707 .60989 .27857 .61666 .29059 .613 .28275 .60619 Mtetra
.28275 .60619 .29059 .613 .30266 .60932 .29485 .60248 Mtetra
.29485 .60248 .30266 .60932 .31479 .60562 .30702 .59875 Mtetra
.30702 .59875 .31479 .60562 .32697 .60191 .31923 .59501 Mtetra
.31923 .59501 .32697 .60191 .33921 .59818 .33151 .59125 Mtetra
.33151 .59125 .33921 .59818 .3515 .59443 .34384 .58747 Mtetra
.34384 .58747 .3515 .59443 .36386 .59067 .35622 .58367 Mtetra
.35622 .58367 .36386 .59067 .37627 .58689 .36867 .57986 Mtetra
.36867 .57986 .37627 .58689 .38873 .58309 .38117 .57602 Mtetra
.38117 .57602 .38873 .58309 .40126 .57927 .39374 .57217 Mtetra
.39374 .57217 .40126 .57927 .41385 .57543 .40636 .56831 Mtetra
.40636 .56831 .41385 .57543 .42649 .57158 .41904 .56442 Mtetra
.41904 .56442 .42649 .57158 .43919 .56771 .43178 .56051 Mtetra
.43178 .56051 .43919 .56771 .45196 .56382 .44458 .55659 Mtetra
.44458 .55659 .45196 .56382 .46478 .55991 .45745 .55265 Mtetra
.45745 .55265 .46478 .55991 .47766 .55598 .47037 .54869 Mtetra
.47037 .54869 .47766 .55598 .49061 .55204 .48336 .54471 Mtetra
.48336 .54471 .49061 .55204 .50362 .54807 .4964 .54071 Mtetra
.4964 .54071 .50362 .54807 .51669 .54409 .50951 .53669 Mtetra
.50951 .53669 .51669 .54409 .52982 .54009 .52269 .53265 Mtetra
.915 .784 .703 r
.52269 .53265 .52982 .54009 .54182 .31564 .53585 .50587 Mtetra
0 0 .287 r
.53585 .50587 .54182 .31564 .55421 .31137 .54761 .30344 Mtetra
.664 .741 .908 r
.54761 .30344 .55421 .31137 .56665 .30708 .56009 .29911 Mtetra
.56009 .29911 .56665 .30708 .57914 .30277 .57262 .29477 Mtetra
.57262 .29477 .57914 .30277 .59169 .29844 .58521 .2904 Mtetra
.58521 .2904 .59169 .29844 .6043 .2941 .59786 .28602 Mtetra
.59786 .28602 .6043 .2941 .61697 .28973 .61056 .28162 Mtetra
.61056 .28162 .61697 .28973 .62969 .28534 .62333 .27719 Mtetra
.62333 .27719 .62969 .28534 .64247 .28094 .63615 .27275 Mtetra
.63615 .27275 .64247 .28094 .65531 .27651 .64903 .26828 Mtetra
.64903 .26828 .65531 .27651 .66821 .27206 .66197 .2638 Mtetra
.66197 .2638 .66821 .27206 .68117 .26759 .67496 .25929 Mtetra
.67496 .25929 .68117 .26759 .69419 .26311 .68802 .25477 Mtetra
.68802 .25477 .69419 .26311 .70726 .2586 .70114 .25022 Mtetra
.70114 .25022 .70726 .2586 .7204 .25407 .71432 .24565 Mtetra
.71432 .24565 .7204 .25407 .7336 .24952 .72756 .24106 Mtetra
.72756 .24106 .7336 .24952 .74686 .24494 .74087 .23645 Mtetra
.74087 .23645 .74686 .24494 .76018 .24035 .75423 .23182 Mtetra
.75423 .23182 .76018 .24035 .77357 .23574 .76766 .22716 Mtetra
.76766 .22716 .77357 .23574 .78702 .2311 .78115 .22248 Mtetra
.78115 .22248 .78702 .2311 .80053 .22644 .79471 .21779 Mtetra
.79471 .21779 .80053 .22644 .8141 .22176 .80833 .21306 Mtetra
.80833 .21306 .8141 .22176 .82774 .21706 .82201 .20832 Mtetra
.646 .762 .934 r
.17972 .62865 .18788 .63527 .19955 .63169 .19142 .62505 Mtetra
.19142 .62505 .19955 .63169 .21127 .6281 .20318 .62142 Mtetra
.20318 .62142 .21127 .6281 .22305 .62449 .21499 .61778 Mtetra
.21499 .61778 .22305 .62449 .23488 .62086 .22685 .61413 Mtetra
.22685 .61413 .23488 .62086 .24677 .61722 .23877 .61045 Mtetra
.23877 .61045 .24677 .61722 .25871 .61356 .25074 .60676 Mtetra
.25074 .60676 .25871 .61356 .2707 .60989 .26276 .60305 Mtetra
.26276 .60305 .2707 .60989 .28275 .60619 .27485 .59933 Mtetra
.27485 .59933 .28275 .60619 .29485 .60248 .28698 .59559 Mtetra
.28698 .59559 .29485 .60248 .30702 .59875 .29918 .59183 Mtetra
.29918 .59183 .30702 .59875 .31923 .59501 .31143 .58805 Mtetra
.31143 .58805 .31923 .59501 .33151 .59125 .32374 .58426 Mtetra
.32374 .58426 .33151 .59125 .34384 .58747 .3361 .58045 Mtetra
.3361 .58045 .34384 .58747 .35622 .58367 .34853 .57662 Mtetra
.34853 .57662 .35622 .58367 .36867 .57986 .36101 .57277 Mtetra
.36101 .57277 .36867 .57986 .38117 .57602 .37355 .5689 Mtetra
.37355 .5689 .38117 .57602 .39374 .57217 .38615 .56502 Mtetra
.38615 .56502 .39374 .57217 .40636 .56831 .39881 .56111 Mtetra
.39881 .56111 .40636 .56831 .41904 .56442 .41153 .55719 Mtetra
.41153 .55719 .41904 .56442 .43178 .56051 .42431 .55325 Mtetra
.42431 .55325 .43178 .56051 .44458 .55659 .43715 .5493 Mtetra
.43715 .5493 .44458 .55659 .45745 .55265 .45005 .54532 Mtetra
.45005 .54532 .45745 .55265 .47037 .54869 .46301 .54132 Mtetra
.46301 .54132 .47037 .54869 .48336 .54471 .47604 .53731 Mtetra
.47604 .53731 .48336 .54471 .4964 .54071 .48912 .53327 Mtetra
.48912 .53327 .4964 .54071 .50951 .53669 .50227 .52922 Mtetra
.913 .783 .703 r
.50227 .52922 .50951 .53669 .52269 .53265 .51555 .5024 Mtetra
.599 .475 .682 r
.51555 .5024 .52269 .53265 .53585 .50587 .52874 .49828 Mtetra
.648 .76 .931 r
.52874 .49828 .53585 .50587 .54761 .30344 .54199 .49414 Mtetra
.524 .287 .497 r
.54199 .49414 .54761 .30344 .56009 .29911 .55531 .48998 Mtetra
0 0 .294 r
.55531 .48998 .56009 .29911 .57262 .29477 .56605 .28669 Mtetra
.664 .741 .908 r
.56605 .28669 .57262 .29477 .58521 .2904 .57868 .28229 Mtetra
.57868 .28229 .58521 .2904 .59786 .28602 .59136 .27787 Mtetra
.59136 .27787 .59786 .28602 .61056 .28162 .60411 .27343 Mtetra
.60411 .27343 .61056 .28162 .62333 .27719 .61691 .26897 Mtetra
.61691 .26897 .62333 .27719 .63615 .27275 .62977 .26449 Mtetra
.62977 .26449 .63615 .27275 .64903 .26828 .64269 .25999 Mtetra
.64269 .25999 .64903 .26828 .66197 .2638 .65567 .25546 Mtetra
.65567 .25546 .66197 .2638 .67496 .25929 .66871 .25092 Mtetra
.66871 .25092 .67496 .25929 .68802 .25477 .68181 .24635 Mtetra
.68181 .24635 .68802 .25477 .70114 .25022 .69497 .24177 Mtetra
.69497 .24177 .70114 .25022 .71432 .24565 .70819 .23716 Mtetra
.70819 .23716 .71432 .24565 .72756 .24106 .72148 .23253 Mtetra
.72148 .23253 .72756 .24106 .74087 .23645 .73482 .22788 Mtetra
.73482 .22788 .74087 .23645 .75423 .23182 .74823 .2232 Mtetra
.74823 .2232 .75423 .23182 .76766 .22716 .7617 .21851 Mtetra
.7617 .21851 .76766 .22716 .78115 .22248 .77524 .21379 Mtetra
.77524 .21379 .78115 .22248 .79471 .21779 .78884 .20905 Mtetra
.78884 .20905 .79471 .21779 .80833 .21306 .80251 .20429 Mtetra
.80251 .20429 .80833 .21306 .82201 .20832 .81623 .19951 Mtetra
.646 .762 .934 r
.17149 .62198 .17972 .62865 .19142 .62505 .18323 .61834 Mtetra
.18323 .61834 .19142 .62505 .20318 .62142 .19501 .61469 Mtetra
.19501 .61469 .20318 .62142 .21499 .61778 .20685 .61102 Mtetra
.20685 .61102 .21499 .61778 .22685 .61413 .21875 .60733 Mtetra
.21875 .60733 .22685 .61413 .23877 .61045 .2307 .60363 Mtetra
.2307 .60363 .23877 .61045 .25074 .60676 .2427 .5999 Mtetra
.2427 .5999 .25074 .60676 .26276 .60305 .25476 .59616 Mtetra
.25476 .59616 .26276 .60305 .27485 .59933 .26688 .59241 Mtetra
.26688 .59241 .27485 .59933 .28698 .59559 .27905 .58863 Mtetra
.27905 .58863 .28698 .59559 .29918 .59183 .29128 .58484 Mtetra
.29128 .58484 .29918 .59183 .31143 .58805 .30356 .58103 Mtetra
.30356 .58103 .31143 .58805 .32374 .58426 .3159 .57721 Mtetra
.3159 .57721 .32374 .58426 .3361 .58045 .3283 .57336 Mtetra
.3283 .57336 .3361 .58045 .34853 .57662 .34076 .5695 Mtetra
.34076 .5695 .34853 .57662 .36101 .57277 .35328 .56562 Mtetra
.35328 .56562 .36101 .57277 .37355 .5689 .36586 .56172 Mtetra
.36586 .56172 .37355 .5689 .38615 .56502 .37849 .5578 Mtetra
.37849 .5578 .38615 .56502 .39881 .56111 .39119 .55386 Mtetra
.39119 .55386 .39881 .56111 .41153 .55719 .40395 .54991 Mtetra
.40395 .54991 .41153 .55719 .42431 .55325 .41677 .54593 Mtetra
.41677 .54593 .42431 .55325 .43715 .5493 .42964 .54194 Mtetra
.42964 .54194 .43715 .5493 .45005 .54532 .44258 .53793 Mtetra
.44258 .53793 .45005 .54532 .46301 .54132 .45559 .53389 Mtetra
.45559 .53389 .46301 .54132 .47604 .53731 .46865 .52984 Mtetra
.46865 .52984 .47604 .53731 .48912 .53327 .48178 .52577 Mtetra
.912 .782 .704 r
.48178 .52577 .48912 .53327 .50227 .52922 .49518 .49891 Mtetra
.598 .474 .682 r
.49518 .49891 .50227 .52922 .51555 .5024 .50834 .49478 Mtetra
.648 .76 .931 r
.50834 .49478 .51555 .5024 .52874 .49828 .52157 .49062 Mtetra
.52157 .49062 .52874 .49828 .54199 .49414 .53486 .48644 Mtetra
.53486 .48644 .54199 .49414 .55531 .48998 .54822 .48224 Mtetra
.54822 .48224 .55531 .48998 .56605 .28669 .56164 .47803 Mtetra
0 0 .294 r
.56164 .47803 .56605 .28669 .57868 .28229 .57209 .27412 Mtetra
.664 .741 .908 r
.57209 .27412 .57868 .28229 .59136 .27787 .58481 .26966 Mtetra
.58481 .26966 .59136 .27787 .60411 .27343 .59759 .26518 Mtetra
.59759 .26518 .60411 .27343 .61691 .26897 .61043 .26068 Mtetra
.61043 .26068 .61691 .26897 .62977 .26449 .62333 .25616 Mtetra
.62333 .25616 .62977 .26449 .64269 .25999 .63629 .25162 Mtetra
.63629 .25162 .64269 .25999 .65567 .25546 .64932 .24706 Mtetra
.64932 .24706 .65567 .25546 .66871 .25092 .6624 .24247 Mtetra
.6624 .24247 .66871 .25092 .68181 .24635 .67554 .23787 Mtetra
.67554 .23787 .68181 .24635 .69497 .24177 .68874 .23324 Mtetra
.68874 .23324 .69497 .24177 .70819 .23716 .70201 .22859 Mtetra
.70201 .22859 .70819 .23716 .72148 .23253 .71533 .22393 Mtetra
.71533 .22393 .72148 .23253 .73482 .22788 .72872 .21923 Mtetra
.72872 .21923 .73482 .22788 .74823 .2232 .74218 .21452 Mtetra
.74218 .21452 .74823 .2232 .7617 .21851 .75569 .20978 Mtetra
.75569 .20978 .7617 .21851 .77524 .21379 .76928 .20502 Mtetra
.76928 .20502 .77524 .21379 .78884 .20905 .78292 .20024 Mtetra
.78292 .20024 .78884 .20905 .80251 .20429 .79663 .19544 Mtetra
.79663 .19544 .80251 .20429 .81623 .19951 .81041 .19061 Mtetra
.646 .762 .934 r
.1632 .61525 .17149 .62198 .18323 .61834 .17496 .61158 Mtetra
.17496 .61158 .18323 .61834 .19501 .61469 .18678 .6079 Mtetra
.18678 .6079 .19501 .61469 .20685 .61102 .19865 .6042 Mtetra
.19865 .6042 .20685 .61102 .21875 .60733 .21058 .60048 Mtetra
.21058 .60048 .21875 .60733 .2307 .60363 .22256 .59674 Mtetra
.22256 .59674 .2307 .60363 .2427 .5999 .23459 .59299 Mtetra
.23459 .59299 .2427 .5999 .25476 .59616 .24669 .58922 Mtetra
.24669 .58922 .25476 .59616 .26688 .59241 .25884 .58543 Mtetra
.25884 .58543 .26688 .59241 .27905 .58863 .27104 .58162 Mtetra
.27104 .58162 .27905 .58863 .29128 .58484 .2833 .5778 Mtetra
.2833 .5778 .29128 .58484 .30356 .58103 .29562 .57395 Mtetra
.29562 .57395 .30356 .58103 .3159 .57721 .308 .57009 Mtetra
.308 .57009 .3159 .57721 .3283 .57336 .32044 .56621 Mtetra
.32044 .56621 .3283 .57336 .34076 .5695 .33293 .56232 Mtetra
.33293 .56232 .34076 .5695 .35328 .56562 .34549 .5584 Mtetra
.34549 .5584 .35328 .56562 .36586 .56172 .3581 .55447 Mtetra
.3581 .55447 .36586 .56172 .37849 .5578 .37077 .55052 Mtetra
.37077 .55052 .37849 .5578 .39119 .55386 .38351 .54654 Mtetra
.38351 .54654 .39119 .55386 .40395 .54991 .3963 .54255 Mtetra
.3963 .54255 .40395 .54991 .41677 .54593 .40916 .53854 Mtetra
.40916 .53854 .41677 .54593 .42964 .54194 .42207 .53452 Mtetra
.42207 .53452 .42964 .54194 .44258 .53793 .43505 .53047 Mtetra
.43505 .53047 .44258 .53793 .45559 .53389 .4481 .5264 Mtetra
.4481 .5264 .45559 .53389 .46865 .52984 .4612 .52231 Mtetra
.911 .78 .704 r
.4612 .52231 .46865 .52984 .48178 .52577 .47472 .49541 Mtetra
.597 .473 .682 r
.47472 .49541 .48178 .52577 .49518 .49891 .48786 .49126 Mtetra
.648 .76 .931 r
.48786 .49126 .49518 .49891 .50834 .49478 .50106 .48709 Mtetra
.50106 .48709 .50834 .49478 .52157 .49062 .51434 .48289 Mtetra
.51434 .48289 .52157 .49062 .53486 .48644 .52767 .47868 Mtetra
.52767 .47868 .53486 .48644 .54822 .48224 .54107 .47444 Mtetra
.54107 .47444 .54822 .48224 .56164 .47803 .55454 .47019 Mtetra
.55454 .47019 .56164 .47803 .57209 .27412 .56807 .46591 Mtetra
.521 .281 .493 r
.56807 .46591 .57209 .27412 .58481 .26966 .58166 .46161 Mtetra
0 0 .3 r
.58166 .46161 .58481 .26966 .59759 .26518 .59102 .25686 Mtetra
.664 .741 .908 r
.59102 .25686 .59759 .26518 .61043 .26068 .60391 .25232 Mtetra
.60391 .25232 .61043 .26068 .62333 .25616 .61685 .24776 Mtetra
.61685 .24776 .62333 .25616 .63629 .25162 .62985 .24318 Mtetra
.62985 .24318 .63629 .25162 .64932 .24706 .64291 .23858 Mtetra
.64291 .23858 .64932 .24706 .6624 .24247 .65603 .23396 Mtetra
.65603 .23396 .6624 .24247 .67554 .23787 .66921 .22931 Mtetra
.66921 .22931 .67554 .23787 .68874 .23324 .68246 .22464 Mtetra
.68246 .22464 .68874 .23324 .70201 .22859 .69577 .21996 Mtetra
.69577 .21996 .70201 .22859 .71533 .22393 .70914 .21525 Mtetra
.70914 .21525 .71533 .22393 .72872 .21923 .72257 .21051 Mtetra
.72257 .21051 .72872 .21923 .74218 .21452 .73607 .20576 Mtetra
.73607 .20576 .74218 .21452 .75569 .20978 .74963 .20098 Mtetra
.74963 .20098 .75569 .20978 .76928 .20502 .76326 .19618 Mtetra
.76326 .19618 .76928 .20502 .78292 .20024 .77695 .19136 Mtetra
.77695 .19136 .78292 .20024 .79663 .19544 .79071 .18651 Mtetra
.79071 .18651 .79663 .19544 .81041 .19061 .80453 .18164 Mtetra
.646 .762 .934 r
.15484 .60847 .1632 .61525 .17496 .61158 .16663 .60477 Mtetra
.16663 .60477 .17496 .61158 .18678 .6079 .17848 .60105 Mtetra
.17848 .60105 .18678 .6079 .19865 .6042 .19038 .59732 Mtetra
.19038 .59732 .19865 .6042 .21058 .60048 .20234 .59357 Mtetra
.20234 .59357 .21058 .60048 .22256 .59674 .21435 .5898 Mtetra
.21435 .5898 .22256 .59674 .23459 .59299 .22642 .58601 Mtetra
.22642 .58601 .23459 .59299 .24669 .58922 .23855 .58221 Mtetra
.23855 .58221 .24669 .58922 .25884 .58543 .25073 .57839 Mtetra
.25073 .57839 .25884 .58543 .27104 .58162 .26297 .57455 Mtetra
.26297 .57455 .27104 .58162 .2833 .5778 .27526 .57069 Mtetra
.27526 .57069 .2833 .5778 .29562 .57395 .28762 .56681 Mtetra
.28762 .56681 .29562 .57395 .308 .57009 .30003 .56292 Mtetra
.30003 .56292 .308 .57009 .32044 .56621 .3125 .55901 Mtetra
.3125 .55901 .32044 .56621 .33293 .56232 .32503 .55507 Mtetra
.32503 .55507 .33293 .56232 .34549 .5584 .33762 .55113 Mtetra
.33762 .55113 .34549 .5584 .3581 .55447 .35027 .54716 Mtetra
.35027 .54716 .3581 .55447 .37077 .55052 .36298 .54317 Mtetra
.36298 .54317 .37077 .55052 .38351 .54654 .37575 .53916 Mtetra
.37575 .53916 .38351 .54654 .3963 .54255 .38859 .53514 Mtetra
.38859 .53514 .3963 .54255 .40916 .53854 .40148 .53109 Mtetra
.40148 .53109 .40916 .53854 .42207 .53452 .41444 .52703 Mtetra
.41444 .52703 .42207 .53452 .43505 .53047 .42746 .52294 Mtetra
.42746 .52294 .43505 .53047 .4481 .5264 .44054 .51884 Mtetra
.44054 .51884 .4481 .5264 .4612 .52231 .45369 .51472 Mtetra
.911 .78 .704 r
.45369 .51472 .4612 .52231 .47472 .49541 .46729 .48773 Mtetra
.648 .76 .931 r
.46729 .48773 .47472 .49541 .48786 .49126 .48048 .48354 Mtetra
.48048 .48354 .48786 .49126 .50106 .48709 .49372 .47933 Mtetra
.49372 .47933 .50106 .48709 .51434 .48289 .50704 .47509 Mtetra
.50704 .47509 .51434 .48289 .52767 .47868 .52041 .47084 Mtetra
.52041 .47084 .52767 .47868 .54107 .47444 .53386 .46657 Mtetra
.53386 .46657 .54107 .47444 .55454 .47019 .54736 .46228 Mtetra
.54736 .46228 .55454 .47019 .56807 .46591 .56094 .45796 Mtetra
.56094 .45796 .56807 .46591 .58166 .46161 .57458 .45362 Mtetra
.57458 .45362 .58166 .46161 .59102 .25686 .58829 .44927 Mtetra
0 0 .3 r
.58829 .44927 .59102 .25686 .60391 .25232 .59732 .24389 Mtetra
.664 .741 .908 r
.59732 .24389 .60391 .25232 .61685 .24776 .6103 .23929 Mtetra
.6103 .23929 .61685 .24776 .62985 .24318 .62334 .23467 Mtetra
.62334 .23467 .62985 .24318 .64291 .23858 .63645 .23003 Mtetra
.63645 .23003 .64291 .23858 .65603 .23396 .64961 .22536 Mtetra
.64961 .22536 .65603 .23396 .66921 .22931 .66284 .22068 Mtetra
.66284 .22068 .66921 .22931 .68246 .22464 .67612 .21597 Mtetra
.67612 .21597 .68246 .22464 .69577 .21996 .68948 .21124 Mtetra
.68948 .21124 .69577 .21996 .70914 .21525 .70289 .20649 Mtetra
.70289 .20649 .70914 .21525 .72257 .21051 .71637 .20172 Mtetra
.71637 .20172 .72257 .21051 .73607 .20576 .72991 .19692 Mtetra
.72991 .19692 .73607 .20576 .74963 .20098 .74352 .1921 Mtetra
.74352 .1921 .74963 .20098 .76326 .19618 .75719 .18726 Mtetra
.75719 .18726 .76326 .19618 .77695 .19136 .77093 .18239 Mtetra
.77093 .18239 .77695 .19136 .79071 .18651 .78473 .1775 Mtetra
.78473 .1775 .79071 .18651 .80453 .18164 .7986 .17259 Mtetra
.572 .405 .616 r
.15128 .55746 .15484 .60847 .16663 .60477 .16296 .55368 Mtetra
.16296 .55368 .16663 .60477 .17848 .60105 .1747 .54988 Mtetra
0 0 .403 r
.1747 .54988 .17848 .60105 .19038 .59732 .18204 .59038 Mtetra
.646 .762 .934 r
.18204 .59038 .19038 .59732 .20234 .59357 .19403 .58659 Mtetra
.19403 .58659 .20234 .59357 .21435 .5898 .20607 .58279 Mtetra
.20607 .58279 .21435 .5898 .22642 .58601 .21817 .57897 Mtetra
.21817 .57897 .22642 .58601 .23855 .58221 .23033 .57514 Mtetra
.23033 .57514 .23855 .58221 .25073 .57839 .24255 .57128 Mtetra
.24255 .57128 .25073 .57839 .26297 .57455 .25482 .56741 Mtetra
.25482 .56741 .26297 .57455 .27526 .57069 .26715 .56352 Mtetra
.26715 .56352 .27526 .57069 .28762 .56681 .27954 .55961 Mtetra
.27954 .55961 .28762 .56681 .30003 .56292 .29199 .55568 Mtetra
.29199 .55568 .30003 .56292 .3125 .55901 .3045 .55173 Mtetra
.3045 .55173 .3125 .55901 .32503 .55507 .31706 .54777 Mtetra
.31706 .54777 .32503 .55507 .33762 .55113 .32969 .54378 Mtetra
.32969 .54378 .33762 .55113 .35027 .54716 .34238 .53978 Mtetra
.34238 .53978 .35027 .54716 .36298 .54317 .35512 .53576 Mtetra
.35512 .53576 .36298 .54317 .37575 .53916 .36793 .53172 Mtetra
.36793 .53172 .37575 .53916 .38859 .53514 .3808 .52765 Mtetra
.3808 .52765 .38859 .53514 .40148 .53109 .39374 .52357 Mtetra
.39374 .52357 .40148 .53109 .41444 .52703 .40673 .51947 Mtetra
.40673 .51947 .41444 .52703 .42746 .52294 .41979 .51535 Mtetra
.41979 .51535 .42746 .52294 .44054 .51884 .43291 .51121 Mtetra
.91 .779 .704 r
.43291 .51121 .44054 .51884 .45369 .51472 .44664 .48418 Mtetra
.596 .472 .681 r
.44664 .48418 .45369 .51472 .46729 .48773 .4598 .47998 Mtetra
.648 .76 .931 r
.4598 .47998 .46729 .48773 .48048 .48354 .47303 .47575 Mtetra
.47303 .47575 .48048 .48354 .49372 .47933 .48632 .4715 Mtetra
.48632 .4715 .49372 .47933 .50704 .47509 .49967 .46723 Mtetra
.49967 .46723 .50704 .47509 .52041 .47084 .51309 .46294 Mtetra
.51309 .46294 .52041 .47084 .53386 .46657 .52658 .45863 Mtetra
.52658 .45863 .53386 .46657 .54736 .46228 .54013 .45429 Mtetra
.54013 .45429 .54736 .46228 .56094 .45796 .55375 .44994 Mtetra
.55375 .44994 .56094 .45796 .57458 .45362 .56743 .44556 Mtetra
.56743 .44556 .57458 .45362 .58829 .44927 .58119 .44116 Mtetra
.58119 .44116 .58829 .44927 .59732 .24389 .59501 .43674 Mtetra
0 0 .3 r
.59501 .43674 .59732 .24389 .6103 .23929 .6037 .23074 Mtetra
.664 .741 .908 r
.6037 .23074 .6103 .23929 .62334 .23467 .61678 .22608 Mtetra
.61678 .22608 .62334 .23467 .63645 .23003 .62993 .2214 Mtetra
.62993 .2214 .63645 .23003 .64961 .22536 .64313 .2167 Mtetra
.64313 .2167 .64961 .22536 .66284 .22068 .6564 .21197 Mtetra
.6564 .21197 .66284 .22068 .67612 .21597 .66973 .20722 Mtetra
.66973 .20722 .67612 .21597 .68948 .21124 .68313 .20245 Mtetra
.68313 .20245 .68948 .21124 .70289 .20649 .69659 .19766 Mtetra
.69659 .19766 .70289 .20649 .71637 .20172 .71011 .19284 Mtetra
.71011 .19284 .71637 .20172 .72991 .19692 .72369 .188 Mtetra
.72369 .188 .72991 .19692 .74352 .1921 .73735 .18314 Mtetra
.73735 .18314 .74352 .1921 .75719 .18726 .75106 .17826 Mtetra
.75106 .17826 .75719 .18726 .77093 .18239 .76485 .17335 Mtetra
.76485 .17335 .77093 .18239 .78473 .1775 .7787 .16841 Mtetra
.7787 .16841 .78473 .1775 .7986 .17259 .79262 .16346 Mtetra
.65 .758 .928 r
.1429 .55046 .15128 .55746 .16296 .55368 .15462 .54665 Mtetra
.15462 .54665 .16296 .55368 .1747 .54988 .16638 .54282 Mtetra
.16638 .54282 .1747 .54988 .18204 .59038 .1782 .53896 Mtetra
.571 .403 .615 r
.1782 .53896 .18204 .59038 .19403 .58659 .19008 .5351 Mtetra
.19008 .5351 .19403 .58659 .20607 .58279 .20201 .53121 Mtetra
.20201 .53121 .20607 .58279 .21817 .57897 .21399 .52731 Mtetra
.21399 .52731 .21817 .57897 .23033 .57514 .22603 .52338 Mtetra
.22603 .52338 .23033 .57514 .24255 .57128 .23813 .51944 Mtetra
.23813 .51944 .24255 .57128 .25482 .56741 .25028 .51548 Mtetra
.25028 .51548 .25482 .56741 .26715 .56352 .2625 .5115 Mtetra
.2625 .5115 .26715 .56352 .27954 .55961 .27476 .50751 Mtetra
.27476 .50751 .27954 .55961 .29199 .55568 .28709 .50349 Mtetra
.28709 .50349 .29199 .55568 .3045 .55173 .29947 .49946 Mtetra
.29947 .49946 .3045 .55173 .31706 .54777 .31191 .49541 Mtetra
.31191 .49541 .31706 .54777 .32969 .54378 .32441 .49133 Mtetra
.32441 .49133 .32969 .54378 .34238 .53978 .33697 .48724 Mtetra
.33697 .48724 .34238 .53978 .35512 .53576 .34959 .48313 Mtetra
.34959 .48313 .35512 .53576 .36793 .53172 .36227 .479 Mtetra
.36227 .479 .36793 .53172 .3808 .52765 .37501 .47485 Mtetra
.37501 .47485 .3808 .52765 .39374 .52357 .38781 .47068 Mtetra
0 0 .484 r
.38781 .47068 .39374 .52357 .40673 .51947 .39896 .51185 Mtetra
.646 .762 .934 r
.39896 .51185 .40673 .51947 .41979 .51535 .41206 .50769 Mtetra
.909 .778 .705 r
.41206 .50769 .41979 .51535 .43291 .51121 .42591 .48062 Mtetra
.595 .471 .681 r
.42591 .48062 .43291 .51121 .44664 .48418 .43904 .4764 Mtetra
.648 .76 .931 r
.43904 .4764 .44664 .48418 .4598 .47998 .45225 .47215 Mtetra
.45225 .47215 .4598 .47998 .47303 .47575 .46551 .46789 Mtetra
.46551 .46789 .47303 .47575 .48632 .4715 .47884 .4636 Mtetra
.47884 .4636 .48632 .4715 .49967 .46723 .49224 .45929 Mtetra
.49224 .45929 .49967 .46723 .51309 .46294 .5057 .45496 Mtetra
.5057 .45496 .51309 .46294 .52658 .45863 .51923 .45061 Mtetra
.51923 .45061 .52658 .45863 .54013 .45429 .53283 .44624 Mtetra
.53283 .44624 .54013 .45429 .55375 .44994 .54649 .44184 Mtetra
.54649 .44184 .55375 .44994 .56743 .44556 .56022 .43742 Mtetra
.56022 .43742 .56743 .44556 .58119 .44116 .57402 .43299 Mtetra
.57402 .43299 .58119 .44116 .59501 .43674 .58789 .42853 Mtetra
.58789 .42853 .59501 .43674 .6037 .23074 .60183 .42404 Mtetra
.515 .273 .486 r
.60183 .42404 .6037 .23074 .61678 .22608 .61584 .41954 Mtetra
0 0 .306 r
.61584 .41954 .61678 .22608 .62993 .2214 .62335 .2127 Mtetra
.664 .741 .908 r
.62335 .2127 .62993 .2214 .64313 .2167 .6366 .20796 Mtetra
.6366 .20796 .64313 .2167 .6564 .21197 .64991 .20319 Mtetra
.64991 .20319 .6564 .21197 .66973 .20722 .66328 .1984 Mtetra
.66328 .1984 .66973 .20722 .68313 .20245 .67672 .19359 Mtetra
.67672 .19359 .68313 .20245 .69659 .19766 .69023 .18875 Mtetra
.69023 .18875 .69659 .19766 .71011 .19284 .70379 .18389 Mtetra
.70379 .18389 .71011 .19284 .72369 .188 .71742 .17901 Mtetra
.71742 .17901 .72369 .188 .73735 .18314 .73112 .1741 Mtetra
.73112 .1741 .73735 .18314 .75106 .17826 .74489 .16917 Mtetra
.74489 .16917 .75106 .17826 .76485 .17335 .75872 .16422 Mtetra
.75872 .16422 .76485 .17335 .7787 .16841 .77261 .15924 Mtetra
.77261 .15924 .7787 .16841 .79262 .16346 .78658 .15424 Mtetra
.65 .758 .928 r
.13445 .54341 .1429 .55046 .15462 .54665 .1462 .53956 Mtetra
.1462 .53956 .15462 .54665 .16638 .54282 .15799 .53569 Mtetra
.15799 .53569 .16638 .54282 .1782 .53896 .16985 .53181 Mtetra
.16985 .53181 .1782 .53896 .19008 .5351 .18175 .52791 Mtetra
.18175 .52791 .19008 .5351 .20201 .53121 .19372 .52399 Mtetra
.19372 .52399 .20201 .53121 .21399 .52731 .20573 .52005 Mtetra
.20573 .52005 .21399 .52731 .22603 .52338 .21781 .51609 Mtetra
.21781 .51609 .22603 .52338 .23813 .51944 .22994 .51212 Mtetra
.22994 .51212 .23813 .51944 .25028 .51548 .24212 .50812 Mtetra
.24212 .50812 .25028 .51548 .2625 .5115 .25437 .50411 Mtetra
.25437 .50411 .2625 .5115 .27476 .50751 .26667 .50008 Mtetra
.26667 .50008 .27476 .50751 .28709 .50349 .27903 .49603 Mtetra
.27903 .49603 .28709 .50349 .29947 .49946 .29145 .49196 Mtetra
.29145 .49196 .29947 .49946 .31191 .49541 .30392 .48787 Mtetra
.30392 .48787 .31191 .49541 .32441 .49133 .31646 .48377 Mtetra
.31646 .48377 .32441 .49133 .33697 .48724 .32905 .47964 Mtetra
.32905 .47964 .33697 .48724 .34959 .48313 .34171 .47549 Mtetra
.34171 .47549 .34959 .48313 .36227 .479 .35443 .47132 Mtetra
.35443 .47132 .36227 .479 .37501 .47485 .3672 .46714 Mtetra
.3672 .46714 .37501 .47485 .38781 .47068 .38004 .46293 Mtetra
.38004 .46293 .38781 .47068 .39896 .51185 .39294 .4587 Mtetra
.57 .402 .615 r
.39294 .4587 .39896 .51185 .41206 .50769 .40591 .45445 Mtetra
.349 .244 .591 r
.40591 .45445 .41206 .50769 .42591 .48062 .4182 .47281 Mtetra
.648 .76 .931 r
.4182 .47281 .42591 .48062 .43904 .4764 .43138 .46854 Mtetra
.43138 .46854 .43904 .4764 .45225 .47215 .44462 .46426 Mtetra
.44462 .46426 .45225 .47215 .46551 .46789 .45793 .45995 Mtetra
.45793 .45995 .46551 .46789 .47884 .4636 .4713 .45563 Mtetra
.4713 .45563 .47884 .4636 .49224 .45929 .48474 .45128 Mtetra
.48474 .45128 .49224 .45929 .5057 .45496 .49824 .44691 Mtetra
.49824 .44691 .5057 .45496 .51923 .45061 .51182 .44252 Mtetra
.51182 .44252 .51923 .45061 .53283 .44624 .52546 .43811 Mtetra
.52546 .43811 .53283 .44624 .54649 .44184 .53916 .43367 Mtetra
.53916 .43367 .54649 .44184 .56022 .43742 .55294 .42921 Mtetra
.55294 .42921 .56022 .43742 .57402 .43299 .56679 .42473 Mtetra
.56679 .42473 .57402 .43299 .58789 .42853 .5807 .42023 Mtetra
.5807 .42023 .58789 .42853 .60183 .42404 .59469 .41571 Mtetra
.59469 .41571 .60183 .42404 .61584 .41954 .60874 .41116 Mtetra
.60874 .41116 .61584 .41954 .62335 .2127 .62287 .40659 Mtetra
0 0 .306 r
.62287 .40659 .62335 .2127 .6366 .20796 .63001 .19914 Mtetra
.664 .741 .908 r
.63001 .19914 .6366 .20796 .64991 .20319 .64336 .19433 Mtetra
.64336 .19433 .64991 .20319 .66328 .1984 .65678 .1895 Mtetra
.65678 .1895 .66328 .1984 .67672 .19359 .67026 .18464 Mtetra
.67026 .18464 .67672 .19359 .69023 .18875 .68381 .17976 Mtetra
.68381 .17976 .69023 .18875 .70379 .18389 .69742 .17486 Mtetra
.69742 .17486 .70379 .18389 .71742 .17901 .7111 .16993 Mtetra
.7111 .16993 .71742 .17901 .73112 .1741 .72484 .16498 Mtetra
.72484 .16498 .73112 .1741 .74489 .16917 .73865 .16001 Mtetra
.73865 .16001 .74489 .16917 .75872 .16422 .75253 .15501 Mtetra
.75253 .15501 .75872 .16422 .77261 .15924 .76647 .14999 Mtetra
.76647 .14999 .77261 .15924 .78658 .15424 .78049 .14494 Mtetra
.65 .758 .928 r
.12593 .53629 .13445 .54341 .1462 .53956 .13771 .53241 Mtetra
.13771 .53241 .1462 .53956 .15799 .53569 .14954 .52851 Mtetra
.14954 .52851 .15799 .53569 .16985 .53181 .16142 .52459 Mtetra
.16142 .52459 .16985 .53181 .18175 .52791 .17336 .52066 Mtetra
.17336 .52066 .18175 .52791 .19372 .52399 .18535 .5167 Mtetra
.18535 .5167 .19372 .52399 .20573 .52005 .1974 .51273 Mtetra
.1974 .51273 .20573 .52005 .21781 .51609 .20951 .50874 Mtetra
.20951 .50874 .21781 .51609 .22994 .51212 .22167 .50473 Mtetra
.22167 .50473 .22994 .51212 .24212 .50812 .23389 .5007 Mtetra
.23389 .5007 .24212 .50812 .25437 .50411 .24617 .49666 Mtetra
.24617 .49666 .25437 .50411 .26667 .50008 .2585 .49259 Mtetra
.2585 .49259 .26667 .50008 .27903 .49603 .2709 .4885 Mtetra
.2709 .4885 .27903 .49603 .29145 .49196 .28335 .4844 Mtetra
.28335 .4844 .29145 .49196 .30392 .48787 .29586 .48027 Mtetra
.29586 .48027 .30392 .48787 .31646 .48377 .30843 .47613 Mtetra
.30843 .47613 .31646 .48377 .32905 .47964 .32107 .47197 Mtetra
.32107 .47197 .32905 .47964 .34171 .47549 .33376 .46778 Mtetra
.33376 .46778 .34171 .47549 .35443 .47132 .34651 .46358 Mtetra
.34651 .46358 .35443 .47132 .3672 .46714 .35933 .45935 Mtetra
.35933 .45935 .3672 .46714 .38004 .46293 .37221 .45511 Mtetra
.37221 .45511 .38004 .46293 .39294 .4587 .38514 .45084 Mtetra
.38514 .45084 .39294 .4587 .40591 .45445 .39815 .44656 Mtetra
.726 .243 0 r
.39815 .44656 .40591 .45445 .4182 .47281 .41042 .46492 Mtetra
.648 .76 .931 r
.41042 .46492 .4182 .47281 .43138 .46854 .42364 .46062 Mtetra
.42364 .46062 .43138 .46854 .44462 .46426 .43692 .45629 Mtetra
.43692 .45629 .44462 .46426 .45793 .45995 .45027 .45195 Mtetra
.45027 .45195 .45793 .45995 .4713 .45563 .46369 .44758 Mtetra
.46369 .44758 .4713 .45563 .48474 .45128 .47717 .4432 Mtetra
.47717 .4432 .48474 .45128 .49824 .44691 .49072 .43879 Mtetra
.49072 .43879 .49824 .44691 .51182 .44252 .50434 .43435 Mtetra
.50434 .43435 .51182 .44252 .52546 .43811 .51802 .4299 Mtetra
.51802 .4299 .52546 .43811 .53916 .43367 .53177 .42542 Mtetra
.53177 .42542 .53916 .43367 .55294 .42921 .54559 .42093 Mtetra
.54559 .42093 .55294 .42921 .56679 .42473 .55948 .4164 Mtetra
.55948 .4164 .56679 .42473 .5807 .42023 .57345 .41186 Mtetra
.57345 .41186 .5807 .42023 .59469 .41571 .58748 .40729 Mtetra
.58748 .40729 .59469 .41571 .60874 .41116 .60158 .4027 Mtetra
.60158 .4027 .60874 .41116 .62287 .40659 .61576 .39809 Mtetra
.61576 .39809 .62287 .40659 .63001 .19914 .63 .39345 Mtetra
.511 .267 .482 r
.63 .39345 .63001 .19914 .64336 .19433 .64432 .38879 Mtetra
0 0 .312 r
.64432 .38879 .64336 .19433 .65678 .1895 .65022 .18051 Mtetra
.664 .741 .908 r
.65022 .18051 .65678 .1895 .67026 .18464 .66374 .17561 Mtetra
.66374 .17561 .67026 .18464 .68381 .17976 .67734 .17069 Mtetra
.67734 .17069 .68381 .17976 .69742 .17486 .69099 .16575 Mtetra
.69099 .16575 .69742 .17486 .7111 .16993 .70472 .16078 Mtetra
.70472 .16078 .7111 .16993 .72484 .16498 .7185 .15578 Mtetra
.7185 .15578 .72484 .16498 .73865 .16001 .73236 .15076 Mtetra
.73236 .15076 .73865 .16001 .75253 .15501 .74629 .14572 Mtetra
.74629 .14572 .75253 .15501 .76647 .14999 .76028 .14065 Mtetra
.76028 .14065 .76647 .14999 .78049 .14494 .77434 .13556 Mtetra
.65 .758 .928 r
.11734 .52911 .12593 .53629 .13771 .53241 .12915 .5252 Mtetra
.12915 .5252 .13771 .53241 .14954 .52851 .141 .52126 Mtetra
.141 .52126 .14954 .52851 .16142 .52459 .15292 .51731 Mtetra
.15292 .51731 .16142 .52459 .17336 .52066 .16489 .51334 Mtetra
.16489 .51334 .17336 .52066 .18535 .5167 .17691 .50936 Mtetra
.17691 .50936 .18535 .5167 .1974 .51273 .189 .50535 Mtetra
.189 .50535 .1974 .51273 .20951 .50874 .20113 .50132 Mtetra
.20113 .50132 .20951 .50874 .22167 .50473 .21333 .49728 Mtetra
.21333 .49728 .22167 .50473 .23389 .5007 .22558 .49322 Mtetra
.22558 .49322 .23389 .5007 .24617 .49666 .2379 .48913 Mtetra
.2379 .48913 .24617 .49666 .2585 .49259 .25027 .48503 Mtetra
.25027 .48503 .2585 .49259 .2709 .4885 .2627 .48091 Mtetra
.2627 .48091 .2709 .4885 .28335 .4844 .27518 .47677 Mtetra
.27518 .47677 .28335 .4844 .29586 .48027 .28773 .47261 Mtetra
.28773 .47261 .29586 .48027 .30843 .47613 .30034 .46843 Mtetra
.30034 .46843 .30843 .47613 .32107 .47197 .31301 .46423 Mtetra
.31301 .46423 .32107 .47197 .33376 .46778 .32574 .46 Mtetra
.32574 .46 .33376 .46778 .34651 .46358 .33853 .45576 Mtetra
.33853 .45576 .34651 .46358 .35933 .45935 .35138 .4515 Mtetra
.35138 .4515 .35933 .45935 .37221 .45511 .3643 .44722 Mtetra
.3643 .44722 .37221 .45511 .38514 .45084 .37728 .44291 Mtetra
.37728 .44291 .38514 .45084 .39815 .44656 .39032 .43859 Mtetra
.726 .243 0 r
.39032 .43859 .39815 .44656 .41042 .46492 .40258 .45696 Mtetra
.648 .76 .931 r
.40258 .45696 .41042 .46492 .42364 .46062 .41584 .45262 Mtetra
.41584 .45262 .42364 .46062 .43692 .45629 .42916 .44826 Mtetra
.42916 .44826 .43692 .45629 .45027 .45195 .44255 .44387 Mtetra
.44255 .44387 .45027 .45195 .46369 .44758 .45601 .43947 Mtetra
.45601 .43947 .46369 .44758 .47717 .4432 .46953 .43504 Mtetra
.46953 .43504 .47717 .4432 .49072 .43879 .48312 .43059 Mtetra
.48312 .43059 .49072 .43879 .50434 .43435 .49678 .42611 Mtetra
.49678 .42611 .50434 .43435 .51802 .4299 .51051 .42162 Mtetra
.51051 .42162 .51802 .4299 .53177 .42542 .52431 .4171 Mtetra
.52431 .4171 .53177 .42542 .54559 .42093 .53818 .41256 Mtetra
.53818 .41256 .54559 .42093 .55948 .4164 .55211 .408 Mtetra
.55211 .408 .55948 .4164 .57345 .41186 .56612 .40341 Mtetra
.56612 .40341 .57345 .41186 .58748 .40729 .5802 .3988 Mtetra
.5802 .3988 .58748 .40729 .60158 .4027 .59435 .39417 Mtetra
.59435 .39417 .60158 .4027 .61576 .39809 .60858 .38951 Mtetra
.60858 .38951 .61576 .39809 .63 .39345 .62287 .38483 Mtetra
.62287 .38483 .63 .39345 .64432 .38879 .63724 .38012 Mtetra
.63724 .38012 .64432 .38879 .65022 .18051 .65168 .3754 Mtetra
0 0 .312 r
.65168 .3754 .65022 .18051 .66374 .17561 .65717 .16651 Mtetra
.664 .741 .908 r
.65717 .16651 .66374 .17561 .67734 .17069 .6708 .16154 Mtetra
.6708 .16154 .67734 .17069 .69099 .16575 .68451 .15655 Mtetra
.68451 .15655 .69099 .16575 .70472 .16078 .69828 .15154 Mtetra
.69828 .15154 .70472 .16078 .7185 .15578 .71211 .1465 Mtetra
.71211 .1465 .7185 .15578 .73236 .15076 .72601 .14144 Mtetra
.72601 .14144 .73236 .15076 .74629 .14572 .73999 .13635 Mtetra
.73999 .13635 .74629 .14572 .76028 .14065 .75403 .13123 Mtetra
.75403 .13123 .76028 .14065 .77434 .13556 .76814 .12609 Mtetra
.65 .758 .928 r
.10867 .52187 .11734 .52911 .12915 .5252 .12051 .51792 Mtetra
.12051 .51792 .12915 .5252 .141 .52126 .1324 .51395 Mtetra
.1324 .51395 .141 .52126 .15292 .51731 .14434 .50997 Mtetra
.14434 .50997 .15292 .51731 .16489 .51334 .15635 .50597 Mtetra
.15635 .50597 .16489 .51334 .17691 .50936 .1684 .50194 Mtetra
.1684 .50194 .17691 .50936 .189 .50535 .18052 .4979 Mtetra
.18052 .4979 .189 .50535 .20113 .50132 .19269 .49384 Mtetra
.19269 .49384 .20113 .50132 .21333 .49728 .20492 .48976 Mtetra
.20492 .48976 .21333 .49728 .22558 .49322 .21721 .48566 Mtetra
.21721 .48566 .22558 .49322 .2379 .48913 .22955 .48154 Mtetra
.22955 .48154 .2379 .48913 .25027 .48503 .24196 .47741 Mtetra
.24196 .47741 .25027 .48503 .2627 .48091 .25442 .47325 Mtetra
.25442 .47325 .2627 .48091 .27518 .47677 .26695 .46907 Mtetra
.26695 .46907 .27518 .47677 .28773 .47261 .27953 .46487 Mtetra
.27953 .46487 .28773 .47261 .30034 .46843 .29217 .46066 Mtetra
.29217 .46066 .30034 .46843 .31301 .46423 .30488 .45642 Mtetra
.30488 .45642 .31301 .46423 .32574 .46 .31765 .45216 Mtetra
.31765 .45216 .32574 .46 .33853 .45576 .33048 .44788 Mtetra
.33048 .44788 .33853 .45576 .35138 .4515 .34337 .44358 Mtetra
.34337 .44358 .35138 .4515 .3643 .44722 .35632 .43926 Mtetra
.35632 .43926 .3643 .44722 .37728 .44291 .36934 .43491 Mtetra
.36934 .43491 .37728 .44291 .39032 .43859 .38242 .43055 Mtetra
.726 .243 0 r
.38242 .43055 .39032 .43859 .40258 .45696 .39466 .44893 Mtetra
.648 .76 .931 r
.39466 .44893 .40258 .45696 .41584 .45262 .40796 .44455 Mtetra
.40796 .44455 .41584 .45262 .42916 .44826 .42132 .44014 Mtetra
.42132 .44014 .42916 .44826 .44255 .44387 .43476 .43572 Mtetra
.43476 .43572 .44255 .44387 .45601 .43947 .44826 .43127 Mtetra
.44826 .43127 .45601 .43947 .46953 .43504 .46182 .4268 Mtetra
.46182 .4268 .46953 .43504 .48312 .43059 .47546 .42231 Mtetra
.47546 .42231 .48312 .43059 .49678 .42611 .48916 .4178 Mtetra
.48916 .4178 .49678 .42611 .51051 .42162 .50294 .41326 Mtetra
.50294 .41326 .51051 .42162 .52431 .4171 .51678 .4087 Mtetra
.51678 .4087 .52431 .4171 .53818 .41256 .53069 .40412 Mtetra
.53069 .40412 .53818 .41256 .55211 .408 .54468 .39951 Mtetra
.54468 .39951 .55211 .408 .56612 .40341 .55873 .39488 Mtetra
.55873 .39488 .56612 .40341 .5802 .3988 .57286 .39023 Mtetra
.57286 .39023 .5802 .3988 .59435 .39417 .58706 .38555 Mtetra
.58706 .38555 .59435 .39417 .60858 .38951 .60133 .38085 Mtetra
.60133 .38085 .60858 .38951 .62287 .38483 .61567 .37612 Mtetra
.61567 .37612 .62287 .38483 .63724 .38012 .63009 .37137 Mtetra
.63009 .37137 .63724 .38012 .65168 .3754 .64459 .3666 Mtetra
.64459 .3666 .65168 .3754 .65717 .16651 .65916 .3618 Mtetra
0 0 .312 r
.65916 .3618 .65717 .16651 .6708 .16154 .66421 .15231 Mtetra
.664 .741 .908 r
.66421 .15231 .6708 .16154 .68451 .15655 .67796 .14728 Mtetra
.67796 .14728 .68451 .15655 .69828 .15154 .69178 .14222 Mtetra
.69178 .14222 .69828 .15154 .71211 .1465 .70566 .13713 Mtetra
.70566 .13713 .71211 .1465 .72601 .14144 .71961 .13202 Mtetra
.71961 .13202 .72601 .14144 .73999 .13635 .73363 .12689 Mtetra
.73363 .12689 .73999 .13635 .75403 .13123 .74772 .12173 Mtetra
.74772 .12173 .75403 .13123 .76814 .12609 .76188 .11654 Mtetra
.65 .758 .928 r
.09993 .51457 .10867 .52187 .12051 .51792 .1118 .51058 Mtetra
.1118 .51058 .12051 .51792 .1324 .51395 .12372 .50658 Mtetra
.12372 .50658 .1324 .51395 .14434 .50997 .1357 .50256 Mtetra
.1357 .50256 .14434 .50997 .15635 .50597 .14773 .49853 Mtetra
.14773 .49853 .15635 .50597 .1684 .50194 .15982 .49447 Mtetra
.15982 .49447 .1684 .50194 .18052 .4979 .17197 .49039 Mtetra
.17197 .49039 .18052 .4979 .19269 .49384 .18417 .4863 Mtetra
.18417 .4863 .19269 .49384 .20492 .48976 .19643 .48218 Mtetra
.19643 .48218 .20492 .48976 .21721 .48566 .20876 .47804 Mtetra
.20876 .47804 .21721 .48566 .22955 .48154 .22114 .47389 Mtetra
.22114 .47389 .22955 .48154 .24196 .47741 .23358 .46972 Mtetra
.23358 .46972 .24196 .47741 .25442 .47325 .24607 .46552 Mtetra
.24607 .46552 .25442 .47325 .26695 .46907 .25863 .46131 Mtetra
.25863 .46131 .26695 .46907 .27953 .46487 .27125 .45707 Mtetra
.27125 .45707 .27953 .46487 .29217 .46066 .28393 .45281 Mtetra
.28393 .45281 .29217 .46066 .30488 .45642 .29668 .44854 Mtetra
.29668 .44854 .30488 .45642 .31765 .45216 .30948 .44424 Mtetra
.30948 .44424 .31765 .45216 .33048 .44788 .32235 .43992 Mtetra
.32235 .43992 .33048 .44788 .34337 .44358 .33528 .43558 Mtetra
.33528 .43558 .34337 .44358 .35632 .43926 .34827 .43122 Mtetra
.34827 .43122 .35632 .43926 .36934 .43491 .36133 .42684 Mtetra
.36133 .42684 .36934 .43491 .38242 .43055 .37445 .42244 Mtetra
.726 .243 0 r
.37445 .42244 .38242 .43055 .39466 .44893 .38667 .44082 Mtetra
.648 .76 .931 r
.38667 .44082 .39466 .44893 .40796 .44455 .40001 .4364 Mtetra
.40001 .4364 .40796 .44455 .42132 .44014 .41342 .43196 Mtetra
.41342 .43196 .42132 .44014 .43476 .43572 .42689 .42749 Mtetra
.42689 .42749 .43476 .43572 .44826 .43127 .44043 .423 Mtetra
.44043 .423 .44826 .43127 .46182 .4268 .45404 .41849 Mtetra
.45404 .41849 .46182 .4268 .47546 .42231 .46772 .41396 Mtetra
.46772 .41396 .47546 .42231 .48916 .4178 .48147 .4094 Mtetra
.48147 .4094 .48916 .4178 .50294 .41326 .49529 .40482 Mtetra
.49529 .40482 .50294 .41326 .51678 .4087 .50918 .40022 Mtetra
.50918 .40022 .51678 .4087 .53069 .40412 .52314 .3956 Mtetra
.52314 .3956 .53069 .40412 .54468 .39951 .53717 .39095 Mtetra
.53717 .39095 .54468 .39951 .55873 .39488 .55127 .38627 Mtetra
.55127 .38627 .55873 .39488 .57286 .39023 .56544 .38157 Mtetra
.56544 .38157 .57286 .39023 .58706 .38555 .57969 .37685 Mtetra
.57969 .37685 .58706 .38555 .60133 .38085 .59401 .37211 Mtetra
.59401 .37211 .60133 .38085 .61567 .37612 .60841 .36734 Mtetra
.60841 .36734 .61567 .37612 .63009 .37137 .62288 .36254 Mtetra
.62288 .36254 .63009 .37137 .64459 .3666 .63742 .35772 Mtetra
.63742 .35772 .64459 .3666 .65916 .3618 .65204 .35288 Mtetra
.65204 .35288 .65916 .3618 .66421 .15231 .66674 .348 Mtetra
.504 .258 .474 r
.66674 .348 .66421 .15231 .67796 .14728 .68151 .34311 Mtetra
0 0 .318 r
.68151 .34311 .67796 .14728 .69178 .14222 .68522 .13281 Mtetra
.664 .741 .908 r
.68522 .13281 .69178 .14222 .70566 .13713 .69915 .12768 Mtetra
.69915 .12768 .70566 .13713 .71961 .13202 .71315 .12252 Mtetra
.71315 .12252 .71961 .13202 .73363 .12689 .72722 .11734 Mtetra
.72722 .11734 .73363 .12689 .74772 .12173 .74135 .11213 Mtetra
.74135 .11213 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.65 .758 .928 r
.09112 .5072 .09993 .51457 .1118 .51058 .10301 .50318 Mtetra
.10301 .50318 .1118 .51058 .12372 .50658 .11496 .49915 Mtetra
.11496 .49915 .12372 .50658 .1357 .50256 .12697 .49509 Mtetra
.12697 .49509 .1357 .50256 .14773 .49853 .13904 .49102 Mtetra
.13904 .49102 .14773 .49853 .15982 .49447 .15116 .48693 Mtetra
.15116 .48693 .15982 .49447 .17197 .49039 .16334 .48281 Mtetra
.16334 .48281 .17197 .49039 .18417 .4863 .17558 .47868 Mtetra
.17558 .47868 .18417 .4863 .19643 .48218 .18787 .47453 Mtetra
.18787 .47453 .19643 .48218 .20876 .47804 .20023 .47036 Mtetra
.20023 .47036 .20876 .47804 .22114 .47389 .21264 .46617 Mtetra
.21264 .46617 .22114 .47389 .23358 .46972 .22512 .46196 Mtetra
.22512 .46196 .23358 .46972 .24607 .46552 .23765 .45772 Mtetra
.23765 .45772 .24607 .46552 .25863 .46131 .25025 .45347 Mtetra
.25025 .45347 .25863 .46131 .27125 .45707 .2629 .4492 Mtetra
.2629 .4492 .27125 .45707 .28393 .45281 .27562 .4449 Mtetra
.27562 .4449 .28393 .45281 .29668 .44854 .2884 .44059 Mtetra
.2884 .44059 .29668 .44854 .30948 .44424 .30124 .43625 Mtetra
.30124 .43625 .30948 .44424 .32235 .43992 .31415 .4319 Mtetra
.31415 .4319 .32235 .43992 .33528 .43558 .32711 .42752 Mtetra
.32711 .42752 .33528 .43558 .34827 .43122 .34015 .42312 Mtetra
.34015 .42312 .34827 .43122 .36133 .42684 .35324 .4187 Mtetra
.35324 .4187 .36133 .42684 .37445 .42244 .3664 .41425 Mtetra
.726 .243 0 r
.3664 .41425 .37445 .42244 .38667 .44082 .3786 .43264 Mtetra
.648 .76 .931 r
.3786 .43264 .38667 .44082 .40001 .4364 .39198 .42818 Mtetra
.39198 .42818 .40001 .4364 .41342 .43196 .40543 .4237 Mtetra
.40543 .4237 .41342 .43196 .42689 .42749 .41895 .41919 Mtetra
.41895 .41919 .42689 .42749 .44043 .423 .43254 .41466 Mtetra
.43254 .41466 .44043 .423 .45404 .41849 .44619 .41011 Mtetra
.44619 .41011 .45404 .41849 .46772 .41396 .45991 .40553 Mtetra
.45991 .40553 .46772 .41396 .48147 .4094 .47371 .40093 Mtetra
.47371 .40093 .48147 .4094 .49529 .40482 .48757 .39631 Mtetra
.48757 .39631 .49529 .40482 .50918 .40022 .5015 .39166 Mtetra
.5015 .39166 .50918 .40022 .52314 .3956 .51551 .38699 Mtetra
.51551 .38699 .52314 .3956 .53717 .39095 .52959 .3823 Mtetra
.52959 .3823 .53717 .39095 .55127 .38627 .54374 .37758 Mtetra
.54374 .37758 .55127 .38627 .56544 .38157 .55796 .37284 Mtetra
.55796 .37284 .56544 .38157 .57969 .37685 .57225 .36807 Mtetra
.57225 .36807 .57969 .37685 .59401 .37211 .58662 .36328 Mtetra
.58662 .36328 .59401 .37211 .60841 .36734 .60107 .35846 Mtetra
.60107 .35846 .60841 .36734 .62288 .36254 .61559 .35362 Mtetra
.61559 .35362 .62288 .36254 .63742 .35772 .63018 .34876 Mtetra
.63018 .34876 .63742 .35772 .65204 .35288 .64486 .34386 Mtetra
.64486 .34386 .65204 .35288 .66674 .348 .65961 .33895 Mtetra
.65961 .33895 .66674 .348 .68151 .34311 .67443 .334 Mtetra
.67443 .334 .68151 .34311 .68522 .13281 .68934 .32903 Mtetra
0 0 .318 r
.68934 .32903 .68522 .13281 .69915 .12768 .69258 .11814 Mtetra
.664 .741 .908 r
.69258 .11814 .69915 .12768 .71315 .12252 .70663 .11294 Mtetra
.70663 .11294 .71315 .12252 .72722 .11734 .72074 .10771 Mtetra
.72074 .10771 .72722 .11734 .74135 .11213 .73493 .10245 Mtetra
.73493 .10245 .74135 .11213 .75556 .1069 .74918 .09717 Mtetra
.65 .758 .928 r
.08222 .49977 .09112 .5072 .10301 .50318 .09415 .49572 Mtetra
.09415 .49572 .10301 .50318 .11496 .49915 .10613 .49165 Mtetra
.10613 .49165 .11496 .49915 .12697 .49509 .11817 .48756 Mtetra
.11817 .48756 .12697 .49509 .13904 .49102 .13027 .48345 Mtetra
.13027 .48345 .13904 .49102 .15116 .48693 .14242 .47932 Mtetra
.14242 .47932 .15116 .48693 .16334 .48281 .15464 .47517 Mtetra
.15464 .47517 .16334 .48281 .17558 .47868 .16691 .471 Mtetra
.16691 .471 .17558 .47868 .18787 .47453 .17924 .46681 Mtetra
.17924 .46681 .18787 .47453 .20023 .47036 .19163 .4626 Mtetra
.19163 .4626 .20023 .47036 .21264 .46617 .20408 .45838 Mtetra
.20408 .45838 .21264 .46617 .22512 .46196 .21659 .45413 Mtetra
.21659 .45413 .22512 .46196 .23765 .45772 .22916 .44986 Mtetra
.22916 .44986 .23765 .45772 .25025 .45347 .24179 .44557 Mtetra
.24179 .44557 .25025 .45347 .2629 .4492 .25448 .44125 Mtetra
.25448 .44125 .2629 .4492 .27562 .4449 .26723 .43692 Mtetra
.26723 .43692 .27562 .4449 .2884 .44059 .28005 .43257 Mtetra
.28005 .43257 .2884 .44059 .30124 .43625 .29293 .42819 Mtetra
.29293 .42819 .30124 .43625 .31415 .4319 .30587 .4238 Mtetra
.30587 .4238 .31415 .4319 .32711 .42752 .31888 .41938 Mtetra
.31888 .41938 .32711 .42752 .34015 .42312 .33195 .41494 Mtetra
.33195 .41494 .34015 .42312 .35324 .4187 .34508 .41047 Mtetra
.34508 .41047 .35324 .4187 .3664 .41425 .35828 .40599 Mtetra
.726 .243 0 r
.35828 .40599 .3664 .41425 .3786 .43264 .37046 .42439 Mtetra
.648 .76 .931 r
.37046 .42439 .3786 .43264 .39198 .42818 .38389 .41988 Mtetra
.38389 .41988 .39198 .42818 .40543 .4237 .39738 .41536 Mtetra
.39738 .41536 .40543 .4237 .41895 .41919 .41094 .41081 Mtetra
.41094 .41081 .41895 .41919 .43254 .41466 .42457 .40624 Mtetra
.42457 .40624 .43254 .41466 .44619 .41011 .43827 .40164 Mtetra
.43827 .40164 .44619 .41011 .45991 .40553 .45203 .39702 Mtetra
.45203 .39702 .45991 .40553 .47371 .40093 .46587 .39238 Mtetra
.46587 .39238 .47371 .40093 .48757 .39631 .47978 .38771 Mtetra
.47978 .38771 .48757 .39631 .5015 .39166 .49376 .38302 Mtetra
.49376 .38302 .5015 .39166 .51551 .38699 .50781 .37831 Mtetra
.50781 .37831 .51551 .38699 .52959 .3823 .52194 .37357 Mtetra
.52194 .37357 .52959 .3823 .54374 .37758 .53613 .36881 Mtetra
.53613 .36881 .54374 .37758 .55796 .37284 .5504 .36402 Mtetra
.5504 .36402 .55796 .37284 .57225 .36807 .56475 .35921 Mtetra
.56475 .35921 .57225 .36807 .58662 .36328 .57917 .35437 Mtetra
.57917 .35437 .58662 .36328 .60107 .35846 .59366 .34951 Mtetra
.59366 .34951 .60107 .35846 .61559 .35362 .60823 .34462 Mtetra
.60823 .34462 .61559 .35362 .63018 .34876 .62288 .3397 Mtetra
.62288 .3397 .63018 .34876 .64486 .34386 .6376 .33476 Mtetra
.6376 .33476 .64486 .34386 .65961 .33895 .65241 .3298 Mtetra
.65241 .3298 .65961 .33895 .67443 .334 .66729 .32481 Mtetra
.66729 .32481 .67443 .334 .68934 .32903 .68224 .31979 Mtetra
.68224 .31979 .68934 .32903 .69258 .11814 .69728 .31474 Mtetra
.5 .252 .469 r
.69728 .31474 .69258 .11814 .70663 .11294 .7124 .30967 Mtetra
0 0 .324 r
.7124 .30967 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.664 .741 .908 r
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.65 .758 .928 r
.07325 .49228 .08222 .49977 .09415 .49572 .08521 .48819 Mtetra
.08521 .48819 .09415 .49572 .10613 .49165 .09722 .48408 Mtetra
.09722 .48408 .10613 .49165 .11817 .48756 .1093 .47996 Mtetra
.1093 .47996 .11817 .48756 .13027 .48345 .12143 .47581 Mtetra
.12143 .47581 .13027 .48345 .14242 .47932 .13361 .47164 Mtetra
.13361 .47164 .14242 .47932 .15464 .47517 .14586 .46746 Mtetra
.14586 .46746 .15464 .47517 .16691 .471 .15816 .46325 Mtetra
.15816 .46325 .16691 .471 .17924 .46681 .17053 .45903 Mtetra
.17053 .45903 .17924 .46681 .19163 .4626 .18295 .45478 Mtetra
.18295 .45478 .19163 .4626 .20408 .45838 .19543 .45051 Mtetra
.19543 .45051 .20408 .45838 .21659 .45413 .20798 .44623 Mtetra
.20798 .44623 .21659 .45413 .22916 .44986 .22058 .44192 Mtetra
.22058 .44192 .22916 .44986 .24179 .44557 .23325 .43759 Mtetra
.23325 .43759 .24179 .44557 .25448 .44125 .24598 .43324 Mtetra
.24598 .43324 .25448 .44125 .26723 .43692 .25877 .42887 Mtetra
.25877 .42887 .26723 .43692 .28005 .43257 .27162 .42447 Mtetra
.27162 .42447 .28005 .43257 .29293 .42819 .28454 .42006 Mtetra
.28454 .42006 .29293 .42819 .30587 .4238 .29752 .41562 Mtetra
.29752 .41562 .30587 .4238 .31888 .41938 .31057 .41116 Mtetra
.31057 .41116 .31888 .41938 .33195 .41494 .32368 .40668 Mtetra
.32368 .40668 .33195 .41494 .34508 .41047 .33685 .40218 Mtetra
.33685 .40218 .34508 .41047 .35828 .40599 .35009 .39765 Mtetra
.35009 .39765 .35828 .40599 .37046 .42439 .3634 .3931 Mtetra
.118 .148 .617 r
.3634 .3931 .37046 .42439 .38389 .41988 .37571 .41151 Mtetra
.648 .76 .931 r
.37571 .41151 .38389 .41988 .39738 .41536 .38925 .40694 Mtetra
.38925 .40694 .39738 .41536 .41094 .41081 .40285 .40235 Mtetra
.40285 .40235 .41094 .41081 .42457 .40624 .41652 .39773 Mtetra
.41652 .39773 .42457 .40624 .43827 .40164 .43026 .39309 Mtetra
.43026 .39309 .43827 .40164 .45203 .39702 .44408 .38843 Mtetra
.44408 .38843 .45203 .39702 .46587 .39238 .45796 .38375 Mtetra
.45796 .38375 .46587 .39238 .47978 .38771 .47191 .37904 Mtetra
.47191 .37904 .47978 .38771 .49376 .38302 .48594 .3743 Mtetra
.48594 .3743 .49376 .38302 .50781 .37831 .50004 .36954 Mtetra
.50004 .36954 .50781 .37831 .52194 .37357 .51421 .36476 Mtetra
.51421 .36476 .52194 .37357 .53613 .36881 .52846 .35995 Mtetra
.52846 .35995 .53613 .36881 .5504 .36402 .54277 .35511 Mtetra
.54277 .35511 .5504 .36402 .56475 .35921 .55717 .35026 Mtetra
.55717 .35026 .56475 .35921 .57917 .35437 .57164 .34537 Mtetra
.57164 .34537 .57917 .35437 .59366 .34951 .58618 .34046 Mtetra
.58618 .34046 .59366 .34951 .60823 .34462 .6008 .33553 Mtetra
.6008 .33553 .60823 .34462 .62288 .3397 .6155 .33056 Mtetra
.6155 .33056 .62288 .3397 .6376 .33476 .63028 .32558 Mtetra
.63028 .32558 .6376 .33476 .65241 .3298 .64513 .32056 Mtetra
.64513 .32056 .65241 .3298 .66729 .32481 .66007 .31552 Mtetra
.66007 .31552 .66729 .32481 .68224 .31979 .67508 .31045 Mtetra
.67508 .31045 .68224 .31979 .69728 .31474 .69017 .30536 Mtetra
.69017 .30536 .69728 .31474 .7124 .30967 .70535 .30023 Mtetra
.70535 .30023 .7124 .30967 .71421 .09798 .7206 .29509 Mtetra
0 0 .324 r
.7206 .29509 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.664 .741 .908 r
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.65 .758 .928 r
.0642 .48471 .07325 .49228 .08521 .48819 .07619 .48059 Mtetra
.07619 .48059 .08521 .48819 .09722 .48408 .08824 .47645 Mtetra
.08824 .47645 .09722 .48408 .1093 .47996 .10034 .47229 Mtetra
.10034 .47229 .1093 .47996 .12143 .47581 .1125 .4681 Mtetra
.1125 .4681 .12143 .47581 .13361 .47164 .12472 .4639 Mtetra
.12472 .4639 .13361 .47164 .14586 .46746 .137 .45968 Mtetra
.137 .45968 .14586 .46746 .15816 .46325 .14934 .45544 Mtetra
.14934 .45544 .15816 .46325 .17053 .45903 .16174 .45117 Mtetra
.16174 .45117 .17053 .45903 .18295 .45478 .17419 .44689 Mtetra
.17419 .44689 .18295 .45478 .19543 .45051 .18671 .44258 Mtetra
.18671 .44258 .19543 .45051 .20798 .44623 .19929 .43826 Mtetra
.19929 .43826 .20798 .44623 .22058 .44192 .21193 .43391 Mtetra
.21193 .43391 .22058 .44192 .23325 .43759 .22464 .42954 Mtetra
.22464 .42954 .23325 .43759 .24598 .43324 .2374 .42515 Mtetra
.2374 .42515 .24598 .43324 .25877 .42887 .25023 .42074 Mtetra
.25023 .42074 .25877 .42887 .27162 .42447 .26312 .41631 Mtetra
.26312 .41631 .27162 .42447 .28454 .42006 .27607 .41185 Mtetra
.27607 .41185 .28454 .42006 .29752 .41562 .28909 .40737 Mtetra
.28909 .40737 .29752 .41562 .31057 .41116 .30218 .40287 Mtetra
.30218 .40287 .31057 .41116 .32368 .40668 .31533 .39835 Mtetra
.31533 .39835 .32368 .40668 .33685 .40218 .32854 .39381 Mtetra
.32854 .39381 .33685 .40218 .35009 .39765 .34182 .38924 Mtetra
.34182 .38924 .35009 .39765 .3634 .3931 .35517 .38465 Mtetra
.718 .234 0 r
.35517 .38465 .3634 .3931 .37571 .41151 .36746 .40306 Mtetra
.648 .76 .931 r
.36746 .40306 .37571 .41151 .38925 .40694 .38104 .39845 Mtetra
.38104 .39845 .38925 .40694 .40285 .40235 .39469 .39381 Mtetra
.39469 .39381 .40285 .40235 .41652 .39773 .4084 .38915 Mtetra
.4084 .38915 .41652 .39773 .43026 .39309 .42219 .38447 Mtetra
.42219 .38447 .43026 .39309 .44408 .38843 .43604 .37976 Mtetra
.43604 .37976 .44408 .38843 .45796 .38375 .44997 .37503 Mtetra
.44997 .37503 .45796 .38375 .47191 .37904 .46397 .37027 Mtetra
.46397 .37027 .47191 .37904 .48594 .3743 .47805 .36549 Mtetra
.47805 .36549 .48594 .3743 .50004 .36954 .49219 .36069 Mtetra
.49219 .36069 .50004 .36954 .51421 .36476 .50641 .35586 Mtetra
.50641 .35586 .51421 .36476 .52846 .35995 .5207 .35101 Mtetra
.5207 .35101 .52846 .35995 .54277 .35511 .53507 .34612 Mtetra
.53507 .34612 .54277 .35511 .55717 .35026 .54952 .34122 Mtetra
.54952 .34122 .55717 .35026 .57164 .34537 .56403 .33629 Mtetra
.56403 .33629 .57164 .34537 .58618 .34046 .57863 .33133 Mtetra
.57863 .33133 .58618 .34046 .6008 .33553 .5933 .32635 Mtetra
.5933 .32635 .6008 .33553 .6155 .33056 .60805 .32133 Mtetra
.60805 .32133 .6155 .33056 .63028 .32558 .62288 .3163 Mtetra
.62288 .3163 .63028 .32558 .64513 .32056 .63779 .31123 Mtetra
.63779 .31123 .64513 .32056 .66007 .31552 .65278 .30614 Mtetra
.65278 .30614 .66007 .31552 .67508 .31045 .66785 .30102 Mtetra
.66785 .30102 .67508 .31045 .69017 .30536 .683 .29588 Mtetra
.683 .29588 .69017 .30536 .70535 .30023 .69823 .29071 Mtetra
.69823 .29071 .70535 .30023 .7206 .29509 .71354 .2855 Mtetra
.71354 .2855 .7206 .29509 .7219 .08282 .72893 .28028 Mtetra
0 0 .324 r
.72893 .28028 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.65 .758 .928 r
.05507 .47709 .0642 .48471 .07619 .48059 .06709 .47293 Mtetra
.06709 .47293 .07619 .48059 .08824 .47645 .07917 .46875 Mtetra
.07917 .46875 .08824 .47645 .10034 .47229 .09131 .46455 Mtetra
.09131 .46455 .10034 .47229 .1125 .4681 .1035 .46033 Mtetra
.1035 .46033 .1125 .4681 .12472 .4639 .11575 .45609 Mtetra
.11575 .45609 .12472 .4639 .137 .45968 .12806 .45183 Mtetra
.12806 .45183 .137 .45968 .14934 .45544 .14044 .44755 Mtetra
.14044 .44755 .14934 .45544 .16174 .45117 .15287 .44325 Mtetra
.15287 .44325 .16174 .45117 .17419 .44689 .16536 .43892 Mtetra
.16536 .43892 .17419 .44689 .18671 .44258 .17791 .43458 Mtetra
.17791 .43458 .18671 .44258 .19929 .43826 .19053 .43021 Mtetra
.19053 .43021 .19929 .43826 .21193 .43391 .2032 .42583 Mtetra
.2032 .42583 .21193 .43391 .22464 .42954 .21594 .42142 Mtetra
.21594 .42142 .22464 .42954 .2374 .42515 .22874 .41699 Mtetra
.22874 .41699 .2374 .42515 .25023 .42074 .24161 .41254 Mtetra
.24161 .41254 .25023 .42074 .26312 .41631 .25454 .40806 Mtetra
.25454 .40806 .26312 .41631 .27607 .41185 .26753 .40357 Mtetra
.26753 .40357 .27607 .41185 .28909 .40737 .28059 .39905 Mtetra
.28059 .39905 .28909 .40737 .30218 .40287 .29371 .39451 Mtetra
.29371 .39451 .30218 .40287 .31533 .39835 .3069 .38994 Mtetra
.3069 .38994 .31533 .39835 .32854 .39381 .32016 .38536 Mtetra
.32016 .38536 .32854 .39381 .34182 .38924 .33348 .38075 Mtetra
.33348 .38075 .34182 .38924 .35517 .38465 .34687 .37611 Mtetra
.718 .234 0 r
.34687 .37611 .35517 .38465 .36746 .40306 .35914 .39452 Mtetra
.648 .76 .931 r
.35914 .39452 .36746 .40306 .38104 .39845 .37275 .38987 Mtetra
.37275 .38987 .38104 .39845 .39469 .39381 .38644 .38519 Mtetra
.38644 .38519 .39469 .39381 .4084 .38915 .4002 .38049 Mtetra
.4002 .38049 .4084 .38915 .42219 .38447 .41403 .37576 Mtetra
.41403 .37576 .42219 .38447 .43604 .37976 .42794 .37101 Mtetra
.42794 .37101 .43604 .37976 .44997 .37503 .44191 .36623 Mtetra
.44191 .36623 .44997 .37503 .46397 .37027 .45596 .36143 Mtetra
.45596 .36143 .46397 .37027 .47805 .36549 .47008 .3566 Mtetra
.47008 .3566 .47805 .36549 .49219 .36069 .48427 .35175 Mtetra
.48427 .35175 .49219 .36069 .50641 .35586 .49854 .34688 Mtetra
.49854 .34688 .50641 .35586 .5207 .35101 .51288 .34198 Mtetra
.51288 .34198 .5207 .35101 .53507 .34612 .5273 .33705 Mtetra
.5273 .33705 .53507 .34612 .54952 .34122 .54179 .33209 Mtetra
.54179 .33209 .54952 .34122 .56403 .33629 .55636 .32711 Mtetra
.55636 .32711 .56403 .33629 .57863 .33133 .571 .32211 Mtetra
.571 .32211 .57863 .33133 .5933 .32635 .58573 .31707 Mtetra
.58573 .31707 .5933 .32635 .60805 .32133 .60053 .31201 Mtetra
.60053 .31201 .60805 .32133 .62288 .3163 .61541 .30693 Mtetra
.61541 .30693 .62288 .3163 .63779 .31123 .63038 .30181 Mtetra
.63038 .30181 .63779 .31123 .65278 .30614 .64542 .29667 Mtetra
.64542 .29667 .65278 .30614 .66785 .30102 .66054 .2915 Mtetra
.66054 .2915 .66785 .30102 .683 .29588 .67575 .28631 Mtetra
.67575 .28631 .683 .29588 .69823 .29071 .69103 .28108 Mtetra
.69103 .28108 .69823 .29071 .71354 .2855 .7064 .27583 Mtetra
.7064 .27583 .71354 .2855 .72893 .28028 .72186 .27055 Mtetra
.72186 .27055 .72893 .28028 .7297 .06743 .73739 .26524 Mtetra
.65 .758 .928 r
.04586 .46939 .05507 .47709 .06709 .47293 .05791 .4652 Mtetra
.05791 .4652 .06709 .47293 .07917 .46875 .07002 .46098 Mtetra
.07002 .46098 .07917 .46875 .09131 .46455 .08219 .45674 Mtetra
.08219 .45674 .09131 .46455 .1035 .46033 .09442 .45249 Mtetra
.09442 .45249 .1035 .46033 .11575 .45609 .1067 .44821 Mtetra
.1067 .44821 .11575 .45609 .12806 .45183 .11905 .44391 Mtetra
.11905 .44391 .12806 .45183 .14044 .44755 .13145 .43959 Mtetra
.13145 .43959 .14044 .44755 .15287 .44325 .14392 .43525 Mtetra
.14392 .43525 .15287 .44325 .16536 .43892 .15644 .43089 Mtetra
.15644 .43089 .16536 .43892 .17791 .43458 .16903 .4265 Mtetra
.16903 .4265 .17791 .43458 .19053 .43021 .18168 .4221 Mtetra
.18168 .4221 .19053 .43021 .2032 .42583 .1944 .41767 Mtetra
.1944 .41767 .2032 .42583 .21594 .42142 .20717 .41322 Mtetra
.20717 .41322 .21594 .42142 .22874 .41699 .22001 .40875 Mtetra
.22001 .40875 .22874 .41699 .24161 .41254 .23291 .40426 Mtetra
.23291 .40426 .24161 .41254 .25454 .40806 .24588 .39974 Mtetra
.24588 .39974 .25454 .40806 .26753 .40357 .25891 .39521 Mtetra
.25891 .39521 .26753 .40357 .28059 .39905 .27201 .39065 Mtetra
.27201 .39065 .28059 .39905 .29371 .39451 .28517 .38606 Mtetra
.28517 .38606 .29371 .39451 .3069 .38994 .2984 .38146 Mtetra
.2984 .38146 .3069 .38994 .32016 .38536 .31169 .37683 Mtetra
.31169 .37683 .32016 .38536 .33348 .38075 .32506 .37217 Mtetra
.32506 .37217 .33348 .38075 .34687 .37611 .33849 .3675 Mtetra
.718 .234 0 r
.33849 .3675 .34687 .37611 .35914 .39452 .35073 .38591 Mtetra
.648 .76 .931 r
.35073 .38591 .35914 .39452 .37275 .38987 .36439 .38121 Mtetra
.36439 .38121 .37275 .38987 .38644 .38519 .37812 .37649 Mtetra
.37812 .37649 .38644 .38519 .4002 .38049 .39193 .37174 Mtetra
.39193 .37174 .4002 .38049 .41403 .37576 .4058 .36697 Mtetra
.4058 .36697 .41403 .37576 .42794 .37101 .41975 .36217 Mtetra
.41975 .36217 .42794 .37101 .44191 .36623 .43377 .35735 Mtetra
.43377 .35735 .44191 .36623 .45596 .36143 .44786 .3525 Mtetra
.44786 .3525 .45596 .36143 .47008 .3566 .46203 .34763 Mtetra
.46203 .34763 .47008 .3566 .48427 .35175 .47627 .34273 Mtetra
.47627 .34273 .48427 .35175 .49854 .34688 .49058 .33781 Mtetra
.49058 .33781 .49854 .34688 .51288 .34198 .50498 .33286 Mtetra
.50498 .33286 .51288 .34198 .5273 .33705 .51944 .32788 Mtetra
.51944 .32788 .5273 .33705 .54179 .33209 .53399 .32288 Mtetra
.53399 .32288 .54179 .33209 .55636 .32711 .54861 .31785 Mtetra
.54861 .31785 .55636 .32711 .571 .32211 .5633 .31279 Mtetra
.5633 .31279 .571 .32211 .58573 .31707 .57808 .30771 Mtetra
.57808 .30771 .58573 .31707 .60053 .31201 .59294 .3026 Mtetra
.59294 .3026 .60053 .31201 .61541 .30693 .60787 .29747 Mtetra
.60787 .29747 .61541 .30693 .63038 .30181 .62289 .2923 Mtetra
.62289 .2923 .63038 .30181 .64542 .29667 .63798 .28711 Mtetra
.63798 .28711 .64542 .29667 .66054 .2915 .65316 .28189 Mtetra
.65316 .28189 .66054 .2915 .67575 .28631 .66842 .27664 Mtetra
.66842 .27664 .67575 .28631 .69103 .28108 .68377 .27136 Mtetra
.68377 .27136 .69103 .28108 .7064 .27583 .69919 .26605 Mtetra
.69919 .26605 .7064 .27583 .72186 .27055 .71471 .26072 Mtetra
.71471 .26072 .72186 .27055 .73739 .26524 .7303 .25535 Mtetra
.65 .758 .928 r
.03657 .46163 .04586 .46939 .05791 .4652 .04865 .4574 Mtetra
.04865 .4574 .05791 .4652 .07002 .46098 .06079 .45314 Mtetra
.06079 .45314 .07002 .46098 .08219 .45674 .07299 .44887 Mtetra
.07299 .44887 .08219 .45674 .09442 .45249 .08525 .44457 Mtetra
.08525 .44457 .09442 .45249 .1067 .44821 .09757 .44026 Mtetra
.09757 .44026 .1067 .44821 .11905 .44391 .10995 .43592 Mtetra
.10995 .43592 .11905 .44391 .13145 .43959 .12239 .43156 Mtetra
.12239 .43156 .13145 .43959 .14392 .43525 .13489 .42718 Mtetra
.13489 .42718 .14392 .43525 .15644 .43089 .14745 .42278 Mtetra
.14745 .42278 .15644 .43089 .16903 .4265 .16007 .41835 Mtetra
.16007 .41835 .16903 .4265 .18168 .4221 .17276 .41391 Mtetra
.17276 .41391 .18168 .4221 .1944 .41767 .18551 .40944 Mtetra
.18551 .40944 .1944 .41767 .20717 .41322 .19832 .40495 Mtetra
.19832 .40495 .20717 .41322 .22001 .40875 .21119 .40044 Mtetra
.21119 .40044 .22001 .40875 .23291 .40426 .22413 .39591 Mtetra
.22413 .39591 .23291 .40426 .24588 .39974 .23714 .39135 Mtetra
.23714 .39135 .24588 .39974 .25891 .39521 .25021 .38677 Mtetra
.25021 .38677 .25891 .39521 .27201 .39065 .26334 .38217 Mtetra
.26334 .38217 .27201 .39065 .28517 .38606 .27655 .37754 Mtetra
.27655 .37754 .28517 .38606 .2984 .38146 .28981 .37289 Mtetra
.28981 .37289 .2984 .38146 .31169 .37683 .30315 .36822 Mtetra
.30315 .36822 .31169 .37683 .32506 .37217 .31655 .36352 Mtetra
.31655 .36352 .32506 .37217 .33849 .3675 .33002 .3588 Mtetra
.718 .234 0 r
.33002 .3588 .33849 .3675 .35073 .38591 .34224 .37722 Mtetra
.648 .76 .931 r
.34224 .37722 .35073 .38591 .36439 .38121 .35595 .37247 Mtetra
.35595 .37247 .36439 .38121 .37812 .37649 .36973 .3677 Mtetra
.36973 .3677 .37812 .37649 .39193 .37174 .38357 .36291 Mtetra
.38357 .36291 .39193 .37174 .4058 .36697 .39749 .35809 Mtetra
.39749 .35809 .4058 .36697 .41975 .36217 .41149 .35325 Mtetra
.41149 .35325 .41975 .36217 .43377 .35735 .42555 .34838 Mtetra
.42555 .34838 .43377 .35735 .44786 .3525 .43969 .34349 Mtetra
.43969 .34349 .44786 .3525 .46203 .34763 .4539 .33857 Mtetra
.4539 .33857 .46203 .34763 .47627 .34273 .46819 .33362 Mtetra
.46819 .33362 .47627 .34273 .49058 .33781 .48256 .32865 Mtetra
.48256 .32865 .49058 .33781 .50498 .33286 .497 .32365 Mtetra
.497 .32365 .50498 .33286 .51944 .32788 .51151 .31863 Mtetra
.51151 .31863 .51944 .32788 .53399 .32288 .52611 .31357 Mtetra
.52611 .31357 .53399 .32288 .54861 .31785 .54078 .3085 Mtetra
.54078 .3085 .54861 .31785 .5633 .31279 .55553 .30339 Mtetra
.55553 .30339 .5633 .31279 .57808 .30771 .57036 .29826 Mtetra
.57036 .29826 .57808 .30771 .59294 .3026 .58526 .2931 Mtetra
.58526 .2931 .59294 .3026 .60787 .29747 .60025 .28791 Mtetra
.60025 .28791 .60787 .29747 .62289 .2923 .61532 .28269 Mtetra
.61532 .28269 .62289 .2923 .63798 .28711 .63048 .27745 Mtetra
.63048 .27745 .63798 .28711 .65316 .28189 .64571 .27217 Mtetra
.64571 .27217 .65316 .28189 .66842 .27664 .66103 .26687 Mtetra
.66103 .26687 .66842 .27664 .68377 .27136 .67643 .26154 Mtetra
.67643 .26154 .68377 .27136 .69919 .26605 .69191 .25618 Mtetra
.69191 .25618 .69919 .26605 .71471 .26072 .70748 .25079 Mtetra
.70748 .25079 .71471 .26072 .7303 .25535 .72314 .24537 Mtetra
.65 .758 .928 r
.0272 .4538 .03657 .46163 .04865 .4574 .03931 .44953 Mtetra
.03931 .44953 .04865 .4574 .06079 .45314 .05148 .44523 Mtetra
.05148 .44523 .06079 .45314 .07299 .44887 .06371 .44092 Mtetra
.06371 .44092 .07299 .44887 .08525 .44457 .076 .43659 Mtetra
.076 .43659 .08525 .44457 .09757 .44026 .08836 .43223 Mtetra
.08836 .43223 .09757 .44026 .10995 .43592 .10077 .42785 Mtetra
.10077 .42785 .10995 .43592 .12239 .43156 .11324 .42346 Mtetra
.11324 .42346 .12239 .43156 .13489 .42718 .12578 .41904 Mtetra
.12578 .41904 .13489 .42718 .14745 .42278 .13837 .41459 Mtetra
.13837 .41459 .14745 .42278 .16007 .41835 .15103 .41013 Mtetra
.15103 .41013 .16007 .41835 .17276 .41391 .16375 .40564 Mtetra
.16375 .40564 .17276 .41391 .18551 .40944 .17654 .40114 Mtetra
.17654 .40114 .18551 .40944 .19832 .40495 .18938 .39661 Mtetra
.18938 .39661 .19832 .40495 .21119 .40044 .2023 .39205 Mtetra
.2023 .39205 .21119 .40044 .22413 .39591 .21527 .38748 Mtetra
.21527 .38748 .22413 .39591 .23714 .39135 .22832 .38288 Mtetra
.22832 .38288 .23714 .39135 .25021 .38677 .24143 .37825 Mtetra
.24143 .37825 .25021 .38677 .26334 .38217 .2546 .37361 Mtetra
.2546 .37361 .26334 .38217 .27655 .37754 .26784 .36894 Mtetra
.26784 .36894 .27655 .37754 .28981 .37289 .28115 .36425 Mtetra
.28115 .36425 .28981 .37289 .30315 .36822 .29453 .35953 Mtetra
.29453 .35953 .30315 .36822 .31655 .36352 .30797 .35479 Mtetra
.30797 .35479 .31655 .36352 .33002 .3588 .32148 .35002 Mtetra
.718 .234 0 r
.32148 .35002 .33002 .3588 .34224 .37722 .33368 .36844 Mtetra
.648 .76 .931 r
.33368 .36844 .34224 .37722 .35595 .37247 .34743 .36365 Mtetra
.34743 .36365 .35595 .37247 .36973 .3677 .36125 .35884 Mtetra
.36125 .35884 .36973 .3677 .38357 .36291 .37514 .354 Mtetra
.37514 .354 .38357 .36291 .39749 .35809 .3891 .34913 Mtetra
.3891 .34913 .39749 .35809 .41149 .35325 .40314 .34424 Mtetra
.40314 .34424 .41149 .35325 .42555 .34838 .41725 .33932 Mtetra
.41725 .33932 .42555 .34838 .43969 .34349 .43144 .33438 Mtetra
.43144 .33438 .43969 .34349 .4539 .33857 .4457 .32942 Mtetra
.4457 .32942 .4539 .33857 .46819 .33362 .46004 .32442 Mtetra
.46004 .32442 .46819 .33362 .48256 .32865 .47445 .3194 Mtetra
.47445 .3194 .48256 .32865 .497 .32365 .48894 .31435 Mtetra
.48894 .31435 .497 .32365 .51151 .31863 .5035 .30928 Mtetra
.5035 .30928 .51151 .31863 .52611 .31357 .51815 .30418 Mtetra
.51815 .30418 .52611 .31357 .54078 .3085 .53287 .29905 Mtetra
.53287 .29905 .54078 .3085 .55553 .30339 .54767 .29389 Mtetra
.54767 .29389 .55553 .30339 .57036 .29826 .56255 .28871 Mtetra
.56255 .28871 .57036 .29826 .58526 .2931 .57752 .2835 Mtetra
.57752 .2835 .58526 .2931 .60025 .28791 .59256 .27826 Mtetra
.59256 .27826 .60025 .28791 .61532 .28269 .60768 .27299 Mtetra
.60768 .27299 .61532 .28269 .63048 .27745 .62289 .26769 Mtetra
.62289 .26769 .63048 .27745 .64571 .27217 .63818 .26236 Mtetra
.63818 .26236 .64571 .27217 .66103 .26687 .65356 .25701 Mtetra
.65356 .25701 .66103 .26687 .67643 .26154 .66901 .25162 Mtetra
.66901 .25162 .67643 .26154 .69191 .25618 .68456 .24621 Mtetra
.68456 .24621 .69191 .25618 .70748 .25079 .70019 .24076 Mtetra
.70019 .24076 .70748 .25079 .72314 .24537 .7159 .23529 Mtetra
.65 .758 .928 r
.01774 .4459 .0272 .4538 .03931 .44953 .02988 .44159 Mtetra
.02988 .44159 .03931 .44953 .05148 .44523 .04209 .43725 Mtetra
.04209 .43725 .05148 .44523 .06371 .44092 .05435 .4329 Mtetra
.05435 .4329 .06371 .44092 .076 .43659 .06667 .42853 Mtetra
.06667 .42853 .076 .43659 .08836 .43223 .07906 .42413 Mtetra
.07906 .42413 .08836 .43223 .10077 .42785 .0915 .41972 Mtetra
.0915 .41972 .10077 .42785 .11324 .42346 .10401 .41528 Mtetra
.10401 .41528 .11324 .42346 .12578 .41904 .11658 .41082 Mtetra
.11658 .41082 .12578 .41904 .13837 .41459 .12921 .40634 Mtetra
.12921 .40634 .13837 .41459 .15103 .41013 .1419 .40183 Mtetra
.1419 .40183 .15103 .41013 .16375 .40564 .15466 .3973 Mtetra
.15466 .3973 .16375 .40564 .17654 .40114 .16748 .39275 Mtetra
.16748 .39275 .17654 .40114 .18938 .39661 .18037 .38818 Mtetra
.18037 .38818 .18938 .39661 .2023 .39205 .19332 .38359 Mtetra
.19332 .38359 .2023 .39205 .21527 .38748 .20633 .37897 Mtetra
.20633 .37897 .21527 .38748 .22832 .38288 .21941 .37432 Mtetra
.21941 .37432 .22832 .38288 .24143 .37825 .23256 .36966 Mtetra
.23256 .36966 .24143 .37825 .2546 .37361 .24577 .36497 Mtetra
.24577 .36497 .2546 .37361 .26784 .36894 .25906 .36026 Mtetra
.25906 .36026 .26784 .36894 .28115 .36425 .2724 .35552 Mtetra
.2724 .35552 .28115 .36425 .29453 .35953 .28582 .35076 Mtetra
.28582 .35076 .29453 .35953 .30797 .35479 .29931 .34597 Mtetra
.29931 .34597 .30797 .35479 .32148 .35002 .31286 .34116 Mtetra
.718 .234 0 r
.31286 .34116 .32148 .35002 .33368 .36844 .32503 .35958 Mtetra
.648 .76 .931 r
.32503 .35958 .33368 .36844 .34743 .36365 .33882 .35474 Mtetra
.33882 .35474 .34743 .36365 .36125 .35884 .35268 .34988 Mtetra
.35268 .34988 .36125 .35884 .37514 .354 .36662 .34499 Mtetra
.36662 .34499 .37514 .354 .3891 .34913 .38063 .34008 Mtetra
.38063 .34008 .3891 .34913 .40314 .34424 .39472 .33515 Mtetra
.39472 .33515 .40314 .34424 .41725 .33932 .40887 .33018 Mtetra
.40887 .33018 .41725 .33932 .43144 .33438 .42311 .32519 Mtetra
.42311 .32519 .43144 .33438 .4457 .32942 .43742 .32017 Mtetra
.43742 .32017 .4457 .32942 .46004 .32442 .4518 .31513 Mtetra
.4518 .31513 .46004 .32442 .47445 .3194 .46626 .31006 Mtetra
.46626 .31006 .47445 .3194 .48894 .31435 .4808 .30496 Mtetra
.4808 .30496 .48894 .31435 .5035 .30928 .49542 .29984 Mtetra
.49542 .29984 .5035 .30928 .51815 .30418 .51011 .29469 Mtetra
.51011 .29469 .51815 .30418 .53287 .29905 .52489 .28951 Mtetra
.52489 .28951 .53287 .29905 .54767 .29389 .53974 .2843 Mtetra
.53974 .2843 .54767 .29389 .56255 .28871 .55468 .27906 Mtetra
.55468 .27906 .56255 .28871 .57752 .2835 .56969 .2738 Mtetra
.56969 .2738 .57752 .2835 .59256 .27826 .58479 .26851 Mtetra
.58479 .26851 .59256 .27826 .60768 .27299 .59997 .26318 Mtetra
.59997 .26318 .60768 .27299 .62289 .26769 .61523 .25783 Mtetra
.61523 .25783 .62289 .26769 .63818 .26236 .63058 .25245 Mtetra
.63058 .25245 .63818 .26236 .65356 .25701 .64601 .24704 Mtetra
.64601 .24704 .65356 .25701 .66901 .25162 .66153 .2416 Mtetra
.66153 .2416 .66901 .25162 .68456 .24621 .67713 .23613 Mtetra
.67713 .23613 .68456 .24621 .70019 .24076 .69282 .23063 Mtetra
.69282 .23063 .70019 .24076 .7159 .23529 .70859 .2251 Mtetra
.65 .758 .928 r
.00819 .43792 .01774 .4459 .02988 .44159 .02037 .43357 Mtetra
.02037 .43357 .02988 .44159 .04209 .43725 .03261 .4292 Mtetra
.03261 .4292 .04209 .43725 .05435 .4329 .0449 .42481 Mtetra
.0449 .42481 .05435 .4329 .06667 .42853 .05726 .4204 Mtetra
.05726 .4204 .06667 .42853 .07906 .42413 .06968 .41596 Mtetra
.06968 .41596 .07906 .42413 .0915 .41972 .08216 .41151 Mtetra
.08216 .41151 .0915 .41972 .10401 .41528 .0947 .40703 Mtetra
.0947 .40703 .10401 .41528 .11658 .41082 .1073 .40253 Mtetra
.1073 .40253 .11658 .41082 .12921 .40634 .11997 .398 Mtetra
.11997 .398 .12921 .40634 .1419 .40183 .13269 .39346 Mtetra
.13269 .39346 .1419 .40183 .15466 .3973 .14549 .38889 Mtetra
.14549 .38889 .15466 .3973 .16748 .39275 .15835 .38429 Mtetra
.15835 .38429 .16748 .39275 .18037 .38818 .17127 .37968 Mtetra
.17127 .37968 .18037 .38818 .19332 .38359 .18425 .37504 Mtetra
.18425 .37504 .19332 .38359 .20633 .37897 .19731 .37038 Mtetra
.19731 .37038 .20633 .37897 .21941 .37432 .21043 .36569 Mtetra
.21043 .36569 .21941 .37432 .23256 .36966 .22361 .36098 Mtetra
.22361 .36098 .23256 .36966 .24577 .36497 .23687 .35625 Mtetra
.23687 .35625 .24577 .36497 .25906 .36026 .25019 .35149 Mtetra
.25019 .35149 .25906 .36026 .2724 .35552 .26358 .34671 Mtetra
.26358 .34671 .2724 .35552 .28582 .35076 .27703 .3419 Mtetra
.27703 .3419 .28582 .35076 .29931 .34597 .29056 .33707 Mtetra
.29056 .33707 .29931 .34597 .31286 .34116 .30416 .33221 Mtetra
.718 .234 0 r
.30416 .33221 .31286 .34116 .32503 .35958 .3163 .35063 Mtetra
.648 .76 .931 r
.3163 .35063 .32503 .35958 .33882 .35474 .33013 .34575 Mtetra
.33013 .34575 .33882 .35474 .35268 .34988 .34404 .34084 Mtetra
.34404 .34084 .35268 .34988 .36662 .34499 .35802 .33591 Mtetra
.35802 .33591 .36662 .34499 .38063 .34008 .37208 .33095 Mtetra
.37208 .33095 .38063 .34008 .39472 .33515 .38621 .32596 Mtetra
.38621 .32596 .39472 .33515 .40887 .33018 .40041 .32095 Mtetra
.40041 .32095 .40887 .33018 .42311 .32519 .41469 .31591 Mtetra
.41469 .31591 .42311 .32519 .43742 .32017 .42905 .31084 Mtetra
.42905 .31084 .43742 .32017 .4518 .31513 .44348 .30575 Mtetra
.44348 .30575 .4518 .31513 .46626 .31006 .45799 .30063 Mtetra
.45799 .30063 .46626 .31006 .4808 .30496 .47258 .29548 Mtetra
.47258 .29548 .4808 .30496 .49542 .29984 .48725 .29031 Mtetra
.48725 .29031 .49542 .29984 .51011 .29469 .502 .2851 Mtetra
.502 .2851 .51011 .29469 .52489 .28951 .51682 .27987 Mtetra
.51682 .27987 .52489 .28951 .53974 .2843 .53173 .27461 Mtetra
.53173 .27461 .53974 .2843 .55468 .27906 .54672 .26932 Mtetra
.54672 .26932 .55468 .27906 .56969 .2738 .56179 .26401 Mtetra
.56179 .26401 .56969 .2738 .58479 .26851 .57694 .25866 Mtetra
.57694 .25866 .58479 .26851 .59997 .26318 .59217 .25328 Mtetra
.59217 .25328 .59997 .26318 .61523 .25783 .60749 .24788 Mtetra
.60749 .24788 .61523 .25783 .63058 .25245 .6229 .24244 Mtetra
.6229 .24244 .63058 .25245 .64601 .24704 .63838 .23698 Mtetra
.63838 .23698 .64601 .24704 .66153 .2416 .65396 .23148 Mtetra
.65396 .23148 .66153 .2416 .67713 .23613 .66962 .22595 Mtetra
.66962 .22595 .67713 .23613 .69282 .23063 .68537 .2204 Mtetra
.68537 .2204 .69282 .23063 .70859 .2251 .70121 .21481 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 154.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000VR000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00QOooool2o`000<Cooooo0_l0
0013ooooo`00P_ooool3o`000003ooooool0003ooooo0<3ooooo0ol000000ooooooo0000ooooo`12
ooooo`00P?ooool2o`0000Cooooo0_l0002nooooo`;o00001?ooool2o`0004;ooooo001mooooo`?o
00001_ooool00ol0003oooooo`00002jooooo`?o00001_ooool00ol0003oooooo`000011ooooo`00
N_ooool3o`0000Wooooo00?o0000ooooool00000^?ooool2o`0000Wooooo00?o0000ooooool00000
@Oooool007Sooooo0_l0000<ooooo`04o`000?ooooooooooo`000;Cooooo0ol0000;ooooo`04o`00
0?ooooooooooo`00043ooooo001eooooo`?o00003_ooool01Ol0003ooooooooooooooooo00000;3o
oooo0ol0000>ooooo`05o`000?ooooooooooooooool00000?oooool007?ooooo0_l0000@ooooo`03
ojVnjOl0003ooooo00;ooooo00?o0000ooooooooool0[?ooool2o`00017ooooo00Go0000oooooooo
ooooooooo`00000oooooo`00L?ooool3o`00013ooooo0onY_^T00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo0:Sooooo0ol0000Dooooo`05o`000?ooooooooooooooool00000?_ooool006ko
oooo0_l0000@ooooo`KoZKkY00?o0000ojVnjOooool00oooool00ol0003oooooooooo`2Uooooo`;o
00005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo001[ooooo`?o0000
3oooool9ojVnj@03o`000?nY_^WoZKkY00?ooooo00?o0000ooooooooool0X_ooool3o`0001Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`00J?ooool3o`00013ooooo2onY
_^T00ol0003oZKkYojVnj@04ooooo`03o`000?oooooooooo09oooooo0_l0000Looooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0>_ooool006Kooooo0_l0000@ooooo`ooZKkY00?o0000
ojVnjOnY_^T00oooool00ol0003oooooooooo`2Looooo`?o00007_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03Wooooo001Sooooo`?o00003ooooolBojVnj@03o`000?nY_^WoZKkY
00Cooooo00?o0000ooooooooool0VOooool2o`00027ooooo00?o0000ooooooooool00oooool00ol0
05;o0000ooooo`0jooooo`00HOooool2o`00013ooooo5?nY_^T01?l0003oZKkYojVnjOnY_^T4oooo
o`03o`000?oooooooooo09Gooooo0ol0000Sooooo`03o`000?oooooooooo00?ooooo0_l005800ol0
003oooooooooo`0hooooo`00G_ooool3o`0000oooooo5onY_^T00ol0003oZKkYojVnj@02ojVnj@?o
oooo00?o0000ooooooooool0Toooool2o`0002Kooooo00?o0000ooooooooool00oooool01?l005;o
ZKgXojVmj?l0000iooooo`00G?ooool2o`00013ooooo6OnY_^T00ol0003oZKkYojVnj@02ojVnj@Co
oooo00?o0000ooooooooool0Soooool3o`0002Sooooo00?o0000ooooooooool00_ooool01Ol005;o
ZKgXojVmj?nY_NSo000003Wooooo001Iooooo`?o00003ooooolLojVnj@03o`000?nY_^WoZKkY00;o
ZKkY1Oooool00ol0003oooooooooo`2;ooooo`?o0000:oooool00ol0003oooooooooo`02ooooo`03
o`00D_nY_NSoZKgX00;oZKgX00?o0000ooooooooool0=_ooool005Oooooo0_l0000?oooooaooZKkY
00?o0000ojVnjOnY_^T00_nY_^T5ooooo`03o`000?oooooooooo08Wooooo0_l0000^ooooo`04o`00
0?ooooooooooooooo`;o001B1?nY_NP00ooooooo0000ooooo`0fooooo`00E?ooool3o`0000oooooo
8OnY_^T00ol0003oZKkYojVnj@02ojVnj@Kooooo00?o0000ooooooooool0QOooool3o`00033ooooo
00Co0000oooooooooooooooo0_l00585ojVmj003o`000?oooooooooo03Gooooo001Aooooo`?o0000
3ooooolTojVnj@03o`000?nY_^WoZKkY00;oZKkY1oooool00ol0003oooooooooo`22ooooo`;o0000
<oooool01?l0003oooooooooooooool2o`00DPGoZKgX00?oooooo`000?ooool0=Oooool004oooooo
0_l0000@ooooobKoZKkY00?o0000ojVnjOnY_^T00onY_^T6ooooo`03o`000?oooooooooo07oooooo
0ol0000eooooo`03o`000?mo@7So001B00?o001B1_nY_NP00ooooooo0000ooooo`0dooooo`00C?oo
ool3o`0000oooooo:OnY_^T00ol0003oZKkYojVnj@03ojVnj@Oooooo00?o0000ooooooooool0O?oo
ool2o`0003Sooooo00?o0000ogm0N?l005800ol005800onU`^koZKgXojVmj004ojVmj003o`000?oo
oooooooo03?ooooo001:ooooo`;o00004?ooool[ojVnj@06o`000?nY_^WoZKkYojVnjOl006coZKkY
2?ooool00ol0003oooooooooo`1hooooo`?o0000>_ooool00omo@7So0000o`00DP03o`00DP03ojG2
k_nY_NSoZKgX00GoZKgX00?o0000ooooooooool0<_ooool004Oooooo0ol0000?ooooobkoZKkY00?o
0000ojVnjOnY_^T00onY_^T8ooooo`03o`000?oooooooooo07Kooooo0_l0000mooooo`03ogm0N?l0
003o001B00?o001B00?oYL;^ojVmj?nY_NP01_nY_NP00ol0003oooooooooo`0aooooo`00AOooool2
o`00013ooooo<?nY_^T01?l0003oZKkYojVnjOl006`2ojVnj@Wooooo00?o0000ooooooooool0L_oo
ool3o`0003gooooo0_l005400omo@7So0000o`00DP03o`00DP03ojG2k_nY_NSoZKgX00KoZKgX00?o
0000ooooooooool0<Oooool004;ooooo0ol0000@oooooc7oZKkY00GoQe27o`000?nY_^WoZKkYo`00
K002ojVnj@[ooooo00?o0000ooooooooool0Koooool2o`00043ooooo0_l005400omo@7So0000o`00
DP03o`00DP03ojG2k_nY_NSoZKgX00OoZKgX00?o0000ooooooooool0<?ooool003oooooo0ol0000@
ooooocCoZKkY00GoQe27o`000?nY_^WoZKkYo`00K002ojVnj@[ooooo00?o0000ooooooooool0K?oo
ool3o`00043ooooo00KoPD9io`00DOl0057o001Aogm0N?l00004o`00DP03ojG2k_nY_NSoZKgX00So
ZKgX00?o0000ooooooooool0;oooool003gooooo0_l00003ooooo`03ojVmj?oooooooooo00_ooooo
=_nY_^T00on7D8Oo0000o`00K004ojVnj@_ooooo00?o0000ooooooooool0JOooool2o`0004;ooooo
0_n1@WT3o`00D@03ogm0N?l0003o001B00?o001B00?oYL;^ojVmj?nY_NP02?nY_NP00ol0003ooooo
ooooo`0_ooooo`00>_ooool3o`0000?ooooo1?nY_NP9ooooocWoZKkY00?oQe27o`000?l006`01?nY
_^T<ooooo`03o`000?oooooooooo06Gooooo0ol00014ooooo`;oPD9i0ol005400omo@7So0000o`00
DP03o`00DP03ojG2k_nY_NSoZKgX00WoZKgX00?o0000ooooooooool0;_ooool003Sooooo0_l00003
ooooo`OoZKgX0_oFI@05oooooc_oZKkY00?oQe27o`000?n7D8L00onY_^T00ol006coooooooooo`0:
ooooo`03o`000?oooooooooo06;ooooo0ol00017ooooo`;oPD9i0ol005400omo@7So0000o`00DP03
o`00DP03ojG2k_nY_NSoZKgX00WoZKgX00?oooooo`000?ooool0;_ooool003Gooooo0ol000000ooo
ooooZKgXojVmj00:ojVmj003omIU0?nY_^WoZKkY03[oZKkY00OoR568ojVnjOl006_oZKkYohM@Qol0
003oQe2700?oZKkY00?o001/ojVnjOooool02oooool00ol0003oooooooooo`1Oooooo`;o0000B?oo
ool2o`00C`;oPD9i0ol005400omo@7So0000o`00DP03o`00DP03ojG2k_nY_NSoZKgX00[oZKgX00?o
0000ooooooooool0;Oooool003?ooooo0_l000000oooooooZKgXojVmj00=ojVmj3_oZKkY0on8DHP0
1_nY_^Wo001[ojVnjOnY_^Wo0000ohM@Q`;oZKkY0_l006`00onY_^Woooooooooo`0:ooooo`03o`00
0?oooooooooo05cooooo0ol0001:ooooo`;o001?0_n1@WT3o`00D@03ogm0N?l0003o001B00?o001B
00?oYL;^ojVmj?nY_NP02onY_NP00ol0003oooooooooo`0/ooooo`00<?ooool3o`000003oooooonY
_NSoZKgX013oZKgX>_nY_^T3ohQAR006ojVnjOl006_oZKkYojVnjOl0003oQe270_nY_^T00ol006co
ZKkYojVnj@0=ooooo`03o`000?oooooooooo05Wooooo0_l0001<ooooo`?o001?0_n1@WT3o`00D@03
ogm0N?l0003o001B00;o001B0_nU`^h=ojVmj003ooooool0003ooooo02cooooo000]ooooo`?o0000
0_oooolEojVmj3WoZKkY0on8DHP4ojVnj@05ohM@Qol0003oZKkYojVnjOl006`00_nY_^T>ooooo`03
o`000?oooooooooo05Gooooo0ol0001>ooooo`?o001?0_n1@WT3o`00D@03ogm0N?l0003o001B00;o
001B0_nU`^h>ojVmj003o`000?oooooooooo02_ooooo000[ooooo`;o00000ooooolHojVmj3SoZKkY
0on8DHP02Ol006_oZKkYojVnjOnY_^WoQe27o`000?l006coZKkYo`00K002ojVnj@kooooo00?o0000
ooooooooool0Doooool2o`00057ooooo0ol004l2oh52N@?o001A00?oOd1ho`000?l005800_l00582
ojG2kPkoZKgX00?oooooo`000?ooool0:oooool002Sooooo0ol00002oooooacoZKgX=onY_^T3ohQA
R009o`00JonY_^WoZKkYojVnjOn7D8Oo0000o`00K?nY_^Wo001/00;oZKkY3oooool00ol0003ooooo
ooooo`1?ooooo`?o0000DOooool00on2A7_o001?o`00C`02o`00C`;oPD9i0ol005401?mo@7So0000
o`00D_l00583ojG2kPooZKgX00?oooooo`000?ooool0:_ooool002Kooooo0_l00003oooooaooZKgX
=_nY_^T4ohQAR0?oZKkY00OoQe27o`000?l006coZKkYo`00K?nY_^Wo001/013ooooo00?o0000oooo
ooooool0C?ooool2o`0005?ooooo0_n2A7/4o`00C`;oPD9i0ol005401?mo@7So0000o`00D_l00583
ojG2kQ3oZKgX00?o0000ooooooooool0:Oooool002?ooooo0ol000000oooooooZKgXojVmj00RojVm
j3CoZKkY00?o001YojVnjOn8DHP00_n8DHP02_nY_^Wo001[ojVnjOn7D8Oo0000o`00K?nY_^Wo001/
ojVnjOl006`@ooooo`03o`000?oooooooooo04Wooooo0ol0001Eooooo`;oPTAk1?l004l2oh52N@?o
001A0_mo@7P00ol0003oYL;^ojG2kP02ojG2kQ3oZKgX00?oooooo`000?ooool0:Oooool0027ooooo
0_l00002ooooobKoZKgX<OnY_^T01On9DhWoZKkYojVnjOl006WoZKkY00?oR56800OoZKkYo`00JonY
_^WoQe27o`000?n7D8OoZKkY00?o001/4Oooool00ol0003oooooooooo`16ooooo`;o0000E_ooool2
o`00CP;oPTAk1?l004l2oh52N@?o001A0_nU`^h00ol0003oYL;^ojG2kP03ojG2kQ3oZKgX00?ooooo
o`000?ooool0:?ooool001kooooo0ol000000oooooooZKgXojVmj00XojVmj2koZKkY0on9DhT4ojVn
j@?oR56800OoZKkYo`00JonY_^WoQe27o`000?n7D8OoZKkY00?o001/00?oZKkYooooooooool03ooo
ool00ol0003oooooooooo`12ooooo`?o0000F?ooool2o`00CP;oPTAk1?l004l2oh52N@GoYL;^00?o
0000ojG2k_nU`^h00onU`^hAojVmj003o`000?oooooooooo02Oooooo000Looooo`;o00000_ooool]
ojVmj2goZKkY0on9DhT01?nY_^Wo001YojVnjOnY_^T3ohQAR006ojVnjOl006_oZKkYohM@Qol0003o
Qe270_nY_^T2o`00K003ojVnjOoooooooooo00oooooo00?o0000ooooooooool0?oooool3o`0005Wo
oooo00CoPdElo`00C_l004ko001>0_n2A7/4o`00C`OoYL;^00?o0000ojG2k_nU`^h00onU`^hAojVm
j003ooooool0003ooooo02Oooooo000Iooooo`?o00000_ooool`ojVmj2coZKkY0on9DhT01?nY_^Wo
001YojVnjOnY_^T3ohQAR008ojVnjOl006_oZKkYohM@Qol0003oQe27o`00K?nY_^T2o`00K003ojVn
jOoooooooooo013ooooo00?o0000ooooooooool0??ooool2o`0005_ooooo0_n3AG`3o`00CP;oPTAk
00?o001?ojG2k_nU`^h02?nU`^h00ol0003oYL;^ojG2kP03ojG2kQ;oZKgX00?o0000ooooooooool0
9_ooool001Kooooo0ol000000oooooooZKgXojVmj00bojVmj003o`lASOnY_^WoZKkY02WoZKkY0on9
DhT01?l006WoZKkYojVnjOnY_^T3ohQAR009ojVnjOl006_oZKkYohM@Qol0003oQe27o`00K?nY_^Wo
001/00;oZKkY4oooool00ol0003oooooooooo`0hooooo`?o0000GOooool2oh=5O0?o001>3OnU`^h0
0ol0003oYL;^ojG2kP03ojG2kQ?oZKgX00?o0000ooooooooool09Oooool001Cooooo0_l00002oooo
ocKoZKgX0_l?4HdZojVnj@?oRE>900Co001YojVnjOnY_^WoZKkY0on8DHP2o`00J`09ojVnjOl0003o
0000ohM@Qol006coZKkYo`00K?nY_^Wo001/01?ooooo00?o0000ooooooooool0=_ooool2o`00063o
oooo0_n3AG`?ojG2kP;o00001OnU`^hCojVmj003ooooool0003ooooo02Gooooo000Aooooo`?o0000
0_oooolhojVmj003o`lASOnY_^WoZKkY02KoZKkY00?oRUB:ojVnjOnY_^T00on9DhT01?l006WoZKkY
ojVnjOnY_^T3ohQAR0?o000000SoZKkYo`000?n7D8Oo001/ojVnjOl006coZKkYo`00K1Cooooo00?o
0000ooooooooool0<_ooool3o`00067ooooo3onU`^h3o`000003ojG2k_l0003oYL;^00CoYL;^5?nY
_NP00ol0003oooooooooo`0Tooooo`004?ooool2o`000003oooooonY_NSoZKgX03WoZKgX9onY_^T3
ohYDRP?oZKkY0_n9DhT01?l006WoZKkYojVnjOnY_^T3o`0000?o001[00GoZKkYohM@Qol0003o001/
ojVnj@03o`00K1Gooooo00?o0000ooooooooool0<?ooool2o`00067ooooo3_nU`^h3o`0000GoYL;^
00?o0000ojG2k_nU`^h00_nU`^hEojVmj003o`000?oooooooooo02?ooooo000@ooooo`03o`000?nY
_NSoZKgX03coZKgX9_nY_^T3ohYDRP03ojVnjOl006SoZKkY00;oRE>900Co001Yo`000?l0003o0000
0on8DHP01?l006_oZKkYo`00JonY_^T2ohM@Q`03o`000?nY_^Wo001/00;o001/5Oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooo000005gooooo3_nU`^h3o`0000WoYL;^00Co0000ojG2k_nU
`^koYL;^5OnY_NP00ooooooo0000ooooo`0Sooooo`004?ooool00ol0003oooooojVmj00nojVmj2Co
ZKkY0on:E8X00onY_^Wo001XojVnj@03o`0000;oZKkY00So001YohQAR?n8DHSoR568o`00JonY_^Wo
001[ojVnj@?oQe2700Co0000o`00K?l006co001/5_ooool00ol0003oooooooooo`0_ooooo`04o`00
0?ooooooooooo`0005Wooooo3_nU`^h3o`0000goYL;^00?o0000ojG2k_nY_NP05_nY_NP00ol0003o
ooooooooo`0Rooooo`004?ooool00ol0003oooooojVmj00nojVmj2CoZKkY0on:E8X3o`0000?oRE>9
0_nY_^T00ol006WoR568ohQAR002ohQAR003ojVnjOl006_oZKkY00?oQe2700Co0000o`00K?l006co
001/5_ooool00ol0003oooooooooo`0_ooooo`05o`000?ooooooooooooooool00000E_ooool=ojG2
kP?o00004?nU`^h00ol0003oZKgXojVmj00GojVmj003o`000?oooooooooo027ooooo000?ooooo`04
o`000?ooooooooooooooocooZKgX8onY_^T3o`000003ojVnjOl006SoZKkY00?oRE>900CoZKkYo`00
JOl006WoZKkY0on8DHP00onY_^Wo001[ojVnj@03ohM@Q`05o`00K?l0003o001/o`00K?nY_^T05_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0D?oo
ool=ojG2kP?o00005?nU`^h00ol0003oZKgXojVmj00FojVmj003ooooool0003ooooo027ooooo000?
ooooo`03o`000?oooooooooo00?ooooo?_nY_NPPojVnj@;o00000on:E8X2o`00J005ojVnjOn9DhWo
RE>9ohUCROnY_^T00_l006T01onY_^WoR568ohQAR?n8DHSoZKkYo`00JonY_^T00on7D8L2o`00K003
o`000?l006co001/01Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo04cooooo3OnU`^h3o`0001KoYL;^0_nY_NP00ol0003oZKgXojVmj00FojVmj003
o`000?oooooooooo023ooooo000?ooooo`03o`000?oooooooooo00Cooooo??nY_NP2oin:_AcoZKkY
0ol000000onY_^Wo001WojVnj@02ohYDRP03o`00J?nY_^WoZKkY00?oRE>90ol006T01OnY_^WoR568
ohQAR?n8DHSoZKkY00;o001[0on7D8L3o`00K003o`000?l006cooooo01Kooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo3OnU`^h3o`0001Wo
YL;^0_nY_NP00ol0003oZKgXojVmj00GojVmj003o`000?oooooooooo01oooooo000?ooooo`03o`00
0?oooooooooo00Gooooo??nY_NP2oin:_ASoZKkY0ol000001_nY_^WoReJ<ojVnjOnY_^Wo001WojVn
j@;oRUB:00?o001XojVnjOnY_^T00on9DhT2o`00J@;oZKkY0on8DHP3o`00J`?oQe270ol006`00ol0
003o001/ooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`15ooooo`goYL;^0_l0000LojG2kP?oZKgX00?o0000ojVmj?nY_NP05_nY_NP00ooo
oooo0000ooooo`0Oooooo`003oooool00ol0003oooooooooo`06ooooocSoZKgX00KoWhZmoeEM__mE
GKkoWhZmojVmj?l006dDojVnj@?o00000onY_^T2oh]FS0;oZKkY00?o001WojVnjOn:E8X00_n:E8X2
ojVnj@?oRE>90_l006T2ojVnj@?oR5680ol006/3ohM@Q`05o`00K?nY_^Wo001/o`00K?l000006Ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@Ooo
ool=ojG2kP?o00007OnU`^h5ojVmj003o`000?nY_NSoZKgX01KoZKgX00?o0000ooooooooool07_oo
ool000oooooo00?o0000ooooooooool02?oooolbojVmj0KoWhZm0_mEGKh2ojVmj17oZKkY0ol00006
ojVnj@;oReJ<0_nY_^T00ol006OoZKkYohYDRP02ohYDRP;oZKkY0on9DhT01?l006WoZKkYojVnjOnY
_^T3ohQAR0?o001[0on7D8L00ol006coZKkYo`00K002o`00K003o`000?oooooooooo01Kooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03kooooo3?nU
`^h3o`0001ooYL;^1onY_NP00ol0003oZKgXojVmj00FojVmj003o`000?oooooooooo01gooooo000?
ooooo`03o`000?oooooooooo00Sooooo;onY_NP9oin:_@03oeEM__nY_NSoZKgX00;oZKgX0_nY_^T2
ojVmj003ojVnjOnY_NSoZKkY00KoZKkY0ol00009ojVnj@;oReJ<0_nY_^T00ol006OoZKkYohYDRP02
ohYDRP03ojVnjOl006SoRE>900;oRE>900Co001YojVnjOnY_^Wo001Y0on8DHP3o`00J`?oQe271Ol0
06`00onU`noo0000ooooo`0Gooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0jooooo`coYL;^0ol0000QojG2kPSoZKgX00?o0000ojVmj?nY_NP05_nY
_NP00ooooooo0000ooooo`0Mooooo`003_ooool00ol0003oooooooooo`0:ooooobcoZKgX2_nOR[d=
ojVmj0?oZKkY0ol0000<ojVnj@;oReJ<00CoZKkYo`00IonY_^WoZKkY0on:E8X00onY_^Wo001XohUC
R@02ohUCR@04o`00JOnY_^WoZKkYo`00J@?oR5680ol006/01?nY_^WoQe27ohM@Qon7D8L3o`00K0;o
YL?_00?o0000ojG3koooool05oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0=_ooool<ojG2kP?o00008_nU`^h;ojVmj003o`000?nY_NSoZKgX01Ko
ZKgX00?o0000ooooooooool07?ooool000kooooo00?o0000ooooooooool03?oooolVojVmj0coWhZm
3onY_NP3o`0000coZKkY00?oS5N<ojVnjOnY_^T00_n;EX`01?nY_^Wo001WojVnjOnY_^T3ohYDRP03
ojVnjOl006SoZKkY00;oRE>900Co001YojVnjOnY_^Wo001Y0on8DHP3o`00J`04ojVnjOn7D8OoQe27
ohM@Q`Co001/0_nU`nl00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0cooooo`_oYL;^0ol0000TojG2kPgoZKgX00?o0000
ojVmj?nY_NP05_nY_NP00ol0003oooooooooo`0Kooooo`003_ooool00ol0003oooooooooo`0<oooo
obCoZKgX3?nOR[d?ojVmj0;o00001OnY_NP2ojVnj@03ojVmj?nY_^WoZKkY00?oZKkY0on<Eh`2ojVn
j@;oReJ<0_l006L2ojVnj@?oRUB:00?oZKkYo`00J?nY_^T00_n9DhT01?l006WoZKkYo`00JOl006T3
ohQAR0Co001[0on7D8L3o`00K0CoYL?_00?o0000ooooooooool05_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;Oooool=ojG2kP?o00009onU`^h>
ojVmj003o`000?nY_NSoZKgX01GoZKgX00?oooooo`000?ooool06oooool000kooooo00?o0000oooo
ooooool03OoooolQojVmj0WoWhZm4OnY_NP3o`0000_oZKgX00CoZKkYojVmj?l00XSoZKkY0on<Eh`2
ojVnj@;oReJ<00Co001WojVnjOnY_^WoZKkY0on:E8X00onY_^Wo001XojVnj@02ohUCR@04o`00JOnY
_^Wo001Yo`00J@?oR56800Co001[ojVnjOl006_o001[0on7D8L00ol006coYL?_ojG3k`04ojG3k`03
o`000?nU`noooooo01Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo02Wooooo3OnU`^h3o`0002WoYL;^3onY_NP00ol0003oZKgXojVmj00FojVmj003
o`000?oooooooooo01[ooooo000>ooooo`03o`000?oooooooooo00oooooo6onY_NP;oin:_A3oZKgX
0ol0000@ojVmj003o`02R?nY_^WoS5N<00;oS5N<0_nY_^T2oh]FS004o`00IonY_^WoZKkYo`00I`?o
RUB:00?oZKkYo`00J?nY_^T00_n9DhT4o`00J@?oR56800Co001[ojVnjOl006_o001[0on7D8L2o`00
K0KoYL?_00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00oooooo0_l0000Jooooo`CoY/;]00?o]c/0ooooooooool01_ooool<ojG2kP?o0000;?nU`^h@ojVm
j003o`000?nY_NSoZKgX01KoZKgX00?o0000ooooooooool06Oooool000kooooo00?o0000oooooooo
ool04?oooolGojVmj0coWhZm3onY_NP3o`0001?oZKgX00?o00:8ojVnjOn<Eh`00_n<Eh`2ojVnj@?o
ReJ<0_nY_^T01?l006OoRUB:ohYDR_n:E8X2o`00J003ojVnjOn9DhWoRE>900Co001Y1?n8DHP3o`00
J`;oQe272_nU`nl00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Eooooo`OoY/;]00?o]c/0ooooooooool00_ooool=ojG2
kP;o0000;onU`^hAojVmj003o`000?nY_NSoZKgX01KoZKgX00?o0000ooooooooool06?ooool000ko
oooo00?o0000ooooooooool04OoooolDojVmj0[oWhZm4?nY_NP3o`0001KoZKgX00?o00:8ojVnjOn<
Eh`00_n<Eh`2ojVnj@?oReJ<0_nY_^T01?l006OoRUB:ohYDR_n:E8X2o`00J003ojVnjOn9DhWoRE>9
00Co001Y00CoZKkYohQAR?n8DHSoR5680ol006/=ojG3k`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo2onV`^d0
0ong>`3oYL;^ojG2kP0;ojG2kP?o0000;OnU`^hEojVmj003o`000?nY_NSoZKgX01KoZKgX00?o0000
ooooooooool06?ooool000gooooo00?o0000ooooooooool04oooool?ojVmj0coWhZm3onY_NP3o`00
01WoZKgX00?o00:8ojVnjOn<Eh`00_n<Eh`00onY_^Wo001Voh]FS002oh]FS0;oZKkY00Co001WojVn
jOn:E8[oRUB:0ol006P2ohUCR@Co001Y00CoZKkYohQAR?n8DHSoR5681?l006/<ojG3k`03o`000?nU
`noooooo01Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00kooooo3_nV`^d00ong>`3oYL;^ojG2kP07ojG2kP?o0000<?nU`^hFojVmj003o`000?nY
_NSoZKgX01GoZKgX00?oooooo`000?ooool06?ooool000gooooo00?o0000ooooooooool05?ooool<
ojVmj0coWhZm3_nY_NP3o`0001coZKgX00?o00:8ojVnjOn<Eh`00_n<Eh`00onY_^Wo001Voh]FS002
oh]FS0;oZKkY00Co001WojVnjOn:E8[oRUB:0ol006P2ohUCR@Go001Y0on8DHP3o`00J`koYL?_00?o
0000ojG3koooool05_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool02ooooolAojK2k@KoYL;^0ol0000cojG2kQOoZKgX00?o0000ojVmj?nY_NP05OnY
_NP00ooooooo0000ooooo`0Gooooo`003Oooool00ol0003oooooooooo`0Fooooo`SoZKgX2_nOR[d@
ojVmj0;o00008?nY_NP01?nY_^WoS5N<ohaGS?n<Eh`2o`00IP?oReJ<0_nY_^T01?l006OoZKkYohYD
R_n:E8X3o`00J0;oRE>90ol006T00onY_^Wo001YohQAR002ohQAR0;o001[4?nU`nl00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`07oooooaGoY/;]0_nU`^h3o`0003GoYL;^6OnY_NP00ol0003oZKgXojVmj00EojVmj003o`00
0?oooooooooo01Kooooo000=ooooo`03o`000?oooooooooo01Kooooo1onY_NP8oin:_A3oZKgX0ol0
000RojVmj004o`00IOn<EhcoS5N<ohaGS0;o001V0on;EX`2ojVnj@04o`00IonY_^WoRUB:ohYDRP?o
001X0on9DhT2o`00J@03ojVnjOl006WoR56800;oR5680ol006/@ojG3k`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;o
oooo6?nV`^d3o`0003OoYL;^6_nY_NP00ol0003oZKgXojVmj00EojVmj003ooooool0003ooooo01Ko
oooo000=ooooo`03o`000?oooooooooo01Oooooo1onY_NP5oin:_@ooZKgX0ol0000UojVmj004o`00
IOnY_^WoS5N<ohaGS0;o001V0on;EX`01?nY_^Wo001Wo`00IonY_^T2ohYDRP?o001X0on9DhT01?l0
06WoZKkYo`00JOl006T2ohQAR1CoYL?_00?o0000ooooooooool05_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01Wooooo00?o0000ojK2kOnV`^d05_nV`^d3o`0000?oY/;]=_nU`^hL
ojVmj003o`000?nY_NSoZKgX01GoZKgX00?oooooo`000?ooool05Oooool000gooooo00?o0000oooo
ooooool06?ooool01?nY_NSoWhZmoin:_OnOR[d2odQF_@03oin:_OnY_NSoZKgX00koZKgX0ol0000X
ojVmj004o`00IOnY_^WoS5N<ohaGS0;o001V0on;EX`01?nY_^Wo001Wo`00IonY_^T2ohYDRP?o001X
0on9DhT00ol006WoZKkYo`00J@02o`00JAKoYL?_00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo01Sooooo5onV`^d3o`0000OoY/;]=OnU`^hMojVmj003o`00
0?nY_NSoZKgX01GoZKgX00?o0000ooooooooool05?ooool000gooooo00?o0000ooooooooool06?oo
ool5oin:_@?oB5Jm3?nY_NP3o`0002_oZKgX00Co00:8ojVnjOn<EhcoS5N<0_l006H3oh]FS0Co001W
0_n:E8X3o`00J0?oRE>91_l006TFojG3k`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0FoooooaOoY/;]0_l0000;ojK2kCCoYL;^7_nY_NP00ol0003oZKgX
ojVmj00EojVmj003o`000?oooooooooo01?ooooo000<ooooo`03o`000?oooooooooo01[ooooo1OnO
R[d00om8E[goZKgXojVmj008ojVmj0?o0000;_nY_NP01?l00XSoZKkYohaGS?n<Eh`2o`00IP?oReJ<
1?l006L2ohYDRP04o`00J?nY_^Wo001XojVnj@;oRE>91Ol006THojG3k`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0CoooooaOoY/;]0ol0000>ojK2kC;o
YL;^7onY_NP00ol0003oZKgXojVmj00EojVmj003ooooool0003ooooo01?ooooo000<ooooo`03o`00
0?oooooooooo01_ooooo0onOR[d9ojVmj0?o0000<OnY_NP01?l00XSoZKkYohaGS?n<Eh`2o`00IP03
ojVnjOn;EXcoReJ<00Co001W0_n:E8X01?l006SoZKkYo`00J?nY_^T2ohUCR@Co001Y6OnU`nl00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03ooooolHojK2
k@?o00004OnV`^d00olN9IgoYL;^ojG2kP0/ojG2kR?oZKgX00?o0000ojVmj?nY_NP05OnY_NP00ol0
003oooooooooo`0Booooo`003?ooool00ol0003oooooooooo`0Kooooo`[oZKgX0_l0000dojVmj004
o`02R?nY_^WoS5N<ohaGS0;o001V00?oZKkYoh]FS?n;EX`01?l006L3ohYDRP03ojVnjOl006So001X
00;oRE>90ol006TKojG3k`03o`000?nU`noooooo00[ooooo00?oR4]oojO0joooool02?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo6?nV`^d3o`0001GoY/;]00?o7RFMojG2
k_nU`^h0:onU`^hTojVmj003o`000?nY_NSoZKgX01CoZKgX00?oooooo`000?ooool04_ooool000co
oooo00?o0000ooooooooool07?ooool6ojVmj0?o0000=_nY_NP01Ol00XSoZKkYohaGS?n<Ehco001V
00;oZKkY0_n;EX`4o`00I`?oRUB:0ol006P2ohUCR@;o001Y7OnU`nl00ol0003oooooooooo`06oooo
o`CoR4]o00?oYl3[ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00_ooooo5onV`^d3o`0001SoY/;]0_lN9Id[ojG2kRGoZKgX00?o0000ojVmj?nY_NP05OnY_NP00ooo
oooo0000ooooo`0Aooooo`003?ooool00ol0003oooooooooo`0Mooooo`;oZKgX0ol0000hojVmj003
o`00K?l00XSoZKkY00;oS5N<00?o001VojVnjOnY_^T00_n;EX`4o`00I`?oRUB:0ol006P2ohUCR@?o
001Y7OnU`nl00ol0003oooooooooo`09ohQ;O`;oYl3[2Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00Wooooo5_nV`^d3o`0001_oY/;]0olN9IdZojG2kRKoZKgX00?o0000ojVmj?nY
_NP05OnY_NP00ol0003oooooooooo`0@ooooo`003?ooool00ol0003oooooooooo`0Looooo`?o0000
>onY_NP00ol006co00:8ojVnj@03ohaGS0;oZKkY0_n;EX`2o`00I`03ojVnjOl006OoRUB:00;oRUB:
0ol006P2ohUCR@;o001Y7_nU`nl00ol0003oYL?_ohQ;O`09ohQ;O`?oYl3[2Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00Cooooo6?nV`^d3o`0001ooY/;]00?o7RFMojG2k_nU`^h0
:?nU`^hXojVmj003o`000?nY_NSoZKgX01CoZKgX00?oooooo`000?ooool04?ooool000cooooo00?o
0000ooooooooool06Oooool3o`0000?ooooo>onY_NP00ol006co00:8ojVnj@03ohaGS0;oZKkY0_n;
EX`2o`00I`03ojVnjOl006OoZKkY00;oRUB:0ol006PSojG3k`03o`000?n8BgooR4]o00SoR4]o0onW
`>/8ooooo`?o00006Oooool00ol0003oooooooooo`02oooooaOoY/;]0ol0000RojK2kBSoYL;^;?nY
_NP00ol0003oZKgXojVmj00DojVmj0;o00004?ooool000_ooooo00?o0000ooooooooool05oooool3
o`0000Oooooo>OnY_NP3o`00K004o`00IOn<EhcoS5N<ohaGS0;oZKkY0_n;EX`01Ol006OoZKkYojVn
jOl006OoZKkY00;oRUB:1?l006PSojG3k`03o`000?n8BgooR4]o00OoR4]o1?nW`>/4ooooo`?o0000
0_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01KoY/;]0ol0000VojK2kBOoYL;^
;?nY_NP00ol0003oZKgXojVmj00EojVmj003o`000?oooooooooo00kooooo000;ooooo`03o`000?oo
oooooooo01Cooooo0ol0000<oooooc;oZKgX00?oTEjBojVmj?nY_NP00_nY_NP3o`00K004o`00IOn<
EhcoS5N<ohaGS0;oZKkY0_n;EX`00ol006OoZKkYo`00I`02o`00I`;oRUB:0ol006PUojG3k`03o`00
0?n8BgooR4]o00KoR4]o1OnW`>/3o`0000Gooooo00?o0000ooooooooool05oooool00ol0003oY/;]
ojK2k@0DojK2k@;o0000:onV`^dTojG2kRkoZKgX00?o0000ojVmj?nY_NP04onY_NP00ooooooo0000
ooooo`0?ooooo`002oooool00ol0003oooooooooo`0Aooooo`?o00004?ooool`ojVmj0;oTEjB0onY
_NP3o`00K003ojVmj?l006GoS5N<00;oS5N<0_nY_^T3oh]FS004ojVnjOl006Oo001Wo`00I`;oRUB:
0ol006PUojG3k`03o`000?n8BgooR4]o00KoR4]o1OnW`>/8ooooo`03o`000?oooooooooo01Kooooo
00?o0000oooooonV`^d04_nV`^d3o`0002goY/;]9?nU`^h_ojVmj003o`000?nY_NSoZKgX00goZKgX
1_ooool00ol0003oooooooooo`0>ooooo`002oooool00ol0003oooooooooo`0?ooooo`;o00005?oo
oolZojVmj003o`19aOnY_NSoZKgX00;oZKgX0_nAGY83ojVmj0?o001/00?oZKgXo`00IOn<Eh`00_n<
Eh`00onY_^Wo001Voh]FS002oh]FS0Co001W0_n:E8X2o`00J2OoYL?_00?o0000ohQ;Oon8Bgl01On8
Bgl5ojO0j`Wooooo00?o0000ooooooooool05Oooool01?l0003oooooooooooooool>ojK2k@?o0000
<OnV`^dSojG2kS3oZKgX00?o0000ojVmj?nY_NP02_nY_NP8ooooo`03o`000?oooooooooo00kooooo
000;ooooo`03o`000?oooooooooo00cooooo0ol0000Gooooo`GoZKgX00?o032]ojVmj?nY_NP00_nY
_NP00ol0<k7oZKgXojVmj008ojVmj003o`0k^?nY_NSoZKgX00;oZKgX00?o03nlojVmj?nY_NP00_nY
_NP00ol0@[ooZKgXojVmj008ojVmj004o`19aOnY_NSo1000ojVmj0;oTEjB0_nY_NP3o`00K0;oZKgX
00Ko001UohaGS?n<EhcoS5N<ojVnjOl006H3oh]FS0Co001W00?oRUB:ojG3konU`nl0:OnU`nl00ol0
003oR4]oohQ;O`04ohQ;O`KoYl3[2?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00;ooooo2_nV`^d3o`0003KoY/;]8?nU`^haojVmj003o`000?nY_NSoZKgX00KoZKgX3Oooool00ol0
003oooooooooo`0=ooooo`002oooool00ol0003oooooooooo`09ooooo`?o00006oooool00onY_NSo
ooooojVmj00XojVmj004o`@00?nY_NSoTEjBoi5NTP;oZKgX0ol006`2ojVmj004o`00IOn<EhcoS5N<
ohaGS0;o001V0on;EX`5o`00Ib_oYL?_00?o0000ohQ;Oon8Bgl01On8Bgl6ojO0j`Oooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`03ooooo`KoY/;]0ol0000gojK2k@;oTFJM00?o^Ch0
ojG2k_nU`^h07OnU`^hbojVmj003o`000?nY_NSoZKgX00;oZKgX4?ooool00ol0003oooooooooo`0=
ooooo`002oooool00ol0003oooooooooo`06ooooo`?o00008_oooolWojVmj005o`@00?nY_NSoTEjB
oi5NT_nY_NP00ol006`3ojVmj004o`00IOn<EhcoS5N<ohaGS0;o001V0on;EX`4o`00IbgoYL?_00?o
0000ohQ;Oon8Bgl01?n8Bgl7ojO0j`Kooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`04ooooo`;oY/;]0ol0000jojK2k@;oTFJM00?oFCjGojG2k_nU`^h07?nU`^hdojVmj003o`000?oo
oooooooo017ooooo00?o0000ooooooooool03Oooool000[ooooo00?o0000ooooooooool01?ooool3
o`0002Kooooo9_nY_NP01?l4003oZKgXoi5NT_nAGY84o`00K0?oZKgX00Co001UohaGS?n<EhcoS5N<
0_l006H3oh]FS0Co001W;_nU`nl00ol0003oR4]oohQ;O`03ohQ;O`SoYl3[1Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00?ooooo0ol0000mojK2k@;oTFJM0_mI?YLJojG2kSGoZKgX
0_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo000:ooooo`04o`000?oo
ooooooooooooo`?o0000:OoooolVojVmj004o`@00?nY_NSoTEjBoi5NTP?o001/1?nY_NP01?l006Go
ZKkYohaGS?n<Eh`2o`00IP?oReJ<0ol006L`ojG3k`03o`000?n8BgooR4]o00;oR4]o2?nW`>/5oooo
o`03o`000?oooooooooo01Cooooo00Co0000oooooooooooooooo0ol00003ooooocWoY/;]0onBIid0
0onV`^goTFJMoi5VW@04oeTnUaSoYL;^<OnY_NP7ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool03Oooool000[ooooo1?l0000]ooooob;oZKgX0_nCI9L00onY_NSo1000ojVmj002oi5N
TP?o001/0onY_NP00ol006co001UojVnj@02ohaGS0;o001V0on;EX`00ol006OoYL?_ojG3k`0`ojG3
k`03o`000?n8BgooR4]o00;oR4]o2OnW`>/4ooooo`03o`000?oooooooooo01Cooooo1?l00008oooo
ocCoY/;]1_nBIid01?nV`^goTFJMoi5VWOnAIYd3oeTnU`?oV7R^0_nU`^h00onHN:koYL;^ojG2kP0?
ojG2kRgoZKgX3Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo000:oooo
o`;o0000<?oooolQojVmj0;oTfBG0_nY_NP00ol006_oTEjBoi5NTP02o`00K0CoZKgX00?o001/o`02
R?nY_^T00_n<Eh`2o`00IP?oReJ<0_l006LbojG3k`04o`000?n8BgooR4]oohQ;O`[oYl3[1?ooool0
0ol0003oooooooooo`0Cooooo`;o00002oooool_ojK2k@[oTVNM00Co001kojK2kOnAIYgoTFJM0omI
?YL7oiQh[Q3oYL;^:onY_NP@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Ooo
ool000cooooo00?o0000ooooooooool0;ooooolOojVmj0;oTfBG00?oZKgXo`<0M?l006/00_nAGY82
o`00K0?oZKgX0_l006`01?l00XSo001UohaGS?n<Eh`2o`00IP;oReJ<=_nU`nl00ol0003oR4]oohQ;
O`0;ojO0j`?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooob_oY/;]3OnB
Iid01?l007_oY/;]oi5VWOnAIYd2oeTnU`05onS7]?nHN:koV7R^oiQh[_oXak@00onHN:h2onW7]003
ojG2k_nHNJkoYL;^00[oYL;^:?nY_NPDooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool000gooooo00?o0000ooooooooool0;ooooolNojVmj0;oTfBG0_l307@01?l006_oTEjB
oi5NT_l006`4ojVmj0;o001/00Co00:8o`00IOn<EhcoS5N<0ol006HhojG3k`03o`000?n8BgooYl3[
00[oYl3[0oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo:?nV`^d@oi9W
W@04ojK2kOnAIYgoTFJMoeTnU`?oj<Nd00?oV7R^onS7]?oXak@00onHN:h2onW7]0?oV7V^0_nU`^h2
oiUi[P04ojG2k_nINJkoVGV^ojG2kP;omkAk9_nY_NPGooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0;ooooolMojVmj0;oTfBG0_l307@0
1?l006_oTEjBoi5NT_l006`3ojVmj0Co001/00?o001UohaGS?n<Eh`01?l006HgojG3k`03o`000?n8
BgooYl3[00_oYl3[0_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo8onV
`^dDoi9WW@04o`00NonAIYgoTFJMoeTnU`?oj<Nd00?oV7R^onS7]?oXak@00_nHN:h3onW7]0?oV7V^
2?nINJh2ooNdNb;oZKgX7?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
000?ooooo`;o0000<?oooolLojVmj0;oTfBG0_l307@01?l006_oTEjBoi5NT_nAGY83ojVmj0Co001/
00?o001UohaGS?n<Eh`00_l006HjojG3k`03o`000?nW`>_oYl3[00[oYl3[0_ooool00ol0003ooooo
ooooo`0Hooooo`;o00002ooooolOojK2kAKoTVNM00Co001koi5VWOnU`nooYL?_0ooXak@01OnHN:ko
j<NdonS7]?oXakCoV7R^00CojLNd0_nHNJh00ooYb;CoVGV^oiUi[P05oiUi[P03ooNdNonY_NSoZKgX
01ooZKgX7_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo000Aooooo`03
o`000?oooooooooo02oooooo6OnY_NP01ol107?oTfBGoi=TUol307CoZKgXo`00JonY_NP00_nAGY82
ojVmj0Co001/00CoY/7/o`00IOn<EhcoS5N<0ol006HiojG3k`03ojO0jol0003oYl3[00_oYl3[00?o
ooooo`000?ooool06oooool00ol0003oooooooooo`09oooooa_oY/;]6OnBIid2o`00N`?oYL?_00?o
j<NdojG3konU`nl00_oXak@00onU`noojLNdonW7]003onW7]003oiQi[_oYb;CojLRd00;oVGV^00?o
jLRcoiUi[_nINJh00_nINJh00oog]7_oZKgXojVmj00JojVmj2Cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`004_ooool00ol0003oooooooooo`0^oooooaWoZKgX00Oo0@1c
oi=TUonCI9Oo0`1dojVmj?l4003oZKgX00;oTEjB0_nY_NP5o`00K003o`00IOn<EhcoYL?_03[oYL?_
1?nW`>/00ol0003oYl3[ojO0j`0:ojO0j`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
2OoooolFojK2kAgoTVNM00?o001kojG3konU`nl02OnU`nl4onW7]003oiQi[_oYb;CojLRd00;oVGV^
0_oYb;<2oiUi[P;omkAk6?nY_NPYooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool001?ooooo00?o0000ooooooooool0;_oooolDojVmj0;oU6FH00CoZKgXo`40Lol107?oZKgX
0_nCI9L00onY_NSo1000ojVmj002oi5NTP03ojVmj?l006co001/00;o001/0_nV`N`00ol006GoYL?_
ojG3k`0gojG3k`OoYl3[00?o0000ojO0jonW`>/02_nW`>/00ooooooo0000ooooo`0Looooo`03o`00
0?oooooooooo00Wooooo4onV`^dNoi9WW@koYL?_0_oYak@00onU`noojLRdonW8]002onW8]004oiUi
[_oYb;?ojLRcoiUi[P?omkAk5_nY_NP/ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03?ooool001Cooooo00?o0000ooooooooool0;_oooolCojVmj0;oU6FH00CoZKgXo`40Lol107?o
ZKgX0_nCI9L00onY_NSo1000ojVmj002oi5NTP03ojVmj?l006co001/00?o001/00?oY/7/o`00IOl0
06D0<onU`nl=ojO0j`03o`000?nW`>_oYl3[00[oYl3[00?o0000ooooooooool07?ooool2o`0000_o
oooo3?nV`^dQoi9WWACoYL?_0_oYb;@2ojG3k`;ojLRc00CoVGV^ooNdNoog]7_omkAk4_nY_NP`oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool001Gooooo0_l0000_oooooa;o
ZKgX0_nDIIP01?nY_NSo0@1cojVmj?nY_NP2oi=TU`03o`<0M?l4003oZKgX00;oTEjB1?l006`3ojK1
k3?oYL?_4?nW`>/00ol0003oYl3[ojO0j`06ojO0j`?ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`08ooooo`[oY/;]7_nBIidPojG3k`?omkAk3_nY_NPeooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03?ooool001Oooooo00?o0000ooooooooool0;OoooolAojVmj0;o
U6FH00CoZKgXo`40LonY_NSoZKgX0_nCI9L00ol307Co1000ojVmj002oi5NTPGo001/0onV`N`00onU
`nooY/7/ojK1k00^ojG3ka;oYl3[00?o0000ojO0jonW`>/02?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Sooooo2?nV`^dMoi9WWBCoYL?_00?omkAkojVmj?nY_NP02_nY_NPhoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool001Sooooo00?o0000oooooooo
ool0;_ooool?ojVmj0;oU6FH1?nY_NP2oi=TU`03o`<0M?l4003oZKgX00;oTEjB1?l006`;ojK1k004
ojG3konV`NcoY/7/ojK1k0CoYL?_0_nV`N`OojG3ka?oYl3[00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo1_nV`^dHoi9WWBWoYL?_00?omkAkojVm
j?nY_NP01_nY_NPmooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool001Wo
oooo00?o0000ooooooooool0;_ooool=ojVmj007o`00L_nDIISoU6FHojVmj?l107?oZKgXo`40L`02
oi=TU`03o`<0M?l4003o001[00;oTEjB0ol006`IojK1k0;oYL?_00?oY/7/ojG3konU`nl04_nU`nlD
ojO0j`Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`;o00002_ooool0
1OnV`^goTVNMoi9WWOnBIigoY/;]01KoTVNM;?nU`nl4ojVmj47ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0;ooooo`006_ooool2o`0002oooooo3?nY_NP01ol007;oU6FHoiAUV?nY
_NSo0@1cojVmj?l107<00_nCI9L00ol307CoZ;o[o`00J`02oi5NTP?o001/7OnV`N`00onU`nooY/7/
ojK1k002ojG3k`03ojK1k?nU`nooYL?_00WoYL?_5?nW`>/8ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`CoTVNM00?oY/;]oi9WWOnBIid0
4_nBIid]ojG3k`?oZKgXA?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo
000Looooo`03o`000?oooooooooo02gooooo2_nY_NP2o`00LP;oU6FH1?l107<2oi=TU`;o0`1d00?o
001[oi5NT_nAGY800_l006`UojK1k003ojG3konV`NcoY/7/00CoYL?_0_of`I@00ol004koYl3[ojO0
j`0=ojO0j`kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00Kooooo1?nBIid00ol006OoY/;]oi9WW@0=oi9WWC;oYL?_B?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00_ooooo000Mooooo`03o`000?oooooooooo02gooooo2OnY_NP2
o`00LP03ojVmj?nDIISoU6FH00?o0@1c00GoTfBGojRojonX_n_oZ;o[o`00J`02oi5NTP;o001/:_nV
`N`4ooK1U0koYl3[4?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool01Oooool4oi9WW@03o`00IonV`^goTVNM00_oTVNM<onU`nm9ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02oooool001kooooo00?o0000ooooooooool0;Oooool4
ojVmj0;oUVJI00GoZKgXo`00L_l007;o001bojVmj002oiAUV0Co0@1c0onX_n/01?l006_oTEjBoi5N
T_l006`/ojK1k0?om/6D2_nW`>/Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`04ooooo`GoTVNM00?oY/;]oi9WWOnBIid01_nBIidgojG3kd[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`007oooool00ol0003ooooooooo
o`0]ooooo`?oZKgX0_nFIYT00onY_NSo001bo`00LP02ojVmj0;oU6FH0ol107<4ojRoj`03o`00JonA
GY;oY/7/02koY/7/0_of`I@00ooe`IGoYl3[ojO0j`02ojO0ja_ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Vooooo`;o00001Oooool4oi9WW@03o`00IonBIigoTVNM00?oTVNM>OnU
`nm<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool0023ooooo0_l0000_
ooooo`04ojVmj?nFIYWoUVJIojVmj0;o001b0_nY_NP2oiAUV0?o0@1c1?nX_n/2o`00JbkoY/7/0oof
`I@00ooe`IGo001@ojO0j`0Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`02ooooo`CoTVNM00?o001Woi9WWOnU`nl0??nU`nm=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool0;?ooool0
1OnY_NSoUVJIoiIVVOnY_NSo001b00;oZKgX00?o001boiAUV?nDIIP00_l107<8ojRojbgoY/7/0_of
`I@2ooG1UB3ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`04o`000?oo
ooooooooooooo`CoTVNM0_l006LlojG3kdkooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0:ooooo`008oooool00ol0003oooooooooo`0[ooooo`03ojVmj?nFIYWoUVJI00CoZKgX00Co
001boiAUV?nDIISo0@1c2_nX_n/00onV`NcoZ;o[ojK1k00ZojK1k003ooK1U?oe`IGomL6E027ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00CoTVNM
00?o001WojG3konU`nl0>onU`nm?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2_ooool002Cooooo00?o0000ooooooooool0:_ooool01_l0077oUVJIoiIVVOnY_NSo001bojVmj0;o
001b0_nDIIP2o`40L`coZ;o[:_nV`N`00oof`IComL6EooG1U@0Rooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0:_ooool2o`0000?oTVNM?_nU`nmAooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool002Gooooo0_l0000Zooooo`06o`00LOnFIYWoUVJIojVmj?l0
07;oZKgX0_l00782oiAUV003o`40LonX_n_oZ;o[00goZ;o[:OnV`N`2ooG1UB;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0/oooood3oYL?_Doooool01Ol0003ooooooooooooooooo
000000cooooo000Wooooo`03o`000?oooooooooo02Oooooo00Co001aoiIVVOnFIYWoUVJI1Ol0078B
ojRoj`03ojK1k?nX_n_oZ;o[02CoY/7/0_oe`IDTooooo`05o`000?ooooooooooooooool00000;ooo
ooloojG3ke?ooooo00Go0000ooooooooooooooooo`00000<ooooo`00:?ooool00ol0003ooooooooo
o`0Vooooo`04o`00LOnY_NSoUVJIoiIVV@Co001b5_nX_n/TojK1k0;omL6E9Oooool01?l0003ooooo
ooooool0000`ooooo`03o`000?nU`nooYL?_03[oYL?_EOooool01?l0003oooooooooool0000<oooo
o`00:Oooool00ol0003oooooooooo`0Uooooo`04o`00LOnY_NSoUVJIoiIVV@Co001b5onX_n/00onV
`NcoZ;o[ojRoj`0QojK1k003ooG1UOoooooooooo02Cooooo00?o0000ooooool00000<Oooool00ol0
003oYL?_ojG3k`0iojG3keKooooo00?o0000ooooool000003?ooool002[ooooo00?o0000oooooooo
ool09?ooool01?l0077oZKgXoiIVVOnFIYT3o`00LQcoZ;o[8OnV`N`Vooooo`03o`000?oooooo0000
03?ooooo00?o0000ojG3konU`nl0=_nU`nmGooooo`04o`000?ooooooooooo`0000_ooooo000[oooo
o`;o00009?ooool01?l0077oZKgXoiIVVOnFIYT3o`00LQSoZ;o[2?oooolKojK1k2Wooooo00?o0000
ooooool00000<oooool00ol0003oYL?_ojG3k`0eojG3keSooooo00?o0000ooooool000002oooool0
02gooooo00?o0000ooooooooool08Oooool2o`00L@;oUVJI0_l0078EojRoj`gooooo00?oY/7/oooo
ooooool05_nV`N`[ooooo`;o0000=?ooool00ol0003oYL?_ojG3k`0cojG3ke[ooooo0_l0000;oooo
o`00;_ooool00ol0003oooooooooo`0Pooooo`;o001a0_nFIYT00ol007;oZ;o[ojRoj`0BojRoja?o
oooo4onV`N`/ooooo`?o0000=Oooool00ol0003oYL?_ojG3k`0_ojG3kecooooo0ol0000;ooooo`00
;oooool00ol0003oooooooooo`0Oooooo`;o001a0_nFIYT00ol007;oZ;o[ojRoj`0>ojRoja[ooooo
3?nV`N`/ooooo`Co0000>_ooool:ojG3k`;ooooo1?nU`nl00oooooooYL?_ojG3k`03ojG3k`;ooooo
0onU`nl3ojO0j`?oYL?_0_nW`>/3ojG3k`?ooooo0onU`nl2ooooo`03ojG3kooooooooooo05Oooooo
1?l0000>ooooo`00<?ooool2o`0001oooooo0_l007400onFIYWoZ;o[ojRoj`0=ojRojakooooo1_nV
`N`^ooooo`?o0000?oooool00ol0003oYL?_ooooo`03ooooo`03ojG3kooooooooooo00?ooooo00?o
YL?_ooooooooool00_ooool00onU`nooooooooooo`04ooooo`_oYl3[HOooool3o`0001;ooooo000b
ooooo`03o`000?oooooooooo01cooooo0ol0074;ojRojb?ooooo00?oY/7/ooooooooool0;?ooool4
o`0004?ooooo00?o0000ooooooooool05Oooool:ojO0jegooooo1?l0000Eooooo`00<oooool00ol0
003oooooooooo`0Kooooo`;o001a2?nX_n]Booooo`Co0000B?ooool2o`0001Kooooo2OnW`>]Ioooo
o`Co00006Oooool003Cooooo00?o0000ooooooooool06_ooool2o`00L@KoZ;o[D?ooool4o`0004ko
oooo00?o0000ooooooooool05Oooool6ojO0j`03o`000?oooooooooo05Cooooo0ol0000Mooooo`00
=Oooool00ol0003oooooooooo`0Jooooo`?oZ;o[DOooool3o`0005?ooooo00?o0000ooooooooool0
5Oooool3ojO0j`;ooooo00?o0000ooooooooool0D?ooool4o`00023ooooo000fooooo`;o00006_oo
ool00ol0003oooooooooo`1=ooooo`Co0000Eoooool00ol0003oooooooooo`0Eooooo`05ojO0jooo
ooooooooooooool00000C_ooool4o`0002Cooooo000hooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0BOooool4o`0005cooooo0_l0000Iooooo`03o`000?oooooooooo04Sooooo1?l0
000Xooooo`00>Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Gooooo1?l0001R
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0AOooool3o`0002cooooo000joooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool3o`0006Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`11ooooo`Co0000;oooool003_ooooo0_l0000Eooooo`03
o`000?oooooooooo03kooooo1?l0001[ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0?_ooool4o`0003?ooooo000mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
>_ooool4o`00073ooooo0_l0000Cooooo`03o`000?oooooooooo03[ooooo1?l0000gooooo`00?_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Kooooo1?l0001fooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0=oooool3o`0003_ooooo000oooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0<_ooool4o`0007_ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0cooooo`Co0000?_ooool0043ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0_ooooo`?o0000P?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
02oooooo1?l00012ooooo`00@Oooool2o`0000oooooo00?o0000ooooooooool0:oooool4o`0008Co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`?o0000A_ooool004?ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`Co0000ROooool2o`0000gooooo
00?o0000ooooooooool0:?ooool4o`0004Wooooo0014ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool08oooool4o`0008oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Tooooo`Co0000COooool004Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0P
ooooo`?o0000U?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo1?l0001A
ooooo`00A_ooool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`0009Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Mooooo`?o0000EOooool004Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Iooooo`Co0000WOooool2o`0000Sooooo00?o0000oooooooo
ool06Oooool4o`0005Sooooo0019ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5Oooool4o`000:?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000
G?ooool004[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`?o0000Z?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo1?l0001Pooooo`00Boooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002/ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03_ooool3o`0006Cooooo001<ooooo`;o00000oooool00ol0
003oooooooooo`0:ooooo`Co0000/Oooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`00
06Oooooo001>ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002gooooo`04o`000?oooooooooo
o`0000Sooooo1?l0001[ooooo`00Coooool00ol0003oooooo`000005ooooo`?o0000_?ooool00ol0
003oooooo`000005ooooo`?o0000Koooool0053ooooo0_l000000ooooooo0000o`000002o`000<3o
oooo0_l000000ooooooo0000o`000002o`0007;ooooo001Aooooo`;o0000aOooool2o`0007Kooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {153.5, 0}} -> {-0.0542361, -0.0193168, \
0.0052844, 0.0052844}, {{10.25, 190.438}, {149.812, 3.625}} -> {-0.0541935, \
0.0451583, 0.00528671, 0.00528671}, {{208.5, 388.688}, {149.812, 3.625}} -> \
{-1.10228, 0.0451583, 0.00528671, 0.00528671}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New classification of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gdnoFrame\  = \ 
        Show[gd, \ Frame \[Rule] False, \ nS];\)\), "\[IndentingNewLine]", 
    \(\(gclass\  = \ 
        DrawHistogramClass[{h1, h2}, \ {class1Color, class2Color}, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gdnoFrame, gclass}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.38973 .69023 Mdot
.92797 .74704 Mdot
.60864 .83117 Mdot
.22047 .96051 Mdot
.82579 .27522 Mdot
.53863 .60265 Mdot
.2968 .87133 Mdot
.91144 .59112 Mdot
.45575 .76095 Mdot
.63715 .44613 Mdot
.5605 .811 Mdot
.59119 .67109 Mdot
.91839 .36981 Mdot
.97032 .45441 Mdot
.34058 .80496 Mdot
.80078 .8659 Mdot
.32506 .79524 Mdot
.46199 .55758 Mdot
.84323 .39312 Mdot
.8189 .4495 Mdot
.48331 .98672 Mdot
.87106 .43289 Mdot
.80054 .44265 Mdot
.74015 .4626 Mdot
.97669 .98821 Mdot
.52307 .54708 Mdot
.83911 .21721 Mdot
.64299 .97918 Mdot
.76698 .55124 Mdot
.14661 .8664 Mdot
.73915 .51147 Mdot
.99405 .05383 Mdot
.61824 .79364 Mdot
.83145 .88351 Mdot
.77418 .58138 Mdot
.79168 .33306 Mdot
.43444 .89351 Mdot
.62011 .53453 Mdot
.94673 .59841 Mdot
.62112 .48566 Mdot
.75581 .27935 Mdot
.95918 .94134 Mdot
.72835 .46244 Mdot
.11319 .92296 Mdot
.48425 .75023 Mdot
.93225 .97514 Mdot
.96812 .03875 Mdot
.44338 .98102 Mdot
.43463 .67366 Mdot
.20648 .9603 Mdot
.32639 .74575 Mdot
.91135 .54294 Mdot
.83432 .30845 Mdot
.09948 .90378 Mdot
.92659 .76768 Mdot
.86467 .28858 Mdot
.74685 .77544 Mdot
.52852 .49195 Mdot
.97622 .48654 Mdot
.88169 .57781 Mdot
.92943 .90906 Mdot
.95015 .80517 Mdot
.45819 .71115 Mdot
.64981 .52667 Mdot
.94653 .32803 Mdot
.96536 .83654 Mdot
.87391 .84616 Mdot
.93952 .93214 Mdot
.87477 .31165 Mdot
.67038 .73746 Mdot
.82334 .47792 Mdot
.70204 .44321 Mdot
.82319 .5921 Mdot
.38218 .94137 Mdot
.87871 .65501 Mdot
.57828 .75035 Mdot
.69755 .86085 Mdot
.75446 .33419 Mdot
.99056 .42259 Mdot
.90643 .18282 Mdot
.65778 .68512 Mdot
.28471 .82223 Mdot
.08445 .92982 Mdot
.75392 .48346 Mdot
.88392 .55404 Mdot
.88854 .36953 Mdot
.92451 .91285 Mdot
.5662 .88341 Mdot
.30331 .73892 Mdot
.55549 .70115 Mdot
.94571 .50711 Mdot
.93968 .97501 Mdot
.54954 .97624 Mdot
.47242 .71703 Mdot
.10551 .90556 Mdot
.73586 .78802 Mdot
.59442 .69731 Mdot
.604 .51509 Mdot
.96388 .56201 Mdot
.65936 .53513 Mdot
0 0 1 r
.02299 .29904 Mdot
.35992 .33389 Mdot
.25936 .42337 Mdot
.40621 .28343 Mdot
.70933 .21896 Mdot
.11987 .5167 Mdot
.40204 .44024 Mdot
.24158 .63961 Mdot
.384 .14616 Mdot
.43216 .28566 Mdot
.7931 .1566 Mdot
.64702 .20191 Mdot
.30332 .37959 Mdot
.41039 .55735 Mdot
.52873 .25163 Mdot
.08591 .66928 Mdot
.20036 .53938 Mdot
.18657 .77355 Mdot
.54839 .34242 Mdot
.14294 .78012 Mdot
.70283 .17407 Mdot
.23417 .10762 Mdot
.34719 .5093 Mdot
.16557 .7308 Mdot
.28232 .33684 Mdot
.31841 .17631 Mdot
.21833 .28273 Mdot
.51055 .1136 Mdot
.20623 .57744 Mdot
.85409 .0731 Mdot
.28721 .69184 Mdot
.32164 .1005 Mdot
.41609 .00546 Mdot
.49405 .28432 Mdot
.10263 .8242 Mdot
.28067 .00655 Mdot
.66224 .14903 Mdot
.36504 .47006 Mdot
.49237 .16559 Mdot
.39469 .33645 Mdot
.59032 .18909 Mdot
.7275 .19236 Mdot
.27148 .62077 Mdot
.85126 .0387 Mdot
.6646 .12722 Mdot
.17449 .46815 Mdot
.34813 .62327 Mdot
.14654 .27662 Mdot
.52297 .33208 Mdot
.66676 .29833 Mdot
.21045 .52863 Mdot
.18559 .76703 Mdot
.74933 .02469 Mdot
.31155 .30794 Mdot
.40615 .39646 Mdot
.16996 .03627 Mdot
.87823 .06933 Mdot
.2949 .38042 Mdot
.21641 .76605 Mdot
.0894 .84684 Mdot
.63509 .28429 Mdot
.03141 .11367 Mdot
.45445 .51231 Mdot
.27713 .09394 Mdot
.14785 .20932 Mdot
.0621 .91632 Mdot
.03564 .8076 Mdot
.50901 .15413 Mdot
.88259 .03104 Mdot
.12835 .53587 Mdot
.10667 .03337 Mdot
.07121 .6146 Mdot
.1432 .36693 Mdot
.04052 .80205 Mdot
.62924 .21775 Mdot
.282 .08838 Mdot
.26808 .27294 Mdot
.39447 .06229 Mdot
.1796 .52697 Mdot
.37133 .12846 Mdot
.07788 .49855 Mdot
.30508 .50891 Mdot
.26951 .70192 Mdot
.04231 .64587 Mdot
.16244 .14965 Mdot
.42685 .26934 Mdot
.16229 .56247 Mdot
.66979 .07369 Mdot
.5768 .38284 Mdot
.47495 .27817 Mdot
.47849 .48108 Mdot
.32466 .43845 Mdot
.30476 .06209 Mdot
.41573 .54915 Mdot
.3377 .12844 Mdot
.19069 .36524 Mdot
.14852 .04338 Mdot
.69872 .05577 Mdot
.21133 .55842 Mdot
.70619 .12378 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.0238095 0.0186741 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
153 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00>oooool3o`00oaGooooo0ol00?oooooooc_ooooo000kooooo`?o003o5Oooool3o`00oooo
oooo>oooool008oooooo0ol00?onooooo`00Soooool3o`00oaKooooo0ol00?oUooooo`007?ooool3
o`00o`Sooooo0ol00?mUooooo`?o003o5_ooool3o`00obWooooo[Ol00?l?ooooo`007?ooool3o`00
o`Sooooo0ol00?mhooooo`?o003o0oooool3o`00o`cooooo0ooo000Jooooojgo003o3oooool001co
oooo0ol00?l4ooooo`?o003o00Coooooo`00ool00?oo003oN?ooool3o`00oa;ooooo0ooo000Joooo
ojgo003o3oooool002?ooooo0ol00?mlooooo`?o003o4_ooool3ool001[ooooo[Ol00?l?ooooo`00
8oooool3o`00of3ooooo0ol00?lcooooo`;oo`005_oooon]o`00o`oooooo000oooooo`?o003o3Ooo
ool3o`00ocCooooo0ol00?lcooooo`;oo`005_oooon]o`00o`oooooo000oooooo`?o003o3Oooool3
o`00ocCooooo0ol00?lNooooo`?o003o4_ooool2ool001Kooooo[Ol00?l?ooooo`00?oooool3o`00
o`gooooo0ol00?l_ooooo`?o003o7_ooool3o`00o`;ooooo0ol00?lZooooojgo003o3oooool0087o
oooo0ol00?lNooooo`?o003o0_ooool3o`00ob[ooooo[Ol00?l?ooooo`00POooool3o`00oakooooo
0ol00?l_ooooojgo003o3oooool003_ooooo0ol00?nFooooojgo003o3oooool003[ooooo1?l00?nF
ooooojgo003o3oooool003[ooooo1?l00?l4ooooo`?o003oSooooon]o`00o`oooooo000cooooo`?o
003o1?ooool3o`00o`Gooooo0ol00?n?ooooojgo003o3oooool000kooooo0ol00?lRooooo`?o003o
3?ooool3o`00oaoooooo0ol00?m]ooooojgo003o3oooool000kooooo0ol00?lRooooo`?o003o;_oo
ool3o`00ofgooooo[Ol00?l?ooooo`003_ooool3o`00oe?ooooo0ol00?lQooooo`?o003oBOoooon]
o`00o`oooooo0015ooooo`?o003o0oooool3o`00oc;ooooo0ol00?l5ooooo`?o003oBOoooon]o`00
o`oooooo0015ooooo`?o003o0oooool3o`00oc;ooooo0ol00?l5ooooo`?o003oBOoooon]o`00o`oo
oooo0015ooooo`?o003o0oooool3o`00oc;ooooo0ol00?mAooooojgo003o3oooool004kooooo0ol0
0?n3oooooj[o003o0ooo000?ooooo`009_ooool3o`00obGooooo0ol00?l_ooooo`?o003oDOoooonZ
o`00o`?oo`003oooool002Kooooo0ol00?lUooooo`?o003o4oooool3o`00oaWooooo0ol00?lDoooo
o`?o003o>_oooonZo`00o`?oo`003oooool002Kooooo0ol00?lkooooo`?o003o6Oooool3o`00oaCo
oooo0ol00?ljooooojKo003o1ooo000?ooooo`00HOooool6o`00oc3ooooo0ol00?ljooooojKo003o
1ooo000?ooooo`00HOooool3o`00ob?ooooo0ol00?m:ooooojKo003o1ooo000?ooooo`00@_ooool3
o`00oacooooo0ol00?lSooooo`?o003oB_oooonVo`00o`Ooo`003oooool004;ooooo0ol00?m2oooo
o`?o003o8_ooool3ool002GoooooXol00?l:ool000oooooo0012ooooo`?o003o;_ooool3o`00ocKo
oooo0ooo000Uoooooj?o003o2_oo000?ooooo`00Loooool3o`00oaKooooo0ol00?lMooooo`?oo`00
9OoooonSo`00o`[oo`003oooool007?ooooo0ol00?l7ooooo`?o003o3?ooool3o`00odGoooooW?l0
0?lAool000oooooo001mooooo`?o003o3?ooool3o`00odGoooooW?l00?lAool000oooooo000Soooo
o`?o003oEoooool3o`00oeCoooooW?l00?lAool000oooooo000Sooooo`?o003oE?ooool3o`00o`_o
oooo0ol00?lEooooo`?oo`00<OoooonIo`00oaCoo`003oooool002?ooooo0ol00?mDooooo`?o003o
2oooool3o`00oaGooooo0ooo000aoooooiWo003o5?oo000?ooooo`00N_ooool3o`00o`_ooooo0ol0
0?lEooooo`?oo`00<OoooonIo`00oaCoo`003oooool00=CoooooVOl00?lDool000oooooo003Doooo
oi;o003o6ooo000?ooooo`00e?oooonBo`00oa_oo`003oooool006Sooooo0ol00?mYoooooi;o003o
6ooo000?ooooo`00J?ooool3o`00ofWoooooSol00?lNool000oooooo001Xooooo`?o003oJOoooon?
o`00oakoo`003oooool005Gooooo0ol00?mlooooohoo003o7_oo000?ooooo`00>Oooool3o`00oaWo
oooo0ol00?mloooooh_o003o8_oo000?ooooo`008oooool3o`00oa?ooooo0ol00?lIooooo`?o003o
1_ooool3o`00oc3ooooo0ooo0009ooooo`?oo`00=?oooon;o`00ob;oo`003oooool002?ooooo0ol0
0?l:ooooo`?o003o1_ooool3o`00oaKooooo0ol00?l01?oooooo003oo`00ool00?l5ooooo`Ko003o
5oooool3o`00oa?ooooo0ooo0009ooooo`?oo`00=?oooon;o`00ob;oo`003oooool002?ooooo0ol0
0?l:ooooo`?o003o7oooool3o`00o`04ooooool00?oo003oo`00o`Gooooo1_l00?lGooooo`?o003o
4oooool3ool000Wooooo0ooo0004ooooo`?oo`00;Ooooon;o`00ob;oo`003oooool0033ooooo0ol0
0?lOooooo`?o003o00Coooooo`00ool00?oo003o2?ooool3o`00oaOooooo0ol00?lVooooo`?oo`00
;Ooooon4o`00obWoo`003oooool000cooooo0ol00?mbooooo`?o003o8?ooool3ool002goooooQ?l0
0?lYool000oooooo000<ooooo`?o003o<_ooool3o`00ocgooooo0ol00?m@ooooohCo003o:Ooo000?
ooooo`003?ooool3o`00oc;ooooo0ol00?lmooooo`?o003o6oooool3ool000Cooooo0ooo000[oooo
oh7o003o;?oo000?ooooo`00@Oooool3o`00oe_ooooo0ooo0004ooooo`?oo`00:ooooon1o`00obco
o`003oooool009oooooo0ooo0004ooooo`?oo`00:ooooon1o`00obcoo`003oooool00;?ooooo0ooo
000Noooooh7o003o;?oo000?ooooo`00BOooool3o`00oa_ooooo0ol00?lVooooo`?oo`001?ooool3
ool001Wooooo0ooo000Nooooog[o003o<ooo000?ooooo`00>oooool3o`00o`_ooooo0ol00?l4oooo
o`?o003o5?ooool3o`00obKooooo0ooo0004ooooo`?oo`006Oooool3ool001koooooN_l00?lcool0
00oooooo000kooooo`?o003o2oooool3o`00o`Cooooo0ol00?lDooooo`?o003o00Coooooo`00ool0
0?oo003o8_ooool3ool000Cooooo0ooo000jooooog[o003o<ooo000?ooooo`00>oooool3o`00oa;o
oooo0ol00?lHooooo`?o003oI_oooomgo`00ocKoo`003oooool006_ooooo0ol00?mVooooogOo003o
=_oo000?ooooo`00e?oooomgo`00ocKoo`003oooool002;ooooo0ol00?l6ooooo`?o003oY_oooomc
o`00oc[oo`003oooool002;ooooo0ol00?l6ooooo`?o003oNoooool3ool000;ooooo0ooo000Soooo
og?o003o>_oo000?ooooo`008_ooool3o`00o`Kooooo0ol00?l@ooooo`Co003oIoooool3ool000;o
oooo0ooo000Sooooog?o003o>_oo000?ooooo`00?_ooool4o`00obkooooo0ol00?lfooooo`?oo`00
0_ooool3ool002?oooooLol00?ljool000oooooo000nooooo`Co003o;_ooool3o`00of7oooooKOl0
0?m0ool000oooooo001Booooo`?o003o6oooool3o`00obgooooo0ooo000aooooofgo003o@?oo000?
ooooo`00D_ooool3o`00od_ooooo0ooo000aooooofgo003o@?oo000?ooooo`00D_ooool3o`00od_o
oooo0ooo000aooooofWo003oA?oo000?ooooo`00e?oooomYo`00odCoo`003oooool00=CoooooJOl0
0?m4ool000oooooo000gooooo`?o003oPOooool3ool001KoooooHol00?m:ool000oooooo000goooo
o`?o003oPOooool3ool001KoooooHol00?m:ool000oooooo000gooooo`?o003oJoooool3ool001?o
oooo0ooo000Fooooof?o003oB_oo000?ooooo`00@oooool3o`00o`_ooooo0ol00?mAooooo`?oo`00
;?oooomSo`00od[oo`003oooool004?ooooo0ol00?l;ooooo`?o003o9oooool3ool000Wooooo0ooo
000?ooooo`?oo`002Oooool3ool002coooooGol00?m>ool000oooooo0013ooooo`?o003o2oooool3
o`00obOooooo0ooo0009ooooo`?oo`003oooool6ool003GoooooGol00?m>ool000oooooo001koooo
o`?oo`002Oooool3ool000oooooo1_oo000Hooooo`?oo`006_oooomOo`00odkoo`003oooool008co
oooo1Ooo000;ooooo`?oo`006?ooool3ool001[oooooGol00?m>ool000oooooo000Xooooo`?o003o
HOooool5ool002Kooooo0ooo000Joooooeoo003oC_oo000?ooooo`00:?ooool3o`00oaoooooo0ol0
0?loooooo`Goo`00@ooooomOo`00odkoo`003oooool002Sooooo0ol00?lOooooo`?o003oD?ooool3
ool003CoooooGol00?m>ool000oooooo001:ooooo`?o003o4_ooool3o`00oaKooooo0ooo000Eoooo
o`?oo`002_ooool3ool003CoooooGol00?m>ool000oooooo001Oooooo`?o003o5_ooool3ool001Go
oooo0ooo000:ooooo`?oo`006?ooool3ool001WoooooGol00?m>ool000oooooo001Oooooo`?o003o
1_ooool3ool000gooooo0ooo000Eooooo`?oo`009Oooool3ool001WoooooGol00?m>ool000oooooo
000Fooooo`?o003oCoooool3ool004gooooo0ooo000Ioooooeco003oDOoo000?ooooo`005_ooool3
o`00odoooooo0ooo0018ooooo`?oo`007_oooomLo`00oe7oo`003oooool001Kooooo0ol00?lVoooo
o`?o003o1Oooool3o`00oa3ooooo0ol00?laooooo`?oo`008_ooool3ool001koooooG?l00?mAool0
00oooooo000Nooooo`?o003o7_ooool3o`00o`Gooooo0ol00?l@ooooo`?o003o6?ooool3ool001Ko
oooo0ooo000Rooooo`?oo`007_oooomHo`00oeGoo`003oooool001kooooo0ol00?lNooooo`?o003o
1Oooool3o`00oa3ooooo0ol00?lHooooo`?oo`005_ooool3ool004?oooooF?l00?mEool000oooooo
000Nooooo`?o003o2?ooool3o`00o`;ooooo0ol00?m4ooooo`?oo`001_ooool3ool005?oooooF?l0
0?mEool000oooooo000Yooooo`?o003o0_ooool3o`00odOooooo0ooo0003ooooo`Coo`00D_oooomE
o`00oeSoo`003oooool001oooooo0ol00?l7ooooo`So003oAoooool3ool000?ooooo1?oo001Boooo
oeGo003oF?oo000?ooooo`007oooool3o`00o`[ooooo0ol00?m9ooooo`?oo`001?ooool3ool002_o
oooo0ooo000ToooooeGo003oF?oo000?ooooo`007oooool3o`00o`[ooooo0ol00?lTooooo`?o003o
4Oooool3ool002Wooooo0ooo000Gooooo`?oo`009?oooomEo`00oeSoo`003oooool005;ooooo1?l0
0?l6ooooo`?oo`002?ooool3ool002Wooooo0ooo000Booooo`?oo`000_ooool3ool002CoooooD_l0
0?mKool000oooooo000Vooooo`?o003o1Oooool3o`00ob7ooooo1?l00?l6ooooo`?oo`002?ooool3
ool002Wooooo0ooo000Booooo`?oo`002oooool3ool001_oooooD_l00?mKool000oooooo000Voooo
o`?o003o1Oooool3o`00ob7ooooo0ol00?l7ooooo`?oo`00BOooool3ool000_ooooo0ooo000Koooo
oe;o003oFooo000?ooooo`009_ooool3o`00o`Gooooo0ol00?n5ooooo`?oo`006ooooom>o`00oeoo
o`003oooool002kooooo0ol00?mfooooo`?oo`00:_oooom>o`00oeooo`003oooool002kooooo0ol0
0?mSooooo`?oo`004?ooool3ool002[oooooC_l00?mOool000oooooo000^ooooo`?o003oHoooool3
ool0013ooooo0ooo0003ooooo`?oo`009?oooom;o`00of;oo`003oooool009Cooooo0ooo0006oooo
o`?oo`003Oooool3ool002CoooooBol00?mRool000oooooo002Mooooo`?oo`003Oooool3ool000?o
oooo0ooo000Noooood_o003oH_oo000?ooooo`00JOooool3ool0037ooooo0ooo000Cooooo`?oo`00
7_oooom;o`00of;oo`003oooool006Wooooo0ooo0017ooooo`?oo`007_oooom7o`00ofKoo`003ooo
ool001Gooooo0ol00?mAooooo`?oo`00J?oooom7o`00ofKoo`003oooool001Gooooo0ol00?lQoooo
o`?o003o2oooool3o`00oh[oooooAol00?mVool000oooooo000Eooooo`?o003o8Oooool3o`00o`_o
oooo0ol00?n:ooooodCo003oJOoo000?ooooo`00>Oooool3o`00o`_ooooo0ol00?n:ooooodCo003o
JOoo000?ooooo`00=?ooool3o`00oigoooooA?l00?mYool000oooooo000@ooooo`?o003o8Oooool3
o`00oigooooo?Ol00?m`ool000oooooo000@ooooo`?o003o8Oooool3o`00oigooooo?Ol00?m`ool0
00oooooo000@ooooo`?o003oU?ooool3ool002[ooooo?Ol00?m`ool000oooooo002Wooooo`?oo`00
:_oooolmo`00og3oo`003oooool00:Oooooo0ooo000Zoooooc[o003oLooo000?ooooo`006?ooool3
o`00occooooo0ooo000Iooooo`?oo`00G_ooooljo`00og?oo`003oooool001Sooooo0ol00?lloooo
o`?oo`006Oooool3ool005kooooo>_l00?mcool000oooooo000Hooooo`?o003o??ooool3ool001Wo
oooo0ooo0009ooooo`?oo`00D_ooooljo`00og?oo`003oooool004oooooo0ooo000]ooooo`?oo`00
D_ooooljo`00og?oo`003oooool003cooooo0ol00?l@ooooo`?oo`00;Oooool3ool005;ooooo>_l0
0?mcool000oooooo000iooooo`Ko003o4?ooool3ool001_ooooo0ooo0004ooooo`?oo`00GOoooolj
o`00og?oo`003oooool003Wooooo1_l00?l^ooooo`?oo`001?ooool3ool005gooooo=ol00?mfool0
00oooooo000iooooo`?o003o7oooool3ool000oooooo0ooo0004ooooo`?oo`00GOoooolgo`00ogKo
o`003oooool005_ooooo1_oo001cooooocOo003oM_oo000?ooooo`00Foooool6ool007?ooooo<ol0
0?mjool000oooooo001Nooooo`?oo`00Looooolco`00og[oo`003oooool002Kooooo0ol00?n[oooo
oc?o003oN_oo000?ooooo`009_ooool3o`00oaKooooo0ooo000oooooo`?oo`00D?ooool/o`00oh7o
o`003oooool002Kooooo0ol00?lFooooo`?oo`0000Coooooool00?oo003oo`00>oooool3ool0053o
oooo;?l00?n1ool000oooooo000oooooo`?oo`0000Coooooool00?oo003oo`006_ooool3ool000ko
oooo0ooo000=ooooo`?oo`00;?ooool3ool0027ooooo;?l00?n1ool000oooooo0013ooooo`?oo`00
6_ooool3ool000kooooo0ooo000looooo`?oo`008Oooool/o`00oh7oo`003oooool005_ooooo0ooo
0002ooooo`?oo`003_ooool3ool003cooooo0ooo000QooooobWo003oQ?oo000?ooooo`00:_ooool3
o`00o`;ooooo0ol00?lYooooo`?oo`00DOooool3ool002;ooooo:Ol00?n4ool000oooooo000Zoooo
o`?o003o0_ooool3o`00obWooooo0ooo001Aooooo`?oo`008_oooolYo`00ohCoo`003oooool002[o
oooo0ol00?l2ooooo`?o003oGOooool3ool001gooooo0ooo000RooooobKo003oQooo000?ooooo`00
8_ooool3o`00o`Gooooo0ol00?mRooooo`?oo`00@_oooolVo`00ohOoo`003oooool002;ooooo0ol0
0?mXooooo`Goo`00@_oooolVo`00ohOoo`003oooool002;ooooo0ol00?lNooooo`?oo`00<_ooool3
ool001;ooooo0ooo0014ooooob;o003oRooo000?ooooo`00@oooool3ool003;ooooo0ooo000Boooo
o`?oo`00A?oooolRo`00oh_oo`003oooool0013ooooo0ol00?l`ooooo`Koo`00;oooool3ool003Wo
oooo0ooo000Mooooob;o003oRooo000?ooooo`003oooool4o`00oc?ooooo0ooo000Tooooo`?oo`00
A?ooool3ool001gooooo8_l00?n;ool000oooooo000?ooooo`Co003o<oooool3ool002Cooooo0ooo
0014ooooo`?oo`007OoooolKo`00oi;oo`003oooool000oooooo0ol00?lZooooo`?oo`00;_ooool3
ool006Cooooo6ol00?nBool000oooooo000Kooooo`?o003o7_ooool3ool009Gooooo6ol00?nBool0
00oooooo000Kooooo`?o003o7_ooool3ool003Oooooo0ooo001KoooooaSo003oUOoo000?ooooo`00
6oooool3o`00oeSooooo0ooo000mooooo`?oo`006ooooolHo`00oiGoo`003oooool007Kooooo0ooo
000]ooooo`?oo`003Oooool3ool001_ooooo6?l00?nEool000oooooo000Hooooo`?o003oRoooool3
ool000gooooo0ooo000KoooooaGo003oV?oo000?ooooo`006?ooool3o`00oh_ooooo0ooo000[oooo
oaGo003oV?oo000?ooooo`006?ooool3o`00of_ooooo0ooo001;oooooaGo003oV?oo000?ooooo`00
8oooool3ool0063ooooo0ooo000@ooooo`?oo`00>?oooolEo`00oiSoo`003oooool002?ooooo0ooo
000Hooooo`?oo`00AOooool3ool0013ooooo0ooo000hoooooa7o003oW?oo000?ooooo`008oooool3
ool001Sooooo0ooo001Hooooo`?oo`00>?oooolAo`00oicoo`003oooool003kooooo0ooo000]oooo
o`?oo`00;Oooool3ool003?ooooo4Ol00?nLool000oooooo001^ooooo`?oo`00;Oooool3ool003?o
oooo3_l00?nOool000oooooo001Gooooo`?oo`005?ooool3ool002gooooo0ooo000cooooo`ko003o
Wooo000?ooooo`00Eoooool3ool007[ooooo3_l00?nOool000oooooo000Jooooo`Coo`00>Oooool3
ool007[ooooo1ol00?nVool000oooooo000Jooooo`Coo`00T_ooool3ool0027ooooo1ol00?nVool0
00oooooo000Dooooo`?o003o0oooool4ool0097ooooo1?oo000Qooooo`Oo003oY_oo000?ooooo`00
5?ooool3o`00o`Kooooo0ooo002?ooooo`Coo`008Oooool7o`00ojKoo`003oooool001Cooooo0ol0
0?l6ooooo`?oo`00Soooool3ool002;ooooo1?l00?nYool000oooooo000Hooooo`?oo`000_ooool3
ool009;ooooo0ooo000Oooooo`Co003oZOoo000?ooooo`006?ooool3ool009Oooooo0ooo000Ooooo
o`Co003oZOoo000?ooooo`006?ooool3ool003;ooooo0ooo001Rooooo`Koo`007?oooon]ool000oo
oooo001=ooooo`?oo`00IOooool3ool001cooooo[Ooo000?ooooo`00COooool3ool006Gooooo0ooo
000Looooojgoo`003oooool002kooooo1Ooo002Qooooojgoo`003oooool002kooooo1Ooo002Qoooo
ojgoo`003oooool002kooooo1Ooo002Qooooojgoo`003oooool006_ooooo0ooo000>ooooo`?oo`00
<Oooool5ool001oooooo[Ooo000?ooooo`00F?ooool3ool0013ooooo0ooo000>ooooo`?oo`00<Ooo
ool5ool00=_ooooo001Hooooo`?oo`001?ooool3ool000Wooooo0ooo000>ooooo`?oo`00<Oooool5
ool000?ooooo0ooo003Eooooo`00F?ooool3ool000Cooooo0ooo001Fooooo`?oo`00eOooool005oo
oooo0ooo001Fooooo`?oo`00eOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-1.1227, \
-1.0611, 0.011199, 0.011199}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-63.1851, -2.62981, 0.296885, 0.296885}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example C: Gaussian distributions", "Section"],

Cell[CellGroupData[{

Cell["Generate data from two Gaussian classes", "Subsection"],

Cell[CellGroupData[{

Cell["Definition of Gaussians", "Subsubsection"],

Cell[BoxData[{
    \(\(\[Mu]1\  = \ { .3,  .3};\)\), "\n", 
    \(\(\[CapitalSigma]1\  = \  .07 {{1. , \(- .5\)}, {\(- .5\),  \
.5}};\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\(\[Mu]2\  = \ {\(- .5\), \(- .5\)};\)\), "\n", 
    \(\(\[CapitalSigma]2\  = \  .04 {{1. , \(- .5\)}, {\(- .5\),  \
.5}};\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[{
    \(\(n1\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(n2\  = \ 100;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = \ 
        Table[rgBounded[{\[Mu]1, \ \[CapitalSigma]1}, pr], {n1}];\)\), "\n", 
    \(\(data2\  = \ 
        Table[rgBounded[{\[Mu]2, \ \[CapitalSigma]2}, 
            pr], {n2}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[data2, pr, style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ 
        Show[gd1, gd2, \ yS, \ FrameTicks \[Rule] None];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.5902 .67744 Mdot
.46312 .69733 Mdot
.59214 .53131 Mdot
.46047 .74158 Mdot
.56465 .66203 Mdot
.8086 .66246 Mdot
.66851 .63894 Mdot
.6967 .72251 Mdot
.72341 .60342 Mdot
.71878 .66901 Mdot
.54356 .73479 Mdot
.70809 .62644 Mdot
.73555 .57647 Mdot
.51893 .72568 Mdot
.69445 .68162 Mdot
.86374 .51921 Mdot
.60122 .65645 Mdot
.79267 .44651 Mdot
.60333 .65744 Mdot
.57936 .65105 Mdot
.43142 .65685 Mdot
.40946 .79986 Mdot
.69034 .70844 Mdot
.46457 .79237 Mdot
.61399 .71665 Mdot
.75952 .57432 Mdot
.88123 .63337 Mdot
.8185 .55277 Mdot
.39649 .75812 Mdot
.76087 .66901 Mdot
.85397 .50058 Mdot
.51365 .7029 Mdot
.54694 .8159 Mdot
.80613 .6079 Mdot
.73421 .63919 Mdot
.49962 .61552 Mdot
.65331 .63926 Mdot
.60361 .59322 Mdot
.63024 .63471 Mdot
.59731 .51057 Mdot
.69356 .6664 Mdot
.54871 .67263 Mdot
.66198 .71319 Mdot
.90975 .55629 Mdot
.80431 .52758 Mdot
.75625 .58565 Mdot
.69275 .57438 Mdot
.58929 .74095 Mdot
.75998 .59643 Mdot
.43925 .66107 Mdot
.60718 .71259 Mdot
.88537 .43158 Mdot
.66189 .65123 Mdot
.57667 .76942 Mdot
.7947 .53318 Mdot
.62389 .76832 Mdot
.98273 .4782 Mdot
.60896 .73721 Mdot
.72618 .69634 Mdot
.67495 .63315 Mdot
.70492 .67363 Mdot
.60561 .69606 Mdot
.68617 .6044 Mdot
.56563 .69788 Mdot
.6306 .62978 Mdot
.74147 .67165 Mdot
.68223 .553 Mdot
.8317 .47934 Mdot
.68727 .54651 Mdot
.5451 .66571 Mdot
.41576 .67613 Mdot
.56079 .65155 Mdot
.49359 .76175 Mdot
.64288 .69711 Mdot
.52028 .67776 Mdot
.65653 .62883 Mdot
.73958 .55973 Mdot
.5496 .64292 Mdot
.8551 .61587 Mdot
.64292 .55537 Mdot
.61093 .71583 Mdot
.71202 .66146 Mdot
.6145 .60683 Mdot
.33066 .77464 Mdot
.61427 .77847 Mdot
.61824 .76947 Mdot
.60947 .61414 Mdot
.44477 .76145 Mdot
.77685 .43763 Mdot
.70438 .58177 Mdot
.63668 .62325 Mdot
.78474 .63249 Mdot
.43564 .82125 Mdot
.74993 .58211 Mdot
.60741 .59623 Mdot
.54654 .7276 Mdot
.46181 .78419 Mdot
.75383 .66573 Mdot
.63838 .58889 Mdot
.50919 .60134 Mdot
0 0 1 r
.34627 .18054 Mdot
.30961 .15807 Mdot
.27877 .28141 Mdot
.24307 .23825 Mdot
.28126 .1827 Mdot
.26246 .15953 Mdot
.25401 .25216 Mdot
.19332 .32918 Mdot
.20476 .24262 Mdot
.32488 .31113 Mdot
.43744 .10485 Mdot
.36357 .1943 Mdot
.23122 .21897 Mdot
.26625 .21923 Mdot
.33078 .21361 Mdot
.39658 .18052 Mdot
.25803 .30573 Mdot
.37693 .15396 Mdot
.26102 .24521 Mdot
.24428 .30309 Mdot
.23991 .23367 Mdot
.18879 .3284 Mdot
.27406 .26595 Mdot
.07351 .45426 Mdot
.08025 .35445 Mdot
.07781 .3011 Mdot
.13429 .32289 Mdot
.19345 .26896 Mdot
.25682 .26574 Mdot
.18025 .23875 Mdot
.2392 .27217 Mdot
.20549 .29636 Mdot
.08646 .26333 Mdot
.40762 .19309 Mdot
.09606 .36719 Mdot
.18278 .21378 Mdot
.54494 .06818 Mdot
.41223 .24141 Mdot
.14142 .31164 Mdot
.10444 .30398 Mdot
.2448 .30784 Mdot
.30016 .21057 Mdot
.34137 .18945 Mdot
.2036 .32631 Mdot
.17641 .2968 Mdot
.3693 .14734 Mdot
.28549 .17826 Mdot
.39086 .15238 Mdot
.19443 .21863 Mdot
.18672 .29753 Mdot
.40011 .26151 Mdot
.32658 .29642 Mdot
.26558 .32834 Mdot
.25593 .30277 Mdot
.22802 .18142 Mdot
.47629 .08051 Mdot
.25036 .31205 Mdot
.33176 .22013 Mdot
.36174 .23539 Mdot
.26844 .19855 Mdot
.19761 .241 Mdot
.18624 .24387 Mdot
.12632 .32736 Mdot
.12715 .35725 Mdot
.26082 .27556 Mdot
.15578 .19966 Mdot
.23157 .2924 Mdot
.16002 .32183 Mdot
.21901 .37384 Mdot
.35656 .1897 Mdot
.28885 .27257 Mdot
.26726 .26384 Mdot
.02331 .34732 Mdot
.11706 .29957 Mdot
.34142 .22452 Mdot
.40696 .27004 Mdot
.28679 .20446 Mdot
.22887 .26714 Mdot
.22333 .26459 Mdot
.38478 .20154 Mdot
.25202 .28039 Mdot
.3077 .23751 Mdot
.42243 .20874 Mdot
.28383 .22173 Mdot
.04772 .32528 Mdot
.19952 .32635 Mdot
.1306 .31796 Mdot
.29542 .28512 Mdot
.20571 .24033 Mdot
.23693 .20504 Mdot
.30538 .25448 Mdot
.18219 .19592 Mdot
.28891 .21704 Mdot
.14445 .25356 Mdot
.28102 .20049 Mdot
.24852 .18777 Mdot
.24467 .3047 Mdot
.20496 .29045 Mdot
.28214 .14275 Mdot
.2754 .31139 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool3o`00oh3ooooo0Ol00001ooooo`0000?o
0000ooooooooool0Uoooool5o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0Uoooool5
o`00ogoooooo0Ol00001ooooo`0000?o0000ooooooooool0Uoooool5o`00ogoooooo0Ol00001oooo
o`0000?o0000ooooooooool0Q?ooool3o`00oa7ooooo0ol00?n0ooooo`7o00000Oooool00003o`00
0?oooooooooo08?ooooo1Ol00?nCooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1Ol0
0?nCooooo`7o00000Oooool00003o`000?oooooooooo08?ooooo1Ol00?nCooooo`7o00000Oooool0
0003o`000?oooooooooo08Cooooo0ol00?nDooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0NOooool3o`00oioooooo0Ol00001ooooo`0000?o0000ooooooooool0N?ooool5
o`00oikooooo0Ol00001ooooo`0000?o0000ooooooooool0N?ooool5o`00oikooooo0Ol00001oooo
o`0000?o0000ooooooooool0N?ooool5o`00oikooooo0Ol00001ooooo`0000?o0000ooooooooool0
NOooool3o`00oioooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0C?ooool3o`00olcooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Boooool5o`00oaGooooo0ol00?ncooooo`7o00000Oooool00003o`000?oooooooooo04_o
oooo1Ol00?lDooooo`Go003o/_ooool1o`00007ooooo00000ol0003oooooooooo`1;ooooo`Go003o
5?ooool6o`00o`04ooooool00?oo003oo`00ojgooooo0Ol00001ooooo`0000?o0000ooooooooool0
C?ooool3o`00o`Gooooo0ol00?l=ooooo`_o003o[?ooool1o`00007ooooo00000ol0003ooooooooo
o`17ooooo`?o003o2Oooool5o`00o`gooooo2_l00?n/ooooo`7o00000Oooool00003o`000?oooooo
oooo04Kooooo1Ol00?l8ooooo`Go003o3_ooool9o`00ojcooooo0Ol00001ooooo`0000?o0000oooo
ooooool0A_ooool5o`00o`Sooooo1Ol00?l?ooooo`?o003o00Coooooo`00ool00?oo003o[Oooool1
o`00007ooooo00000ol0003oooooooooo`16ooooo`Go003o2Oooool3o`00olCooooo0Ol00001oooo
o`0000?o0000ooooooooool0Aoooool3o`00om7ooooo0Ol00001ooooo`0000?o0000ooooooooool0
COooool3o`00ol_ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool3o`00o`cooooo1Ol0
0?l>ooooo`?o003o2oooool3o`00oj_ooooo0Ol00001ooooo`0000?o0000ooooooooool0??ooool5
o`00o`[ooooo1_l00?l=ooooo`Go003o2Oooool5o`00oj[ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0??ooool5o`00o`;ooooo0ol00?l5ooooo`Ko003o3?ooool8o`00o`Oooooo1Ol00?nZoooo
o`7o00000Oooool00003o`000?oooooooooo03cooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Co
oooo1Ol00?l<ooooo`[o003o1_ooool7o`00ojSooooo0Ol00001ooooo`0000?o0000ooooooooool0
<?ooool3o`00o`[ooooo0ol00?l2ooooo`Go003o1Oooool3o`00o`gooooo2ol00?l6ooooo`Oo003o
Yoooool1o`00007ooooo00000ol0003oooooooooo`0Xooooo`?o003o1?ooool5o`00o`kooooo1Ol0
0?l01Ooooooo003oo`00ool00?oooooo00?o003o3Oooool<o`00o`Oooooo1Ol00?nWooooo`7o0000
0Oooool00003o`000?oooooooooo02Oooooo1Ol00?l3ooooo`Go003o3oooool3o`00o`03ooooool0
0?oo003o00Oo003o3Oooool3o`00o`;ooooo1_l00?l2ooooo`?o003o0_ooool5o`00ojOooooo0Ol0
0001ooooo`0000?o0000ooooooooool09oooool5o`00o`?ooooo1Ol00?l;ooooo`?o003o1Oooool:
o`00oa;ooooo1Ol00?l00ooooooo003oo`00o`03o`00o`;ooooo0ol00?nXooooo`7o00000Oooool0
0003o`000?oooooooooo02Oooooo1Ol00?l4ooooo`?o003o2oooool5o`00o`Cooooo3Ol00?l@oooo
o`?o003o0_ooool5o`00o`Kooooo0ol00?nTooooo`7o00000Oooool00003o`000?oooooooooo02So
oooo0ol00?l5ooooo`?o003o2oooool5o`00o`Gooooo0ol00?l00ooooooo003oo`00o`07o`00o`Go
oooo0ol00?l<ooooo`Go003o1Oooool5o`00oj?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
;oooool5o`00o`[ooooo1Ol00?l:ooooo`So003o1?ooool5o`00o`cooooo0ol00?l6ooooo`Go003o
Xoooool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`Oo003o2?ooool4o`00o`Kooooo0ol0
0?l2ooooo`So003o1?ooool5o`00oaGooooo1Ol00?nSooooo`7o00000Oooool00003o`000?oooooo
oooo02oooooo2?l00?l6ooooo`Go003o1Oooool5o`00o`03ooooool00?oo003o00Go003o1Oooool7
o`00oaCooooo0ol00?nTooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1ol00?l6oooo
o`Go003o1Oooool;o`00o`Oooooo2?l00?njooooo`7o00000Oooool00003o`000?oooooooooo03;o
oooo1Ol00?l6ooooo`Go003o1Oooool:o`00o`Sooooo2?l00?njooooo`7o00000Oooool00003o`00
0?oooooooooo03?ooooo0ol00?l8ooooo`Go003o1Oooool3o`00o`03ooooool00?oo003o00?o003o
2Oooool7o`00o`;ooooo0ol00?neooooo`7o00000Oooool00003o`000?oooooooooo02oooooo0ol0
0?l=ooooo`Go003o2Oooool3o`00o`Cooooo0ol00?l6ooooo`?o003o0_ooool5o`00okCooooo0Ol0
0001ooooo`0000?o0000ooooooooool0;_ooool5o`00o`03ooooool00?oo003o00?o003o1_ooool6
o`00o`kooooo1Ol00?l:ooooo`Go003o2oooool3o`00ojKooooo0Ol00001ooooo`0000?o0000oooo
ooooool0;_ooool<o`00o`Gooooo1_l00?l01?oooooo003oo`00ool00?l:ooooo`Go003o2_ooool5
o`00o`[ooooo1Ol00?nUooooo`7o00000Oooool00003o`000?oooooooooo02kooooo3?l00?l6oooo
o`[o003o2Oooool5o`00o`_ooooo0ol00?l;ooooo`Go003oYOooool1o`00007ooooo00000ol0003o
ooooooooo`0_ooooo`_o003o1oooool9o`00o`[ooooo0ol00?lJooooo`Go003oYOooool1o`00007o
oooo00000ol0003oooooooooo`0Uooooo`?o003o2?ooool:o`00o`Wooooo1ol00?l9ooooo`?o003o
7?ooool3o`00ojKooooo0Ol00001ooooo`0000?o0000ooooooooool09?ooool5o`00o`Sooooo0ol0
0?l2ooooo`?o003o2_ooool6o`00o`Wooooo1Ol00?o4ooooo`7o00000Oooool00003o`000?oooooo
oooo01Cooooo0ol00?l=ooooo`Go003o6_ooool5o`00o`[ooooo1Ol00?lGooooo`?o003oZ_ooool1
o`00007ooooo00000ol0003oooooooooo`0Cooooo`Go003o3?ooool5o`00oa;ooooo0ol00?l6oooo
o`Wo003o1Oooool5o`00oaKooooo1Ol00?nYooooo`7o00000Oooool00003o`000?oooooooooo01?o
oooo1Ol00?l=ooooo`?o003o2oooool3o`00o`Cooooo1_l00?l4ooooo`[o003o1Oooool3o`00oaOo
oooo1_l00?nXooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo1Ol00?lJooooo`Go003o
0oooool9o`00o`03ooooool00?oo003o00_o003o7?ooool7o`00ojOooooo0Ol00001ooooo`0000?o
0000ooooooooool05?ooool3o`00oa_ooooo1Ol00?l3oooooaSo003o7?ooool6o`00ojOooooo0Ol0
0001ooooo`0000?o0000ooooooooool0<_ooool5o`00o`Cooooo5ol00?lMooooo`Go003oYoooool1
o`00007ooooo00000ol0003oooooooooo`0cooooo`?o003o1oooool=o`00o`03ooooool00?oo003o
00Go003o7_ooool3o`00ojSooooo0Ol00001ooooo`0000?o0000ooooooooool0@?oooolCo`00olSo
oooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool3o`00o`[ooooo1_l00?l00ooooooo003o
o`00o`08o`00olOooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool5o`00o`Cooooo0ol0
0?l3ooooo`?o003o0oooool:o`00olOooooo0Ol00001ooooo`0000?o0000ooooooooool0;_ooool6
o`00o`03ooooool00?oo003o00?o003o0oooool5o`00o`Wooooo0ol00?l00ooooooo003oo`00o`03
o`00o`Gooooo0ol00?noooooo`7o00000Oooool00003o`000?oooooooooo01;ooooo0ol00?l8oooo
o`?o003o3Oooool=o`00o`?ooooo1Ol00?l>ooooo`?o003o1Oooool5o`00okkooooo0Ol00001oooo
o`0000?o0000ooooooooool04Oooool5o`00o`?ooooo2?l00?l<ooooo`go003o0oooool7o`00o`04
ooooool00?oo003oo`00oa3ooooo1Ol00?nnooooo`7o00000Oooool00003o`000?oooooooooo017o
oooo1Ol00?l2ooooo`Wo003o3?ooool=o`00o`Cooooo2ol00?l?ooooo`Go003o__ooool1o`00007o
oooo00000ol0003oooooooooo`0Aooooo`Go003o0_ooool9o`00o`?ooooo0ol00?l7ooooo`Ko003o
0_ooool3o`00o`Oooooo2Ol00?l01?oooooo003oo`00ool00?l;ooooo`Co003o_oooool1o`00007o
oooo00000ol0003oooooooooo`0Booooo`?o003o0oooool8o`00o`?ooooo1Ol00?lHooooo`ko003o
2Oooool5o`00okoooooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool3o`00o`Gooooo1ol0
0?lIooooo`go003o2Oooool5o`00okoooooo0Ol00001ooooo`0000?o0000ooooooooool08?ooool8
o`00o`04ooooool00?oo003oo`00oaKooooo1_l00?l00ooooooo003oo`00o`03o`00o`Wooooo1Ol0
0?noooooo`7o00000Oooool00003o`000?oooooooooo00Wooooo0ol00?lDooooo`Oo003o00?ooooo
o`00ool00?l00ol00?lFooooo`?o003o1?ooool3o`00o`_ooooo0ol00?o0ooooo`7o00000Oooool0
0003o`000?oooooooooo00Sooooo1Ol00?lCooooo`Ko003o0_ooool5o`00o`Cooooo2?l00?l>oooo
o`?o003odOooool1o`00007ooooo00000ol0003oooooooooo`08ooooo`Go003o4_ooool7o`00o`;o
oooo1Ol00?l3ooooo`[o003o3?ooool5o`00om3ooooo0Ol00001ooooo`0000?o0000ooooooooool0
2?ooool5o`00oa;ooooo1ol00?l3ooooo`?o003o1?ooool:o`00o`cooooo1Ol00?o@ooooo`7o0000
0Oooool00003o`000?oooooooooo00Wooooo0ol00?lCooooo`Ko003o2oooool:o`00o`cooooo1Ol0
0?o@ooooo`7o00000Oooool00003o`000?oooooooooo023ooooo0ol00?l>ooooo`So003o3_ooool3
o`00om7ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo00;ooooo0ol00?oooooooaOooooo0Ol00001ooooo`0000Co0000oooooooooooo
oooo1Ol00?oooooooaKooooo0Ol00001ooooo`0000Co0000oooooooooooooooo1Ol00?l<ooooo`?o
003o2oooool3o`00ooSooooo0Ol00001ooooo`0000Co0000oooooooooooooooo1Ol00?l;ooooo`Go
003o2Oooool5o`00ooOooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool3o`00o`cooooo
1Ol00?l9ooooo`Go003omoooool1o`00007ooooo00000ol0003oooooooooo`0Aooooo`Go003o00Co
ooooo`00ool00?oo003o1Oooool5o`00ooOooooo0Ol00001ooooo`0000?o0000ooooooooool04_oo
ool3o`00o`03ooooool00?oo003o00?o003o1Oooool3o`00ooSooooo0Ol00001ooooo`0000?o0000
ooooooooool05_ooool5o`00oaoooooo0ol00?oNooooo`7o00000Oooool00003o`000?oooooooooo
01Kooooo1Ol00?lNooooo`Go003ogOooool1o`00007ooooo00000ol0003oooooooooo`0Gooooo`?o
003o7oooool5o`00omgooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool5o`00omgooooo
0Ol00001ooooo`0000?o0000ooooooooool0>_ooool3o`00omkooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0nOooool3ool001oooooo0Ol00001ooooo`00
00?o0000ooooooooool0f_ooool3ool001_ooooo1Ooo000Nooooo`7o00000Oooool00003o`000?oo
oooooooo0=Wooooo1Ooo000Jooooo`Goo`007_ooool1o`00007ooooo00000ol0003oooooooooo`3I
ooooo`Goo`006_ooool5ool001kooooo0Ol00001ooooo`0000?o0000ooooooooool0fOooool5ool0
0004oooooooo003oo`00ool001Oooooo0ooo000Oooooo`7o00000Oooool00003o`000?oooooooooo
0=[ooooo0ooo00000oooooooo`00ool00003ool003Sooooo0Ol00001ooooo`0000?o0000oooooooo
ool04?ooool3o`00ol_ooooo1Ooo000hooooo`7o00000Oooool00003o`000?oooooooooo00oooooo
1Ol00?o:ooooo`Goo`00>?ooool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`Go003obooo
ool3ool003Wooooo0Ol00001ooooo`0000?o0000ooooooooool03oooool5o`00oooooooo2?ooool1
o`00007ooooo00000ol0003oooooooooo`0@ooooo`?o003oooooool9ooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0j_ooool3ool002Sooooo0ooo0003ooooo`7o00000Ooo
ool00003o`000?oooooooooo0>Wooooo1Ooo000Vooooo`Goo`000_ooool1o`00007ooooo00000ol0
003oooooooooo`3Yooooo`Goo`009_ooool5ool000;ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0jOooool5ool002Kooooo1Ooo0002ooooo`7o00000Oooool00003o`000?oooooooooo0>[ooooo
0ooo000Xooooo`?oo`000oooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0l?ooool3ool002Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool0koooool5ool002Oooooo0Ol00001ooooo`0000?o0000ooooooooool0koooool5ool002Oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0Yoooool3ool004Gooooo1Ooo000Wooooo`7o0000
0Oooool00003o`000?oooooooooo0:Kooooo1Ooo0015ooooo`?oo`00:?ooool1o`00007ooooo0000
0ol0003oooooooooo`2Vooooo`Goo`00L?ooool1o`00007ooooo00000ol0003oooooooooo`2Voooo
o`Goo`00B?ooool3ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0Yoooool3ool004So
oooo1Ooo000Tooooo`7o00000Oooool00003o`000?oooooooooo0>;ooooo0ooo000=ooooo`Goo`00
9?ooool1o`00007ooooo00000ol0003oooooooooo`2Uooooo`?oo`00>Oooool5ool000cooooo1Ooo
000Tooooo`7o00000Oooool00003o`000?oooooooooo0:Cooooo1Ooo000fooooo`Ooo`003Oooool3
ool002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0Y?ooool5ool003Gooooo2?oo000eoooo
o`7o00000Oooool00003o`000?oooooooooo0:Cooooo1Ooo000eooooo`Ooo`00=_ooool1o`00007o
oooo00000ol0003oooooooooo`2Uooooo`?oo`00=_ooool5ool003Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0`?ooool3ool001cooooo0ooo000iooooo`7o00000Oooool00003o`000?oooooo
oooo0;oooooo1Ooo000Rooooo`?oo`00<_ooool1o`00007ooooo00000ol0003oooooooooo`2doooo
o`?oo`002?ooool5ool0027ooooo1Ooo000Fooooo`?oo`006?ooool1o`00007ooooo00000ol0003o
ooooooooo`2cooooo`Goo`001_ooool6ool000_ooooo0ooo000Cooooo`Goo`005Oooool5ool001Oo
oooo0Ol00001ooooo`0000?o0000ooooooooool0/oooool5ool000Kooooo1Ooo000;ooooo`Goo`00
4_ooool5ool001Gooooo1Ooo000Gooooo`7o00000Oooool00003o`000?oooooooooo0;?ooooo1Ooo
0006ooooo`Goo`002oooool5ool001?ooooo0ooo000Fooooo`Goo`005oooool1o`00007ooooo0000
0ol0003oooooooooo`2dooooo`?oo`002?ooool3ool000cooooo1Ooo000]ooooo`?oo`006?ooool1
o`00007ooooo00000ol0003oooooooooo`3?ooooo`?oo`00BOooool1o`00007ooooo00000ol0003o
ooooooooo`32ooooo`?oo`002Oooool3ool000Cooooo0ooo0013ooooo`7o00000Oooool00003o`00
0?oooooooooo0<7ooooo1Ooo0007ooooo`Goo`000_ooool5ool004;ooooo0Ol00001ooooo`0000?o
0000ooooooooool0`Oooool7ool000Gooooo3?oo0012ooooo`7o00000Oooool00003o`000?oooooo
oooo0<7ooooo2?oo0004ooooo`coo`00@_ooool1o`00007ooooo00000ol0003oooooooooo`2boooo
o`?oo`003Oooool7ool000Gooooo2_oo0013ooooo`7o00000Oooool00003o`000?oooooooooo0:So
oooo0ooo0006ooooo`Goo`003_ooool5ool000Sooooo1ooo0013ooooo`7o00000Oooool00003o`00
0?oooooooooo0:Oooooo1Ooo0005ooooo`Goo`003oooool3ool000[ooooo1_oo0013ooooo`7o0000
0Oooool00003o`000?oooooooooo08gooooo0ooo000Gooooo`Koo`001?ooool5ool001kooooo1Ooo
0012ooooo`7o00000Oooool00003o`000?oooooooooo08cooooo1Ooo000Fooooo`Koo`001Oooool3
ool000_ooooo0ooo0008ooooo`?oo`001_ooool5ool004;ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0S?ooool5ool001Oooooo1ooo000@ooooo`Goo`001_ooool5ool000Gooooo1Ooo0009oooo
o`?oo`00=_ooool1o`00007ooooo00000ol0003oooooooooo`2<ooooo`Goo`006?ooool7ool000oo
oooo1Ooo0006ooooo`Goo`001_ooool3ool000Wooooo1Ooo000eooooo`7o00000Oooool00003o`00
0?oooooooooo08_ooooo1Ooo000Jooooo`Koo`003oooool5ool000Kooooo1Ooo000Booooo`Goo`00
=Oooool1o`00007ooooo00000ol0003oooooooooo`2:ooooo`Goo`006_ooool7ool0013ooooo0ooo
0008ooooo`?oo`004oooool5ool000_ooooo0ooo000Wooooo`7o00000Oooool00003o`000?oooooo
oooo08[ooooo1Ooo000Jooooo`Koo`00<oooool3ool000_ooooo1Ooo000Vooooo`7o00000Oooool0
0003o`000?oooooooooo08[ooooo1Ooo000Jooooo`Goo`001?ooool3ool003_ooooo1Ooo000Voooo
o`7o00000Oooool00003o`000?oooooooooo08_ooooo0ooo000Looooo`?oo`001?ooool5ool000;o
oooo0ooo000;ooooo`?oo`009oooool5ool002Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
/?ooool6ool00003oooooooo003oo`0000?oo`0000Coooooool00?oo003oo`001Oooool5ool001;o
oooo0ooo000Booooo`?oo`009oooool1o`00007ooooo00000ol0003oooooooooo`2_ooooo`Ooo`00
00?oooooool00?oo00002?oo0004ooooo`Goo`004Oooool5ool001Sooooo0ooo000Pooooo`7o0000
0Oooool00003o`000?oooooooooo0:oooooo1_oo0002ooooo`[oo`001?ooool5ool000Cooooo0ooo
000:ooooo`Goo`005oooool5ool001oooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool3
ool001?ooooo1Ooo0002ooooo`_oo`001Oooool3ool000Cooooo1Ooo0009ooooo`Goo`005oooool5
ool001oooooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool5ool001;ooooo1Ooo0002oooo
o`[oo`003Oooool5ool000[ooooo0ooo000Hooooo`Goo`007oooool1o`00007ooooo00000ol0003o
ooooooooo`2Hooooo`Goo`004oooool3ool000?ooooo2Ooo000>ooooo`Goo`009_ooool3ool0023o
oooo0Ol00001ooooo`0000?o0000ooooooooool0V?ooool7ool000;ooooo0ooo000Cooooo`Ooo`00
4?ooool3ool004[ooooo0Ol00001ooooo`0000?o0000ooooooooool0Moooool3ool001oooooo3?oo
0003ooooo`?oo`003Oooool5ool005kooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool6
ool001oooooo2_oo0002ooooo`Goo`003?ooool5ool005kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0M_ooool7ool001kooooo2_oo0002ooooo`Goo`003?ooool5ool000[ooooo0ooo000Ioooo
o`?oo`00=Oooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`Ooo`006oooool3ool00003
oooooooo003oo`0000Koo`000oooool5ool000gooooo0ooo0006ooooo`?oo`0000?oooooool00?oo
00000ooo0008ooooo`?oo`003?ooool5ool003Cooooo0Ol00001ooooo`0000?o0000ooooooooool0
Moooool6ool001[ooooo2_oo0007ooooo`?oo`005_ooool;ool000Kooooo1_oo000:ooooo`Goo`00
=?ooool1o`00007ooooo00000ol0003oooooooooo`1iooooo`?oo`006oooool:ool0023ooooo3?oo
0003ooooo`Woo`002Oooool5ool003Cooooo0Ol00001ooooo`0000?o0000ooooooooool0Loooool3
ool001_ooooo0ooo0003ooooo`Woo`001Oooool3ool001Wooooo3?oo0002ooooo`[oo`002_ooool3
ool003Gooooo0Ol00001ooooo`0000?o0000ooooooooool0L_ooool5ool001Wooooo1Ooo0003oooo
o`Goo`001oooool5ool001Wooooo2ooo0002ooooo`[oo`00@_ooool1o`00007ooooo00000ol0003o
ooooooooo`1booooo`Goo`006Oooool5ool000?ooooo1Ooo0007ooooo`Goo`006?ooool;ool000?o
oooo1Ooo00001?ooooooo`00ool00?oo0013ooooo`7o00000Oooool00003o`000?oooooooooo07;o
oooo1Ooo000Iooooo`Goo`001?ooool3ool000Sooooo1Ooo000Hooooo`Ooo`002?ooool3ool004So
oooo0Ol00001ooooo`0000?o0000ooooooooool0Loooool3ool001_ooooo0ooo000Aooooo`?oo`00
6Oooool5ool005Gooooo0Ol00001ooooo`0000?o0000ooooooooool0`_ooool3ool005Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0P?ooool3ool001_ooooo0ooo0008ooooo`?oo`002?ooool3
ool001Gooooo0ooo001<ooooo`7o00000Oooool00003o`000?oooooooooo07oooooo1Ooo000;oooo
o`?oo`002oooool5ool000Kooooo1Ooo0006ooooo`Goo`004oooool5ool004_ooooo0Ol00001oooo
o`0000?o0000ooooooooool0Ooooool5ool000[ooooo1Ooo000:ooooo`Goo`001_ooool5ool000Ko
oooo1Ooo000Cooooo`Goo`00Boooool1o`00007ooooo00000ol0003oooooooooo`1oooooo`Goo`00
2_ooool5ool000[ooooo1Ooo0006ooooo`Goo`001_ooool5ool000Wooooo0ooo0007ooooo`Goo`00
Boooool1o`00007ooooo00000ol0003oooooooooo`20ooooo`?oo`002oooool5ool000_ooooo0ooo
0008ooooo`?oo`002?ooool3ool000;ooooo0ooo0004ooooo`Goo`001oooool3ool004cooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Soooool3ool001Kooooo1_oo000:ooooo`Goo`000oooool5
ool005Kooooo0Ol00001ooooo`0000?o0000ooooooooool0Z?ooool7ool000Wooooo1Ooo0003oooo
o`Goo`00E_ooool1o`00007ooooo00000ol0003oooooooooo`2Xooooo`Ooo`002Oooool5ool000Co
oooo1Ooo001Eooooo`7o00000Oooool00003o`000?oooooooooo093ooooo0ooo000Fooooo`Koo`00
2_ooool3ool000Kooooo1Ooo001Dooooo`7o00000Oooool00003o`000?oooooooooo08oooooo1Ooo
0004ooooo`?oo`003oooool4ool001Cooooo1Ooo001Dooooo`7o00000Oooool00003o`000?oooooo
oooo08oooooo1Ooo0003ooooo`Goo`009_ooool5ool005Cooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Soooool5ool000?ooooo1Ooo000>ooooo`?oo`005_ooool3ool005Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0T?ooool3ool000?ooooo1_oo0008ooooo`?oo`000_ooool5ool006go
oooo0Ol00001ooooo`0000?o0000ooooooooool0Ooooool3ool001Cooooo1Ooo0008ooooo`Goo`00
00?oooooool00?oo00000ooo001]ooooo`7o00000Oooool00003o`000?oooooooooo07kooooo1Ooo
000Cooooo`Goo`002?ooool5ool00003oooooooo003oo`0000?oo`00KOooool1o`00007ooooo0000
0ol0003oooooooooo`1nooooo`Goo`005?ooool3ool000Wooooo1Ooo0002ooooo`?oo`00K_ooool1
o`00007ooooo00000ol0003oooooooooo`1nooooo`Goo`008Oooool3ool007Cooooo0Ol00001oooo
o`0000?o0000ooooooooool0KOooool3ool000oooooo0ooo002Iooooo`7o00000Oooool00003o`00
0?oooooooooo06cooooo1Ooo000:ooooo`?oo`002oooool3ool008oooooo0Ol00001ooooo`0000?o
0000ooooooooool0K?ooool5ool000Wooooo1Ooo0009ooooo`Goo`00S_ooool1o`00007ooooo0000
0ol0003oooooooooo`1/ooooo`Goo`002Oooool5ool000Wooooo1Ooo000Qooooo`?oo`00J_ooool1
o`00007ooooo00000ol0003oooooooooo`1]ooooo`?oo`002_ooool5ool000Wooooo1Ooo000Doooo
o`?oo`002Oooool5ool006Wooooo0Ol00001ooooo`0000?o0000ooooooooool0F_ooool3ool001ko
oooo0ooo000;ooooo`?oo`005?ooool5ool000Oooooo1_oo001Yooooo`7o00000Oooool00003o`00
0?oooooooooo05Wooooo1Ooo0012ooooo`Goo`001_ooool7ool006Wooooo0Ol00001ooooo`0000?o
0000ooooooooool0FOooool5ool004;ooooo1Ooo0005ooooo`Ooo`00J_ooool1o`00007ooooo0000
0ol0003oooooooooo`1Iooooo`Goo`008_ooool3ool001kooooo0ooo0006ooooo`Koo`00Joooool1
o`00007ooooo00000ol0003oooooooooo`1Jooooo`?oo`008_ooool5ool002Kooooo1Ooo001/oooo
o`7o00000Oooool00003o`000?oooooooooo07oooooo1Ooo000Wooooo`?oo`00KOooool1o`00007o
oooo00000ol0003oooooooooo`1oooooo`Koo`00U_ooool1o`00007ooooo00000ol0003ooooooooo
o`1aooooo`?oo`003?ooool5ool009Kooooo0Ol00001ooooo`0000?o0000ooooooooool0L?ooool5
ool000_ooooo1Ooo002Fooooo`7o00000Oooool00003o`000?oooooooooo073ooooo1Ooo000<oooo
o`?oo`00Uoooool1o`00007ooooo00000ol0003oooooooooo`1`ooooo`Goo`00Y_ooool1o`00007o
oooo00000ol0003oooooooooo`1aooooo`?oo`00Yoooool1o`00007ooooo00000ol0003ooooooooo
o`2Hooooo`?oo`00P?ooool1o`00007ooooo00000ol0003oooooooooo`1hooooo`?oo`007?ooool5
ool007oooooo0Ol00001ooooo`0000?o0000ooooooooool0Moooool5ool001_ooooo1Ooo001ooooo
o`7o00000Oooool00003o`000?oooooooooo07Oooooo1Ooo000Kooooo`Goo`00Ooooool1o`00007o
oooo00000ol0003oooooooooo`1gooooo`Goo`007?ooool3ool0083ooooo0Ol00001ooooo`0000?o
0000ooooooooool0N?ooool3ool00:3ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Uniform quantization", "Subsection"],

Cell[CellGroupData[{

Cell["Number of centroids in each direction", "Subsubsection"],

Cell[BoxData[
    \(\(nCentroids\  = \ 4;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute uniformly distributed centroids", "Subsubsection"],

Cell[BoxData[
    \(\(uniformCentroids\  = \ 
        UniformQuantization[pr[\([1]\)], pr[\([2]\)], 
          nCentroids];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gCentroids = \ 
        PlotData2D[uniformCentroids, pr, \ centroidStyle, 
          FrameTicks \[Rule] None];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 1 r
.02 w
.12871 .12871 Mdot
.12871 .37624 Mdot
.12871 .62377 Mdot
.12871 .8713 Mdot
.37624 .12871 Mdot
.37624 .37624 Mdot
.37624 .62377 Mdot
.37624 .8713 Mdot
.62377 .12871 Mdot
.62377 .37624 Mdot
.62377 .62377 Mdot
.62377 .8713 Mdot
.8713 .12871 Mdot
.8713 .37624 Mdot
.8713 .62377 Mdot
.8713 .8713 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool08?ooool3ool0odCooooo0ooo0?m4oooo
o`?oo`3oA?ooool3ool0ob?ooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool5ool0od;o
oooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
7oooool5ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol00001ooooo`0000?o
0000ooooooooool07oooool5ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol0
0001ooooo`0000?o0000ooooooooool08?ooool3ool0odCooooo0ooo0?m4ooooo`?oo`3oA?ooool3
ool0ob?ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool08?ooool3ool0odCooooo0ooo0?m4ooooo`?oo`3oA?ooool3ool0ob?o
oooo0Ol00001ooooo`0000?o0000ooooooooool07oooool5ool0od;ooooo1Ooo0?m2ooooo`Goo`3o
@_ooool5ool0ob;ooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool5ool0od;ooooo1Ooo
0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool5
ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol00001ooooo`0000?o0000oooo
ooooool08?ooool3ool0odCooooo0ooo0?m4ooooo`?oo`3oA?ooool3ool0ob?ooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
8?ooool3ool0odCooooo0ooo0?m4ooooo`?oo`3oA?ooool3ool0ob?ooooo0Ol00001ooooo`0000?o
0000ooooooooool07oooool5ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol0
0001ooooo`0000?o0000ooooooooool07oooool5ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5
ool0ob;ooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool5ool0od;ooooo1Ooo0?m2oooo
o`Goo`3o@_ooool5ool0ob;ooooo0Ol00001ooooo`0000?o0000ooooooooool08?ooool3ool0odCo
oooo0ooo0?m4ooooo`?oo`3oA?ooool3ool0ob?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool08?ooool3ool0odCooooo0ooo
0?m4ooooo`?oo`3oA?ooool3ool0ob?ooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool5
ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol00001ooooo`0000?o0000oooo
ooooool07oooool5ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;ooooo0Ol00001oooo
o`0000?o0000ooooooooool07oooool5ool0od;ooooo1Ooo0?m2ooooo`Goo`3o@_ooool5ool0ob;o
oooo0Ol00001ooooo`0000?o0000ooooooooool08?ooool3ool0odCooooo0ooo0?m4ooooo`?oo`3o
A?ooool3ool0ob?ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Histograms for two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Compute histograms based on uniform centroids", "Subsubsection"],

Cell[BoxData[{
    \(\(h1\  = Histogram[data1, uniformCentroids, pr, 50];\)\), "\n", 
    \(\(h2\  = Histogram[data2, uniformCentroids, pr, 50];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize two histograms", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gh1\  = 
        DrawHistogram[h1, pr, \ nS, \ 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(gh2\  = 
        DrawHistogram[h2, pr, \ nS, \ 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gh1, gh2}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
%%ImageSize: 400 154.502 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .57879 .48228 .57294 Mtetra
.48228 .57294 .48818 .57879 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57244 .5035 .56654 Mtetra
.5035 .56654 .50935 .57244 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .56009 Mtetra
.881 .451 .065 r
.52489 .56009 .53068 .56605 .54154 .58924 .53573 .58332 Mtetra
.662 .744 .911 r
.53573 .58332 .54154 .58924 .55239 .58604 .54661 .58009 Mtetra
.54661 .58009 .55239 .58604 .56329 .58282 .55754 .57685 Mtetra
.55754 .57685 .56329 .58282 .57423 .57959 .5685 .5736 Mtetra
.5685 .5736 .57423 .57959 .58521 .57635 .57952 .57033 Mtetra
.57952 .57033 .58521 .57635 .59624 .57309 .59057 .56705 Mtetra
.59057 .56705 .59624 .57309 .60731 .56983 .60167 .56376 Mtetra
.60167 .56376 .60731 .56983 .61843 .56654 .61282 .56045 Mtetra
.61282 .56045 .61843 .56654 .62959 .56325 .62401 .55713 Mtetra
.62401 .55713 .62959 .56325 .64079 .55994 .63524 .5538 Mtetra
.63524 .5538 .64079 .55994 .65204 .55662 .64652 .55046 Mtetra
.64652 .55046 .65204 .55662 .66334 .55329 .65785 .5471 Mtetra
.65785 .5471 .66334 .55329 .67467 .54994 .66922 .54373 Mtetra
.848 .779 .785 r
.66922 .54373 .67467 .54994 .68558 .53649 .68017 .53023 Mtetra
.662 .743 .91 r
.68017 .53023 .68558 .53649 .69697 .53311 .6916 .52682 Mtetra
.6916 .52682 .69697 .53311 .70842 .52971 .70307 .5234 Mtetra
.70307 .5234 .70842 .52971 .7199 .5263 .71459 .51996 Mtetra
.71459 .51996 .7199 .5263 .73144 .52287 .72616 .51651 Mtetra
.72616 .51651 .73144 .52287 .74302 .51943 .73777 .51304 Mtetra
.73777 .51304 .74302 .51943 .75465 .51598 .74943 .50956 Mtetra
.74943 .50956 .75465 .51598 .76633 .51251 .76114 .50607 Mtetra
.76114 .50607 .76633 .51251 .77805 .50903 .7729 .50256 Mtetra
.7729 .50256 .77805 .50903 .78982 .50553 .78471 .49904 Mtetra
.78471 .49904 .78982 .50553 .80164 .50202 .79656 .4955 Mtetra
.79656 .4955 .80164 .50202 .81351 .4985 .80847 .49195 Mtetra
.904 .787 .722 r
.80847 .49195 .81351 .4985 .8239 .47808 .81891 .47148 Mtetra
.664 .741 .908 r
.81891 .47148 .8239 .47808 .8358 .47451 .83085 .46788 Mtetra
.83085 .46788 .8358 .47451 .84775 .47092 .84283 .46427 Mtetra
.84283 .46427 .84775 .47092 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .45699 Mtetra
.86696 .45699 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57342 Mtetra
.45523 .57342 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55735 Mtetra
.50831 .55735 .51417 .56332 .52489 .56009 .51905 .5541 Mtetra
.881 .451 .065 r
.51905 .5541 .52489 .56009 .53573 .58332 .52987 .57735 Mtetra
.662 .744 .911 r
.52987 .57735 .53573 .58332 .54661 .58009 .54078 .5741 Mtetra
.54078 .5741 .54661 .58009 .55754 .57685 .55174 .57083 Mtetra
.55174 .57083 .55754 .57685 .5685 .5736 .56274 .56756 Mtetra
.56274 .56756 .5685 .5736 .57952 .57033 .57378 .56427 Mtetra
.57378 .56427 .57952 .57033 .59057 .56705 .58486 .56096 Mtetra
.58486 .56096 .59057 .56705 .60167 .56376 .59599 .55765 Mtetra
.59599 .55765 .60167 .56376 .61282 .56045 .60717 .55432 Mtetra
.60717 .55432 .61282 .56045 .62401 .55713 .61839 .55097 Mtetra
.61839 .55097 .62401 .55713 .63524 .5538 .62965 .54762 Mtetra
.62965 .54762 .63524 .5538 .64652 .55046 .64096 .54424 Mtetra
.64096 .54424 .64652 .55046 .65785 .5471 .65232 .54086 Mtetra
.65232 .54086 .65785 .5471 .66922 .54373 .66372 .53746 Mtetra
.848 .779 .785 r
.66372 .53746 .66922 .54373 .68017 .53023 .67472 .52393 Mtetra
.662 .743 .91 r
.67472 .52393 .68017 .53023 .6916 .52682 .68618 .52049 Mtetra
.68618 .52049 .6916 .52682 .70307 .5234 .69768 .51704 Mtetra
.69768 .51704 .70307 .5234 .71459 .51996 .70924 .51358 Mtetra
.70924 .51358 .71459 .51996 .72616 .51651 .72084 .5101 Mtetra
.72084 .5101 .72616 .51651 .73777 .51304 .73248 .50661 Mtetra
.73248 .50661 .73777 .51304 .74943 .50956 .74418 .5031 Mtetra
.74418 .5031 .74943 .50956 .76114 .50607 .75592 .49958 Mtetra
.75592 .49958 .76114 .50607 .7729 .50256 .76771 .49605 Mtetra
.76771 .49605 .7729 .50256 .78471 .49904 .77955 .4925 Mtetra
.77955 .4925 .78471 .49904 .79656 .4955 .79144 .48893 Mtetra
.79144 .48893 .79656 .4955 .80847 .49195 .80338 .48535 Mtetra
.904 .787 .722 r
.80338 .48535 .80847 .49195 .81891 .47148 .81388 .46482 Mtetra
.664 .741 .908 r
.81388 .46482 .81891 .47148 .83085 .46788 .82585 .4612 Mtetra
.82585 .4612 .83085 .46788 .84283 .46427 .83788 .45756 Mtetra
.83788 .45756 .84283 .46427 .85487 .46064 .84995 .4539 Mtetra
.84995 .4539 .85487 .46064 .86696 .45699 .86207 .45023 Mtetra
.86207 .45023 .86696 .45699 .87909 .45334 .87424 .44654 Mtetra
.87424 .44654 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57342 .44919 .56753 Mtetra
.44919 .56753 .45523 .57342 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .5546 Mtetra
.49168 .5546 .49761 .56059 .50831 .55735 .5024 .55134 Mtetra
.5024 .55134 .50831 .55735 .51905 .5541 .51317 .54806 Mtetra
.881 .451 .065 r
.51317 .54806 .51905 .5541 .52987 .57735 .52398 .57134 Mtetra
.662 .744 .911 r
.52398 .57134 .52987 .57735 .54078 .5741 .53492 .56806 Mtetra
.53492 .56806 .54078 .5741 .55174 .57083 .5459 .56477 Mtetra
.5459 .56477 .55174 .57083 .56274 .56756 .55693 .56147 Mtetra
.55693 .56147 .56274 .56756 .57378 .56427 .568 .55816 Mtetra
.568 .55816 .57378 .56427 .58486 .56096 .57911 .55483 Mtetra
.57911 .55483 .58486 .56096 .59599 .55765 .59027 .55149 Mtetra
.59027 .55149 .59599 .55765 .60717 .55432 .60148 .54813 Mtetra
.60148 .54813 .60717 .55432 .61839 .55097 .61273 .54476 Mtetra
.61273 .54476 .61839 .55097 .62965 .54762 .62402 .54138 Mtetra
.62402 .54138 .62965 .54762 .64096 .54424 .63536 .53799 Mtetra
.63536 .53799 .64096 .54424 .65232 .54086 .64675 .53458 Mtetra
.64675 .53458 .65232 .54086 .66372 .53746 .65819 .53115 Mtetra
.848 .779 .785 r
.65819 .53115 .66372 .53746 .67472 .52393 .66923 .51757 Mtetra
.662 .743 .91 r
.66923 .51757 .67472 .52393 .68618 .52049 .68072 .51411 Mtetra
.68072 .51411 .68618 .52049 .69768 .51704 .69226 .51064 Mtetra
.69226 .51064 .69768 .51704 .70924 .51358 .70384 .50715 Mtetra
.70384 .50715 .70924 .51358 .72084 .5101 .71548 .50364 Mtetra
.71548 .50364 .72084 .5101 .73248 .50661 .72716 .50012 Mtetra
.72716 .50012 .73248 .50661 .74418 .5031 .73888 .49659 Mtetra
.73888 .49659 .74418 .5031 .75592 .49958 .75066 .49304 Mtetra
.75066 .49304 .75592 .49958 .76771 .49605 .76249 .48948 Mtetra
.76249 .48948 .76771 .49605 .77955 .4925 .77436 .4859 Mtetra
.77436 .4859 .77955 .4925 .79144 .48893 .78629 .48231 Mtetra
.78629 .48231 .79144 .48893 .80338 .48535 .79826 .47871 Mtetra
.904 .787 .722 r
.79826 .47871 .80338 .48535 .81388 .46482 .80881 .45812 Mtetra
.664 .741 .908 r
.80881 .45812 .81388 .46482 .82585 .4612 .82082 .45446 Mtetra
.82082 .45446 .82585 .4612 .83788 .45756 .83288 .4508 Mtetra
.83288 .4508 .83788 .45756 .84995 .4539 .84499 .44711 Mtetra
.84499 .44711 .84995 .4539 .86207 .45023 .85715 .44341 Mtetra
.85715 .44341 .86207 .45023 .87424 .44654 .86936 .4397 Mtetra
.86936 .4397 .87424 .44654 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .5551 Mtetra
.46432 .5551 .47035 .56109 .48099 .55785 .47499 .55184 Mtetra
.47499 .55184 .48099 .55785 .49168 .5546 .4857 .54857 Mtetra
.4857 .54857 .49168 .5546 .5024 .55134 .49646 .54528 Mtetra
.49646 .54528 .5024 .55134 .51317 .54806 .50725 .54198 Mtetra
.881 .451 .065 r
.50725 .54198 .51317 .54806 .52398 .57134 .51804 .56528 Mtetra
.662 .744 .911 r
.51804 .56528 .52398 .57134 .53492 .56806 .529 .56198 Mtetra
.529 .56198 .53492 .56806 .5459 .56477 .54002 .55867 Mtetra
.54002 .55867 .5459 .56477 .55693 .56147 .55107 .55534 Mtetra
.55107 .55534 .55693 .56147 .568 .55816 .56217 .552 Mtetra
.56217 .552 .568 .55816 .57911 .55483 .57332 .54865 Mtetra
.57332 .54865 .57911 .55483 .59027 .55149 .58451 .54528 Mtetra
.58451 .54528 .59027 .55149 .60148 .54813 .59574 .5419 Mtetra
.59574 .5419 .60148 .54813 .61273 .54476 .60702 .53851 Mtetra
.60702 .53851 .61273 .54476 .62402 .54138 .61835 .5351 Mtetra
.61835 .5351 .62402 .54138 .63536 .53799 .62972 .53168 Mtetra
.62972 .53168 .63536 .53799 .64675 .53458 .64114 .52825 Mtetra
.64114 .52825 .64675 .53458 .65819 .53115 .65261 .5248 Mtetra
.848 .779 .785 r
.65261 .5248 .65819 .53115 .66923 .51757 .66369 .51117 Mtetra
.662 .743 .91 r
.66369 .51117 .66923 .51757 .68072 .51411 .67522 .50768 Mtetra
.67522 .50768 .68072 .51411 .69226 .51064 .68679 .50418 Mtetra
.68679 .50418 .69226 .51064 .70384 .50715 .69841 .50067 Mtetra
.69841 .50067 .70384 .50715 .71548 .50364 .71007 .49714 Mtetra
.71007 .49714 .71548 .50364 .72716 .50012 .72179 .49359 Mtetra
.72179 .49359 .72716 .50012 .73888 .49659 .73355 .49003 Mtetra
.73355 .49003 .73888 .49659 .75066 .49304 .74536 .48646 Mtetra
.74536 .48646 .75066 .49304 .76249 .48948 .75722 .48287 Mtetra
.75722 .48287 .76249 .48948 .77436 .4859 .76913 .47926 Mtetra
.76913 .47926 .77436 .4859 .78629 .48231 .78109 .47564 Mtetra
.78109 .47564 .78629 .48231 .79826 .47871 .7931 .47201 Mtetra
.904 .787 .722 r
.7931 .47201 .79826 .47871 .80881 .45812 .80371 .45136 Mtetra
.664 .741 .908 r
.80371 .45136 .80881 .45812 .82082 .45446 .81575 .44768 Mtetra
.81575 .44768 .82082 .45446 .83288 .4508 .82785 .44398 Mtetra
.82785 .44398 .83288 .4508 .84499 .44711 .83999 .44027 Mtetra
.83999 .44027 .84499 .44711 .85715 .44341 .85219 .43654 Mtetra
.85219 .43654 .85715 .44341 .86936 .4397 .86443 .4328 Mtetra
.86443 .4328 .86936 .4397 .88162 .43597 .87673 .42904 Mtetra
.87673 .42904 .88162 .43597 .89393 .43222 .88908 .42526 Mtetra
.88908 .42526 .89393 .43222 .9063 .42846 .90148 .42147 Mtetra
.90148 .42147 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .5556 Mtetra
.43698 .5556 .44311 .56159 .45369 .55835 .4476 .55234 Mtetra
.4476 .55234 .45369 .55835 .46432 .5551 .45825 .54907 Mtetra
.45825 .54907 .46432 .5551 .47499 .55184 .46895 .54579 Mtetra
.46895 .54579 .47499 .55184 .4857 .54857 .47968 .54249 Mtetra
.47968 .54249 .4857 .54857 .49646 .54528 .49046 .53918 Mtetra
.49046 .53918 .49646 .54528 .50725 .54198 .50129 .53585 Mtetra
.881 .451 .065 r
.50129 .53585 .50725 .54198 .51804 .56528 .51205 .55918 Mtetra
.662 .744 .911 r
.51205 .55918 .51804 .56528 .529 .56198 .52305 .55585 Mtetra
.52305 .55585 .529 .56198 .54002 .55867 .53409 .55252 Mtetra
.53409 .55252 .54002 .55867 .55107 .55534 .54518 .54917 Mtetra
.54518 .54917 .55107 .55534 .56217 .552 .5563 .5458 Mtetra
.5563 .5458 .56217 .552 .57332 .54865 .56748 .54242 Mtetra
.56748 .54242 .57332 .54865 .58451 .54528 .5787 .53903 Mtetra
.5787 .53903 .58451 .54528 .59574 .5419 .58996 .53563 Mtetra
.58996 .53563 .59574 .5419 .60702 .53851 .60128 .53221 Mtetra
.60128 .53221 .60702 .53851 .61835 .5351 .61263 .52878 Mtetra
.61263 .52878 .61835 .5351 .62972 .53168 .62404 .52533 Mtetra
.62404 .52533 .62972 .53168 .64114 .52825 .63549 .52187 Mtetra
.63549 .52187 .64114 .52825 .65261 .5248 .64698 .51839 Mtetra
.848 .779 .785 r
.64698 .51839 .65261 .5248 .66369 .51117 .65812 .50472 Mtetra
.662 .743 .91 r
.65812 .50472 .66369 .51117 .67522 .50768 .66968 .50121 Mtetra
.66968 .50121 .67522 .50768 .68679 .50418 .68128 .49768 Mtetra
.68128 .49768 .68679 .50418 .69841 .50067 .69293 .49414 Mtetra
.69293 .49414 .69841 .50067 .71007 .49714 .70463 .49058 Mtetra
.70463 .49058 .71007 .49714 .72179 .49359 .71638 .48701 Mtetra
.71638 .48701 .72179 .49359 .73355 .49003 .72817 .48342 Mtetra
.72817 .48342 .73355 .49003 .74536 .48646 .74002 .47982 Mtetra
.74002 .47982 .74536 .48646 .75722 .48287 .75191 .4762 Mtetra
.75191 .4762 .75722 .48287 .76913 .47926 .76386 .47257 Mtetra
.76386 .47257 .76913 .47926 .78109 .47564 .77585 .46892 Mtetra
.77585 .46892 .78109 .47564 .7931 .47201 .78789 .46526 Mtetra
.904 .787 .722 r
.78789 .46526 .7931 .47201 .80371 .45136 .79856 .44455 Mtetra
.664 .741 .908 r
.79856 .44455 .80371 .45136 .81575 .44768 .81064 .44084 Mtetra
.81064 .44084 .81575 .44768 .82785 .44398 .82277 .43712 Mtetra
.82277 .43712 .82785 .44398 .83999 .44027 .83495 .43338 Mtetra
.83495 .43338 .83999 .44027 .85219 .43654 .84719 .42962 Mtetra
.84719 .42962 .85219 .43654 .86443 .4328 .85947 .42585 Mtetra
.85947 .42585 .86443 .4328 .87673 .42904 .87181 .42206 Mtetra
.87181 .42206 .87673 .42904 .88908 .42526 .88419 .41825 Mtetra
.88419 .41825 .88908 .42526 .90148 .42147 .89664 .41443 Mtetra
.89664 .41443 .90148 .42147 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55284 Mtetra
.42022 .55284 .42641 .55885 .43698 .5556 .43081 .54957 Mtetra
.43081 .54957 .43698 .5556 .4476 .55234 .44145 .54629 Mtetra
.44145 .54629 .4476 .55234 .45825 .54907 .45213 .543 Mtetra
.45213 .543 .45825 .54907 .46895 .54579 .46286 .53969 Mtetra
.46286 .53969 .46895 .54579 .47968 .54249 .47362 .53636 Mtetra
.47362 .53636 .47968 .54249 .49046 .53918 .48443 .53303 Mtetra
.48443 .53303 .49046 .53918 .50129 .53585 .49528 .52968 Mtetra
.881 .451 .065 r
.49528 .52968 .50129 .53585 .51205 .55918 .50603 .55303 Mtetra
.662 .744 .911 r
.50603 .55303 .51205 .55918 .52305 .55585 .51705 .54968 Mtetra
.51705 .54968 .52305 .55585 .53409 .55252 .52812 .54632 Mtetra
.52812 .54632 .53409 .55252 .54518 .54917 .53923 .54294 Mtetra
.53923 .54294 .54518 .54917 .5563 .5458 .55039 .53956 Mtetra
.55039 .53956 .5563 .5458 .56748 .54242 .5616 .53615 Mtetra
.5616 .53615 .56748 .54242 .5787 .53903 .57285 .53274 Mtetra
.57285 .53274 .5787 .53903 .58996 .53563 .58414 .5293 Mtetra
.58414 .5293 .58996 .53563 .60128 .53221 .59549 .52586 Mtetra
.59549 .52586 .60128 .53221 .61263 .52878 .60687 .5224 Mtetra
.60687 .5224 .61263 .52878 .62404 .52533 .61831 .51893 Mtetra
.61831 .51893 .62404 .52533 .63549 .52187 .62979 .51544 Mtetra
.62979 .51544 .63549 .52187 .64698 .51839 .64132 .51194 Mtetra
.848 .779 .785 r
.64132 .51194 .64698 .51839 .65812 .50472 .6525 .49822 Mtetra
.662 .743 .91 r
.6525 .49822 .65812 .50472 .66968 .50121 .66409 .49468 Mtetra
.66409 .49468 .66968 .50121 .68128 .49768 .67573 .49113 Mtetra
.67573 .49113 .68128 .49768 .69293 .49414 .68741 .48756 Mtetra
.68741 .48756 .69293 .49414 .70463 .49058 .69914 .48397 Mtetra
.69914 .48397 .70463 .49058 .71638 .48701 .71093 .48037 Mtetra
.71093 .48037 .71638 .48701 .72817 .48342 .72276 .47676 Mtetra
.72276 .47676 .72817 .48342 .74002 .47982 .73463 .47313 Mtetra
.73463 .47313 .74002 .47982 .75191 .4762 .74656 .46948 Mtetra
.74656 .46948 .75191 .4762 .76386 .47257 .75854 .46582 Mtetra
.75854 .46582 .76386 .47257 .77585 .46892 .77057 .46215 Mtetra
.77057 .46215 .77585 .46892 .78789 .46526 .78265 .45846 Mtetra
.904 .787 .722 r
.78265 .45846 .78789 .46526 .79856 .44455 .79338 .43769 Mtetra
.664 .741 .908 r
.79338 .43769 .79856 .44455 .81064 .44084 .80549 .43395 Mtetra
.80549 .43395 .81064 .44084 .82277 .43712 .81766 .4302 Mtetra
.81766 .4302 .82277 .43712 .83495 .43338 .82988 .42643 Mtetra
.82988 .42643 .83495 .43338 .84719 .42962 .84215 .42264 Mtetra
.84215 .42264 .84719 .42962 .85947 .42585 .85447 .41884 Mtetra
.85447 .41884 .85947 .42585 .87181 .42206 .86684 .41502 Mtetra
.86684 .41502 .87181 .42206 .88419 .41825 .87927 .41119 Mtetra
.87927 .41119 .88419 .41825 .89664 .41443 .89175 .40734 Mtetra
.89175 .40734 .89664 .41443 .90913 .4106 .90428 .40347 Mtetra
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39958 Mtetra
.91687 .39958 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55984 Mtetra
.37189 .55984 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55284 .41397 .5468 Mtetra
.41397 .5468 .42022 .55284 .43081 .54957 .4246 .5435 Mtetra
.4246 .5435 .43081 .54957 .44145 .54629 .43526 .5402 Mtetra
.43526 .5402 .44145 .54629 .45213 .543 .44597 .53688 Mtetra
.44597 .53688 .45213 .543 .46286 .53969 .45672 .53354 Mtetra
.45672 .53354 .46286 .53969 .47362 .53636 .46751 .5302 Mtetra
.46751 .5302 .47362 .53636 .48443 .53303 .47835 .52684 Mtetra
.47835 .52684 .48443 .53303 .49528 .52968 .48923 .52346 Mtetra
.881 .451 .065 r
.48923 .52346 .49528 .52968 .50603 .55303 .49995 .54684 Mtetra
.662 .744 .911 r
.49995 .54684 .50603 .55303 .51705 .54968 .51101 .54347 Mtetra
.51101 .54347 .51705 .54968 .52812 .54632 .52211 .54008 Mtetra
.52211 .54008 .52812 .54632 .53923 .54294 .53325 .53668 Mtetra
.53325 .53668 .53923 .54294 .55039 .53956 .54444 .53326 Mtetra
.54444 .53326 .55039 .53956 .5616 .53615 .55567 .52983 Mtetra
.55567 .52983 .5616 .53615 .57285 .53274 .56695 .52639 Mtetra
.56695 .52639 .57285 .53274 .58414 .5293 .57828 .52293 Mtetra
.57828 .52293 .58414 .5293 .59549 .52586 .58965 .51946 Mtetra
.58965 .51946 .59549 .52586 .60687 .5224 .60107 .51598 Mtetra
.60107 .51598 .60687 .5224 .61831 .51893 .61254 .51248 Mtetra
.61254 .51248 .61831 .51893 .62979 .51544 .62405 .50897 Mtetra
.62405 .50897 .62979 .51544 .64132 .51194 .63561 .50544 Mtetra
.848 .779 .785 r
.63561 .50544 .64132 .51194 .6525 .49822 .64685 .49168 Mtetra
.662 .743 .91 r
.64685 .49168 .6525 .49822 .66409 .49468 .65847 .48811 Mtetra
.65847 .48811 .66409 .49468 .67573 .49113 .67013 .48453 Mtetra
.67013 .48453 .67573 .49113 .68741 .48756 .68185 .48093 Mtetra
.68185 .48093 .68741 .48756 .69914 .48397 .69362 .47732 Mtetra
.69362 .47732 .69914 .48397 .71093 .48037 .70543 .47369 Mtetra
.70543 .47369 .71093 .48037 .72276 .47676 .7173 .47005 Mtetra
.7173 .47005 .72276 .47676 .73463 .47313 .72921 .46639 Mtetra
.72921 .46639 .73463 .47313 .74656 .46948 .74117 .46271 Mtetra
.74117 .46271 .74656 .46948 .75854 .46582 .75319 .45903 Mtetra
.75319 .45903 .75854 .46582 .77057 .46215 .76525 .45532 Mtetra
.76525 .45532 .77057 .46215 .78265 .45846 .77737 .4516 Mtetra
.904 .787 .722 r
.77737 .4516 .78265 .45846 .79338 .43769 .78815 .43078 Mtetra
.664 .741 .908 r
.78815 .43078 .79338 .43769 .80549 .43395 .8003 .42701 Mtetra
.8003 .42701 .80549 .43395 .81766 .4302 .81251 .42323 Mtetra
.81251 .42323 .81766 .4302 .82988 .42643 .82476 .41943 Mtetra
.82476 .41943 .82988 .42643 .84215 .42264 .83707 .41561 Mtetra
.83707 .41561 .84215 .42264 .85447 .41884 .84943 .41178 Mtetra
.84943 .41178 .85447 .41884 .86684 .41502 .86184 .40793 Mtetra
.86184 .40793 .86684 .41502 .87927 .41119 .8743 .40406 Mtetra
.8743 .40406 .87927 .41119 .89175 .40734 .88682 .40018 Mtetra
.88682 .40018 .89175 .40734 .90428 .40347 .89939 .39628 Mtetra
.89939 .39628 .90428 .40347 .91687 .39958 .91202 .39237 Mtetra
.91202 .39237 .91687 .39958 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.35506 .5571 .36148 .56307 .37189 .55984 .3655 .55385 Mtetra
.3655 .55385 .37189 .55984 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .5435 .41834 .53739 Mtetra
.41834 .53739 .4246 .5435 .43526 .5402 .42903 .53406 Mtetra
.42903 .53406 .43526 .5402 .44597 .53688 .43976 .53071 Mtetra
.43976 .53071 .44597 .53688 .45672 .53354 .45054 .52735 Mtetra
.45054 .52735 .45672 .53354 .46751 .5302 .46136 .52398 Mtetra
.46136 .52398 .46751 .5302 .47835 .52684 .47222 .5206 Mtetra
.47222 .5206 .47835 .52684 .48923 .52346 .48313 .5172 Mtetra
.881 .451 .065 r
.48313 .5172 .48923 .52346 .49995 .54684 .49383 .5406 Mtetra
.662 .744 .911 r
.49383 .5406 .49995 .54684 .51101 .54347 .50492 .5372 Mtetra
.50492 .5372 .51101 .54347 .52211 .54008 .51605 .53379 Mtetra
.51605 .53379 .52211 .54008 .53325 .53668 .52722 .53036 Mtetra
.52722 .53036 .53325 .53668 .54444 .53326 .53844 .52692 Mtetra
.53844 .52692 .54444 .53326 .55567 .52983 .5497 .52347 Mtetra
.5497 .52347 .55567 .52983 .56695 .52639 .56101 .52 Mtetra
.56101 .52 .56695 .52639 .57828 .52293 .57237 .51652 Mtetra
.57237 .51652 .57828 .52293 .58965 .51946 .58377 .51302 Mtetra
.58377 .51302 .58965 .51946 .60107 .51598 .59522 .50951 Mtetra
.59522 .50951 .60107 .51598 .61254 .51248 .60672 .50598 Mtetra
.60672 .50598 .61254 .51248 .62405 .50897 .61827 .50244 Mtetra
.61827 .50244 .62405 .50897 .63561 .50544 .62986 .49888 Mtetra
.848 .779 .785 r
.62986 .49888 .63561 .50544 .64685 .49168 .64114 .48508 Mtetra
.662 .743 .91 r
.64114 .48508 .64685 .49168 .65847 .48811 .6528 .48148 Mtetra
.6528 .48148 .65847 .48811 .67013 .48453 .6645 .47787 Mtetra
.6645 .47787 .67013 .48453 .68185 .48093 .67625 .47425 Mtetra
.67625 .47425 .68185 .48093 .69362 .47732 .68805 .47061 Mtetra
.68805 .47061 .69362 .47732 .70543 .47369 .6999 .46695 Mtetra
.6999 .46695 .70543 .47369 .7173 .47005 .71179 .46328 Mtetra
.71179 .46328 .7173 .47005 .72921 .46639 .72374 .45959 Mtetra
.72374 .45959 .72921 .46639 .74117 .46271 .73574 .45589 Mtetra
.73574 .45589 .74117 .46271 .75319 .45903 .74779 .45217 Mtetra
.74779 .45217 .75319 .45903 .76525 .45532 .75989 .44844 Mtetra
.75989 .44844 .76525 .45532 .77737 .4516 .77204 .44469 Mtetra
.904 .787 .722 r
.77204 .44469 .77737 .4516 .78815 .43078 .78289 .42381 Mtetra
.664 .741 .908 r
.78289 .42381 .78815 .43078 .8003 .42701 .79507 .42001 Mtetra
.79507 .42001 .8003 .42701 .81251 .42323 .80731 .4162 Mtetra
.80731 .4162 .81251 .42323 .82476 .41943 .81961 .41237 Mtetra
.81961 .41237 .82476 .41943 .83707 .41561 .83195 .40852 Mtetra
.83195 .40852 .83707 .41561 .84943 .41178 .84435 .40466 Mtetra
.84435 .40466 .84943 .41178 .86184 .40793 .8568 .40078 Mtetra
.8568 .40078 .86184 .40793 .8743 .40406 .8693 .39689 Mtetra
.8693 .39689 .8743 .40406 .88682 .40018 .88186 .39297 Mtetra
.88186 .39297 .88682 .40018 .89939 .39628 .89447 .38904 Mtetra
.89447 .38904 .89939 .39628 .91202 .39237 .90713 .3851 Mtetra
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37715 Mtetra
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53457 Mtetra
.40135 .53457 .40769 .54071 .41834 .53739 .41203 .53123 Mtetra
.41203 .53123 .41834 .53739 .42903 .53406 .42275 .52787 Mtetra
.42275 .52787 .42903 .53406 .43976 .53071 .43351 .5245 Mtetra
.43351 .5245 .43976 .53071 .45054 .52735 .44432 .52112 Mtetra
.44432 .52112 .45054 .52735 .46136 .52398 .45516 .51772 Mtetra
.45516 .51772 .46136 .52398 .47222 .5206 .46605 .51431 Mtetra
.46605 .51431 .47222 .5206 .48313 .5172 .47699 .51089 Mtetra
.881 .451 .065 r
.47699 .51089 .48313 .5172 .49383 .5406 .48767 .53431 Mtetra
.662 .744 .911 r
.48767 .53431 .49383 .5406 .50492 .5372 .49878 .53089 Mtetra
.49878 .53089 .50492 .5372 .51605 .53379 .50994 .52745 Mtetra
.50994 .52745 .51605 .53379 .52722 .53036 .52114 .524 Mtetra
.52114 .524 .52722 .53036 .53844 .52692 .53239 .52053 Mtetra
.53239 .52053 .53844 .52692 .5497 .52347 .54369 .51705 Mtetra
.54369 .51705 .5497 .52347 .56101 .52 .55503 .51356 Mtetra
.55503 .51356 .56101 .52 .57237 .51652 .56642 .51005 Mtetra
.56642 .51005 .57237 .51652 .58377 .51302 .57785 .50652 Mtetra
.57785 .50652 .58377 .51302 .59522 .50951 .58933 .50299 Mtetra
.58933 .50299 .59522 .50951 .60672 .50598 .60086 .49943 Mtetra
.60086 .49943 .60672 .50598 .61827 .50244 .61244 .49586 Mtetra
.61244 .49586 .61827 .50244 .62986 .49888 .62407 .49228 Mtetra
.848 .779 .785 r
.62407 .49228 .62986 .49888 .64114 .48508 .6354 .47843 Mtetra
.662 .743 .91 r
.6354 .47843 .64114 .48508 .6528 .48148 .64708 .47481 Mtetra
.64708 .47481 .6528 .48148 .6645 .47787 .65882 .47117 Mtetra
.65882 .47117 .6645 .47787 .67625 .47425 .6706 .46751 Mtetra
.6706 .46751 .67625 .47425 .68805 .47061 .68243 .46385 Mtetra
.68243 .46385 .68805 .47061 .6999 .46695 .69432 .46016 Mtetra
.69432 .46016 .6999 .46695 .71179 .46328 .70625 .45646 Mtetra
.70625 .45646 .71179 .46328 .72374 .45959 .71823 .45275 Mtetra
.71823 .45275 .72374 .45959 .73574 .45589 .73027 .44902 Mtetra
.73027 .44902 .73574 .45589 .74779 .45217 .74235 .44527 Mtetra
.74235 .44527 .74779 .45217 .75989 .44844 .75449 .44151 Mtetra
.75449 .44151 .75989 .44844 .77204 .44469 .76668 .43773 Mtetra
.904 .787 .722 r
.76668 .43773 .77204 .44469 .78289 .42381 .77758 .41679 Mtetra
.664 .741 .908 r
.77758 .41679 .78289 .42381 .79507 .42001 .7898 .41296 Mtetra
.7898 .41296 .79507 .42001 .80731 .4162 .80208 .40912 Mtetra
.80208 .40912 .80731 .4162 .81961 .41237 .81441 .40526 Mtetra
.81441 .40526 .81961 .41237 .83195 .40852 .82679 .40138 Mtetra
.82679 .40138 .83195 .40852 .84435 .40466 .83923 .39749 Mtetra
.83923 .39749 .84435 .40466 .8568 .40078 .85171 .39358 Mtetra
.85171 .39358 .8568 .40078 .8693 .39689 .86426 .38965 Mtetra
.86426 .38965 .8693 .39689 .88186 .39297 .87685 .38571 Mtetra
.87685 .38571 .88186 .39297 .89447 .38904 .8895 .38175 Mtetra
.8895 .38175 .89447 .38904 .90713 .3851 .90221 .37777 Mtetra
.90221 .37777 .90713 .3851 .91985 .38114 .91497 .37377 Mtetra
.91497 .37377 .91985 .38114 .93263 .37715 .92778 .36976 Mtetra
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53508 Mtetra
.3737 .53508 .38013 .54122 .39072 .5379 .38431 .53174 Mtetra
.38431 .53174 .39072 .5379 .40135 .53457 .39497 .52839 Mtetra
.39497 .52839 .40135 .53457 .41203 .53123 .40568 .52502 Mtetra
.40568 .52502 .41203 .53123 .42275 .52787 .41642 .52164 Mtetra
.41642 .52164 .42275 .52787 .43351 .5245 .42721 .51825 Mtetra
.42721 .51825 .43351 .5245 .44432 .52112 .43804 .51484 Mtetra
.43804 .51484 .44432 .52112 .45516 .51772 .44892 .51142 Mtetra
.44892 .51142 .45516 .51772 .46605 .51431 .45984 .50798 Mtetra
.45984 .50798 .46605 .51431 .47699 .51089 .4708 .50453 Mtetra
.881 .451 .065 r
.4708 .50453 .47699 .51089 .48767 .53431 .48146 .52798 Mtetra
.662 .744 .911 r
.48146 .52798 .48767 .53431 .49878 .53089 .4926 .52453 Mtetra
.4926 .52453 .49878 .53089 .50994 .52745 .50379 .52107 Mtetra
.50379 .52107 .50994 .52745 .52114 .524 .51502 .51759 Mtetra
.51502 .51759 .52114 .524 .53239 .52053 .5263 .5141 Mtetra
.5263 .5141 .53239 .52053 .54369 .51705 .53762 .51059 Mtetra
.53762 .51059 .54369 .51705 .55503 .51356 .549 .50707 Mtetra
.549 .50707 .55503 .51356 .56642 .51005 .56042 .50353 Mtetra
.56042 .50353 .56642 .51005 .57785 .50652 .57188 .49998 Mtetra
.57188 .49998 .57785 .50652 .58933 .50299 .5834 .49641 Mtetra
.5834 .49641 .58933 .50299 .60086 .49943 .59496 .49283 Mtetra
.59496 .49283 .60086 .49943 .61244 .49586 .60657 .48924 Mtetra
.60657 .48924 .61244 .49586 .62407 .49228 .61823 .48563 Mtetra
.848 .779 .785 r
.61823 .48563 .62407 .49228 .6354 .47843 .62961 .47173 Mtetra
.662 .743 .91 r
.62961 .47173 .6354 .47843 .64708 .47481 .64133 .46808 Mtetra
.64133 .46808 .64708 .47481 .65882 .47117 .65309 .46441 Mtetra
.65309 .46441 .65882 .47117 .6706 .46751 .66491 .46073 Mtetra
.66491 .46073 .6706 .46751 .68243 .46385 .67678 .45703 Mtetra
.67678 .45703 .68243 .46385 .69432 .46016 .6887 .45332 Mtetra
.6887 .45332 .69432 .46016 .70625 .45646 .70066 .44959 Mtetra
.70066 .44959 .70625 .45646 .71823 .45275 .71268 .44585 Mtetra
.71268 .44585 .71823 .45275 .73027 .44902 .72475 .44209 Mtetra
.72475 .44209 .73027 .44902 .74235 .44527 .73687 .43831 Mtetra
.73687 .43831 .74235 .44527 .75449 .44151 .74904 .43452 Mtetra
.74904 .43452 .75449 .44151 .76668 .43773 .76127 .43071 Mtetra
.904 .787 .722 r
.76127 .43071 .76668 .43773 .77758 .41679 .77223 .40971 Mtetra
.664 .741 .908 r
.77223 .40971 .77758 .41679 .7898 .41296 .78449 .40585 Mtetra
.78449 .40585 .7898 .41296 .80208 .40912 .79681 .40198 Mtetra
.79681 .40198 .80208 .40912 .81441 .40526 .80917 .39809 Mtetra
.80917 .39809 .81441 .40526 .82679 .40138 .82159 .39418 Mtetra
.82159 .39418 .82679 .40138 .83923 .39749 .83406 .39025 Mtetra
.83406 .39025 .83923 .39749 .85171 .39358 .84659 .38631 Mtetra
.84659 .38631 .85171 .39358 .86426 .38965 .85917 .38236 Mtetra
.85917 .38236 .86426 .38965 .87685 .38571 .87181 .37838 Mtetra
.87181 .37838 .87685 .38571 .8895 .38175 .8845 .37439 Mtetra
.8845 .37439 .8895 .38175 .90221 .37777 .89724 .37038 Mtetra
.89724 .37038 .90221 .37777 .91497 .37377 .91004 .36635 Mtetra
.91004 .36635 .91497 .37377 .92778 .36976 .9229 .36231 Mtetra
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53508 .36722 .52891 Mtetra
.36722 .52891 .3737 .53508 .38431 .53174 .37786 .52554 Mtetra
.37786 .52554 .38431 .53174 .39497 .52839 .38855 .52216 Mtetra
.38855 .52216 .39497 .52839 .40568 .52502 .39928 .51877 Mtetra
.39928 .51877 .40568 .52502 .41642 .52164 .41005 .51537 Mtetra
.41005 .51537 .41642 .52164 .42721 .51825 .42087 .51195 Mtetra
.42087 .51195 .42721 .51825 .43804 .51484 .43173 .50851 Mtetra
.43173 .50851 .43804 .51484 .44892 .51142 .44263 .50507 Mtetra
.44263 .50507 .44892 .51142 .45984 .50798 .45358 .50161 Mtetra
.45358 .50161 .45984 .50798 .4708 .50453 .46457 .49813 Mtetra
.881 .451 .065 r
.46457 .49813 .4708 .50453 .48146 .52798 .4752 .5216 Mtetra
.662 .744 .911 r
.4752 .5216 .48146 .52798 .4926 .52453 .48637 .51812 Mtetra
.48637 .51812 .4926 .52453 .50379 .52107 .49759 .51463 Mtetra
.49759 .51463 .50379 .52107 .51502 .51759 .50885 .51113 Mtetra
.50885 .51113 .51502 .51759 .5263 .5141 .52016 .50761 Mtetra
.52016 .50761 .5263 .5141 .53762 .51059 .53152 .50408 Mtetra
.53152 .50408 .53762 .51059 .549 .50707 .54292 .50053 Mtetra
.54292 .50053 .549 .50707 .56042 .50353 .55437 .49696 Mtetra
.55437 .49696 .56042 .50353 .57188 .49998 .56587 .49339 Mtetra
.56587 .49339 .57188 .49998 .5834 .49641 .57741 .48979 Mtetra
.57741 .48979 .5834 .49641 .59496 .49283 .58901 .48618 Mtetra
.58901 .48618 .59496 .49283 .60657 .48924 .60065 .48256 Mtetra
.60065 .48256 .60657 .48924 .61823 .48563 .61234 .47892 Mtetra
.848 .779 .785 r
.61234 .47892 .61823 .48563 .62961 .47173 .62377 .46498 Mtetra
.662 .743 .91 r
.62377 .46498 .62961 .47173 .64133 .46808 .63552 .4613 Mtetra
.63552 .4613 .64133 .46808 .65309 .46441 .64732 .4576 Mtetra
.64732 .4576 .65309 .46441 .66491 .46073 .65918 .45389 Mtetra
.65918 .45389 .66491 .46073 .67678 .45703 .67108 .45017 Mtetra
.67108 .45017 .67678 .45703 .6887 .45332 .68303 .44642 Mtetra
.68303 .44642 .6887 .45332 .70066 .44959 .69503 .44267 Mtetra
.69503 .44267 .70066 .44959 .71268 .44585 .70709 .43889 Mtetra
.70709 .43889 .71268 .44585 .72475 .44209 .71919 .4351 Mtetra
.71919 .4351 .72475 .44209 .73687 .43831 .73135 .4313 Mtetra
.73135 .4313 .73687 .43831 .74904 .43452 .74356 .42748 Mtetra
.74356 .42748 .74904 .43452 .76127 .43071 .75582 .42364 Mtetra
.904 .787 .722 r
.75582 .42364 .76127 .43071 .77223 .40971 .76684 .40257 Mtetra
.664 .741 .908 r
.76684 .40257 .77223 .40971 .78449 .40585 .77914 .39869 Mtetra
.77914 .39869 .78449 .40585 .79681 .40198 .79149 .39478 Mtetra
.79149 .39478 .79681 .40198 .80917 .39809 .80389 .39086 Mtetra
.80389 .39086 .80917 .39809 .82159 .39418 .81635 .38692 Mtetra
.81635 .38692 .82159 .39418 .83406 .39025 .82886 .38297 Mtetra
.82886 .38297 .83406 .39025 .84659 .38631 .84143 .37899 Mtetra
.84143 .37899 .84659 .38631 .85917 .38236 .85405 .375 Mtetra
.85405 .375 .85917 .38236 .87181 .37838 .86672 .371 Mtetra
.86672 .371 .87181 .37838 .8845 .37439 .87945 .36697 Mtetra
.87945 .36697 .8845 .37439 .89724 .37038 .89224 .36293 Mtetra
.89224 .36293 .89724 .37038 .91004 .36635 .90508 .35887 Mtetra
.90508 .35887 .91004 .36635 .9229 .36231 .91798 .35479 Mtetra
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52268 Mtetra
.36069 .52268 .36722 .52891 .37786 .52554 .37136 .51929 Mtetra
.37136 .51929 .37786 .52554 .38855 .52216 .38207 .51589 Mtetra
.38207 .51589 .38855 .52216 .39928 .51877 .39283 .51247 Mtetra
.39283 .51247 .39928 .51877 .41005 .51537 .40363 .50904 Mtetra
.40363 .50904 .41005 .51537 .42087 .51195 .41447 .5056 Mtetra
.41447 .5056 .42087 .51195 .43173 .50851 .42536 .50214 Mtetra
.42536 .50214 .43173 .50851 .44263 .50507 .43629 .49867 Mtetra
.43629 .49867 .44263 .50507 .45358 .50161 .44727 .49518 Mtetra
.44727 .49518 .45358 .50161 .46457 .49813 .45829 .49168 Mtetra
.881 .451 .065 r
.45829 .49168 .46457 .49813 .4752 .5216 .4689 .51517 Mtetra
.662 .744 .911 r
.4689 .51517 .4752 .5216 .48637 .51812 .4801 .51167 Mtetra
.4801 .51167 .48637 .51812 .49759 .51463 .49134 .50815 Mtetra
.49134 .50815 .49759 .51463 .50885 .51113 .50264 .50462 Mtetra
.50264 .50462 .50885 .51113 .52016 .50761 .51398 .50107 Mtetra
.51398 .50107 .52016 .50761 .53152 .50408 .52536 .49751 Mtetra
.52536 .49751 .53152 .50408 .54292 .50053 .5368 .49394 Mtetra
.5368 .49394 .54292 .50053 .55437 .49696 .54828 .49035 Mtetra
.54828 .49035 .55437 .49696 .56587 .49339 .55981 .48674 Mtetra
.55981 .48674 .56587 .49339 .57741 .48979 .57138 .48312 Mtetra
.57138 .48312 .57741 .48979 .58901 .48618 .58301 .47948 Mtetra
.58301 .47948 .58901 .48618 .60065 .48256 .59468 .47583 Mtetra
.59468 .47583 .60065 .48256 .61234 .47892 .60641 .47217 Mtetra
.848 .779 .785 r
.60641 .47217 .61234 .47892 .62377 .46498 .61789 .45817 Mtetra
.662 .743 .91 r
.61789 .45817 .62377 .46498 .63552 .4613 .62968 .45446 Mtetra
.62968 .45446 .63552 .4613 .64732 .4576 .64151 .45074 Mtetra
.64151 .45074 .64732 .4576 .65918 .45389 .6534 .447 Mtetra
.6534 .447 .65918 .45389 .67108 .45017 .66533 .44325 Mtetra
.66533 .44325 .67108 .45017 .68303 .44642 .67732 .43948 Mtetra
.67732 .43948 .68303 .44642 .69503 .44267 .68936 .43569 Mtetra
.68936 .43569 .69503 .44267 .70709 .43889 .70145 .43188 Mtetra
.70145 .43188 .70709 .43889 .71919 .4351 .71359 .42807 Mtetra
.71359 .42807 .71919 .4351 .73135 .4313 .72578 .42423 Mtetra
.72578 .42423 .73135 .4313 .74356 .42748 .73802 .42038 Mtetra
.73802 .42038 .74356 .42748 .75582 .42364 .75032 .41651 Mtetra
.904 .787 .722 r
.75032 .41651 .75582 .42364 .76684 .40257 .76141 .39538 Mtetra
.664 .741 .908 r
.76141 .39538 .76684 .40257 .77914 .39869 .77374 .39146 Mtetra
.77374 .39146 .77914 .39869 .79149 .39478 .78613 .38753 Mtetra
.78613 .38753 .79149 .39478 .80389 .39086 .79857 .38358 Mtetra
.79857 .38358 .80389 .39086 .81635 .38692 .81107 .37961 Mtetra
.81107 .37961 .81635 .38692 .82886 .38297 .82362 .37562 Mtetra
.82362 .37562 .82886 .38297 .84143 .37899 .83622 .37161 Mtetra
.83622 .37161 .84143 .37899 .85405 .375 .84888 .36759 Mtetra
.84888 .36759 .85405 .375 .86672 .371 .8616 .36355 Mtetra
.8616 .36355 .86672 .371 .87945 .36697 .87437 .3595 Mtetra
.87437 .3595 .87945 .36697 .89224 .36293 .88719 .35542 Mtetra
.88719 .35542 .89224 .36293 .90508 .35887 .90008 .35133 Mtetra
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .5232 Mtetra
.33285 .5232 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52268 .35411 .51641 Mtetra
.35411 .51641 .36069 .52268 .37136 .51929 .36481 .513 Mtetra
.36481 .513 .37136 .51929 .38207 .51589 .37555 .50957 Mtetra
.37555 .50957 .38207 .51589 .39283 .51247 .38633 .50613 Mtetra
.38633 .50613 .39283 .51247 .40363 .50904 .39716 .50267 Mtetra
.39716 .50267 .40363 .50904 .41447 .5056 .40803 .4992 Mtetra
.40803 .4992 .41447 .5056 .42536 .50214 .41895 .49572 Mtetra
.41895 .49572 .42536 .50214 .43629 .49867 .42991 .49222 Mtetra
.42991 .49222 .43629 .49867 .44727 .49518 .44091 .48871 Mtetra
.44091 .48871 .44727 .49518 .45829 .49168 .45196 .48518 Mtetra
.77 .293 0 r
.45196 .48518 .45829 .49168 .4689 .51517 .46267 .50189 Mtetra
.644 .596 .785 r
.46267 .50189 .4689 .51517 .4801 .51167 .47388 .49835 Mtetra
.47388 .49835 .4801 .51167 .49134 .50815 .48513 .4948 Mtetra
.48513 .4948 .49134 .50815 .50264 .50462 .49643 .49124 Mtetra
.49643 .49124 .50264 .50462 .51398 .50107 .50778 .48766 Mtetra
.50778 .48766 .51398 .50107 .52536 .49751 .51917 .48406 Mtetra
.51917 .48406 .52536 .49751 .5368 .49394 .53061 .48045 Mtetra
.53061 .48045 .5368 .49394 .54828 .49035 .5421 .47682 Mtetra
.5421 .47682 .54828 .49035 .55981 .48674 .55364 .47318 Mtetra
.55364 .47318 .55981 .48674 .57138 .48312 .56522 .46953 Mtetra
.56522 .46953 .57138 .48312 .58301 .47948 .57686 .46586 Mtetra
.57686 .46586 .58301 .47948 .59468 .47583 .58854 .46217 Mtetra
.58854 .46217 .59468 .47583 .60641 .47217 .60027 .45847 Mtetra
.973 .67 .378 r
.60027 .45847 .60641 .47217 .61789 .45817 .61719 .6478 Mtetra
.551 .326 .527 r
.61719 .6478 .61789 .45817 .62968 .45446 .62973 .64428 Mtetra
.62973 .64428 .62968 .45446 .64151 .45074 .64233 .64074 Mtetra
.64233 .64074 .64151 .45074 .6534 .447 .65498 .63719 Mtetra
.65498 .63719 .6534 .447 .66533 .44325 .6677 .63362 Mtetra
.6677 .63362 .66533 .44325 .67732 .43948 .68047 .63004 Mtetra
.68047 .63004 .67732 .43948 .68936 .43569 .69329 .62644 Mtetra
.69329 .62644 .68936 .43569 .70145 .43188 .70618 .62282 Mtetra
.70618 .62282 .70145 .43188 .71359 .42807 .71912 .61919 Mtetra
.71912 .61919 .71359 .42807 .72578 .42423 .73213 .61553 Mtetra
.73213 .61553 .72578 .42423 .73802 .42038 .74519 .61187 Mtetra
.74519 .61187 .73802 .42038 .75032 .41651 .75831 .60818 Mtetra
.186 .056 .46 r
.75831 .60818 .75032 .41651 .76141 .39538 .76021 .44762 Mtetra
.525 .268 .469 r
.76021 .44762 .76141 .39538 .77374 .39146 .77282 .44373 Mtetra
.77282 .44373 .77374 .39146 .78613 .38753 .78549 .43982 Mtetra
.78549 .43982 .78613 .38753 .79857 .38358 .79821 .43589 Mtetra
.79821 .43589 .79857 .38358 .81107 .37961 .81099 .43195 Mtetra
.81099 .43195 .81107 .37961 .82362 .37562 .82383 .42798 Mtetra
.82383 .42798 .82362 .37562 .83622 .37161 .83672 .424 Mtetra
.83672 .424 .83622 .37161 .84888 .36759 .84967 .42001 Mtetra
.84967 .42001 .84888 .36759 .8616 .36355 .86268 .41599 Mtetra
.86268 .41599 .8616 .36355 .87437 .3595 .87575 .41196 Mtetra
.87575 .41196 .87437 .3595 .88719 .35542 .88887 .40791 Mtetra
.88887 .40791 .88719 .35542 .90008 .35133 .90206 .40384 Mtetra
.90206 .40384 .90008 .35133 .91302 .34722 .9153 .39975 Mtetra
.664 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .34346 .51982 .33681 .51353 Mtetra
.33681 .51353 .34346 .51982 .35411 .51641 .34749 .5101 Mtetra
.34749 .5101 .35411 .51641 .36481 .513 .35821 .50666 Mtetra
.35821 .50666 .36481 .513 .37555 .50957 .36898 .5032 Mtetra
.36898 .5032 .37555 .50957 .38633 .50613 .37979 .49974 Mtetra
.37979 .49974 .38633 .50613 .39716 .50267 .39065 .49625 Mtetra
.39065 .49625 .39716 .50267 .40803 .4992 .40154 .49276 Mtetra
.40154 .49276 .40803 .4992 .41895 .49572 .41249 .48925 Mtetra
.41249 .48925 .41895 .49572 .42991 .49222 .42347 .48572 Mtetra
.42347 .48572 .42991 .49222 .44091 .48871 .4345 .48218 Mtetra
.4345 .48218 .44091 .48871 .45196 .48518 .44558 .47863 Mtetra
.77 .293 0 r
.44558 .47863 .45196 .48518 .46267 .50189 .45629 .49535 Mtetra
.662 .743 .91 r
.45629 .49535 .46267 .50189 .47388 .49835 .46752 .49179 Mtetra
.46752 .49179 .47388 .49835 .48513 .4948 .4788 .48821 Mtetra
.4788 .48821 .48513 .4948 .49643 .49124 .49013 .48461 Mtetra
.49013 .48461 .49643 .49124 .50778 .48766 .50151 .48101 Mtetra
.50151 .48101 .50778 .48766 .51917 .48406 .51294 .47738 Mtetra
.51294 .47738 .51917 .48406 .53061 .48045 .52441 .47374 Mtetra
.52441 .47374 .53061 .48045 .5421 .47682 .53593 .47009 Mtetra
.53593 .47009 .5421 .47682 .55364 .47318 .5475 .46642 Mtetra
.5475 .46642 .55364 .47318 .56522 .46953 .55911 .46274 Mtetra
.55911 .46274 .56522 .46953 .57686 .46586 .57078 .45904 Mtetra
.57078 .45904 .57686 .46586 .58854 .46217 .5825 .45532 Mtetra
.5825 .45532 .58854 .46217 .60027 .45847 .59426 .45159 Mtetra
.966 .662 .398 r
.59426 .45159 .60027 .45847 .61719 .6478 .61088 .64129 Mtetra
.646 .762 .934 r
.61088 .64129 .61719 .6478 .62973 .64428 .62346 .63774 Mtetra
.62346 .63774 .62973 .64428 .64233 .64074 .63609 .63417 Mtetra
.63609 .63417 .64233 .64074 .65498 .63719 .64879 .63059 Mtetra
.64879 .63059 .65498 .63719 .6677 .63362 .66154 .62699 Mtetra
.66154 .62699 .6677 .63362 .68047 .63004 .67435 .62338 Mtetra
.67435 .62338 .68047 .63004 .69329 .62644 .68722 .61975 Mtetra
.68722 .61975 .69329 .62644 .70618 .62282 .70014 .6161 Mtetra
.70014 .6161 .70618 .62282 .71912 .61919 .71313 .61243 Mtetra
.71313 .61243 .71912 .61919 .73213 .61553 .72617 .60875 Mtetra
.72617 .60875 .73213 .61553 .74519 .61187 .73928 .60505 Mtetra
.73928 .60505 .74519 .61187 .75831 .60818 .75244 .60134 Mtetra
.978 .713 .458 r
.75244 .60134 .75831 .60818 .76021 .44762 .7546 .44042 Mtetra
.659 .747 .915 r
.7546 .44042 .76021 .44762 .77282 .44373 .76725 .4365 Mtetra
.76725 .4365 .77282 .44373 .78549 .43982 .77996 .43255 Mtetra
.77996 .43255 .78549 .43982 .79821 .43589 .79272 .42859 Mtetra
.79272 .42859 .79821 .43589 .81099 .43195 .80554 .42462 Mtetra
.80554 .42462 .81099 .43195 .82383 .42798 .81842 .42062 Mtetra
.81842 .42062 .82383 .42798 .83672 .424 .83135 .41661 Mtetra
.83135 .41661 .83672 .424 .84967 .42001 .84435 .41258 Mtetra
.84435 .41258 .84967 .42001 .86268 .41599 .8574 .40853 Mtetra
.8574 .40853 .86268 .41599 .87575 .41196 .87051 .40447 Mtetra
.87051 .40447 .87575 .41196 .88887 .40791 .88368 .40038 Mtetra
.88368 .40038 .88887 .40791 .90206 .40384 .8969 .39628 Mtetra
.8969 .39628 .90206 .40384 .9153 .39975 .91019 .39216 Mtetra
.664 .741 .908 r
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.34082 .50374 .34749 .5101 .35821 .50666 .35157 .50027 Mtetra
.35157 .50027 .35821 .50666 .36898 .5032 .36236 .49679 Mtetra
.36236 .49679 .36898 .5032 .37979 .49974 .3732 .4933 Mtetra
.3732 .4933 .37979 .49974 .39065 .49625 .38408 .48979 Mtetra
.38408 .48979 .39065 .49625 .40154 .49276 .39501 .48626 Mtetra
.39501 .48626 .40154 .49276 .41249 .48925 .40598 .48273 Mtetra
.40598 .48273 .41249 .48925 .42347 .48572 .41699 .47918 Mtetra
.41699 .47918 .42347 .48572 .4345 .48218 .42805 .47561 Mtetra
.42805 .47561 .4345 .48218 .44558 .47863 .43916 .47203 Mtetra
.77 .293 0 r
.43916 .47203 .44558 .47863 .45629 .49535 .44985 .48876 Mtetra
.662 .743 .91 r
.44985 .48876 .45629 .49535 .46752 .49179 .46111 .48517 Mtetra
.46111 .48517 .46752 .49179 .4788 .48821 .47243 .48156 Mtetra
.47243 .48156 .4788 .48821 .49013 .48461 .48379 .47794 Mtetra
.48379 .47794 .49013 .48461 .50151 .48101 .4952 .47431 Mtetra
.4952 .47431 .50151 .48101 .51294 .47738 .50665 .47065 Mtetra
.50665 .47065 .51294 .47738 .52441 .47374 .51815 .46699 Mtetra
.51815 .46699 .52441 .47374 .53593 .47009 .52971 .46331 Mtetra
.52971 .46331 .53593 .47009 .5475 .46642 .54131 .45961 Mtetra
.54131 .45961 .5475 .46642 .55911 .46274 .55296 .4559 Mtetra
.55296 .4559 .55911 .46274 .57078 .45904 .56466 .45217 Mtetra
.56466 .45217 .57078 .45904 .5825 .45532 .5764 .44842 Mtetra
.5764 .44842 .5825 .45532 .59426 .45159 .5882 .44466 Mtetra
.966 .662 .398 r
.5882 .44466 .59426 .45159 .61088 .64129 .60452 .63472 Mtetra
.646 .762 .934 r
.60452 .63472 .61088 .64129 .62346 .63774 .61713 .63114 Mtetra
.61713 .63114 .62346 .63774 .63609 .63417 .62981 .62755 Mtetra
.62981 .62755 .63609 .63417 .64879 .63059 .64254 .62393 Mtetra
.64254 .62393 .64879 .63059 .66154 .62699 .65533 .62031 Mtetra
.65533 .62031 .66154 .62699 .67435 .62338 .66818 .61666 Mtetra
.66818 .61666 .67435 .62338 .68722 .61975 .68109 .613 Mtetra
.68109 .613 .68722 .61975 .70014 .6161 .69405 .60932 Mtetra
.69405 .60932 .70014 .6161 .71313 .61243 .70708 .60562 Mtetra
.70708 .60562 .71313 .61243 .72617 .60875 .72017 .60191 Mtetra
.72017 .60191 .72617 .60875 .73928 .60505 .73331 .59818 Mtetra
.73331 .59818 .73928 .60505 .75244 .60134 .74652 .59443 Mtetra
.978 .713 .458 r
.74652 .59443 .75244 .60134 .7546 .44042 .74895 .43316 Mtetra
.659 .747 .915 r
.74895 .43316 .7546 .44042 .76725 .4365 .76164 .4292 Mtetra
.76164 .4292 .76725 .4365 .77996 .43255 .77439 .42523 Mtetra
.77439 .42523 .77996 .43255 .79272 .42859 .78719 .42124 Mtetra
.78719 .42124 .79272 .42859 .80554 .42462 .80005 .41723 Mtetra
.80005 .41723 .80554 .42462 .81842 .42062 .81297 .4132 Mtetra
.81297 .4132 .81842 .42062 .83135 .41661 .82594 .40916 Mtetra
.82594 .40916 .83135 .41661 .84435 .41258 .83898 .40509 Mtetra
.83898 .40509 .84435 .41258 .8574 .40853 .85207 .40101 Mtetra
.85207 .40101 .8574 .40853 .87051 .40447 .86522 .39691 Mtetra
.86522 .39691 .87051 .40447 .88368 .40038 .87843 .39279 Mtetra
.87843 .39279 .88368 .40038 .8969 .39628 .89171 .38865 Mtetra
.89171 .38865 .8969 .39628 .91019 .39216 .90504 .3845 Mtetra
.664 .741 .908 r
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .5008 Mtetra
.32336 .5008 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49383 Mtetra
.34487 .49383 .35157 .50027 .36236 .49679 .35569 .49033 Mtetra
.35569 .49033 .36236 .49679 .3732 .4933 .36656 .48681 Mtetra
.36656 .48681 .3732 .4933 .38408 .48979 .37746 .48327 Mtetra
.37746 .48327 .38408 .48979 .39501 .48626 .38842 .47972 Mtetra
.38842 .47972 .39501 .48626 .40598 .48273 .39942 .47616 Mtetra
.39942 .47616 .40598 .48273 .41699 .47918 .41046 .47258 Mtetra
.41046 .47258 .41699 .47918 .42805 .47561 .42155 .46899 Mtetra
.42155 .46899 .42805 .47561 .43916 .47203 .43268 .46538 Mtetra
.77 .293 0 r
.43268 .46538 .43916 .47203 .44985 .48876 .44336 .48212 Mtetra
.662 .743 .91 r
.44336 .48212 .44985 .48876 .46111 .48517 .45466 .4785 Mtetra
.45466 .4785 .46111 .48517 .47243 .48156 .466 .47487 Mtetra
.466 .47487 .47243 .48156 .48379 .47794 .47739 .47122 Mtetra
.47739 .47122 .48379 .47794 .4952 .47431 .48883 .46755 Mtetra
.48883 .46755 .4952 .47431 .50665 .47065 .50032 .46387 Mtetra
.50032 .46387 .50665 .47065 .51815 .46699 .51185 .46018 Mtetra
.51185 .46018 .51815 .46699 .52971 .46331 .52344 .45647 Mtetra
.52344 .45647 .52971 .46331 .54131 .45961 .53507 .45274 Mtetra
.53507 .45274 .54131 .45961 .55296 .4559 .54675 .449 Mtetra
.54675 .449 .55296 .4559 .56466 .45217 .55848 .44524 Mtetra
.55848 .44524 .56466 .45217 .5764 .44842 .57026 .44147 Mtetra
.57026 .44147 .5764 .44842 .5882 .44466 .58209 .43768 Mtetra
.966 .662 .398 r
.58209 .43768 .5882 .44466 .60452 .63472 .5981 .6281 Mtetra
.646 .762 .934 r
.5981 .6281 .60452 .63472 .61713 .63114 .61075 .62449 Mtetra
.61075 .62449 .61713 .63114 .62981 .62755 .62347 .62086 Mtetra
.62347 .62086 .62981 .62755 .64254 .62393 .63624 .61722 Mtetra
.63624 .61722 .64254 .62393 .65533 .62031 .64907 .61356 Mtetra
.64907 .61356 .65533 .62031 .66818 .61666 .66196 .60989 Mtetra
.66196 .60989 .66818 .61666 .68109 .613 .67491 .60619 Mtetra
.67491 .60619 .68109 .613 .69405 .60932 .68791 .60248 Mtetra
.68791 .60248 .69405 .60932 .70708 .60562 .70098 .59875 Mtetra
.70098 .59875 .70708 .60562 .72017 .60191 .71411 .59501 Mtetra
.71411 .59501 .72017 .60191 .73331 .59818 .7273 .59125 Mtetra
.7273 .59125 .73331 .59818 .74652 .59443 .74055 .58747 Mtetra
.978 .713 .458 r
.74055 .58747 .74652 .59443 .74895 .43316 .74325 .42584 Mtetra
.659 .747 .915 r
.74325 .42584 .74895 .43316 .76164 .4292 .75598 .42185 Mtetra
.75598 .42185 .76164 .4292 .77439 .42523 .76877 .41785 Mtetra
.76877 .41785 .77439 .42523 .78719 .42124 .78161 .41382 Mtetra
.78161 .41382 .78719 .42124 .80005 .41723 .79451 .40978 Mtetra
.79451 .40978 .80005 .41723 .81297 .4132 .80747 .40572 Mtetra
.80747 .40572 .81297 .4132 .82594 .40916 .82049 .40164 Mtetra
.82049 .40164 .82594 .40916 .83898 .40509 .83357 .39754 Mtetra
.83357 .39754 .83898 .40509 .85207 .40101 .8467 .39343 Mtetra
.8467 .39343 .85207 .40101 .86522 .39691 .8599 .38929 Mtetra
.8599 .38929 .86522 .39691 .87843 .39279 .87315 .38514 Mtetra
.87315 .38514 .87843 .39279 .89171 .38865 .88647 .38097 Mtetra
.88647 .38097 .89171 .38865 .90504 .3845 .89984 .37677 Mtetra
.664 .741 .908 r
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49786 Mtetra
.30585 .49786 .31267 .50427 .32336 .5008 .31656 .49437 Mtetra
.31656 .49437 .32336 .5008 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49383 .33812 .48735 Mtetra
.33812 .48735 .34487 .49383 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36656 .48681 .35986 .48027 Mtetra
.35986 .48027 .36656 .48681 .37746 .48327 .3708 .47671 Mtetra
.3708 .47671 .37746 .48327 .38842 .47972 .38178 .47313 Mtetra
.38178 .47313 .38842 .47972 .39942 .47616 .39281 .46954 Mtetra
.39281 .46954 .39942 .47616 .41046 .47258 .40388 .46593 Mtetra
.40388 .46593 .41046 .47258 .42155 .46899 .415 .46231 Mtetra
.415 .46231 .42155 .46899 .43268 .46538 .42616 .45868 Mtetra
.77 .293 0 r
.42616 .45868 .43268 .46538 .44336 .48212 .43683 .47543 Mtetra
.662 .743 .91 r
.43683 .47543 .44336 .48212 .45466 .4785 .44815 .47178 Mtetra
.44815 .47178 .45466 .4785 .466 .47487 .45953 .46812 Mtetra
.45953 .46812 .466 .47487 .47739 .47122 .47095 .46444 Mtetra
.47095 .46444 .47739 .47122 .48883 .46755 .48242 .46075 Mtetra
.48242 .46075 .48883 .46755 .50032 .46387 .49393 .45704 Mtetra
.49393 .45704 .50032 .46387 .51185 .46018 .5055 .45332 Mtetra
.5055 .45332 .51185 .46018 .52344 .45647 .51712 .44958 Mtetra
.51712 .44958 .52344 .45647 .53507 .45274 .52878 .44582 Mtetra
.52878 .44582 .53507 .45274 .54675 .449 .5405 .44205 Mtetra
.5405 .44205 .54675 .449 .55848 .44524 .55226 .43826 Mtetra
.55226 .43826 .55848 .44524 .57026 .44147 .56407 .43446 Mtetra
.56407 .43446 .57026 .44147 .58209 .43768 .57594 .43064 Mtetra
.966 .662 .398 r
.57594 .43064 .58209 .43768 .5981 .6281 .59163 .62142 Mtetra
.646 .762 .934 r
.59163 .62142 .5981 .6281 .61075 .62449 .60432 .61778 Mtetra
.60432 .61778 .61075 .62449 .62347 .62086 .61707 .61413 Mtetra
.61707 .61413 .62347 .62086 .63624 .61722 .62989 .61045 Mtetra
.62989 .61045 .63624 .61722 .64907 .61356 .64276 .60676 Mtetra
.64276 .60676 .64907 .61356 .66196 .60989 .65568 .60305 Mtetra
.65568 .60305 .66196 .60989 .67491 .60619 .66867 .59933 Mtetra
.66867 .59933 .67491 .60619 .68791 .60248 .68172 .59559 Mtetra
.68172 .59559 .68791 .60248 .70098 .59875 .69483 .59183 Mtetra
.69483 .59183 .70098 .59875 .71411 .59501 .708 .58805 Mtetra
.708 .58805 .71411 .59501 .7273 .59125 .72123 .58426 Mtetra
.72123 .58426 .7273 .59125 .74055 .58747 .73453 .58045 Mtetra
.978 .713 .458 r
.73453 .58045 .74055 .58747 .74325 .42584 .73751 .41847 Mtetra
.659 .747 .915 r
.73751 .41847 .74325 .42584 .75598 .42185 .75028 .41444 Mtetra
.75028 .41444 .75598 .42185 .76877 .41785 .7631 .4104 Mtetra
.7631 .4104 .76877 .41785 .78161 .41382 .77599 .40635 Mtetra
.77599 .40635 .78161 .41382 .79451 .40978 .78893 .40227 Mtetra
.78893 .40227 .79451 .40978 .80747 .40572 .80193 .39817 Mtetra
.80193 .39817 .80747 .40572 .82049 .40164 .81499 .39406 Mtetra
.81499 .39406 .82049 .40164 .83357 .39754 .82811 .38993 Mtetra
.82811 .38993 .83357 .39754 .8467 .39343 .84128 .38578 Mtetra
.84128 .38578 .8467 .39343 .8599 .38929 .85452 .38161 Mtetra
.85452 .38161 .8599 .38929 .87315 .38514 .86782 .37742 Mtetra
.86782 .37742 .87315 .38514 .88647 .38097 .88118 .37321 Mtetra
.88118 .37321 .88647 .38097 .89984 .37677 .8946 .36899 Mtetra
.664 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .3708 .47671 .36408 .47009 Mtetra
.36408 .47009 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.37509 .46649 .38178 .47313 .39281 .46954 .38615 .46287 Mtetra
.38615 .46287 .39281 .46954 .40388 .46593 .39725 .45924 Mtetra
.39725 .45924 .40388 .46593 .415 .46231 .4084 .45559 Mtetra
.4084 .45559 .415 .46231 .42616 .45868 .41959 .45193 Mtetra
.77 .293 0 r
.41959 .45193 .42616 .45868 .43683 .47543 .43024 .46868 Mtetra
.662 .743 .91 r
.43024 .46868 .43683 .47543 .44815 .47178 .4416 .46501 Mtetra
.4416 .46501 .44815 .47178 .45953 .46812 .453 .46132 Mtetra
.453 .46132 .45953 .46812 .47095 .46444 .46445 .45761 Mtetra
.46445 .45761 .47095 .46444 .48242 .46075 .47595 .45389 Mtetra
.47595 .45389 .48242 .46075 .49393 .45704 .4875 .45015 Mtetra
.4875 .45015 .49393 .45704 .5055 .45332 .4991 .4464 Mtetra
.4991 .4464 .5055 .45332 .51712 .44958 .51075 .44263 Mtetra
.51075 .44263 .51712 .44958 .52878 .44582 .52244 .43885 Mtetra
.52244 .43885 .52878 .44582 .5405 .44205 .53419 .43505 Mtetra
.53419 .43505 .5405 .44205 .55226 .43826 .54599 .43123 Mtetra
.54599 .43123 .55226 .43826 .56407 .43446 .55784 .42739 Mtetra
.55784 .42739 .56407 .43446 .57594 .43064 .56974 .42354 Mtetra
.966 .662 .398 r
.56974 .42354 .57594 .43064 .59163 .62142 .5851 .61469 Mtetra
.646 .762 .934 r
.5851 .61469 .59163 .62142 .60432 .61778 .59784 .61102 Mtetra
.59784 .61102 .60432 .61778 .61707 .61413 .61063 .60733 Mtetra
.61063 .60733 .61707 .61413 .62989 .61045 .62348 .60363 Mtetra
.62348 .60363 .62989 .61045 .64276 .60676 .63639 .5999 Mtetra
.63639 .5999 .64276 .60676 .65568 .60305 .64936 .59616 Mtetra
.64936 .59616 .65568 .60305 .66867 .59933 .66239 .59241 Mtetra
.66239 .59241 .66867 .59933 .68172 .59559 .67548 .58863 Mtetra
.67548 .58863 .68172 .59559 .69483 .59183 .68863 .58484 Mtetra
.68863 .58484 .69483 .59183 .708 .58805 .70184 .58103 Mtetra
.70184 .58103 .708 .58805 .72123 .58426 .71511 .57721 Mtetra
.71511 .57721 .72123 .58426 .73453 .58045 .72845 .57336 Mtetra
.978 .713 .458 r
.72845 .57336 .73453 .58045 .73751 .41847 .73171 .41103 Mtetra
.659 .747 .915 r
.73171 .41103 .73751 .41847 .75028 .41444 .74452 .40697 Mtetra
.74452 .40697 .75028 .41444 .7631 .4104 .75739 .4029 Mtetra
.75739 .4029 .7631 .4104 .77599 .40635 .77031 .39881 Mtetra
.77031 .39881 .77599 .40635 .78893 .40227 .7833 .39469 Mtetra
.7833 .39469 .78893 .40227 .80193 .39817 .79634 .39057 Mtetra
.79634 .39057 .80193 .39817 .81499 .39406 .80944 .38642 Mtetra
.80944 .38642 .81499 .39406 .82811 .38993 .8226 .38225 Mtetra
.8226 .38225 .82811 .38993 .84128 .38578 .83582 .37807 Mtetra
.83582 .37807 .84128 .38578 .85452 .38161 .8491 .37386 Mtetra
.8491 .37386 .85452 .38161 .86782 .37742 .86245 .36964 Mtetra
.86245 .36964 .86782 .37742 .88118 .37321 .87585 .36539 Mtetra
.87585 .36539 .88118 .37321 .8946 .36899 .88932 .36113 Mtetra
.664 .741 .908 r
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.34633 .46705 .35312 .47368 .36408 .47009 .35732 .46343 Mtetra
.35732 .46343 .36408 .47009 .37509 .46649 .36835 .4598 Mtetra
.36835 .4598 .37509 .46649 .38615 .46287 .37944 .45615 Mtetra
.37944 .45615 .38615 .46287 .39725 .45924 .39057 .45249 Mtetra
.39057 .45249 .39725 .45924 .4084 .45559 .40174 .44881 Mtetra
.40174 .44881 .4084 .45559 .41959 .45193 .41296 .44512 Mtetra
.77 .293 0 r
.41296 .44512 .41959 .45193 .43024 .46868 .4236 .46189 Mtetra
.662 .743 .91 r
.4236 .46189 .43024 .46868 .4416 .46501 .43499 .45818 Mtetra
.43499 .45818 .4416 .46501 .453 .46132 .44642 .45446 Mtetra
.44642 .45446 .453 .46132 .46445 .45761 .45791 .45073 Mtetra
.45791 .45073 .46445 .45761 .47595 .45389 .46944 .44698 Mtetra
.46944 .44698 .47595 .45389 .4875 .45015 .48102 .44321 Mtetra
.48102 .44321 .4875 .45015 .4991 .4464 .49265 .43943 Mtetra
.49265 .43943 .4991 .4464 .51075 .44263 .50433 .43563 Mtetra
.50433 .43563 .51075 .44263 .52244 .43885 .51606 .43182 Mtetra
.51606 .43182 .52244 .43885 .53419 .43505 .52784 .42798 Mtetra
.52784 .42798 .53419 .43505 .54599 .43123 .53967 .42414 Mtetra
.53967 .42414 .54599 .43123 .55784 .42739 .55155 .42027 Mtetra
.55155 .42027 .55784 .42739 .56974 .42354 .56348 .41639 Mtetra
.966 .662 .398 r
.56348 .41639 .56974 .42354 .5851 .61469 .57852 .6079 Mtetra
.646 .762 .934 r
.57852 .6079 .5851 .61469 .59784 .61102 .59129 .6042 Mtetra
.59129 .6042 .59784 .61102 .61063 .60733 .60412 .60048 Mtetra
.60412 .60048 .61063 .60733 .62348 .60363 .61702 .59674 Mtetra
.61702 .59674 .62348 .60363 .63639 .5999 .62997 .59299 Mtetra
.62997 .59299 .63639 .5999 .64936 .59616 .64298 .58922 Mtetra
.64298 .58922 .64936 .59616 .66239 .59241 .65605 .58543 Mtetra
.65605 .58543 .66239 .59241 .67548 .58863 .66918 .58162 Mtetra
.66918 .58162 .67548 .58863 .68863 .58484 .68237 .5778 Mtetra
.68237 .5778 .68863 .58484 .70184 .58103 .69563 .57395 Mtetra
.69563 .57395 .70184 .58103 .71511 .57721 .70894 .57009 Mtetra
.70894 .57009 .71511 .57721 .72845 .57336 .72232 .56621 Mtetra
.978 .713 .458 r
.72232 .56621 .72845 .57336 .73171 .41103 .72587 .40352 Mtetra
.659 .747 .915 r
.72587 .40352 .73171 .41103 .74452 .40697 .73872 .39944 Mtetra
.73872 .39944 .74452 .40697 .75739 .4029 .75163 .39533 Mtetra
.75163 .39533 .75739 .4029 .77031 .39881 .7646 .3912 Mtetra
.7646 .3912 .77031 .39881 .7833 .39469 .77762 .38706 Mtetra
.77762 .38706 .7833 .39469 .79634 .39057 .7907 .38289 Mtetra
.7907 .38289 .79634 .39057 .80944 .38642 .80385 .37871 Mtetra
.80385 .37871 .80944 .38642 .8226 .38225 .81705 .37451 Mtetra
.81705 .37451 .8226 .38225 .83582 .37807 .83032 .37029 Mtetra
.83032 .37029 .83582 .37807 .8491 .37386 .84364 .36605 Mtetra
.84364 .36605 .8491 .37386 .86245 .36964 .85703 .36179 Mtetra
.85703 .36179 .86245 .36964 .87585 .36539 .87047 .35751 Mtetra
.87047 .35751 .87585 .36539 .88932 .36113 .88398 .35321 Mtetra
.664 .741 .908 r
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.3285 .46399 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45671 Mtetra
.3505 .45671 .35732 .46343 .36835 .4598 .36156 .45306 Mtetra
.36156 .45306 .36835 .4598 .37944 .45615 .37268 .44938 Mtetra
.37268 .44938 .37944 .45615 .39057 .45249 .38383 .44569 Mtetra
.38383 .44569 .39057 .45249 .40174 .44881 .39504 .44199 Mtetra
.39504 .44199 .40174 .44881 .41296 .44512 .40629 .43827 Mtetra
.77 .293 0 r
.40629 .43827 .41296 .44512 .4236 .46189 .41691 .45504 Mtetra
.662 .743 .91 r
.41691 .45504 .4236 .46189 .43499 .45818 .42833 .45131 Mtetra
.42833 .45131 .43499 .45818 .44642 .45446 .43979 .44756 Mtetra
.43979 .44756 .44642 .45446 .45791 .45073 .45131 .44379 Mtetra
.45131 .44379 .45791 .45073 .46944 .44698 .46287 .44001 Mtetra
.46287 .44001 .46944 .44698 .48102 .44321 .47448 .43622 Mtetra
.47448 .43622 .48102 .44321 .49265 .43943 .48614 .4324 Mtetra
.48614 .4324 .49265 .43943 .50433 .43563 .49786 .42858 Mtetra
.49786 .42858 .50433 .43563 .51606 .43182 .50962 .42473 Mtetra
.50962 .42473 .51606 .43182 .52784 .42798 .52143 .42087 Mtetra
.52143 .42087 .52784 .42798 .53967 .42414 .5333 .41699 Mtetra
.5333 .41699 .53967 .42414 .55155 .42027 .54521 .41309 Mtetra
.54521 .41309 .55155 .42027 .56348 .41639 .55718 .40918 Mtetra
.966 .662 .398 r
.55718 .40918 .56348 .41639 .57852 .6079 .57188 .60105 Mtetra
.646 .762 .934 r
.57188 .60105 .57852 .6079 .59129 .6042 .5847 .59732 Mtetra
.5847 .59732 .59129 .6042 .60412 .60048 .59757 .59357 Mtetra
.59757 .59357 .60412 .60048 .61702 .59674 .6105 .5898 Mtetra
.6105 .5898 .61702 .59674 .62997 .59299 .62349 .58601 Mtetra
.62349 .58601 .62997 .59299 .64298 .58922 .63654 .58221 Mtetra
.63654 .58221 .64298 .58922 .65605 .58543 .64965 .57839 Mtetra
.64965 .57839 .65605 .58543 .66918 .58162 .66282 .57455 Mtetra
.66282 .57455 .66918 .58162 .68237 .5778 .67606 .57069 Mtetra
.67606 .57069 .68237 .5778 .69563 .57395 .68936 .56681 Mtetra
.68936 .56681 .69563 .57395 .70894 .57009 .70272 .56292 Mtetra
.70272 .56292 .70894 .57009 .72232 .56621 .71614 .55901 Mtetra
.978 .713 .458 r
.71614 .55901 .72232 .56621 .72587 .40352 .71998 .39596 Mtetra
.659 .747 .915 r
.71998 .39596 .72587 .40352 .73872 .39944 .73287 .39184 Mtetra
.73287 .39184 .73872 .39944 .75163 .39533 .74582 .3877 Mtetra
.74582 .3877 .75163 .39533 .7646 .3912 .75883 .38354 Mtetra
.75883 .38354 .7646 .3912 .77762 .38706 .77189 .37936 Mtetra
.77189 .37936 .77762 .38706 .7907 .38289 .78502 .37516 Mtetra
.78502 .37516 .7907 .38289 .80385 .37871 .79821 .37094 Mtetra
.79821 .37094 .80385 .37871 .81705 .37451 .81145 .3667 Mtetra
.81145 .3667 .81705 .37451 .83032 .37029 .82476 .36244 Mtetra
.82476 .36244 .83032 .37029 .84364 .36605 .83813 .35817 Mtetra
.83813 .35817 .84364 .36605 .85703 .36179 .85156 .35387 Mtetra
.85156 .35387 .85703 .36179 .87047 .35751 .86505 .34955 Mtetra
.86505 .34955 .87047 .35751 .88398 .35321 .87861 .34522 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.33258 .45362 .33948 .46036 .3505 .45671 .34363 .44995 Mtetra
.34363 .44995 .3505 .45671 .36156 .45306 .35472 .44626 Mtetra
.35472 .44626 .36156 .45306 .37268 .44938 .36586 .44256 Mtetra
.36586 .44256 .37268 .44938 .38383 .44569 .37705 .43884 Mtetra
.37705 .43884 .38383 .44569 .39504 .44199 .38828 .4351 Mtetra
.38828 .4351 .39504 .44199 .40629 .43827 .39956 .43136 Mtetra
.77 .293 0 r
.39956 .43136 .40629 .43827 .41691 .45504 .41017 .44813 Mtetra
.662 .743 .91 r
.41017 .44813 .41691 .45504 .42833 .45131 .42162 .44437 Mtetra
.42162 .44437 .42833 .45131 .43979 .44756 .43311 .4406 Mtetra
.43311 .4406 .43979 .44756 .45131 .44379 .44466 .4368 Mtetra
.44466 .4368 .45131 .44379 .46287 .44001 .45625 .43299 Mtetra
.45625 .43299 .46287 .44001 .47448 .43622 .4679 .42917 Mtetra
.4679 .42917 .47448 .43622 .48614 .4324 .47959 .42532 Mtetra
.47959 .42532 .48614 .4324 .49786 .42858 .49133 .42146 Mtetra
.49133 .42146 .49786 .42858 .50962 .42473 .50313 .41759 Mtetra
.50313 .41759 .50962 .42473 .52143 .42087 .51498 .41369 Mtetra
.51498 .41369 .52143 .42087 .5333 .41699 .52687 .40979 Mtetra
.52687 .40979 .5333 .41699 .54521 .41309 .53882 .40586 Mtetra
.53882 .40586 .54521 .41309 .55718 .40918 .55082 .40192 Mtetra
.966 .662 .398 r
.55082 .40192 .55718 .40918 .57188 .60105 .56519 .59414 Mtetra
.646 .762 .934 r
.56519 .59414 .57188 .60105 .5847 .59732 .57804 .59038 Mtetra
.57804 .59038 .5847 .59732 .59757 .59357 .59095 .58659 Mtetra
.59095 .58659 .59757 .59357 .6105 .5898 .60392 .58279 Mtetra
.60392 .58279 .6105 .5898 .62349 .58601 .61695 .57897 Mtetra
.61695 .57897 .62349 .58601 .63654 .58221 .63005 .57514 Mtetra
.63005 .57514 .63654 .58221 .64965 .57839 .6432 .57128 Mtetra
.6432 .57128 .64965 .57839 .66282 .57455 .65642 .56741 Mtetra
.65642 .56741 .66282 .57455 .67606 .57069 .66969 .56352 Mtetra
.66969 .56352 .67606 .57069 .68936 .56681 .68303 .55961 Mtetra
.68303 .55961 .68936 .56681 .70272 .56292 .69644 .55568 Mtetra
.69644 .55568 .70272 .56292 .71614 .55901 .70991 .55173 Mtetra
.978 .713 .458 r
.70991 .55173 .71614 .55901 .71998 .39596 .71404 .38833 Mtetra
.659 .747 .915 r
.71404 .38833 .71998 .39596 .73287 .39184 .72698 .38418 Mtetra
.72698 .38418 .73287 .39184 .74582 .3877 .73996 .38 Mtetra
.73996 .38 .74582 .3877 .75883 .38354 .75301 .3758 Mtetra
.75301 .3758 .75883 .38354 .77189 .37936 .76612 .37159 Mtetra
.76612 .37159 .77189 .37936 .78502 .37516 .77929 .36735 Mtetra
.77929 .36735 .78502 .37516 .79821 .37094 .79252 .3631 Mtetra
.79252 .3631 .79821 .37094 .81145 .3667 .80581 .35883 Mtetra
.80581 .35883 .81145 .3667 .82476 .36244 .81916 .35453 Mtetra
.81916 .35453 .82476 .36244 .83813 .35817 .83257 .35022 Mtetra
.83257 .35022 .83813 .35817 .85156 .35387 .84605 .34589 Mtetra
.84605 .34589 .85156 .35387 .86505 .34955 .85959 .34153 Mtetra
.85959 .34153 .86505 .34955 .87861 .34522 .87319 .33716 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
.3146 .45051 .32158 .45728 .33258 .45362 .32563 .44683 Mtetra
.32563 .44683 .33258 .45362 .34363 .44995 .3367 .44313 Mtetra
.3367 .44313 .34363 .44995 .35472 .44626 .34783 .43941 Mtetra
.34783 .43941 .35472 .44626 .36586 .44256 .35899 .43568 Mtetra
.35899 .43568 .36586 .44256 .37705 .43884 .37021 .43193 Mtetra
.37021 .43193 .37705 .43884 .38828 .4351 .38147 .42817 Mtetra
.38147 .42817 .38828 .4351 .39956 .43136 .39278 .42439 Mtetra
.77 .293 0 r
.39278 .42439 .39956 .43136 .41017 .44813 .40338 .44118 Mtetra
.662 .743 .91 r
.40338 .44118 .41017 .44813 .42162 .44437 .41485 .43739 Mtetra
.41485 .43739 .42162 .44437 .43311 .4406 .42638 .43358 Mtetra
.42638 .43358 .43311 .4406 .44466 .4368 .43796 .42976 Mtetra
.43796 .42976 .44466 .4368 .45625 .43299 .44958 .42592 Mtetra
.44958 .42592 .45625 .43299 .4679 .42917 .46126 .42206 Mtetra
.46126 .42206 .4679 .42917 .47959 .42532 .47298 .41819 Mtetra
.47298 .41819 .47959 .42532 .49133 .42146 .48476 .41429 Mtetra
.48476 .41429 .49133 .42146 .50313 .41759 .49659 .41039 Mtetra
.49659 .41039 .50313 .41759 .51498 .41369 .50847 .40646 Mtetra
.50847 .40646 .51498 .41369 .52687 .40979 .5204 .40252 Mtetra
.5204 .40252 .52687 .40979 .53882 .40586 .53238 .39856 Mtetra
.53238 .39856 .53882 .40586 .55082 .40192 .54442 .39459 Mtetra
.966 .662 .398 r
.54442 .39459 .55082 .40192 .56519 .59414 .55844 .58718 Mtetra
.646 .762 .934 r
.55844 .58718 .56519 .59414 .57804 .59038 .57133 .58338 Mtetra
.57133 .58338 .57804 .59038 .59095 .58659 .58428 .57956 Mtetra
.58428 .57956 .59095 .58659 .60392 .58279 .59729 .57573 Mtetra
.59729 .57573 .60392 .58279 .61695 .57897 .61036 .57188 Mtetra
.61036 .57188 .61695 .57897 .63005 .57514 .6235 .56801 Mtetra
.6235 .56801 .63005 .57514 .6432 .57128 .63669 .56412 Mtetra
.63669 .56412 .6432 .57128 .65642 .56741 .64995 .56021 Mtetra
.64995 .56021 .65642 .56741 .66969 .56352 .66327 .55629 Mtetra
.66327 .55629 .66969 .56352 .68303 .55961 .67666 .55234 Mtetra
.67666 .55234 .68303 .55961 .69644 .55568 .6901 .54838 Mtetra
.6901 .54838 .69644 .55568 .70991 .55173 .70361 .5444 Mtetra
.978 .713 .458 r
.70361 .5444 .70991 .55173 .71404 .38833 .70806 .38064 Mtetra
.659 .747 .915 r
.70806 .38064 .71404 .38833 .72698 .38418 .72103 .37645 Mtetra
.72103 .37645 .72698 .38418 .73996 .38 .73406 .37224 Mtetra
.73406 .37224 .73996 .38 .75301 .3758 .74715 .36801 Mtetra
.74715 .36801 .75301 .3758 .76612 .37159 .7603 .36376 Mtetra
.7603 .36376 .76612 .37159 .77929 .36735 .77351 .35949 Mtetra
.77351 .35949 .77929 .36735 .79252 .3631 .78678 .3552 Mtetra
.78678 .3552 .79252 .3631 .80581 .35883 .80011 .35089 Mtetra
.80011 .35089 .80581 .35883 .81916 .35453 .81351 .34655 Mtetra
.81351 .34655 .81916 .35453 .83257 .35022 .82697 .3422 Mtetra
.82697 .3422 .83257 .35022 .84605 .34589 .84049 .33783 Mtetra
.84049 .33783 .84605 .34589 .85959 .34153 .85407 .33344 Mtetra
.85407 .33344 .85959 .34153 .87319 .33716 .86772 .32903 Mtetra
.664 .741 .908 r
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.28559 .45108 .29268 .45784 .30361 .45418 .29655 .4474 Mtetra
.29655 .4474 .30361 .45418 .3146 .45051 .30756 .4437 Mtetra
.30756 .4437 .3146 .45051 .32563 .44683 .31862 .43998 Mtetra
.31862 .43998 .32563 .44683 .3367 .44313 .32973 .43626 Mtetra
.32973 .43626 .3367 .44313 .34783 .43941 .34088 .43251 Mtetra
.34088 .43251 .34783 .43941 .35899 .43568 .35207 .42875 Mtetra
.35207 .42875 .35899 .43568 .37021 .43193 .36332 .42497 Mtetra
.36332 .42497 .37021 .43193 .38147 .42817 .37461 .42118 Mtetra
.37461 .42118 .38147 .42817 .39278 .42439 .38595 .41737 Mtetra
.77 .293 0 r
.38595 .41737 .39278 .42439 .40338 .44118 .39653 .43417 Mtetra
.662 .743 .91 r
.39653 .43417 .40338 .44118 .41485 .43739 .40804 .43034 Mtetra
.40804 .43034 .41485 .43739 .42638 .43358 .41959 .42651 Mtetra
.41959 .42651 .42638 .43358 .43796 .42976 .4312 .42265 Mtetra
.4312 .42265 .43796 .42976 .44958 .42592 .44286 .41878 Mtetra
.44286 .41878 .44958 .42592 .46126 .42206 .45457 .41489 Mtetra
.45457 .41489 .46126 .42206 .47298 .41819 .46632 .41099 Mtetra
.46632 .41099 .47298 .41819 .48476 .41429 .47813 .40707 Mtetra
.47813 .40707 .48476 .41429 .49659 .41039 .49 .40313 Mtetra
.49 .40313 .49659 .41039 .50847 .40646 .50191 .39917 Mtetra
.50191 .39917 .50847 .40646 .5204 .40252 .51387 .3952 Mtetra
.51387 .3952 .5204 .40252 .53238 .39856 .52589 .39121 Mtetra
.52589 .39121 .53238 .39856 .54442 .39459 .53796 .3872 Mtetra
.966 .662 .398 r
.53796 .3872 .54442 .39459 .55844 .58718 .55163 .58015 Mtetra
.646 .762 .934 r
.55163 .58015 .55844 .58718 .57133 .58338 .56456 .57632 Mtetra
.56456 .57632 .57133 .58338 .58428 .57956 .57755 .57247 Mtetra
.57755 .57247 .58428 .57956 .59729 .57573 .5906 .5686 Mtetra
.5906 .5686 .59729 .57573 .61036 .57188 .60372 .56472 Mtetra
.60372 .56472 .61036 .57188 .6235 .56801 .61689 .56081 Mtetra
.61689 .56081 .6235 .56801 .63669 .56412 .63013 .55689 Mtetra
.63013 .55689 .63669 .56412 .64995 .56021 .64343 .55295 Mtetra
.64343 .55295 .64995 .56021 .66327 .55629 .65679 .54899 Mtetra
.65679 .54899 .66327 .55629 .67666 .55234 .67022 .54501 Mtetra
.67022 .54501 .67666 .55234 .6901 .54838 .68371 .54101 Mtetra
.68371 .54101 .6901 .54838 .70361 .5444 .69727 .537 Mtetra
.978 .713 .458 r
.69727 .537 .70361 .5444 .70806 .38064 .70202 .37289 Mtetra
.659 .747 .915 r
.70202 .37289 .70806 .38064 .72103 .37645 .71503 .36866 Mtetra
.71503 .36866 .72103 .37645 .73406 .37224 .7281 .36441 Mtetra
.7281 .36441 .73406 .37224 .74715 .36801 .74123 .36014 Mtetra
.74123 .36014 .74715 .36801 .7603 .36376 .75443 .35586 Mtetra
.75443 .35586 .7603 .36376 .77351 .35949 .76768 .35155 Mtetra
.76768 .35155 .77351 .35949 .78678 .3552 .78099 .34722 Mtetra
.78099 .34722 .78678 .3552 .80011 .35089 .79437 .34288 Mtetra
.79437 .34288 .80011 .35089 .81351 .34655 .80781 .33851 Mtetra
.80781 .33851 .81351 .34655 .82697 .3422 .82131 .33412 Mtetra
.82131 .33412 .82697 .3422 .84049 .33783 .83488 .32971 Mtetra
.83488 .32971 .84049 .33783 .85407 .33344 .84851 .32528 Mtetra
.84851 .32528 .85407 .33344 .86772 .32903 .8622 .32083 Mtetra
.664 .741 .908 r
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .4437 .30048 .43683 Mtetra
.30048 .43683 .30756 .4437 .31862 .43998 .31156 .43309 Mtetra
.31156 .43309 .31862 .43998 .32973 .43626 .32269 .42933 Mtetra
.32269 .42933 .32973 .43626 .34088 .43251 .33387 .42556 Mtetra
.33387 .42556 .34088 .43251 .35207 .42875 .3451 .42177 Mtetra
.3451 .42177 .35207 .42875 .36332 .42497 .35637 .41796 Mtetra
.35637 .41796 .36332 .42497 .37461 .42118 .3677 .41414 Mtetra
.3677 .41414 .37461 .42118 .38595 .41737 .37907 .4103 Mtetra
.77 .293 0 r
.37907 .4103 .38595 .41737 .39653 .43417 .38962 .4271 Mtetra
.662 .743 .91 r
.38962 .4271 .39653 .43417 .40804 .43034 .40116 .42325 Mtetra
.40116 .42325 .40804 .43034 .41959 .42651 .41275 .41938 Mtetra
.41275 .41938 .41959 .42651 .4312 .42265 .42439 .41549 Mtetra
.42439 .41549 .4312 .42265 .44286 .41878 .43608 .41159 Mtetra
.43608 .41159 .44286 .41878 .45457 .41489 .44782 .40767 Mtetra
.44782 .40767 .45457 .41489 .46632 .41099 .45961 .40374 Mtetra
.45961 .40374 .46632 .41099 .47813 .40707 .47145 .39978 Mtetra
.47145 .39978 .47813 .40707 .49 .40313 .48335 .39581 Mtetra
.48335 .39581 .49 .40313 .50191 .39917 .4953 .39183 Mtetra
.4953 .39183 .50191 .39917 .51387 .3952 .50729 .38782 Mtetra
.50729 .38782 .51387 .3952 .52589 .39121 .51935 .3838 Mtetra
.51935 .3838 .52589 .39121 .53796 .3872 .53145 .37976 Mtetra
.966 .662 .398 r
.53145 .37976 .53796 .3872 .55163 .58015 .54476 .57306 Mtetra
.646 .762 .934 r
.54476 .57306 .55163 .58015 .56456 .57632 .55773 .5692 Mtetra
.55773 .5692 .56456 .57632 .57755 .57247 .57076 .56532 Mtetra
.57076 .56532 .57755 .57247 .5906 .5686 .58386 .56142 Mtetra
.58386 .56142 .5906 .5686 .60372 .56472 .59701 .5575 Mtetra
.59701 .5575 .60372 .56472 .61689 .56081 .61023 .55356 Mtetra
.61023 .55356 .61689 .56081 .63013 .55689 .62351 .5496 Mtetra
.62351 .5496 .63013 .55689 .64343 .55295 .63685 .54563 Mtetra
.63685 .54563 .64343 .55295 .65679 .54899 .65026 .54163 Mtetra
.65026 .54163 .65679 .54899 .67022 .54501 .66373 .53762 Mtetra
.66373 .53762 .67022 .54501 .68371 .54101 .67726 .53358 Mtetra
.67726 .53358 .68371 .54101 .69727 .537 .69087 .52953 Mtetra
.978 .713 .458 r
.69087 .52953 .69727 .537 .70202 .37289 .69593 .36507 Mtetra
.659 .747 .915 r
.69593 .36507 .70202 .37289 .71503 .36866 .70898 .3608 Mtetra
.70898 .3608 .71503 .36866 .7281 .36441 .72209 .35652 Mtetra
.72209 .35652 .7281 .36441 .74123 .36014 .73527 .35221 Mtetra
.73527 .35221 .74123 .36014 .75443 .35586 .7485 .34789 Mtetra
.7485 .34789 .75443 .35586 .76768 .35155 .7618 .34355 Mtetra
.7618 .34355 .76768 .35155 .78099 .34722 .77516 .33918 Mtetra
.77516 .33918 .78099 .34722 .79437 .34288 .78858 .3348 Mtetra
.78858 .3348 .79437 .34288 .80781 .33851 .80206 .33039 Mtetra
.80206 .33039 .80781 .33851 .82131 .33412 .81561 .32597 Mtetra
.81561 .32597 .82131 .33412 .83488 .32971 .82922 .32152 Mtetra
.82922 .32152 .83488 .32971 .84851 .32528 .8429 .31705 Mtetra
.8429 .31705 .84851 .32528 .8622 .32083 .85664 .31256 Mtetra
.664 .741 .908 r
.23846 .44853 .24574 .45531 .25659 .45164 .24934 .44484 Mtetra
.24934 .44484 .25659 .45164 .2675 .44796 .26027 .44113 Mtetra
.26027 .44113 .2675 .44796 .27844 .44427 .27124 .4374 Mtetra
.27124 .4374 .27844 .44427 .28944 .44056 .28226 .43366 Mtetra
.28226 .43366 .28944 .44056 .30048 .43683 .29333 .42991 Mtetra
.29333 .42991 .30048 .43683 .31156 .43309 .30445 .42614 Mtetra
.30445 .42614 .31156 .43309 .32269 .42933 .31561 .42235 Mtetra
.31561 .42235 .32269 .42933 .33387 .42556 .32681 .41855 Mtetra
.32681 .41855 .33387 .42556 .3451 .42177 .33807 .41473 Mtetra
.33807 .41473 .3451 .42177 .35637 .41796 .34937 .41089 Mtetra
.34937 .41089 .35637 .41796 .3677 .41414 .36072 .40704 Mtetra
.36072 .40704 .3677 .41414 .37907 .4103 .37213 .40317 Mtetra
.37213 .40317 .37907 .4103 .38962 .4271 .38357 .39928 Mtetra
.606 .478 .68 r
.38357 .39928 .38962 .4271 .40116 .42325 .39507 .39538 Mtetra
.39507 .39538 .40116 .42325 .41275 .41938 .40662 .39146 Mtetra
.40662 .39146 .41275 .41938 .42439 .41549 .41822 .38753 Mtetra
.41822 .38753 .42439 .41549 .43608 .41159 .42986 .38358 Mtetra
.42986 .38358 .43608 .41159 .44782 .40767 .44156 .37961 Mtetra
.44156 .37961 .44782 .40767 .45961 .40374 .45331 .37562 Mtetra
.45331 .37562 .45961 .40374 .47145 .39978 .46511 .37161 Mtetra
.46511 .37161 .47145 .39978 .48335 .39581 .47696 .36759 Mtetra
.47696 .36759 .48335 .39581 .4953 .39183 .48886 .36355 Mtetra
.48886 .36355 .4953 .39183 .50729 .38782 .50082 .3595 Mtetra
.50082 .3595 .50729 .38782 .51935 .3838 .51283 .35542 Mtetra
.51283 .35542 .51935 .3838 .53145 .37976 .52489 .35133 Mtetra
.52489 .35133 .53145 .37976 .54476 .57306 .537 .34722 Mtetra
.554 .346 .553 r
.537 .34722 .54476 .57306 .55773 .5692 .54917 .34309 Mtetra
.54917 .34309 .55773 .5692 .57076 .56532 .56139 .33894 Mtetra
.56139 .33894 .57076 .56532 .58386 .56142 .57366 .33478 Mtetra
.57366 .33478 .58386 .56142 .59701 .5575 .58599 .33059 Mtetra
.58599 .33059 .59701 .5575 .61023 .55356 .59838 .32639 Mtetra
.59838 .32639 .61023 .55356 .62351 .5496 .61082 .32217 Mtetra
.61082 .32217 .62351 .5496 .63685 .54563 .62331 .31793 Mtetra
.62331 .31793 .63685 .54563 .65026 .54163 .63586 .31367 Mtetra
.63586 .31367 .65026 .54163 .66373 .53762 .64847 .30939 Mtetra
.64847 .30939 .66373 .53762 .67726 .53358 .66113 .30509 Mtetra
.66113 .30509 .67726 .53358 .69087 .52953 .67385 .30078 Mtetra
.524 .325 .552 r
.67385 .30078 .69087 .52953 .69593 .36507 .68755 .31406 Mtetra
.583 .416 .621 r
.68755 .31406 .69593 .36507 .70898 .3608 .70046 .30972 Mtetra
.70046 .30972 .70898 .3608 .72209 .35652 .71343 .30536 Mtetra
.71343 .30536 .72209 .35652 .73527 .35221 .72646 .30098 Mtetra
.72646 .30098 .73527 .35221 .7485 .34789 .73955 .29658 Mtetra
.73955 .29658 .7485 .34789 .7618 .34355 .7527 .29216 Mtetra
.7527 .29216 .7618 .34355 .77516 .33918 .76591 .28772 Mtetra
.76591 .28772 .77516 .33918 .78858 .3348 .77918 .28325 Mtetra
.77918 .28325 .78858 .3348 .80206 .33039 .79252 .27877 Mtetra
.79252 .27877 .80206 .33039 .81561 .32597 .80591 .27427 Mtetra
.80591 .27427 .81561 .32597 .82922 .32152 .81937 .26974 Mtetra
.81937 .26974 .82922 .32152 .8429 .31705 .83289 .2652 Mtetra
.83289 .2652 .8429 .31705 .85664 .31256 .84648 .26063 Mtetra
.664 .741 .908 r
.23112 .4417 .23846 .44853 .24934 .44484 .24203 .43798 Mtetra
.24203 .43798 .24934 .44484 .26027 .44113 .25299 .43424 Mtetra
.25299 .43424 .26027 .44113 .27124 .4374 .26399 .43049 Mtetra
.26399 .43049 .27124 .4374 .28226 .43366 .27504 .42672 Mtetra
.27504 .42672 .28226 .43366 .29333 .42991 .28613 .42293 Mtetra
.28613 .42293 .29333 .42991 .30445 .42614 .29727 .41913 Mtetra
.29727 .41913 .30445 .42614 .31561 .42235 .30846 .41532 Mtetra
.30846 .41532 .31561 .42235 .32681 .41855 .3197 .41148 Mtetra
.3197 .41148 .32681 .41855 .33807 .41473 .33099 .40763 Mtetra
.33099 .40763 .33807 .41473 .34937 .41089 .34232 .40377 Mtetra
.34232 .40377 .34937 .41089 .36072 .40704 .3537 .39988 Mtetra
.3537 .39988 .36072 .40704 .37213 .40317 .36513 .39598 Mtetra
.36513 .39598 .37213 .40317 .38357 .39928 .37661 .39207 Mtetra
.37661 .39207 .38357 .39928 .39507 .39538 .38814 .38814 Mtetra
.38814 .38814 .39507 .39538 .40662 .39146 .39972 .38419 Mtetra
.39972 .38419 .40662 .39146 .41822 .38753 .41135 .38022 Mtetra
.41135 .38022 .41822 .38753 .42986 .38358 .42302 .37623 Mtetra
.42302 .37623 .42986 .38358 .44156 .37961 .43475 .37223 Mtetra
.43475 .37223 .44156 .37961 .45331 .37562 .44654 .36821 Mtetra
.44654 .36821 .45331 .37562 .46511 .37161 .45837 .36418 Mtetra
.45837 .36418 .46511 .37161 .47696 .36759 .47025 .36012 Mtetra
.47025 .36012 .47696 .36759 .48886 .36355 .48219 .35605 Mtetra
.48219 .35605 .48886 .36355 .50082 .3595 .49418 .35196 Mtetra
.49418 .35196 .50082 .3595 .51283 .35542 .50622 .34785 Mtetra
.50622 .34785 .51283 .35542 .52489 .35133 .51831 .34373 Mtetra
.51831 .34373 .52489 .35133 .537 .34722 .53046 .33958 Mtetra
.53046 .33958 .537 .34722 .54917 .34309 .54266 .33542 Mtetra
.54266 .33542 .54917 .34309 .56139 .33894 .55492 .33124 Mtetra
.55492 .33124 .56139 .33894 .57366 .33478 .56723 .32704 Mtetra
.56723 .32704 .57366 .33478 .58599 .33059 .5796 .32282 Mtetra
.5796 .32282 .58599 .33059 .59838 .32639 .59202 .31858 Mtetra
.59202 .31858 .59838 .32639 .61082 .32217 .60449 .31433 Mtetra
.60449 .31433 .61082 .32217 .62331 .31793 .61703 .31005 Mtetra
.61703 .31005 .62331 .31793 .63586 .31367 .62962 .30576 Mtetra
.62962 .30576 .63586 .31367 .64847 .30939 .64226 .30144 Mtetra
.64226 .30144 .64847 .30939 .66113 .30509 .65497 .29711 Mtetra
.65497 .29711 .66113 .30509 .67385 .30078 .66773 .29276 Mtetra
0 .095 .628 r
.66773 .29276 .67385 .30078 .68755 .31406 .68143 .30603 Mtetra
.662 .743 .91 r
.68143 .30603 .68755 .31406 .70046 .30972 .69438 .30166 Mtetra
.69438 .30166 .70046 .30972 .71343 .30536 .70739 .29726 Mtetra
.70739 .29726 .71343 .30536 .72646 .30098 .72046 .29284 Mtetra
.72046 .29284 .72646 .30098 .73955 .29658 .7336 .2884 Mtetra
.7336 .2884 .73955 .29658 .7527 .29216 .74679 .28394 Mtetra
.74679 .28394 .7527 .29216 .76591 .28772 .76004 .27946 Mtetra
.76004 .27946 .76591 .28772 .77918 .28325 .77336 .27496 Mtetra
.77336 .27496 .77918 .28325 .79252 .27877 .78673 .27044 Mtetra
.78673 .27044 .79252 .27877 .80591 .27427 .80017 .2659 Mtetra
.80017 .2659 .80591 .27427 .81937 .26974 .81368 .26134 Mtetra
.81368 .26134 .81937 .26974 .83289 .2652 .82724 .25675 Mtetra
.82724 .25675 .83289 .2652 .84648 .26063 .84087 .25214 Mtetra
.664 .741 .908 r
.22373 .43482 .23112 .4417 .24203 .43798 .23467 .43107 Mtetra
.23467 .43107 .24203 .43798 .25299 .43424 .24565 .4273 Mtetra
.24565 .4273 .25299 .43424 .26399 .43049 .25668 .42352 Mtetra
.25668 .42352 .26399 .43049 .27504 .42672 .26775 .41972 Mtetra
.26775 .41972 .27504 .42672 .28613 .42293 .27888 .4159 Mtetra
.27888 .4159 .28613 .42293 .29727 .41913 .29005 .41207 Mtetra
.29005 .41207 .29727 .41913 .30846 .41532 .30127 .40823 Mtetra
.30127 .40823 .30846 .41532 .3197 .41148 .31253 .40436 Mtetra
.31253 .40436 .3197 .41148 .33099 .40763 .32384 .40048 Mtetra
.32384 .40048 .33099 .40763 .34232 .40377 .33521 .39659 Mtetra
.33521 .39659 .34232 .40377 .3537 .39988 .34662 .39267 Mtetra
.34662 .39267 .3537 .39988 .36513 .39598 .35808 .38874 Mtetra
.35808 .38874 .36513 .39598 .37661 .39207 .36959 .38479 Mtetra
.36959 .38479 .37661 .39207 .38814 .38814 .38115 .38083 Mtetra
.38115 .38083 .38814 .38814 .39972 .38419 .39276 .37685 Mtetra
.39276 .37685 .39972 .38419 .41135 .38022 .40442 .37285 Mtetra
.40442 .37285 .41135 .38022 .42302 .37623 .41613 .36883 Mtetra
.41613 .36883 .42302 .37623 .43475 .37223 .42789 .3648 Mtetra
.42789 .3648 .43475 .37223 .44654 .36821 .43971 .36075 Mtetra
.43971 .36075 .44654 .36821 .45837 .36418 .45157 .35668 Mtetra
.45157 .35668 .45837 .36418 .47025 .36012 .46349 .35259 Mtetra
.46349 .35259 .47025 .36012 .48219 .35605 .47546 .34849 Mtetra
.47546 .34849 .48219 .35605 .49418 .35196 .48748 .34436 Mtetra
.48748 .34436 .49418 .35196 .50622 .34785 .49956 .34022 Mtetra
.49956 .34022 .50622 .34785 .51831 .34373 .51169 .33606 Mtetra
.51169 .33606 .51831 .34373 .53046 .33958 .52387 .33188 Mtetra
.52387 .33188 .53046 .33958 .54266 .33542 .53611 .32769 Mtetra
.53611 .32769 .54266 .33542 .55492 .33124 .5484 .32347 Mtetra
.5484 .32347 .55492 .33124 .56723 .32704 .56075 .31924 Mtetra
.56075 .31924 .56723 .32704 .5796 .32282 .57315 .31498 Mtetra
.57315 .31498 .5796 .32282 .59202 .31858 .58561 .31071 Mtetra
.58561 .31071 .59202 .31858 .60449 .31433 .59812 .30642 Mtetra
.59812 .30642 .60449 .31433 .61703 .31005 .61069 .30211 Mtetra
.61069 .30211 .61703 .31005 .62962 .30576 .62332 .29778 Mtetra
.62332 .29778 .62962 .30576 .64226 .30144 .636 .29343 Mtetra
.636 .29343 .64226 .30144 .65497 .29711 .64874 .28906 Mtetra
.64874 .28906 .65497 .29711 .66773 .29276 .66155 .28467 Mtetra
0 .095 .628 r
.66155 .28467 .66773 .29276 .68143 .30603 .67526 .29794 Mtetra
.662 .743 .91 r
.67526 .29794 .68143 .30603 .69438 .30166 .68825 .29352 Mtetra
.68825 .29352 .69438 .30166 .70739 .29726 .7013 .28909 Mtetra
.7013 .28909 .70739 .29726 .72046 .29284 .71442 .28463 Mtetra
.71442 .28463 .72046 .29284 .7336 .2884 .72759 .28015 Mtetra
.72759 .28015 .7336 .2884 .74679 .28394 .74082 .27566 Mtetra
.74082 .27566 .74679 .28394 .76004 .27946 .75412 .27114 Mtetra
.75412 .27114 .76004 .27946 .77336 .27496 .76748 .2666 Mtetra
.76748 .2666 .77336 .27496 .78673 .27044 .7809 .26204 Mtetra
.7809 .26204 .78673 .27044 .80017 .2659 .79439 .25746 Mtetra
.79439 .25746 .80017 .2659 .81368 .26134 .80793 .25285 Mtetra
.80793 .25285 .81368 .26134 .82724 .25675 .82154 .24823 Mtetra
.82154 .24823 .82724 .25675 .84087 .25214 .83522 .24358 Mtetra
.664 .741 .908 r
.21628 .42788 .22373 .43482 .23467 .43107 .22724 .4241 Mtetra
.22724 .4241 .23467 .43107 .24565 .4273 .23825 .4203 Mtetra
.23825 .4203 .24565 .4273 .25668 .42352 .24931 .41649 Mtetra
.24931 .41649 .25668 .42352 .26775 .41972 .26041 .41266 Mtetra
.26041 .41266 .26775 .41972 .27888 .4159 .27156 .40882 Mtetra
.27156 .40882 .27888 .4159 .29005 .41207 .28276 .40496 Mtetra
.28276 .40496 .29005 .41207 .30127 .40823 .29401 .40108 Mtetra
.29401 .40108 .30127 .40823 .31253 .40436 .3053 .39719 Mtetra
.3053 .39719 .31253 .40436 .32384 .40048 .31665 .39327 Mtetra
.31665 .39327 .32384 .40048 .33521 .39659 .32804 .38935 Mtetra
.32804 .38935 .33521 .39659 .34662 .39267 .33948 .3854 Mtetra
.33948 .3854 .34662 .39267 .35808 .38874 .35097 .38144 Mtetra
.35097 .38144 .35808 .38874 .36959 .38479 .36251 .37746 Mtetra
.36251 .37746 .36959 .38479 .38115 .38083 .3741 .37347 Mtetra
.3741 .37347 .38115 .38083 .39276 .37685 .38574 .36945 Mtetra
.38574 .36945 .39276 .37685 .40442 .37285 .39744 .36542 Mtetra
.39744 .36542 .40442 .37285 .41613 .36883 .40918 .36137 Mtetra
.40918 .36137 .41613 .36883 .42789 .3648 .42097 .35731 Mtetra
.42097 .35731 .42789 .3648 .43971 .36075 .43282 .35322 Mtetra
.43282 .35322 .43971 .36075 .45157 .35668 .44472 .34912 Mtetra
.44472 .34912 .45157 .35668 .46349 .35259 .45667 .345 Mtetra
.45667 .345 .46349 .35259 .47546 .34849 .46867 .34086 Mtetra
.46867 .34086 .47546 .34849 .48748 .34436 .48073 .3367 Mtetra
.48073 .3367 .48748 .34436 .49956 .34022 .49284 .33253 Mtetra
.49284 .33253 .49956 .34022 .51169 .33606 .505 .32833 Mtetra
.505 .32833 .51169 .33606 .52387 .33188 .51722 .32412 Mtetra
.51722 .32412 .52387 .33188 .53611 .32769 .5295 .31989 Mtetra
.5295 .31989 .53611 .32769 .5484 .32347 .54182 .31564 Mtetra
.54182 .31564 .5484 .32347 .56075 .31924 .55421 .31137 Mtetra
.55421 .31137 .56075 .31924 .57315 .31498 .56665 .30708 Mtetra
.56665 .30708 .57315 .31498 .58561 .31071 .57914 .30277 Mtetra
.57914 .30277 .58561 .31071 .59812 .30642 .59169 .29844 Mtetra
.59169 .29844 .59812 .30642 .61069 .30211 .6043 .2941 Mtetra
.6043 .2941 .61069 .30211 .62332 .29778 .61697 .28973 Mtetra
.61697 .28973 .62332 .29778 .636 .29343 .62969 .28534 Mtetra
.62969 .28534 .636 .29343 .64874 .28906 .64247 .28094 Mtetra
.64247 .28094 .64874 .28906 .66155 .28467 .65531 .27651 Mtetra
0 .095 .628 r
.65531 .27651 .66155 .28467 .67526 .29794 .66903 .28977 Mtetra
.662 .743 .91 r
.66903 .28977 .67526 .29794 .68825 .29352 .68207 .28532 Mtetra
.68207 .28532 .68825 .29352 .7013 .28909 .69516 .28084 Mtetra
.69516 .28084 .7013 .28909 .71442 .28463 .70832 .27635 Mtetra
.70832 .27635 .71442 .28463 .72759 .28015 .72153 .27184 Mtetra
.72153 .27184 .72759 .28015 .74082 .27566 .73481 .2673 Mtetra
.73481 .2673 .74082 .27566 .75412 .27114 .74815 .26274 Mtetra
.74815 .26274 .75412 .27114 .76748 .2666 .76155 .25816 Mtetra
.76155 .25816 .76748 .2666 .7809 .26204 .77502 .25356 Mtetra
.77502 .25356 .7809 .26204 .79439 .25746 .78855 .24894 Mtetra
.78855 .24894 .79439 .25746 .80793 .25285 .80214 .2443 Mtetra
.80214 .2443 .80793 .25285 .82154 .24823 .8158 .23963 Mtetra
.8158 .23963 .82154 .24823 .83522 .24358 .82952 .23495 Mtetra
.664 .741 .908 r
.20877 .42089 .21628 .42788 .22724 .4241 .21976 .41708 Mtetra
.21976 .41708 .22724 .4241 .23825 .4203 .2308 .41325 Mtetra
.2308 .41325 .23825 .4203 .24931 .41649 .24188 .40941 Mtetra
.24188 .40941 .24931 .41649 .26041 .41266 .25302 .40555 Mtetra
.25302 .40555 .26041 .41266 .27156 .40882 .26419 .40168 Mtetra
.26419 .40168 .27156 .40882 .28276 .40496 .27542 .39779 Mtetra
.27542 .39779 .28276 .40496 .29401 .40108 .2867 .39388 Mtetra
.2867 .39388 .29401 .40108 .3053 .39719 .29802 .38995 Mtetra
.29802 .38995 .3053 .39719 .31665 .39327 .30939 .38601 Mtetra
.30939 .38601 .31665 .39327 .32804 .38935 .32082 .38205 Mtetra
.32082 .38205 .32804 .38935 .33948 .3854 .33229 .37807 Mtetra
.33229 .37807 .33948 .3854 .35097 .38144 .34381 .37408 Mtetra
.34381 .37408 .35097 .38144 .36251 .37746 .35538 .37007 Mtetra
.35538 .37007 .36251 .37746 .3741 .37347 .367 .36604 Mtetra
.367 .36604 .3741 .37347 .38574 .36945 .37867 .362 Mtetra
.37867 .362 .38574 .36945 .39744 .36542 .3904 .35793 Mtetra
.3904 .35793 .39744 .36542 .40918 .36137 .40217 .35385 Mtetra
.40217 .35385 .40918 .36137 .42097 .35731 .414 .34975 Mtetra
.414 .34975 .42097 .35731 .43282 .35322 .42588 .34563 Mtetra
.42588 .34563 .43282 .35322 .44472 .34912 .43781 .3415 Mtetra
.43781 .3415 .44472 .34912 .45667 .345 .44979 .33734 Mtetra
.44979 .33734 .45667 .345 .46867 .34086 .46183 .33317 Mtetra
.46183 .33317 .46867 .34086 .48073 .3367 .47392 .32898 Mtetra
.47392 .32898 .48073 .3367 .49284 .33253 .48607 .32477 Mtetra
.48607 .32477 .49284 .33253 .505 .32833 .49827 .32054 Mtetra
.49827 .32054 .505 .32833 .51722 .32412 .51052 .31629 Mtetra
.51052 .31629 .51722 .32412 .5295 .31989 .52283 .31203 Mtetra
.52283 .31203 .5295 .31989 .54182 .31564 .53519 .30774 Mtetra
.53519 .30774 .54182 .31564 .55421 .31137 .54761 .30344 Mtetra
.54761 .30344 .55421 .31137 .56665 .30708 .56009 .29911 Mtetra
.56009 .29911 .56665 .30708 .57914 .30277 .57262 .29477 Mtetra
.57262 .29477 .57914 .30277 .59169 .29844 .58521 .2904 Mtetra
.58521 .2904 .59169 .29844 .6043 .2941 .59786 .28602 Mtetra
.59786 .28602 .6043 .2941 .61697 .28973 .61056 .28162 Mtetra
.61056 .28162 .61697 .28973 .62969 .28534 .62333 .27719 Mtetra
.62333 .27719 .62969 .28534 .64247 .28094 .63615 .27275 Mtetra
.63615 .27275 .64247 .28094 .65531 .27651 .64903 .26828 Mtetra
0 .095 .628 r
.64903 .26828 .65531 .27651 .66903 .28977 .66275 .28153 Mtetra
.662 .743 .91 r
.66275 .28153 .66903 .28977 .68207 .28532 .67583 .27704 Mtetra
.67583 .27704 .68207 .28532 .69516 .28084 .68897 .27253 Mtetra
.68897 .27253 .69516 .28084 .70832 .27635 .70216 .268 Mtetra
.70216 .268 .70832 .27635 .72153 .27184 .71542 .26345 Mtetra
.71542 .26345 .72153 .27184 .73481 .2673 .72874 .25887 Mtetra
.72874 .25887 .73481 .2673 .74815 .26274 .74213 .25427 Mtetra
.74213 .25427 .74815 .26274 .76155 .25816 .75557 .24966 Mtetra
.75557 .24966 .76155 .25816 .77502 .25356 .76908 .24502 Mtetra
.76908 .24502 .77502 .25356 .78855 .24894 .78266 .24035 Mtetra
.78266 .24035 .78855 .24894 .80214 .2443 .7963 .23567 Mtetra
.7963 .23567 .80214 .2443 .8158 .23963 .81 .23096 Mtetra
.81 .23096 .8158 .23963 .82952 .23495 .82377 .22624 Mtetra
.664 .741 .908 r
.2012 .41384 .20877 .42089 .21976 .41708 .21222 .41 Mtetra
.21222 .41 .21976 .41708 .2308 .41325 .22329 .40615 Mtetra
.22329 .40615 .2308 .41325 .24188 .40941 .2344 .40227 Mtetra
.2344 .40227 .24188 .40941 .25302 .40555 .24556 .39839 Mtetra
.24556 .39839 .25302 .40555 .26419 .40168 .25677 .39448 Mtetra
.25677 .39448 .26419 .40168 .27542 .39779 .26802 .39056 Mtetra
.26802 .39056 .27542 .39779 .2867 .39388 .27933 .38662 Mtetra
.27933 .38662 .2867 .39388 .29802 .38995 .29068 .38266 Mtetra
.29068 .38266 .29802 .38995 .30939 .38601 .30208 .37869 Mtetra
.30208 .37869 .30939 .38601 .32082 .38205 .31353 .3747 Mtetra
.31353 .3747 .32082 .38205 .33229 .37807 .32503 .37069 Mtetra
.32503 .37069 .33229 .37807 .34381 .37408 .33659 .36666 Mtetra
.33659 .36666 .34381 .37408 .35538 .37007 .34819 .36262 Mtetra
.34819 .36262 .35538 .37007 .367 .36604 .35984 .35856 Mtetra
.35984 .35856 .367 .36604 .37867 .362 .37155 .35448 Mtetra
.37155 .35448 .37867 .362 .3904 .35793 .3833 .35038 Mtetra
.3833 .35038 .3904 .35793 .40217 .35385 .39511 .34627 Mtetra
.39511 .34627 .40217 .35385 .414 .34975 .40697 .34213 Mtetra
.40697 .34213 .414 .34975 .42588 .34563 .41888 .33798 Mtetra
.41888 .33798 .42588 .34563 .43781 .3415 .43084 .33381 Mtetra
.43084 .33381 .43781 .3415 .44979 .33734 .44286 .32963 Mtetra
.44286 .32963 .44979 .33734 .46183 .33317 .45493 .32542 Mtetra
.45493 .32542 .46183 .33317 .47392 .32898 .46706 .32119 Mtetra
.46706 .32119 .47392 .32898 .48607 .32477 .47924 .31695 Mtetra
.47924 .31695 .48607 .32477 .49827 .32054 .49147 .31268 Mtetra
.49147 .31268 .49827 .32054 .51052 .31629 .50376 .3084 Mtetra
.50376 .3084 .51052 .31629 .52283 .31203 .51611 .3041 Mtetra
.51611 .3041 .52283 .31203 .53519 .30774 .52851 .29978 Mtetra
.52851 .29978 .53519 .30774 .54761 .30344 .54097 .29544 Mtetra
.54097 .29544 .54761 .30344 .56009 .29911 .55348 .29108 Mtetra
.55348 .29108 .56009 .29911 .57262 .29477 .56605 .28669 Mtetra
.56605 .28669 .57262 .29477 .58521 .2904 .57868 .28229 Mtetra
.57868 .28229 .58521 .2904 .59786 .28602 .59136 .27787 Mtetra
.59136 .27787 .59786 .28602 .61056 .28162 .60411 .27343 Mtetra
.60411 .27343 .61056 .28162 .62333 .27719 .61691 .26897 Mtetra
.61691 .26897 .62333 .27719 .63615 .27275 .62977 .26449 Mtetra
.62977 .26449 .63615 .27275 .64903 .26828 .64269 .25999 Mtetra
0 .095 .628 r
.64269 .25999 .64903 .26828 .66275 .28153 .65642 .27323 Mtetra
.662 .743 .91 r
.65642 .27323 .66275 .28153 .67583 .27704 .66954 .2687 Mtetra
.66954 .2687 .67583 .27704 .68897 .27253 .68272 .26415 Mtetra
.68272 .26415 .68897 .27253 .70216 .268 .69596 .25958 Mtetra
.69596 .25958 .70216 .268 .71542 .26345 .70926 .25498 Mtetra
.70926 .25498 .71542 .26345 .72874 .25887 .72262 .25037 Mtetra
.72262 .25037 .72874 .25887 .74213 .25427 .73605 .24573 Mtetra
.73605 .24573 .74213 .25427 .75557 .24966 .74954 .24107 Mtetra
.74954 .24107 .75557 .24966 .76908 .24502 .7631 .23639 Mtetra
.7631 .23639 .76908 .24502 .78266 .24035 .77672 .23169 Mtetra
.77672 .23169 .78266 .24035 .7963 .23567 .7904 .22696 Mtetra
.7904 .22696 .7963 .23567 .81 .23096 .80415 .22222 Mtetra
.80415 .22222 .81 .23096 .82377 .22624 .81796 .21745 Mtetra
.664 .741 .908 r
.19358 .40674 .2012 .41384 .21222 .41 .20462 .40287 Mtetra
.20462 .40287 .21222 .41 .22329 .40615 .21571 .39899 Mtetra
.21571 .39899 .22329 .40615 .2344 .40227 .22685 .39508 Mtetra
.22685 .39508 .2344 .40227 .24556 .39839 .23804 .39116 Mtetra
.23804 .39116 .24556 .39839 .25677 .39448 .24928 .38723 Mtetra
.24928 .38723 .25677 .39448 .26802 .39056 .26056 .38327 Mtetra
.26056 .38327 .26802 .39056 .27933 .38662 .2719 .3793 Mtetra
.2719 .3793 .27933 .38662 .29068 .38266 .28328 .37531 Mtetra
.28328 .37531 .29068 .38266 .30208 .37869 .29471 .37131 Mtetra
.29471 .37131 .30208 .37869 .31353 .3747 .30619 .36728 Mtetra
.30619 .36728 .31353 .3747 .32503 .37069 .31772 .36324 Mtetra
.31772 .36324 .32503 .37069 .33659 .36666 .32931 .35918 Mtetra
.32931 .35918 .33659 .36666 .34819 .36262 .34094 .35511 Mtetra
.34094 .35511 .34819 .36262 .35984 .35856 .35262 .35101 Mtetra
.35262 .35101 .35984 .35856 .37155 .35448 .36436 .3469 Mtetra
.36436 .3469 .37155 .35448 .3833 .35038 .37615 .34277 Mtetra
.37615 .34277 .3833 .35038 .39511 .34627 .38799 .33862 Mtetra
.38799 .33862 .39511 .34627 .40697 .34213 .39988 .33446 Mtetra
.39988 .33446 .40697 .34213 .41888 .33798 .41182 .33027 Mtetra
.41182 .33027 .41888 .33798 .43084 .33381 .42382 .32607 Mtetra
.42382 .32607 .43084 .33381 .44286 .32963 .43587 .32184 Mtetra
.43587 .32184 .44286 .32963 .45493 .32542 .44798 .3176 Mtetra
.44798 .3176 .45493 .32542 .46706 .32119 .46014 .31334 Mtetra
.46014 .31334 .46706 .32119 .47924 .31695 .47236 .30906 Mtetra
.47236 .30906 .47924 .31695 .49147 .31268 .48463 .30476 Mtetra
.48463 .30476 .49147 .31268 .50376 .3084 .49695 .30044 Mtetra
.49695 .30044 .50376 .3084 .51611 .3041 .50933 .29611 Mtetra
.50933 .29611 .51611 .3041 .52851 .29978 .52177 .29175 Mtetra
.52177 .29175 .52851 .29978 .54097 .29544 .53426 .28737 Mtetra
.53426 .28737 .54097 .29544 .55348 .29108 .54681 .28297 Mtetra
.54681 .28297 .55348 .29108 .56605 .28669 .55942 .27855 Mtetra
.55942 .27855 .56605 .28669 .57868 .28229 .57209 .27412 Mtetra
.57209 .27412 .57868 .28229 .59136 .27787 .58481 .26966 Mtetra
.58481 .26966 .59136 .27787 .60411 .27343 .59759 .26518 Mtetra
.59759 .26518 .60411 .27343 .61691 .26897 .61043 .26068 Mtetra
.61043 .26068 .61691 .26897 .62977 .26449 .62333 .25616 Mtetra
.62333 .25616 .62977 .26449 .64269 .25999 .63629 .25162 Mtetra
0 .095 .628 r
.63629 .25162 .64269 .25999 .65642 .27323 .65004 .26485 Mtetra
.662 .743 .91 r
.65004 .26485 .65642 .27323 .66954 .2687 .66319 .26028 Mtetra
.66319 .26028 .66954 .2687 .68272 .26415 .67642 .25569 Mtetra
.67642 .25569 .68272 .26415 .69596 .25958 .6897 .25108 Mtetra
.6897 .25108 .69596 .25958 .70926 .25498 .70304 .24645 Mtetra
.70304 .24645 .70926 .25498 .72262 .25037 .71645 .24179 Mtetra
.71645 .24179 .72262 .25037 .73605 .24573 .72992 .23711 Mtetra
.72992 .23711 .73605 .24573 .74954 .24107 .74346 .23241 Mtetra
.74346 .23241 .74954 .24107 .7631 .23639 .75706 .22769 Mtetra
.75706 .22769 .7631 .23639 .77672 .23169 .77072 .22295 Mtetra
.77072 .22295 .77672 .23169 .7904 .22696 .78445 .21818 Mtetra
.78445 .21818 .7904 .22696 .80415 .22222 .79825 .21339 Mtetra
.79825 .21339 .80415 .22222 .81796 .21745 .81211 .20858 Mtetra
.664 .741 .908 r
.18589 .39958 .19358 .40674 .20462 .40287 .19696 .39568 Mtetra
.19696 .39568 .20462 .40287 .21571 .39899 .20808 .39177 Mtetra
.20808 .39177 .21571 .39899 .22685 .39508 .21925 .38783 Mtetra
.21925 .38783 .22685 .39508 .23804 .39116 .23047 .38388 Mtetra
.23047 .38388 .23804 .39116 .24928 .38723 .24173 .37991 Mtetra
.24173 .37991 .24928 .38723 .26056 .38327 .25304 .37593 Mtetra
.25304 .37593 .26056 .38327 .2719 .3793 .26441 .37192 Mtetra
.26441 .37192 .2719 .3793 .28328 .37531 .27582 .3679 Mtetra
.27582 .3679 .28328 .37531 .29471 .37131 .28728 .36387 Mtetra
.28728 .36387 .29471 .37131 .30619 .36728 .29879 .35981 Mtetra
.29879 .35981 .30619 .36728 .31772 .36324 .31035 .35574 Mtetra
.31035 .35574 .31772 .36324 .32931 .35918 .32197 .35165 Mtetra
.32197 .35165 .32931 .35918 .34094 .35511 .33363 .34754 Mtetra
.33363 .34754 .34094 .35511 .35262 .35101 .34535 .34341 Mtetra
.34535 .34341 .35262 .35101 .36436 .3469 .35711 .33926 Mtetra
.35711 .33926 .36436 .3469 .37615 .34277 .36893 .3351 Mtetra
.36893 .3351 .37615 .34277 .38799 .33862 .38081 .33092 Mtetra
.38081 .33092 .38799 .33862 .39988 .33446 .39273 .32671 Mtetra
.39273 .32671 .39988 .33446 .41182 .33027 .40471 .32249 Mtetra
.40471 .32249 .41182 .33027 .42382 .32607 .41674 .31826 Mtetra
.41674 .31826 .42382 .32607 .43587 .32184 .42883 .314 Mtetra
.42883 .314 .43587 .32184 .44798 .3176 .44097 .30972 Mtetra
.44097 .30972 .44798 .3176 .46014 .31334 .45316 .30543 Mtetra
.45316 .30543 .46014 .31334 .47236 .30906 .46541 .30111 Mtetra
.46541 .30111 .47236 .30906 .48463 .30476 .47772 .29677 Mtetra
.47772 .29677 .48463 .30476 .49695 .30044 .49008 .29242 Mtetra
.49008 .29242 .49695 .30044 .50933 .29611 .5025 .28804 Mtetra
.5025 .28804 .50933 .29611 .52177 .29175 .51497 .28365 Mtetra
.51497 .28365 .52177 .29175 .53426 .28737 .5275 .27924 Mtetra
.5275 .27924 .53426 .28737 .54681 .28297 .54009 .2748 Mtetra
.54009 .2748 .54681 .28297 .55942 .27855 .55274 .27035 Mtetra
.55274 .27035 .55942 .27855 .57209 .27412 .56544 .26587 Mtetra
.56544 .26587 .57209 .27412 .58481 .26966 .5782 .26137 Mtetra
.5782 .26137 .58481 .26966 .59759 .26518 .59102 .25686 Mtetra
.59102 .25686 .59759 .26518 .61043 .26068 .60391 .25232 Mtetra
.60391 .25232 .61043 .26068 .62333 .25616 .61685 .24776 Mtetra
.61685 .24776 .62333 .25616 .63629 .25162 .62985 .24318 Mtetra
0 .095 .628 r
.62985 .24318 .63629 .25162 .65004 .26485 .6436 .2564 Mtetra
.662 .743 .91 r
.6436 .2564 .65004 .26485 .66319 .26028 .6568 .25179 Mtetra
.6568 .25179 .66319 .26028 .67642 .25569 .67006 .24716 Mtetra
.67006 .24716 .67642 .25569 .6897 .25108 .68338 .24251 Mtetra
.68338 .24251 .6897 .25108 .70304 .24645 .69677 .23783 Mtetra
.69677 .23783 .70304 .24645 .71645 .24179 .71022 .23314 Mtetra
.71022 .23314 .71645 .24179 .72992 .23711 .72374 .22842 Mtetra
.72374 .22842 .72992 .23711 .74346 .23241 .73732 .22368 Mtetra
.73732 .22368 .74346 .23241 .75706 .22769 .75097 .21892 Mtetra
.75097 .21892 .75706 .22769 .77072 .22295 .76468 .21413 Mtetra
.76468 .21413 .77072 .22295 .78445 .21818 .77845 .20932 Mtetra
.77845 .20932 .78445 .21818 .79825 .21339 .7923 .20449 Mtetra
.7923 .20449 .79825 .21339 .81211 .20858 .8062 .19963 Mtetra
.664 .741 .908 r
.17814 .39237 .18589 .39958 .19696 .39568 .18924 .38844 Mtetra
.18924 .38844 .19696 .39568 .20808 .39177 .20039 .38449 Mtetra
.20039 .38449 .20808 .39177 .21925 .38783 .21158 .38052 Mtetra
.21158 .38052 .21925 .38783 .23047 .38388 .22283 .37654 Mtetra
.22283 .37654 .23047 .38388 .24173 .37991 .23412 .37254 Mtetra
.23412 .37254 .24173 .37991 .25304 .37593 .24546 .36852 Mtetra
.24546 .36852 .25304 .37593 .26441 .37192 .25686 .36449 Mtetra
.25686 .36449 .26441 .37192 .27582 .3679 .2683 .36043 Mtetra
.2683 .36043 .27582 .3679 .28728 .36387 .27979 .35636 Mtetra
.27979 .35636 .28728 .36387 .29879 .35981 .29133 .35228 Mtetra
.29133 .35228 .29879 .35981 .31035 .35574 .30292 .34817 Mtetra
.30292 .34817 .31035 .35574 .32197 .35165 .31457 .34404 Mtetra
.31457 .34404 .32197 .35165 .33363 .34754 .32626 .3399 Mtetra
.32626 .3399 .33363 .34754 .34535 .34341 .33801 .33574 Mtetra
.33801 .33574 .34535 .34341 .35711 .33926 .34981 .33156 Mtetra
.34981 .33156 .35711 .33926 .36893 .3351 .36166 .32736 Mtetra
.36166 .32736 .36893 .3351 .38081 .33092 .37357 .32315 Mtetra
.37357 .32315 .38081 .33092 .39273 .32671 .38553 .31891 Mtetra
.38553 .31891 .39273 .32671 .40471 .32249 .39754 .31465 Mtetra
.39754 .31465 .40471 .32249 .41674 .31826 .4096 .31038 Mtetra
.4096 .31038 .41674 .31826 .42883 .314 .42172 .30609 Mtetra
.42172 .30609 .42883 .314 .44097 .30972 .4339 .30177 Mtetra
.4339 .30177 .44097 .30972 .45316 .30543 .44613 .29744 Mtetra
.44613 .29744 .45316 .30543 .46541 .30111 .45841 .29309 Mtetra
.45841 .29309 .46541 .30111 .47772 .29677 .47075 .28872 Mtetra
.47075 .28872 .47772 .29677 .49008 .29242 .48315 .28433 Mtetra
.48315 .28433 .49008 .29242 .5025 .28804 .49561 .27992 Mtetra
.49561 .27992 .5025 .28804 .51497 .28365 .50812 .27548 Mtetra
.50812 .27548 .51497 .28365 .5275 .27924 .52068 .27103 Mtetra
.52068 .27103 .5275 .27924 .54009 .2748 .53331 .26656 Mtetra
.53331 .26656 .54009 .2748 .55274 .27035 .54599 .26207 Mtetra
.54599 .26207 .55274 .27035 .56544 .26587 .55874 .25755 Mtetra
.55874 .25755 .56544 .26587 .5782 .26137 .57154 .25302 Mtetra
.57154 .25302 .5782 .26137 .59102 .25686 .5844 .24846 Mtetra
.5844 .24846 .59102 .25686 .60391 .25232 .59732 .24389 Mtetra
.59732 .24389 .60391 .25232 .61685 .24776 .6103 .23929 Mtetra
.6103 .23929 .61685 .24776 .62985 .24318 .62334 .23467 Mtetra
0 .095 .628 r
.62334 .23467 .62985 .24318 .6436 .2564 .6371 .24787 Mtetra
.662 .743 .91 r
.6371 .24787 .6436 .2564 .6568 .25179 .65034 .24323 Mtetra
.65034 .24323 .6568 .25179 .67006 .24716 .66365 .23856 Mtetra
.66365 .23856 .67006 .24716 .68338 .24251 .67701 .23386 Mtetra
.67701 .23386 .68338 .24251 .69677 .23783 .69045 .22915 Mtetra
.69045 .22915 .69677 .23783 .71022 .23314 .70394 .22441 Mtetra
.70394 .22441 .71022 .23314 .72374 .22842 .7175 .21965 Mtetra
.7175 .21965 .72374 .22842 .73732 .22368 .73113 .21487 Mtetra
.73113 .21487 .73732 .22368 .75097 .21892 .74482 .21006 Mtetra
.74482 .21006 .75097 .21892 .76468 .21413 .75858 .20523 Mtetra
.75858 .20523 .76468 .21413 .77845 .20932 .7724 .20038 Mtetra
.7724 .20038 .77845 .20932 .7923 .20449 .78629 .19551 Mtetra
.78629 .19551 .7923 .20449 .8062 .19963 .80025 .19061 Mtetra
.664 .741 .908 r
.17033 .3851 .17814 .39237 .18924 .38844 .18146 .38114 Mtetra
.18146 .38114 .18924 .38844 .20039 .38449 .19263 .37715 Mtetra
.19263 .37715 .20039 .38449 .21158 .38052 .20386 .37316 Mtetra
.20386 .37316 .21158 .38052 .22283 .37654 .21513 .36914 Mtetra
.21513 .36914 .22283 .37654 .23412 .37254 .22645 .36511 Mtetra
.22645 .36511 .23412 .37254 .24546 .36852 .23782 .36106 Mtetra
.23782 .36106 .24546 .36852 .25686 .36449 .24924 .35699 Mtetra
.24924 .35699 .25686 .36449 .2683 .36043 .26072 .35291 Mtetra
.26072 .35291 .2683 .36043 .27979 .35636 .27224 .3488 Mtetra
.27224 .3488 .27979 .35636 .29133 .35228 .28381 .34468 Mtetra
.28381 .34468 .29133 .35228 .30292 .34817 .29543 .34054 Mtetra
.29543 .34054 .30292 .34817 .31457 .34404 .30711 .33638 Mtetra
.30711 .33638 .31457 .34404 .32626 .3399 .31884 .3322 Mtetra
.31884 .3322 .32626 .3399 .33801 .33574 .33061 .32801 Mtetra
.33061 .32801 .33801 .33574 .34981 .33156 .34245 .3238 Mtetra
.34245 .3238 .34981 .33156 .36166 .32736 .35433 .31956 Mtetra
.35433 .31956 .36166 .32736 .37357 .32315 .36627 .31531 Mtetra
.36627 .31531 .37357 .32315 .38553 .31891 .37826 .31104 Mtetra
.37826 .31104 .38553 .31891 .39754 .31465 .39031 .30675 Mtetra
.39031 .30675 .39754 .31465 .4096 .31038 .40241 .30244 Mtetra
.40241 .30244 .4096 .31038 .42172 .30609 .41456 .29811 Mtetra
.41456 .29811 .42172 .30609 .4339 .30177 .42677 .29376 Mtetra
.42677 .29376 .4339 .30177 .44613 .29744 .43903 .28939 Mtetra
.43903 .28939 .44613 .29744 .45841 .29309 .45135 .285 Mtetra
.45135 .285 .45841 .29309 .47075 .28872 .46373 .2806 Mtetra
.46373 .2806 .47075 .28872 .48315 .28433 .47617 .27617 Mtetra
.47617 .27617 .48315 .28433 .49561 .27992 .48866 .27172 Mtetra
.48866 .27172 .49561 .27992 .50812 .27548 .5012 .26725 Mtetra
.5012 .26725 .50812 .27548 .52068 .27103 .51381 .26276 Mtetra
.51381 .26276 .52068 .27103 .53331 .26656 .52647 .25825 Mtetra
.52647 .25825 .53331 .26656 .54599 .26207 .5392 .25372 Mtetra
.5392 .25372 .54599 .26207 .55874 .25755 .55198 .24917 Mtetra
.55198 .24917 .55874 .25755 .57154 .25302 .56482 .24459 Mtetra
.56482 .24459 .57154 .25302 .5844 .24846 .57772 .24 Mtetra
.57772 .24 .5844 .24846 .59732 .24389 .59068 .23538 Mtetra
.59068 .23538 .59732 .24389 .6103 .23929 .6037 .23074 Mtetra
.6037 .23074 .6103 .23929 .62334 .23467 .61678 .22608 Mtetra
0 .095 .628 r
.61678 .22608 .62334 .23467 .6371 .24787 .63054 .23927 Mtetra
.662 .743 .91 r
.63054 .23927 .6371 .24787 .65034 .24323 .64383 .23459 Mtetra
.64383 .23459 .65034 .24323 .66365 .23856 .65718 .22987 Mtetra
.65718 .22987 .66365 .23856 .67701 .23386 .67059 .22514 Mtetra
.67059 .22514 .67701 .23386 .69045 .22915 .68406 .22038 Mtetra
.68406 .22038 .69045 .22915 .70394 .22441 .69761 .21561 Mtetra
.69761 .21561 .70394 .22441 .7175 .21965 .71121 .2108 Mtetra
.71121 .2108 .7175 .21965 .73113 .21487 .72488 .20598 Mtetra
.72488 .20598 .73113 .21487 .74482 .21006 .73862 .20113 Mtetra
.73862 .20113 .74482 .21006 .75858 .20523 .75242 .19626 Mtetra
.75242 .19626 .75858 .20523 .7724 .20038 .76629 .19136 Mtetra
.76629 .19136 .7724 .20038 .78629 .19551 .78023 .18644 Mtetra
.78023 .18644 .78629 .19551 .80025 .19061 .79423 .1815 Mtetra
.664 .741 .908 r
.16246 .37777 .17033 .3851 .18146 .38114 .17361 .37377 Mtetra
.17361 .37377 .18146 .38114 .19263 .37715 .18482 .36976 Mtetra
.18482 .36976 .19263 .37715 .20386 .37316 .19607 .36573 Mtetra
.19607 .36573 .20386 .37316 .21513 .36914 .20737 .36168 Mtetra
.20737 .36168 .21513 .36914 .22645 .36511 .21872 .35762 Mtetra
.21872 .35762 .22645 .36511 .23782 .36106 .23012 .35354 Mtetra
.23012 .35354 .23782 .36106 .24924 .35699 .24157 .34943 Mtetra
.24157 .34943 .24924 .35699 .26072 .35291 .25307 .34532 Mtetra
.25307 .34532 .26072 .35291 .27224 .3488 .26462 .34118 Mtetra
.26462 .34118 .27224 .3488 .28381 .34468 .27623 .33702 Mtetra
.27623 .33702 .28381 .34468 .29543 .34054 .28788 .33285 Mtetra
.28788 .33285 .29543 .34054 .30711 .33638 .29959 .32866 Mtetra
.29959 .32866 .30711 .33638 .31884 .3322 .31135 .32444 Mtetra
.31135 .32444 .31884 .3322 .33061 .32801 .32316 .32021 Mtetra
.32316 .32021 .33061 .32801 .34245 .3238 .33502 .31597 Mtetra
.33502 .31597 .34245 .3238 .35433 .31956 .34694 .3117 Mtetra
.34694 .3117 .35433 .31956 .36627 .31531 .35891 .30741 Mtetra
.35891 .30741 .36627 .31531 .37826 .31104 .37093 .3031 Mtetra
.37093 .3031 .37826 .31104 .39031 .30675 .38301 .29878 Mtetra
.38301 .29878 .39031 .30675 .40241 .30244 .39515 .29443 Mtetra
.39515 .29443 .40241 .30244 .41456 .29811 .40734 .29007 Mtetra
.40734 .29007 .41456 .29811 .42677 .29376 .41958 .28568 Mtetra
.41958 .28568 .42677 .29376 .43903 .28939 .43188 .28128 Mtetra
.43188 .28128 .43903 .28939 .45135 .285 .44424 .27685 Mtetra
.44424 .27685 .45135 .285 .46373 .2806 .45665 .2724 Mtetra
.45665 .2724 .46373 .2806 .47617 .27617 .46912 .26794 Mtetra
.46912 .26794 .47617 .27617 .48866 .27172 .48165 .26345 Mtetra
.48165 .26345 .48866 .27172 .5012 .26725 .49423 .25894 Mtetra
.49423 .25894 .5012 .26725 .51381 .26276 .50688 .25442 Mtetra
.50688 .25442 .51381 .26276 .52647 .25825 .51958 .24987 Mtetra
.51958 .24987 .52647 .25825 .5392 .25372 .53234 .2453 Mtetra
.53234 .2453 .5392 .25372 .55198 .24917 .54516 .24071 Mtetra
.54516 .24071 .55198 .24917 .56482 .24459 .55804 .23609 Mtetra
.55804 .23609 .56482 .24459 .57772 .24 .57098 .23146 Mtetra
.57098 .23146 .57772 .24 .59068 .23538 .58398 .2268 Mtetra
.58398 .2268 .59068 .23538 .6037 .23074 .59704 .22212 Mtetra
.59704 .22212 .6037 .23074 .61678 .22608 .61017 .21742 Mtetra
0 .095 .628 r
.61017 .21742 .61678 .22608 .63054 .23927 .62393 .2306 Mtetra
.662 .743 .91 r
.62393 .2306 .63054 .23927 .64383 .23459 .63726 .22587 Mtetra
.63726 .22587 .64383 .23459 .65718 .22987 .65065 .22112 Mtetra
.65065 .22112 .65718 .22987 .67059 .22514 .66411 .21634 Mtetra
.66411 .21634 .67059 .22514 .68406 .22038 .67763 .21154 Mtetra
.67763 .21154 .68406 .22038 .69761 .21561 .69121 .20672 Mtetra
.69121 .20672 .69761 .21561 .71121 .2108 .70486 .20188 Mtetra
.70486 .20188 .71121 .2108 .72488 .20598 .71858 .19701 Mtetra
.71858 .19701 .72488 .20598 .73862 .20113 .73236 .19212 Mtetra
.73236 .19212 .73862 .20113 .75242 .19626 .74621 .1872 Mtetra
.74621 .1872 .75242 .19626 .76629 .19136 .76013 .18226 Mtetra
.76013 .18226 .76629 .19136 .78023 .18644 .77411 .1773 Mtetra
.77411 .1773 .78023 .18644 .79423 .1815 .78817 .17231 Mtetra
.664 .741 .908 r
.15452 .37038 .16246 .37777 .17361 .37377 .16571 .36635 Mtetra
.16571 .36635 .17361 .37377 .18482 .36976 .17694 .36231 Mtetra
.17694 .36231 .18482 .36976 .19607 .36573 .18822 .35825 Mtetra
.18822 .35825 .19607 .36573 .20737 .36168 .19955 .35416 Mtetra
.19955 .35416 .20737 .36168 .21872 .35762 .21093 .35007 Mtetra
.21093 .35007 .21872 .35762 .23012 .35354 .22236 .34595 Mtetra
.22236 .34595 .23012 .35354 .24157 .34943 .23384 .34182 Mtetra
.23384 .34182 .24157 .34943 .25307 .34532 .24537 .33766 Mtetra
.24537 .33766 .25307 .34532 .26462 .34118 .25695 .33349 Mtetra
.25695 .33349 .26462 .34118 .27623 .33702 .26858 .3293 Mtetra
.26858 .3293 .27623 .33702 .28788 .33285 .28027 .32509 Mtetra
.28027 .32509 .28788 .33285 .29959 .32866 .292 .32087 Mtetra
.292 .32087 .29959 .32866 .31135 .32444 .30379 .31662 Mtetra
.30379 .31662 .31135 .32444 .32316 .32021 .31564 .31236 Mtetra
.31564 .31236 .32316 .32021 .33502 .31597 .32753 .30807 Mtetra
.32753 .30807 .33502 .31597 .34694 .3117 .33948 .30377 Mtetra
.33948 .30377 .34694 .3117 .35891 .30741 .35149 .29944 Mtetra
.35149 .29944 .35891 .30741 .37093 .3031 .36355 .2951 Mtetra
.36355 .2951 .37093 .3031 .38301 .29878 .37566 .29074 Mtetra
.37566 .29074 .38301 .29878 .39515 .29443 .38783 .28636 Mtetra
.38783 .28636 .39515 .29443 .40734 .29007 .40005 .28195 Mtetra
.40005 .28195 .40734 .29007 .41958 .28568 .41233 .27753 Mtetra
.41233 .27753 .41958 .28568 .43188 .28128 .42467 .27309 Mtetra
.42467 .27309 .43188 .28128 .44424 .27685 .43706 .26863 Mtetra
.43706 .26863 .44424 .27685 .45665 .2724 .44951 .26414 Mtetra
.44951 .26414 .45665 .2724 .46912 .26794 .46201 .25964 Mtetra
.46201 .25964 .46912 .26794 .48165 .26345 .47458 .25511 Mtetra
.47458 .25511 .48165 .26345 .49423 .25894 .4872 .25057 Mtetra
.4872 .25057 .49423 .25894 .50688 .25442 .49988 .246 Mtetra
.49988 .246 .50688 .25442 .51958 .24987 .51262 .24141 Mtetra
.51262 .24141 .51958 .24987 .53234 .2453 .52542 .2368 Mtetra
.52542 .2368 .53234 .2453 .54516 .24071 .53828 .23217 Mtetra
.53828 .23217 .54516 .24071 .55804 .23609 .5512 .22752 Mtetra
.5512 .22752 .55804 .23609 .57098 .23146 .56418 .22284 Mtetra
.56418 .22284 .57098 .23146 .58398 .2268 .57722 .21815 Mtetra
.57722 .21815 .58398 .2268 .59704 .22212 .59033 .21343 Mtetra
.59033 .21343 .59704 .22212 .61017 .21742 .60349 .20869 Mtetra
0 .095 .628 r
.60349 .20869 .61017 .21742 .62393 .2306 .61726 .22185 Mtetra
.662 .743 .91 r
.61726 .22185 .62393 .2306 .63726 .22587 .63063 .21708 Mtetra
.63063 .21708 .63726 .22587 .65065 .22112 .64407 .21228 Mtetra
.64407 .21228 .65065 .22112 .66411 .21634 .65757 .20747 Mtetra
.65757 .20747 .66411 .21634 .67763 .21154 .67113 .20262 Mtetra
.67113 .20262 .67763 .21154 .69121 .20672 .68476 .19776 Mtetra
.68476 .19776 .69121 .20672 .70486 .20188 .69846 .19287 Mtetra
.69846 .19287 .70486 .20188 .71858 .19701 .71222 .18796 Mtetra
.71222 .18796 .71858 .19701 .73236 .19212 .72605 .18302 Mtetra
.72605 .18302 .73236 .19212 .74621 .1872 .73995 .17806 Mtetra
.73995 .17806 .74621 .1872 .76013 .18226 .75391 .17308 Mtetra
.75391 .17308 .76013 .18226 .77411 .1773 .76794 .16807 Mtetra
.76794 .16807 .77411 .1773 .78817 .17231 .78204 .16304 Mtetra
.664 .741 .908 r
.14652 .36293 .15452 .37038 .16571 .36635 .15773 .35887 Mtetra
.15773 .35887 .16571 .36635 .17694 .36231 .16899 .35479 Mtetra
.16899 .35479 .17694 .36231 .18822 .35825 .1803 .3507 Mtetra
.1803 .3507 .18822 .35825 .19955 .35416 .19166 .34658 Mtetra
.19166 .34658 .19955 .35416 .21093 .35007 .20307 .34245 Mtetra
.20307 .34245 .21093 .35007 .22236 .34595 .21453 .3383 Mtetra
.21453 .3383 .22236 .34595 .23384 .34182 .22604 .33414 Mtetra
.22604 .33414 .23384 .34182 .24537 .33766 .2376 .32995 Mtetra
.2376 .32995 .24537 .33766 .25695 .33349 .24921 .32574 Mtetra
.24921 .32574 .25695 .33349 .26858 .3293 .26087 .32152 Mtetra
.26087 .32152 .26858 .3293 .28027 .32509 .27259 .31728 Mtetra
.27259 .31728 .28027 .32509 .292 .32087 .28436 .31301 Mtetra
.28436 .31301 .292 .32087 .30379 .31662 .29618 .30873 Mtetra
.29618 .30873 .30379 .31662 .31564 .31236 .30806 .30443 Mtetra
.30806 .30443 .31564 .31236 .32753 .30807 .31998 .30011 Mtetra
.31998 .30011 .32753 .30807 .33948 .30377 .33197 .29577 Mtetra
.33197 .29577 .33948 .30377 .35149 .29944 .344 .29141 Mtetra
.344 .29141 .35149 .29944 .36355 .2951 .3561 .28703 Mtetra
.3561 .28703 .36355 .2951 .37566 .29074 .36824 .28263 Mtetra
.36824 .28263 .37566 .29074 .38783 .28636 .38045 .27821 Mtetra
.38045 .27821 .38783 .28636 .40005 .28195 .3927 .27377 Mtetra
.3927 .27377 .40005 .28195 .41233 .27753 .40502 .26932 Mtetra
.40502 .26932 .41233 .27753 .42467 .27309 .41739 .26483 Mtetra
.41739 .26483 .42467 .27309 .43706 .26863 .42982 .26033 Mtetra
.42982 .26033 .43706 .26863 .44951 .26414 .4423 .25581 Mtetra
.4423 .25581 .44951 .26414 .46201 .25964 .45485 .25127 Mtetra
.45485 .25127 .46201 .25964 .47458 .25511 .46745 .24671 Mtetra
.46745 .24671 .47458 .25511 .4872 .25057 .48011 .24212 Mtetra
.48011 .24212 .4872 .25057 .49988 .246 .49283 .23751 Mtetra
.49283 .23751 .49988 .246 .51262 .24141 .50561 .23289 Mtetra
.50561 .23289 .51262 .24141 .52542 .2368 .51844 .22824 Mtetra
.51844 .22824 .52542 .2368 .53828 .23217 .53134 .22356 Mtetra
.53134 .22356 .53828 .23217 .5512 .22752 .5443 .21887 Mtetra
.5443 .21887 .5512 .22752 .56418 .22284 .55732 .21416 Mtetra
.55732 .21416 .56418 .22284 .57722 .21815 .57041 .20942 Mtetra
.57041 .20942 .57722 .21815 .59033 .21343 .58355 .20466 Mtetra
.58355 .20466 .59033 .21343 .60349 .20869 .59676 .19987 Mtetra
0 .095 .628 r
.59676 .19987 .60349 .20869 .61726 .22185 .61053 .21302 Mtetra
.662 .743 .91 r
.61053 .21302 .61726 .22185 .63063 .21708 .62395 .20821 Mtetra
.62395 .20821 .63063 .21708 .64407 .21228 .63743 .20337 Mtetra
.63743 .20337 .64407 .21228 .65757 .20747 .65097 .19851 Mtetra
.65097 .19851 .65757 .20747 .67113 .20262 .66458 .19363 Mtetra
.66458 .19363 .67113 .20262 .68476 .19776 .67825 .18872 Mtetra
.67825 .18872 .68476 .19776 .69846 .19287 .69199 .18379 Mtetra
.69199 .18379 .69846 .19287 .71222 .18796 .7058 .17883 Mtetra
.7058 .17883 .71222 .18796 .72605 .18302 .71968 .17385 Mtetra
.71968 .17385 .72605 .18302 .73995 .17806 .73362 .16884 Mtetra
.73362 .16884 .73995 .17806 .75391 .17308 .74764 .16382 Mtetra
.74764 .16382 .75391 .17308 .76794 .16807 .76172 .15876 Mtetra
.76172 .15876 .76794 .16807 .78204 .16304 .77587 .15368 Mtetra
.664 .741 .908 r
.13846 .35542 .14652 .36293 .15773 .35887 .1497 .35133 Mtetra
.1497 .35133 .15773 .35887 .16899 .35479 .16098 .34722 Mtetra
.16098 .34722 .16899 .35479 .1803 .3507 .17232 .34309 Mtetra
.17232 .34309 .1803 .3507 .19166 .34658 .18371 .33894 Mtetra
.18371 .33894 .19166 .34658 .20307 .34245 .19515 .33478 Mtetra
.19515 .33478 .20307 .34245 .21453 .3383 .20663 .33059 Mtetra
.20663 .33059 .21453 .3383 .22604 .33414 .21817 .32639 Mtetra
.21817 .32639 .22604 .33414 .2376 .32995 .22976 .32217 Mtetra
.22976 .32217 .2376 .32995 .24921 .32574 .24141 .31793 Mtetra
.24141 .31793 .24921 .32574 .26087 .32152 .2531 .31367 Mtetra
.2531 .31367 .26087 .32152 .27259 .31728 .26485 .30939 Mtetra
.26485 .30939 .27259 .31728 .28436 .31301 .27665 .30509 Mtetra
.27665 .30509 .28436 .31301 .29618 .30873 .2885 .30078 Mtetra
.2885 .30078 .29618 .30873 .30806 .30443 .30041 .29644 Mtetra
.30041 .29644 .30806 .30443 .31998 .30011 .31237 .29208 Mtetra
.31237 .29208 .31998 .30011 .33197 .29577 .32439 .28771 Mtetra
.32439 .28771 .33197 .29577 .344 .29141 .33646 .28331 Mtetra
.33646 .28331 .344 .29141 .3561 .28703 .34858 .2789 Mtetra
.34858 .2789 .3561 .28703 .36824 .28263 .36077 .27446 Mtetra
.36077 .27446 .36824 .28263 .38045 .27821 .373 .27 Mtetra
.373 .27 .38045 .27821 .3927 .27377 .3853 .26553 Mtetra
.3853 .26553 .3927 .27377 .40502 .26932 .39764 .26103 Mtetra
.39764 .26103 .40502 .26932 .41739 .26483 .41005 .25651 Mtetra
.41005 .25651 .41739 .26483 .42982 .26033 .42252 .25197 Mtetra
.42252 .25197 .42982 .26033 .4423 .25581 .43504 .24741 Mtetra
.43504 .24741 .4423 .25581 .45485 .25127 .44762 .24283 Mtetra
.44762 .24283 .45485 .25127 .46745 .24671 .46026 .23822 Mtetra
.46026 .23822 .46745 .24671 .48011 .24212 .47296 .2336 Mtetra
.47296 .2336 .48011 .24212 .49283 .23751 .48571 .22895 Mtetra
.48571 .22895 .49283 .23751 .50561 .23289 .49853 .22429 Mtetra
.49853 .22429 .50561 .23289 .51844 .22824 .51141 .2196 Mtetra
.51141 .2196 .51844 .22824 .53134 .22356 .52435 .21488 Mtetra
.52435 .21488 .53134 .22356 .5443 .21887 .53735 .21015 Mtetra
.53735 .21015 .5443 .21887 .55732 .21416 .55041 .20539 Mtetra
.55041 .20539 .55732 .21416 .57041 .20942 .56353 .20061 Mtetra
.56353 .20061 .57041 .20942 .58355 .20466 .57672 .19581 Mtetra
.57672 .19581 .58355 .20466 .59676 .19987 .58996 .19098 Mtetra
.58996 .19098 .59676 .19987 .61053 .21302 .60328 .18614 Mtetra
.605 .491 .697 r
.60328 .18614 .61053 .21302 .62395 .20821 .61665 .18126 Mtetra
.61665 .18126 .62395 .20821 .63743 .20337 .63009 .17637 Mtetra
.63009 .17637 .63743 .20337 .65097 .19851 .6436 .17145 Mtetra
.6436 .17145 .65097 .19851 .66458 .19363 .65717 .16651 Mtetra
.65717 .16651 .66458 .19363 .67825 .18872 .6708 .16154 Mtetra
.6708 .16154 .67825 .18872 .69199 .18379 .68451 .15655 Mtetra
.68451 .15655 .69199 .18379 .7058 .17883 .69828 .15154 Mtetra
.69828 .15154 .7058 .17883 .71968 .17385 .71211 .1465 Mtetra
.71211 .1465 .71968 .17385 .73362 .16884 .72601 .14144 Mtetra
.72601 .14144 .73362 .16884 .74764 .16382 .73999 .13635 Mtetra
.73999 .13635 .74764 .16382 .76172 .15876 .75403 .13123 Mtetra
.75403 .13123 .76172 .15876 .77587 .15368 .76814 .12609 Mtetra
.664 .741 .908 r
.13033 .34785 .13846 .35542 .1497 .35133 .1416 .34373 Mtetra
.1416 .34373 .1497 .35133 .16098 .34722 .15291 .33958 Mtetra
.15291 .33958 .16098 .34722 .17232 .34309 .16428 .33542 Mtetra
.16428 .33542 .17232 .34309 .18371 .33894 .17569 .33124 Mtetra
.17569 .33124 .18371 .33894 .19515 .33478 .18716 .32704 Mtetra
.18716 .32704 .19515 .33478 .20663 .33059 .19868 .32282 Mtetra
.19868 .32282 .20663 .33059 .21817 .32639 .21025 .31858 Mtetra
.21025 .31858 .21817 .32639 .22976 .32217 .22187 .31433 Mtetra
.22187 .31433 .22976 .32217 .24141 .31793 .23354 .31005 Mtetra
.23354 .31005 .24141 .31793 .2531 .31367 .24527 .30576 Mtetra
.24527 .30576 .2531 .31367 .26485 .30939 .25704 .30144 Mtetra
.25704 .30144 .26485 .30939 .27665 .30509 .26888 .29711 Mtetra
.26888 .29711 .27665 .30509 .2885 .30078 .28076 .29276 Mtetra
.28076 .29276 .2885 .30078 .30041 .29644 .2927 .28838 Mtetra
.2927 .28838 .30041 .29644 .31237 .29208 .3047 .28399 Mtetra
.3047 .28399 .31237 .29208 .32439 .28771 .31674 .27958 Mtetra
.31674 .27958 .32439 .28771 .33646 .28331 .32885 .27514 Mtetra
.32885 .27514 .33646 .28331 .34858 .2789 .34101 .27069 Mtetra
.34101 .27069 .34858 .2789 .36077 .27446 .35322 .26622 Mtetra
.35322 .26622 .36077 .27446 .373 .27 .36549 .26172 Mtetra
.36549 .26172 .373 .27 .3853 .26553 .37782 .25721 Mtetra
.37782 .25721 .3853 .26553 .39764 .26103 .39021 .25267 Mtetra
.39021 .25267 .39764 .26103 .41005 .25651 .40265 .24811 Mtetra
.40265 .24811 .41005 .25651 .42252 .25197 .41515 .24353 Mtetra
.41515 .24353 .42252 .25197 .43504 .24741 .42771 .23893 Mtetra
.42771 .23893 .43504 .24741 .44762 .24283 .44033 .23431 Mtetra
.44033 .23431 .44762 .24283 .46026 .23822 .453 .22967 Mtetra
.453 .22967 .46026 .23822 .47296 .2336 .46574 .225 Mtetra
.46574 .225 .47296 .2336 .48571 .22895 .47854 .22032 Mtetra
.47854 .22032 .48571 .22895 .49853 .22429 .49139 .21561 Mtetra
.49139 .21561 .49853 .22429 .51141 .2196 .50431 .21088 Mtetra
.50431 .21088 .51141 .2196 .52435 .21488 .51729 .20612 Mtetra
.51729 .20612 .52435 .21488 .53735 .21015 .53033 .20135 Mtetra
.53033 .20135 .53735 .21015 .55041 .20539 .54343 .19655 Mtetra
.54343 .19655 .55041 .20539 .56353 .20061 .55659 .19173 Mtetra
.55659 .19173 .56353 .20061 .57672 .19581 .56982 .18688 Mtetra
.56982 .18688 .57672 .19581 .58996 .19098 .58311 .18202 Mtetra
.58311 .18202 .58996 .19098 .60328 .18614 .59647 .17712 Mtetra
.59647 .17712 .60328 .18614 .61665 .18126 .60989 .17221 Mtetra
.60989 .17221 .61665 .18126 .63009 .17637 .62337 .16727 Mtetra
.62337 .16727 .63009 .17637 .6436 .17145 .63692 .16231 Mtetra
.63692 .16231 .6436 .17145 .65717 .16651 .65053 .15732 Mtetra
.65053 .15732 .65717 .16651 .6708 .16154 .66421 .15231 Mtetra
.66421 .15231 .6708 .16154 .68451 .15655 .67796 .14728 Mtetra
.67796 .14728 .68451 .15655 .69828 .15154 .69178 .14222 Mtetra
.69178 .14222 .69828 .15154 .71211 .1465 .70566 .13713 Mtetra
.70566 .13713 .71211 .1465 .72601 .14144 .71961 .13202 Mtetra
.71961 .13202 .72601 .14144 .73999 .13635 .73363 .12689 Mtetra
.73363 .12689 .73999 .13635 .75403 .13123 .74772 .12173 Mtetra
.74772 .12173 .75403 .13123 .76814 .12609 .76188 .11654 Mtetra
.12213 .34022 .13033 .34785 .1416 .34373 .13343 .33606 Mtetra
.13343 .33606 .1416 .34373 .15291 .33958 .14477 .33188 Mtetra
.14477 .33188 .15291 .33958 .16428 .33542 .15616 .32769 Mtetra
.15616 .32769 .16428 .33542 .17569 .33124 .16761 .32347 Mtetra
.16761 .32347 .17569 .33124 .18716 .32704 .17911 .31924 Mtetra
.17911 .31924 .18716 .32704 .19868 .32282 .19065 .31498 Mtetra
.19065 .31498 .19868 .32282 .21025 .31858 .20225 .31071 Mtetra
.20225 .31071 .21025 .31858 .22187 .31433 .2139 .30642 Mtetra
.2139 .30642 .22187 .31433 .23354 .31005 .22561 .30211 Mtetra
.22561 .30211 .23354 .31005 .24527 .30576 .23736 .29778 Mtetra
.23736 .29778 .24527 .30576 .25704 .30144 .24917 .29343 Mtetra
.24917 .29343 .25704 .30144 .26888 .29711 .26104 .28906 Mtetra
.26104 .28906 .26888 .29711 .28076 .29276 .27296 .28467 Mtetra
.27296 .28467 .28076 .29276 .2927 .28838 .28493 .28026 Mtetra
.28493 .28026 .2927 .28838 .3047 .28399 .29695 .27583 Mtetra
.29695 .27583 .3047 .28399 .31674 .27958 .30904 .27138 Mtetra
.30904 .27138 .31674 .27958 .32885 .27514 .32117 .26691 Mtetra
.32117 .26691 .32885 .27514 .34101 .27069 .33337 .26241 Mtetra
.33337 .26241 .34101 .27069 .35322 .26622 .34562 .2579 Mtetra
.34562 .2579 .35322 .26622 .36549 .26172 .35792 .25337 Mtetra
.35792 .25337 .36549 .26172 .37782 .25721 .37029 .24881 Mtetra
.37029 .24881 .37782 .25721 .39021 .25267 .38271 .24424 Mtetra
.38271 .24424 .39021 .25267 .40265 .24811 .39519 .23964 Mtetra
.39519 .23964 .40265 .24811 .41515 .24353 .40772 .23502 Mtetra
.40772 .23502 .41515 .24353 .42771 .23893 .42032 .23039 Mtetra
.42032 .23039 .42771 .23893 .44033 .23431 .43297 .22572 Mtetra
.43297 .22572 .44033 .23431 .453 .22967 .44569 .22104 Mtetra
.44569 .22104 .453 .22967 .46574 .225 .45846 .21634 Mtetra
.45846 .21634 .46574 .225 .47854 .22032 .4713 .21161 Mtetra
.4713 .21161 .47854 .22032 .49139 .21561 .48419 .20686 Mtetra
.48419 .20686 .49139 .21561 .50431 .21088 .49715 .20209 Mtetra
.49715 .20209 .50431 .21088 .51729 .20612 .51017 .19729 Mtetra
.51017 .19729 .51729 .20612 .53033 .20135 .52325 .19247 Mtetra
.52325 .19247 .53033 .20135 .54343 .19655 .53639 .18763 Mtetra
.53639 .18763 .54343 .19655 .55659 .19173 .5496 .18277 Mtetra
.5496 .18277 .55659 .19173 .56982 .18688 .56287 .17788 Mtetra
.56287 .17788 .56982 .18688 .58311 .18202 .5762 .17297 Mtetra
.5762 .17297 .58311 .18202 .59647 .17712 .5896 .16803 Mtetra
.5896 .16803 .59647 .17712 .60989 .17221 .60306 .16307 Mtetra
.60306 .16307 .60989 .17221 .62337 .16727 .61659 .15809 Mtetra
.61659 .15809 .62337 .16727 .63692 .16231 .63018 .15308 Mtetra
.63018 .15308 .63692 .16231 .65053 .15732 .64384 .14805 Mtetra
.64384 .14805 .65053 .15732 .66421 .15231 .65757 .143 Mtetra
.65757 .143 .66421 .15231 .67796 .14728 .67136 .13792 Mtetra
.67136 .13792 .67796 .14728 .69178 .14222 .68522 .13281 Mtetra
.68522 .13281 .69178 .14222 .70566 .13713 .69915 .12768 Mtetra
.69915 .12768 .70566 .13713 .71961 .13202 .71315 .12252 Mtetra
.71315 .12252 .71961 .13202 .73363 .12689 .72722 .11734 Mtetra
.72722 .11734 .73363 .12689 .74772 .12173 .74135 .11213 Mtetra
.74135 .11213 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.11387 .33253 .12213 .34022 .13343 .33606 .12519 .32833 Mtetra
.12519 .32833 .13343 .33606 .14477 .33188 .13656 .32412 Mtetra
.13656 .32412 .14477 .33188 .15616 .32769 .14799 .31989 Mtetra
.14799 .31989 .15616 .32769 .16761 .32347 .15946 .31564 Mtetra
.15946 .31564 .16761 .32347 .17911 .31924 .17099 .31137 Mtetra
.17099 .31137 .17911 .31924 .19065 .31498 .18256 .30708 Mtetra
.18256 .30708 .19065 .31498 .20225 .31071 .19419 .30277 Mtetra
.19419 .30277 .20225 .31071 .2139 .30642 .20587 .29844 Mtetra
.20587 .29844 .2139 .30642 .22561 .30211 .21761 .2941 Mtetra
.21761 .2941 .22561 .30211 .23736 .29778 .2294 .28973 Mtetra
.2294 .28973 .23736 .29778 .24917 .29343 .24124 .28534 Mtetra
.24124 .28534 .24917 .29343 .26104 .28906 .25313 .28094 Mtetra
.25313 .28094 .26104 .28906 .27296 .28467 .26508 .27651 Mtetra
.26508 .27651 .27296 .28467 .28493 .28026 .27709 .27206 Mtetra
.27709 .27206 .28493 .28026 .29695 .27583 .28915 .26759 Mtetra
.28915 .26759 .29695 .27583 .30904 .27138 .30126 .26311 Mtetra
.30126 .26311 .30904 .27138 .32117 .26691 .31343 .2586 Mtetra
.31343 .2586 .32117 .26691 .33337 .26241 .32566 .25407 Mtetra
.32566 .25407 .33337 .26241 .34562 .2579 .33795 .24952 Mtetra
.33795 .24952 .34562 .2579 .35792 .25337 .35029 .24494 Mtetra
.35029 .24494 .35792 .25337 .37029 .24881 .36269 .24035 Mtetra
.36269 .24035 .37029 .24881 .38271 .24424 .37514 .23574 Mtetra
.37514 .23574 .38271 .24424 .39519 .23964 .38766 .2311 Mtetra
.38766 .2311 .39519 .23964 .40772 .23502 .40023 .22644 Mtetra
.40023 .22644 .40772 .23502 .42032 .23039 .41286 .22176 Mtetra
.41286 .22176 .42032 .23039 .43297 .22572 .42556 .21706 Mtetra
.42556 .21706 .43297 .22572 .44569 .22104 .43831 .21234 Mtetra
.43831 .21234 .44569 .22104 .45846 .21634 .45112 .20759 Mtetra
.45112 .20759 .45846 .21634 .4713 .21161 .46399 .20282 Mtetra
.46399 .20282 .4713 .21161 .48419 .20686 .47693 .19803 Mtetra
.47693 .19803 .48419 .20686 .49715 .20209 .48993 .19321 Mtetra
.48993 .19321 .49715 .20209 .51017 .19729 .50298 .18838 Mtetra
.50298 .18838 .51017 .19729 .52325 .19247 .5161 .18352 Mtetra
.5161 .18352 .52325 .19247 .53639 .18763 .52929 .17863 Mtetra
.52929 .17863 .53639 .18763 .5496 .18277 .54254 .17372 Mtetra
.54254 .17372 .5496 .18277 .56287 .17788 .55585 .16879 Mtetra
.55585 .16879 .56287 .17788 .5762 .17297 .56922 .16384 Mtetra
.56922 .16384 .5762 .17297 .5896 .16803 .58266 .15886 Mtetra
.58266 .15886 .5896 .16803 .60306 .16307 .59617 .15386 Mtetra
.59617 .15386 .60306 .16307 .61659 .15809 .60974 .14883 Mtetra
.60974 .14883 .61659 .15809 .63018 .15308 .62338 .14378 Mtetra
.62338 .14378 .63018 .15308 .64384 .14805 .63708 .1387 Mtetra
.63708 .1387 .64384 .14805 .65757 .143 .65086 .1336 Mtetra
.65086 .1336 .65757 .143 .67136 .13792 .6647 .12847 Mtetra
.6647 .12847 .67136 .13792 .68522 .13281 .6786 .12332 Mtetra
.6786 .12332 .68522 .13281 .69915 .12768 .69258 .11814 Mtetra
.69258 .11814 .69915 .12768 .71315 .12252 .70663 .11294 Mtetra
.70663 .11294 .71315 .12252 .72722 .11734 .72074 .10771 Mtetra
.72074 .10771 .72722 .11734 .74135 .11213 .73493 .10245 Mtetra
.73493 .10245 .74135 .11213 .75556 .1069 .74918 .09717 Mtetra
.10554 .32477 .11387 .33253 .12519 .32833 .11689 .32054 Mtetra
.11689 .32054 .12519 .32833 .13656 .32412 .12829 .31629 Mtetra
.12829 .31629 .13656 .32412 .14799 .31989 .13974 .31203 Mtetra
.13974 .31203 .14799 .31989 .15946 .31564 .15124 .30774 Mtetra
.15124 .30774 .15946 .31564 .17099 .31137 .1628 .30344 Mtetra
.1628 .30344 .17099 .31137 .18256 .30708 .1744 .29911 Mtetra
.1744 .29911 .18256 .30708 .19419 .30277 .18606 .29477 Mtetra
.18606 .29477 .19419 .30277 .20587 .29844 .19778 .2904 Mtetra
.19778 .2904 .20587 .29844 .21761 .2941 .20954 .28602 Mtetra
.20954 .28602 .21761 .2941 .2294 .28973 .22136 .28162 Mtetra
.22136 .28162 .2294 .28973 .24124 .28534 .23323 .27719 Mtetra
.23323 .27719 .24124 .28534 .25313 .28094 .24516 .27275 Mtetra
.24516 .27275 .25313 .28094 .26508 .27651 .25714 .26828 Mtetra
.25714 .26828 .26508 .27651 .27709 .27206 .26918 .2638 Mtetra
.26918 .2638 .27709 .27206 .28915 .26759 .28127 .25929 Mtetra
.28127 .25929 .28915 .26759 .30126 .26311 .29342 .25477 Mtetra
.29342 .25477 .30126 .26311 .31343 .2586 .30563 .25022 Mtetra
.30563 .25022 .31343 .2586 .32566 .25407 .31789 .24565 Mtetra
.31789 .24565 .32566 .25407 .33795 .24952 .33021 .24106 Mtetra
.33021 .24106 .33795 .24952 .35029 .24494 .34259 .23645 Mtetra
.34259 .23645 .35029 .24494 .36269 .24035 .35502 .23182 Mtetra
.35502 .23182 .36269 .24035 .37514 .23574 .36751 .22716 Mtetra
.36751 .22716 .37514 .23574 .38766 .2311 .38006 .22248 Mtetra
.38006 .22248 .38766 .2311 .40023 .22644 .39267 .21779 Mtetra
.39267 .21779 .40023 .22644 .41286 .22176 .40534 .21306 Mtetra
.40534 .21306 .41286 .22176 .42556 .21706 .41807 .20832 Mtetra
.41807 .20832 .42556 .21706 .43831 .21234 .43086 .20356 Mtetra
.43086 .20356 .43831 .21234 .45112 .20759 .44372 .19877 Mtetra
.44372 .19877 .45112 .20759 .46399 .20282 .45663 .19396 Mtetra
.45663 .19396 .46399 .20282 .47693 .19803 .4696 .18912 Mtetra
.4696 .18912 .47693 .19803 .48993 .19321 .48264 .18427 Mtetra
.48264 .18427 .48993 .19321 .50298 .18838 .49574 .17939 Mtetra
.49574 .17939 .50298 .18838 .5161 .18352 .5089 .17448 Mtetra
.5089 .17448 .5161 .18352 .52929 .17863 .52212 .16955 Mtetra
.52212 .16955 .52929 .17863 .54254 .17372 .53541 .1646 Mtetra
.53541 .1646 .54254 .17372 .55585 .16879 .54877 .15963 Mtetra
.54877 .15963 .55585 .16879 .56922 .16384 .56218 .15463 Mtetra
.56218 .15463 .56922 .16384 .58266 .15886 .57567 .1496 Mtetra
.57567 .1496 .58266 .15886 .59617 .15386 .58922 .14455 Mtetra
.58922 .14455 .59617 .15386 .60974 .14883 .60283 .13948 Mtetra
.60283 .13948 .60974 .14883 .62338 .14378 .61652 .13438 Mtetra
.61652 .13438 .62338 .14378 .63708 .1387 .63027 .12926 Mtetra
.63027 .12926 .63708 .1387 .65086 .1336 .64408 .12411 Mtetra
.64408 .12411 .65086 .1336 .6647 .12847 .65797 .11894 Mtetra
.65797 .11894 .6647 .12847 .6786 .12332 .67193 .11374 Mtetra
.67193 .11374 .6786 .12332 .69258 .11814 .68595 .10851 Mtetra
.68595 .10851 .69258 .11814 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.09714 .31695 .10554 .32477 .11689 .32054 .10852 .31268 Mtetra
.10852 .31268 .11689 .32054 .12829 .31629 .11995 .3084 Mtetra
.11995 .3084 .12829 .31629 .13974 .31203 .13143 .3041 Mtetra
.13143 .3041 .13974 .31203 .15124 .30774 .14296 .29978 Mtetra
.14296 .29978 .15124 .30774 .1628 .30344 .15454 .29544 Mtetra
.15454 .29544 .1628 .30344 .1744 .29911 .16618 .29108 Mtetra
.16618 .29108 .1744 .29911 .18606 .29477 .17787 .28669 Mtetra
.17787 .28669 .18606 .29477 .19778 .2904 .18961 .28229 Mtetra
.18961 .28229 .19778 .2904 .20954 .28602 .20141 .27787 Mtetra
.20141 .27787 .20954 .28602 .22136 .28162 .21326 .27343 Mtetra
.21326 .27343 .22136 .28162 .23323 .27719 .22516 .26897 Mtetra
.22516 .26897 .23323 .27719 .24516 .27275 .23712 .26449 Mtetra
.23712 .26449 .24516 .27275 .25714 .26828 .24914 .25999 Mtetra
.24914 .25999 .25714 .26828 .26918 .2638 .26121 .25546 Mtetra
.26121 .25546 .26918 .2638 .28127 .25929 .27333 .25092 Mtetra
.27333 .25092 .28127 .25929 .29342 .25477 .28552 .24635 Mtetra
.28552 .24635 .29342 .25477 .30563 .25022 .29776 .24177 Mtetra
.29776 .24177 .30563 .25022 .31789 .24565 .31005 .23716 Mtetra
.31005 .23716 .31789 .24565 .33021 .24106 .32241 .23253 Mtetra
.32241 .23253 .33021 .24106 .34259 .23645 .33482 .22788 Mtetra
.33482 .22788 .34259 .23645 .35502 .23182 .34729 .2232 Mtetra
.34729 .2232 .35502 .23182 .36751 .22716 .35982 .21851 Mtetra
.35982 .21851 .36751 .22716 .38006 .22248 .3724 .21379 Mtetra
.3724 .21379 .38006 .22248 .39267 .21779 .38505 .20905 Mtetra
.38505 .20905 .39267 .21779 .40534 .21306 .39776 .20429 Mtetra
.39776 .20429 .40534 .21306 .41807 .20832 .41053 .19951 Mtetra
.41053 .19951 .41807 .20832 .43086 .20356 .42335 .1947 Mtetra
.42335 .1947 .43086 .20356 .44372 .19877 .43624 .18987 Mtetra
.43624 .18987 .44372 .19877 .45663 .19396 .4492 .18501 Mtetra
.4492 .18501 .45663 .19396 .4696 .18912 .46221 .18014 Mtetra
.46221 .18014 .4696 .18912 .48264 .18427 .47529 .17524 Mtetra
.47529 .17524 .48264 .18427 .49574 .17939 .48843 .17031 Mtetra
.48843 .17031 .49574 .17939 .5089 .17448 .50163 .16537 Mtetra
.50163 .16537 .5089 .17448 .52212 .16955 .51489 .16039 Mtetra
.51489 .16039 .52212 .16955 .53541 .1646 .52823 .1554 Mtetra
.52823 .1554 .53541 .1646 .54877 .15963 .54162 .15038 Mtetra
.54162 .15038 .54877 .15963 .56218 .15463 .55508 .14533 Mtetra
.55508 .14533 .56218 .15463 .57567 .1496 .56861 .14026 Mtetra
.56861 .14026 .57567 .1496 .58922 .14455 .5822 .13517 Mtetra
.5822 .13517 .58922 .14455 .60283 .13948 .59586 .13005 Mtetra
.59586 .13005 .60283 .13948 .61652 .13438 .60959 .12491 Mtetra
.60959 .12491 .61652 .13438 .63027 .12926 .62339 .11974 Mtetra
.62339 .11974 .63027 .12926 .64408 .12411 .63725 .11454 Mtetra
.63725 .11454 .64408 .12411 .65797 .11894 .65119 .10932 Mtetra
.65119 .10932 .65797 .11894 .67193 .11374 .66519 .10407 Mtetra
.66519 .10407 .67193 .11374 .68595 .10851 .67926 .0988 Mtetra
.67926 .0988 .68595 .10851 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.08867 .30906 .09714 .31695 .10852 .31268 .10008 .30476 Mtetra
.10008 .30476 .10852 .31268 .11995 .3084 .11153 .30044 Mtetra
.11153 .30044 .11995 .3084 .13143 .3041 .12304 .29611 Mtetra
.12304 .29611 .13143 .3041 .14296 .29978 .1346 .29175 Mtetra
.1346 .29175 .14296 .29978 .15454 .29544 .14622 .28737 Mtetra
.14622 .28737 .15454 .29544 .16618 .29108 .15788 .28297 Mtetra
.15788 .28297 .16618 .29108 .17787 .28669 .1696 .27855 Mtetra
.1696 .27855 .17787 .28669 .18961 .28229 .18138 .27412 Mtetra
.18138 .27412 .18961 .28229 .20141 .27787 .1932 .26966 Mtetra
.1932 .26966 .20141 .27787 .21326 .27343 .20509 .26518 Mtetra
.20509 .26518 .21326 .27343 .22516 .26897 .21702 .26068 Mtetra
.21702 .26068 .22516 .26897 .23712 .26449 .22901 .25616 Mtetra
.22901 .25616 .23712 .26449 .24914 .25999 .24106 .25162 Mtetra
.24106 .25162 .24914 .25999 .26121 .25546 .25317 .24706 Mtetra
.25317 .24706 .26121 .25546 .27333 .25092 .26532 .24247 Mtetra
.26532 .24247 .27333 .25092 .28552 .24635 .27754 .23787 Mtetra
.27754 .23787 .28552 .24635 .29776 .24177 .28981 .23324 Mtetra
.28981 .23324 .29776 .24177 .31005 .23716 .30215 .22859 Mtetra
.30215 .22859 .31005 .23716 .32241 .23253 .31453 .22393 Mtetra
.31453 .22393 .32241 .23253 .33482 .22788 .32698 .21923 Mtetra
.32698 .21923 .33482 .22788 .34729 .2232 .33949 .21452 Mtetra
.33949 .21452 .34729 .2232 .35982 .21851 .35205 .20978 Mtetra
.35205 .20978 .35982 .21851 .3724 .21379 .36468 .20502 Mtetra
.36468 .20502 .3724 .21379 .38505 .20905 .37736 .20024 Mtetra
.37736 .20024 .38505 .20905 .39776 .20429 .39011 .19544 Mtetra
.39011 .19544 .39776 .20429 .41053 .19951 .40291 .19061 Mtetra
.40291 .19061 .41053 .19951 .42335 .1947 .41578 .18576 Mtetra
.41578 .18576 .42335 .1947 .43624 .18987 .42871 .18089 Mtetra
.42871 .18089 .43624 .18987 .4492 .18501 .4417 .17599 Mtetra
.4417 .17599 .4492 .18501 .46221 .18014 .45475 .17107 Mtetra
.45475 .17107 .46221 .18014 .47529 .17524 .46787 .16613 Mtetra
.46787 .16613 .47529 .17524 .48843 .17031 .48105 .16116 Mtetra
.48105 .16116 .48843 .17031 .50163 .16537 .49429 .15617 Mtetra
.49429 .15617 .50163 .16537 .51489 .16039 .5076 .15115 Mtetra
.5076 .15115 .51489 .16039 .52823 .1554 .52097 .14611 Mtetra
.52097 .14611 .52823 .1554 .54162 .15038 .53441 .14104 Mtetra
.53441 .14104 .54162 .15038 .55508 .14533 .54792 .13595 Mtetra
.54792 .13595 .55508 .14533 .56861 .14026 .56149 .13084 Mtetra
.56149 .13084 .56861 .14026 .5822 .13517 .57513 .1257 Mtetra
.57513 .1257 .5822 .13517 .59586 .13005 .58883 .12053 Mtetra
.58883 .12053 .59586 .13005 .60959 .12491 .60261 .11534 Mtetra
.60261 .11534 .60959 .12491 .62339 .11974 .61645 .11012 Mtetra
.61645 .11012 .62339 .11974 .63725 .11454 .63036 .10488 Mtetra
.63036 .10488 .63725 .11454 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09431 Mtetra
.65839 .09431 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.08013 .30111 .08867 .30906 .10008 .30476 .09156 .29677 Mtetra
.09156 .29677 .10008 .30476 .11153 .30044 .10305 .29242 Mtetra
.10305 .29242 .11153 .30044 .12304 .29611 .11459 .28804 Mtetra
.11459 .28804 .12304 .29611 .1346 .29175 .12618 .28365 Mtetra
.12618 .28365 .1346 .29175 .14622 .28737 .13782 .27924 Mtetra
.13782 .27924 .14622 .28737 .15788 .28297 .14952 .2748 Mtetra
.14952 .2748 .15788 .28297 .1696 .27855 .16127 .27035 Mtetra
.16127 .27035 .1696 .27855 .18138 .27412 .17307 .26587 Mtetra
.17307 .26587 .18138 .27412 .1932 .26966 .18493 .26137 Mtetra
.18493 .26137 .1932 .26966 .20509 .26518 .19684 .25686 Mtetra
.19684 .25686 .20509 .26518 .21702 .26068 .20881 .25232 Mtetra
.20881 .25232 .21702 .26068 .22901 .25616 .22084 .24776 Mtetra
.22084 .24776 .22901 .25616 .24106 .25162 .23292 .24318 Mtetra
.23292 .24318 .24106 .25162 .25317 .24706 .24505 .23858 Mtetra
.24505 .23858 .25317 .24706 .26532 .24247 .25725 .23396 Mtetra
.25725 .23396 .26532 .24247 .27754 .23787 .2695 .22931 Mtetra
.2695 .22931 .27754 .23787 .28981 .23324 .2818 .22464 Mtetra
.2818 .22464 .28981 .23324 .30215 .22859 .29417 .21996 Mtetra
.29417 .21996 .30215 .22859 .31453 .22393 .30659 .21525 Mtetra
.30659 .21525 .31453 .22393 .32698 .21923 .31908 .21051 Mtetra
.31908 .21051 .32698 .21923 .33949 .21452 .33162 .20576 Mtetra
.33162 .20576 .33949 .21452 .35205 .20978 .34422 .20098 Mtetra
.34422 .20098 .35205 .20978 .36468 .20502 .35688 .19618 Mtetra
.35688 .19618 .36468 .20502 .37736 .20024 .3696 .19136 Mtetra
.3696 .19136 .37736 .20024 .39011 .19544 .38239 .18651 Mtetra
.38239 .18651 .39011 .19544 .40291 .19061 .39523 .18164 Mtetra
.39523 .18164 .40291 .19061 .41578 .18576 .40813 .17675 Mtetra
.40813 .17675 .41578 .18576 .42871 .18089 .4211 .17183 Mtetra
.4211 .17183 .42871 .18089 .4417 .17599 .43413 .16689 Mtetra
.43413 .16689 .4417 .17599 .45475 .17107 .44723 .16193 Mtetra
.44723 .16193 .45475 .17107 .46787 .16613 .46038 .15694 Mtetra
.46038 .15694 .46787 .16613 .48105 .16116 .4736 .15192 Mtetra
.4736 .15192 .48105 .16116 .49429 .15617 .48689 .14689 Mtetra
.48689 .14689 .49429 .15617 .5076 .15115 .50024 .14183 Mtetra
.50024 .14183 .5076 .15115 .52097 .14611 .51366 .13674 Mtetra
.51366 .13674 .52097 .14611 .53441 .14104 .52714 .13163 Mtetra
.52714 .13163 .53441 .14104 .54792 .13595 .54069 .12649 Mtetra
.54069 .12649 .54792 .13595 .56149 .13084 .5543 .12133 Mtetra
.5543 .12133 .56149 .13084 .57513 .1257 .56798 .11614 Mtetra
.56798 .11614 .57513 .1257 .58883 .12053 .58173 .11093 Mtetra
.58173 .11093 .58883 .12053 .60261 .11534 .59555 .10569 Mtetra
.59555 .10569 .60261 .11534 .61645 .11012 .60944 .10042 Mtetra
.60944 .10042 .61645 .11012 .63036 .10488 .6234 .09513 Mtetra
.6234 .09513 .63036 .10488 .64434 .09961 .63742 .08981 Mtetra
.63742 .08981 .64434 .09961 .65839 .09431 .65152 .08447 Mtetra
.65152 .08447 .65839 .09431 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.07152 .29309 .08013 .30111 .09156 .29677 .08298 .28872 Mtetra
.08298 .28872 .09156 .29677 .10305 .29242 .09449 .28433 Mtetra
.09449 .28433 .10305 .29242 .11459 .28804 .10606 .27992 Mtetra
.10606 .27992 .11459 .28804 .12618 .28365 .11768 .27548 Mtetra
.11768 .27548 .12618 .28365 .13782 .27924 .12935 .27103 Mtetra
.12935 .27103 .13782 .27924 .14952 .2748 .14108 .26656 Mtetra
.14108 .26656 .14952 .2748 .16127 .27035 .15286 .26207 Mtetra
.15286 .26207 .16127 .27035 .17307 .26587 .1647 .25755 Mtetra
.1647 .25755 .17307 .26587 .18493 .26137 .17659 .25302 Mtetra
.17659 .25302 .18493 .26137 .19684 .25686 .18853 .24846 Mtetra
.18853 .24846 .19684 .25686 .20881 .25232 .20053 .24389 Mtetra
.20053 .24389 .20881 .25232 .22084 .24776 .21259 .23929 Mtetra
.21259 .23929 .22084 .24776 .23292 .24318 .2247 .23467 Mtetra
.2247 .23467 .23292 .24318 .24505 .23858 .23687 .23003 Mtetra
.23687 .23003 .24505 .23858 .25725 .23396 .2491 .22536 Mtetra
.2491 .22536 .25725 .23396 .2695 .22931 .26138 .22068 Mtetra
.26138 .22068 .2695 .22931 .2818 .22464 .27373 .21597 Mtetra
.27373 .21597 .2818 .22464 .29417 .21996 .28613 .21124 Mtetra
.28613 .21124 .29417 .21996 .30659 .21525 .29858 .20649 Mtetra
.29858 .20649 .30659 .21525 .31908 .21051 .3111 .20172 Mtetra
.3111 .20172 .31908 .21051 .33162 .20576 .32368 .19692 Mtetra
.32368 .19692 .33162 .20576 .34422 .20098 .33632 .1921 Mtetra
.33632 .1921 .34422 .20098 .35688 .19618 .34902 .18726 Mtetra
.34902 .18726 .35688 .19618 .3696 .19136 .36178 .18239 Mtetra
.36178 .18239 .3696 .19136 .38239 .18651 .3746 .1775 Mtetra
.3746 .1775 .38239 .18651 .39523 .18164 .38748 .17259 Mtetra
.38748 .17259 .39523 .18164 .40813 .17675 .40042 .16765 Mtetra
.40042 .16765 .40813 .17675 .4211 .17183 .41343 .16269 Mtetra
.41343 .16269 .4211 .17183 .43413 .16689 .4265 .15771 Mtetra
.4265 .15771 .43413 .16689 .44723 .16193 .43963 .1527 Mtetra
.43963 .1527 .44723 .16193 .46038 .15694 .45283 .14766 Mtetra
.45283 .14766 .46038 .15694 .4736 .15192 .46609 .14261 Mtetra
.46609 .14261 .4736 .15192 .48689 .14689 .47942 .13752 Mtetra
.47942 .13752 .48689 .14689 .50024 .14183 .49281 .13242 Mtetra
.49281 .13242 .50024 .14183 .51366 .13674 .50627 .12728 Mtetra
.50627 .12728 .51366 .13674 .52714 .13163 .5198 .12212 Mtetra
.5198 .12212 .52714 .13163 .54069 .12649 .53339 .11694 Mtetra
.53339 .11694 .54069 .12649 .5543 .12133 .54705 .11173 Mtetra
.54705 .11173 .5543 .12133 .56798 .11614 .56078 .1065 Mtetra
.56078 .1065 .56798 .11614 .58173 .11093 .57457 .10123 Mtetra
.57457 .10123 .58173 .11093 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10042 .60237 .09063 Mtetra
.60237 .09063 .60944 .10042 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63742 .08981 .63045 .07992 Mtetra
.63045 .07992 .63742 .08981 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.06283 .285 .07152 .29309 .08298 .28872 .07432 .2806 Mtetra
.07432 .2806 .08298 .28872 .09449 .28433 .08587 .27617 Mtetra
.08587 .27617 .09449 .28433 .10606 .27992 .09746 .27172 Mtetra
.09746 .27172 .10606 .27992 .11768 .27548 .10911 .26725 Mtetra
.10911 .26725 .11768 .27548 .12935 .27103 .12082 .26276 Mtetra
.12082 .26276 .12935 .27103 .14108 .26656 .13257 .25825 Mtetra
.13257 .25825 .14108 .26656 .15286 .26207 .14438 .25372 Mtetra
.14438 .25372 .15286 .26207 .1647 .25755 .15625 .24917 Mtetra
.15625 .24917 .1647 .25755 .17659 .25302 .16817 .24459 Mtetra
.16817 .24459 .17659 .25302 .18853 .24846 .18015 .24 Mtetra
.18015 .24 .18853 .24846 .20053 .24389 .19218 .23538 Mtetra
.19218 .23538 .20053 .24389 .21259 .23929 .20427 .23074 Mtetra
.20427 .23074 .21259 .23929 .2247 .23467 .21642 .22608 Mtetra
.21642 .22608 .2247 .23467 .23687 .23003 .22862 .2214 Mtetra
.22862 .2214 .23687 .23003 .2491 .22536 .24088 .2167 Mtetra
.24088 .2167 .2491 .22536 .26138 .22068 .2532 .21197 Mtetra
.2532 .21197 .26138 .22068 .27373 .21597 .26558 .20722 Mtetra
.26558 .20722 .27373 .21597 .28613 .21124 .27801 .20245 Mtetra
.27801 .20245 .28613 .21124 .29858 .20649 .29051 .19766 Mtetra
.29051 .19766 .29858 .20649 .3111 .20172 .30306 .19284 Mtetra
.30306 .19284 .3111 .20172 .32368 .19692 .31567 .188 Mtetra
.31567 .188 .32368 .19692 .33632 .1921 .32835 .18314 Mtetra
.32835 .18314 .33632 .1921 .34902 .18726 .34108 .17826 Mtetra
.34108 .17826 .34902 .18726 .36178 .18239 .35388 .17335 Mtetra
.35388 .17335 .36178 .18239 .3746 .1775 .36674 .16841 Mtetra
.36674 .16841 .3746 .1775 .38748 .17259 .37966 .16346 Mtetra
.37966 .16346 .38748 .17259 .40042 .16765 .39264 .15847 Mtetra
.39264 .15847 .40042 .16765 .41343 .16269 .40569 .15347 Mtetra
.40569 .15347 .41343 .16269 .4265 .15771 .4188 .14844 Mtetra
.4188 .14844 .4265 .15771 .43963 .1527 .43197 .14339 Mtetra
.43197 .14339 .43963 .1527 .45283 .14766 .44521 .13831 Mtetra
.44521 .13831 .45283 .14766 .46609 .14261 .45852 .1332 Mtetra
.45852 .1332 .46609 .14261 .47942 .13752 .47188 .12807 Mtetra
.47188 .12807 .47942 .13752 .49281 .13242 .48532 .12292 Mtetra
.48532 .12292 .49281 .13242 .50627 .12728 .49882 .11774 Mtetra
.49882 .11774 .50627 .12728 .5198 .12212 .51239 .11253 Mtetra
.51239 .11253 .5198 .12212 .53339 .11694 .52603 .1073 Mtetra
.52603 .1073 .53339 .11694 .54705 .11173 .53973 .10205 Mtetra
.53973 .10205 .54705 .11173 .56078 .1065 .5535 .09676 Mtetra
.5535 .09676 .56078 .1065 .57457 .10123 .56734 .09145 Mtetra
.56734 .09145 .57457 .10123 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09063 .59523 .08075 Mtetra
.59523 .08075 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.05408 .27685 .06283 .285 .07432 .2806 .06559 .2724 Mtetra
.06559 .2724 .07432 .2806 .08587 .27617 .07717 .26794 Mtetra
.07717 .26794 .08587 .27617 .09746 .27172 .08879 .26345 Mtetra
.08879 .26345 .09746 .27172 .10911 .26725 .10047 .25894 Mtetra
.10047 .25894 .10911 .26725 .12082 .26276 .1122 .25442 Mtetra
.1122 .25442 .12082 .26276 .13257 .25825 .12399 .24987 Mtetra
.12399 .24987 .13257 .25825 .14438 .25372 .13583 .2453 Mtetra
.13583 .2453 .14438 .25372 .15625 .24917 .14773 .24071 Mtetra
.14773 .24071 .15625 .24917 .16817 .24459 .15968 .23609 Mtetra
.15968 .23609 .16817 .24459 .18015 .24 .17169 .23146 Mtetra
.17169 .23146 .18015 .24 .19218 .23538 .18376 .2268 Mtetra
.18376 .2268 .19218 .23538 .20427 .23074 .19588 .22212 Mtetra
.19588 .22212 .20427 .23074 .21642 .22608 .20806 .21742 Mtetra
.20806 .21742 .21642 .22608 .22862 .2214 .2203 .2127 Mtetra
.2203 .2127 .22862 .2214 .24088 .2167 .23259 .20796 Mtetra
.23259 .20796 .24088 .2167 .2532 .21197 .24494 .20319 Mtetra
.24494 .20319 .2532 .21197 .26558 .20722 .25735 .1984 Mtetra
.25735 .1984 .26558 .20722 .27801 .20245 .26982 .19359 Mtetra
.26982 .19359 .27801 .20245 .29051 .19766 .28235 .18875 Mtetra
.28235 .18875 .29051 .19766 .30306 .19284 .29494 .18389 Mtetra
.29494 .18389 .30306 .19284 .31567 .188 .30759 .17901 Mtetra
.30759 .17901 .31567 .188 .32835 .18314 .32031 .1741 Mtetra
.32031 .1741 .32835 .18314 .34108 .17826 .33308 .16917 Mtetra
.33308 .16917 .34108 .17826 .35388 .17335 .34591 .16422 Mtetra
.34591 .16422 .35388 .17335 .36674 .16841 .35881 .15924 Mtetra
.35881 .15924 .36674 .16841 .37966 .16346 .37177 .15424 Mtetra
.37177 .15424 .37966 .16346 .39264 .15847 .38479 .14922 Mtetra
.38479 .14922 .39264 .15847 .40569 .15347 .39788 .14417 Mtetra
.39788 .14417 .40569 .15347 .4188 .14844 .41103 .13909 Mtetra
.41103 .13909 .4188 .14844 .43197 .14339 .42424 .13399 Mtetra
.42424 .13399 .43197 .14339 .44521 .13831 .43752 .12886 Mtetra
.43752 .12886 .44521 .13831 .45852 .1332 .45087 .12371 Mtetra
.45087 .12371 .45852 .1332 .47188 .12807 .46428 .11854 Mtetra
.46428 .11854 .47188 .12807 .48532 .12292 .47776 .11334 Mtetra
.47776 .11334 .48532 .12292 .49882 .11774 .4913 .10811 Mtetra
.4913 .10811 .49882 .11774 .51239 .11253 .50491 .10286 Mtetra
.50491 .10286 .51239 .11253 .52603 .1073 .51859 .09758 Mtetra
.51859 .09758 .52603 .1073 .53973 .10205 .53234 .09227 Mtetra
.53234 .09227 .53973 .10205 .5535 .09676 .54616 .08694 Mtetra
.54616 .08694 .5535 .09676 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.04524 .26863 .05408 .27685 .06559 .2724 .05679 .26414 Mtetra
.05679 .26414 .06559 .2724 .07717 .26794 .06839 .25964 Mtetra
.06839 .25964 .07717 .26794 .08879 .26345 .08005 .25511 Mtetra
.08005 .25511 .08879 .26345 .10047 .25894 .09176 .25057 Mtetra
.09176 .25057 .10047 .25894 .1122 .25442 .10352 .246 Mtetra
.10352 .246 .1122 .25442 .12399 .24987 .11534 .24141 Mtetra
.11534 .24141 .12399 .24987 .13583 .2453 .12721 .2368 Mtetra
.12721 .2368 .13583 .2453 .14773 .24071 .13914 .23217 Mtetra
.13914 .23217 .14773 .24071 .15968 .23609 .15112 .22752 Mtetra
.15112 .22752 .15968 .23609 .17169 .23146 .16316 .22284 Mtetra
.16316 .22284 .17169 .23146 .18376 .2268 .17526 .21815 Mtetra
.17526 .21815 .18376 .2268 .19588 .22212 .18742 .21343 Mtetra
.18742 .21343 .19588 .22212 .20806 .21742 .19963 .20869 Mtetra
.19963 .20869 .20806 .21742 .2203 .2127 .2119 .20392 Mtetra
.2119 .20392 .2203 .2127 .23259 .20796 .22423 .19914 Mtetra
.22423 .19914 .23259 .20796 .24494 .20319 .23661 .19433 Mtetra
.23661 .19433 .24494 .20319 .25735 .1984 .24906 .1895 Mtetra
.24906 .1895 .25735 .1984 .26982 .19359 .26157 .18464 Mtetra
.26157 .18464 .26982 .19359 .28235 .18875 .27413 .17976 Mtetra
.27413 .17976 .28235 .18875 .29494 .18389 .28676 .17486 Mtetra
.28676 .17486 .29494 .18389 .30759 .17901 .29944 .16993 Mtetra
.29944 .16993 .30759 .17901 .32031 .1741 .31219 .16498 Mtetra
.31219 .16498 .32031 .1741 .33308 .16917 .325 .16001 Mtetra
.325 .16001 .33308 .16917 .34591 .16422 .33788 .15501 Mtetra
.33788 .15501 .34591 .16422 .35881 .15924 .35081 .14999 Mtetra
.35081 .14999 .35881 .15924 .37177 .15424 .36381 .14494 Mtetra
.36381 .14494 .37177 .15424 .38479 .14922 .37687 .13987 Mtetra
.37687 .13987 .38479 .14922 .39788 .14417 .39 .13478 Mtetra
.39 .13478 .39788 .14417 .41103 .13909 .40319 .12965 Mtetra
.40319 .12965 .41103 .13909 .42424 .13399 .41644 .12451 Mtetra
.41644 .12451 .42424 .13399 .43752 .12886 .42976 .11934 Mtetra
.42976 .11934 .43752 .12886 .45087 .12371 .44315 .11414 Mtetra
.44315 .11414 .45087 .12371 .46428 .11854 .4566 .10892 Mtetra
.4566 .10892 .46428 .11854 .47776 .11334 .47013 .10367 Mtetra
.47013 .10367 .47776 .11334 .4913 .10811 .48371 .09839 Mtetra
.48371 .09839 .4913 .10811 .50491 .10286 .49737 .09309 Mtetra
.49737 .09309 .50491 .10286 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09227 .52489 .0824 Mtetra
.52489 .0824 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.03634 .26033 .04524 .26863 .05679 .26414 .04791 .25581 Mtetra
.04791 .25581 .05679 .26414 .06839 .25964 .05954 .25127 Mtetra
.05954 .25127 .06839 .25964 .08005 .25511 .07123 .24671 Mtetra
.07123 .24671 .08005 .25511 .09176 .25057 .08297 .24212 Mtetra
.08297 .24212 .09176 .25057 .10352 .246 .09476 .23751 Mtetra
.09476 .23751 .10352 .246 .11534 .24141 .10661 .23289 Mtetra
.10661 .23289 .11534 .24141 .12721 .2368 .11851 .22824 Mtetra
.11851 .22824 .12721 .2368 .13914 .23217 .13047 .22356 Mtetra
.13047 .22356 .13914 .23217 .15112 .22752 .14249 .21887 Mtetra
.14249 .21887 .15112 .22752 .16316 .22284 .15456 .21416 Mtetra
.15456 .21416 .16316 .22284 .17526 .21815 .16669 .20942 Mtetra
.16669 .20942 .17526 .21815 .18742 .21343 .17888 .20466 Mtetra
.17888 .20466 .18742 .21343 .19963 .20869 .19112 .19987 Mtetra
.19112 .19987 .19963 .20869 .2119 .20392 .20343 .19507 Mtetra
.20343 .19507 .2119 .20392 .22423 .19914 .21579 .19024 Mtetra
.21579 .19024 .22423 .19914 .23661 .19433 .22821 .18539 Mtetra
.22821 .18539 .23661 .19433 .24906 .1895 .24069 .18051 Mtetra
.24069 .18051 .24906 .1895 .26157 .18464 .25323 .17561 Mtetra
.25323 .17561 .26157 .18464 .27413 .17976 .26583 .17069 Mtetra
.26583 .17069 .27413 .17976 .28676 .17486 .2785 .16575 Mtetra
.2785 .16575 .28676 .17486 .29944 .16993 .29122 .16078 Mtetra
.29122 .16078 .29944 .16993 .31219 .16498 .30401 .15578 Mtetra
.30401 .15578 .31219 .16498 .325 .16001 .31685 .15076 Mtetra
.31685 .15076 .325 .16001 .33788 .15501 .32977 .14572 Mtetra
.32977 .14572 .33788 .15501 .35081 .14999 .34274 .14065 Mtetra
.34274 .14065 .35081 .14999 .36381 .14494 .35578 .13556 Mtetra
.35578 .13556 .36381 .14494 .37687 .13987 .36888 .13044 Mtetra
.36888 .13044 .37687 .13987 .39 .13478 .38204 .1253 Mtetra
.38204 .1253 .39 .13478 .40319 .12965 .39527 .12013 Mtetra
.39527 .12013 .40319 .12965 .41644 .12451 .40857 .11494 Mtetra
.40857 .11494 .41644 .12451 .42976 .11934 .42193 .10972 Mtetra
.42193 .10972 .42976 .11934 .44315 .11414 .43536 .10448 Mtetra
.43536 .10448 .44315 .11414 .4566 .10892 .44886 .0992 Mtetra
.44886 .0992 .4566 .10892 .47013 .10367 .46242 .09391 Mtetra
.46242 .09391 .47013 .10367 .48371 .09839 .47605 .08858 Mtetra
.47605 .08858 .48371 .09839 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .0824 .51736 .07245 Mtetra
.51736 .07245 .52489 .0824 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .57879 .48228 .57294 Mtetra
.48228 .57294 .48818 .57879 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57244 .5035 .56654 Mtetra
.5035 .56654 .50935 .57244 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .56009 Mtetra
.52489 .56009 .53068 .56605 .54141 .56283 .53564 .55685 Mtetra
.53564 .55685 .54141 .56283 .55218 .5596 .54644 .5536 Mtetra
.54644 .5536 .55218 .5596 .56299 .55635 .55728 .55033 Mtetra
.55728 .55033 .56299 .55635 .57385 .5531 .56816 .54705 Mtetra
.56816 .54705 .57385 .5531 .58474 .54983 .57909 .54376 Mtetra
.57909 .54376 .58474 .54983 .59568 .54654 .59006 .54045 Mtetra
.59006 .54045 .59568 .54654 .60667 .54325 .60107 .53713 Mtetra
.60107 .53713 .60667 .54325 .61769 .53994 .61213 .5338 Mtetra
.61213 .5338 .61769 .53994 .62876 .53662 .62323 .53045 Mtetra
.62323 .53045 .62876 .53662 .63988 .53329 .63437 .5271 Mtetra
.63437 .5271 .63988 .53329 .65104 .52994 .64556 .52372 Mtetra
.64556 .52372 .65104 .52994 .66224 .52658 .65679 .52034 Mtetra
.65679 .52034 .66224 .52658 .67349 .5232 .66807 .51694 Mtetra
.66807 .51694 .67349 .5232 .68478 .51982 .67939 .51353 Mtetra
.67939 .51353 .68478 .51982 .69612 .51641 .69076 .5101 Mtetra
.69076 .5101 .69612 .51641 .7075 .513 .70218 .50666 Mtetra
.70218 .50666 .7075 .513 .71893 .50957 .71364 .5032 Mtetra
.71364 .5032 .71893 .50957 .73041 .50613 .72515 .49974 Mtetra
.72515 .49974 .73041 .50613 .74193 .50267 .7367 .49625 Mtetra
.7367 .49625 .74193 .50267 .7535 .4992 .7483 .49276 Mtetra
.7483 .49276 .7535 .4992 .76511 .49572 .75995 .48925 Mtetra
.75995 .48925 .76511 .49572 .77677 .49222 .77165 .48572 Mtetra
.77165 .48572 .77677 .49222 .78848 .48871 .78339 .48218 Mtetra
.78339 .48218 .78848 .48871 .80024 .48518 .79518 .47863 Mtetra
.79518 .47863 .80024 .48518 .81205 .48164 .80702 .47506 Mtetra
.80702 .47506 .81205 .48164 .8239 .47808 .81891 .47148 Mtetra
.81891 .47148 .8239 .47808 .8358 .47451 .83085 .46788 Mtetra
.83085 .46788 .8358 .47451 .84775 .47092 .84283 .46427 Mtetra
.84283 .46427 .84775 .47092 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .45699 Mtetra
.86696 .45699 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57342 Mtetra
.45523 .57342 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55735 Mtetra
.50831 .55735 .51417 .56332 .52489 .56009 .51905 .5541 Mtetra
.51905 .5541 .52489 .56009 .53564 .55685 .52983 .55083 Mtetra
.52983 .55083 .53564 .55685 .54644 .5536 .54066 .54756 Mtetra
.54066 .54756 .54644 .5536 .55728 .55033 .55153 .54426 Mtetra
.55153 .54426 .55728 .55033 .56816 .54705 .56244 .54096 Mtetra
.56244 .54096 .56816 .54705 .57909 .54376 .57339 .53764 Mtetra
.57339 .53764 .57909 .54376 .59006 .54045 .58439 .53431 Mtetra
.58439 .53431 .59006 .54045 .60107 .53713 .59543 .53097 Mtetra
.59543 .53097 .60107 .53713 .61213 .5338 .60652 .52761 Mtetra
.60652 .52761 .61213 .5338 .62323 .53045 .61765 .52424 Mtetra
.61765 .52424 .62323 .53045 .63437 .5271 .62882 .52086 Mtetra
.62882 .52086 .63437 .5271 .64556 .52372 .64004 .51746 Mtetra
.64004 .51746 .64556 .52372 .65679 .52034 .6513 .51405 Mtetra
.6513 .51405 .65679 .52034 .66807 .51694 .66261 .51063 Mtetra
.66261 .51063 .66807 .51694 .67939 .51353 .67397 .50719 Mtetra
.67397 .50719 .67939 .51353 .69076 .5101 .68537 .50374 Mtetra
.68537 .50374 .69076 .5101 .70218 .50666 .69682 .50027 Mtetra
.69682 .50027 .70218 .50666 .71364 .5032 .70831 .49679 Mtetra
.70831 .49679 .71364 .5032 .72515 .49974 .71985 .4933 Mtetra
.71985 .4933 .72515 .49974 .7367 .49625 .73144 .48979 Mtetra
.73144 .48979 .7367 .49625 .7483 .49276 .74307 .48626 Mtetra
.74307 .48626 .7483 .49276 .75995 .48925 .75475 .48273 Mtetra
.75475 .48273 .75995 .48925 .77165 .48572 .76648 .47918 Mtetra
.76648 .47918 .77165 .48572 .78339 .48218 .77826 .47561 Mtetra
.77826 .47561 .78339 .48218 .79518 .47863 .79008 .47203 Mtetra
.79008 .47203 .79518 .47863 .80702 .47506 .80196 .46843 Mtetra
.80196 .46843 .80702 .47506 .81891 .47148 .81388 .46482 Mtetra
.81388 .46482 .81891 .47148 .83085 .46788 .82585 .4612 Mtetra
.82585 .4612 .83085 .46788 .84283 .46427 .83788 .45756 Mtetra
.83788 .45756 .84283 .46427 .85487 .46064 .84995 .4539 Mtetra
.84995 .4539 .85487 .46064 .86696 .45699 .86207 .45023 Mtetra
.86207 .45023 .86696 .45699 .87909 .45334 .87424 .44654 Mtetra
.87424 .44654 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57342 .44919 .56753 Mtetra
.44919 .56753 .45523 .57342 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .5546 Mtetra
.49168 .5546 .49761 .56059 .50831 .55735 .5024 .55134 Mtetra
.5024 .55134 .50831 .55735 .51905 .5541 .51317 .54806 Mtetra
.51317 .54806 .51905 .5541 .52983 .55083 .52398 .54477 Mtetra
.52398 .54477 .52983 .55083 .54066 .54756 .53484 .54147 Mtetra
.53484 .54147 .54066 .54756 .55153 .54426 .54573 .53815 Mtetra
.54573 .53815 .55153 .54426 .56244 .54096 .55667 .53483 Mtetra
.55667 .53483 .56244 .54096 .57339 .53764 .56766 .53149 Mtetra
.56766 .53149 .57339 .53764 .58439 .53431 .57868 .52813 Mtetra
.57868 .52813 .58439 .53431 .59543 .53097 .58975 .52476 Mtetra
.58975 .52476 .59543 .53097 .60652 .52761 .60087 .52138 Mtetra
.60087 .52138 .60652 .52761 .61765 .52424 .61203 .51799 Mtetra
.61203 .51799 .61765 .52424 .62882 .52086 .62323 .51458 Mtetra
.62323 .51458 .62882 .52086 .64004 .51746 .63448 .51115 Mtetra
.63448 .51115 .64004 .51746 .6513 .51405 .64578 .50772 Mtetra
.64578 .50772 .6513 .51405 .66261 .51063 .65712 .50427 Mtetra
.65712 .50427 .66261 .51063 .67397 .50719 .6685 .5008 Mtetra
.6685 .5008 .67397 .50719 .68537 .50374 .67993 .49733 Mtetra
.67993 .49733 .68537 .50374 .69682 .50027 .69141 .49383 Mtetra
.69141 .49383 .69682 .50027 .70831 .49679 .70294 .49033 Mtetra
.70294 .49033 .70831 .49679 .71985 .4933 .71451 .48681 Mtetra
.71451 .48681 .71985 .4933 .73144 .48979 .72613 .48327 Mtetra
.72613 .48327 .73144 .48979 .74307 .48626 .7378 .47972 Mtetra
.7378 .47972 .74307 .48626 .75475 .48273 .74951 .47616 Mtetra
.74951 .47616 .75475 .48273 .76648 .47918 .76127 .47258 Mtetra
.76127 .47258 .76648 .47918 .77826 .47561 .77309 .46899 Mtetra
.77309 .46899 .77826 .47561 .79008 .47203 .78495 .46538 Mtetra
.78495 .46538 .79008 .47203 .80196 .46843 .79686 .46176 Mtetra
.79686 .46176 .80196 .46843 .81388 .46482 .80881 .45812 Mtetra
.80881 .45812 .81388 .46482 .82585 .4612 .82082 .45446 Mtetra
.82082 .45446 .82585 .4612 .83788 .45756 .83288 .4508 Mtetra
.83288 .4508 .83788 .45756 .84995 .4539 .84499 .44711 Mtetra
.84499 .44711 .84995 .4539 .86207 .45023 .85715 .44341 Mtetra
.85715 .44341 .86207 .45023 .87424 .44654 .86936 .4397 Mtetra
.86936 .4397 .87424 .44654 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .5551 Mtetra
.46432 .5551 .47035 .56109 .48099 .55785 .47499 .55184 Mtetra
.47499 .55184 .48099 .55785 .49168 .5546 .4857 .54857 Mtetra
.4857 .54857 .49168 .5546 .5024 .55134 .49646 .54528 Mtetra
.49646 .54528 .5024 .55134 .51317 .54806 .50725 .54198 Mtetra
.50725 .54198 .51317 .54806 .52398 .54477 .51809 .53867 Mtetra
.51809 .53867 .52398 .54477 .53484 .54147 .52897 .53534 Mtetra
.52897 .53534 .53484 .54147 .54573 .53815 .5399 .532 Mtetra
.5399 .532 .54573 .53815 .55667 .53483 .55087 .52865 Mtetra
.55087 .52865 .55667 .53483 .56766 .53149 .56188 .52528 Mtetra
.56188 .52528 .56766 .53149 .57868 .52813 .57293 .5219 Mtetra
.57293 .5219 .57868 .52813 .58975 .52476 .58403 .51851 Mtetra
.58403 .51851 .58975 .52476 .60087 .52138 .59518 .5151 Mtetra
.59518 .5151 .60087 .52138 .61203 .51799 .60637 .51168 Mtetra
.60637 .51168 .61203 .51799 .62323 .51458 .6176 .50825 Mtetra
.6176 .50825 .62323 .51458 .63448 .51115 .62888 .5048 Mtetra
.62888 .5048 .63448 .51115 .64578 .50772 .64021 .50134 Mtetra
.64021 .50134 .64578 .50772 .65712 .50427 .65158 .49786 Mtetra
.65158 .49786 .65712 .50427 .6685 .5008 .663 .49437 Mtetra
.663 .49437 .6685 .5008 .67993 .49733 .67446 .49087 Mtetra
.67446 .49087 .67993 .49733 .69141 .49383 .68597 .48735 Mtetra
.68597 .48735 .69141 .49383 .70294 .49033 .69753 .48382 Mtetra
.69753 .48382 .70294 .49033 .71451 .48681 .70913 .48027 Mtetra
.70913 .48027 .71451 .48681 .72613 .48327 .72078 .47671 Mtetra
.72078 .47671 .72613 .48327 .7378 .47972 .73248 .47313 Mtetra
.73248 .47313 .7378 .47972 .74951 .47616 .74423 .46954 Mtetra
.74423 .46954 .74951 .47616 .76127 .47258 .75603 .46593 Mtetra
.75603 .46593 .76127 .47258 .77309 .46899 .76788 .46231 Mtetra
.76788 .46231 .77309 .46899 .78495 .46538 .77977 .45868 Mtetra
.77977 .45868 .78495 .46538 .79686 .46176 .79171 .45503 Mtetra
.79171 .45503 .79686 .46176 .80881 .45812 .80371 .45136 Mtetra
.80371 .45136 .80881 .45812 .82082 .45446 .81575 .44768 Mtetra
.81575 .44768 .82082 .45446 .83288 .4508 .82785 .44398 Mtetra
.82785 .44398 .83288 .4508 .84499 .44711 .83999 .44027 Mtetra
.83999 .44027 .84499 .44711 .85715 .44341 .85219 .43654 Mtetra
.85219 .43654 .85715 .44341 .86936 .4397 .86443 .4328 Mtetra
.86443 .4328 .86936 .4397 .88162 .43597 .87673 .42904 Mtetra
.87673 .42904 .88162 .43597 .89393 .43222 .88908 .42526 Mtetra
.88908 .42526 .89393 .43222 .9063 .42846 .90148 .42147 Mtetra
.90148 .42147 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .5556 Mtetra
.43698 .5556 .44311 .56159 .45369 .55835 .4476 .55234 Mtetra
.4476 .55234 .45369 .55835 .46432 .5551 .45825 .54907 Mtetra
.45825 .54907 .46432 .5551 .47499 .55184 .46895 .54579 Mtetra
.46895 .54579 .47499 .55184 .4857 .54857 .47968 .54249 Mtetra
.47968 .54249 .4857 .54857 .49646 .54528 .49046 .53918 Mtetra
.49046 .53918 .49646 .54528 .50725 .54198 .50129 .53585 Mtetra
.50129 .53585 .50725 .54198 .51809 .53867 .51215 .53251 Mtetra
.51215 .53251 .51809 .53867 .52897 .53534 .52306 .52916 Mtetra
.52306 .52916 .52897 .53534 .5399 .532 .53402 .5258 Mtetra
.53402 .5258 .5399 .532 .55087 .52865 .54501 .52242 Mtetra
.54501 .52242 .55087 .52865 .56188 .52528 .55606 .51903 Mtetra
.55606 .51903 .56188 .52528 .57293 .5219 .56714 .51563 Mtetra
.56714 .51563 .57293 .5219 .58403 .51851 .57827 .51221 Mtetra
.57827 .51221 .58403 .51851 .59518 .5151 .58944 .50878 Mtetra
.58944 .50878 .59518 .5151 .60637 .51168 .60066 .50533 Mtetra
.60066 .50533 .60637 .51168 .6176 .50825 .61193 .50187 Mtetra
.61193 .50187 .6176 .50825 .62888 .5048 .62324 .4984 Mtetra
.62324 .4984 .62888 .5048 .64021 .50134 .6346 .49491 Mtetra
.6346 .49491 .64021 .50134 .65158 .49786 .646 .49141 Mtetra
.646 .49141 .65158 .49786 .663 .49437 .65745 .48789 Mtetra
.65745 .48789 .663 .49437 .67446 .49087 .66894 .48436 Mtetra
.66894 .48436 .67446 .49087 .68597 .48735 .68049 .48082 Mtetra
.68049 .48082 .68597 .48735 .69753 .48382 .69208 .47726 Mtetra
.69208 .47726 .69753 .48382 .70913 .48027 .70371 .47368 Mtetra
.70371 .47368 .70913 .48027 .72078 .47671 .7154 .47009 Mtetra
.7154 .47009 .72078 .47671 .73248 .47313 .72713 .46649 Mtetra
.72713 .46649 .73248 .47313 .74423 .46954 .73891 .46287 Mtetra
.73891 .46287 .74423 .46954 .75603 .46593 .75075 .45924 Mtetra
.75075 .45924 .75603 .46593 .76788 .46231 .76263 .45559 Mtetra
.76263 .45559 .76788 .46231 .77977 .45868 .77455 .45193 Mtetra
.77455 .45193 .77977 .45868 .79171 .45503 .78653 .44825 Mtetra
.78653 .44825 .79171 .45503 .80371 .45136 .79856 .44455 Mtetra
.79856 .44455 .80371 .45136 .81575 .44768 .81064 .44084 Mtetra
.81064 .44084 .81575 .44768 .82785 .44398 .82277 .43712 Mtetra
.82277 .43712 .82785 .44398 .83999 .44027 .83495 .43338 Mtetra
.83495 .43338 .83999 .44027 .85219 .43654 .84719 .42962 Mtetra
.84719 .42962 .85219 .43654 .86443 .4328 .85947 .42585 Mtetra
.85947 .42585 .86443 .4328 .87673 .42904 .87181 .42206 Mtetra
.87181 .42206 .87673 .42904 .88908 .42526 .88419 .41825 Mtetra
.88419 .41825 .88908 .42526 .90148 .42147 .89664 .41443 Mtetra
.89664 .41443 .90148 .42147 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55284 Mtetra
.42022 .55284 .42641 .55885 .43698 .5556 .43081 .54957 Mtetra
.43081 .54957 .43698 .5556 .4476 .55234 .44145 .54629 Mtetra
.44145 .54629 .4476 .55234 .45825 .54907 .45213 .543 Mtetra
.45213 .543 .45825 .54907 .46895 .54579 .46286 .53969 Mtetra
.46286 .53969 .46895 .54579 .47968 .54249 .47362 .53636 Mtetra
.47362 .53636 .47968 .54249 .49046 .53918 .48443 .53303 Mtetra
.48443 .53303 .49046 .53918 .50129 .53585 .49528 .52968 Mtetra
.49528 .52968 .50129 .53585 .51215 .53251 .50617 .52632 Mtetra
.50617 .52632 .51215 .53251 .52306 .52916 .51711 .52294 Mtetra
.51711 .52294 .52306 .52916 .53402 .5258 .52809 .51955 Mtetra
.52809 .51955 .53402 .5258 .54501 .52242 .53912 .51615 Mtetra
.53912 .51615 .54501 .52242 .55606 .51903 .55019 .51274 Mtetra
.55019 .51274 .55606 .51903 .56714 .51563 .5613 .50931 Mtetra
.5613 .50931 .56714 .51563 .57827 .51221 .57246 .50586 Mtetra
.57246 .50586 .57827 .51221 .58944 .50878 .58367 .50241 Mtetra
.58367 .50241 .58944 .50878 .60066 .50533 .59492 .49893 Mtetra
.59492 .49893 .60066 .50533 .61193 .50187 .60621 .49545 Mtetra
.60621 .49545 .61193 .50187 .62324 .4984 .61755 .49195 Mtetra
.61755 .49195 .62324 .4984 .6346 .49491 .62894 .48843 Mtetra
.62894 .48843 .6346 .49491 .646 .49141 .64038 .48491 Mtetra
.64038 .48491 .646 .49141 .65745 .48789 .65186 .48136 Mtetra
.65186 .48136 .65745 .48789 .66894 .48436 .66338 .47781 Mtetra
.66338 .47781 .66894 .48436 .68049 .48082 .67496 .47423 Mtetra
.67496 .47423 .68049 .48082 .69208 .47726 .68658 .47065 Mtetra
.68658 .47065 .69208 .47726 .70371 .47368 .69825 .46705 Mtetra
.69825 .46705 .70371 .47368 .7154 .47009 .70997 .46343 Mtetra
.70997 .46343 .7154 .47009 .72713 .46649 .72174 .4598 Mtetra
.72174 .4598 .72713 .46649 .73891 .46287 .73355 .45615 Mtetra
.73355 .45615 .73891 .46287 .75075 .45924 .74542 .45249 Mtetra
.74542 .45249 .75075 .45924 .76263 .45559 .75733 .44881 Mtetra
.75733 .44881 .76263 .45559 .77455 .45193 .7693 .44512 Mtetra
.7693 .44512 .77455 .45193 .78653 .44825 .78131 .44141 Mtetra
.78131 .44141 .78653 .44825 .79856 .44455 .79338 .43769 Mtetra
.79338 .43769 .79856 .44455 .81064 .44084 .80549 .43395 Mtetra
.80549 .43395 .81064 .44084 .82277 .43712 .81766 .4302 Mtetra
.81766 .4302 .82277 .43712 .83495 .43338 .82988 .42643 Mtetra
.82988 .42643 .83495 .43338 .84719 .42962 .84215 .42264 Mtetra
.84215 .42264 .84719 .42962 .85947 .42585 .85447 .41884 Mtetra
.85447 .41884 .85947 .42585 .87181 .42206 .86684 .41502 Mtetra
.86684 .41502 .87181 .42206 .88419 .41825 .87927 .41119 Mtetra
.87927 .41119 .88419 .41825 .89664 .41443 .89175 .40734 Mtetra
.89175 .40734 .89664 .41443 .90913 .4106 .90428 .40347 Mtetra
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39958 Mtetra
.91687 .39958 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55984 Mtetra
.37189 .55984 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55284 .41397 .5468 Mtetra
.41397 .5468 .42022 .55284 .43081 .54957 .4246 .5435 Mtetra
.4246 .5435 .43081 .54957 .44145 .54629 .43526 .5402 Mtetra
.43526 .5402 .44145 .54629 .45213 .543 .44597 .53688 Mtetra
.44597 .53688 .45213 .543 .46286 .53969 .45672 .53354 Mtetra
.45672 .53354 .46286 .53969 .47362 .53636 .46751 .5302 Mtetra
.46751 .5302 .47362 .53636 .48443 .53303 .47835 .52684 Mtetra
.47835 .52684 .48443 .53303 .49528 .52968 .48923 .52346 Mtetra
.48923 .52346 .49528 .52968 .50617 .52632 .50015 .52008 Mtetra
.50015 .52008 .50617 .52632 .51711 .52294 .51112 .51668 Mtetra
.51112 .51668 .51711 .52294 .52809 .51955 .52213 .51326 Mtetra
.52213 .51326 .52809 .51955 .53912 .51615 .53318 .50983 Mtetra
.53318 .50983 .53912 .51615 .55019 .51274 .54428 .50639 Mtetra
.54428 .50639 .55019 .51274 .5613 .50931 .55543 .50294 Mtetra
.55543 .50294 .5613 .50931 .57246 .50586 .56661 .49947 Mtetra
.56661 .49947 .57246 .50586 .58367 .50241 .57785 .49599 Mtetra
.57785 .49599 .58367 .50241 .59492 .49893 .58913 .49249 Mtetra
.58913 .49249 .59492 .49893 .60621 .49545 .60045 .48898 Mtetra
.60045 .48898 .60621 .49545 .61755 .49195 .61183 .48545 Mtetra
.61183 .48545 .61755 .49195 .62894 .48843 .62325 .48191 Mtetra
.62325 .48191 .62894 .48843 .64038 .48491 .63471 .47835 Mtetra
.63471 .47835 .64038 .48491 .65186 .48136 .64622 .47478 Mtetra
.64622 .47478 .65186 .48136 .66338 .47781 .65778 .4712 Mtetra
.65778 .4712 .66338 .47781 .67496 .47423 .66939 .4676 Mtetra
.66939 .4676 .67496 .47423 .68658 .47065 .68105 .46399 Mtetra
.68105 .46399 .68658 .47065 .69825 .46705 .69275 .46036 Mtetra
.69275 .46036 .69825 .46705 .70997 .46343 .7045 .45671 Mtetra
.7045 .45671 .70997 .46343 .72174 .4598 .7163 .45306 Mtetra
.7163 .45306 .72174 .4598 .73355 .45615 .72815 .44938 Mtetra
.72815 .44938 .73355 .45615 .74542 .45249 .74005 .44569 Mtetra
.74005 .44569 .74542 .45249 .75733 .44881 .752 .44199 Mtetra
.752 .44199 .75733 .44881 .7693 .44512 .764 .43827 Mtetra
.764 .43827 .7693 .44512 .78131 .44141 .77605 .43453 Mtetra
.77605 .43453 .78131 .44141 .79338 .43769 .78815 .43078 Mtetra
.78815 .43078 .79338 .43769 .80549 .43395 .8003 .42701 Mtetra
.8003 .42701 .80549 .43395 .81766 .4302 .81251 .42323 Mtetra
.81251 .42323 .81766 .4302 .82988 .42643 .82476 .41943 Mtetra
.82476 .41943 .82988 .42643 .84215 .42264 .83707 .41561 Mtetra
.83707 .41561 .84215 .42264 .85447 .41884 .84943 .41178 Mtetra
.84943 .41178 .85447 .41884 .86684 .41502 .86184 .40793 Mtetra
.86184 .40793 .86684 .41502 .87927 .41119 .8743 .40406 Mtetra
.8743 .40406 .87927 .41119 .89175 .40734 .88682 .40018 Mtetra
.88682 .40018 .89175 .40734 .90428 .40347 .89939 .39628 Mtetra
.89939 .39628 .90428 .40347 .91687 .39958 .91202 .39237 Mtetra
.91202 .39237 .91687 .39958 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.35506 .5571 .36148 .56307 .37189 .55984 .3655 .55385 Mtetra
.3655 .55385 .37189 .55984 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .5435 .41834 .53739 Mtetra
.41834 .53739 .4246 .5435 .43526 .5402 .42903 .53406 Mtetra
.42903 .53406 .43526 .5402 .44597 .53688 .43976 .53071 Mtetra
.43976 .53071 .44597 .53688 .45672 .53354 .45054 .52735 Mtetra
.45054 .52735 .45672 .53354 .46751 .5302 .46136 .52398 Mtetra
.46136 .52398 .46751 .5302 .47835 .52684 .47222 .5206 Mtetra
.47222 .5206 .47835 .52684 .48923 .52346 .48313 .5172 Mtetra
.48313 .5172 .48923 .52346 .50015 .52008 .49408 .51379 Mtetra
.49408 .51379 .50015 .52008 .51112 .51668 .50508 .51036 Mtetra
.50508 .51036 .51112 .51668 .52213 .51326 .51612 .50692 Mtetra
.51612 .50692 .52213 .51326 .53318 .50983 .5272 .50347 Mtetra
.5272 .50347 .53318 .50983 .54428 .50639 .53833 .5 Mtetra
.53833 .5 .54428 .50639 .55543 .50294 .5495 .49652 Mtetra
.5495 .49652 .55543 .50294 .56661 .49947 .56072 .49303 Mtetra
.56072 .49303 .56661 .49947 .57785 .49599 .57199 .48952 Mtetra
.57199 .48952 .57785 .49599 .58913 .49249 .5833 .48599 Mtetra
.5833 .48599 .58913 .49249 .60045 .48898 .59465 .48245 Mtetra
.59465 .48245 .60045 .48898 .61183 .48545 .60606 .4789 Mtetra
.60606 .4789 .61183 .48545 .62325 .48191 .61751 .47533 Mtetra
.61751 .47533 .62325 .48191 .63471 .47835 .629 .47175 Mtetra
.629 .47175 .63471 .47835 .64622 .47478 .64055 .46816 Mtetra
.64055 .46816 .64622 .47478 .65778 .4712 .65214 .46454 Mtetra
.65214 .46454 .65778 .4712 .66939 .4676 .66378 .46092 Mtetra
.66378 .46092 .66939 .4676 .68105 .46399 .67547 .45728 Mtetra
.67547 .45728 .68105 .46399 .69275 .46036 .68721 .45362 Mtetra
.68721 .45362 .69275 .46036 .7045 .45671 .69899 .44995 Mtetra
.69899 .44995 .7045 .45671 .7163 .45306 .71083 .44626 Mtetra
.71083 .44626 .7163 .45306 .72815 .44938 .72271 .44256 Mtetra
.72271 .44256 .72815 .44938 .74005 .44569 .73465 .43884 Mtetra
.73465 .43884 .74005 .44569 .752 .44199 .74663 .4351 Mtetra
.74663 .4351 .752 .44199 .764 .43827 .75866 .43136 Mtetra
.75866 .43136 .764 .43827 .77605 .43453 .77075 .42759 Mtetra
.77075 .42759 .77605 .43453 .78815 .43078 .78289 .42381 Mtetra
.78289 .42381 .78815 .43078 .8003 .42701 .79507 .42001 Mtetra
.79507 .42001 .8003 .42701 .81251 .42323 .80731 .4162 Mtetra
.80731 .4162 .81251 .42323 .82476 .41943 .81961 .41237 Mtetra
.81961 .41237 .82476 .41943 .83707 .41561 .83195 .40852 Mtetra
.83195 .40852 .83707 .41561 .84943 .41178 .84435 .40466 Mtetra
.84435 .40466 .84943 .41178 .86184 .40793 .8568 .40078 Mtetra
.8568 .40078 .86184 .40793 .8743 .40406 .8693 .39689 Mtetra
.8693 .39689 .8743 .40406 .88682 .40018 .88186 .39297 Mtetra
.88186 .39297 .88682 .40018 .89939 .39628 .89447 .38904 Mtetra
.89447 .38904 .89939 .39628 .91202 .39237 .90713 .3851 Mtetra
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37715 Mtetra
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53457 Mtetra
.40135 .53457 .40769 .54071 .41834 .53739 .41203 .53123 Mtetra
.41203 .53123 .41834 .53739 .42903 .53406 .42275 .52787 Mtetra
.42275 .52787 .42903 .53406 .43976 .53071 .43351 .5245 Mtetra
.43351 .5245 .43976 .53071 .45054 .52735 .44432 .52112 Mtetra
.44432 .52112 .45054 .52735 .46136 .52398 .45516 .51772 Mtetra
.45516 .51772 .46136 .52398 .47222 .5206 .46605 .51431 Mtetra
.46605 .51431 .47222 .5206 .48313 .5172 .47699 .51089 Mtetra
.47699 .51089 .48313 .5172 .49408 .51379 .48797 .50745 Mtetra
.48797 .50745 .49408 .51379 .50508 .51036 .49899 .504 Mtetra
.49899 .504 .50508 .51036 .51612 .50692 .51006 .50054 Mtetra
.51006 .50054 .51612 .50692 .5272 .50347 .52117 .49706 Mtetra
.52117 .49706 .5272 .50347 .53833 .5 .53233 .49357 Mtetra
.53233 .49357 .53833 .5 .5495 .49652 .54353 .49006 Mtetra
.54353 .49006 .5495 .49652 .56072 .49303 .55478 .48654 Mtetra
.55478 .48654 .56072 .49303 .57199 .48952 .56608 .483 Mtetra
.56608 .483 .57199 .48952 .5833 .48599 .57742 .47945 Mtetra
.57742 .47945 .5833 .48599 .59465 .48245 .58881 .47588 Mtetra
.58881 .47588 .59465 .48245 .60606 .4789 .60024 .4723 Mtetra
.60024 .4723 .60606 .4789 .61751 .47533 .61172 .46871 Mtetra
.61172 .46871 .61751 .47533 .629 .47175 .62325 .4651 Mtetra
.62325 .4651 .629 .47175 .64055 .46816 .63483 .46148 Mtetra
.63483 .46148 .64055 .46816 .65214 .46454 .64645 .45784 Mtetra
.64645 .45784 .65214 .46454 .66378 .46092 .65813 .45418 Mtetra
.65813 .45418 .66378 .46092 .67547 .45728 .66985 .45051 Mtetra
.66985 .45051 .67547 .45728 .68721 .45362 .68162 .44683 Mtetra
.68162 .44683 .68721 .45362 .69899 .44995 .69344 .44313 Mtetra
.69344 .44313 .69899 .44995 .71083 .44626 .70531 .43941 Mtetra
.70531 .43941 .71083 .44626 .72271 .44256 .71723 .43568 Mtetra
.71723 .43568 .72271 .44256 .73465 .43884 .7292 .43193 Mtetra
.7292 .43193 .73465 .43884 .74663 .4351 .74122 .42817 Mtetra
.74122 .42817 .74663 .4351 .75866 .43136 .75329 .42439 Mtetra
.75329 .42439 .75866 .43136 .77075 .42759 .76541 .4206 Mtetra
.76541 .4206 .77075 .42759 .78289 .42381 .77758 .41679 Mtetra
.77758 .41679 .78289 .42381 .79507 .42001 .7898 .41296 Mtetra
.7898 .41296 .79507 .42001 .80731 .4162 .80208 .40912 Mtetra
.80208 .40912 .80731 .4162 .81961 .41237 .81441 .40526 Mtetra
.81441 .40526 .81961 .41237 .83195 .40852 .82679 .40138 Mtetra
.82679 .40138 .83195 .40852 .84435 .40466 .83923 .39749 Mtetra
.83923 .39749 .84435 .40466 .8568 .40078 .85171 .39358 Mtetra
.85171 .39358 .8568 .40078 .8693 .39689 .86426 .38965 Mtetra
.86426 .38965 .8693 .39689 .88186 .39297 .87685 .38571 Mtetra
.87685 .38571 .88186 .39297 .89447 .38904 .8895 .38175 Mtetra
.8895 .38175 .89447 .38904 .90713 .3851 .90221 .37777 Mtetra
.90221 .37777 .90713 .3851 .91985 .38114 .91497 .37377 Mtetra
.91497 .37377 .91985 .38114 .93263 .37715 .92778 .36976 Mtetra
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53508 Mtetra
.3737 .53508 .38013 .54122 .39072 .5379 .38431 .53174 Mtetra
.38431 .53174 .39072 .5379 .40135 .53457 .39497 .52839 Mtetra
.39497 .52839 .40135 .53457 .41203 .53123 .40568 .52502 Mtetra
.40568 .52502 .41203 .53123 .42275 .52787 .41642 .52164 Mtetra
.41642 .52164 .42275 .52787 .43351 .5245 .42721 .51825 Mtetra
.42721 .51825 .43351 .5245 .44432 .52112 .43804 .51484 Mtetra
.43804 .51484 .44432 .52112 .45516 .51772 .44892 .51142 Mtetra
.44892 .51142 .45516 .51772 .46605 .51431 .45984 .50798 Mtetra
.45984 .50798 .46605 .51431 .47699 .51089 .4708 .50453 Mtetra
.4708 .50453 .47699 .51089 .48797 .50745 .48181 .50107 Mtetra
.48181 .50107 .48797 .50745 .49899 .504 .49286 .49759 Mtetra
.49286 .49759 .49899 .504 .51006 .50054 .50396 .4941 Mtetra
.50396 .4941 .51006 .50054 .52117 .49706 .5151 .4906 Mtetra
.5151 .4906 .52117 .49706 .53233 .49357 .52629 .48708 Mtetra
.52629 .48708 .53233 .49357 .54353 .49006 .53752 .48355 Mtetra
.53752 .48355 .54353 .49006 .55478 .48654 .5488 .48 Mtetra
.5488 .48 .55478 .48654 .56608 .483 .56013 .47643 Mtetra
.56013 .47643 .56608 .483 .57742 .47945 .5715 .47286 Mtetra
.5715 .47286 .57742 .47945 .58881 .47588 .58292 .46926 Mtetra
.58292 .46926 .58881 .47588 .60024 .4723 .59438 .46566 Mtetra
.59438 .46566 .60024 .4723 .61172 .46871 .6059 .46203 Mtetra
.6059 .46203 .61172 .46871 .62325 .4651 .61746 .4584 Mtetra
.61746 .4584 .62325 .4651 .63483 .46148 .62907 .45475 Mtetra
.62907 .45475 .63483 .46148 .64645 .45784 .64072 .45108 Mtetra
.64072 .45108 .64645 .45784 .65813 .45418 .65243 .4474 Mtetra
.65243 .4474 .65813 .45418 .66985 .45051 .66418 .4437 Mtetra
.66418 .4437 .66985 .45051 .68162 .44683 .67599 .43998 Mtetra
.67599 .43998 .68162 .44683 .69344 .44313 .68784 .43626 Mtetra
.68784 .43626 .69344 .44313 .70531 .43941 .69975 .43251 Mtetra
.69975 .43251 .70531 .43941 .71723 .43568 .7117 .42875 Mtetra
.7117 .42875 .71723 .43568 .7292 .43193 .7237 .42497 Mtetra
.7237 .42497 .7292 .43193 .74122 .42817 .73576 .42118 Mtetra
.73576 .42118 .74122 .42817 .75329 .42439 .74786 .41737 Mtetra
.74786 .41737 .75329 .42439 .76541 .4206 .76002 .41355 Mtetra
.76002 .41355 .76541 .4206 .77758 .41679 .77223 .40971 Mtetra
.77223 .40971 .77758 .41679 .7898 .41296 .78449 .40585 Mtetra
.78449 .40585 .7898 .41296 .80208 .40912 .79681 .40198 Mtetra
.79681 .40198 .80208 .40912 .81441 .40526 .80917 .39809 Mtetra
.80917 .39809 .81441 .40526 .82679 .40138 .82159 .39418 Mtetra
.82159 .39418 .82679 .40138 .83923 .39749 .83406 .39025 Mtetra
.83406 .39025 .83923 .39749 .85171 .39358 .84659 .38631 Mtetra
.84659 .38631 .85171 .39358 .86426 .38965 .85917 .38236 Mtetra
.85917 .38236 .86426 .38965 .87685 .38571 .87181 .37838 Mtetra
.87181 .37838 .87685 .38571 .8895 .38175 .8845 .37439 Mtetra
.8845 .37439 .8895 .38175 .90221 .37777 .89724 .37038 Mtetra
.89724 .37038 .90221 .37777 .91497 .37377 .91004 .36635 Mtetra
.91004 .36635 .91497 .37377 .92778 .36976 .9229 .36231 Mtetra
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53508 .36722 .52891 Mtetra
.36722 .52891 .3737 .53508 .38431 .53174 .37786 .52554 Mtetra
.37786 .52554 .38431 .53174 .39497 .52839 .38855 .52216 Mtetra
.38855 .52216 .39497 .52839 .40568 .52502 .39928 .51877 Mtetra
.39928 .51877 .40568 .52502 .41642 .52164 .41005 .51537 Mtetra
.41005 .51537 .41642 .52164 .42721 .51825 .42087 .51195 Mtetra
.42087 .51195 .42721 .51825 .43804 .51484 .43173 .50851 Mtetra
.43173 .50851 .43804 .51484 .44892 .51142 .44263 .50507 Mtetra
.44263 .50507 .44892 .51142 .45984 .50798 .45358 .50161 Mtetra
.45358 .50161 .45984 .50798 .4708 .50453 .46457 .49813 Mtetra
.46457 .49813 .4708 .50453 .48181 .50107 .4756 .49464 Mtetra
.4756 .49464 .48181 .50107 .49286 .49759 .48668 .49114 Mtetra
.48668 .49114 .49286 .49759 .50396 .4941 .49781 .48762 Mtetra
.49781 .48762 .50396 .4941 .5151 .4906 .50898 .48409 Mtetra
.50898 .48409 .5151 .4906 .52629 .48708 .5202 .48054 Mtetra
.5202 .48054 .52629 .48708 .53752 .48355 .53146 .47698 Mtetra
.53146 .47698 .53752 .48355 .5488 .48 .54277 .47341 Mtetra
.54277 .47341 .5488 .48 .56013 .47643 .55413 .46982 Mtetra
.55413 .46982 .56013 .47643 .5715 .47286 .56553 .46621 Mtetra
.56553 .46621 .5715 .47286 .58292 .46926 .57698 .46259 Mtetra
.57698 .46259 .58292 .46926 .59438 .46566 .58848 .45896 Mtetra
.58848 .45896 .59438 .46566 .6059 .46203 .60002 .45531 Mtetra
.60002 .45531 .6059 .46203 .61746 .4584 .61162 .45164 Mtetra
.61162 .45164 .61746 .4584 .62907 .45475 .62326 .44796 Mtetra
.62326 .44796 .62907 .45475 .64072 .45108 .63495 .44427 Mtetra
.63495 .44427 .64072 .45108 .65243 .4474 .64669 .44056 Mtetra
.64669 .44056 .65243 .4474 .66418 .4437 .65848 .43683 Mtetra
.65848 .43683 .66418 .4437 .67599 .43998 .67031 .43309 Mtetra
.67031 .43309 .67599 .43998 .68784 .43626 .6822 .42933 Mtetra
.6822 .42933 .68784 .43626 .69975 .43251 .69414 .42556 Mtetra
.69414 .42556 .69975 .43251 .7117 .42875 .70613 .42177 Mtetra
.70613 .42177 .7117 .42875 .7237 .42497 .71817 .41796 Mtetra
.71817 .41796 .7237 .42497 .73576 .42118 .73026 .41414 Mtetra
.73026 .41414 .73576 .42118 .74786 .41737 .7424 .4103 Mtetra
.7424 .4103 .74786 .41737 .76002 .41355 .75459 .40644 Mtetra
.75459 .40644 .76002 .41355 .77223 .40971 .76684 .40257 Mtetra
.76684 .40257 .77223 .40971 .78449 .40585 .77914 .39869 Mtetra
.77914 .39869 .78449 .40585 .79681 .40198 .79149 .39478 Mtetra
.79149 .39478 .79681 .40198 .80917 .39809 .80389 .39086 Mtetra
.80389 .39086 .80917 .39809 .82159 .39418 .81635 .38692 Mtetra
.81635 .38692 .82159 .39418 .83406 .39025 .82886 .38297 Mtetra
.82886 .38297 .83406 .39025 .84659 .38631 .84143 .37899 Mtetra
.84143 .37899 .84659 .38631 .85917 .38236 .85405 .375 Mtetra
.85405 .375 .85917 .38236 .87181 .37838 .86672 .371 Mtetra
.86672 .371 .87181 .37838 .8845 .37439 .87945 .36697 Mtetra
.87945 .36697 .8845 .37439 .89724 .37038 .89224 .36293 Mtetra
.89224 .36293 .89724 .37038 .91004 .36635 .90508 .35887 Mtetra
.90508 .35887 .91004 .36635 .9229 .36231 .91798 .35479 Mtetra
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52268 Mtetra
.36069 .52268 .36722 .52891 .37786 .52554 .37136 .51929 Mtetra
.37136 .51929 .37786 .52554 .38855 .52216 .38207 .51589 Mtetra
.38207 .51589 .38855 .52216 .39928 .51877 .39283 .51247 Mtetra
.39283 .51247 .39928 .51877 .41005 .51537 .40363 .50904 Mtetra
.40363 .50904 .41005 .51537 .42087 .51195 .41447 .5056 Mtetra
.41447 .5056 .42087 .51195 .43173 .50851 .42536 .50214 Mtetra
.42536 .50214 .43173 .50851 .44263 .50507 .43629 .49867 Mtetra
.43629 .49867 .44263 .50507 .45358 .50161 .44727 .49518 Mtetra
.44727 .49518 .45358 .50161 .46457 .49813 .45829 .49168 Mtetra
.45829 .49168 .46457 .49813 .4756 .49464 .46935 .48816 Mtetra
.46935 .48816 .4756 .49464 .48668 .49114 .48046 .48463 Mtetra
.48046 .48463 .48668 .49114 .49781 .48762 .49162 .48109 Mtetra
.49162 .48109 .49781 .48762 .50898 .48409 .50282 .47753 Mtetra
.50282 .47753 .50898 .48409 .5202 .48054 .51406 .47396 Mtetra
.51406 .47396 .5202 .48054 .53146 .47698 .52536 .47037 Mtetra
.52536 .47037 .53146 .47698 .54277 .47341 .5367 .46677 Mtetra
.5367 .46677 .54277 .47341 .55413 .46982 .54809 .46315 Mtetra
.54809 .46315 .55413 .46982 .56553 .46621 .55952 .45952 Mtetra
.55952 .45952 .56553 .46621 .57698 .46259 .571 .45587 Mtetra
.571 .45587 .57698 .46259 .58848 .45896 .58253 .45221 Mtetra
.58253 .45221 .58848 .45896 .60002 .45531 .59411 .44853 Mtetra
.59411 .44853 .60002 .45531 .61162 .45164 .60573 .44484 Mtetra
.60573 .44484 .61162 .45164 .62326 .44796 .61741 .44113 Mtetra
.61741 .44113 .62326 .44796 .63495 .44427 .62913 .4374 Mtetra
.62913 .4374 .63495 .44427 .64669 .44056 .6409 .43366 Mtetra
.6409 .43366 .64669 .44056 .65848 .43683 .65272 .42991 Mtetra
.65272 .42991 .65848 .43683 .67031 .43309 .6646 .42614 Mtetra
.6646 .42614 .67031 .43309 .6822 .42933 .67652 .42235 Mtetra
.67652 .42235 .6822 .42933 .69414 .42556 .68849 .41855 Mtetra
.68849 .41855 .69414 .42556 .70613 .42177 .70051 .41473 Mtetra
.70051 .41473 .70613 .42177 .71817 .41796 .71259 .41089 Mtetra
.71259 .41089 .71817 .41796 .73026 .41414 .72471 .40704 Mtetra
.72471 .40704 .73026 .41414 .7424 .4103 .73689 .40317 Mtetra
.73689 .40317 .7424 .4103 .75459 .40644 .74912 .39928 Mtetra
.74912 .39928 .75459 .40644 .76684 .40257 .76141 .39538 Mtetra
.76141 .39538 .76684 .40257 .77914 .39869 .77374 .39146 Mtetra
.77374 .39146 .77914 .39869 .79149 .39478 .78613 .38753 Mtetra
.78613 .38753 .79149 .39478 .80389 .39086 .79857 .38358 Mtetra
.79857 .38358 .80389 .39086 .81635 .38692 .81107 .37961 Mtetra
.81107 .37961 .81635 .38692 .82886 .38297 .82362 .37562 Mtetra
.82362 .37562 .82886 .38297 .84143 .37899 .83622 .37161 Mtetra
.83622 .37161 .84143 .37899 .85405 .375 .84888 .36759 Mtetra
.84888 .36759 .85405 .375 .86672 .371 .8616 .36355 Mtetra
.8616 .36355 .86672 .371 .87945 .36697 .87437 .3595 Mtetra
.87437 .3595 .87945 .36697 .89224 .36293 .88719 .35542 Mtetra
.88719 .35542 .89224 .36293 .90508 .35887 .90008 .35133 Mtetra
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .5232 Mtetra
.33285 .5232 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52268 .35411 .51641 Mtetra
.35411 .51641 .36069 .52268 .37136 .51929 .36481 .513 Mtetra
.36481 .513 .37136 .51929 .38207 .51589 .37555 .50957 Mtetra
.37555 .50957 .38207 .51589 .39283 .51247 .38633 .50613 Mtetra
.38633 .50613 .39283 .51247 .40363 .50904 .39716 .50267 Mtetra
.39716 .50267 .40363 .50904 .41447 .5056 .40803 .4992 Mtetra
.40803 .4992 .41447 .5056 .42536 .50214 .41895 .49572 Mtetra
.41895 .49572 .42536 .50214 .43629 .49867 .42991 .49222 Mtetra
.42991 .49222 .43629 .49867 .44727 .49518 .44091 .48871 Mtetra
.44091 .48871 .44727 .49518 .45829 .49168 .45196 .48518 Mtetra
.45196 .48518 .45829 .49168 .46935 .48816 .46305 .48164 Mtetra
.46305 .48164 .46935 .48816 .48046 .48463 .47419 .47808 Mtetra
.47419 .47808 .48046 .48463 .49162 .48109 .48538 .47451 Mtetra
.48538 .47451 .49162 .48109 .50282 .47753 .49661 .47092 Mtetra
.49661 .47092 .50282 .47753 .51406 .47396 .50788 .46732 Mtetra
.50788 .46732 .51406 .47396 .52536 .47037 .51921 .46371 Mtetra
.51921 .46371 .52536 .47037 .5367 .46677 .53058 .46008 Mtetra
.53058 .46008 .5367 .46677 .54809 .46315 .542 .45643 Mtetra
.542 .45643 .54809 .46315 .55952 .45952 .55346 .45277 Mtetra
.55346 .45277 .55952 .45952 .571 .45587 .56497 .4491 Mtetra
.56497 .4491 .571 .45587 .58253 .45221 .57654 .44541 Mtetra
.57654 .44541 .58253 .45221 .59411 .44853 .58814 .4417 Mtetra
.58814 .4417 .59411 .44853 .60573 .44484 .5998 .43798 Mtetra
.5998 .43798 .60573 .44484 .61741 .44113 .61151 .43424 Mtetra
.61151 .43424 .61741 .44113 .62913 .4374 .62327 .43049 Mtetra
.62327 .43049 .62913 .4374 .6409 .43366 .63507 .42672 Mtetra
.63507 .42672 .6409 .43366 .65272 .42991 .64693 .42293 Mtetra
.64693 .42293 .65272 .42991 .6646 .42614 .65883 .41913 Mtetra
.65883 .41913 .6646 .42614 .67652 .42235 .67079 .41532 Mtetra
.67079 .41532 .67652 .42235 .68849 .41855 .6828 .41148 Mtetra
.6828 .41148 .68849 .41855 .70051 .41473 .69486 .40763 Mtetra
.69486 .40763 .70051 .41473 .71259 .41089 .70697 .40377 Mtetra
.70697 .40377 .71259 .41089 .72471 .40704 .71913 .39988 Mtetra
.71913 .39988 .72471 .40704 .73689 .40317 .73134 .39598 Mtetra
.73134 .39598 .73689 .40317 .74912 .39928 .74361 .39207 Mtetra
.74361 .39207 .74912 .39928 .76141 .39538 .75593 .38814 Mtetra
.75593 .38814 .76141 .39538 .77374 .39146 .7683 .38419 Mtetra
.7683 .38419 .77374 .39146 .78613 .38753 .78073 .38022 Mtetra
.78073 .38022 .78613 .38753 .79857 .38358 .79321 .37623 Mtetra
.79321 .37623 .79857 .38358 .81107 .37961 .80574 .37223 Mtetra
.80574 .37223 .81107 .37961 .82362 .37562 .81833 .36821 Mtetra
.81833 .36821 .82362 .37562 .83622 .37161 .83097 .36418 Mtetra
.83097 .36418 .83622 .37161 .84888 .36759 .84367 .36012 Mtetra
.84367 .36012 .84888 .36759 .8616 .36355 .85643 .35605 Mtetra
.85643 .35605 .8616 .36355 .87437 .3595 .86924 .35196 Mtetra
.86924 .35196 .87437 .3595 .88719 .35542 .88211 .34785 Mtetra
.88211 .34785 .88719 .35542 .90008 .35133 .89503 .34373 Mtetra
.89503 .34373 .90008 .35133 .91302 .34722 .90801 .33958 Mtetra
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .34346 .51982 .33681 .51353 Mtetra
.33681 .51353 .34346 .51982 .35411 .51641 .34749 .5101 Mtetra
.34749 .5101 .35411 .51641 .36481 .513 .35821 .50666 Mtetra
.35821 .50666 .36481 .513 .37555 .50957 .36898 .5032 Mtetra
.36898 .5032 .37555 .50957 .38633 .50613 .37979 .49974 Mtetra
.37979 .49974 .38633 .50613 .39716 .50267 .39065 .49625 Mtetra
.39065 .49625 .39716 .50267 .40803 .4992 .40154 .49276 Mtetra
.40154 .49276 .40803 .4992 .41895 .49572 .41249 .48925 Mtetra
.41249 .48925 .41895 .49572 .42991 .49222 .42347 .48572 Mtetra
.42347 .48572 .42991 .49222 .44091 .48871 .4345 .48218 Mtetra
.4345 .48218 .44091 .48871 .45196 .48518 .44558 .47863 Mtetra
.44558 .47863 .45196 .48518 .46305 .48164 .4567 .47506 Mtetra
.4567 .47506 .46305 .48164 .47419 .47808 .46787 .47148 Mtetra
.46787 .47148 .47419 .47808 .48538 .47451 .47909 .46788 Mtetra
.47909 .46788 .48538 .47451 .49661 .47092 .49035 .46427 Mtetra
.49035 .46427 .49661 .47092 .50788 .46732 .50166 .46064 Mtetra
.50166 .46064 .50788 .46732 .51921 .46371 .51301 .45699 Mtetra
.51301 .45699 .51921 .46371 .53058 .46008 .52441 .45334 Mtetra
.52441 .45334 .53058 .46008 .542 .45643 .53586 .44966 Mtetra
.53586 .44966 .542 .45643 .55346 .45277 .54736 .44598 Mtetra
.54736 .44598 .55346 .45277 .56497 .4491 .5589 .44227 Mtetra
.5589 .44227 .56497 .4491 .57654 .44541 .57049 .43855 Mtetra
.57049 .43855 .57654 .44541 .58814 .4417 .58214 .43482 Mtetra
.58214 .43482 .58814 .4417 .5998 .43798 .59383 .43107 Mtetra
.59383 .43107 .5998 .43798 .61151 .43424 .60557 .4273 Mtetra
.60557 .4273 .61151 .43424 .62327 .43049 .61736 .42352 Mtetra
.61736 .42352 .62327 .43049 .63507 .42672 .6292 .41972 Mtetra
.6292 .41972 .63507 .42672 .64693 .42293 .64109 .4159 Mtetra
.64109 .4159 .64693 .42293 .65883 .41913 .65303 .41207 Mtetra
.65303 .41207 .65883 .41913 .67079 .41532 .66502 .40823 Mtetra
.66502 .40823 .67079 .41532 .6828 .41148 .67706 .40436 Mtetra
.67706 .40436 .6828 .41148 .69486 .40763 .68915 .40048 Mtetra
.68915 .40048 .69486 .40763 .70697 .40377 .7013 .39659 Mtetra
.7013 .39659 .70697 .40377 .71913 .39988 .7135 .39267 Mtetra
.7135 .39267 .71913 .39988 .73134 .39598 .72575 .38874 Mtetra
.72575 .38874 .73134 .39598 .74361 .39207 .73805 .38479 Mtetra
.73805 .38479 .74361 .39207 .75593 .38814 .75041 .38083 Mtetra
.75041 .38083 .75593 .38814 .7683 .38419 .76282 .37685 Mtetra
.76282 .37685 .7683 .38419 .78073 .38022 .77528 .37285 Mtetra
.77528 .37285 .78073 .38022 .79321 .37623 .7878 .36883 Mtetra
.7878 .36883 .79321 .37623 .80574 .37223 .80037 .3648 Mtetra
.80037 .3648 .80574 .37223 .81833 .36821 .813 .36075 Mtetra
.813 .36075 .81833 .36821 .83097 .36418 .82568 .35668 Mtetra
.82568 .35668 .83097 .36418 .84367 .36012 .83842 .35259 Mtetra
.83842 .35259 .84367 .36012 .85643 .35605 .85122 .34849 Mtetra
.85122 .34849 .85643 .35605 .86924 .35196 .86407 .34436 Mtetra
.86407 .34436 .86924 .35196 .88211 .34785 .87698 .34022 Mtetra
.87698 .34022 .88211 .34785 .89503 .34373 .88994 .33606 Mtetra
.88994 .33606 .89503 .34373 .90801 .33958 .90297 .33188 Mtetra
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.34082 .50374 .34749 .5101 .35821 .50666 .35157 .50027 Mtetra
.35157 .50027 .35821 .50666 .36898 .5032 .36236 .49679 Mtetra
.36236 .49679 .36898 .5032 .37979 .49974 .3732 .4933 Mtetra
.3732 .4933 .37979 .49974 .39065 .49625 .38408 .48979 Mtetra
.38408 .48979 .39065 .49625 .40154 .49276 .39501 .48626 Mtetra
.39501 .48626 .40154 .49276 .41249 .48925 .40598 .48273 Mtetra
.40598 .48273 .41249 .48925 .42347 .48572 .41699 .47918 Mtetra
.41699 .47918 .42347 .48572 .4345 .48218 .42805 .47561 Mtetra
.42805 .47561 .4345 .48218 .44558 .47863 .43916 .47203 Mtetra
.43916 .47203 .44558 .47863 .4567 .47506 .45031 .46843 Mtetra
.45031 .46843 .4567 .47506 .46787 .47148 .46151 .46482 Mtetra
.46151 .46482 .46787 .47148 .47909 .46788 .47275 .4612 Mtetra
.47275 .4612 .47909 .46788 .49035 .46427 .48404 .45756 Mtetra
.48404 .45756 .49035 .46427 .50166 .46064 .49538 .4539 Mtetra
.49538 .4539 .50166 .46064 .51301 .45699 .50676 .45023 Mtetra
.50676 .45023 .51301 .45699 .52441 .45334 .5182 .44654 Mtetra
.5182 .44654 .52441 .45334 .53586 .44966 .52968 .44284 Mtetra
.52968 .44284 .53586 .44966 .54736 .44598 .5412 .43913 Mtetra
.5412 .43913 .54736 .44598 .5589 .44227 .55278 .43539 Mtetra
.55278 .43539 .5589 .44227 .57049 .43855 .56441 .43164 Mtetra
.56441 .43164 .57049 .43855 .58214 .43482 .57608 .42788 Mtetra
.57608 .42788 .58214 .43482 .59383 .43107 .5878 .4241 Mtetra
.5878 .4241 .59383 .43107 .60557 .4273 .59958 .4203 Mtetra
.59958 .4203 .60557 .4273 .61736 .42352 .6114 .41649 Mtetra
.6114 .41649 .61736 .42352 .6292 .41972 .62327 .41266 Mtetra
.62327 .41266 .6292 .41972 .64109 .4159 .6352 .40882 Mtetra
.6352 .40882 .64109 .4159 .65303 .41207 .64717 .40496 Mtetra
.64717 .40496 .65303 .41207 .66502 .40823 .6592 .40108 Mtetra
.6592 .40108 .66502 .40823 .67706 .40436 .67128 .39719 Mtetra
.67128 .39719 .67706 .40436 .68915 .40048 .6834 .39327 Mtetra
.6834 .39327 .68915 .40048 .7013 .39659 .69559 .38935 Mtetra
.69559 .38935 .7013 .39659 .7135 .39267 .70782 .3854 Mtetra
.70782 .3854 .7135 .39267 .72575 .38874 .72011 .38144 Mtetra
.72011 .38144 .72575 .38874 .73805 .38479 .73245 .37746 Mtetra
.73245 .37746 .73805 .38479 .75041 .38083 .74484 .37347 Mtetra
.74484 .37347 .75041 .38083 .76282 .37685 .75729 .36945 Mtetra
.75729 .36945 .76282 .37685 .77528 .37285 .76979 .36542 Mtetra
.76979 .36542 .77528 .37285 .7878 .36883 .78235 .36137 Mtetra
.78235 .36137 .7878 .36883 .80037 .3648 .79496 .35731 Mtetra
.79496 .35731 .80037 .3648 .813 .36075 .80763 .35322 Mtetra
.80763 .35322 .813 .36075 .82568 .35668 .82035 .34912 Mtetra
.82035 .34912 .82568 .35668 .83842 .35259 .83313 .345 Mtetra
.83313 .345 .83842 .35259 .85122 .34849 .84597 .34086 Mtetra
.84597 .34086 .85122 .34849 .86407 .34436 .85886 .3367 Mtetra
.85886 .3367 .86407 .34436 .87698 .34022 .87181 .33253 Mtetra
.87181 .33253 .87698 .34022 .88994 .33606 .88482 .32833 Mtetra
.88482 .32833 .88994 .33606 .90297 .33188 .89788 .32412 Mtetra
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .5008 Mtetra
.32336 .5008 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49383 Mtetra
.34487 .49383 .35157 .50027 .36236 .49679 .35569 .49033 Mtetra
.35569 .49033 .36236 .49679 .3732 .4933 .36656 .48681 Mtetra
.36656 .48681 .3732 .4933 .38408 .48979 .37746 .48327 Mtetra
.37746 .48327 .38408 .48979 .39501 .48626 .38842 .47972 Mtetra
.38842 .47972 .39501 .48626 .40598 .48273 .39942 .47616 Mtetra
.39942 .47616 .40598 .48273 .41699 .47918 .41046 .47258 Mtetra
.41046 .47258 .41699 .47918 .42805 .47561 .42155 .46899 Mtetra
.42155 .46899 .42805 .47561 .43916 .47203 .43268 .46538 Mtetra
.43268 .46538 .43916 .47203 .45031 .46843 .44386 .46176 Mtetra
.44386 .46176 .45031 .46843 .46151 .46482 .45509 .45812 Mtetra
.45509 .45812 .46151 .46482 .47275 .4612 .46637 .45446 Mtetra
.46637 .45446 .47275 .4612 .48404 .45756 .47769 .4508 Mtetra
.47769 .4508 .48404 .45756 .49538 .4539 .48905 .44711 Mtetra
.48905 .44711 .49538 .4539 .50676 .45023 .50047 .44341 Mtetra
.50047 .44341 .50676 .45023 .5182 .44654 .51193 .4397 Mtetra
.51193 .4397 .5182 .44654 .52968 .44284 .52344 .43597 Mtetra
.52344 .43597 .52968 .44284 .5412 .43913 .535 .43222 Mtetra
.535 .43222 .5412 .43913 .55278 .43539 .54661 .42846 Mtetra
.54661 .42846 .55278 .43539 .56441 .43164 .55827 .42468 Mtetra
.55827 .42468 .56441 .43164 .57608 .42788 .56998 .42089 Mtetra
.56998 .42089 .57608 .42788 .5878 .4241 .58173 .41708 Mtetra
.58173 .41708 .5878 .4241 .59958 .4203 .59354 .41325 Mtetra
.59354 .41325 .59958 .4203 .6114 .41649 .6054 .40941 Mtetra
.6054 .40941 .6114 .41649 .62327 .41266 .6173 .40555 Mtetra
.6173 .40555 .62327 .41266 .6352 .40882 .62926 .40168 Mtetra
.62926 .40168 .6352 .40882 .64717 .40496 .64127 .39779 Mtetra
.64127 .39779 .64717 .40496 .6592 .40108 .65333 .39388 Mtetra
.65333 .39388 .6592 .40108 .67128 .39719 .66545 .38995 Mtetra
.66545 .38995 .67128 .39719 .6834 .39327 .67761 .38601 Mtetra
.67761 .38601 .6834 .39327 .69559 .38935 .68983 .38205 Mtetra
.68983 .38205 .69559 .38935 .70782 .3854 .7021 .37807 Mtetra
.7021 .37807 .70782 .3854 .72011 .38144 .71442 .37408 Mtetra
.71442 .37408 .72011 .38144 .73245 .37746 .7268 .37007 Mtetra
.7268 .37007 .73245 .37746 .74484 .37347 .73923 .36604 Mtetra
.73923 .36604 .74484 .37347 .75729 .36945 .75172 .362 Mtetra
.75172 .362 .75729 .36945 .76979 .36542 .76426 .35793 Mtetra
.76426 .35793 .76979 .36542 .78235 .36137 .77685 .35385 Mtetra
.77685 .35385 .78235 .36137 .79496 .35731 .78951 .34975 Mtetra
.78951 .34975 .79496 .35731 .80763 .35322 .80221 .34563 Mtetra
.80221 .34563 .80763 .35322 .82035 .34912 .81498 .3415 Mtetra
.81498 .3415 .82035 .34912 .83313 .345 .82779 .33734 Mtetra
.82779 .33734 .83313 .345 .84597 .34086 .84067 .33317 Mtetra
.84067 .33317 .84597 .34086 .85886 .3367 .8536 .32898 Mtetra
.8536 .32898 .85886 .3367 .87181 .33253 .8666 .32477 Mtetra
.8666 .32477 .87181 .33253 .88482 .32833 .87965 .32054 Mtetra
.87965 .32054 .88482 .32833 .89788 .32412 .89275 .31629 Mtetra
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49786 Mtetra
.30585 .49786 .31267 .50427 .32336 .5008 .31656 .49437 Mtetra
.31656 .49437 .32336 .5008 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49383 .33812 .48735 Mtetra
.33812 .48735 .34487 .49383 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36656 .48681 .35986 .48027 Mtetra
.35986 .48027 .36656 .48681 .37746 .48327 .3708 .47671 Mtetra
.3708 .47671 .37746 .48327 .38842 .47972 .38178 .47313 Mtetra
.38178 .47313 .38842 .47972 .39942 .47616 .39281 .46954 Mtetra
.39281 .46954 .39942 .47616 .41046 .47258 .40388 .46593 Mtetra
.40388 .46593 .41046 .47258 .42155 .46899 .415 .46231 Mtetra
.415 .46231 .42155 .46899 .43268 .46538 .42616 .45868 Mtetra
.42616 .45868 .43268 .46538 .44386 .46176 .43737 .45503 Mtetra
.43737 .45503 .44386 .46176 .45509 .45812 .44863 .45136 Mtetra
.44863 .45136 .45509 .45812 .46637 .45446 .45993 .44768 Mtetra
.45993 .44768 .46637 .45446 .47769 .4508 .47128 .44398 Mtetra
.47128 .44398 .47769 .4508 .48905 .44711 .48268 .44027 Mtetra
.48268 .44027 .48905 .44711 .50047 .44341 .49413 .43654 Mtetra
.49413 .43654 .50047 .44341 .51193 .4397 .50562 .4328 Mtetra
.50562 .4328 .51193 .4397 .52344 .43597 .51716 .42904 Mtetra
.51716 .42904 .52344 .43597 .535 .43222 .52876 .42526 Mtetra
.52876 .42526 .535 .43222 .54661 .42846 .5404 .42147 Mtetra
.5404 .42147 .54661 .42846 .55827 .42468 .55209 .41767 Mtetra
.55209 .41767 .55827 .42468 .56998 .42089 .56383 .41384 Mtetra
.56383 .41384 .56998 .42089 .58173 .41708 .57562 .41 Mtetra
.57562 .41 .58173 .41708 .59354 .41325 .58746 .40615 Mtetra
.58746 .40615 .59354 .41325 .6054 .40941 .59935 .40227 Mtetra
.59935 .40227 .6054 .40941 .6173 .40555 .61129 .39839 Mtetra
.61129 .39839 .6173 .40555 .62926 .40168 .62328 .39448 Mtetra
.62328 .39448 .62926 .40168 .64127 .39779 .63532 .39056 Mtetra
.63532 .39056 .64127 .39779 .65333 .39388 .64742 .38662 Mtetra
.64742 .38662 .65333 .39388 .66545 .38995 .65957 .38266 Mtetra
.65957 .38266 .66545 .38995 .67761 .38601 .67177 .37869 Mtetra
.67177 .37869 .67761 .38601 .68983 .38205 .68402 .3747 Mtetra
.68402 .3747 .68983 .38205 .7021 .37807 .69633 .37069 Mtetra
.69633 .37069 .7021 .37807 .71442 .37408 .70869 .36666 Mtetra
.70869 .36666 .71442 .37408 .7268 .37007 .72111 .36262 Mtetra
.72111 .36262 .7268 .37007 .73923 .36604 .73358 .35856 Mtetra
.73358 .35856 .73923 .36604 .75172 .362 .7461 .35448 Mtetra
.7461 .35448 .75172 .362 .76426 .35793 .75868 .35038 Mtetra
.75868 .35038 .76426 .35793 .77685 .35385 .77131 .34627 Mtetra
.77131 .34627 .77685 .35385 .78951 .34975 .78401 .34213 Mtetra
.78401 .34213 .78951 .34975 .80221 .34563 .79675 .33798 Mtetra
.79675 .33798 .80221 .34563 .81498 .3415 .80955 .33381 Mtetra
.80955 .33381 .81498 .3415 .82779 .33734 .82241 .32963 Mtetra
.82241 .32963 .82779 .33734 .84067 .33317 .83533 .32542 Mtetra
.83533 .32542 .84067 .33317 .8536 .32898 .84831 .32119 Mtetra
.84831 .32119 .8536 .32898 .8666 .32477 .86134 .31695 Mtetra
.86134 .31695 .8666 .32477 .87965 .32054 .87443 .31268 Mtetra
.87443 .31268 .87965 .32054 .89275 .31629 .88758 .3084 Mtetra
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .3708 .47671 .36408 .47009 Mtetra
.36408 .47009 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.37509 .46649 .38178 .47313 .39281 .46954 .38615 .46287 Mtetra
.38615 .46287 .39281 .46954 .40388 .46593 .39725 .45924 Mtetra
.39725 .45924 .40388 .46593 .415 .46231 .4084 .45559 Mtetra
.4084 .45559 .415 .46231 .42616 .45868 .41959 .45193 Mtetra
.41959 .45193 .42616 .45868 .43737 .45503 .43083 .44825 Mtetra
.43083 .44825 .43737 .45503 .44863 .45136 .44211 .44455 Mtetra
.44211 .44455 .44863 .45136 .45993 .44768 .45345 .44084 Mtetra
.45345 .44084 .45993 .44768 .47128 .44398 .46483 .43712 Mtetra
.46483 .43712 .47128 .44398 .48268 .44027 .47626 .43338 Mtetra
.47626 .43338 .48268 .44027 .49413 .43654 .48774 .42962 Mtetra
.48774 .42962 .49413 .43654 .50562 .4328 .49926 .42585 Mtetra
.49926 .42585 .50562 .4328 .51716 .42904 .51084 .42206 Mtetra
.51084 .42206 .51716 .42904 .52876 .42526 .52246 .41825 Mtetra
.52246 .41825 .52876 .42526 .5404 .42147 .53413 .41443 Mtetra
.53413 .41443 .5404 .42147 .55209 .41767 .54585 .4106 Mtetra
.54585 .4106 .55209 .41767 .56383 .41384 .55763 .40674 Mtetra
.55763 .40674 .56383 .41384 .57562 .41 .56945 .40287 Mtetra
.56945 .40287 .57562 .41 .58746 .40615 .58132 .39899 Mtetra
.58132 .39899 .58746 .40615 .59935 .40227 .59325 .39508 Mtetra
.59325 .39508 .59935 .40227 .61129 .39839 .60522 .39116 Mtetra
.60522 .39116 .61129 .39839 .62328 .39448 .61725 .38723 Mtetra
.61725 .38723 .62328 .39448 .63532 .39056 .62933 .38327 Mtetra
.62933 .38327 .63532 .39056 .64742 .38662 .64146 .3793 Mtetra
.64146 .3793 .64742 .38662 .65957 .38266 .65365 .37531 Mtetra
.65365 .37531 .65957 .38266 .67177 .37869 .66588 .37131 Mtetra
.66588 .37131 .67177 .37869 .68402 .3747 .67817 .36728 Mtetra
.67817 .36728 .68402 .3747 .69633 .37069 .69052 .36324 Mtetra
.69052 .36324 .69633 .37069 .70869 .36666 .70292 .35918 Mtetra
.70292 .35918 .70869 .36666 .72111 .36262 .71537 .35511 Mtetra
.71537 .35511 .72111 .36262 .73358 .35856 .72788 .35101 Mtetra
.72788 .35101 .73358 .35856 .7461 .35448 .74044 .3469 Mtetra
.74044 .3469 .7461 .35448 .75868 .35038 .75306 .34277 Mtetra
.75306 .34277 .75868 .35038 .77131 .34627 .76573 .33862 Mtetra
.76573 .33862 .77131 .34627 .78401 .34213 .77846 .33446 Mtetra
.77846 .33446 .78401 .34213 .79675 .33798 .79125 .33027 Mtetra
.79125 .33027 .79675 .33798 .80955 .33381 .80409 .32607 Mtetra
.80409 .32607 .80955 .33381 .82241 .32963 .81699 .32184 Mtetra
.81699 .32184 .82241 .32963 .83533 .32542 .82995 .3176 Mtetra
.82995 .3176 .83533 .32542 .84831 .32119 .84297 .31334 Mtetra
.84297 .31334 .84831 .32119 .86134 .31695 .85604 .30906 Mtetra
.85604 .30906 .86134 .31695 .87443 .31268 .86918 .30476 Mtetra
.86918 .30476 .87443 .31268 .88758 .3084 .88237 .30044 Mtetra
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.34633 .46705 .35312 .47368 .36408 .47009 .35732 .46343 Mtetra
.35732 .46343 .36408 .47009 .37509 .46649 .36835 .4598 Mtetra
.36835 .4598 .37509 .46649 .38615 .46287 .37944 .45615 Mtetra
.37944 .45615 .38615 .46287 .39725 .45924 .39057 .45249 Mtetra
.39057 .45249 .39725 .45924 .4084 .45559 .40174 .44881 Mtetra
.40174 .44881 .4084 .45559 .41959 .45193 .41296 .44512 Mtetra
.41296 .44512 .41959 .45193 .43083 .44825 .42423 .44141 Mtetra
.42423 .44141 .43083 .44825 .44211 .44455 .43555 .43769 Mtetra
.43555 .43769 .44211 .44455 .45345 .44084 .44691 .43395 Mtetra
.44691 .43395 .45345 .44084 .46483 .43712 .45833 .4302 Mtetra
.45833 .4302 .46483 .43712 .47626 .43338 .46979 .42643 Mtetra
.46979 .42643 .47626 .43338 .48774 .42962 .48129 .42264 Mtetra
.48129 .42264 .48774 .42962 .49926 .42585 .49285 .41884 Mtetra
.49285 .41884 .49926 .42585 .51084 .42206 .50446 .41502 Mtetra
.50446 .41502 .51084 .42206 .52246 .41825 .51611 .41119 Mtetra
.51611 .41119 .52246 .41825 .53413 .41443 .52782 .40734 Mtetra
.52782 .40734 .53413 .41443 .54585 .4106 .53957 .40347 Mtetra
.53957 .40347 .54585 .4106 .55763 .40674 .55138 .39958 Mtetra
.55138 .39958 .55763 .40674 .56945 .40287 .56323 .39568 Mtetra
.56323 .39568 .56945 .40287 .58132 .39899 .57514 .39177 Mtetra
.57514 .39177 .58132 .39899 .59325 .39508 .5871 .38783 Mtetra
.5871 .38783 .59325 .39508 .60522 .39116 .59911 .38388 Mtetra
.59911 .38388 .60522 .39116 .61725 .38723 .61117 .37991 Mtetra
.61117 .37991 .61725 .38723 .62933 .38327 .62329 .37593 Mtetra
.62329 .37593 .62933 .38327 .64146 .3793 .63545 .37192 Mtetra
.63545 .37192 .64146 .3793 .65365 .37531 .64767 .3679 Mtetra
.64767 .3679 .65365 .37531 .66588 .37131 .65995 .36387 Mtetra
.65995 .36387 .66588 .37131 .67817 .36728 .67228 .35981 Mtetra
.67228 .35981 .67817 .36728 .69052 .36324 .68466 .35574 Mtetra
.68466 .35574 .69052 .36324 .70292 .35918 .69709 .35165 Mtetra
.69709 .35165 .70292 .35918 .71537 .35511 .70958 .34754 Mtetra
.70958 .34754 .71537 .35511 .72788 .35101 .72213 .34341 Mtetra
.72213 .34341 .72788 .35101 .74044 .3469 .73473 .33926 Mtetra
.73473 .33926 .74044 .3469 .75306 .34277 .74739 .3351 Mtetra
.74739 .3351 .75306 .34277 .76573 .33862 .7601 .33092 Mtetra
.7601 .33092 .76573 .33862 .77846 .33446 .77287 .32671 Mtetra
.77287 .32671 .77846 .33446 .79125 .33027 .7857 .32249 Mtetra
.7857 .32249 .79125 .33027 .80409 .32607 .79858 .31826 Mtetra
.79858 .31826 .80409 .32607 .81699 .32184 .81152 .314 Mtetra
.81152 .314 .81699 .32184 .82995 .3176 .82452 .30972 Mtetra
.82452 .30972 .82995 .3176 .84297 .31334 .83758 .30543 Mtetra
.83758 .30543 .84297 .31334 .85604 .30906 .8507 .30111 Mtetra
.8507 .30111 .85604 .30906 .86918 .30476 .86387 .29677 Mtetra
.86387 .29677 .86918 .30476 .88237 .30044 .87711 .29242 Mtetra
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.3285 .46399 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45671 Mtetra
.3505 .45671 .35732 .46343 .36835 .4598 .36156 .45306 Mtetra
.36156 .45306 .36835 .4598 .37944 .45615 .37268 .44938 Mtetra
.37268 .44938 .37944 .45615 .39057 .45249 .38383 .44569 Mtetra
.38383 .44569 .39057 .45249 .40174 .44881 .39504 .44199 Mtetra
.39504 .44199 .40174 .44881 .41296 .44512 .40629 .43827 Mtetra
.40629 .43827 .41296 .44512 .42423 .44141 .41759 .43453 Mtetra
.41759 .43453 .42423 .44141 .43555 .43769 .42893 .43078 Mtetra
.42893 .43078 .43555 .43769 .44691 .43395 .44033 .42701 Mtetra
.44033 .42701 .44691 .43395 .45833 .4302 .45177 .42323 Mtetra
.45177 .42323 .45833 .4302 .46979 .42643 .46326 .41943 Mtetra
.46326 .41943 .46979 .42643 .48129 .42264 .4748 .41561 Mtetra
.4748 .41561 .48129 .42264 .49285 .41884 .48639 .41178 Mtetra
.48639 .41178 .49285 .41884 .50446 .41502 .49803 .40793 Mtetra
.49803 .40793 .50446 .41502 .51611 .41119 .50972 .40406 Mtetra
.50972 .40406 .51611 .41119 .52782 .40734 .52145 .40018 Mtetra
.52145 .40018 .52782 .40734 .53957 .40347 .53324 .39628 Mtetra
.53324 .39628 .53957 .40347 .55138 .39958 .54508 .39237 Mtetra
.54508 .39237 .55138 .39958 .56323 .39568 .55697 .38844 Mtetra
.55697 .38844 .56323 .39568 .57514 .39177 .56891 .38449 Mtetra
.56891 .38449 .57514 .39177 .5871 .38783 .5809 .38052 Mtetra
.5809 .38052 .5871 .38783 .59911 .38388 .59295 .37654 Mtetra
.59295 .37654 .59911 .38388 .61117 .37991 .60505 .37254 Mtetra
.60505 .37254 .61117 .37991 .62329 .37593 .6172 .36852 Mtetra
.6172 .36852 .62329 .37593 .63545 .37192 .6294 .36449 Mtetra
.6294 .36449 .63545 .37192 .64767 .3679 .64166 .36043 Mtetra
.64166 .36043 .64767 .3679 .65995 .36387 .65397 .35636 Mtetra
.65397 .35636 .65995 .36387 .67228 .35981 .66633 .35228 Mtetra
.66633 .35228 .67228 .35981 .68466 .35574 .67875 .34817 Mtetra
.67875 .34817 .68466 .35574 .69709 .35165 .69122 .34404 Mtetra
.69122 .34404 .69709 .35165 .70958 .34754 .70375 .3399 Mtetra
.70375 .3399 .70958 .34754 .72213 .34341 .71633 .33574 Mtetra
.71633 .33574 .72213 .34341 .73473 .33926 .72897 .33156 Mtetra
.72897 .33156 .73473 .33926 .74739 .3351 .74167 .32736 Mtetra
.74167 .32736 .74739 .3351 .7601 .33092 .75442 .32315 Mtetra
.75442 .32315 .7601 .33092 .77287 .32671 .76723 .31891 Mtetra
.76723 .31891 .77287 .32671 .7857 .32249 .7801 .31465 Mtetra
.7801 .31465 .7857 .32249 .79858 .31826 .79302 .31038 Mtetra
.79302 .31038 .79858 .31826 .81152 .314 .80601 .30609 Mtetra
.80601 .30609 .81152 .314 .82452 .30972 .81905 .30177 Mtetra
.81905 .30177 .82452 .30972 .83758 .30543 .83215 .29744 Mtetra
.83215 .29744 .83758 .30543 .8507 .30111 .84531 .29309 Mtetra
.84531 .29309 .8507 .30111 .86387 .29677 .85853 .28872 Mtetra
.85853 .28872 .86387 .29677 .87711 .29242 .87181 .28433 Mtetra
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.33258 .45362 .33948 .46036 .3505 .45671 .34363 .44995 Mtetra
.34363 .44995 .3505 .45671 .36156 .45306 .35472 .44626 Mtetra
.35472 .44626 .36156 .45306 .37268 .44938 .36586 .44256 Mtetra
.36586 .44256 .37268 .44938 .38383 .44569 .37705 .43884 Mtetra
.37705 .43884 .38383 .44569 .39504 .44199 .38828 .4351 Mtetra
.38828 .4351 .39504 .44199 .40629 .43827 .39956 .43136 Mtetra
.39956 .43136 .40629 .43827 .41759 .43453 .41089 .42759 Mtetra
.41089 .42759 .41759 .43453 .42893 .43078 .42227 .42381 Mtetra
.42227 .42381 .42893 .43078 .44033 .42701 .43369 .42001 Mtetra
.43369 .42001 .44033 .42701 .45177 .42323 .44517 .4162 Mtetra
.44517 .4162 .45177 .42323 .46326 .41943 .45669 .41237 Mtetra
.45669 .41237 .46326 .41943 .4748 .41561 .46826 .40852 Mtetra
.46826 .40852 .4748 .41561 .48639 .41178 .47988 .40466 Mtetra
.47988 .40466 .48639 .41178 .49803 .40793 .49155 .40078 Mtetra
.49155 .40078 .49803 .40793 .50972 .40406 .50327 .39689 Mtetra
.50327 .39689 .50972 .40406 .52145 .40018 .51504 .39297 Mtetra
.51504 .39297 .52145 .40018 .53324 .39628 .52686 .38904 Mtetra
.52686 .38904 .53324 .39628 .54508 .39237 .53873 .3851 Mtetra
.53873 .3851 .54508 .39237 .55697 .38844 .55066 .38114 Mtetra
.55066 .38114 .55697 .38844 .56891 .38449 .56263 .37715 Mtetra
.56263 .37715 .56891 .38449 .5809 .38052 .57466 .37316 Mtetra
.57466 .37316 .5809 .38052 .59295 .37654 .58674 .36914 Mtetra
.58674 .36914 .59295 .37654 .60505 .37254 .59887 .36511 Mtetra
.59887 .36511 .60505 .37254 .6172 .36852 .61106 .36106 Mtetra
.61106 .36106 .6172 .36852 .6294 .36449 .62329 .35699 Mtetra
.62329 .35699 .6294 .36449 .64166 .36043 .63559 .35291 Mtetra
.63559 .35291 .64166 .36043 .65397 .35636 .64793 .3488 Mtetra
.64793 .3488 .65397 .35636 .66633 .35228 .66033 .34468 Mtetra
.66033 .34468 .66633 .35228 .67875 .34817 .67279 .34054 Mtetra
.67279 .34054 .67875 .34817 .69122 .34404 .6853 .33638 Mtetra
.6853 .33638 .69122 .34404 .70375 .3399 .69787 .3322 Mtetra
.69787 .3322 .70375 .3399 .71633 .33574 .71049 .32801 Mtetra
.71049 .32801 .71633 .33574 .72897 .33156 .72317 .3238 Mtetra
.72317 .3238 .72897 .33156 .74167 .32736 .73591 .31956 Mtetra
.73591 .31956 .74167 .32736 .75442 .32315 .7487 .31531 Mtetra
.7487 .31531 .75442 .32315 .76723 .31891 .76155 .31104 Mtetra
.76155 .31104 .76723 .31891 .7801 .31465 .77446 .30675 Mtetra
.77446 .30675 .7801 .31465 .79302 .31038 .78742 .30244 Mtetra
.78742 .30244 .79302 .31038 .80601 .30609 .80045 .29811 Mtetra
.80045 .29811 .80601 .30609 .81905 .30177 .81353 .29376 Mtetra
.81353 .29376 .81905 .30177 .83215 .29744 .82667 .28939 Mtetra
.82667 .28939 .83215 .29744 .84531 .29309 .83988 .285 Mtetra
.83988 .285 .84531 .29309 .85853 .28872 .85314 .2806 Mtetra
.85314 .2806 .85853 .28872 .87181 .28433 .86646 .27617 Mtetra
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
.3146 .45051 .32158 .45728 .33258 .45362 .32563 .44683 Mtetra
.32563 .44683 .33258 .45362 .34363 .44995 .3367 .44313 Mtetra
.3367 .44313 .34363 .44995 .35472 .44626 .34783 .43941 Mtetra
.34783 .43941 .35472 .44626 .36586 .44256 .35899 .43568 Mtetra
.35899 .43568 .36586 .44256 .37705 .43884 .37021 .43193 Mtetra
.37021 .43193 .37705 .43884 .38828 .4351 .38147 .42817 Mtetra
.38147 .42817 .38828 .4351 .39956 .43136 .39278 .42439 Mtetra
.39278 .42439 .39956 .43136 .41089 .42759 .40414 .4206 Mtetra
.40414 .4206 .41089 .42759 .42227 .42381 .41555 .41679 Mtetra
.41555 .41679 .42227 .42381 .43369 .42001 .427 .41296 Mtetra
.427 .41296 .43369 .42001 .44517 .4162 .43851 .40912 Mtetra
.43851 .40912 .44517 .4162 .45669 .41237 .45006 .40526 Mtetra
.45006 .40526 .45669 .41237 .46826 .40852 .46166 .40138 Mtetra
.46166 .40138 .46826 .40852 .47988 .40466 .47332 .39749 Mtetra
.47332 .39749 .47988 .40466 .49155 .40078 .48502 .39358 Mtetra
.48502 .39358 .49155 .40078 .50327 .39689 .49677 .38965 Mtetra
.49677 .38965 .50327 .39689 .51504 .39297 .50857 .38571 Mtetra
.50857 .38571 .51504 .39297 .52686 .38904 .52043 .38175 Mtetra
.52043 .38175 .52686 .38904 .53873 .3851 .53233 .37777 Mtetra
.53233 .37777 .53873 .3851 .55066 .38114 .54429 .37377 Mtetra
.54429 .37377 .55066 .38114 .56263 .37715 .5563 .36976 Mtetra
.5563 .36976 .56263 .37715 .57466 .37316 .56836 .36573 Mtetra
.56836 .36573 .57466 .37316 .58674 .36914 .58048 .36168 Mtetra
.58048 .36168 .58674 .36914 .59887 .36511 .59265 .35762 Mtetra
.59265 .35762 .59887 .36511 .61106 .36106 .60487 .35354 Mtetra
.60487 .35354 .61106 .36106 .62329 .35699 .61714 .34943 Mtetra
.61714 .34943 .62329 .35699 .63559 .35291 .62947 .34532 Mtetra
.62947 .34532 .63559 .35291 .64793 .3488 .64185 .34118 Mtetra
.64185 .34118 .64793 .3488 .66033 .34468 .65429 .33702 Mtetra
.65429 .33702 .66033 .34468 .67279 .34054 .66679 .33285 Mtetra
.66679 .33285 .67279 .34054 .6853 .33638 .67933 .32866 Mtetra
.67933 .32866 .6853 .33638 .69787 .3322 .69194 .32444 Mtetra
.69194 .32444 .69787 .3322 .71049 .32801 .7046 .32021 Mtetra
.7046 .32021 .71049 .32801 .72317 .3238 .71732 .31597 Mtetra
.71732 .31597 .72317 .3238 .73591 .31956 .73009 .3117 Mtetra
.73009 .3117 .73591 .31956 .7487 .31531 .74293 .30741 Mtetra
.74293 .30741 .7487 .31531 .76155 .31104 .75582 .3031 Mtetra
.75582 .3031 .76155 .31104 .77446 .30675 .76877 .29878 Mtetra
.76877 .29878 .77446 .30675 .78742 .30244 .78177 .29443 Mtetra
.78177 .29443 .78742 .30244 .80045 .29811 .79484 .29007 Mtetra
.79484 .29007 .80045 .29811 .81353 .29376 .80797 .28568 Mtetra
.80797 .28568 .81353 .29376 .82667 .28939 .82115 .28128 Mtetra
.82115 .28128 .82667 .28939 .83988 .285 .8344 .27685 Mtetra
.8344 .27685 .83988 .285 .85314 .2806 .8477 .2724 Mtetra
.8477 .2724 .85314 .2806 .86646 .27617 .86107 .26794 Mtetra
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.28559 .45108 .29268 .45784 .30361 .45418 .29655 .4474 Mtetra
.29655 .4474 .30361 .45418 .3146 .45051 .30756 .4437 Mtetra
.30756 .4437 .3146 .45051 .32563 .44683 .31862 .43998 Mtetra
.31862 .43998 .32563 .44683 .3367 .44313 .32973 .43626 Mtetra
.32973 .43626 .3367 .44313 .34783 .43941 .34088 .43251 Mtetra
.34088 .43251 .34783 .43941 .35899 .43568 .35207 .42875 Mtetra
.35207 .42875 .35899 .43568 .37021 .43193 .36332 .42497 Mtetra
.36332 .42497 .37021 .43193 .38147 .42817 .37461 .42118 Mtetra
.37461 .42118 .38147 .42817 .39278 .42439 .38595 .41737 Mtetra
.38595 .41737 .39278 .42439 .40414 .4206 .39734 .41355 Mtetra
.39734 .41355 .40414 .4206 .41555 .41679 .40878 .40971 Mtetra
.40878 .40971 .41555 .41679 .427 .41296 .42026 .40585 Mtetra
.42026 .40585 .427 .41296 .43851 .40912 .4318 .40198 Mtetra
.4318 .40198 .43851 .40912 .45006 .40526 .44338 .39809 Mtetra
.44338 .39809 .45006 .40526 .46166 .40138 .45502 .39418 Mtetra
.45502 .39418 .46166 .40138 .47332 .39749 .4667 .39025 Mtetra
.4667 .39025 .47332 .39749 .48502 .39358 .47843 .38631 Mtetra
.47843 .38631 .48502 .39358 .49677 .38965 .49022 .38236 Mtetra
.49022 .38236 .49677 .38965 .50857 .38571 .50206 .37838 Mtetra
.50206 .37838 .50857 .38571 .52043 .38175 .51394 .37439 Mtetra
.51394 .37439 .52043 .38175 .53233 .37777 .52588 .37038 Mtetra
.52588 .37038 .53233 .37777 .54429 .37377 .53788 .36635 Mtetra
.53788 .36635 .54429 .37377 .5563 .36976 .54992 .36231 Mtetra
.54992 .36231 .5563 .36976 .56836 .36573 .56202 .35825 Mtetra
.56202 .35825 .56836 .36573 .58048 .36168 .57417 .35416 Mtetra
.57417 .35416 .58048 .36168 .59265 .35762 .58637 .35007 Mtetra
.58637 .35007 .59265 .35762 .60487 .35354 .59863 .34595 Mtetra
.59863 .34595 .60487 .35354 .61714 .34943 .61094 .34182 Mtetra
.61094 .34182 .61714 .34943 .62947 .34532 .6233 .33766 Mtetra
.6233 .33766 .62947 .34532 .64185 .34118 .63572 .33349 Mtetra
.63572 .33349 .64185 .34118 .65429 .33702 .6482 .3293 Mtetra
.6482 .3293 .65429 .33702 .66679 .33285 .66073 .32509 Mtetra
.66073 .32509 .66679 .33285 .67933 .32866 .67332 .32087 Mtetra
.67332 .32087 .67933 .32866 .69194 .32444 .68596 .31662 Mtetra
.68596 .31662 .69194 .32444 .7046 .32021 .69866 .31236 Mtetra
.69866 .31236 .7046 .32021 .71732 .31597 .71142 .30807 Mtetra
.71142 .30807 .71732 .31597 .73009 .3117 .72423 .30377 Mtetra
.72423 .30377 .73009 .3117 .74293 .30741 .73711 .29944 Mtetra
.73711 .29944 .74293 .30741 .75582 .3031 .75004 .2951 Mtetra
.75004 .2951 .75582 .3031 .76877 .29878 .76303 .29074 Mtetra
.76303 .29074 .76877 .29878 .78177 .29443 .77608 .28636 Mtetra
.77608 .28636 .78177 .29443 .79484 .29007 .78919 .28195 Mtetra
.78919 .28195 .79484 .29007 .80797 .28568 .80235 .27753 Mtetra
.80235 .27753 .80797 .28568 .82115 .28128 .81558 .27309 Mtetra
.81558 .27309 .82115 .28128 .8344 .27685 .82887 .26863 Mtetra
.82887 .26863 .8344 .27685 .8477 .2724 .84222 .26414 Mtetra
.84222 .26414 .8477 .2724 .86107 .26794 .85563 .25964 Mtetra
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .4437 .30048 .43683 Mtetra
.30048 .43683 .30756 .4437 .31862 .43998 .31156 .43309 Mtetra
.31156 .43309 .31862 .43998 .32973 .43626 .32269 .42933 Mtetra
.32269 .42933 .32973 .43626 .34088 .43251 .33387 .42556 Mtetra
.33387 .42556 .34088 .43251 .35207 .42875 .3451 .42177 Mtetra
.3451 .42177 .35207 .42875 .36332 .42497 .35637 .41796 Mtetra
.35637 .41796 .36332 .42497 .37461 .42118 .3677 .41414 Mtetra
.3677 .41414 .37461 .42118 .38595 .41737 .37907 .4103 Mtetra
.37907 .4103 .38595 .41737 .39734 .41355 .39048 .40644 Mtetra
.39048 .40644 .39734 .41355 .40878 .40971 .40195 .40257 Mtetra
.40195 .40257 .40878 .40971 .42026 .40585 .41347 .39869 Mtetra
.41347 .39869 .42026 .40585 .4318 .40198 .42503 .39478 Mtetra
.42503 .39478 .4318 .40198 .44338 .39809 .43665 .39086 Mtetra
.43665 .39086 .44338 .39809 .45502 .39418 .44832 .38692 Mtetra
.44832 .38692 .45502 .39418 .4667 .39025 .46003 .38297 Mtetra
.46003 .38297 .4667 .39025 .47843 .38631 .4718 .37899 Mtetra
.4718 .37899 .47843 .38631 .49022 .38236 .48362 .375 Mtetra
.48362 .375 .49022 .38236 .50206 .37838 .49549 .371 Mtetra
.49549 .371 .50206 .37838 .51394 .37439 .50741 .36697 Mtetra
.50741 .36697 .51394 .37439 .52588 .37038 .51938 .36293 Mtetra
.51938 .36293 .52588 .37038 .53788 .36635 .53141 .35887 Mtetra
.53141 .35887 .53788 .36635 .54992 .36231 .54349 .35479 Mtetra
.54349 .35479 .54992 .36231 .56202 .35825 .55562 .3507 Mtetra
.55562 .3507 .56202 .35825 .57417 .35416 .5678 .34658 Mtetra
.5678 .34658 .57417 .35416 .58637 .35007 .58004 .34245 Mtetra
.58004 .34245 .58637 .35007 .59863 .34595 .59233 .3383 Mtetra
.59233 .3383 .59863 .34595 .61094 .34182 .60468 .33414 Mtetra
.60468 .33414 .61094 .34182 .6233 .33766 .61708 .32995 Mtetra
.61708 .32995 .6233 .33766 .63572 .33349 .62954 .32574 Mtetra
.62954 .32574 .63572 .33349 .6482 .3293 .64206 .32152 Mtetra
.64206 .32152 .6482 .3293 .66073 .32509 .65462 .31728 Mtetra
.65462 .31728 .66073 .32509 .67332 .32087 .66725 .31301 Mtetra
.66725 .31301 .67332 .32087 .68596 .31662 .67993 .30873 Mtetra
.67993 .30873 .68596 .31662 .69866 .31236 .69267 .30443 Mtetra
.69267 .30443 .69866 .31236 .71142 .30807 .70547 .30011 Mtetra
.70547 .30011 .71142 .30807 .72423 .30377 .71832 .29577 Mtetra
.71832 .29577 .72423 .30377 .73711 .29944 .73124 .29141 Mtetra
.73124 .29141 .73711 .29944 .75004 .2951 .74421 .28703 Mtetra
.74421 .28703 .75004 .2951 .76303 .29074 .75724 .28263 Mtetra
.75724 .28263 .76303 .29074 .77608 .28636 .77033 .27821 Mtetra
.77033 .27821 .77608 .28636 .78919 .28195 .78348 .27377 Mtetra
.78348 .27377 .78919 .28195 .80235 .27753 .79669 .26932 Mtetra
.79669 .26932 .80235 .27753 .81558 .27309 .80997 .26483 Mtetra
.80997 .26483 .81558 .27309 .82887 .26863 .8233 .26033 Mtetra
.8233 .26033 .82887 .26863 .84222 .26414 .83669 .25581 Mtetra
.83669 .25581 .84222 .26414 .85563 .25964 .85015 .25127 Mtetra
.534 .302 .509 r
.21984 .6612 .24574 .45531 .25659 .45164 .23139 .65774 Mtetra
.23139 .65774 .25659 .45164 .2675 .44796 .24299 .65426 Mtetra
.24299 .65426 .2675 .44796 .27844 .44427 .25464 .65077 Mtetra
.25464 .65077 .27844 .44427 .28944 .44056 .26635 .64726 Mtetra
.26635 .64726 .28944 .44056 .30048 .43683 .27811 .64374 Mtetra
.27811 .64374 .30048 .43683 .31156 .43309 .28992 .6402 Mtetra
.28992 .6402 .31156 .43309 .32269 .42933 .30179 .63664 Mtetra
.30179 .63664 .32269 .42933 .33387 .42556 .3137 .63307 Mtetra
.3137 .63307 .33387 .42556 .3451 .42177 .32568 .62949 Mtetra
.32568 .62949 .3451 .42177 .35637 .41796 .3377 .62588 Mtetra
.3377 .62588 .35637 .41796 .3677 .41414 .34979 .62226 Mtetra
.34979 .62226 .3677 .41414 .37907 .4103 .36192 .61862 Mtetra
.199 .031 .414 r
.36192 .61862 .37907 .4103 .39048 .40644 .3794 .49443 Mtetra
.52 .271 .478 r
.3794 .49443 .39048 .40644 .40195 .40257 .39123 .49062 Mtetra
.39123 .49062 .40195 .40257 .41347 .39869 .40311 .4868 Mtetra
.40311 .4868 .41347 .39869 .42503 .39478 .41505 .48295 Mtetra
.41505 .48295 .42503 .39478 .43665 .39086 .42703 .4791 Mtetra
.42703 .4791 .43665 .39086 .44832 .38692 .43907 .47522 Mtetra
.43907 .47522 .44832 .38692 .46003 .38297 .45117 .47133 Mtetra
.45117 .47133 .46003 .38297 .4718 .37899 .46332 .46742 Mtetra
.46332 .46742 .4718 .37899 .48362 .375 .47552 .46349 Mtetra
.47552 .46349 .48362 .375 .49549 .371 .48778 .45955 Mtetra
.48778 .45955 .49549 .371 .50741 .36697 .50009 .45558 Mtetra
.50009 .45558 .50741 .36697 .51938 .36293 .51246 .4516 Mtetra
.51246 .4516 .51938 .36293 .53141 .35887 .52489 .4476 Mtetra
0 0 .231 r
.52489 .4476 .53141 .35887 .54349 .35479 .537 .34722 Mtetra
.664 .741 .908 r
.537 .34722 .54349 .35479 .55562 .3507 .54917 .34309 Mtetra
.54917 .34309 .55562 .3507 .5678 .34658 .56139 .33894 Mtetra
.56139 .33894 .5678 .34658 .58004 .34245 .57366 .33478 Mtetra
.57366 .33478 .58004 .34245 .59233 .3383 .58599 .33059 Mtetra
.58599 .33059 .59233 .3383 .60468 .33414 .59838 .32639 Mtetra
.59838 .32639 .60468 .33414 .61708 .32995 .61082 .32217 Mtetra
.61082 .32217 .61708 .32995 .62954 .32574 .62331 .31793 Mtetra
.62331 .31793 .62954 .32574 .64206 .32152 .63586 .31367 Mtetra
.63586 .31367 .64206 .32152 .65462 .31728 .64847 .30939 Mtetra
.64847 .30939 .65462 .31728 .66725 .31301 .66113 .30509 Mtetra
.66113 .30509 .66725 .31301 .67993 .30873 .67385 .30078 Mtetra
.67385 .30078 .67993 .30873 .69267 .30443 .68663 .29644 Mtetra
.68663 .29644 .69267 .30443 .70547 .30011 .69947 .29208 Mtetra
.69947 .29208 .70547 .30011 .71832 .29577 .71237 .28771 Mtetra
.71237 .28771 .71832 .29577 .73124 .29141 .72532 .28331 Mtetra
.72532 .28331 .73124 .29141 .74421 .28703 .73833 .2789 Mtetra
.73833 .2789 .74421 .28703 .75724 .28263 .75141 .27446 Mtetra
.75141 .27446 .75724 .28263 .77033 .27821 .76454 .27 Mtetra
.76454 .27 .77033 .27821 .78348 .27377 .77773 .26553 Mtetra
.77773 .26553 .78348 .27377 .79669 .26932 .79099 .26103 Mtetra
.79099 .26103 .79669 .26932 .80997 .26483 .8043 .25651 Mtetra
.8043 .25651 .80997 .26483 .8233 .26033 .81768 .25197 Mtetra
.81768 .25197 .8233 .26033 .83669 .25581 .83112 .24741 Mtetra
.83112 .24741 .83669 .25581 .85015 .25127 .84462 .24283 Mtetra
.646 .762 .934 r
.21194 .6548 .21984 .6612 .23139 .65774 .22353 .65131 Mtetra
.22353 .65131 .23139 .65774 .24299 .65426 .23516 .6478 Mtetra
.23516 .6478 .24299 .65426 .25464 .65077 .24684 .64428 Mtetra
.24684 .64428 .25464 .65077 .26635 .64726 .25858 .64074 Mtetra
.25858 .64074 .26635 .64726 .27811 .64374 .27037 .63719 Mtetra
.27037 .63719 .27811 .64374 .28992 .6402 .28221 .63362 Mtetra
.28221 .63362 .28992 .6402 .30179 .63664 .29411 .63004 Mtetra
.29411 .63004 .30179 .63664 .3137 .63307 .30606 .62644 Mtetra
.30606 .62644 .3137 .63307 .32568 .62949 .31807 .62282 Mtetra
.31807 .62282 .32568 .62949 .3377 .62588 .33013 .61919 Mtetra
.33013 .61919 .3377 .62588 .34979 .62226 .34224 .61553 Mtetra
.34224 .61553 .34979 .62226 .36192 .61862 .35441 .61187 Mtetra
.945 .712 .554 r
.35441 .61187 .36192 .61862 .3794 .49443 .37221 .48739 Mtetra
.657 .75 .919 r
.37221 .48739 .3794 .49443 .39123 .49062 .38407 .48355 Mtetra
.38407 .48355 .39123 .49062 .40311 .4868 .39599 .47969 Mtetra
.39599 .47969 .40311 .4868 .41505 .48295 .40796 .47582 Mtetra
.40796 .47582 .41505 .48295 .42703 .4791 .41998 .47193 Mtetra
.41998 .47193 .42703 .4791 .43907 .47522 .43205 .46802 Mtetra
.43205 .46802 .43907 .47522 .45117 .47133 .44418 .4641 Mtetra
.44418 .4641 .45117 .47133 .46332 .46742 .45636 .46015 Mtetra
.45636 .46015 .46332 .46742 .47552 .46349 .4686 .45619 Mtetra
.4686 .45619 .47552 .46349 .48778 .45955 .4809 .45221 Mtetra
.4809 .45221 .48778 .45955 .50009 .45558 .49325 .44822 Mtetra
.49325 .44822 .50009 .45558 .51246 .4516 .50565 .4442 Mtetra
.50565 .4442 .51246 .4516 .52489 .4476 .51811 .44017 Mtetra
.96 .722 .535 r
.51811 .44017 .52489 .4476 .537 .34722 .53046 .33958 Mtetra
.664 .741 .908 r
.53046 .33958 .537 .34722 .54917 .34309 .54266 .33542 Mtetra
.54266 .33542 .54917 .34309 .56139 .33894 .55492 .33124 Mtetra
.55492 .33124 .56139 .33894 .57366 .33478 .56723 .32704 Mtetra
.56723 .32704 .57366 .33478 .58599 .33059 .5796 .32282 Mtetra
.5796 .32282 .58599 .33059 .59838 .32639 .59202 .31858 Mtetra
.59202 .31858 .59838 .32639 .61082 .32217 .60449 .31433 Mtetra
.60449 .31433 .61082 .32217 .62331 .31793 .61703 .31005 Mtetra
.61703 .31005 .62331 .31793 .63586 .31367 .62962 .30576 Mtetra
.62962 .30576 .63586 .31367 .64847 .30939 .64226 .30144 Mtetra
.64226 .30144 .64847 .30939 .66113 .30509 .65497 .29711 Mtetra
.65497 .29711 .66113 .30509 .67385 .30078 .66773 .29276 Mtetra
.66773 .29276 .67385 .30078 .68663 .29644 .68054 .28838 Mtetra
.68054 .28838 .68663 .29644 .69947 .29208 .69342 .28399 Mtetra
.69342 .28399 .69947 .29208 .71237 .28771 .70636 .27958 Mtetra
.70636 .27958 .71237 .28771 .72532 .28331 .71935 .27514 Mtetra
.71935 .27514 .72532 .28331 .73833 .2789 .73241 .27069 Mtetra
.73241 .27069 .73833 .2789 .75141 .27446 .74552 .26622 Mtetra
.74552 .26622 .75141 .27446 .76454 .27 .7587 .26172 Mtetra
.7587 .26172 .76454 .27 .77773 .26553 .77193 .25721 Mtetra
.77193 .25721 .77773 .26553 .79099 .26103 .78523 .25267 Mtetra
.78523 .25267 .79099 .26103 .8043 .25651 .79859 .24811 Mtetra
.79859 .24811 .8043 .25651 .81768 .25197 .81201 .24353 Mtetra
.81201 .24353 .81768 .25197 .83112 .24741 .82549 .23893 Mtetra
.82549 .23893 .83112 .24741 .84462 .24283 .83904 .23431 Mtetra
.646 .762 .934 r
.20399 .64834 .21194 .6548 .22353 .65131 .2156 .64482 Mtetra
.2156 .64482 .22353 .65131 .23516 .6478 .22726 .64129 Mtetra
.22726 .64129 .23516 .6478 .24684 .64428 .23898 .63774 Mtetra
.23898 .63774 .24684 .64428 .25858 .64074 .25075 .63417 Mtetra
.25075 .63417 .25858 .64074 .27037 .63719 .26257 .63059 Mtetra
.26257 .63059 .27037 .63719 .28221 .63362 .27444 .62699 Mtetra
.27444 .62699 .28221 .63362 .29411 .63004 .28637 .62338 Mtetra
.28637 .62338 .29411 .63004 .30606 .62644 .29836 .61975 Mtetra
.29836 .61975 .30606 .62644 .31807 .62282 .3104 .6161 Mtetra
.3104 .6161 .31807 .62282 .33013 .61919 .32249 .61243 Mtetra
.32249 .61243 .33013 .61919 .34224 .61553 .33464 .60875 Mtetra
.33464 .60875 .34224 .61553 .35441 .61187 .34684 .60505 Mtetra
.945 .712 .554 r
.34684 .60505 .35441 .61187 .37221 .48739 .36497 .48029 Mtetra
.657 .75 .919 r
.36497 .48029 .37221 .48739 .38407 .48355 .37686 .47642 Mtetra
.37686 .47642 .38407 .48355 .39599 .47969 .38881 .47253 Mtetra
.38881 .47253 .39599 .47969 .40796 .47582 .40081 .46862 Mtetra
.40081 .46862 .40796 .47582 .41998 .47193 .41286 .4647 Mtetra
.41286 .4647 .41998 .47193 .43205 .46802 .42497 .46076 Mtetra
.42497 .46076 .43205 .46802 .44418 .4641 .43713 .4568 Mtetra
.43713 .4568 .44418 .4641 .45636 .46015 .44935 .45283 Mtetra
.44935 .45283 .45636 .46015 .4686 .45619 .46163 .44883 Mtetra
.46163 .44883 .4686 .45619 .4809 .45221 .47396 .44482 Mtetra
.47396 .44482 .4809 .45221 .49325 .44822 .48634 .44079 Mtetra
.48634 .44079 .49325 .44822 .50565 .4442 .49878 .43675 Mtetra
.49878 .43675 .50565 .4442 .51811 .44017 .51128 .43268 Mtetra
.96 .722 .535 r
.51128 .43268 .51811 .44017 .53046 .33958 .52387 .33188 Mtetra
.664 .741 .908 r
.52387 .33188 .53046 .33958 .54266 .33542 .53611 .32769 Mtetra
.53611 .32769 .54266 .33542 .55492 .33124 .5484 .32347 Mtetra
.5484 .32347 .55492 .33124 .56723 .32704 .56075 .31924 Mtetra
.56075 .31924 .56723 .32704 .5796 .32282 .57315 .31498 Mtetra
.57315 .31498 .5796 .32282 .59202 .31858 .58561 .31071 Mtetra
.58561 .31071 .59202 .31858 .60449 .31433 .59812 .30642 Mtetra
.59812 .30642 .60449 .31433 .61703 .31005 .61069 .30211 Mtetra
.61069 .30211 .61703 .31005 .62962 .30576 .62332 .29778 Mtetra
.62332 .29778 .62962 .30576 .64226 .30144 .636 .29343 Mtetra
.636 .29343 .64226 .30144 .65497 .29711 .64874 .28906 Mtetra
.64874 .28906 .65497 .29711 .66773 .29276 .66155 .28467 Mtetra
.66155 .28467 .66773 .29276 .68054 .28838 .6744 .28026 Mtetra
.6744 .28026 .68054 .28838 .69342 .28399 .68732 .27583 Mtetra
.68732 .27583 .69342 .28399 .70636 .27958 .7003 .27138 Mtetra
.7003 .27138 .70636 .27958 .71935 .27514 .71333 .26691 Mtetra
.71333 .26691 .71935 .27514 .73241 .27069 .72643 .26241 Mtetra
.72643 .26241 .73241 .27069 .74552 .26622 .73959 .2579 Mtetra
.73959 .2579 .74552 .26622 .7587 .26172 .7528 .25337 Mtetra
.7528 .25337 .7587 .26172 .77193 .25721 .76608 .24881 Mtetra
.76608 .24881 .77193 .25721 .78523 .25267 .77942 .24424 Mtetra
.77942 .24424 .78523 .25267 .79859 .24811 .79283 .23964 Mtetra
.79283 .23964 .79859 .24811 .81201 .24353 .80629 .23502 Mtetra
.80629 .23502 .81201 .24353 .82549 .23893 .81982 .23039 Mtetra
.81982 .23039 .82549 .23893 .83904 .23431 .83341 .22572 Mtetra
.646 .762 .934 r
.19597 .64183 .20399 .64834 .2156 .64482 .20761 .63829 Mtetra
.20761 .63829 .2156 .64482 .22726 .64129 .2193 .63472 Mtetra
.2193 .63472 .22726 .64129 .23898 .63774 .23105 .63114 Mtetra
.23105 .63114 .23898 .63774 .25075 .63417 .24285 .62755 Mtetra
.24285 .62755 .25075 .63417 .26257 .63059 .2547 .62393 Mtetra
.2547 .62393 .26257 .63059 .27444 .62699 .26661 .62031 Mtetra
.26661 .62031 .27444 .62699 .28637 .62338 .27857 .61666 Mtetra
.27857 .61666 .28637 .62338 .29836 .61975 .29059 .613 Mtetra
.29059 .613 .29836 .61975 .3104 .6161 .30266 .60932 Mtetra
.30266 .60932 .3104 .6161 .32249 .61243 .31479 .60562 Mtetra
.31479 .60562 .32249 .61243 .33464 .60875 .32697 .60191 Mtetra
.32697 .60191 .33464 .60875 .34684 .60505 .33921 .59818 Mtetra
.945 .712 .554 r
.33921 .59818 .34684 .60505 .36497 .48029 .35766 .47313 Mtetra
.657 .75 .919 r
.35766 .47313 .36497 .48029 .37686 .47642 .36959 .46923 Mtetra
.36959 .46923 .37686 .47642 .38881 .47253 .38157 .46531 Mtetra
.38157 .46531 .38881 .47253 .40081 .46862 .3936 .46137 Mtetra
.3936 .46137 .40081 .46862 .41286 .4647 .40569 .45741 Mtetra
.40569 .45741 .41286 .4647 .42497 .46076 .41783 .45344 Mtetra
.41783 .45344 .42497 .46076 .43713 .4568 .43003 .44945 Mtetra
.43003 .44945 .43713 .4568 .44935 .45283 .44228 .44544 Mtetra
.44228 .44544 .44935 .45283 .46163 .44883 .45459 .44141 Mtetra
.45459 .44141 .46163 .44883 .47396 .44482 .46696 .43737 Mtetra
.46696 .43737 .47396 .44482 .48634 .44079 .47938 .43331 Mtetra
.47938 .43331 .48634 .44079 .49878 .43675 .49186 .42922 Mtetra
.49186 .42922 .49878 .43675 .51128 .43268 .50439 .42512 Mtetra
.96 .722 .535 r
.50439 .42512 .51128 .43268 .52387 .33188 .51722 .32412 Mtetra
.664 .741 .908 r
.51722 .32412 .52387 .33188 .53611 .32769 .5295 .31989 Mtetra
.5295 .31989 .53611 .32769 .5484 .32347 .54182 .31564 Mtetra
.54182 .31564 .5484 .32347 .56075 .31924 .55421 .31137 Mtetra
.55421 .31137 .56075 .31924 .57315 .31498 .56665 .30708 Mtetra
.56665 .30708 .57315 .31498 .58561 .31071 .57914 .30277 Mtetra
.57914 .30277 .58561 .31071 .59812 .30642 .59169 .29844 Mtetra
.59169 .29844 .59812 .30642 .61069 .30211 .6043 .2941 Mtetra
.6043 .2941 .61069 .30211 .62332 .29778 .61697 .28973 Mtetra
.61697 .28973 .62332 .29778 .636 .29343 .62969 .28534 Mtetra
.62969 .28534 .636 .29343 .64874 .28906 .64247 .28094 Mtetra
.64247 .28094 .64874 .28906 .66155 .28467 .65531 .27651 Mtetra
.65531 .27651 .66155 .28467 .6744 .28026 .66821 .27206 Mtetra
.66821 .27206 .6744 .28026 .68732 .27583 .68117 .26759 Mtetra
.68117 .26759 .68732 .27583 .7003 .27138 .69419 .26311 Mtetra
.69419 .26311 .7003 .27138 .71333 .26691 .70726 .2586 Mtetra
.70726 .2586 .71333 .26691 .72643 .26241 .7204 .25407 Mtetra
.7204 .25407 .72643 .26241 .73959 .2579 .7336 .24952 Mtetra
.7336 .24952 .73959 .2579 .7528 .25337 .74686 .24494 Mtetra
.74686 .24494 .7528 .25337 .76608 .24881 .76018 .24035 Mtetra
.76018 .24035 .76608 .24881 .77942 .24424 .77357 .23574 Mtetra
.77357 .23574 .77942 .24424 .79283 .23964 .78702 .2311 Mtetra
.78702 .2311 .79283 .23964 .80629 .23502 .80053 .22644 Mtetra
.80053 .22644 .80629 .23502 .81982 .23039 .8141 .22176 Mtetra
.8141 .22176 .81982 .23039 .83341 .22572 .82774 .21706 Mtetra
.646 .762 .934 r
.18788 .63527 .19597 .64183 .20761 .63829 .19955 .63169 Mtetra
.19955 .63169 .20761 .63829 .2193 .63472 .21127 .6281 Mtetra
.21127 .6281 .2193 .63472 .23105 .63114 .22305 .62449 Mtetra
.22305 .62449 .23105 .63114 .24285 .62755 .23488 .62086 Mtetra
.23488 .62086 .24285 .62755 .2547 .62393 .24677 .61722 Mtetra
.24677 .61722 .2547 .62393 .26661 .62031 .25871 .61356 Mtetra
.25871 .61356 .26661 .62031 .27857 .61666 .2707 .60989 Mtetra
.2707 .60989 .27857 .61666 .29059 .613 .28275 .60619 Mtetra
.28275 .60619 .29059 .613 .30266 .60932 .29485 .60248 Mtetra
.29485 .60248 .30266 .60932 .31479 .60562 .30702 .59875 Mtetra
.30702 .59875 .31479 .60562 .32697 .60191 .31923 .59501 Mtetra
.31923 .59501 .32697 .60191 .33921 .59818 .33151 .59125 Mtetra
.945 .712 .554 r
.33151 .59125 .33921 .59818 .35766 .47313 .35029 .46591 Mtetra
.657 .75 .919 r
.35029 .46591 .35766 .47313 .36959 .46923 .36225 .46198 Mtetra
.36225 .46198 .36959 .46923 .38157 .46531 .37426 .45802 Mtetra
.37426 .45802 .38157 .46531 .3936 .46137 .38633 .45405 Mtetra
.38633 .45405 .3936 .46137 .40569 .45741 .39846 .45007 Mtetra
.39846 .45007 .40569 .45741 .41783 .45344 .41063 .44606 Mtetra
.41063 .44606 .41783 .45344 .43003 .44945 .42287 .44204 Mtetra
.42287 .44204 .43003 .44945 .44228 .44544 .43515 .43799 Mtetra
.43515 .43799 .44228 .44544 .45459 .44141 .4475 .43393 Mtetra
.4475 .43393 .45459 .44141 .46696 .43737 .4599 .42985 Mtetra
.4599 .42985 .46696 .43737 .47938 .43331 .47236 .42575 Mtetra
.47236 .42575 .47938 .43331 .49186 .42922 .48487 .42164 Mtetra
.48487 .42164 .49186 .42922 .50439 .42512 .49745 .4175 Mtetra
.96 .722 .535 r
.49745 .4175 .50439 .42512 .51722 .32412 .51052 .31629 Mtetra
.664 .741 .908 r
.51052 .31629 .51722 .32412 .5295 .31989 .52283 .31203 Mtetra
.52283 .31203 .5295 .31989 .54182 .31564 .53519 .30774 Mtetra
.53519 .30774 .54182 .31564 .55421 .31137 .54761 .30344 Mtetra
.54761 .30344 .55421 .31137 .56665 .30708 .56009 .29911 Mtetra
.56009 .29911 .56665 .30708 .57914 .30277 .57262 .29477 Mtetra
.57262 .29477 .57914 .30277 .59169 .29844 .58521 .2904 Mtetra
.58521 .2904 .59169 .29844 .6043 .2941 .59786 .28602 Mtetra
.59786 .28602 .6043 .2941 .61697 .28973 .61056 .28162 Mtetra
.61056 .28162 .61697 .28973 .62969 .28534 .62333 .27719 Mtetra
.62333 .27719 .62969 .28534 .64247 .28094 .63615 .27275 Mtetra
.63615 .27275 .64247 .28094 .65531 .27651 .64903 .26828 Mtetra
.64903 .26828 .65531 .27651 .66821 .27206 .66197 .2638 Mtetra
.66197 .2638 .66821 .27206 .68117 .26759 .67496 .25929 Mtetra
.67496 .25929 .68117 .26759 .69419 .26311 .68802 .25477 Mtetra
.68802 .25477 .69419 .26311 .70726 .2586 .70114 .25022 Mtetra
.70114 .25022 .70726 .2586 .7204 .25407 .71432 .24565 Mtetra
.71432 .24565 .7204 .25407 .7336 .24952 .72756 .24106 Mtetra
.72756 .24106 .7336 .24952 .74686 .24494 .74087 .23645 Mtetra
.74087 .23645 .74686 .24494 .76018 .24035 .75423 .23182 Mtetra
.75423 .23182 .76018 .24035 .77357 .23574 .76766 .22716 Mtetra
.76766 .22716 .77357 .23574 .78702 .2311 .78115 .22248 Mtetra
.78115 .22248 .78702 .2311 .80053 .22644 .79471 .21779 Mtetra
.79471 .21779 .80053 .22644 .8141 .22176 .80833 .21306 Mtetra
.80833 .21306 .8141 .22176 .82774 .21706 .82201 .20832 Mtetra
.646 .762 .934 r
.17972 .62865 .18788 .63527 .19955 .63169 .19142 .62505 Mtetra
.19142 .62505 .19955 .63169 .21127 .6281 .20318 .62142 Mtetra
.20318 .62142 .21127 .6281 .22305 .62449 .21499 .61778 Mtetra
.21499 .61778 .22305 .62449 .23488 .62086 .22685 .61413 Mtetra
.22685 .61413 .23488 .62086 .24677 .61722 .23877 .61045 Mtetra
.23877 .61045 .24677 .61722 .25871 .61356 .25074 .60676 Mtetra
.25074 .60676 .25871 .61356 .2707 .60989 .26276 .60305 Mtetra
.26276 .60305 .2707 .60989 .28275 .60619 .27485 .59933 Mtetra
.27485 .59933 .28275 .60619 .29485 .60248 .28698 .59559 Mtetra
.28698 .59559 .29485 .60248 .30702 .59875 .29918 .59183 Mtetra
.29918 .59183 .30702 .59875 .31923 .59501 .31143 .58805 Mtetra
.31143 .58805 .31923 .59501 .33151 .59125 .32374 .58426 Mtetra
.945 .712 .554 r
.32374 .58426 .33151 .59125 .35029 .46591 .34286 .45863 Mtetra
.657 .75 .919 r
.34286 .45863 .35029 .46591 .36225 .46198 .35485 .45467 Mtetra
.35485 .45467 .36225 .46198 .37426 .45802 .3669 .45068 Mtetra
.3669 .45068 .37426 .45802 .38633 .45405 .379 .44668 Mtetra
.379 .44668 .38633 .45405 .39846 .45007 .39116 .44266 Mtetra
.39116 .44266 .39846 .45007 .41063 .44606 .40337 .43862 Mtetra
.40337 .43862 .41063 .44606 .42287 .44204 .41564 .43456 Mtetra
.41564 .43456 .42287 .44204 .43515 .43799 .42796 .43048 Mtetra
.42796 .43048 .43515 .43799 .4475 .43393 .44035 .42639 Mtetra
.44035 .42639 .4475 .43393 .4599 .42985 .45278 .42227 Mtetra
.45278 .42227 .4599 .42985 .47236 .42575 .46528 .41814 Mtetra
.46528 .41814 .47236 .42575 .48487 .42164 .47783 .41399 Mtetra
.47783 .41399 .48487 .42164 .49745 .4175 .49044 .40981 Mtetra
.96 .722 .535 r
.49044 .40981 .49745 .4175 .51052 .31629 .50376 .3084 Mtetra
.664 .741 .908 r
.50376 .3084 .51052 .31629 .52283 .31203 .51611 .3041 Mtetra
.51611 .3041 .52283 .31203 .53519 .30774 .52851 .29978 Mtetra
.52851 .29978 .53519 .30774 .54761 .30344 .54097 .29544 Mtetra
.54097 .29544 .54761 .30344 .56009 .29911 .55348 .29108 Mtetra
.55348 .29108 .56009 .29911 .57262 .29477 .56605 .28669 Mtetra
.56605 .28669 .57262 .29477 .58521 .2904 .57868 .28229 Mtetra
.57868 .28229 .58521 .2904 .59786 .28602 .59136 .27787 Mtetra
.59136 .27787 .59786 .28602 .61056 .28162 .60411 .27343 Mtetra
.60411 .27343 .61056 .28162 .62333 .27719 .61691 .26897 Mtetra
.61691 .26897 .62333 .27719 .63615 .27275 .62977 .26449 Mtetra
.62977 .26449 .63615 .27275 .64903 .26828 .64269 .25999 Mtetra
.64269 .25999 .64903 .26828 .66197 .2638 .65567 .25546 Mtetra
.65567 .25546 .66197 .2638 .67496 .25929 .66871 .25092 Mtetra
.66871 .25092 .67496 .25929 .68802 .25477 .68181 .24635 Mtetra
.68181 .24635 .68802 .25477 .70114 .25022 .69497 .24177 Mtetra
.69497 .24177 .70114 .25022 .71432 .24565 .70819 .23716 Mtetra
.70819 .23716 .71432 .24565 .72756 .24106 .72148 .23253 Mtetra
.72148 .23253 .72756 .24106 .74087 .23645 .73482 .22788 Mtetra
.73482 .22788 .74087 .23645 .75423 .23182 .74823 .2232 Mtetra
.74823 .2232 .75423 .23182 .76766 .22716 .7617 .21851 Mtetra
.7617 .21851 .76766 .22716 .78115 .22248 .77524 .21379 Mtetra
.77524 .21379 .78115 .22248 .79471 .21779 .78884 .20905 Mtetra
.78884 .20905 .79471 .21779 .80833 .21306 .80251 .20429 Mtetra
.80251 .20429 .80833 .21306 .82201 .20832 .81623 .19951 Mtetra
.646 .762 .934 r
.17149 .62198 .17972 .62865 .19142 .62505 .18323 .61834 Mtetra
.18323 .61834 .19142 .62505 .20318 .62142 .19501 .61469 Mtetra
.19501 .61469 .20318 .62142 .21499 .61778 .20685 .61102 Mtetra
.20685 .61102 .21499 .61778 .22685 .61413 .21875 .60733 Mtetra
.21875 .60733 .22685 .61413 .23877 .61045 .2307 .60363 Mtetra
.2307 .60363 .23877 .61045 .25074 .60676 .2427 .5999 Mtetra
.2427 .5999 .25074 .60676 .26276 .60305 .25476 .59616 Mtetra
.25476 .59616 .26276 .60305 .27485 .59933 .26688 .59241 Mtetra
.26688 .59241 .27485 .59933 .28698 .59559 .27905 .58863 Mtetra
.27905 .58863 .28698 .59559 .29918 .59183 .29128 .58484 Mtetra
.29128 .58484 .29918 .59183 .31143 .58805 .30356 .58103 Mtetra
.30356 .58103 .31143 .58805 .32374 .58426 .3159 .57721 Mtetra
.945 .712 .554 r
.3159 .57721 .32374 .58426 .34286 .45863 .33537 .45129 Mtetra
.657 .75 .919 r
.33537 .45129 .34286 .45863 .35485 .45467 .3474 .44729 Mtetra
.3474 .44729 .35485 .45467 .3669 .45068 .35948 .44328 Mtetra
.35948 .44328 .3669 .45068 .379 .44668 .37161 .43924 Mtetra
.37161 .43924 .379 .44668 .39116 .44266 .38381 .43518 Mtetra
.38381 .43518 .39116 .44266 .40337 .43862 .39605 .43111 Mtetra
.39605 .43111 .40337 .43862 .41564 .43456 .40835 .42702 Mtetra
.40835 .42702 .41564 .43456 .42796 .43048 .42071 .42291 Mtetra
.42071 .42291 .42796 .43048 .44035 .42639 .43313 .41878 Mtetra
.43313 .41878 .44035 .42639 .45278 .42227 .4456 .41463 Mtetra
.4456 .41463 .45278 .42227 .46528 .41814 .45814 .41046 Mtetra
.45814 .41046 .46528 .41814 .47783 .41399 .47072 .40627 Mtetra
.47072 .40627 .47783 .41399 .49044 .40981 .48337 .40206 Mtetra
.96 .722 .535 r
.48337 .40206 .49044 .40981 .50376 .3084 .49695 .30044 Mtetra
.664 .741 .908 r
.49695 .30044 .50376 .3084 .51611 .3041 .50933 .29611 Mtetra
.50933 .29611 .51611 .3041 .52851 .29978 .52177 .29175 Mtetra
.52177 .29175 .52851 .29978 .54097 .29544 .53426 .28737 Mtetra
.53426 .28737 .54097 .29544 .55348 .29108 .54681 .28297 Mtetra
.54681 .28297 .55348 .29108 .56605 .28669 .55942 .27855 Mtetra
.55942 .27855 .56605 .28669 .57868 .28229 .57209 .27412 Mtetra
.57209 .27412 .57868 .28229 .59136 .27787 .58481 .26966 Mtetra
.58481 .26966 .59136 .27787 .60411 .27343 .59759 .26518 Mtetra
.59759 .26518 .60411 .27343 .61691 .26897 .61043 .26068 Mtetra
.61043 .26068 .61691 .26897 .62977 .26449 .62333 .25616 Mtetra
.62333 .25616 .62977 .26449 .64269 .25999 .63629 .25162 Mtetra
.63629 .25162 .64269 .25999 .65567 .25546 .64932 .24706 Mtetra
.64932 .24706 .65567 .25546 .66871 .25092 .6624 .24247 Mtetra
.6624 .24247 .66871 .25092 .68181 .24635 .67554 .23787 Mtetra
.67554 .23787 .68181 .24635 .69497 .24177 .68874 .23324 Mtetra
.68874 .23324 .69497 .24177 .70819 .23716 .70201 .22859 Mtetra
.70201 .22859 .70819 .23716 .72148 .23253 .71533 .22393 Mtetra
.71533 .22393 .72148 .23253 .73482 .22788 .72872 .21923 Mtetra
.72872 .21923 .73482 .22788 .74823 .2232 .74218 .21452 Mtetra
.74218 .21452 .74823 .2232 .7617 .21851 .75569 .20978 Mtetra
.75569 .20978 .7617 .21851 .77524 .21379 .76928 .20502 Mtetra
.76928 .20502 .77524 .21379 .78884 .20905 .78292 .20024 Mtetra
.78292 .20024 .78884 .20905 .80251 .20429 .79663 .19544 Mtetra
.79663 .19544 .80251 .20429 .81623 .19951 .81041 .19061 Mtetra
.646 .762 .934 r
.1632 .61525 .17149 .62198 .18323 .61834 .17496 .61158 Mtetra
.17496 .61158 .18323 .61834 .19501 .61469 .18678 .6079 Mtetra
.18678 .6079 .19501 .61469 .20685 .61102 .19865 .6042 Mtetra
.19865 .6042 .20685 .61102 .21875 .60733 .21058 .60048 Mtetra
.21058 .60048 .21875 .60733 .2307 .60363 .22256 .59674 Mtetra
.22256 .59674 .2307 .60363 .2427 .5999 .23459 .59299 Mtetra
.23459 .59299 .2427 .5999 .25476 .59616 .24669 .58922 Mtetra
.24669 .58922 .25476 .59616 .26688 .59241 .25884 .58543 Mtetra
.25884 .58543 .26688 .59241 .27905 .58863 .27104 .58162 Mtetra
.27104 .58162 .27905 .58863 .29128 .58484 .2833 .5778 Mtetra
.2833 .5778 .29128 .58484 .30356 .58103 .29562 .57395 Mtetra
.29562 .57395 .30356 .58103 .3159 .57721 .308 .57009 Mtetra
.945 .712 .554 r
.308 .57009 .3159 .57721 .33537 .45129 .32782 .44389 Mtetra
.657 .75 .919 r
.32782 .44389 .33537 .45129 .3474 .44729 .33988 .43986 Mtetra
.33988 .43986 .3474 .44729 .35948 .44328 .35199 .43581 Mtetra
.35199 .43581 .35948 .44328 .37161 .43924 .36416 .43174 Mtetra
.36416 .43174 .37161 .43924 .38381 .43518 .37639 .42765 Mtetra
.37639 .42765 .38381 .43518 .39605 .43111 .38867 .42354 Mtetra
.38867 .42354 .39605 .43111 .40835 .42702 .40101 .41941 Mtetra
.40101 .41941 .40835 .42702 .42071 .42291 .4134 .41527 Mtetra
.4134 .41527 .42071 .42291 .43313 .41878 .42585 .4111 Mtetra
.42585 .4111 .43313 .41878 .4456 .41463 .43836 .40692 Mtetra
.43836 .40692 .4456 .41463 .45814 .41046 .45093 .40271 Mtetra
.45093 .40271 .45814 .41046 .47072 .40627 .46356 .39849 Mtetra
.46356 .39849 .47072 .40627 .48337 .40206 .47625 .39424 Mtetra
.96 .722 .535 r
.47625 .39424 .48337 .40206 .49695 .30044 .49008 .29242 Mtetra
.664 .741 .908 r
.49008 .29242 .49695 .30044 .50933 .29611 .5025 .28804 Mtetra
.5025 .28804 .50933 .29611 .52177 .29175 .51497 .28365 Mtetra
.51497 .28365 .52177 .29175 .53426 .28737 .5275 .27924 Mtetra
.5275 .27924 .53426 .28737 .54681 .28297 .54009 .2748 Mtetra
.54009 .2748 .54681 .28297 .55942 .27855 .55274 .27035 Mtetra
.55274 .27035 .55942 .27855 .57209 .27412 .56544 .26587 Mtetra
.56544 .26587 .57209 .27412 .58481 .26966 .5782 .26137 Mtetra
.5782 .26137 .58481 .26966 .59759 .26518 .59102 .25686 Mtetra
.59102 .25686 .59759 .26518 .61043 .26068 .60391 .25232 Mtetra
.60391 .25232 .61043 .26068 .62333 .25616 .61685 .24776 Mtetra
.61685 .24776 .62333 .25616 .63629 .25162 .62985 .24318 Mtetra
.62985 .24318 .63629 .25162 .64932 .24706 .64291 .23858 Mtetra
.64291 .23858 .64932 .24706 .6624 .24247 .65603 .23396 Mtetra
.65603 .23396 .6624 .24247 .67554 .23787 .66921 .22931 Mtetra
.66921 .22931 .67554 .23787 .68874 .23324 .68246 .22464 Mtetra
.68246 .22464 .68874 .23324 .70201 .22859 .69577 .21996 Mtetra
.69577 .21996 .70201 .22859 .71533 .22393 .70914 .21525 Mtetra
.70914 .21525 .71533 .22393 .72872 .21923 .72257 .21051 Mtetra
.72257 .21051 .72872 .21923 .74218 .21452 .73607 .20576 Mtetra
.73607 .20576 .74218 .21452 .75569 .20978 .74963 .20098 Mtetra
.74963 .20098 .75569 .20978 .76928 .20502 .76326 .19618 Mtetra
.76326 .19618 .76928 .20502 .78292 .20024 .77695 .19136 Mtetra
.77695 .19136 .78292 .20024 .79663 .19544 .79071 .18651 Mtetra
.79071 .18651 .79663 .19544 .81041 .19061 .80453 .18164 Mtetra
.646 .762 .934 r
.15484 .60847 .1632 .61525 .17496 .61158 .16663 .60477 Mtetra
.16663 .60477 .17496 .61158 .18678 .6079 .17848 .60105 Mtetra
.17848 .60105 .18678 .6079 .19865 .6042 .19038 .59732 Mtetra
.19038 .59732 .19865 .6042 .21058 .60048 .20234 .59357 Mtetra
.20234 .59357 .21058 .60048 .22256 .59674 .21435 .5898 Mtetra
.21435 .5898 .22256 .59674 .23459 .59299 .22642 .58601 Mtetra
.22642 .58601 .23459 .59299 .24669 .58922 .23855 .58221 Mtetra
.23855 .58221 .24669 .58922 .25884 .58543 .25073 .57839 Mtetra
.25073 .57839 .25884 .58543 .27104 .58162 .26297 .57455 Mtetra
.26297 .57455 .27104 .58162 .2833 .5778 .27526 .57069 Mtetra
.27526 .57069 .2833 .5778 .29562 .57395 .28762 .56681 Mtetra
.28762 .56681 .29562 .57395 .308 .57009 .30003 .56292 Mtetra
.945 .712 .554 r
.30003 .56292 .308 .57009 .32782 .44389 .3202 .43643 Mtetra
.657 .75 .919 r
.3202 .43643 .32782 .44389 .33988 .43986 .33229 .43236 Mtetra
.33229 .43236 .33988 .43986 .35199 .43581 .34444 .42828 Mtetra
.34444 .42828 .35199 .43581 .36416 .43174 .35665 .42417 Mtetra
.35665 .42417 .36416 .43174 .37639 .42765 .36891 .42005 Mtetra
.36891 .42005 .37639 .42765 .38867 .42354 .38122 .41591 Mtetra
.38122 .41591 .38867 .42354 .40101 .41941 .3936 .41174 Mtetra
.3936 .41174 .40101 .41941 .4134 .41527 .40603 .40756 Mtetra
.40603 .40756 .4134 .41527 .42585 .4111 .41852 .40336 Mtetra
.41852 .40336 .42585 .4111 .43836 .40692 .43106 .39914 Mtetra
.43106 .39914 .43836 .40692 .45093 .40271 .44367 .3949 Mtetra
.44367 .3949 .45093 .40271 .46356 .39849 .45633 .39064 Mtetra
.45633 .39064 .46356 .39849 .47625 .39424 .46906 .38636 Mtetra
.96 .722 .535 r
.46906 .38636 .47625 .39424 .49008 .29242 .48315 .28433 Mtetra
.664 .741 .908 r
.48315 .28433 .49008 .29242 .5025 .28804 .49561 .27992 Mtetra
.49561 .27992 .5025 .28804 .51497 .28365 .50812 .27548 Mtetra
.50812 .27548 .51497 .28365 .5275 .27924 .52068 .27103 Mtetra
.52068 .27103 .5275 .27924 .54009 .2748 .53331 .26656 Mtetra
.53331 .26656 .54009 .2748 .55274 .27035 .54599 .26207 Mtetra
.54599 .26207 .55274 .27035 .56544 .26587 .55874 .25755 Mtetra
.55874 .25755 .56544 .26587 .5782 .26137 .57154 .25302 Mtetra
.57154 .25302 .5782 .26137 .59102 .25686 .5844 .24846 Mtetra
.5844 .24846 .59102 .25686 .60391 .25232 .59732 .24389 Mtetra
.59732 .24389 .60391 .25232 .61685 .24776 .6103 .23929 Mtetra
.6103 .23929 .61685 .24776 .62985 .24318 .62334 .23467 Mtetra
.62334 .23467 .62985 .24318 .64291 .23858 .63645 .23003 Mtetra
.63645 .23003 .64291 .23858 .65603 .23396 .64961 .22536 Mtetra
.64961 .22536 .65603 .23396 .66921 .22931 .66284 .22068 Mtetra
.66284 .22068 .66921 .22931 .68246 .22464 .67612 .21597 Mtetra
.67612 .21597 .68246 .22464 .69577 .21996 .68948 .21124 Mtetra
.68948 .21124 .69577 .21996 .70914 .21525 .70289 .20649 Mtetra
.70289 .20649 .70914 .21525 .72257 .21051 .71637 .20172 Mtetra
.71637 .20172 .72257 .21051 .73607 .20576 .72991 .19692 Mtetra
.72991 .19692 .73607 .20576 .74963 .20098 .74352 .1921 Mtetra
.74352 .1921 .74963 .20098 .76326 .19618 .75719 .18726 Mtetra
.75719 .18726 .76326 .19618 .77695 .19136 .77093 .18239 Mtetra
.77093 .18239 .77695 .19136 .79071 .18651 .78473 .1775 Mtetra
.78473 .1775 .79071 .18651 .80453 .18164 .7986 .17259 Mtetra
.646 .762 .934 r
.1464 .60162 .15484 .60847 .16663 .60477 .15822 .59789 Mtetra
.15822 .59789 .16663 .60477 .17848 .60105 .1701 .59414 Mtetra
.1701 .59414 .17848 .60105 .19038 .59732 .18204 .59038 Mtetra
.18204 .59038 .19038 .59732 .20234 .59357 .19403 .58659 Mtetra
.19403 .58659 .20234 .59357 .21435 .5898 .20607 .58279 Mtetra
.20607 .58279 .21435 .5898 .22642 .58601 .21817 .57897 Mtetra
.21817 .57897 .22642 .58601 .23855 .58221 .23033 .57514 Mtetra
.23033 .57514 .23855 .58221 .25073 .57839 .24255 .57128 Mtetra
.24255 .57128 .25073 .57839 .26297 .57455 .25482 .56741 Mtetra
.25482 .56741 .26297 .57455 .27526 .57069 .26715 .56352 Mtetra
.26715 .56352 .27526 .57069 .28762 .56681 .27954 .55961 Mtetra
.27954 .55961 .28762 .56681 .30003 .56292 .29199 .55568 Mtetra
.945 .712 .554 r
.29199 .55568 .30003 .56292 .3202 .43643 .31252 .42891 Mtetra
.657 .75 .919 r
.31252 .42891 .3202 .43643 .33229 .43236 .32465 .42481 Mtetra
.32465 .42481 .33229 .43236 .34444 .42828 .33683 .42068 Mtetra
.33683 .42068 .34444 .42828 .35665 .42417 .34907 .41654 Mtetra
.34907 .41654 .35665 .42417 .36891 .42005 .36136 .41238 Mtetra
.36136 .41238 .36891 .42005 .38122 .41591 .37371 .40821 Mtetra
.37371 .40821 .38122 .41591 .3936 .41174 .38612 .40401 Mtetra
.38612 .40401 .3936 .41174 .40603 .40756 .39859 .39979 Mtetra
.39859 .39979 .40603 .40756 .41852 .40336 .41111 .39555 Mtetra
.41111 .39555 .41852 .40336 .43106 .39914 .4237 .39129 Mtetra
.4237 .39129 .43106 .39914 .44367 .3949 .43634 .38702 Mtetra
.43634 .38702 .44367 .3949 .45633 .39064 .44904 .38272 Mtetra
.44904 .38272 .45633 .39064 .46906 .38636 .4618 .3784 Mtetra
.96 .722 .535 r
.4618 .3784 .46906 .38636 .48315 .28433 .47617 .27617 Mtetra
.664 .741 .908 r
.47617 .27617 .48315 .28433 .49561 .27992 .48866 .27172 Mtetra
.48866 .27172 .49561 .27992 .50812 .27548 .5012 .26725 Mtetra
.5012 .26725 .50812 .27548 .52068 .27103 .51381 .26276 Mtetra
.51381 .26276 .52068 .27103 .53331 .26656 .52647 .25825 Mtetra
.52647 .25825 .53331 .26656 .54599 .26207 .5392 .25372 Mtetra
.5392 .25372 .54599 .26207 .55874 .25755 .55198 .24917 Mtetra
.55198 .24917 .55874 .25755 .57154 .25302 .56482 .24459 Mtetra
.56482 .24459 .57154 .25302 .5844 .24846 .57772 .24 Mtetra
.57772 .24 .5844 .24846 .59732 .24389 .59068 .23538 Mtetra
.59068 .23538 .59732 .24389 .6103 .23929 .6037 .23074 Mtetra
.6037 .23074 .6103 .23929 .62334 .23467 .61678 .22608 Mtetra
.61678 .22608 .62334 .23467 .63645 .23003 .62993 .2214 Mtetra
.62993 .2214 .63645 .23003 .64961 .22536 .64313 .2167 Mtetra
.64313 .2167 .64961 .22536 .66284 .22068 .6564 .21197 Mtetra
.6564 .21197 .66284 .22068 .67612 .21597 .66973 .20722 Mtetra
.66973 .20722 .67612 .21597 .68948 .21124 .68313 .20245 Mtetra
.68313 .20245 .68948 .21124 .70289 .20649 .69659 .19766 Mtetra
.69659 .19766 .70289 .20649 .71637 .20172 .71011 .19284 Mtetra
.71011 .19284 .71637 .20172 .72991 .19692 .72369 .188 Mtetra
.72369 .188 .72991 .19692 .74352 .1921 .73735 .18314 Mtetra
.73735 .18314 .74352 .1921 .75719 .18726 .75106 .17826 Mtetra
.75106 .17826 .75719 .18726 .77093 .18239 .76485 .17335 Mtetra
.76485 .17335 .77093 .18239 .78473 .1775 .7787 .16841 Mtetra
.7787 .16841 .78473 .1775 .7986 .17259 .79262 .16346 Mtetra
.646 .762 .934 r
.13789 .59472 .1464 .60162 .15822 .59789 .14975 .59096 Mtetra
.14975 .59096 .15822 .59789 .1701 .59414 .16166 .58718 Mtetra
.16166 .58718 .1701 .59414 .18204 .59038 .17362 .58338 Mtetra
.17362 .58338 .18204 .59038 .19403 .58659 .18564 .57956 Mtetra
.18564 .57956 .19403 .58659 .20607 .58279 .19772 .57573 Mtetra
.19772 .57573 .20607 .58279 .21817 .57897 .20986 .57188 Mtetra
.20986 .57188 .21817 .57897 .23033 .57514 .22205 .56801 Mtetra
.22205 .56801 .23033 .57514 .24255 .57128 .2343 .56412 Mtetra
.2343 .56412 .24255 .57128 .25482 .56741 .24661 .56021 Mtetra
.24661 .56021 .25482 .56741 .26715 .56352 .25897 .55629 Mtetra
.25897 .55629 .26715 .56352 .27954 .55961 .27139 .55234 Mtetra
.27139 .55234 .27954 .55961 .29199 .55568 .28388 .54838 Mtetra
.945 .712 .554 r
.28388 .54838 .29199 .55568 .31252 .42891 .30477 .42132 Mtetra
.657 .75 .919 r
.30477 .42132 .31252 .42891 .32465 .42481 .31693 .41718 Mtetra
.31693 .41718 .32465 .42481 .33683 .42068 .32915 .41303 Mtetra
.32915 .41303 .33683 .42068 .34907 .41654 .34142 .40885 Mtetra
.34142 .40885 .34907 .41654 .36136 .41238 .35375 .40465 Mtetra
.35375 .40465 .36136 .41238 .37371 .40821 .36614 .40044 Mtetra
.36614 .40044 .37371 .40821 .38612 .40401 .37858 .39621 Mtetra
.37858 .39621 .38612 .40401 .39859 .39979 .39109 .39195 Mtetra
.39109 .39195 .39859 .39979 .41111 .39555 .40365 .38768 Mtetra
.40365 .38768 .41111 .39555 .4237 .39129 .41627 .38338 Mtetra
.41627 .38338 .4237 .39129 .43634 .38702 .42895 .37907 Mtetra
.42895 .37907 .43634 .38702 .44904 .38272 .44169 .37473 Mtetra
.44169 .37473 .44904 .38272 .4618 .3784 .45449 .37038 Mtetra
.96 .722 .535 r
.45449 .37038 .4618 .3784 .47617 .27617 .46912 .26794 Mtetra
.664 .741 .908 r
.46912 .26794 .47617 .27617 .48866 .27172 .48165 .26345 Mtetra
.48165 .26345 .48866 .27172 .5012 .26725 .49423 .25894 Mtetra
.49423 .25894 .5012 .26725 .51381 .26276 .50688 .25442 Mtetra
.50688 .25442 .51381 .26276 .52647 .25825 .51958 .24987 Mtetra
.51958 .24987 .52647 .25825 .5392 .25372 .53234 .2453 Mtetra
.53234 .2453 .5392 .25372 .55198 .24917 .54516 .24071 Mtetra
.54516 .24071 .55198 .24917 .56482 .24459 .55804 .23609 Mtetra
.55804 .23609 .56482 .24459 .57772 .24 .57098 .23146 Mtetra
.57098 .23146 .57772 .24 .59068 .23538 .58398 .2268 Mtetra
.58398 .2268 .59068 .23538 .6037 .23074 .59704 .22212 Mtetra
.59704 .22212 .6037 .23074 .61678 .22608 .61017 .21742 Mtetra
.61017 .21742 .61678 .22608 .62993 .2214 .62335 .2127 Mtetra
.62335 .2127 .62993 .2214 .64313 .2167 .6366 .20796 Mtetra
.6366 .20796 .64313 .2167 .6564 .21197 .64991 .20319 Mtetra
.64991 .20319 .6564 .21197 .66973 .20722 .66328 .1984 Mtetra
.66328 .1984 .66973 .20722 .68313 .20245 .67672 .19359 Mtetra
.67672 .19359 .68313 .20245 .69659 .19766 .69023 .18875 Mtetra
.69023 .18875 .69659 .19766 .71011 .19284 .70379 .18389 Mtetra
.70379 .18389 .71011 .19284 .72369 .188 .71742 .17901 Mtetra
.71742 .17901 .72369 .188 .73735 .18314 .73112 .1741 Mtetra
.73112 .1741 .73735 .18314 .75106 .17826 .74489 .16917 Mtetra
.74489 .16917 .75106 .17826 .76485 .17335 .75872 .16422 Mtetra
.75872 .16422 .76485 .17335 .7787 .16841 .77261 .15924 Mtetra
.77261 .15924 .7787 .16841 .79262 .16346 .78658 .15424 Mtetra
.646 .762 .934 r
.12931 .58776 .13789 .59472 .14975 .59096 .1412 .58396 Mtetra
.1412 .58396 .14975 .59096 .16166 .58718 .15314 .58015 Mtetra
.15314 .58015 .16166 .58718 .17362 .58338 .16514 .57632 Mtetra
.16514 .57632 .17362 .58338 .18564 .57956 .17719 .57247 Mtetra
.17719 .57247 .18564 .57956 .19772 .57573 .1893 .5686 Mtetra
.1893 .5686 .19772 .57573 .20986 .57188 .20147 .56472 Mtetra
.20147 .56472 .20986 .57188 .22205 .56801 .21369 .56081 Mtetra
.21369 .56081 .22205 .56801 .2343 .56412 .22598 .55689 Mtetra
.22598 .55689 .2343 .56412 .24661 .56021 .23832 .55295 Mtetra
.23832 .55295 .24661 .56021 .25897 .55629 .25072 .54899 Mtetra
.25072 .54899 .25897 .55629 .27139 .55234 .26318 .54501 Mtetra
.26318 .54501 .27139 .55234 .28388 .54838 .2757 .54101 Mtetra
.945 .712 .554 r
.2757 .54101 .28388 .54838 .30477 .42132 .29696 .41367 Mtetra
.657 .75 .919 r
.29696 .41367 .30477 .42132 .31693 .41718 .30915 .40949 Mtetra
.30915 .40949 .31693 .41718 .32915 .41303 .3214 .4053 Mtetra
.3214 .4053 .32915 .41303 .34142 .40885 .33371 .40109 Mtetra
.33371 .40109 .34142 .40885 .35375 .40465 .34608 .39686 Mtetra
.34608 .39686 .35375 .40465 .36614 .40044 .3585 .39261 Mtetra
.3585 .39261 .36614 .40044 .37858 .39621 .37098 .38834 Mtetra
.37098 .38834 .37858 .39621 .39109 .39195 .38352 .38404 Mtetra
.38352 .38404 .39109 .39195 .40365 .38768 .39612 .37973 Mtetra
.39612 .37973 .40365 .38768 .41627 .38338 .40878 .3754 Mtetra
.40878 .3754 .41627 .38338 .42895 .37907 .42149 .37105 Mtetra
.42149 .37105 .42895 .37907 .44169 .37473 .43427 .36668 Mtetra
.43427 .36668 .44169 .37473 .45449 .37038 .44711 .36228 Mtetra
.96 .722 .535 r
.44711 .36228 .45449 .37038 .46912 .26794 .46201 .25964 Mtetra
.664 .741 .908 r
.46201 .25964 .46912 .26794 .48165 .26345 .47458 .25511 Mtetra
.47458 .25511 .48165 .26345 .49423 .25894 .4872 .25057 Mtetra
.4872 .25057 .49423 .25894 .50688 .25442 .49988 .246 Mtetra
.49988 .246 .50688 .25442 .51958 .24987 .51262 .24141 Mtetra
.51262 .24141 .51958 .24987 .53234 .2453 .52542 .2368 Mtetra
.52542 .2368 .53234 .2453 .54516 .24071 .53828 .23217 Mtetra
.53828 .23217 .54516 .24071 .55804 .23609 .5512 .22752 Mtetra
.5512 .22752 .55804 .23609 .57098 .23146 .56418 .22284 Mtetra
.56418 .22284 .57098 .23146 .58398 .2268 .57722 .21815 Mtetra
.57722 .21815 .58398 .2268 .59704 .22212 .59033 .21343 Mtetra
.59033 .21343 .59704 .22212 .61017 .21742 .60349 .20869 Mtetra
.60349 .20869 .61017 .21742 .62335 .2127 .61672 .20392 Mtetra
.61672 .20392 .62335 .2127 .6366 .20796 .63001 .19914 Mtetra
.63001 .19914 .6366 .20796 .64991 .20319 .64336 .19433 Mtetra
.64336 .19433 .64991 .20319 .66328 .1984 .65678 .1895 Mtetra
.65678 .1895 .66328 .1984 .67672 .19359 .67026 .18464 Mtetra
.67026 .18464 .67672 .19359 .69023 .18875 .68381 .17976 Mtetra
.68381 .17976 .69023 .18875 .70379 .18389 .69742 .17486 Mtetra
.69742 .17486 .70379 .18389 .71742 .17901 .7111 .16993 Mtetra
.7111 .16993 .71742 .17901 .73112 .1741 .72484 .16498 Mtetra
.72484 .16498 .73112 .1741 .74489 .16917 .73865 .16001 Mtetra
.73865 .16001 .74489 .16917 .75872 .16422 .75253 .15501 Mtetra
.75253 .15501 .75872 .16422 .77261 .15924 .76647 .14999 Mtetra
.76647 .14999 .77261 .15924 .78658 .15424 .78049 .14494 Mtetra
.646 .762 .934 r
.12065 .58074 .12931 .58776 .1412 .58396 .13257 .57691 Mtetra
.13257 .57691 .1412 .58396 .15314 .58015 .14455 .57306 Mtetra
.14455 .57306 .15314 .58015 .16514 .57632 .15657 .5692 Mtetra
.15657 .5692 .16514 .57632 .17719 .57247 .16866 .56532 Mtetra
.16866 .56532 .17719 .57247 .1893 .5686 .1808 .56142 Mtetra
.1808 .56142 .1893 .5686 .20147 .56472 .193 .5575 Mtetra
.193 .5575 .20147 .56472 .21369 .56081 .20526 .55356 Mtetra
.20526 .55356 .21369 .56081 .22598 .55689 .21758 .5496 Mtetra
.21758 .5496 .22598 .55689 .23832 .55295 .22996 .54563 Mtetra
.22996 .54563 .23832 .55295 .25072 .54899 .24239 .54163 Mtetra
.24239 .54163 .25072 .54899 .26318 .54501 .25489 .53762 Mtetra
.25489 .53762 .26318 .54501 .2757 .54101 .26744 .53358 Mtetra
.945 .712 .554 r
.26744 .53358 .2757 .54101 .29696 .41367 .28908 .40595 Mtetra
.657 .75 .919 r
.28908 .40595 .29696 .41367 .30915 .40949 .30131 .40174 Mtetra
.30131 .40174 .30915 .40949 .3214 .4053 .31359 .39751 Mtetra
.31359 .39751 .3214 .4053 .33371 .40109 .32594 .39326 Mtetra
.32594 .39326 .33371 .40109 .34608 .39686 .33834 .38899 Mtetra
.33834 .38899 .34608 .39686 .3585 .39261 .35079 .38471 Mtetra
.35079 .38471 .3585 .39261 .37098 .38834 .36331 .3804 Mtetra
.36331 .3804 .37098 .38834 .38352 .38404 .37589 .37607 Mtetra
.37589 .37607 .38352 .38404 .39612 .37973 .38852 .37172 Mtetra
.38852 .37172 .39612 .37973 .40878 .3754 .40122 .36735 Mtetra
.40122 .36735 .40878 .3754 .42149 .37105 .41397 .36296 Mtetra
.41397 .36296 .42149 .37105 .43427 .36668 .42679 .35855 Mtetra
.42679 .35855 .43427 .36668 .44711 .36228 .43967 .35412 Mtetra
.96 .722 .535 r
.43967 .35412 .44711 .36228 .46201 .25964 .45485 .25127 Mtetra
.664 .741 .908 r
.45485 .25127 .46201 .25964 .47458 .25511 .46745 .24671 Mtetra
.46745 .24671 .47458 .25511 .4872 .25057 .48011 .24212 Mtetra
.48011 .24212 .4872 .25057 .49988 .246 .49283 .23751 Mtetra
.49283 .23751 .49988 .246 .51262 .24141 .50561 .23289 Mtetra
.50561 .23289 .51262 .24141 .52542 .2368 .51844 .22824 Mtetra
.51844 .22824 .52542 .2368 .53828 .23217 .53134 .22356 Mtetra
.53134 .22356 .53828 .23217 .5512 .22752 .5443 .21887 Mtetra
.5443 .21887 .5512 .22752 .56418 .22284 .55732 .21416 Mtetra
.55732 .21416 .56418 .22284 .57722 .21815 .57041 .20942 Mtetra
.57041 .20942 .57722 .21815 .59033 .21343 .58355 .20466 Mtetra
.58355 .20466 .59033 .21343 .60349 .20869 .59676 .19987 Mtetra
.59676 .19987 .60349 .20869 .61672 .20392 .61003 .19507 Mtetra
.61003 .19507 .61672 .20392 .63001 .19914 .62336 .19024 Mtetra
.62336 .19024 .63001 .19914 .64336 .19433 .63676 .18539 Mtetra
.63676 .18539 .64336 .19433 .65678 .1895 .65022 .18051 Mtetra
.65022 .18051 .65678 .1895 .67026 .18464 .66374 .17561 Mtetra
.66374 .17561 .67026 .18464 .68381 .17976 .67734 .17069 Mtetra
.67734 .17069 .68381 .17976 .69742 .17486 .69099 .16575 Mtetra
.69099 .16575 .69742 .17486 .7111 .16993 .70472 .16078 Mtetra
.70472 .16078 .7111 .16993 .72484 .16498 .7185 .15578 Mtetra
.7185 .15578 .72484 .16498 .73865 .16001 .73236 .15076 Mtetra
.73236 .15076 .73865 .16001 .75253 .15501 .74629 .14572 Mtetra
.74629 .14572 .75253 .15501 .76647 .14999 .76028 .14065 Mtetra
.76028 .14065 .76647 .14999 .78049 .14494 .77434 .13556 Mtetra
.541 .336 .55 r
.12752 .44542 .12065 .58074 .13257 .57691 .13905 .44141 Mtetra
.13905 .44141 .13257 .57691 .14455 .57306 .15063 .43739 Mtetra
.15063 .43739 .14455 .57306 .15657 .5692 .16227 .43335 Mtetra
.16227 .43335 .15657 .5692 .16866 .56532 .17396 .42929 Mtetra
.17396 .42929 .16866 .56532 .1808 .56142 .1857 .42521 Mtetra
.1857 .42521 .1808 .56142 .193 .5575 .1975 .42111 Mtetra
.1975 .42111 .193 .5575 .20526 .55356 .20935 .417 Mtetra
.20935 .417 .20526 .55356 .21758 .5496 .22125 .41286 Mtetra
.22125 .41286 .21758 .5496 .22996 .54563 .23321 .40871 Mtetra
.23321 .40871 .22996 .54563 .24239 .54163 .24523 .40453 Mtetra
.24523 .40453 .24239 .54163 .25489 .53762 .2573 .40034 Mtetra
.2573 .40034 .25489 .53762 .26744 .53358 .26942 .39613 Mtetra
0 0 .327 r
.26942 .39613 .26744 .53358 .28908 .40595 .27278 .50852 Mtetra
.496 .237 .452 r
.27278 .50852 .28908 .40595 .30131 .40174 .28544 .50439 Mtetra
.28544 .50439 .30131 .40174 .31359 .39751 .29817 .50025 Mtetra
.29817 .50025 .31359 .39751 .32594 .39326 .31096 .49608 Mtetra
.31096 .49608 .32594 .39326 .33834 .38899 .3238 .4919 Mtetra
.3238 .4919 .33834 .38899 .35079 .38471 .33671 .48769 Mtetra
.33671 .48769 .35079 .38471 .36331 .3804 .34969 .48347 Mtetra
.34969 .48347 .36331 .3804 .37589 .37607 .36273 .47922 Mtetra
.36273 .47922 .37589 .37607 .38852 .37172 .37583 .47495 Mtetra
.37583 .47495 .38852 .37172 .40122 .36735 .38899 .47067 Mtetra
.38899 .47067 .40122 .36735 .41397 .36296 .40223 .46636 Mtetra
.40223 .46636 .41397 .36296 .42679 .35855 .41552 .46202 Mtetra
.41552 .46202 .42679 .35855 .43967 .35412 .42888 .45767 Mtetra
.851 .715 .188 r
.42888 .45767 .43967 .35412 .45485 .25127 .44747 .24881 Mtetra
.596 .903 .985 r
.44747 .24881 .45485 .25127 .46745 .24671 .46013 .24421 Mtetra
.46013 .24421 .46745 .24671 .48011 .24212 .47285 .23959 Mtetra
.47285 .23959 .48011 .24212 .49283 .23751 .48564 .23495 Mtetra
.48564 .23495 .49283 .23751 .50561 .23289 .49848 .23028 Mtetra
.49848 .23028 .50561 .23289 .51844 .22824 .51138 .2256 Mtetra
.51138 .2256 .51844 .22824 .53134 .22356 .52435 .22089 Mtetra
.52435 .22089 .53134 .22356 .5443 .21887 .53737 .21616 Mtetra
.53737 .21616 .5443 .21887 .55732 .21416 .55046 .21141 Mtetra
.55046 .21141 .55732 .21416 .57041 .20942 .56361 .20664 Mtetra
.56361 .20664 .57041 .20942 .58355 .20466 .57682 .20184 Mtetra
.57682 .20184 .58355 .20466 .59676 .19987 .5901 .19702 Mtetra
.828 .948 .899 r
.5901 .19702 .59676 .19987 .61003 .19507 .60328 .18614 Mtetra
.664 .741 .908 r
.60328 .18614 .61003 .19507 .62336 .19024 .61665 .18126 Mtetra
.61665 .18126 .62336 .19024 .63676 .18539 .63009 .17637 Mtetra
.63009 .17637 .63676 .18539 .65022 .18051 .6436 .17145 Mtetra
.6436 .17145 .65022 .18051 .66374 .17561 .65717 .16651 Mtetra
.65717 .16651 .66374 .17561 .67734 .17069 .6708 .16154 Mtetra
.6708 .16154 .67734 .17069 .69099 .16575 .68451 .15655 Mtetra
.68451 .15655 .69099 .16575 .70472 .16078 .69828 .15154 Mtetra
.69828 .15154 .70472 .16078 .7185 .15578 .71211 .1465 Mtetra
.71211 .1465 .7185 .15578 .73236 .15076 .72601 .14144 Mtetra
.72601 .14144 .73236 .15076 .74629 .14572 .73999 .13635 Mtetra
.73999 .13635 .74629 .14572 .76028 .14065 .75403 .13123 Mtetra
.75403 .13123 .76028 .14065 .77434 .13556 .76814 .12609 Mtetra
.657 .75 .918 r
.11911 .43801 .12752 .44542 .13905 .44141 .13067 .43397 Mtetra
.13067 .43397 .13905 .44141 .15063 .43739 .14229 .42991 Mtetra
.14229 .42991 .15063 .43739 .16227 .43335 .15395 .42584 Mtetra
.15395 .42584 .16227 .43335 .17396 .42929 .16567 .42174 Mtetra
.16567 .42174 .17396 .42929 .1857 .42521 .17744 .41763 Mtetra
.17744 .41763 .1857 .42521 .1975 .42111 .18927 .4135 Mtetra
.18927 .4135 .1975 .42111 .20935 .417 .20115 .40935 Mtetra
.20115 .40935 .20935 .417 .22125 .41286 .21309 .40518 Mtetra
.21309 .40518 .22125 .41286 .23321 .40871 .22508 .40099 Mtetra
.22508 .40099 .23321 .40871 .24523 .40453 .23713 .39678 Mtetra
.23713 .39678 .24523 .40453 .2573 .40034 .24923 .39255 Mtetra
.24923 .39255 .2573 .40034 .26942 .39613 .26139 .3883 Mtetra
.954 .652 .423 r
.26139 .3883 .26942 .39613 .27278 .50852 .26445 .50089 Mtetra
.647 .761 .932 r
.26445 .50089 .27278 .50852 .28544 .50439 .27715 .49672 Mtetra
.27715 .49672 .28544 .50439 .29817 .50025 .28991 .49254 Mtetra
.28991 .49254 .29817 .50025 .31096 .49608 .30274 .48834 Mtetra
.30274 .48834 .31096 .49608 .3238 .4919 .31562 .48412 Mtetra
.31562 .48412 .3238 .4919 .33671 .48769 .32857 .47988 Mtetra
.32857 .47988 .33671 .48769 .34969 .48347 .34159 .47561 Mtetra
.34159 .47561 .34969 .48347 .36273 .47922 .35466 .47133 Mtetra
.35466 .47133 .36273 .47922 .37583 .47495 .3678 .46702 Mtetra
.3678 .46702 .37583 .47495 .38899 .47067 .38101 .46269 Mtetra
.38101 .46269 .38899 .47067 .40223 .46636 .39428 .45834 Mtetra
.39428 .45834 .40223 .46636 .41552 .46202 .40762 .45397 Mtetra
.40762 .45397 .41552 .46202 .42888 .45767 .42102 .44958 Mtetra
.965 .707 .494 r
.42102 .44958 .42888 .45767 .44747 .24881 .44016 .2403 Mtetra
.663 .742 .909 r
.44016 .2403 .44747 .24881 .46013 .24421 .45286 .23566 Mtetra
.45286 .23566 .46013 .24421 .47285 .23959 .46562 .231 Mtetra
.46562 .231 .47285 .23959 .48564 .23495 .47844 .22632 Mtetra
.47844 .22632 .48564 .23495 .49848 .23028 .49133 .22162 Mtetra
.49133 .22162 .49848 .23028 .51138 .2256 .50427 .21689 Mtetra
.50427 .21689 .51138 .2256 .52435 .22089 .51727 .21214 Mtetra
.51727 .21214 .52435 .22089 .53737 .21616 .53034 .20737 Mtetra
.53034 .20737 .53737 .21616 .55046 .21141 .54347 .20258 Mtetra
.54347 .20258 .55046 .21141 .56361 .20664 .55666 .19776 Mtetra
.55666 .19776 .56361 .20664 .57682 .20184 .56991 .19292 Mtetra
.56991 .19292 .57682 .20184 .5901 .19702 .58323 .18806 Mtetra
.796 .781 .839 r
.58323 .18806 .5901 .19702 .60328 .18614 .59647 .17712 Mtetra
.664 .741 .908 r
.59647 .17712 .60328 .18614 .61665 .18126 .60989 .17221 Mtetra
.60989 .17221 .61665 .18126 .63009 .17637 .62337 .16727 Mtetra
.62337 .16727 .63009 .17637 .6436 .17145 .63692 .16231 Mtetra
.63692 .16231 .6436 .17145 .65717 .16651 .65053 .15732 Mtetra
.65053 .15732 .65717 .16651 .6708 .16154 .66421 .15231 Mtetra
.66421 .15231 .6708 .16154 .68451 .15655 .67796 .14728 Mtetra
.67796 .14728 .68451 .15655 .69828 .15154 .69178 .14222 Mtetra
.69178 .14222 .69828 .15154 .71211 .1465 .70566 .13713 Mtetra
.70566 .13713 .71211 .1465 .72601 .14144 .71961 .13202 Mtetra
.71961 .13202 .72601 .14144 .73999 .13635 .73363 .12689 Mtetra
.73363 .12689 .73999 .13635 .75403 .13123 .74772 .12173 Mtetra
.74772 .12173 .75403 .13123 .76814 .12609 .76188 .11654 Mtetra
.657 .75 .918 r
.11063 .43054 .11911 .43801 .13067 .43397 .12222 .42647 Mtetra
.12222 .42647 .13067 .43397 .14229 .42991 .13387 .42238 Mtetra
.13387 .42238 .14229 .42991 .15395 .42584 .14556 .41827 Mtetra
.14556 .41827 .15395 .42584 .16567 .42174 .15731 .41414 Mtetra
.15731 .41414 .16567 .42174 .17744 .41763 .16912 .40999 Mtetra
.16912 .40999 .17744 .41763 .18927 .4135 .18098 .40582 Mtetra
.18098 .40582 .18927 .4135 .20115 .40935 .19289 .40163 Mtetra
.19289 .40163 .20115 .40935 .21309 .40518 .20486 .39743 Mtetra
.20486 .39743 .21309 .40518 .22508 .40099 .21688 .3932 Mtetra
.21688 .3932 .22508 .40099 .23713 .39678 .22896 .38896 Mtetra
.22896 .38896 .23713 .39678 .24923 .39255 .2411 .38469 Mtetra
.2411 .38469 .24923 .39255 .26139 .3883 .25329 .38041 Mtetra
.954 .652 .423 r
.25329 .38041 .26139 .3883 .26445 .50089 .25605 .49319 Mtetra
.647 .761 .932 r
.25605 .49319 .26445 .50089 .27715 .49672 .26879 .48899 Mtetra
.26879 .48899 .27715 .49672 .28991 .49254 .28158 .48477 Mtetra
.28158 .48477 .28991 .49254 .30274 .48834 .29445 .48053 Mtetra
.29445 .48053 .30274 .48834 .31562 .48412 .30737 .47627 Mtetra
.30737 .47627 .31562 .48412 .32857 .47988 .32036 .47199 Mtetra
.32036 .47199 .32857 .47988 .34159 .47561 .33341 .46768 Mtetra
.33341 .46768 .34159 .47561 .35466 .47133 .34653 .46336 Mtetra
.34653 .46336 .35466 .47133 .3678 .46702 .35971 .45901 Mtetra
.35971 .45901 .3678 .46702 .38101 .46269 .37295 .45465 Mtetra
.37295 .45465 .38101 .46269 .39428 .45834 .38627 .45026 Mtetra
.38627 .45026 .39428 .45834 .40762 .45397 .39965 .44585 Mtetra
.39965 .44585 .40762 .45397 .42102 .44958 .41309 .44141 Mtetra
.965 .707 .494 r
.41309 .44141 .42102 .44958 .44016 .2403 .43279 .23172 Mtetra
.663 .742 .909 r
.43279 .23172 .44016 .2403 .45286 .23566 .44553 .22704 Mtetra
.44553 .22704 .45286 .23566 .46562 .231 .45833 .22234 Mtetra
.45833 .22234 .46562 .231 .47844 .22632 .47119 .21762 Mtetra
.47119 .21762 .47844 .22632 .49133 .22162 .48411 .21288 Mtetra
.48411 .21288 .49133 .22162 .50427 .21689 .49709 .20811 Mtetra
.49709 .20811 .50427 .21689 .51727 .21214 .51014 .20332 Mtetra
.51014 .20332 .51727 .21214 .53034 .20737 .52324 .1985 Mtetra
.52324 .1985 .53034 .20737 .54347 .20258 .53641 .19367 Mtetra
.53641 .19367 .54347 .20258 .55666 .19776 .54965 .18881 Mtetra
.54965 .18881 .55666 .19776 .56991 .19292 .56294 .18392 Mtetra
.56294 .18392 .56991 .19292 .58323 .18806 .5763 .17902 Mtetra
.796 .781 .839 r
.5763 .17902 .58323 .18806 .59647 .17712 .5896 .16803 Mtetra
.664 .741 .908 r
.5896 .16803 .59647 .17712 .60989 .17221 .60306 .16307 Mtetra
.60306 .16307 .60989 .17221 .62337 .16727 .61659 .15809 Mtetra
.61659 .15809 .62337 .16727 .63692 .16231 .63018 .15308 Mtetra
.63018 .15308 .63692 .16231 .65053 .15732 .64384 .14805 Mtetra
.64384 .14805 .65053 .15732 .66421 .15231 .65757 .143 Mtetra
.65757 .143 .66421 .15231 .67796 .14728 .67136 .13792 Mtetra
.67136 .13792 .67796 .14728 .69178 .14222 .68522 .13281 Mtetra
.68522 .13281 .69178 .14222 .70566 .13713 .69915 .12768 Mtetra
.69915 .12768 .70566 .13713 .71961 .13202 .71315 .12252 Mtetra
.71315 .12252 .71961 .13202 .73363 .12689 .72722 .11734 Mtetra
.72722 .11734 .73363 .12689 .74772 .12173 .74135 .11213 Mtetra
.74135 .11213 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.657 .75 .918 r
.10208 .42301 .11063 .43054 .12222 .42647 .1137 .4189 Mtetra
.1137 .4189 .12222 .42647 .13387 .42238 .12538 .41477 Mtetra
.12538 .41477 .13387 .42238 .14556 .41827 .1371 .41063 Mtetra
.1371 .41063 .14556 .41827 .15731 .41414 .14888 .40646 Mtetra
.14888 .40646 .15731 .41414 .16912 .40999 .16072 .40228 Mtetra
.16072 .40228 .16912 .40999 .18098 .40582 .17261 .39808 Mtetra
.17261 .39808 .18098 .40582 .19289 .40163 .18455 .39385 Mtetra
.18455 .39385 .19289 .40163 .20486 .39743 .19655 .38961 Mtetra
.19655 .38961 .20486 .39743 .21688 .3932 .20861 .38535 Mtetra
.20861 .38535 .21688 .3932 .22896 .38896 .22072 .38107 Mtetra
.22072 .38107 .22896 .38896 .2411 .38469 .23289 .37677 Mtetra
.23289 .37677 .2411 .38469 .25329 .38041 .24512 .37244 Mtetra
.954 .652 .423 r
.24512 .37244 .25329 .38041 .25605 .49319 .24757 .48542 Mtetra
.647 .761 .932 r
.24757 .48542 .25605 .49319 .26879 .48899 .26034 .48118 Mtetra
.26034 .48118 .26879 .48899 .28158 .48477 .27318 .47693 Mtetra
.27318 .47693 .28158 .48477 .29445 .48053 .28608 .47265 Mtetra
.28608 .47265 .29445 .48053 .30737 .47627 .29904 .46835 Mtetra
.29904 .46835 .30737 .47627 .32036 .47199 .31207 .46403 Mtetra
.31207 .46403 .32036 .47199 .33341 .46768 .32516 .45968 Mtetra
.32516 .45968 .33341 .46768 .34653 .46336 .33831 .45532 Mtetra
.33831 .45532 .34653 .46336 .35971 .45901 .35153 .45093 Mtetra
.35153 .45093 .35971 .45901 .37295 .45465 .36482 .44653 Mtetra
.36482 .44653 .37295 .45465 .38627 .45026 .37818 .4421 Mtetra
.37818 .4421 .38627 .45026 .39965 .44585 .3916 .43765 Mtetra
.3916 .43765 .39965 .44585 .41309 .44141 .40509 .43317 Mtetra
.965 .707 .494 r
.40509 .43317 .41309 .44141 .43279 .23172 .42536 .22307 Mtetra
.663 .742 .909 r
.42536 .22307 .43279 .23172 .44553 .22704 .43814 .21835 Mtetra
.43814 .21835 .44553 .22704 .45833 .22234 .45097 .21361 Mtetra
.45097 .21361 .45833 .22234 .47119 .21762 .46387 .20884 Mtetra
.46387 .20884 .47119 .21762 .48411 .21288 .47683 .20406 Mtetra
.47683 .20406 .48411 .21288 .49709 .20811 .48986 .19925 Mtetra
.48986 .19925 .49709 .20811 .51014 .20332 .50294 .19441 Mtetra
.50294 .19441 .51014 .20332 .52324 .1985 .51609 .18956 Mtetra
.51609 .18956 .52324 .1985 .53641 .19367 .5293 .18468 Mtetra
.5293 .18468 .53641 .19367 .54965 .18881 .54257 .17977 Mtetra
.54257 .17977 .54965 .18881 .56294 .18392 .55591 .17485 Mtetra
.55591 .17485 .56294 .18392 .5763 .17902 .56931 .1699 Mtetra
.796 .781 .839 r
.56931 .1699 .5763 .17902 .5896 .16803 .58266 .15886 Mtetra
.664 .741 .908 r
.58266 .15886 .5896 .16803 .60306 .16307 .59617 .15386 Mtetra
.59617 .15386 .60306 .16307 .61659 .15809 .60974 .14883 Mtetra
.60974 .14883 .61659 .15809 .63018 .15308 .62338 .14378 Mtetra
.62338 .14378 .63018 .15308 .64384 .14805 .63708 .1387 Mtetra
.63708 .1387 .64384 .14805 .65757 .143 .65086 .1336 Mtetra
.65086 .1336 .65757 .143 .67136 .13792 .6647 .12847 Mtetra
.6647 .12847 .67136 .13792 .68522 .13281 .6786 .12332 Mtetra
.6786 .12332 .68522 .13281 .69915 .12768 .69258 .11814 Mtetra
.69258 .11814 .69915 .12768 .71315 .12252 .70663 .11294 Mtetra
.70663 .11294 .71315 .12252 .72722 .11734 .72074 .10771 Mtetra
.72074 .10771 .72722 .11734 .74135 .11213 .73493 .10245 Mtetra
.73493 .10245 .74135 .11213 .75556 .1069 .74918 .09717 Mtetra
.657 .75 .918 r
.09346 .41541 .10208 .42301 .1137 .4189 .10511 .41127 Mtetra
.10511 .41127 .1137 .4189 .12538 .41477 .11682 .4071 Mtetra
.11682 .4071 .12538 .41477 .1371 .41063 .12857 .40292 Mtetra
.12857 .40292 .1371 .41063 .14888 .40646 .14038 .39872 Mtetra
.14038 .39872 .14888 .40646 .16072 .40228 .15225 .3945 Mtetra
.15225 .3945 .16072 .40228 .17261 .39808 .16417 .39027 Mtetra
.16417 .39027 .17261 .39808 .18455 .39385 .17615 .38601 Mtetra
.17615 .38601 .18455 .39385 .19655 .38961 .18818 .38173 Mtetra
.18818 .38173 .19655 .38961 .20861 .38535 .20027 .37743 Mtetra
.20027 .37743 .20861 .38535 .22072 .38107 .21241 .37311 Mtetra
.21241 .37311 .22072 .38107 .23289 .37677 .22462 .36877 Mtetra
.22462 .36877 .23289 .37677 .24512 .37244 .23688 .36441 Mtetra
.954 .652 .423 r
.23688 .36441 .24512 .37244 .24757 .48542 .23901 .47758 Mtetra
.647 .761 .932 r
.23901 .47758 .24757 .48542 .26034 .48118 .25182 .47331 Mtetra
.25182 .47331 .26034 .48118 .27318 .47693 .2647 .46901 Mtetra
.2647 .46901 .27318 .47693 .28608 .47265 .27763 .46469 Mtetra
.27763 .46469 .28608 .47265 .29904 .46835 .29063 .46035 Mtetra
.29063 .46035 .29904 .46835 .31207 .46403 .3037 .45599 Mtetra
.3037 .45599 .31207 .46403 .32516 .45968 .31683 .45161 Mtetra
.31683 .45161 .32516 .45968 .33831 .45532 .33003 .44721 Mtetra
.33003 .44721 .33831 .45532 .35153 .45093 .34329 .44278 Mtetra
.34329 .44278 .35153 .45093 .36482 .44653 .35662 .43833 Mtetra
.35662 .43833 .36482 .44653 .37818 .4421 .37001 .43386 Mtetra
.37001 .43386 .37818 .4421 .3916 .43765 .38347 .42937 Mtetra
.38347 .42937 .3916 .43765 .40509 .43317 .397 .42485 Mtetra
.965 .707 .494 r
.397 .42485 .40509 .43317 .42536 .22307 .41786 .21434 Mtetra
.663 .742 .909 r
.41786 .21434 .42536 .22307 .43814 .21835 .43068 .20958 Mtetra
.43068 .20958 .43814 .21835 .45097 .21361 .44355 .20479 Mtetra
.44355 .20479 .45097 .21361 .46387 .20884 .45649 .19999 Mtetra
.45649 .19999 .46387 .20884 .47683 .20406 .46949 .19516 Mtetra
.46949 .19516 .47683 .20406 .48986 .19925 .48255 .19031 Mtetra
.48255 .19031 .48986 .19925 .50294 .19441 .49568 .18543 Mtetra
.49568 .18543 .50294 .19441 .51609 .18956 .50887 .18053 Mtetra
.50887 .18053 .51609 .18956 .5293 .18468 .52212 .17561 Mtetra
.52212 .17561 .5293 .18468 .54257 .17977 .53543 .17066 Mtetra
.53543 .17066 .54257 .17977 .55591 .17485 .54881 .16569 Mtetra
.54881 .16569 .55591 .17485 .56931 .1699 .56226 .16069 Mtetra
.796 .781 .839 r
.56226 .16069 .56931 .1699 .58266 .15886 .57567 .1496 Mtetra
.664 .741 .908 r
.57567 .1496 .58266 .15886 .59617 .15386 .58922 .14455 Mtetra
.58922 .14455 .59617 .15386 .60974 .14883 .60283 .13948 Mtetra
.60283 .13948 .60974 .14883 .62338 .14378 .61652 .13438 Mtetra
.61652 .13438 .62338 .14378 .63708 .1387 .63027 .12926 Mtetra
.63027 .12926 .63708 .1387 .65086 .1336 .64408 .12411 Mtetra
.64408 .12411 .65086 .1336 .6647 .12847 .65797 .11894 Mtetra
.65797 .11894 .6647 .12847 .6786 .12332 .67193 .11374 Mtetra
.67193 .11374 .6786 .12332 .69258 .11814 .68595 .10851 Mtetra
.68595 .10851 .69258 .11814 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.657 .75 .918 r
.08477 .40775 .09346 .41541 .10511 .41127 .09645 .40357 Mtetra
.09645 .40357 .10511 .41127 .11682 .4071 .10818 .39937 Mtetra
.10818 .39937 .11682 .4071 .12857 .40292 .11997 .39515 Mtetra
.11997 .39515 .12857 .40292 .14038 .39872 .13181 .39092 Mtetra
.13181 .39092 .14038 .39872 .15225 .3945 .14371 .38666 Mtetra
.14371 .38666 .15225 .3945 .16417 .39027 .15566 .38239 Mtetra
.15566 .38239 .16417 .39027 .17615 .38601 .16767 .37809 Mtetra
.16767 .37809 .17615 .38601 .18818 .38173 .17973 .37378 Mtetra
.17973 .37378 .18818 .38173 .20027 .37743 .19185 .36944 Mtetra
.19185 .36944 .20027 .37743 .21241 .37311 .20403 .36508 Mtetra
.20403 .36508 .21241 .37311 .22462 .36877 .21627 .36071 Mtetra
.21627 .36071 .22462 .36877 .23688 .36441 .22856 .35631 Mtetra
.954 .652 .423 r
.22856 .35631 .23688 .36441 .23901 .47758 .23038 .46967 Mtetra
.647 .761 .932 r
.23038 .46967 .23901 .47758 .25182 .47331 .24323 .46536 Mtetra
.24323 .46536 .25182 .47331 .2647 .46901 .25614 .46102 Mtetra
.25614 .46102 .2647 .46901 .27763 .46469 .26911 .45667 Mtetra
.26911 .45667 .27763 .46469 .29063 .46035 .28215 .45229 Mtetra
.28215 .45229 .29063 .46035 .3037 .45599 .29526 .44789 Mtetra
.29526 .44789 .3037 .45599 .31683 .45161 .30843 .44346 Mtetra
.30843 .44346 .31683 .45161 .33003 .44721 .32166 .43902 Mtetra
.32166 .43902 .33003 .44721 .34329 .44278 .33496 .43455 Mtetra
.33496 .43455 .34329 .44278 .35662 .43833 .34833 .43006 Mtetra
.34833 .43006 .35662 .43833 .37001 .43386 .36177 .42555 Mtetra
.36177 .42555 .37001 .43386 .38347 .42937 .37527 .42101 Mtetra
.37527 .42101 .38347 .42937 .397 .42485 .38885 .41646 Mtetra
.965 .707 .494 r
.38885 .41646 .397 .42485 .41786 .21434 .4103 .20553 Mtetra
.663 .742 .909 r
.4103 .20553 .41786 .21434 .43068 .20958 .42315 .20073 Mtetra
.42315 .20073 .43068 .20958 .44355 .20479 .43607 .1959 Mtetra
.43607 .1959 .44355 .20479 .45649 .19999 .44904 .19105 Mtetra
.44904 .19105 .45649 .19999 .46949 .19516 .46208 .18618 Mtetra
.46208 .18618 .46949 .19516 .48255 .19031 .47519 .18129 Mtetra
.47519 .18129 .48255 .19031 .49568 .18543 .48835 .17637 Mtetra
.48835 .17637 .49568 .18543 .50887 .18053 .50158 .17142 Mtetra
.50158 .17142 .50887 .18053 .52212 .17561 .51487 .16646 Mtetra
.51487 .16646 .52212 .17561 .53543 .17066 .52823 .16146 Mtetra
.52823 .16146 .53543 .17066 .54881 .16569 .54166 .15645 Mtetra
.54166 .15645 .54881 .16569 .56226 .16069 .55515 .15141 Mtetra
.796 .781 .839 r
.55515 .15141 .56226 .16069 .57567 .1496 .56861 .14026 Mtetra
.664 .741 .908 r
.56861 .14026 .57567 .1496 .58922 .14455 .5822 .13517 Mtetra
.5822 .13517 .58922 .14455 .60283 .13948 .59586 .13005 Mtetra
.59586 .13005 .60283 .13948 .61652 .13438 .60959 .12491 Mtetra
.60959 .12491 .61652 .13438 .63027 .12926 .62339 .11974 Mtetra
.62339 .11974 .63027 .12926 .64408 .12411 .63725 .11454 Mtetra
.63725 .11454 .64408 .12411 .65797 .11894 .65119 .10932 Mtetra
.65119 .10932 .65797 .11894 .67193 .11374 .66519 .10407 Mtetra
.66519 .10407 .67193 .11374 .68595 .10851 .67926 .0988 Mtetra
.67926 .0988 .68595 .10851 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.657 .75 .918 r
.076 .40002 .08477 .40775 .09645 .40357 .08771 .3958 Mtetra
.08771 .3958 .09645 .40357 .10818 .39937 .09947 .39157 Mtetra
.09947 .39157 .10818 .39937 .11997 .39515 .11129 .38732 Mtetra
.11129 .38732 .11997 .39515 .13181 .39092 .12316 .38305 Mtetra
.12316 .38305 .13181 .39092 .14371 .38666 .13509 .37875 Mtetra
.13509 .37875 .14371 .38666 .15566 .38239 .14707 .37444 Mtetra
.14707 .37444 .15566 .38239 .16767 .37809 .15911 .37011 Mtetra
.15911 .37011 .16767 .37809 .17973 .37378 .17121 .36575 Mtetra
.17121 .36575 .17973 .37378 .19185 .36944 .18337 .36138 Mtetra
.18337 .36138 .19185 .36944 .20403 .36508 .19558 .35699 Mtetra
.19558 .35699 .20403 .36508 .21627 .36071 .20785 .35257 Mtetra
.20785 .35257 .21627 .36071 .22856 .35631 .22018 .34813 Mtetra
.954 .652 .423 r
.22018 .34813 .22856 .35631 .23038 .46967 .22167 .46169 Mtetra
.647 .761 .932 r
.22167 .46169 .23038 .46967 .24323 .46536 .23455 .45734 Mtetra
.23455 .45734 .24323 .46536 .25614 .46102 .2475 .45296 Mtetra
.2475 .45296 .25614 .46102 .26911 .45667 .26051 .44856 Mtetra
.26051 .44856 .26911 .45667 .28215 .45229 .27359 .44415 Mtetra
.27359 .44415 .28215 .45229 .29526 .44789 .28673 .4397 Mtetra
.28673 .4397 .29526 .44789 .30843 .44346 .29994 .43524 Mtetra
.29994 .43524 .30843 .44346 .32166 .43902 .31322 .43075 Mtetra
.31322 .43075 .32166 .43902 .33496 .43455 .32656 .42624 Mtetra
.32656 .42624 .33496 .43455 .34833 .43006 .33997 .42171 Mtetra
.33997 .42171 .34833 .43006 .36177 .42555 .35345 .41716 Mtetra
.35345 .41716 .36177 .42555 .37527 .42101 .367 .41258 Mtetra
.367 .41258 .37527 .42101 .38885 .41646 .38061 .40798 Mtetra
.965 .707 .494 r
.38061 .40798 .38885 .41646 .4103 .20553 .40267 .19665 Mtetra
.663 .742 .909 r
.40267 .19665 .4103 .20553 .42315 .20073 .41556 .1918 Mtetra
.41556 .1918 .42315 .20073 .43607 .1959 .42851 .18693 Mtetra
.42851 .18693 .43607 .1959 .44904 .19105 .44153 .18204 Mtetra
.44153 .18204 .44904 .19105 .46208 .18618 .45461 .17712 Mtetra
.45461 .17712 .46208 .18618 .47519 .18129 .46775 .17219 Mtetra
.46775 .17219 .47519 .18129 .48835 .17637 .48096 .16722 Mtetra
.48096 .16722 .48835 .17637 .50158 .17142 .49423 .16223 Mtetra
.49423 .16223 .50158 .17142 .51487 .16646 .50757 .15722 Mtetra
.50757 .15722 .51487 .16646 .52823 .16146 .52097 .15219 Mtetra
.52097 .15219 .52823 .16146 .54166 .15645 .53443 .14712 Mtetra
.53443 .14712 .54166 .15645 .55515 .15141 .54796 .14204 Mtetra
.796 .781 .839 r
.54796 .14204 .55515 .15141 .56861 .14026 .56149 .13084 Mtetra
.664 .741 .908 r
.56149 .13084 .56861 .14026 .5822 .13517 .57513 .1257 Mtetra
.57513 .1257 .5822 .13517 .59586 .13005 .58883 .12053 Mtetra
.58883 .12053 .59586 .13005 .60959 .12491 .60261 .11534 Mtetra
.60261 .11534 .60959 .12491 .62339 .11974 .61645 .11012 Mtetra
.61645 .11012 .62339 .11974 .63725 .11454 .63036 .10488 Mtetra
.63036 .10488 .63725 .11454 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09431 Mtetra
.65839 .09431 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.657 .75 .918 r
.06716 .39222 .076 .40002 .08771 .3958 .07889 .38797 Mtetra
.07889 .38797 .08771 .3958 .09947 .39157 .09069 .3837 Mtetra
.09069 .3837 .09947 .39157 .11129 .38732 .10253 .37942 Mtetra
.10253 .37942 .11129 .38732 .12316 .38305 .11444 .37511 Mtetra
.11444 .37511 .12316 .38305 .13509 .37875 .1264 .37078 Mtetra
.1264 .37078 .13509 .37875 .14707 .37444 .13841 .36643 Mtetra
.13841 .36643 .14707 .37444 .15911 .37011 .15049 .36205 Mtetra
.15049 .36205 .15911 .37011 .17121 .36575 .16262 .35766 Mtetra
.16262 .35766 .17121 .36575 .18337 .36138 .1748 .35325 Mtetra
.1748 .35325 .18337 .36138 .19558 .35699 .18705 .34882 Mtetra
.18705 .34882 .19558 .35699 .20785 .35257 .19935 .34436 Mtetra
.19935 .34436 .20785 .35257 .22018 .34813 .21171 .33989 Mtetra
.954 .652 .423 r
.21171 .33989 .22018 .34813 .22167 .46169 .21287 .45364 Mtetra
.647 .761 .932 r
.21287 .45364 .22167 .46169 .23455 .45734 .2258 .44924 Mtetra
.2258 .44924 .23455 .45734 .2475 .45296 .23878 .44483 Mtetra
.23878 .44483 .2475 .45296 .26051 .44856 .25183 .44039 Mtetra
.25183 .44039 .26051 .44856 .27359 .44415 .26495 .43593 Mtetra
.26495 .43593 .27359 .44415 .28673 .4397 .27813 .43145 Mtetra
.27813 .43145 .28673 .4397 .29994 .43524 .29138 .42694 Mtetra
.29138 .42694 .29994 .43524 .31322 .43075 .3047 .42241 Mtetra
.3047 .42241 .31322 .43075 .32656 .42624 .31808 .41786 Mtetra
.31808 .41786 .32656 .42624 .33997 .42171 .33153 .41329 Mtetra
.33153 .41329 .33997 .42171 .35345 .41716 .34505 .40869 Mtetra
.34505 .40869 .35345 .41716 .367 .41258 .35864 .40407 Mtetra
.35864 .40407 .367 .41258 .38061 .40798 .3723 .39942 Mtetra
.965 .707 .494 r
.3723 .39942 .38061 .40798 .40267 .19665 .39497 .18768 Mtetra
.663 .742 .909 r
.39497 .18768 .40267 .19665 .41556 .1918 .4079 .18279 Mtetra
.4079 .18279 .41556 .1918 .42851 .18693 .42089 .17788 Mtetra
.42089 .17788 .42851 .18693 .44153 .18204 .43395 .17295 Mtetra
.43395 .17295 .44153 .18204 .45461 .17712 .44707 .16799 Mtetra
.44707 .16799 .45461 .17712 .46775 .17219 .46025 .163 Mtetra
.46025 .163 .46775 .17219 .48096 .16722 .4735 .15799 Mtetra
.4735 .15799 .48096 .16722 .49423 .16223 .48681 .15296 Mtetra
.48681 .15296 .49423 .16223 .50757 .15722 .50019 .1479 Mtetra
.50019 .1479 .50757 .15722 .52097 .15219 .51363 .14282 Mtetra
.51363 .14282 .52097 .15219 .53443 .14712 .52714 .13772 Mtetra
.52714 .13772 .53443 .14712 .54796 .14204 .54072 .13258 Mtetra
.796 .781 .839 r
.54072 .13258 .54796 .14204 .56149 .13084 .5543 .12133 Mtetra
.664 .741 .908 r
.5543 .12133 .56149 .13084 .57513 .1257 .56798 .11614 Mtetra
.56798 .11614 .57513 .1257 .58883 .12053 .58173 .11093 Mtetra
.58173 .11093 .58883 .12053 .60261 .11534 .59555 .10569 Mtetra
.59555 .10569 .60261 .11534 .61645 .11012 .60944 .10042 Mtetra
.60944 .10042 .61645 .11012 .63036 .10488 .6234 .09513 Mtetra
.6234 .09513 .63036 .10488 .64434 .09961 .63742 .08981 Mtetra
.63742 .08981 .64434 .09961 .65839 .09431 .65152 .08447 Mtetra
.65152 .08447 .65839 .09431 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.657 .75 .918 r
.05824 .38436 .06716 .39222 .07889 .38797 .07 .38008 Mtetra
.07 .38008 .07889 .38797 .09069 .3837 .08183 .37577 Mtetra
.08183 .37577 .09069 .3837 .10253 .37942 .09371 .37144 Mtetra
.09371 .37144 .10253 .37942 .11444 .37511 .10564 .3671 Mtetra
.10564 .3671 .11444 .37511 .1264 .37078 .11763 .36273 Mtetra
.11763 .36273 .1264 .37078 .13841 .36643 .12968 .35834 Mtetra
.12968 .35834 .13841 .36643 .15049 .36205 .14178 .35393 Mtetra
.14178 .35393 .15049 .36205 .16262 .35766 .15395 .3495 Mtetra
.15395 .3495 .16262 .35766 .1748 .35325 .16617 .34505 Mtetra
.16617 .34505 .1748 .35325 .18705 .34882 .17844 .34058 Mtetra
.17844 .34058 .18705 .34882 .19935 .34436 .19078 .33608 Mtetra
.19078 .33608 .19935 .34436 .21171 .33989 .20318 .33157 Mtetra
.954 .652 .423 r
.20318 .33157 .21171 .33989 .21287 .45364 .204 .44551 Mtetra
.647 .761 .932 r
.204 .44551 .21287 .45364 .2258 .44924 .21696 .44107 Mtetra
.21696 .44107 .2258 .44924 .23878 .44483 .22998 .43662 Mtetra
.22998 .43662 .23878 .44483 .25183 .44039 .24307 .43214 Mtetra
.24307 .43214 .25183 .44039 .26495 .43593 .25623 .42763 Mtetra
.25623 .42763 .26495 .43593 .27813 .43145 .26945 .42311 Mtetra
.26945 .42311 .27813 .43145 .29138 .42694 .28274 .41856 Mtetra
.28274 .41856 .29138 .42694 .3047 .42241 .2961 .41399 Mtetra
.2961 .41399 .3047 .42241 .31808 .41786 .30952 .4094 Mtetra
.30952 .4094 .31808 .41786 .33153 .41329 .32302 .40478 Mtetra
.32302 .40478 .33153 .41329 .34505 .40869 .33658 .40014 Mtetra
.33658 .40014 .34505 .40869 .35864 .40407 .35021 .39547 Mtetra
.35021 .39547 .35864 .40407 .3723 .39942 .36391 .39079 Mtetra
.965 .707 .494 r
.36391 .39079 .3723 .39942 .39497 .18768 .3872 .17864 Mtetra
.663 .742 .909 r
.3872 .17864 .39497 .18768 .4079 .18279 .40017 .17371 Mtetra
.40017 .17371 .4079 .18279 .42089 .17788 .4132 .16875 Mtetra
.4132 .16875 .42089 .17788 .43395 .17295 .4263 .16377 Mtetra
.4263 .16377 .43395 .17295 .44707 .16799 .43946 .15877 Mtetra
.43946 .15877 .44707 .16799 .46025 .163 .45268 .15374 Mtetra
.45268 .15374 .46025 .163 .4735 .15799 .46597 .14868 Mtetra
.46597 .14868 .4735 .15799 .48681 .15296 .47933 .14361 Mtetra
.47933 .14361 .48681 .15296 .50019 .1479 .49275 .1385 Mtetra
.49275 .1385 .50019 .1479 .51363 .14282 .50623 .13337 Mtetra
.50623 .13337 .51363 .14282 .52714 .13772 .51979 .12822 Mtetra
.51979 .12822 .52714 .13772 .54072 .13258 .53341 .12304 Mtetra
.796 .781 .839 r
.53341 .12304 .54072 .13258 .5543 .12133 .54705 .11173 Mtetra
.664 .741 .908 r
.54705 .11173 .5543 .12133 .56798 .11614 .56078 .1065 Mtetra
.56078 .1065 .56798 .11614 .58173 .11093 .57457 .10123 Mtetra
.57457 .10123 .58173 .11093 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10042 .60237 .09063 Mtetra
.60237 .09063 .60944 .10042 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63742 .08981 .63045 .07992 Mtetra
.63045 .07992 .63742 .08981 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.657 .75 .918 r
.04924 .37643 .05824 .38436 .07 .38008 .06104 .37211 Mtetra
.06104 .37211 .07 .38008 .08183 .37577 .07289 .36777 Mtetra
.07289 .36777 .08183 .37577 .09371 .37144 .0848 .3634 Mtetra
.0848 .3634 .09371 .37144 .10564 .3671 .09676 .35902 Mtetra
.09676 .35902 .10564 .3671 .11763 .36273 .10879 .35461 Mtetra
.10879 .35461 .11763 .36273 .12968 .35834 .12087 .35018 Mtetra
.12087 .35018 .12968 .35834 .14178 .35393 .133 .34574 Mtetra
.133 .34574 .14178 .35393 .15395 .3495 .1452 .34127 Mtetra
.1452 .34127 .15395 .3495 .16617 .34505 .15745 .33678 Mtetra
.15745 .33678 .16617 .34505 .17844 .34058 .16976 .33226 Mtetra
.16976 .33226 .17844 .34058 .19078 .33608 .18213 .32773 Mtetra
.18213 .32773 .19078 .33608 .20318 .33157 .19457 .32317 Mtetra
.954 .652 .423 r
.19457 .32317 .20318 .33157 .204 .44551 .19505 .4373 Mtetra
.647 .761 .932 r
.19505 .4373 .204 .44551 .21696 .44107 .20804 .43283 Mtetra
.20804 .43283 .21696 .44107 .22998 .43662 .2211 .42833 Mtetra
.2211 .42833 .22998 .43662 .24307 .43214 .23423 .42381 Mtetra
.23423 .42381 .24307 .43214 .25623 .42763 .24743 .41926 Mtetra
.24743 .41926 .25623 .42763 .26945 .42311 .26069 .4147 Mtetra
.26069 .4147 .26945 .42311 .28274 .41856 .27402 .41011 Mtetra
.27402 .41011 .28274 .41856 .2961 .41399 .28742 .40549 Mtetra
.28742 .40549 .2961 .41399 .30952 .4094 .30088 .40086 Mtetra
.30088 .40086 .30952 .4094 .32302 .40478 .31442 .39619 Mtetra
.31442 .39619 .32302 .40478 .33658 .40014 .32802 .39151 Mtetra
.32802 .39151 .33658 .40014 .35021 .39547 .3417 .3868 Mtetra
.3417 .3868 .35021 .39547 .36391 .39079 .35544 .38207 Mtetra
.965 .707 .494 r
.35544 .38207 .36391 .39079 .3872 .17864 .37936 .16952 Mtetra
.663 .742 .909 r
.37936 .16952 .3872 .17864 .40017 .17371 .39237 .16454 Mtetra
.39237 .16454 .40017 .17371 .4132 .16875 .40545 .15954 Mtetra
.40545 .15954 .4132 .16875 .4263 .16377 .41858 .15451 Mtetra
.41858 .15451 .4263 .16377 .43946 .15877 .43178 .14946 Mtetra
.43178 .14946 .43946 .15877 .45268 .15374 .44505 .14439 Mtetra
.44505 .14439 .45268 .15374 .46597 .14868 .45838 .13929 Mtetra
.45838 .13929 .46597 .14868 .47933 .14361 .47178 .13417 Mtetra
.47178 .13417 .47933 .14361 .49275 .1385 .48524 .12902 Mtetra
.48524 .12902 .49275 .1385 .50623 .13337 .49877 .12384 Mtetra
.49877 .12384 .50623 .13337 .51979 .12822 .51236 .11864 Mtetra
.51236 .11864 .51979 .12822 .53341 .12304 .52603 .11341 Mtetra
.796 .781 .839 r
.52603 .11341 .53341 .12304 .54705 .11173 .53973 .10205 Mtetra
.664 .741 .908 r
.53973 .10205 .54705 .11173 .56078 .1065 .5535 .09676 Mtetra
.5535 .09676 .56078 .1065 .57457 .10123 .56734 .09145 Mtetra
.56734 .09145 .57457 .10123 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09063 .59523 .08075 Mtetra
.59523 .08075 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.657 .75 .918 r
.04016 .36844 .04924 .37643 .06104 .37211 .05199 .36407 Mtetra
.05199 .36407 .06104 .37211 .07289 .36777 .06387 .35969 Mtetra
.06387 .35969 .07289 .36777 .0848 .3634 .07581 .35529 Mtetra
.07581 .35529 .0848 .3634 .09676 .35902 .08781 .35087 Mtetra
.08781 .35087 .09676 .35902 .10879 .35461 .09986 .34642 Mtetra
.09986 .34642 .10879 .35461 .12087 .35018 .11198 .34196 Mtetra
.11198 .34196 .12087 .35018 .133 .34574 .12415 .33747 Mtetra
.12415 .33747 .133 .34574 .1452 .34127 .13637 .33296 Mtetra
.13637 .33296 .1452 .34127 .15745 .33678 .14866 .32843 Mtetra
.14866 .32843 .15745 .33678 .16976 .33226 .16101 .32388 Mtetra
.16101 .32388 .16976 .33226 .18213 .32773 .17341 .3193 Mtetra
.17341 .3193 .18213 .32773 .19457 .32317 .18588 .31471 Mtetra
.954 .652 .423 r
.18588 .31471 .19457 .32317 .19505 .4373 .18601 .42902 Mtetra
.647 .761 .932 r
.18601 .42902 .19505 .4373 .20804 .43283 .19904 .4245 Mtetra
.19904 .4245 .20804 .43283 .2211 .42833 .21214 .41996 Mtetra
.21214 .41996 .2211 .42833 .23423 .42381 .22531 .4154 Mtetra
.22531 .4154 .23423 .42381 .24743 .41926 .23854 .41081 Mtetra
.23854 .41081 .24743 .41926 .26069 .4147 .25184 .4062 Mtetra
.25184 .4062 .26069 .4147 .27402 .41011 .26521 .40157 Mtetra
.26521 .40157 .27402 .41011 .28742 .40549 .27865 .39691 Mtetra
.27865 .39691 .28742 .40549 .30088 .40086 .29216 .39223 Mtetra
.29216 .39223 .30088 .40086 .31442 .39619 .30574 .38753 Mtetra
.30574 .38753 .31442 .39619 .32802 .39151 .31938 .3828 Mtetra
.31938 .3828 .32802 .39151 .3417 .3868 .3331 .37804 Mtetra
.3331 .37804 .3417 .3868 .35544 .38207 .34689 .37326 Mtetra
.965 .707 .494 r
.34689 .37326 .35544 .38207 .37936 .16952 .37146 .16031 Mtetra
.663 .742 .909 r
.37146 .16031 .37936 .16952 .39237 .16454 .38451 .15529 Mtetra
.38451 .15529 .39237 .16454 .40545 .15954 .39762 .15024 Mtetra
.39762 .15024 .40545 .15954 .41858 .15451 .41079 .14517 Mtetra
.41079 .14517 .41858 .15451 .43178 .14946 .42404 .14008 Mtetra
.42404 .14008 .43178 .14946 .44505 .14439 .43734 .13496 Mtetra
.43734 .13496 .44505 .14439 .45838 .13929 .45072 .12981 Mtetra
.45072 .12981 .45838 .13929 .47178 .13417 .46415 .12464 Mtetra
.46415 .12464 .47178 .13417 .48524 .12902 .47766 .11944 Mtetra
.47766 .11944 .48524 .12902 .49877 .12384 .49123 .11422 Mtetra
.49123 .11422 .49877 .12384 .51236 .11864 .50487 .10897 Mtetra
.50487 .10897 .51236 .11864 .52603 .11341 .51858 .10369 Mtetra
.796 .781 .839 r
.51858 .10369 .52603 .11341 .53973 .10205 .53234 .09227 Mtetra
.664 .741 .908 r
.53234 .09227 .53973 .10205 .5535 .09676 .54616 .08694 Mtetra
.54616 .08694 .5535 .09676 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.657 .75 .918 r
.03101 .36037 .04016 .36844 .05199 .36407 .04287 .35597 Mtetra
.04287 .35597 .05199 .36407 .06387 .35969 .05478 .35155 Mtetra
.05478 .35155 .06387 .35969 .07581 .35529 .06675 .34711 Mtetra
.06675 .34711 .07581 .35529 .08781 .35087 .07878 .34264 Mtetra
.07878 .34264 .08781 .35087 .09986 .34642 .09086 .33816 Mtetra
.09086 .33816 .09986 .34642 .11198 .34196 .10301 .33365 Mtetra
.10301 .33365 .11198 .34196 .12415 .33747 .11521 .32913 Mtetra
.11521 .32913 .12415 .33747 .13637 .33296 .12747 .32458 Mtetra
.12747 .32458 .13637 .33296 .14866 .32843 .13979 .32001 Mtetra
.13979 .32001 .14866 .32843 .16101 .32388 .15217 .31541 Mtetra
.15217 .31541 .16101 .32388 .17341 .3193 .16461 .3108 Mtetra
.16461 .3108 .17341 .3193 .18588 .31471 .17711 .30616 Mtetra
.954 .652 .423 r
.17711 .30616 .18588 .31471 .18601 .42902 .17688 .42066 Mtetra
.647 .761 .932 r
.17688 .42066 .18601 .42902 .19904 .4245 .18995 .4161 Mtetra
.18995 .4161 .19904 .4245 .21214 .41996 .20309 .41152 Mtetra
.20309 .41152 .21214 .41996 .22531 .4154 .2163 .40691 Mtetra
.2163 .40691 .22531 .4154 .23854 .41081 .22957 .40228 Mtetra
.22957 .40228 .23854 .41081 .25184 .4062 .24291 .39763 Mtetra
.24291 .39763 .25184 .4062 .26521 .40157 .25633 .39295 Mtetra
.25633 .39295 .26521 .40157 .27865 .39691 .2698 .38825 Mtetra
.2698 .38825 .27865 .39691 .29216 .39223 .28335 .38353 Mtetra
.28335 .38353 .29216 .39223 .30574 .38753 .29697 .37877 Mtetra
.29697 .37877 .30574 .38753 .31938 .3828 .31066 .374 Mtetra
.31066 .374 .31938 .3828 .3331 .37804 .32442 .3692 Mtetra
.32442 .3692 .3331 .37804 .34689 .37326 .33826 .36437 Mtetra
.965 .707 .494 r
.33826 .36437 .34689 .37326 .37146 .16031 .36348 .15102 Mtetra
.663 .742 .909 r
.36348 .15102 .37146 .16031 .38451 .15529 .37657 .14595 Mtetra
.37657 .14595 .38451 .15529 .39762 .15024 .38972 .14086 Mtetra
.38972 .14086 .39762 .15024 .41079 .14517 .40294 .13574 Mtetra
.40294 .13574 .41079 .14517 .42404 .14008 .41622 .1306 Mtetra
.41622 .1306 .42404 .14008 .43734 .13496 .42957 .12544 Mtetra
.42957 .12544 .43734 .13496 .45072 .12981 .44298 .12024 Mtetra
.44298 .12024 .45072 .12981 .46415 .12464 .45646 .11502 Mtetra
.45646 .11502 .46415 .12464 .47766 .11944 .47001 .10978 Mtetra
.47001 .10978 .47766 .11944 .49123 .11422 .48363 .10451 Mtetra
.48363 .10451 .49123 .11422 .50487 .10897 .49731 .09921 Mtetra
.49731 .09921 .50487 .10897 .51858 .10369 .51106 .09388 Mtetra
.796 .781 .839 r
.51106 .09388 .51858 .10369 .53234 .09227 .52489 .0824 Mtetra
.664 .741 .908 r
.52489 .0824 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.657 .75 .918 r
.02177 .35223 .03101 .36037 .04287 .35597 .03366 .34779 Mtetra
.03366 .34779 .04287 .35597 .05478 .35155 .04561 .34333 Mtetra
.04561 .34333 .05478 .35155 .06675 .34711 .05761 .33885 Mtetra
.05761 .33885 .06675 .34711 .07878 .34264 .06967 .33435 Mtetra
.06967 .33435 .07878 .34264 .09086 .33816 .08178 .32982 Mtetra
.08178 .32982 .09086 .33816 .10301 .33365 .09396 .32528 Mtetra
.09396 .32528 .10301 .33365 .11521 .32913 .10619 .32071 Mtetra
.10619 .32071 .11521 .32913 .12747 .32458 .11849 .31612 Mtetra
.11849 .31612 .12747 .32458 .13979 .32001 .13084 .31151 Mtetra
.13084 .31151 .13979 .32001 .15217 .31541 .14325 .30688 Mtetra
.14325 .30688 .15217 .31541 .16461 .3108 .15573 .30222 Mtetra
.15573 .30222 .16461 .3108 .17711 .30616 .16826 .29754 Mtetra
.954 .652 .423 r
.16826 .29754 .17711 .30616 .17688 .42066 .16767 .41223 Mtetra
.647 .761 .932 r
.16767 .41223 .17688 .42066 .18995 .4161 .18078 .40762 Mtetra
.18078 .40762 .18995 .4161 .20309 .41152 .19396 .403 Mtetra
.19396 .403 .20309 .41152 .2163 .40691 .20721 .39835 Mtetra
.20721 .39835 .2163 .40691 .22957 .40228 .22052 .39367 Mtetra
.22052 .39367 .22957 .40228 .24291 .39763 .2339 .38898 Mtetra
.2339 .38898 .24291 .39763 .25633 .39295 .24735 .38425 Mtetra
.24735 .38425 .25633 .39295 .2698 .38825 .26087 .37951 Mtetra
.26087 .37951 .2698 .38825 .28335 .38353 .27446 .37474 Mtetra
.27446 .37474 .28335 .38353 .29697 .37877 .28812 .36994 Mtetra
.28812 .36994 .29697 .37877 .31066 .374 .30186 .36512 Mtetra
.30186 .36512 .31066 .374 .32442 .3692 .31566 .36027 Mtetra
.31566 .36027 .32442 .3692 .33826 .36437 .32954 .3554 Mtetra
.965 .707 .494 r
.32954 .3554 .33826 .36437 .36348 .15102 .35543 .14165 Mtetra
.663 .742 .909 r
.35543 .14165 .36348 .15102 .37657 .14595 .36856 .13653 Mtetra
.36856 .13653 .37657 .14595 .38972 .14086 .38175 .1314 Mtetra
.38175 .1314 .38972 .14086 .40294 .13574 .39501 .12623 Mtetra
.39501 .12623 .40294 .13574 .41622 .1306 .40833 .12104 Mtetra
.40833 .12104 .41622 .1306 .42957 .12544 .42172 .11583 Mtetra
.42172 .11583 .42957 .12544 .44298 .12024 .43518 .11059 Mtetra
.43518 .11059 .44298 .12024 .45646 .11502 .4487 .10532 Mtetra
.4487 .10532 .45646 .11502 .47001 .10978 .46229 .10003 Mtetra
.46229 .10003 .47001 .10978 .48363 .10451 .47595 .09471 Mtetra
.47595 .09471 .48363 .10451 .49731 .09921 .48968 .08936 Mtetra
.48968 .08936 .49731 .09921 .51106 .09388 .50348 .08398 Mtetra
.796 .781 .839 r
.50348 .08398 .51106 .09388 .52489 .0824 .51736 .07245 Mtetra
.664 .741 .908 r
.51736 .07245 .52489 .0824 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 154.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000VR000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00QOooool2o`000<Cooooo0_l0
0013ooooo`00P_ooool3o`000003ooooool0003ooooo0<3ooooo0ol000000ooooooo0000ooooo`12
ooooo`00P?ooool2o`0000?ooooo00<0ZKgXo`000?l00000__ooool2o`0000?ooooo00?oZKgXo`00
0?l00000@_ooool007gooooo0ol00002ooooo`@0ZKgX00?o0000ooooool00000^_ooool3o`0000?o
oooo0onY_NP00ol0003oooooo`000011ooooo`00N_ooool3o`0000?ooooo1P2Y_NP00ol00000ZKgX
o`00002hooooo`;o00000oooool6ojVmj003o`000?nY_NSo0000047ooooo001hooooo`;o00000ooo
ool90:Vmj004o`00002Y_NP0ZKgXo`000;Cooooo0ol00002ooooo`WoZKgX00Co0000ojVmj?nY_NSo
0000@?ooool007Gooooo0ol00002ooooo``0ZKgX00Go00000:Vmj02Y_NP0ZKgXo`00002`ooooo`?o
00000oooool;ojVmj005o`000?nY_NSoZKgXojVmj?l00000?oooool007?ooooo0_l00003ooooo`h0
ZKgX00Go00000:Vmj02Y_NP0ZKgXo`00002^ooooo`;o00000oooool>ojVmj005o`000?nY_NSoZKgX
ojVmj?l00000?oooool0073ooooo0ol00002oooooa40ZKgX00?o00000:Vmj02Y_NP00P2Y_NP00ol0
003oooooooooo`2Xooooo`?o00000_oooolBojVmj005o`000?nY_NSoZKgXojVmj?l00000?_ooool0
06kooooo0_l00003oooooa<0ZKgX00?o00000:Vmj02Y_NP00P2Y_NP00ooooooo0000ooooo`2Voooo
o`;o00000ooooolDojVmj006o`000?nY_NSoZKgXojVmj?oooooo0000?Oooool006_ooooo0ol00002
oooooaH0ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00ol0003oooooooooo`2Rooooo`?o00000_oooolG
ojVmj003o`00002Y_NSoZKgX00;oZKgX00?o0000ooooooooool0>oooool006Sooooo0ol00003oooo
oaP0ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00ooooooo0000ooooo`2Pooooo`;o00000ooooolGojVm
j080ZKgX00Oo00000:Vmj02Y_NSoZKgX0:Vmj?oooooo000003cooooo001Vooooo`;o00000ooooolL
0:Vmj003o`00002Y_NP0ZKgX00<0ZKgX00?o0000ooooooooool0W?ooool3o`0000;ooooo5onY_NP5
0:Vmj003o`00002Y_NP0ZKgX00<0ZKgX00?oooooo`000?ooool0>_ooool006?ooooo0ol00002oooo
oal0ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00ooooooo0000ooooo`2Jooooo`;o00000ooooolGojVm
j0L0ZKgX00?o00000:Vmj02Y_NP0102Y_NP00ol0003oooooooooo`0iooooo`00HOooool2o`0000?o
oooo8@2Y_NP00ol00000ZKgX0:Vmj0040:Vmj003ooooool0003ooooo09Kooooo0ol00003ooooo`03
ol_7e_nY_NSoZKgX01?oZKgX2P2Y_NP00ol00000ZKgX0:Vmj0050:Vmj003o`000?oooooooooo03So
oooo001Nooooo`?o00000_oooolT0:Vmj003o`00002Y_NP0ZKgX00D0ZKgX00?o0000ooooooooool0
Toooool2o`0000Gooooo0oo;amHBojVmj0`0ZKgX00?o00000:Vmj02Y_NP01P2Y_NP00ol0003ooooo
ooooo`0gooooo`00G?ooool2o`0000?ooooo9P2Y_NP00ol00000ZKgX0:Vmj0060:Vmj003o`000?oo
oooooooo08oooooo0ol00005ooooo`03ojVmj?o;amKoblOF00?oblOF3_nY_NP?0:Vmj003o`00002Y
_NP0ZKgX00H0ZKgX00?o0000ooooooooool0=oooool005Wooooo0ol00003ooooobP0ZKgX00?o0000
0:Vmj02Y_NP01`2Y_NP00ol0003oooooooooo`2;ooooo`?o00001Oooool5ojVmj0CoblOF3?nY_NPA
0:Vmj003o`00002Y_NP0ZKgX00L0ZKgX00?o0000ooooooooool0=_ooool005Oooooo0_l00003oooo
ob/0ZKgX00?o00000:Vmj02Y_NP01`2Y_NP00ol0003oooooooooo`29ooooo`;o00001_ooool8ojVm
j0CoblOF2?nY_NPD0:Vmj003o`00002Y_NP0ZKgX00L0ZKgX00?oooooo`000?ooool0=_ooool005Co
oooo0ol00003ooooobd0ZKgX00?o00000:Vmj02Y_NP0202Y_NP00ol0003oooooooooo`25ooooo`?o
00001Oooool<ojVmj0CoblOF1OnY_NPF0:Vmj003o`00002Y_NP0ZKgX00P0ZKgX00?o0000oooooooo
ool0=Oooool0057ooooo0ol000000oooool0ZKgX0:Vmj00`0:Vmj003o`00002Y_NP0ZKgX00P0ZKgX
00?oooooo`000?ooool0Poooool2o`0000Kooooo3onY_NP4ol_7eP03ojVmj02Y_NP0ZKgX01L0ZKgX
00?o00000:Vmj02Y_NP0202Y_NP00ooooooo0000ooooo`0eooooo`00Coooool2o`000003ooooo`2Y
_NP0ZKgX03<0ZKgX00?o00000:Vmj02Y_NP02@2Y_NP00ol0003oooooooooo`1oooooo`?o00001Ooo
oolBojVmj0?oblOF00<0blOF0:Vmj02Y_NP0602Y_NP00ol00000ZKgX0:Vmj0090:Vmj003ooooool0
003ooooo03Cooooo001<ooooo`?o000000?ooooo0:Vmj02Y_NP0=@2Y_NP00ol00000ZKgX0:Vmj00:
0:Vmj003o`000?oooooooooo07cooooo0_l00006oooooaGoZKgX00CoblOF0<_7eP3;amH0blOF6@2Y
_NP00ol00000ZKgX0:Vmj00:0:Vmj003o`000?oooooooooo03?ooooo001:ooooo`;o00000_ooooli
0:Vmj003o`00002Y_NP0ZKgX00T0ZKgX00<0VWfbooooool00000N_ooool3o`0000?ooooo6OnY_NP0
0`2Y_NP0blOF0<_7eP030<_7eQT0ZKgX00?o00000:Vmj02Y_NP02P2Y_NP00ol0003oooooooooo`0b
ooooo`00Aoooool3o`000003ooooo`2Y_NP0ZKgX03X0ZKgX00?o00000:Vmj02Y_NP01`2Y_NP409Ym
/P03o`000?oooooooooo07Kooooo0_l00004oooooaWoZKgX102Y_NP40<_7eQT0ZKgX00?o00000:Vm
j02Y_NP02`2Y_NP00ol0003oooooooooo`0aooooo`00AOooool2o`0000;ooooo?P2Y_NP00ol00000
ZKgX0:Vmj0040:Vmj0L0VWfb00?oooooo`000?ooool0Loooool3o`0000?ooooo6OnY_NP90:Vmj0<0
blOF602Y_NP00ol00000ZKgX0:Vmj00;0:Vmj003o`000?oooooooooo037ooooo0012ooooo`?o0000
0_oooom00:Vmj003o`00002Y_NP0ZKgX0080ZKgX2@2JOK82ooooo`03o`000?oooooooooo06oooooo
0_l00005oooooaSoZKgX2`2Y_NP40<_7eQL0ZKgX00?o00000:Vmj02Y_NP0302Y_NP00ol0003ooooo
ooooo`0`ooooo`00?oooool3o`0000;ooooo@`2Y_NP00ol00000ZKgX09Ym/P0<09Ym/P03ooooool0
003ooooo06gooooo0ol00007ooooo`03ooNdO_nY_NSoZKgX013oZKgX4@2Y_NP40<_7eQH0ZKgX00?o
00000:Vmj02Y_NP03@2Y_NP00ol0003oooooooooo`0_ooooo`00?Oooool2o`0000?oooooA@2Y_NP0
0ol00000VWfb09Ym/P0;09Ym/P040:Vnj?ooooooooooo`0006_ooooo0_l0000:ooooo`;omkAn3onY
_NPC0:Vmj0D0blOF5@2Y_NP00ol00000ZKgX0:Vmj00=0:Vmj003o`000?oooooooooo02oooooo000j
ooooo`?o00000ooooom40:Vmj0<0VWfb00?o000009Ym/P2JOK80202JOK850:Vnj0;ooooo00?o0000
ooooooooool0IOooool3o`0000cooooo0oog]7h;ojVmj1L0ZKgX103;amHE0:Vmj003o`00002Y_NP0
ZKgX00h0ZKgX00?o0000ooooooooool0;_ooool003Sooooo0_l00003ooooodD0ZKgX1@2JOK800ol0
0000VWfb09Ym/P0509Ym/PP0ZKkX0_ooool00ol0003oooooooooo`1Rooooo`?o00003oooool4ooNd
OPSoZKgX6`2Y_NP30<_7eQ@0ZKgX00?o00000:Vmj02Y_NP03P2Y_NP00ooooooo0000ooooo`0^oooo
o`00=Oooool3o`000003ooooo`2Y_NP0ZKgX04@0ZKgX202JOK800ol00000VWfb09Ym/P0309Ym/P/0
ZKkX0_ooool00ol0003oooooooooo`1Oooooo`;o00004Oooool6ooNdOPCoZKgX7P2Y_NP30<_7eQ@0
ZKgX00?o00000:Vmj02Y_NP03`2Y_NP00ol0003oooooooooo`0]ooooo`00<oooool2o`000003oooo
o`2Y_NP0ZKgX0480ZKgX3@2JOK800ol00000VWfb09Ym/P0?0:Vnj003ooooool0003ooooo05gooooo
0ol0000Cooooo`OomkAn00?oZKgX0:Vmj02Y_NP07`2Y_NP30<_7eQ<0ZKgX00?o00000:Vmj02Y_NP0
402Y_NP00ol0003oooooooooo`0/ooooo`00<?ooool3o`000003ooooo`2Y_NP0ZKgX0480ZKgX3`2J
OK800ol00000ZKkX0:Vnj00?0:Vnj0;ooooo00?o0000ooooooooool0FOooool2o`0001Kooooo1oog
]7hR0:Vmj0D0blOF4@2Y_NP00ol00000ZKgX0:Vmj00@0:Vmj003ooooool0003ooooo02cooooo000]
ooooo`?o00000_oooom40:Vmj0l0VWfb0`2Y_^P00ol00000ZKkX0:Vnj00?0:Vnj0;ooooo00?o0000
ooooooooool0EOooool3o`0001Sooooo1oog]7h00`3g]7h0ZKgX0:Vmj00P0:Vmj0<0blOF00<0do;V
0:Vmj02Y_NP03`2Y_NP00ol00000ZKgX0:Vmj00A0:Vmj003o`000?oooooooooo02_ooooo000[oooo
o`;o00000ooooom70:Vmj0`0VWfb1@2Y_^P00ol00000ZKkX0:Vnj00?0:Vnj0;ooooo00?o0000oooo
ooooool0Doooool2o`0001_ooooo1oog]7h30?NdOR40ZKgX00@0blOF0=?biP3Cl^H0do;V402Y_NP0
0ol00000ZKgX0:Vmj00A0:Vmj003ooooool0003ooooo02_ooooo000Xooooo`?o00000_oooom:0:Vm
j0L0VWfb2P2Y_^P00ol00000ZKkX0:Vnj00@0:Vnj0;ooooo00?o0000ooooooooool0Coooool3o`00
01gooooo1oog]7h30?NdOR00ZKgX0`2Hio`00`3Cl^H0ZKgX0:Vmj00?0:Vmj003o`00002Y_NP0ZKgX
0180ZKgX00?oooooo`000?ooool0:_ooool002Kooooo0_l00003oooood/0ZKgX00<001RP09Ym/P2J
OK800`2JOK8<0:Vnj003o`00002Y_^P0ZKkX0140ZKkX0_ooool00ol0003oooooooooo`1<ooooo`;o
00008?ooool7ooNdOP@0mkAn7@2Y_NP409SWo1<0ZKgX00?o00000:Vmj02Y_NP04`2Y_NP00ol0003o
ooooooooo`0Yooooo`008oooool3o`000003ooooo`2Y_NP0ZKgX04h0ZKgX00<001RP09Ym/P2Y_^P0
3P2Y_^P00ol00000ZKkX0:Vnj00A0:Vnj0;ooooo00?o0000ooooooooool0BOooool3o`0002;ooooo
1oog]7h50?NdOQX0ZKgX00<0V>Ol0:Vmj02Y_NP05`2Y_NP00ol00000ZKgX0:Vmj00B0:Vmj003oooo
ool0003ooooo02Wooooo000Qooooo`;o00000_oooomC0:Vmj100ZKkX00?o00000:Vnj02Y_^P04P2Y
_^P2ooooo`03o`000?oooooooooo04Kooooo0_l0000Tooooo`OomkAn1`3g]7hF0:Vmj00309SWo02Y
_NP0ZKgX01X0ZKgX00?o00000:Vmj02Y_NP04`2Y_NP00ooooooo0000ooooo`0Xooooo`007_ooool3
o`000003ooooo`2Y_NP0ZKgX05D0ZKgX3`2Y_^P00ol00000ZKkX0:Vnj00C0:Vnj0;ooooo00?o0000
ooooooooool0@_ooool3o`0002Kooooo1oog]7h80?NdOQ<0ZKgX00<0V>Ol0:Vmj02Y_NP0702Y_NP0
0ol00000ZKgX0:Vmj00D0:Vmj003o`000?oooooooooo02Oooooo000Looooo`;o00000_oooomI0:Vm
j003000HX02Y_^P0ZKkX00`0ZKkX00?o00000:Vnj02Y_^P04`2Y_^P2ooooo`03o`000?oooooooooo
03oooooo0ol0000Yooooo`OomkAn2@3g]7h=0:Vmj0@0V>Ol802Y_NP00ol00000ZKgX0:Vmj00D0:Vm
j003ooooool0003ooooo02Oooooo000Iooooo`?o00000_oooomL0:Vmj0h0ZKkX00?o00000:Vnj02Y
_^P0502Y_^P2ooooo`03o`000?oooooooooo03cooooo0_l0000/ooooo`OomkAn2@3g]7h;0:Vmj0<0
V>Ol8`2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003o`000?oooooooooo02Kooooo000Fooooo`?o0000
00?ooooo0:Vmj02Y_NP0GP2Y_NP00`006:00ZKkX0:Vnj00;0:Vnj003o`00002Y_^P0ZKkX01@0ZKkX
0oooool00ol0003oooooooooo`0hooooo`?o0000;_ooool7ooNdOPX0mkAn202Y_NP00`2Hio`0ZKgX
0:Vmj00U0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o0000ooooooooool09Oooool001Cooooo0_l0
0002ooooof<0ZKgX0P006:0:0:Vnj0;o00005`2Y_^P2ooooo`03o`000?oooooooooo03Kooooo0_l0
000aooooo`OomkAn2`3g]7h40:Vmj080V>Ol:02Y_NP2o`0001P0ZKgX00?oooooo`000?ooool09Ooo
ool0017ooooo0ol00002ooooofH0ZKgX00<001RP0:Vnj02Y_^P01@2Y_^P3o`0000030:Vnj?l00000
ZKkX01L0ZKkX0_ooool00ol0003oooooooooo`0booooo`?o0000<oooool7ooNdOP`0mkAn00<0ZKgX
09SWo02Y_NP09`2Y_NP3o`0000030:Vmj?l00000ZKgX01P0ZKgX00?o0000ooooooooool09?ooool0
013ooooo0_l000000oooool0ZKgX0:Vmj01X0:Vmj004000HX02Y_^P0ZKkX0:Vnj0?o00001@2Y_^P0
0ol00000ZKkX0:Vnj00E0:Vnj0?ooooo00?o0000ooooooooool0<?ooool2o`0003Cooooo2?og]7h<
0?NdOP030=Vg<03e^8P0ZKgX02@0ZKgX0ol000050:Vmj003o`00002Y_NP0ZKgX01L0ZKgX00?o0000
ooooooooool08oooool0013ooooo00?o00000:Vmj02Y_NP0J`2Y_NP3o`0000T0ZKkX00?o00000:Vn
j02Y_^P05@2Y_^P2ooooo`03o`000?oooooooooo033ooooo00?o0000ooooool00000<oooool8ooNd
OP`0mkAn00<0fKL`0?FhR03e^8P08@2Y_NP3o`0000T0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ooo
oooo0000ooooo`0Sooooo`004?ooool00ol0003ooooo0:Vmj01X0:Vmj0?o000000<0ZKgX0:Vnj02Y
_^P02P2Y_^P00ol00000ZKkX0:Vnj00A0:Vnj0<0UFZN0oooool00ol0003oooooooooo`0_ooooo`04
o`000?ooooooooooo`0003;ooooo1oog]7h=0?NdOP040=Vg<03e^8P0mKR80?FhR1d0ZKgX0ol0000=
0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o0000ooooooooool08_ooool0013ooooo00?o0000oooo
o`2Y_NP0I@2Y_NP3o`0000@0ZKgX00<001RP0:Vnj02Y_^P02@2Y_^P00ol00000ZKkX0:Vnj00>0:Vn
j0H0UFZN0oooool00ol0003oooooooooo`0_ooooo`05o`000?ooooooooooooooool00000<Oooool7
ooNdOPd0mkAn00<0fKL`0?FhR03e^8P00P3e^8PI0:Vmj0?o0000402Y_NP00ol00000ZKgX0:Vmj00G
0:Vmj003o`000?oooooooooo027ooooo000?ooooo`04o`000?ooooooooooooooof80ZKgX0ol00008
0:Vmj003000HX02Y_^P0ZKkX00T0ZKkX00?o00000:Vnj02Y_^P02`2Y_^P909EZWP?ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo1oog]7h=
0?NdOPD0mKR85P2Y_NP3o`0001@0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ooooooo0000ooooo`0Q
ooooo`003oooool00ol0003oooooooooo`03oooooeh0ZKgX0_l0000<0:Vmj0`0ZKkX00?o00000:Vn
j02Y_^P0202Y_^P;09EZWPCooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02gooooo1oog]7h=0?NdOPH0mKR84P2Y_NP3o`0001P0ZKgX00?o00000:Vm
j02Y_NP05P2Y_NP00ol0003oooooooooo`0Pooooo`003oooool00ol0003oooooooooo`04oooooeX0
ZKgX0ol0000?0:Vmj0`0ZKkX00?o00000:Vnj02Y_^P0102Y_^P>09EZWPCooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02cooooo1oog]7h<0?NdOP03
0=Vg<03e^8P0mKR800D0mKR83P2Y_NP3o`0001/0ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ol0003o
ooooooooo`0Oooooo`003oooool00ol0003oooooooooo`05oooooeH0ZKgX0ol0000B0:Vmj003000H
X02Y_^P0ZKkX00T0ZKkX00?o00000:Vnj02EJYh04P2EJYh5ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`OomkAn303g]7h00`3I]c00mKR8
0?FhR0060?FhR0/0ZKgX0_l0000O0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?oooooo`000?ooool0
7oooool000oooooo00?o0000ooooooooool01_oooomB0:Vmj0?o00005P2Y_NP00`006:00ZKkX0:Vn
j0080:Vnj00309EZW_l00000UFZN0180UFZN1_ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02_ooool00onX_n_om:I/ooooo`0Looooo`SomkAn303g
]7h00`3I]c00mKR80?FhR0070?FhR0L0ZKgX0ol0000R0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o
0000ooooooooool07_ooool000oooooo00?o0000ooooooooool02?oooom=0:Vmj0?o0000602Y_NP0
0`2=F8d0QU>=08ICS@070:Vnj0@0UFZN00?o000009EZWP2EJYh04@2EJYh5ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`?oZ;o[0_odYV`L
ooooo`SomkAn303g]7h00`3I]c00mKR80?FhR0080?FhR0<0ZKgX0ol0000V0:Vmj003o`00002Y_NP0
ZKgX01H0ZKgX00?o0000ooooooooool07Oooool000oooooo00?o0000ooooooooool02?oooom:0:Vm
j0?o00005`2Y_NP508eHS@<0QU>=0`2Y_^P809EZWP03o`00002EJYh0UFZN0100UFZN1_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool5ojRo
j`?om:I/6oooool8ooNdOP`0mkAn2`3e^8P3o`0002T0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ooo
oooo0000ooooo`0Mooooo`003_ooool00ol0003oooooooooo`0:ooooodH0ZKgX0ol0000G0:Vmj0P0
SER=0`26Dhd;09EZWP03o`00002EJYh0UFZN00l0UFZN00<0Z;oZooooooooool01Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo1onX_n/4ooBV
K1[ooooo2?og]7h<0?NdOPP0mKR80ol000000`3e^8P0ZKgX0:Vmj00Z0:Vmj003o`00002Y_NP0ZKgX
01H0ZKgX00?o0000ooooooooool07?ooool000kooooo00?o0000ooooooooool03?oooom10:Vmj0?o
0000602Y_NP:08eHS@<0QU>=302EJYh00ol00000UFZN09EZWP0<09EZWP@0Z;oZ1_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo3?nX_n/5ooBVK1Wooooo1oog]7h=0?NdOPD0
mKR80ol000050?FhR2`0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Kooooo`00
3_ooool00ol0003oooooooooo`0<ooooocl0ZKgX0_l0000I0:Vmj0`0SER=0`26Dhd=09EZWP03o`00
002EJYh0UFZN00H0UFZN2P2X_nX6ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
2?ooool>ojRoj`Oom:I/5oooool7ooNdOPd0mkAn0P3e^8P3o`0000P0mKR8;@2Y_NP00ol00000ZKgX
0:Vmj00E0:Vmj003ooooool0003ooooo01_ooooo000>ooooo`03o`000?oooooooooo00gooooo>`2Y
_NP3o`0001H0ZKgX4@2=F8d308ICS@d0UFZN00?o000009EZWP2EJYh00`2EJYh>0:RojPKooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`06oooooa3oZ;o[1oodYV`Gooooo`OomkAn303g
]7h3o`0000`0mKR8;02Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`000?oooooooooo01[ooooo000>
ooooo`03o`000?oooooooooo00oooooo=P2Y_NP3o`0001L0ZKgX4`2=F8d408ICS@d0UFZN00?o0000
09EZWP2EJYh0402X_nX6ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?oooolB
ojRoj`Oom:I/00<0m:I/ooooooooool05?ooool7ooNdOPT0mkAn0ol000000`3I]c00mKR80?FhR00>
0?FhR2/0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Iooooo`003_ooool00ol0
003oooooooooo`0@oooooc80ZKgX0ol0000H0:Vmj1H0SER=0`26Dhd=09EZWP030:Roj_l00000Z;oZ
0140Z;oZ1_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo5OnX_n/7ooBV
K0<0m:I/4oooool8ooNdOPL0mkAn0_l000030?NdOP030=Vg<03e^8P0mKR800l0mKR8:`2Y_NP00ol0
0000ZKgX0:Vmj00F0:Vmj003o`000?oooooooooo01Sooooo000>ooooo`03o`000?oooooooooo017o
oooo;P2Y_NP3o`0001L0ZKgX00<0VgZ^08eHS@2=F8d05`2=F8d308ICS@T0UFZN1P2X_nX00ol00000
Z;oZ0:RojP0@0:RojPCooooo00<0QTAhooooool000009?ooool00ol0003oZ;o[ojRoj`0FojRoj`03
0:RojoodYVcom:I/00Gom:I/0`3dYV`Cooooo`SomkAn103g]7h3o`0000D0mkAn4P3e^8P[0:Vmj003
o`00002Y_NP0ZKgX01H0ZKgX00?o0000ooooooooool06?ooool000gooooo00?o0000ooooooooool0
4ooooolZ0:Vmj0?o00005`2Y_NP409]j[QT0SER=0`26Dhd609EZWPT0Z;oZ00?o00000:RojP2X_nX0
402X_nX2ooooo`<0QTAh00?oZKgXo`000?ooool08oooool00ol0003oZ;o[ojRoj`0BojRoj`D0Z;o[
1oodYV`40?BVK1;ooooo2?og]7h0103g]7ko0000o`000?l000080?NdOQ80mKR800<0000k0:Vmj02Y
_NP0:@2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003ooooool0003ooooo01Sooooo000=ooooo`03o`00
0?oooooooooo01Cooooo9P2Y_NP3o`0001H0ZKgX202KNZhI08eHS@<0QU>=102EJYh<0:RojP03o`00
002X_nX0Z;oZ0100Z;oZ1026A7P2ojVmj003o`000?oooooooooo027ooooo00?o0000oooooonX_n/0
3onX_n/80:Roj`Oom:I/1P3dYV`?ooooo`?oYL;^1?og]7h3o`0000/0mkAn0P2X_n/@0?FhR2d0ZKgX
00?o00000:Vmj02Y_NP05@2Y_NP00ooooooo0000ooooo`0Gooooo`003Oooool00ol0003ooooooooo
o`0Fooooob80ZKgX0_l0000G0:Vmj0X0VgZ^6@2=F8d308ICSA40Z;oZ00?o00000:RojP2X_nX0402X
_nX308I4N0?oZKgX00?o0000ooooooooool08?ooool00ol0003oooooooooo`0=ojRoj`X0Z;o[1ood
YV`60?BVK0[ooooo2OnU`^h3o`0000;omkAn303g]7h30:Roj`l0mKR8;P2Y_NP00ol00000ZKgX0:Vm
j00E0:Vmj003o`000?oooooooooo01Kooooo000=ooooo`03o`000?oooooooooo01Kooooo7`2Y_NP3
o`0001L0ZKgX302KNZhI08eHS@<0QU>=00<0n[Ie0:RojP2X_nX03`2X_nX00ol00000Z;oZ0:RojP0?
0:RojP<0QTAh0onY_NP00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooooooo`[oZ;o[302X
_n/7ooBVK0L0m:I/1oooool8ojG2kP?o000000CoYL;^ooNdO_og]7komkAn3@3g]7h30:Roj`l0mKR8
;P2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003ooooool0003ooooo01Kooooo000=ooooo`03o`000?oo
oooooooo01Oooooo6`2Y_NP3o`0001D0ZKgX4@2KNZhI08eHS@<0QU>=0P3j]WD@0:RojP03o`00002X
_nX0Z;oZ0100Z;oZ0`26A7P3ojVmj003o`000?oooooooooo01kooooo00?o0000ooooooooool00ooo
ool5ojRoja00Z;o[1oodYV`90?BVK0;ooooo2?nU`^h3o`0000CoYL;^0oog]7h=0?NdOP@0Z;o[3@3e
^8P`0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?oooooo`000?ooool05Oooool000gooooo00?o0000
ooooooooool06?oooolG0:Vmj0?o00005P2Y_NPA09]j[P030:Vnj02KNZh0SER=01P0SER=0`26Dhd2
0?ZfMA40Z;oZ00?o00000:RojP2X_nX0402X_nX208I4N0?oZKgX00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`04ooooo`;oZ;o[4P2X_n/7ooBVK0T0m:I/1onU`^h3o`0000SoYL;^0_og]7h=
0?NdOPH0Z;o[2`3e^8Pa0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?o0000ooooooooool05?ooool0
00gooooo00?o0000ooooooooool06_oooolB0:Vmj0?o00005`2Y_NP@09]j[P@0ZKkX00<0VgZ^08eH
S@2=F8d05`2=F8d308ICS@<0n[Ie4@2X_nX00ol00000Z;oZ0:RojP0@0:RojP0308I4N?nY_NSoZKgX
00;oZKgX00?o0000ooooooooool07Oooool00ol0003oooooooooo`06oooooa80Z;o[1oodYV`70?BV
K0OoYL;^0_l0000=ojG2kP`0mkAn1`2X_n/;0?FhR380ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ol0
003oooooooooo`0Cooooo`003?ooool00ol0003oooooooooo`0Kooooo`l0ZKgX0ol0000F0:Vmj100
VgZ^202Y_^P00`2KNZh0SER=08eHS@0G08eHS@<0QU>=103j]WDA0:RojP03o`00002X_nX0Z;oZ00l0
Z;oZ00<0QTAhojVmj?nY_NP00onY_NP00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oo
oooo4@2X_n/7ooBVK0@0m:I/1onU`^h3o`0000koYL;^00<0YL;^0?NdOP3g]7h02P3g]7h80:Roj`X0
mKR8<P2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003ooooool0003ooooo01?ooooo000<ooooo`03o`00
0?oooooooooo01cooooo2`2Y_NP3o`0001L0ZKgX402KNZh:0:Vnj00309]j[P2=F8d0SER=01L0SER=
0`26Dhd60?ZfM@l0Z;oZ00?o00000:RojP2X_nX0402X_nX5ojVmj003o`000?oooooooooo01cooooo
00?o0000ooooooooool02?ooool@0:Roj`Kom:I/2OnU`^h3o`0000koYL;^1@2U`^h;0?NdOPT0Z;o[
2@3e^8Pc0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?o0000ooooooooool04_ooool000cooooo00?o
0000ooooooooool07_ooool70:Vmj0;o00006@2Y_NP=09]j[Ph0ZKkX00<0VgZ^08eHS@2=F8d05`2=
F8d308ICS@H0n[Ie402X_nX00ol00000Z;oZ0:RojP0;0:RojP[oZKgX00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`09ooooo`l0Z;o[1?odYV`8ojG2kP?o00003onU`^h90:G2kPT0mkAn2@2X
_n/90?FhR3@0ZKgX00?o00000:Vmj02Y_NP0502Y_NP00ooooooo0000ooooo`0Booooo`003?ooool0
0ol0003oooooooooo`0Oooooo`<0ZKgX0ol0000K0:Vmj0X0VgZ^4@2Y_^P00`2KNZh0SER=08eHS@0G
08eHS@<0QU>=1`3j]WD@0:RojP03o`00002X_nX0Z;oZ00P0Z;oZ3OnY_NP00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00_ooooo3P2X_n/2ooBVK0OoYL;^0ol0000=ojG2kPh0YL;^2@3g]7h:
0:Roj`P0mKR8=02Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003ooooool0003ooooo017ooooo000<oooo
o`03o`000?oooooooooo01oooooo0ol0000O0:Vmj0L0VgZ^4`2Y_^P00`2KNZh0SER=08eHS@0H08eH
S@80QU>=203j]WD@0:RojP03o`00002X_nX0Z;oZ00D0Z;oZ3onY_NP00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00cooooo3`2X_n/4ojG2kP?o00003OnU`^hB0:G2kPP0mkAn302X_n/60?Fh
R3D0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ol0003oooooooooo`0@ooooo`003?ooool00ol0003o
ooooooooo`0Looooo`?o000000?ooooo0:Vmj02Y_NP07`2Y_NP309]j[QL0ZKkX00<0VgZ^08eHS@2=
F8d0602=F8d208ICS@T0n[Ie3`2X_nX00ol00000Z;oZ0:RojP0EojVmj003o`000?oooooooooo01So
oooo00?o0000ooooooooool03Oooool?0:Roj`?o00003_nU`^hF0:G2kPH0mkAn3@2X_n/50?FhR3H0
ZKgX00?o00000:Vmj02Y_NP0502Y_NP00ooooooo0000ooooo`0@ooooo`003?ooool00ol0003ooooo
ooooo`0Iooooo`?o00001_oooolO0:Vmj00309]j[P2Y_^P0ZKkX01L0ZKkX00<0VgZ^08eHS@2=F8d0
602=F8d208ICS@T0n[Ie402X_nX00ol0003oZKgXojVmj00EojVmj003o`000?oooooooooo01Oooooo
00?o0000ooooooooool03oooool:0:Roj`?o000000<0RUJ<ojG2k_nU`^h03?nU`^hH0:G2kPH0mkAn
3@2X_n/40?FhR3P0ZKgX00?o00000:Vmj02Y_NP0502Y_NP2o`00013ooooo000;ooooo`03o`000?oo
oooooooo01Oooooo0ol0000:oooooal0ZKgX6P2Y_^PJ08eHS@80QU>=2P3j]WD<0:RojPCoZKgX00?o
0000ojVmj?nY_NP05?nY_NP00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00oooooo1`2X
_n/3o`0000D0RUJ<2_nU`^hL0:G2kPD0mkAn3P2X_n/30?FhR3P0ZKgX00?o00000:Vmj02Y_NP05@2Y
_NP00ol0003oooooooooo`0>ooooo`002oooool00ol0003oooooooooo`0Dooooo`?o00003_oooolO
0:Vmj1T0ZKkX6P2=F8d208ICS@/0n[Ie1`2X_nX9ojVmj003o`000?nY_NSoZKgX01?oZKgX00?o0000
ooooooooool05oooool00ol0003oooooooooo`0@ooooo`@0Z;o[0_l000000`2X_n/0RUJ<08YFS006
08YFS0CoYL;^8P2U`^h30?NdOQ00Z;o[0P3e^8Pi0:Vmj003o`00002Y_NP0ZKgX01<0ZKgX00?ooooo
o`000?ooool03oooool000_ooooo00?o0000ooooooooool04Oooool3o`0001;ooooo7`2Y_NP00`35
B`00ZKkX0:Vnj00E0:Vnj1X0SER=0P26Dhd<0?ZfM@<0Z;oZ1?oWbKP8ojVmj003o`000?nY_NSoZKgX
00koZKgX1Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01;ooooo0ol0000<08YF
S003ojG2kP2U`^h0YL;^02<0YL;^0P3g]7hB0:RojcX0ZKgX00?o00000:Vmj02Y_NP03@2Y_NP6oooo
o`03o`000?oooooooooo00kooooo000;ooooo`03o`000?oooooooooo00oooooo0_l0000Foooooal0
ZKgX5`2Y_^PJ08eHS@80QU>=303j]WD3ojVnj0GoilVh2?nY_NP00ol0003oZKgXojVmj00;ojVmj0So
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0?ooooo`?o000000?ooooo08YFS02:
EX`03@2:EX`V0:G2kP030?NdOP2X_n/0Z;o[00l0Z;o[?02Y_NP00ol00000ZKgX0:Vmj00:0:Vmj0So
oooo00?o0000ooooooooool03_ooool000_ooooo00?o0000ooooooooool03?ooool3o`0001Wooooo
7`2Y_NPF0:Vnj1X0SER=00<0QU>=0?ZfM@3j]WD02`3j]WD4ojVnj0CoilVh2OnY_NP00ol0003oZKgX
ojVmj005ojVmj0gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0<ooooo`?o0000
1?ooool@08YFS2H0YL;^3P2X_n/o0:Vmj003o`00002Y_NP0ZKgX00H0ZKgX3Oooool00ol0003ooooo
ooooo`0=ooooo`002oooool00ol0003oooooooooo`09ooooo`?o00007OoooolO0:Vmj1D0ZKkX00<0
VgZ^08eHS@2=F8d05`2=F8d00`26Dhd0n[Ie0?ZfM@0;0?ZfM@CoZKkX1OoWbKP8ojVmj003o`000?nY
_NSoZKgX00?oZKgX3oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo0ol0
0007oooooa40RUJ<902U`^h=0:Rojd80ZKgX00?o00000:Vmj02Y_NP00P2Y_NP@ooooo`03o`000?oo
oooooooo00gooooo000;ooooo`03o`000?oooooooooo00Kooooo0ol0000Roooooah0ZKgX502Y_^P0
0`2KNZh0SER=08eHS@0G08eHS@0308ICS@3j]WD0n[Ie00/0n[Ie1OnY_^P4onO9^0WoZKgX00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo0ol0000:
oooooa<0RUJ<802U`^h;0:RojdL0ZKgX00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=
ooooo`002_ooool00ol0003oooooooooo`04ooooo`?o00009_oooolN0:Vmj1<0ZKkX00<0VgZ^08eH
S@2=F8d05`2=F8d00`26Dhd0n[Ie0?ZfM@0;0?ZfM@KoZKkX1?oWbKP7ojVmj0;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo0ol0000=oooo
oa<0RUJ<7@2U`^h;0:RojdP0ZKgX0_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00gooooo000:ooooo`04o`000?ooooooooooooooo`?o0000:OoooolO0:Vmj180ZKkX00<0VgZ^08eH
S@2=F8d05`2=F8d00`26Dhd0n[Ie0?ZfM@0;0?ZfM@OoZKkX1?oWbKP00onY_NSoooooooooo`06oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool01?l0003oooooooooooooool3
o`00013ooooo502:EX`H0:G2kP/0Z;o[B02Y_NP7ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool03Oooool000[ooooo1?l0000]oooooal0ZKgX3P2Y_^P3ojBHb00309]j[P2=F8d0SER=
01L0SER=00<0QU>=0?ZfM@3j]WD02`3j]WD8ojVnj0?oilVh2Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Cooooo1?l0000CoooooaH0RUJ<4`2U`^h20?6fS@X0Z;o[A@2Y_NP=oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool000[ooooo0_l0000`oooooah0
ZKgX00?oZKgX0:Vnj02Y_^P02@2Y_^P5ojBHb00309]j[P2=F8d0SER=01L0SER=00<0QU>=0?ZfM@3j
]WD02`3j]WD8ojVnj0?oilVh2_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?o
oooo0_l0000EoooooaH0RUJ<4@2U`^h50?6fS@D0Z;o[A`2Y_NP@ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool000cooooo00?o0000ooooooooool0;ooooolH0:Vmj0KoZKgX
1P2Y_^P9ojBHb00309]j[P2=F8d0SER=01P0SER=3@3j]WD8ojVnj0;oilVh3?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04_oooolG08YFS0/0YL;^
2`3a]Xd00`2X_n/0ZKgX0:Vmj0140:Vmj1Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`003Oooool00ol0003oooooooooo`0_oooooaD0ZKgX2OnY_NP00`2Y_^SoY9S8ojBH
b007ojBHb0CoZKkY00<0VgZ^08eHS@2=F8d0602=F8d=0?ZfM@WoZKkX00?oilVhooooooooool02ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04Ooo
oolI08YFS0L0YL;^3@3a]Xe50:Vmj1Oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0<ooooo`003_ooool00ol0003oooooooooo`0_oooooa00ZKgX3OnY_NP8ojBHb0KoZKkY00<0VgZ^
08eHS@2=F8d0602=F8d=0?ZfM@KoZKkX4Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool04?oooolI08YFS0030000D`2U`^h0YL;^0080YL;^3`3a]Xe1
0:Vmj1cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`003oooool2o`00
033ooooo3@2Y_NP?ojVmj004olE;0?nTV<SoY9S8ojBHb0[oZKkY00<0VgZ^08eHS@2=F8d0602=F8d=
0?ZfM@;oZKkX5_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo0_l0000@
oooooaT0RUJ<00<0001C0?6fS@3a]Xd04@3a]Xdo0:Vmj1kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0<ooooo`004Oooool00ol0003oooooooooo`0_ooooo`P0ZKgX4onY_NP00onT
V<SoZKkYojVnj@0:ojVnj@0309]j[P2=F8d0SER=01P0SER=3@3j]WDIooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=oooooaT0RUJ<00<0001C0?6f
S@3a]Xd04@3a]Xdj0:Vmj2Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`004_ooool00ol0003oooooooooo`0^ooooo`@0ZKgX6?nY_NP<ojVnj@0309]j[P2=F8d0SER=01P0
SER=3@3j]WDJooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0;oooooaX0RUJ<00<0001C0?6fS@3a]Xd04@3a]Xdf0:Vmj2Wooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`004oooool00ol0003oooooooooo`0^ooooo`030:Vm
j?nY_NSoZKgX01[oZKgX2onY_^TJ08eHS@d0n[Ie6_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02_oooolJ08YFS1<0lKJ==@2Y_NP/ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03?ooool001Cooooo00?o0000ooooooooool0;_oo
oolMojVmj0[oZKkY6@2=F8d20:G3k`/0n[Ie7?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01cooooo0_l0000:oooooaX0RUJ<4`3a]Xda0:Vmj33ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0<ooooo`005Oooool2o`0002oooooo7OnY_NP9ojVnjAL0SER=1@2U`nl:
0?ZfMAgooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Oooooo6@2:EX`30:G3ka40lKJ=;@2Y_NPeooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool03?ooool001Oooooo00?o0000ooooooooool0;OoooolMojVmj0SoZKkY4P2=F8d;0:G3
k`T0n[Ie7_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool01_oooolE08YFS0L0YL?_4@3a]Xd[0:Vmj3Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0;ooooo`006?ooool00ol0003oooooooooo`0^oooooacoZKgX1onY_^T@08eHS@h0
YL?_203j]WDNooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`05oooooa80RUJ<2`2U`nl@0?6fSBL0ZKgX?Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo02kooooo7?nY_NP6ojVnj@/0SER=
502U`nl70?ZfMAoooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`;o0000
1Oooool>08YFS140YL?_3P3a]XdS0:Vmj47ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0;ooooo`006_ooool2o`0002oooooo6onY_NP6ojVnj@P0SER=5`2U`nl70?ZfMB3ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00;ooooo302:
EX`D0:G3k`d0lKJ=8@2Y_NQ4ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02ooo
ool001cooooo00?o0000ooooooooool0;OoooolKojVmj0GoZKkY1P2=F8dJ0:G3k`H0n[Ie8Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooooooo2P2:
EX`H0:G3k`X0lKJ=7`2Y_NQ8ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool001gooooo00?o0000ooooooooool0;OoooolJojVmj003oooooonY_^WoZKkY00;oZKkY00<0SER=
0:G3k`2U`nl07P2U`nl50?ZfMB7ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00D0RUJ<7@2U`nl:0?6fS@03ooooo`2Y_NP0ZKgX01P0ZKgXC?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo000Nooooo`03o`000?oooooooooo
02gooooo5OnY_NP6ooooo`CoZKkY8@2U`nl40?ZfMB;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Uooooo`03o`000?ooool0RUJ<0080RUJ<802U`nl90?6fS@?ooooo502Y_NQAoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool001oooooo00?o0000oooooooo
ool0;OoooolBojVmj0Wooooo0onY_^TQ0:G3k`@0n[Ie8oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02Kooooo00?o00000:G3k`2U`nl08P2U`nl80?6fS@Cooooo4@2Y_NQDooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool0023ooooo0_l0000_ooooo`coZKgX
3_ooool00onY_^Woooooooooo`0Q0:G3k`<0n[Ie8oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02Sooooo9@2U`nl60?6fS@Gooooo302Y_NQIooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool0;Oooool7ojVmj1Oooooo802U
`nl20?ZfMBCooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`00002U
`nl0YL?_0280YL?_1@3a]Xd6ooooo`P0ZKgXG?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00[ooooo000Sooooo`03o`000?oooooooooo02gooooo0onY_NPKooooob00YL?_00<0n[Ie
ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Wooooo00?o0000
0:G3k`2U`nl08@2U`nl50?6fS@Oooooo0`2Y_NQQooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02_ooool002Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Loooo
ob00YL?_9_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo0_l0000R0:G3
k`<0lKJ=2?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02_ooool002Gooooo0_l0000/ooooo`03o`000?oooooooooo01gooooo7P2U`nlWooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?oooolT0:G3k`030?6fSOoooooooooo00Ko
oooo00?o0000ooooooooool0Hoooool01Ol0003ooooooooooooooooo000000cooooo000Wooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool07OoooolL0:G3kb[ooooo00Go0000oooooooo
ooooooooo`00000_ooooob@0YL?_2?ooool00ol0003oooooooooo`1Sooooo`05o`000?oooooooooo
ooooool000003?ooool002Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Noooo
oaH0YL?_<?ooool01?l0003oooooooooool0000`ooooo`03o`00002U`nl0YL?_01l0YL?_2Oooool0
0ol0003oooooooooo`1Tooooo`04o`000?ooooooooooo`0000cooooo000Yooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool08?oooolB0:G3kc?ooooo00?o0000ooooool00000<Oooool0
0ol00000YL?_0:G3k`0J0:G3k`gooooo00?o0000ooooooooool0IOooool00ol0003oooooo`00000<
ooooo`00:_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo027ooooo302U`nlhoooo
o`03o`000?oooooo000003?ooooo00?o00000:G3k`2U`nl05P2U`nl?ooooo`03o`000?oooooooooo
06Gooooo00Co0000oooooooooooo00002oooool002_ooooo0_l0000Vooooo`03o`000?oooooooooo
02;ooooo2@2U`nlkooooo`03o`000?oooooo000003?ooooo00?o00000:G3k`2U`nl0402U`nlDoooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooool000002oooool002gooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0Sooooo`<0YL?_@Oooool2o`0003Cooooo00?o00000:G3k`2U
`nl03@2U`nlFooooo`03o`000?oooooooooo06Oooooo0_l0000;ooooo`00;_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo06Kooooo0ol0000eooooo`03o`00002U`nl0YL?_00P0YL?_
6_ooool00ol0003oooooooooo`1Vooooo`?o00002oooool002oooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`1Sooooo`Co0000>_ooool70:G3kacooooo00?o0000ooooooooool0H_oo
ool4o`0000kooooo000`ooooo`;o00008?ooool00ol0003oooooooooo`1Pooooo`?o0000?oooool0
0ol00000YL?_ooooo`0Oooooo`03o`000?oooooooooo05oooooo0ol0000Booooo`00<_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo05cooooo1?l00013ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0Foooool4o`0001Gooooo000cooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0F?ooool4o`0004Sooooo0_l0000Nooooo`03o`000?oooooooooo05Oo
oooo1?l0000Iooooo`00=?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Cooooo
1?l0001>ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E?ooool3o`0001gooooo
000eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool3o`0005?ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`1@ooooo`Co00008?ooool003Kooooo0_l0000J
ooooo`03o`000?oooooooooo04gooooo1?l0001Gooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0C?ooool4o`0002Cooooo000hooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0BOooool4o`0005cooooo0_l0000Iooooo`03o`000?oooooooooo04Sooooo1?l0000Xoooo
o`00>Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Gooooo1?l0001Rooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0AOooool3o`0002cooooo000jooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool3o`0006Oooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`11ooooo`Co0000;oooool003_ooooo0_l0000Eooooo`03o`000?oo
oooooooo03kooooo1?l0001[ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?_oo
ool4o`0003?ooooo000mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>_ooool4
o`00073ooooo0_l0000Cooooo`03o`000?oooooooooo03[ooooo1?l0000gooooo`00?_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo03Kooooo1?l0001fooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0=oooool3o`0003_ooooo000oooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0<_ooool4o`0007_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0cooooo`Co0000?_ooool0043ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0_ooooo`?o0000P?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02oooooo
1?l00012ooooo`00@Oooool2o`0000oooooo00?o0000ooooooooool0:oooool4o`0008Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`?o0000A_ooool004?ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`Co0000ROooool2o`0000gooooo00?o0000
ooooooooool0:?ooool4o`0004Wooooo0014ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool08oooool4o`0008oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Toooo
o`Co0000COooool004Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`?o
0000U?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo1?l0001Aooooo`00
A_ooool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`0009Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Mooooo`?o0000EOooool004Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Iooooo`Co0000WOooool2o`0000Sooooo00?o0000ooooooooool06Ooo
ool4o`0005Sooooo0019ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool4
o`000:?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000G?ooool0
04[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`?o0000Z?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo1?l0001Pooooo`00Boooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002/ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03_ooool3o`0006Cooooo001<ooooo`;o00000oooool00ol0003ooooo
ooooo`0:ooooo`Co0000/Oooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`0006Oooooo
001>ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002gooooo`04o`000?ooooooooooo`0000So
oooo1?l0001[ooooo`00Coooool00ol0003oooooo`000005ooooo`?o0000_?ooool00ol0003ooooo
o`000005ooooo`?o0000Koooool0053ooooo0_l000000ooooooo0000o`000002o`000<3ooooo0_l0
00000ooooooo0000o`000002o`0007;ooooo001Aooooo`;o0000aOooool2o`0007Kooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {153.5, 0}} -> {-0.0542361, -0.0193168, \
0.0052844, 0.0052844}, {{10.25, 190.438}, {149.812, 3.625}} -> {-0.0541935, \
0.0451583, 0.00528671, 0.00528671}, {{208.5, 388.688}, {149.812, 3.625}} -> \
{-1.10228, 0.0451583, 0.00528671, 0.00528671}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gdnoFrame\  = \ 
        Show[gd, \ Frame \[Rule] False, \ nS];\)\), "\[IndentingNewLine]", 
    \(\(gclass\  = \ 
        DrawHistogramClass[{h1, h2}, \ {class1Color, class2Color}, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gdnoFrame, gclass}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.5902 .67744 Mdot
.46312 .69733 Mdot
.59214 .53131 Mdot
.46047 .74158 Mdot
.56465 .66203 Mdot
.8086 .66246 Mdot
.66851 .63894 Mdot
.6967 .72251 Mdot
.72341 .60342 Mdot
.71878 .66901 Mdot
.54356 .73479 Mdot
.70809 .62644 Mdot
.73555 .57647 Mdot
.51893 .72568 Mdot
.69445 .68162 Mdot
.86374 .51921 Mdot
.60122 .65645 Mdot
.79267 .44651 Mdot
.60333 .65744 Mdot
.57936 .65105 Mdot
.43142 .65685 Mdot
.40946 .79986 Mdot
.69034 .70844 Mdot
.46457 .79237 Mdot
.61399 .71665 Mdot
.75952 .57432 Mdot
.88123 .63337 Mdot
.8185 .55277 Mdot
.39649 .75812 Mdot
.76087 .66901 Mdot
.85397 .50058 Mdot
.51365 .7029 Mdot
.54694 .8159 Mdot
.80613 .6079 Mdot
.73421 .63919 Mdot
.49962 .61552 Mdot
.65331 .63926 Mdot
.60361 .59322 Mdot
.63024 .63471 Mdot
.59731 .51057 Mdot
.69356 .6664 Mdot
.54871 .67263 Mdot
.66198 .71319 Mdot
.90975 .55629 Mdot
.80431 .52758 Mdot
.75625 .58565 Mdot
.69275 .57438 Mdot
.58929 .74095 Mdot
.75998 .59643 Mdot
.43925 .66107 Mdot
.60718 .71259 Mdot
.88537 .43158 Mdot
.66189 .65123 Mdot
.57667 .76942 Mdot
.7947 .53318 Mdot
.62389 .76832 Mdot
.98273 .4782 Mdot
.60896 .73721 Mdot
.72618 .69634 Mdot
.67495 .63315 Mdot
.70492 .67363 Mdot
.60561 .69606 Mdot
.68617 .6044 Mdot
.56563 .69788 Mdot
.6306 .62978 Mdot
.74147 .67165 Mdot
.68223 .553 Mdot
.8317 .47934 Mdot
.68727 .54651 Mdot
.5451 .66571 Mdot
.41576 .67613 Mdot
.56079 .65155 Mdot
.49359 .76175 Mdot
.64288 .69711 Mdot
.52028 .67776 Mdot
.65653 .62883 Mdot
.73958 .55973 Mdot
.5496 .64292 Mdot
.8551 .61587 Mdot
.64292 .55537 Mdot
.61093 .71583 Mdot
.71202 .66146 Mdot
.6145 .60683 Mdot
.33066 .77464 Mdot
.61427 .77847 Mdot
.61824 .76947 Mdot
.60947 .61414 Mdot
.44477 .76145 Mdot
.77685 .43763 Mdot
.70438 .58177 Mdot
.63668 .62325 Mdot
.78474 .63249 Mdot
.43564 .82125 Mdot
.74993 .58211 Mdot
.60741 .59623 Mdot
.54654 .7276 Mdot
.46181 .78419 Mdot
.75383 .66573 Mdot
.63838 .58889 Mdot
.50919 .60134 Mdot
0 0 1 r
.34627 .18054 Mdot
.30961 .15807 Mdot
.27877 .28141 Mdot
.24307 .23825 Mdot
.28126 .1827 Mdot
.26246 .15953 Mdot
.25401 .25216 Mdot
.19332 .32918 Mdot
.20476 .24262 Mdot
.32488 .31113 Mdot
.43744 .10485 Mdot
.36357 .1943 Mdot
.23122 .21897 Mdot
.26625 .21923 Mdot
.33078 .21361 Mdot
.39658 .18052 Mdot
.25803 .30573 Mdot
.37693 .15396 Mdot
.26102 .24521 Mdot
.24428 .30309 Mdot
.23991 .23367 Mdot
.18879 .3284 Mdot
.27406 .26595 Mdot
.07351 .45426 Mdot
.08025 .35445 Mdot
.07781 .3011 Mdot
.13429 .32289 Mdot
.19345 .26896 Mdot
.25682 .26574 Mdot
.18025 .23875 Mdot
.2392 .27217 Mdot
.20549 .29636 Mdot
.08646 .26333 Mdot
.40762 .19309 Mdot
.09606 .36719 Mdot
.18278 .21378 Mdot
.54494 .06818 Mdot
.41223 .24141 Mdot
.14142 .31164 Mdot
.10444 .30398 Mdot
.2448 .30784 Mdot
.30016 .21057 Mdot
.34137 .18945 Mdot
.2036 .32631 Mdot
.17641 .2968 Mdot
.3693 .14734 Mdot
.28549 .17826 Mdot
.39086 .15238 Mdot
.19443 .21863 Mdot
.18672 .29753 Mdot
.40011 .26151 Mdot
.32658 .29642 Mdot
.26558 .32834 Mdot
.25593 .30277 Mdot
.22802 .18142 Mdot
.47629 .08051 Mdot
.25036 .31205 Mdot
.33176 .22013 Mdot
.36174 .23539 Mdot
.26844 .19855 Mdot
.19761 .241 Mdot
.18624 .24387 Mdot
.12632 .32736 Mdot
.12715 .35725 Mdot
.26082 .27556 Mdot
.15578 .19966 Mdot
.23157 .2924 Mdot
.16002 .32183 Mdot
.21901 .37384 Mdot
.35656 .1897 Mdot
.28885 .27257 Mdot
.26726 .26384 Mdot
.02331 .34732 Mdot
.11706 .29957 Mdot
.34142 .22452 Mdot
.40696 .27004 Mdot
.28679 .20446 Mdot
.22887 .26714 Mdot
.22333 .26459 Mdot
.38478 .20154 Mdot
.25202 .28039 Mdot
.3077 .23751 Mdot
.42243 .20874 Mdot
.28383 .22173 Mdot
.04772 .32528 Mdot
.19952 .32635 Mdot
.1306 .31796 Mdot
.29542 .28512 Mdot
.20571 .24033 Mdot
.23693 .20504 Mdot
.30538 .25448 Mdot
.18219 .19592 Mdot
.28891 .21704 Mdot
.14445 .25356 Mdot
.28102 .20049 Mdot
.24852 .18777 Mdot
.24467 .3047 Mdot
.20496 .29045 Mdot
.28214 .14275 Mdot
.2754 .31139 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.0238095 0.0186741 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
153 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00e?oooon1
o`00obcoo`003oooool00=CoooooPOl00?l/ool000oooooo003Doooooh7o003o;?oo000?ooooo`00
e?oooon1o`00obcoo`003oooool00=CoooooPOl00?l/ool000oooooo003Doooooh7o003o;?oo000?
ooooo`00Joooool3o`00ofKoooooPOl00?l/ool000oooooo001[ooooo`?o003oI_oooon1o`00obco
o`003oooool005kooooo0ol00?l:ooooo`?o003oI_oooon1o`00obcoo`003oooool005kooooo0ol0
0?mcoooooh7o003o;?oo000?ooooo`00G_ooool3o`00og?oooooPOl00?l/ool000oooooo003Doooo
oh7o003o;?oo000?ooooo`00e?oooon1o`00obcoo`003oooool005Oooooo0ol00?mjoooooh7o003o
;?oo000?ooooo`00Eoooool3o`00og[oooooPOl00?l/ool000oooooo001Gooooo`?o003oN_oooon1
o`00obcoo`003oooool00=CoooooPOl00?l/ool000oooooo003Doooooh7o003o;?oo000?ooooo`00
e?oooon1o`00obcoo`003oooool00=CoooooPOl00?l/ool000oooooo000kooooo`?o003o3Oooool3
o`00ohKoooooPOl00?l/ool000oooooo000kooooo`?o003o3Oooool3o`00o`04ooooool00?oo003o
o`00oh;oooooPOl00?l/ool000oooooo000kooooo`?o003o0_ooool3o`00o`Sooooo1ol00?n2oooo
oh7o003o;?oo000?ooooo`00>?ooool3o`00o`Gooooo0ol00?l9ooooo`Ko003oP_oooon1o`00obco
o`003oooool003Sooooo0ol00?l5ooooo`?o003o2Oooool3o`00ohGoooooPOl00?l/ool000oooooo
000hooooo`?o003oVOoooon1o`00obcoo`003oooool003cooooo0ol00?l8ooooo`?o003o1_ooool3
o`00oh7oooooPOl00?l/ool000oooooo000aooooo`?o003o1oooool4o`00o`Sooooo0ol00?l6oooo
o`?o003oPOoooon1o`00obcoo`003oooool0037ooooo0ol00?l01?oooooo003oo`00ool00?l3oooo
o`Co003o1oooool6o`00o`Cooooo0ol00?n1oooooh7o003o;?oo000?ooooo`00:Oooool3o`00o`Go
oooo0ol00?l01?oooooo003oo`00ool00?l3ooooo`?o003o2?ooool7o`00o`Gooooo0ol00?mooooo
oh7o003o;?oo000?ooooo`009?ooool3o`00o`;ooooo0ol00?l9ooooo`?o003o00?oooooo`00ool0
0?l00ol00?l8ooooo`Oo003o00Goooooo`00ool00?oo003oooooo`03o`00ogooooooPOl00?l/ool0
00oooooo000Tooooo`?o003o0_ooool3o`00o`Oooooo0ol00?l3ooooo`Ko003o2oooool3o`00o`05
ooooool00?oo003oo`00ooooool00ol00?mooooooh7o003o;?oo000?ooooo`009?ooool3o`00o`;o
oooo0ol00?l7ooooo`?o003o0oooool8o`00o`?ooooo0ol00?l7ooooo`?o003o1?ooool3o`00ogco
ooooPOl00?l/ool000oooooo000Yooooo`Go003o1?ooool4o`00o`;ooooo0ol00?l00ooooooo003o
o`00o`03o`00o`?ooooo0ol00?l>ooooo`?o003oO?oooon1o`00obcoo`003oooool002Wooooo1Ol0
0?l4ooooo`?o003o0oooool3o`00o`03ooooool00?oo003o00?o003o0oooool5o`00o`cooooo0ol0
0?mloooooh7o003o;?oo000?ooooo`00:oooool3o`00o`Cooooo0ol00?l3ooooo`?o003o00Cooooo
o`00ool00?oo003o1Oooool5o`00oh_oooooPOl00?l/ool000oooooo000dooooo`?o003o1Oooool3
o`00o`Gooooo1Ol00?l01?oooooo003oo`00ool00?n7oooooh7o003o;?oo000?ooooo`00:Oooool7
o`00o`Cooooo0ol00?l9ooooo`?o003o1oooool3o`00o`Kooooo0ol00?mnoooooh7o003o;?oo000?
ooooo`00:Oooool7o`00o`Cooooo1_l00?l6ooooo`?o003o1oooool3o`00o`Kooooo0ol00?mnoooo
oh7o003o;?oo000?ooooo`00:Oooool7o`00o`Cooooo1_l00?l6ooooo`?o003o4?ooool3o`00ogko
ooooPOl00?l/ool000oooooo000Rooooo`?o003o1Oooool6o`00o`Kooooo1?l00?l5ooooo`?o003o
T_oooon1o`00obcoo`003oooool001Sooooo0ol00?l7ooooo`?o003o4Oooool6o`00o`?ooooo0ol0
0?l>ooooo`?o003oPOoooon1o`00obcoo`003oooool001Sooooo0ol00?l7ooooo`?o003o1_ooool3
o`00o`?ooooo1?l00?l2ooooo`Ko003o0_ooool3o`00o`kooooo0ol00?n1oooooh7o003o;?oo000?
ooooo`006?ooool3o`00oa3ooooo0ol00?l3ooooo`Go003o00?oooooo`00ool00?l01_l00?lAoooo
o`Go003oOooooomHo`00oeGoo`003oooool002_ooooo0ol00?l3ooooo`ko003o4oooool3o`00ogoo
ooooF?l00?mEool000oooooo000cooooo`Oo003o00?oooooo`00ool00?l01?l00?lAooooo`?o003o
OooooomHo`00oeGoo`003oooool002gooooo0ol00?l6ooooo`Co003o00?oooooo`00ool00?l01?l0
0?nCoooooeSo003oEOoo000?ooooo`00:?ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o1_ooool6
o`00o`;ooooo0ol00?n>oooooeSo003oEOoo000?ooooo`005_ooool3o`00o`Cooooo0ol00?l8oooo
o`So003o0_ooool3o`00o`04ooooool00?oo003oo`00o`[ooooo0ol00?n>oooooeSo003oEOoo000?
ooooo`005_ooool3o`00o`;ooooo1Ol00?l8ooooo`So003o0_ooool8o`00o`Wooooo0ol00?n>oooo
oeSo003oEOoo000?ooooo`005_ooool3o`00o`;ooooo1Ol00?l2ooooo`?o003o1Oooool3o`00o`Oo
oooo2Ol00?l6ooooo`?o003oS_oooomHo`00oeGoo`003oooool001_ooooo0ol00?l2ooooo`Go003o
3oooool9o`00o`Kooooo0ol00?n>oooooeSo003oEOoo000?ooooo`008?ooool8o`00o`gooooo0ol0
0?l2ooooo`?o003o1_ooool3o`00ohkoooooF?l00?mEool000oooooo000Aooooo`?o003o2oooool5
o`00o`04ooooool00?oo003oo`00o`;ooooo1_l00?l8ooooo`?o003oVOoooomHo`00oeGoo`003ooo
ool0017ooooo0ol00?l;ooooo`Go003o00Coooooo`00ool00?oo003o0_ooool6o`00o`Sooooo0ol0
0?nIoooooeSo003oEOoo000?ooooo`004Oooool3o`00o`_ooooo0ol00?l8ooooo`Ko003o2?ooool3
o`00oiWoooooF?l00?mEool000oooooo003DoooooeSo003oEOoo000?ooooo`003Oooool3o`00olCo
ooooF?l00?mEool000oooooo000=ooooo`?o003o1oooool3o`00o`Gooooo0ol00?nboooooeSo003o
EOoo000?ooooo`003Oooool3o`00o`Oooooo0ol00?l5ooooo`?o003o/_oooomHo`00oeGoo`003ooo
ool001Oooooo1_l00?l2ooooo`?o003o/_oooomHo`00oeGoo`003oooool001[ooooo0ol00?lCoooo
o`?o003oXOoooomHo`00oeGoo`003oooool001[ooooo0ol00?lCooooo`?o003oXOoooomHo`00oeGo
o`003oooool0033ooooo0ol00?nQoooooeSo003oEOoo000?ooooo`00e?oooomHo`00oeGoo`003ooo
ool00=CoooooF?l00?mEool000oooooo003DoooooeSo003oEOoo000?ooooo`00e?oooomHo`00oeGo
o`003oooool00=CoooooF?l00?mEool000oooooo003DoooooeSo003oEOoo000?ooooo`00e?oooomH
o`00oeGoo`003oooool00=CoooooF?l00?mEool000oooooo002Xooooo`?oo`00:OoooomHo`00oeGo
o`003oooool009Cooooo0ooo000Aooooo`?oo`00:OoooomHo`00oeGoo`003oooool009Cooooo1_oo
000>ooooo`?oo`00:OoooomHo`00oeGoo`003oooool009Cooooo1_oo000joooooeSo003oEOoo000?
ooooo`005_ooool3o`00ogkooooo0ooo000joooooeSo003oEOoo000?ooooo`005_ooool3o`00ok_o
ooooF?l00?mEool000oooooo000Fooooo`?o003o^ooooomHo`00oeGoo`003oooool00=CoooooF?l0
0?mEool000oooooo002Nooooo`?oo`006Oooool3ool001OoooooF?l00?mEool000oooooo002Noooo
o`?oo`006Oooool3ool001OoooooF?l00?mEool000oooooo002Nooooo`?oo`006Oooool3ool001Oo
ooooF?l00?mEool000oooooo003DoooooeSo003oEOoo000?ooooo`00X_ooool3ool002ooooooF?l0
0?mEool000oooooo002Rooooo`?oo`00;ooooomHo`00oeGoo`003oooool007Cooooo0ooo000[oooo
o`?oo`00;ooooomHo`00oeGoo`003oooool007Cooooo0ooo001Mooooojgoo`003oooool007Cooooo
0ooo000]ooooo`?oo`00;Ooooon]ool000oooooo002Iooooo`?oo`002?ooool3ool002gooooo[Ooo
000?ooooo`00Loooool3ool002;ooooo1?oo0008ooooo`?oo`00;Ooooon]ool000oooooo001coooo
o`?oo`008_ooool4ool003Sooooo[Ooo000?ooooo`00Loooool3ool000kooooo0ooo000Aooooo`?o
o`00>Ooooon]ool000oooooo0024ooooo`?oo`00COoooon]ool000oooooo001looooo`?oo`001?oo
ool4ool001Gooooo0ooo000=ooooo`?oo`009Ooooon]ool000oooooo001looooo`?oo`001?ooool3
ool000Sooooo0ooo000;ooooo`?oo`003Oooool3ool002Gooooo[Ooo000?ooooo`00O?ooool3ool0
00Cooooo0ooo0008ooooo`?oo`002oooool3ool000gooooo0ooo000Uooooojgoo`003oooool008Go
oooo0ooo0006ooooo`Koo`00@?oooon]ool000oooooo0025ooooo`?oo`001Oooool3ool00004oooo
oooo003oo`00ool0043ooooo[Ooo000?ooooo`00QOooool5ool000?ooooo1ooo0010ooooojgoo`00
3oooool007_ooooo0ooo0009ooooo`?oo`000oooool7ool0043ooooo[Ooo000?ooooo`00MOooool4
ool000;ooooo0ooo0009ooooo`?oo`001_ooool4ool0043ooooo[Ooo000?ooooo`00I?ooool3ool0
00kooooo1?oo0002ooooo`?oo`004oooool3ool0043ooooo[Ooo000?ooooo`00I?ooool3ool000ko
oooo1Ooo000:ooooo`?oo`001?ooool3ool000?ooooo0ooo0010ooooojgoo`003oooool006Cooooo
0ooo000@ooooo`?oo`002_ooool3ool000Cooooo0ooo000<ooooo`?oo`00=ooooon]ool000oooooo
001Rooooo`?oo`004Oooool4ool000[ooooo0ooo0004ooooo`?oo`003?ooool3ool000Kooooo0ooo
000^ooooojgoo`003oooool006;ooooo0ooo000Aooooo`?oo`000_ooool3ool001cooooo0ooo0006
ooooo`?oo`00;_oooon]ool000oooooo001Rooooo`?oo`004Oooool3ool00003oooooooo003oo`00
00;oo`0000Coooooool00?oo003oo`001_ooool3ool001Sooooo0ooo000^ooooojgoo`003oooool0
07[ooooo1?oo00000oooooooo`00ool00004ool000?ooooo0ooo000;ooooo`?oo`003_ooool3ool0
02[ooooo[Ooo000?ooooo`00N_ooool3ool00003oooooooo003oo`0000Goo`000oooool3ool000;o
oooo0ooo0006ooooo`?oo`003_ooool3ool002[ooooo[Ooo000?ooooo`00Joooool3ool000cooooo
0ooo00000oooooooo`00ool00005ool000Sooooo0ooo0006ooooo`?oo`003_ooool3ool002[ooooo
[Ooo000?ooooo`00Joooool5ool00004oooooooo003oo`00ool000[ooooo1_oo0009ooooo`?oo`00
A?oooon]ool000oooooo001Fooooo`?oo`004_ooool5ool00005oooooooo003oo`00ool00?ooool0
0ooo0008ooooo`?oo`00DOoooon]ool000oooooo001Fooooo`Goo`004_ooool7ool00004oooooooo
003oo`00ool000Sooooo0ooo0006ooooo`?oo`003_ooool3ool003Oooooo[Ooo000?ooooo`00E_oo
ool5ool0013ooooo1_oo0004ooooo`?oo`003Oooool3ool00004oooooooo003oo`00ool000Cooooo
0ooo0007ooooo`?oo`00=ooooon]ool000oooooo001Hooooo`?oo`004?ooool6ool001Cooooo2?oo
00000oooooooo`00ool00005ool000Gooooo0ooo000gooooojgoo`003oooool005?ooooo0ooo000@
ooooo`?oo`000_ooool3ool000Gooooo0ooo000?ooooo`Soo`0000?oooooool00?oo00001Ooo000o
ooooojgoo`003oooool005?ooooo0ooo000@ooooo`?oo`000_ooool3ool000Gooooo0ooo000@oooo
o`Ooo`0000Goooooool00?oo003oo`00ooooo`03ool003oooooo[Ooo000?ooooo`00Doooool3ool0
013ooooo0ooo000:ooooo`?oo`004?ooool3ool004_ooooo[Ooo000?ooooo`00M_ooool3ool000go
oooo0ooo0002ooooo`?oo`00A_oooon]ool000oooooo001Looooo`?oo`003oooool3ool000Gooooo
0ooo0003ooooo`?oo`003?ooool3ool004Kooooo[Ooo000?ooooo`00G?ooool3ool000Kooooo0ooo
0006ooooo`?oo`001Oooool3ool000?ooooo0ooo000<ooooo`?oo`00A_oooon]ool000oooooo001L
ooooo`?oo`001_ooool3ool000Kooooo0ooo0005ooooo`?oo`000oooool3ool000Kooooo0ooo001<
ooooojgoo`003oooool006Gooooo0ooo000>ooooo`Coo`001_ooool3ool000;ooooo0ooo001<oooo
ojgoo`003oooool007Kooooo1?oo0006ooooo`?oo`000_ooool4ool004_ooooo[Ooo000?ooooo`00
I_ooool3ool000;ooooo0ooo0009ooooo`?oo`001_ooool3ool000?ooooo0ooo001;ooooojgoo`00
3oooool006Kooooo0ooo00000oooooooo`00ool00002ool001Sooooo0ooo001;ooooojgoo`003ooo
ool006Kooooo0ooo00000oooooooo`00ool00002ool000Sooooo0ooo001Kooooojgoo`003oooool0
05_ooooo0ooo000<ooooo`?oo`001_ooool6ool005_ooooo[Ooo000?ooooo`00Foooool3ool001Go
oooo1_oo001Kooooojgoo`003oooool005_ooooo0ooo000Eooooo`?oo`00G_oooon]ool000oooooo
001@ooooo`?oo`001_ooool3ool000Gooooo0ooo001`ooooojgoo`003oooool0053ooooo0ooo0006
ooooo`?oo`001Oooool3ool001Gooooo0ooo001Hooooojgoo`003oooool0053ooooo0ooo0006oooo
o`?oo`001Oooool3ool000cooooo0ooo0005ooooo`Coo`00F?oooon]ool000oooooo0014ooooo`?o
o`00:Oooool3ool000Cooooo1Ooo001Hooooojgoo`003oooool004Cooooo0ooo000Eooooo`?oo`00
4Oooool3ool000Cooooo1?oo001Iooooojgoo`003oooool004Cooooo0ooo000Eooooo`?oo`006?oo
ool3ool005[ooooo[Ooo000?ooooo`00G?ooool3ool007Gooooo[Ooo000?ooooo`00D_ooool3ool0
00Oooooo0ooo001eooooojgoo`003oooool005;ooooo0ooo0007ooooo`?oo`00MOoooon]ool000oo
oooo001Booooo`?oo`00Oooooon]ool000oooooo001[ooooo`?oo`00I_oooon]ool000oooooo001G
ooooo`?oo`004Oooool3ool006Kooooo[Ooo000?ooooo`00Eoooool3ool0017ooooo0ooo001Voooo
ojgoo`003oooool005Oooooo0ooo001jooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00e?oo
oon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00e?oooon]ool000oo
oooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00e?oooon]ool000oooooo003Doooo
ojgoo`003oooool00=Cooooo[Ooo000?ooooo`00e?oooon]ool000oooooo003Dooooojgoo`003ooo
ool00=Cooooo[Ooo000?ooooo`00e?oooon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo
[Ooo000?ooooo`00e?oooon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?oooo
o`00e?oooon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00e?oooon]
ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00e?oooon]ool000oooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-1.1227, \
-1.0611, 0.011199, 0.011199}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-63.1851, -2.62981, 0.296885, 0.296885}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data-dependent quantization (vector quantization)", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Number of centroids for each class (",
  Cell[BoxData[
      \(TraditionalForm\`2\^m\)]],
  ")"
}], "Subsubsection"],

Cell[BoxData[
    \(\(m\  = \ 3;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute data-dependent centroids", "Subsubsection"],

Cell[BoxData[{
    \(\(vqCentroids1 = \ VQ[data1, m];\)\), "\n", 
    \(\(vqCentroids2\  = VQ[data2, m];\)\), "\n", 
    \(\(vqCentroids\  = \ vqCentroids1~Join~vqCentroids2;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gCentroids = \ 
        PlotData2D[vqCentroids, pr, \ centroidStyle, \ 
          FrameTicks \[Rule] None];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 1 r
.02 w
.88311 .56847 Mdot
.79222 .52211 Mdot
.72363 .65951 Mdot
.64392 .59218 Mdot
.60929 .74086 Mdot
.55061 .6718 Mdot
.43305 .77725 Mdot
.43739 .67285 Mdot
.39126 .21762 Mdot
.43263 .11787 Mdot
.30005 .20072 Mdot
.20783 .21998 Mdot
.26592 .288 Mdot
.19485 .30295 Mdot
.1137 .35162 Mdot
.07613 .30676 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0Moooool3ool0oj7ooooo
0Ol00001ooooo`0000?o0000ooooooooool0M_ooool5ool0oj3ooooo0Ol00001ooooo`0000?o0000
ooooooooool0M_ooool5ool0oj3ooooo0Ol00001ooooo`0000?o0000ooooooooool0M_ooool5ool0
oj3ooooo0Ol00001ooooo`0000?o0000ooooooooool0Moooool3ool0oj7ooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0DOooool3ool0olOooooo0Ol00001ooooo`0000?o0000oooooooo
ool0D?ooool5ool0olKooooo0Ol00001ooooo`0000?o0000ooooooooool0D?ooool5ool0olKooooo
0Ol00001ooooo`0000?o0000ooooooooool0D?ooool5ool0olKooooo0Ol00001ooooo`0000?o0000
ooooooooool0DOooool3ool0olOooooo0Ol00001ooooo`0000?o0000ooooooooool0K?ooool3ool0
ojcooooo0Ol00001ooooo`0000?o0000ooooooooool0=oooool3ool0oc7ooooo1Ooo0?n[ooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo1Ooo0?l`ooooo`Goo`3oZoooool1o`00007ooooo
00000ol0003oooooooooo`0fooooo`Goo`3o<?ooool5ool0oj_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0=_ooool5ool0oc7ooooo0ooo0?n/ooooo`7o00000Oooool00003o`000?oooooooooo
03Oooooo0ooo0?oQooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo04So
oooo0ooo0?o@ooooo`7o00000Oooool00003o`000?oooooooooo04Oooooo1Ooo0?o?ooooo`7o0000
0Oooool00003o`000?oooooooooo04Oooooo1Ooo0?o?ooooo`7o00000Oooool00003o`000?oooooo
oooo04Oooooo1Ooo0?o?ooooo`7o00000Oooool00003o`000?oooooooooo03?ooooo0ooo0?lBoooo
o`?oo`3od?ooool1o`00007ooooo00000ol0003oooooooooo`0Aooooo`?oo`3o7_ooool5ool0onCo
oooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool5ool0oagooooo1Ooo0?oTooooo`7o0000
0Oooool00003o`000?oooooooooo013ooooo1Ooo0?lMooooo`Goo`3oi?ooool1o`00007ooooo0000
0ol0003oooooooooo`0@ooooo`Goo`3o7_ooool3ool0onGooooo0Ol00001ooooo`0000?o0000oooo
ooooool04Oooool3ool0oooooooo2?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo01cooooo0ooo0?ol
ooooo`7o00000Oooool00003o`000?oooooooooo01_ooooo1Ooo0?okooooo`7o00000Oooool00003
o`000?oooooooooo01_ooooo1Ooo0?okooooo`7o00000Oooool00003o`000?oooooooooo01_ooooo
1Ooo0?okooooo`7o00000Oooool00003o`000?oooooooooo01cooooo0ooo0?olooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0g_ooool3ool0oc[ooooo0Ol00001ooooo`0000?o0000
ooooooooool0gOooool5ool0ocWooooo0Ol00001ooooo`0000?o0000ooooooooool0gOooool5ool0
ocWooooo0Ol00001ooooo`0000?o0000ooooooooool0gOooool5ool0ocWooooo0Ol00001ooooo`00
00?o0000ooooooooool0g_ooool3ool0oc[ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3iooooo`?o
o`3o7oooool1o`00007ooooo00000ol0003oooooooooo`3hooooo`Goo`3o7_ooool1o`00007ooooo
00000ol0003oooooooooo`3hooooo`Goo`3o7_ooool1o`00007ooooo00000ol0003oooooooooo`3h
ooooo`Goo`3o7_ooool1o`00007ooooo00000ol0003oooooooooo`3iooooo`?oo`3o7oooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo0ooo0?mTooooo`7o00000Ooo
ool00003o`000?oooooooooo0;?ooooo1Ooo0?mSooooo`7o00000Oooool00003o`000?oooooooooo
0;?ooooo1Ooo0?mSooooo`7o00000Oooool00003o`000?oooooooooo0;?ooooo1Ooo0?mSooooo`7o
00000Oooool00003o`000?oooooooooo0;Cooooo0ooo0?mTooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0boooool3ool0odgooooo
0Ol00001ooooo`0000?o0000ooooooooool0b_ooool5ool0odcooooo0Ol00001ooooo`0000?o0000
ooooooooool0b_ooool5ool0odcooooo0Ol00001ooooo`0000?o0000ooooooooool0b_ooool5ool0
odcooooo0Ol00001ooooo`0000?o0000ooooooooool0NOooool3ool0oagooooo0ooo0?l_ooooo`?o
o`3oCOooool1o`00007ooooo00000ol0003oooooooooo`1hooooo`Goo`3o6oooool5ool0ogkooooo
0Ol00001ooooo`0000?o0000ooooooooool0N?ooool5ool0oa_ooooo1Ooo0?mnooooo`7o00000Ooo
ool00003o`000?oooooooooo07Sooooo1Ooo0?lKooooo`Goo`3oO_ooool1o`00007ooooo00000ol0
003oooooooooo`1iooooo`?oo`3o7Oooool3ool0ogoooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2Zooooo`?oo`3oK_ooool1o`00
007ooooo00000ol0003oooooooooo`2Yooooo`Goo`3oKOooool1o`00007ooooo00000ol0003ooooo
ooooo`2Yooooo`Goo`3oKOooool1o`00007ooooo00000ol0003oooooooooo`2Yooooo`Goo`3oKOoo
ool1o`00007ooooo00000ol0003oooooooooo`2Zooooo`?oo`3oK_ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`1gooooo`?o
o`3oXOooool1o`00007ooooo00000ol0003oooooooooo`1fooooo`Goo`3oX?ooool1o`00007ooooo
00000ol0003oooooooooo`1fooooo`Goo`3oX?ooool1o`00007ooooo00000ol0003oooooooooo`1f
ooooo`Goo`3oX?ooool1o`00007ooooo00000ol0003oooooooooo`1gooooo`?oo`3oXOooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize resultant partitioning of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gpart1\  = \ 
        DrawPartitioning[vqCentroids, \ pr, nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[gpart1, gCentroids, yS, \ 
        FrameTicks \[Rule] None];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.012 w
.88695 .56916 Mdot
.79515 .52233 Mdot
.72587 .6611 Mdot
.64535 .5931 Mdot
.61039 .74327 Mdot
.55111 .67352 Mdot
.43238 .78002 Mdot
.43676 .67457 Mdot
.39017 .2148 Mdot
.43195 .11405 Mdot
.29805 .19772 Mdot
.20491 .21718 Mdot
.26358 .28588 Mdot
.1918 .30098 Mdot
.10984 .35014 Mdot
.0719 .30483 Mdot
.07483 .71235 Mdot
.1301 .2484 Mdot
.13154 .29342 Mdot
.22122 .26265 Mdot
.25668 .23236 Mdot
.26679 .51892 Mdot
.27411 .51411 Mdot
.33369 .26248 Mdot
.35609 .14163 Mdot
.43479 .44253 Mdot
.46513 .43945 Mdot
.49242 .50932 Mdot
.49445 .72978 Mdot
.52089 .75926 Mdot
.61622 .33753 Mdot
.62802 .66822 Mdot
.64712 .67267 Mdot
.66706 .27059 Mdot
.72885 .57591 Mdot
.80601 .61443 Mdot
.003 w
.52089 .75926 m
.55814 .93965 L
s
.1301 .2484 m
.04245 .11539 L
s
1 .95428 m
.80601 .61443 L
s
.80601 .61443 m
1 .23411 L
s
.66706 .27059 m
0 0 rlineto s
.66706 .27059 m
.97124 0 L
s
1 .23411 m
.80601 .61443 L
.72885 .57591 L
.61622 .33753 L
.66706 .27059 L
s
.64712 .67267 m
.72885 .57591 L
.80601 .61443 L
s
.80601 .61443 m
1 .95428 L
s
.88003 1 m
.64712 .67267 L
s
.62802 .66822 m
.49242 .50932 L
.46513 .43945 L
.61622 .33753 L
.72885 .57591 L
.64712 .67267 L
.62802 .66822 L
s
.52089 .75926 m
.62802 .66822 L
.64712 .67267 L
s
.64712 .67267 m
.88003 1 L
s
.52089 .75926 m
.49445 .72978 L
.49242 .50932 L
.62802 .66822 L
.52089 .75926 L
s
0 .7685 m
.07483 .71235 L
.49445 .72978 L
.52089 .75926 L
s
.26679 .51892 m
.27411 .51411 L
.43479 .44253 L
.46513 .43945 L
.49242 .50932 L
.49445 .72978 L
.07483 .71235 L
.26679 .51892 L
s
.33369 .26248 m
.35609 .14163 L
.66706 .27059 L
.61622 .33753 L
.46513 .43945 L
.43479 .44253 L
.33369 .26248 L
s
.97124 0 m
.66706 .27059 L
.35609 .14163 L
s
.35609 .14163 m
.26759 0 L
s
.26759 0 m
.35609 .14163 L
.33369 .26248 L
.25668 .23236 L
s
.25668 .23236 m
.20815 0 L
s
.20815 0 m
.25668 .23236 L
.22122 .26265 L
.1301 .2484 L
s
.22122 .26265 m
.25668 .23236 L
.33369 .26248 L
.43479 .44253 L
.27411 .51411 L
.22122 .26265 L
s
.13154 .29342 m
.1301 .2484 L
.22122 .26265 L
.27411 .51411 L
.26679 .51892 L
.13154 .29342 L
s
.13154 .29342 m
.26679 .51892 L
.07483 .71235 L
s
.07483 .71235 m
0 .7685 L
s
0 .40357 m
.13154 .29342 L
s
.1301 .2484 m
.13154 .29342 L
s
.13154 .29342 m
0 .40357 L
s
1 0 1 r
.02 w
.88695 .56916 Mdot
.79515 .52233 Mdot
.72587 .6611 Mdot
.64535 .5931 Mdot
.61039 .74327 Mdot
.55111 .67352 Mdot
.43238 .78002 Mdot
.43676 .67457 Mdot
.39017 .2148 Mdot
.43195 .11405 Mdot
.29805 .19772 Mdot
.20491 .21718 Mdot
.26358 .28588 Mdot
.1918 .30098 Mdot
.10984 .35014 Mdot
.0719 .30483 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0hooooo`0300000?oooooooooo00ko
oooo00<00000ooooooooool0aOooool00`00003oooooooooo`07ooooo`7o00000Oooool00003o`00
0?oooooooooo03Sooooo00<00000ooooooooool03oooool00`00003oooooooooo`33ooooo`030000
0?oooooooooo00Sooooo0Ol00001ooooo`0000?o0000ooooooooool0>Oooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo0<7ooooo00<00000ooooooooool02Oooool1o`00007ooooo0000
0ol0003oooooooooo`0iooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0`?ooool0
0`00003oooooooooo`0:ooooo`7o00000Oooool00003o`000?oooooooooo03Wooooo00<00000oooo
ooooool04?ooool00`00003oooooooooo`2nooooo`0300000?oooooooooo00_ooooo0Ol00001oooo
o`0000?o0000ooooooooool0>Oooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo0;co
oooo00<00000ooooooooool03?ooool1o`00007ooooo00000ol0003oooooooooo`0iooooo`030000
0?oooooooooo017ooooo00<00000ooooooooool0^oooool00`00003oooooooooo`0=ooooo`7o0000
0Oooool00003o`000?oooooooooo03[ooooo00<00000ooooooooool04Oooool00`00003ooooooooo
o`2hooooo`8000004?ooool1o`00007ooooo00000ol0003oooooooooo`0jooooo`0300000?oooooo
oooo01;ooooo00<00000ooooooooool0]_ooool00`00003oooooooooo`0@ooooo`7o00000Oooool0
0003o`000?oooooooooo03[ooooo00<00000ooooooooool04_ooool00`00003oooooooooo`2eoooo
o`0300000?oooooooooo017ooooo0Ol00001ooooo`0000?o0000ooooooooool0>_ooool00`00003o
ooooooooo`0Cooooo`0300000?oooooooooo0;?ooooo00<00000ooooooooool04_ooool1o`00007o
oooo00000ol0003oooooooooo`0jooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool0
/_ooool00`00003oooooooooo`0Cooooo`7o00000Oooool00003o`000?oooooooooo03_ooooo00<0
0000ooooooooool04oooool00`00003oooooooooo`2`ooooo`0300000?oooooooooo01Cooooo0Ol0
0001ooooo`0000?o0000ooooooooool0>oooool00`00003oooooooooo`0Dooooo`0300000?oooooo
oooo0:kooooo00<00000ooooooooool05Oooool1o`00007ooooo00000ol0003oooooooooo`0koooo
o`0300000?oooooooooo01Cooooo00<00000ooooooooool0[?ooool2000001Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0>oooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo0:[o
oooo00<00000ooooooooool06?ooool1o`00007ooooo00000ol0003oooooooooo`0looooo`030000
0?oooooooooo01Gooooo00<00000ooooooooool0Z?ooool00`00003oooooooooo`0Iooooo`7o0000
0Oooool00003o`000?oooooooooo03cooooo00<00000ooooooooool05Oooool00`00003ooooooooo
o`2Wooooo`0300000?oooooooooo01[ooooo0Ol00001ooooo`0000?o0000ooooooooool0??ooool0
0`00003oooooooooo`0Fooooo`0300000?oooooooooo0:Gooooo00<00000ooooooooool06oooool1
o`00007ooooo00000ol0003oooooooooo`0looooo`0300000?oooooooooo01Oooooo00<00000oooo
ooooool0Xoooool00`00003oooooooooo`0Looooo`7o00000Oooool00003o`000?oooooooooo03co
oooo00<00000ooooooooool05oooool00`00003oooooooooo`2Rooooo`0300000?oooooooooo01go
oooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00`00003oooooooooo`0Gooooo`030000
0?oooooooooo0:3ooooo00<00000ooooooooool07_ooool1o`00007ooooo00000ol0003ooooooooo
o`0mooooo`0300000?oooooooooo01Sooooo00<00000ooooooooool0WOooool20000027ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0?Oooool00`00003oooooooooo`0Hooooo`0300000?oooooo
oooo09cooooo00<00000ooooooooool08Oooool1o`00007ooooo00000ol0003oooooooooo`0moooo
o`0300000?oooooooooo01Wooooo00<00000ooooooooool0V_ooool00`00003oooooooooo`0Roooo
o`7o00000Oooool00003o`000?oooooooooo03gooooo00<00000ooooooooool06_ooool00`00003o
ooooooooo`2Hooooo`0300000?oooooooooo02?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
?_ooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo09Oooooo00<00000ooooooooool0
9?ooool1o`00007ooooo00000ol0003oooooooooo`0nooooo`0300000?oooooooooo01[ooooo00<0
0000ooooooooool0UOooool00`00003oooooooooo`0Uooooo`7o00000Oooool00003o`000?oooooo
oooo03kooooo00<00000ooooooooool06oooool00`00003oooooooooo`2Cooooo`0300000?oooooo
oooo02Kooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00`00003oooooooooo`0Koooo
o`0300000?oooooooooo09;ooooo00<00000ooooooooool09oooool1o`00007ooooo00000ol0003o
ooooooooo`0nooooo`0300000?oooooooooo01cooooo00<00000ooooooooool05oooool3ool0ogGo
oooo0P00000Zooooo`7o00000Oooool00003o`000?oooooooooo03oooooo00<00000ooooooooool0
6oooool00`00003oooooooooo`0Fooooo`Goo`3oLoooool00`00003oooooooooo`0Zooooo`7o0000
0Oooool00003o`000?oooooooooo00Wooooo00?o0000ooooooooool0<oooool00`00003ooooooooo
o`0Looooo`0300000?oooooooooo01Gooooo1Ooo0?mbooooo`0300000?oooooooooo02_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`0300000?oooooo
oooo01gooooo00<00000ooooooooool05?ooool5ool0og7ooooo00<00000ooooooooool0;?ooool1
o`00007ooooo00000ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03;ooooo00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Eooooo`?oo`3oLOooool00`00003oooooooooo`0]oooo
o`7o00000Oooool00003o`000?oooooooooo00_ooooo00?o0000ooooooooool0<_ooool00`00003o
ooooooooo`0Mooooo`0300000?oooooooooo08Oooooo00<00000ooooooooool0;_ooool1o`00007o
oooo00000ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03;ooooo00<00000ooooooooool0
7_ooool00`00003oooooooooo`25ooooo`0300000?oooooooooo02oooooo0Ol00001ooooo`0000?o
0000ooooooooool03?ooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo01kooooo00<0
0000ooooooooool0Poooool2000003;ooooo0Ol00001ooooo`0000?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0`ooooo`0300000?oooooooooo01oooooo00<00000o`000?l00000POooool0
0`00003oooooooooo`0booooo`7o00000Oooool00003o`000?oooooooooo00gooooo00?o0000oooo
ooooool0<?ooool00`00003oooooooooo`0Oooooo`03o`00000000000000083ooooo00<00000oooo
ooooool0<oooool1o`00007ooooo00000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033o
oooo00<00000ooooooooool07_ooool00ol000000000o`000003000007cooooo00<00000oooooooo
ool0=?ooool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo
00<00000ooooooooool07oooool00`00003oooooooooo`02ooooo`800000NOooool00`00003ooooo
ooooo`0eooooo`7o00000Oooool00003o`000?oooooooooo00oooooo00?o0000ooooooooool0;ooo
ool00`00003oooooooooo`0Nooooo`0300000?oooooooooo00Gooooo0P00001fooooo`0300000?oo
oooooooo03Kooooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool00ol0003oooooooooo`0^
ooooo`0300000?oooooooooo01kooooo00<00000ooooooooool01oooool3000007;ooooo00<00000
ooooooooool0=oooool1o`00007ooooo00000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02gooooo00<00000ooooooooool07_ooool00`00003oooooooooo`0:ooooo`800000Koooool00`00
003oooooooooo`0hooooo`7o00000Oooool00003o`000?oooooooooo017ooooo00?o0000oooooooo
ool0;_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00cooooo0`00001Zooooo`80
0000>oooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03o`000?oooooooooo02gooooo
00<00000ooooooooool07Oooool00`00003oooooooooo`0?ooooo`800000Ioooool00`00003ooooo
ooooo`0kooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo00?o0000ooooooooool0;?oo
ool00`00003oooooooooo`0Looooo`0300000?oooooooooo01;ooooo0P00001Tooooo`0300000?oo
oooooooo03cooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool00ol0003oooooooooo`0/
ooooo`0300000?oooooooooo01cooooo00<00000ooooooooool05?ooool30000063ooooo00<00000
ooooooooool0?Oooool1o`00007ooooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02cooooo00<00000ooooooooool06oooool00`00003oooooooooo`0Gooooo`800000GOooool00`00
003oooooooooo`0nooooo`7o00000Oooool00003o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0:oooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo01Wooooo0`00001Iooooo`03
00000?oooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0[ooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool07?ooool2000005Kooooo
00<00000ooooooooool0@?ooool1o`00007ooooo00000ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02[ooooo00<00000ooooooooool06_ooool00`00003oooooooooo`0Oooooo`800000Dooo
ool00`00003oooooooooo`11ooooo`7o00000Oooool00003o`000?oooooooooo01Kooooo00?o0000
ooooooooool0:_ooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo027ooooo0`00001>
ooooo`800000A?ooool1o`00007ooooo00000ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
02[ooooo00<00000ooooooooool02_ooool3ool0o`cooooo00<00000ooooooooool09?ooool20000
04_ooooo00<00000ooooooooool0A?ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo02Wooooo00<00000ooooooooool02Oooool5ool0o`_ooooo00<00000oooooooo
ool09_ooool3000004Oooooo00<00000ooooooooool0AOooool1o`00007ooooo00000ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo02Wooooo00<00000ooooooooool02Oooool5ool0o`_ooooo
00<00000ooooooooool0:Oooool2000004Cooooo00<00000ooooooooool0A_ooool1o`00007ooooo
00000ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Sooooo00<00000ooooooooool02Ooo
ool5ool0o`[ooooo00<00000ooooooooool0;?ooool30000043ooooo00<00000ooooooooool0Aooo
ool1o`00007ooooo00000ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oooooo00<00000
ooooooooool02_ooool3ool0o`_ooooo00<00000ooooooooool0;oooool2000003gooooo00<00000
ooooooooool0B?ooool1o`00007ooooo00000ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01Wooooo0ooo0?l<ooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool02Oooool3ool0
obGooooo0P00000jooooo`0300000?oooooooooo04Wooooo0Ol00001ooooo`0000?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Gooooo`Goo`3o2oooool00`00003oooooooooo`0Gooooo`03
00000?oooooooooo00Sooooo1Ooo0?lVooooo`<00000=_ooool00`00003oooooooooo`1:ooooo`7o
00000Oooool00003o`000?oooooooooo01cooooo00?o0000ooooooooool05_ooool5ool0o`_ooooo
00<00000ooooooooool05oooool00`00003oooooooooo`08ooooo`Goo`3o:Oooool2000003;ooooo
0P00001=ooooo`7o00000Oooool00003o`000?oooooooooo01cooooo00?o0000ooooooooool05_oo
ool5ool0o`_ooooo00<00000ooooooooool05_ooool00`00003oooooooooo`09ooooo`Goo`3o:ooo
ool3000002kooooo00<00000ooooooooool0COooool1o`00007ooooo00000ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01Kooooo0ooo0?l<ooooo`0300000?oooooooooo01Kooooo00<00000
ooooooooool02_ooool3ool0oboooooo0P00000[ooooo`0300000?oooooooooo04kooooo0Ol00001
ooooo`0000?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000000003o0000
01Kooooo00<00000ooooooooool0?_ooool2000002Sooooo00<00000ooooooooool0Coooool1o`00
007ooooo00000ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo0`00000Fooooo`03
00000?oooooooooo043ooooo0`00000Tooooo`0300000?oooooooooo053ooooo0Ol00001ooooo`00
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Rooooo`0400000?l0003o0000o`0000<0
00004oooool00`00003oooooooooo`13ooooo`8000008Oooool00`00003oooooooooo`1Aooooo`7o
00000Oooool00003o`000?oooooooooo023ooooo00?o0000ooooooooool08?ooool00`00003ooooo
ooooo`05ooooo`8000004?ooool00`00003oooooooooo`16ooooo`<000007Oooool00`00003ooooo
ooooo`1Booooo`7o00000Oooool00003o`000?oooooooooo023ooooo00?o0000ooooooooool07ooo
ool00`00003oooooooooo`08ooooo`<000003Oooool00`00003oooooooooo`19ooooo`8000006Ooo
ool2000005Cooooo0@000001o`00007ooooo00000ol0003oooooooooo`0Qooooo`?o00007Oooool0
0`00003oooooooooo`0<ooooo`8000002oooool00`00003oooooooooo`1;ooooo`8000005_ooool0
0`00003oooooooooo`1Dooooo`4000000Ol00001ooooo`0000?o0000ooooooooool08Oooool00ol0
0000000000000002000001[ooooo00<00000ooooooooool03oooool2000000Wooooo00<00000oooo
ooooool0COooool3000001;ooooo00<00000ooooooooool0E?ooool00`00003oooooo`000001oooo
o`0000?o0000ooooooooool08Oooool00ol000000000o`000002ooooo`L000004_ooool00`00003o
ooooooooo`0Booooo`<000001_ooool00`00003oooooooooo`1@ooooo`8000003oooool00`00003o
ooooooooo`1Eooooo`0300000?oooooo0000007ooooo00000ol0003oooooooooo`0Rooooo`030000
0?oooooooooo00Sooooo1P00000;ooooo`0300000?oooooooooo01Kooooo0P000003ooooo`030000
0?oooooooooo05?ooooo0`00000;ooooo`0300000?oooooooooo05Gooooo00@00000oooooooooooo
00000Oooool00003o`000?oooooooooo02;ooooo00<00000ooooooooool03_ooool700000004oooo
ool0003o0000000001_ooooo100000000ol0003oooooooooo`1Eooooo`8000002?ooool00`00003o
ooooooooo`1Fooooo`0400000?ooooooooooo`00007ooooo00000ol0003oooooooooo`0Rooooo`03
00000?oooooooooo01Gooooo0`0000000ol0003oooooooooo`0Kooooo`03o`000000003o000005Wo
oooo0P000005ooooo`0300000?oooooooooo05Kooooo00D00000ooooooooooooooooo`000001oooo
o`0000?o0000ooooooooool08_ooool00`00003oooooooooo`0Fooooo`03o`000000003o000001go
oooo00?o000000000?l00000Foooool300000003o`000000003ooooo05Sooooo00D00000oooooooo
ooooooooo`000001ooooo`0000?o0000ooooooooool08_ooool00`00003oooooooooo`0Gooooo`03
00000?oooooooooo01kooooo00<00000ooooooooool0Foooool00ol000000000o`00001Hooooo`03
00000?oooooooooo00;ooooo0Ol00001ooooo`0000?o0000ooooooooool08_ooool00`00003ooooo
ooooo`0Hooooo`0300000?oooooooooo01gooooo00<00000ooooooooool0Foooool00ol000000000
o`00001Hooooo`0300000?oooooooooo00;ooooo0Ol00001ooooo`0000?o0000ooooooooool08_oo
ool00`00003oooooooooo`0Hooooo`0300000?oooooooooo01kooooo00<00000ooooooooool0F_oo
ool00`00003oooooooooo`1Gooooo`0300000?oooooooooo00?ooooo0Ol00001ooooo`0000?o0000
ooooooooool08_ooool00`00003oooooooooo`0Hooooo`0300000?oooooooooo00Oooooo0ooo0?lE
ooooo`0300000?oooooooooo05Sooooo00<00000ooooooooool0F?ooool00`00003oooooooooo`03
ooooo`7o00000Oooool00003o`000?oooooooooo02;ooooo00<00000ooooooooool06?ooool00`00
003oooooooooo`06ooooo`Goo`3o5?ooool00`00003oooooooooo`1Gooooo`0300000?oooooooooo
05Sooooo00<00000ooooooooool01?ooool1o`00007ooooo00000ol0003oooooooooo`0Rooooo`03
00000?oooooooooo01Sooooo00<00000ooooooooool01_ooool5ool0oaGooooo00<00000oooooooo
ool0EOooool00`00003oooooooooo`1Iooooo`0300000?oooooooooo00Cooooo0Ol00001ooooo`00
00?o0000ooooooooool08Oooool00ol000000000o`00000Jooooo`0300000?oooooooooo00Gooooo
1Ooo0?lEooooo`0300000?oooooooooo05Gooooo00<00000ooooooooool0F?ooool00`00003ooooo
ooooo`05ooooo`7o00000Oooool00003o`000?oooooooooo027ooooo0P0000000ol0003ooooooooo
o`0<ooooo`?oo`3o2Oooool00`00003oooooooooo`06ooooo`?oo`3o5oooool00`00003ooooooooo
o`1Cooooo`0300000?oooooooooo05Wooooo00<00000ooooooooool01Oooool1o`00007ooooo0000
0ol0003oooooooooo`0@ooooo`?oo`3o3Oooool01000003o000000000?l0000=ooooo`Goo`3o2?oo
ool00`00003oooooooooo`0Pooooo`0300000?oooooooooo05;ooooo00<00000ooooooooool0FOoo
ool00`00003oooooooooo`06ooooo`7o00000Oooool00003o`000?oooooooooo00oooooo1Ooo0?l;
ooooo`0500000?ooooooooooooooo`0000003Oooool5ool0o`Sooooo00<00000ooooooooool08Ooo
ool00`00003oooooooooo`1@ooooo`0300000?oooooooooo05[ooooo00<00000ooooooooool01_oo
ool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`Goo`3o2_ooool00`00003oooooooooo`03
ooooo`0300000?oooooooooo00[ooooo1Ooo0?l8ooooo`0300000?oooooooooo027ooooo00<00000
ooooooooool0Coooool00`00003oooooooooo`1Jooooo`0300000?oooooooooo00Oooooo0Ol00001
ooooo`0000?o0000ooooooooool03oooool5ool0o`Wooooo00<00000ooooooooool01?ooool00`00
003oooooooooo`0;ooooo`?oo`3o2_ooool00`00003oooooooooo`0Qooooo`0300000?oooooooooo
04kooooo00<00000ooooooooool0F_ooool00`00003oooooooooo`07ooooo`7o00000Oooool00003
o`000?oooooooooo013ooooo0ooo0?l8ooooo`8000002?ooool00`00003oooooooooo`0Gooooo`03
00000?oooooooooo02;ooooo00<00000ooooooooool0C?ooool00`00003oooooooooo`1Jooooo`03
00000?oooooooooo00Sooooo0Ol00001ooooo`0000?o0000ooooooooool06_ooool00`00003ooooo
ooooo`08ooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool08_ooool00`00003ooooo
ooooo`1;ooooo`0300000?oooooooooo05_ooooo00<00000ooooooooool02?ooool1o`00007ooooo
00000ol0003oooooooooo`0Iooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool05_oo
ool00`00003oooooooooo`0Sooooo`0300000?oooooooooo04Wooooo00<00000ooooooooool0Fooo
ool00`00003oooooooooo`09ooooo`7o00000Oooool00003o`000?oooooooooo01Sooooo00<00000
ooooooooool03?ooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo02?ooooo00<00000
ooooooooool0BOooool00`00003oooooooooo`1Kooooo`0300000?oooooooooo00Wooooo0Ol00001
ooooo`0000?o0000ooooooooool05oooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo
01Kooooo00<00000ooooooooool08oooool00`00003oooooooooo`17ooooo`0300000?oooooooooo
05_ooooo00<00000ooooooooool02_ooool1o`00007ooooo00000ol0003oooooooooo`0Eooooo`80
00004Oooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo02?ooooo00<00000oooooooo
ool0A_ooool00`00003oooooooooo`1Looooo`0300000?oooooooooo00[ooooo0Ol00001ooooo`00
00?o0000ooooooooool05?ooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo01Gooooo
00<00000ooooooooool09?ooool00`00003oooooooooo`14ooooo`0300000?oooooooooo05cooooo
00<00000ooooooooool02oooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`0300000?oo
oooooooo01?ooooo00<00000ooooooooool05?ooool00`00003oooooooooo`0Tooooo`0300000?oo
oooooooo04;ooooo0P0000000ol0003oooooooooo`1Looooo`0300000?oooooooooo00_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool04_ooool00`00003oooooooooo`0Eooooo`0300000?oooooo
oooo01?ooooo00<00000ooooooooool09Oooool00`00003oooooooooo`10ooooo`0400000?l00000
0000o`0005gooooo00<00000ooooooooool03?ooool1o`00007ooooo00000ol0003oooooooooo`0A
ooooo`0300000?oooooooooo00Oooooo0ooo0?l<ooooo`0300000?oooooooooo01Cooooo00<00000
ooooooooool09Oooool00`00003oooooooooo`0mooooo`80000000Coooooo`000?l000000000GOoo
ool00`00003oooooooooo`0<ooooo`7o00000Oooool00003o`000?oooooooooo00oooooo0P000009
ooooo`Goo`3o3?ooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo02Gooooo00<00000
ooooooooool0??ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo05[ooooo00<00000
ooooooooool03Oooool1o`00007ooooo00000ol0003oooooooooo`0>ooooo`0300000?oooooooooo
00Wooooo1Ooo0?l<ooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool09_ooool00`00
003oooooooooo`0jooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0FOooool00`00
003oooooooooo`0=ooooo`7o00000Oooool00003o`000?oooooooooo00gooooo00<00000oooooooo
ool02_ooool5ool0o`gooooo00<00000ooooooooool04_ooool00`00003oooooooooo`0Vooooo`03
00000?oooooooooo03Sooooo0P000008ooooo`0300000?oooooooooo05Sooooo00<00000oooooooo
ool03_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`0300000?oooooooooo00cooooo
0ooo0?l?ooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool09_ooool00`00003ooooo
ooooo`0fooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0Eoooool00`00003ooooo
ooooo`0>ooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo00<00000ooooooooool07ooo
ool00`00003oooooooooo`0Booooo`0300000?oooooooooo02Kooooo00<00000ooooooooool0=?oo
ool2000000cooooo00<00000ooooooooool0E_ooool00`00003oooooooooo`0?ooooo`7o00000Ooo
ool00003o`000?oooooooooo00[ooooo00<00000ooooooooool08Oooool00`00003oooooooooo`0A
ooooo`0300000?oooooooooo02Oooooo00<00000ooooooooool0<_ooool00`00003oooooooooo`0=
ooooo`0300000?oooooooooo05Gooooo00<00000ooooooooool03oooool1o`00007ooooo00000ol0
003oooooooooo`08ooooo`8000009?ooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo
02Oooooo00<00000ooooooooool0<?ooool20000013ooooo00<00000ooooooooool0E?ooool00`00
003oooooooooo`0@ooooo`7o00000Oooool00003o`000?oooooooooo00Oooooo00<00000oooooooo
ool09Oooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo02Sooooo00<00000oooooooo
ool0;_ooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo05?ooooo00<00000oooooooo
ool04?ooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`0300000?oooooooooo02Oooooo
00<00000ooooooooool04?ooool00`00003oooooooooo`0Xooooo`0300000?oooooooooo02cooooo
00<00000ooooooooool04_ooool00`00003oooooooooo`1Booooo`0300000?oooooooooo017ooooo
0Ol00001ooooo`0000?o0000ooooooooool01Oooool00`00003oooooooooo`0Xooooo`0300000?oo
oooooooo013ooooo00<00000ooooooooool0:?ooool00`00003oooooooooo`0Zooooo`8000005_oo
ool00`00003oooooooooo`1Aooooo`0300000?oooooooooo017ooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00oooooo00<00000
ooooooooool0:Oooool00`00003oooooooooo`0Xooooo`0300000?oooooooooo01Kooooo00<00000
ooooooooool0D?ooool00`00003oooooooooo`0Booooo`7o00000Oooool00003o`000?oooooooooo
00;ooooo0P00000^ooooo`0300000?oooooooooo00kooooo00<00000ooooooooool0:Oooool00`00
003oooooooooo`0Vooooo`8000006Oooool00`00003oooooooooo`1@ooooo`0300000?oooooooooo
01;ooooo0Ol00001ooooo`0000Go0000oooooooooooooooo0000000`ooooo`0300000?oooooooooo
00kooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0Tooooo`0300000?oooooooooo
01[ooooo00<00000ooooooooool0C_ooool00`00003oooooooooo`0Cooooo`7o00000Oooool00004
o`000?oooooooooo000003;ooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0Yoooo
o`0300000?oooooooooo02;ooooo0P00000Mooooo`0300000?oooooooooo04kooooo00<00000oooo
ooooool04oooool1o`00007ooooo00000ol0003ooooo0000000cooooo`0300000?oooooooooo00ko
oooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0Pooooo`0300000?oooooooooo01ko
oooo00<00000ooooooooool0C?ooool00`00003oooooooooo`0Dooooo`7o00000Oooool00003o`00
0000003ooooo03Cooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0Zooooo`030000
0?oooooooooo01kooooo0P00000Qooooo`0300000?oooooooooo04cooooo00<00000ooooooooool0
5?ooool1o`00007ooooo00000`00003oooooooooo`0eooooo`0300000?oooooooooo00cooooo00<0
0000ooooooooool0:oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo02;ooooo00<0
0000ooooooooool0B_ooool00`00003oooooooooo`0Eooooo`7o00000Oooool00003o`000?oooooo
oooo03Gooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0/ooooo`0300000?oooooo
oooo01[ooooo00<00000ooooooooool08oooool00`00003oooooooooo`1:ooooo`0300000?oooooo
oooo01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00`00003oooooooooo`0<oooo
o`0300000?oooooooooo02_ooooo00<00000ooooooooool06?ooool2000002Oooooo00<00000oooo
ooooool0B?ooool00`00003oooooooooo`0Fooooo`7o00000Oooool00003o`000?oooooooooo03Ko
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`0/ooooo`0300000?oooooooooo01Ko
oooo00<00000ooooooooool09oooool00`00003oooooooooo`18ooooo`0300000?oooooooooo01Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0=oooool00`00003oooooooooo`0;ooooo`030000
0?oooooooooo02cooooo00<00000ooooooooool05?ooool2000002_ooooo00<00000ooooooooool0
A_ooool00`00003oooooooooo`0Gooooo`7o00000Oooool00003o`000?oooooooooo03Sooooo00<0
0000ooooooooool02_ooool00`00003oooooooooo`0]ooooo`0300000?oooooooooo01;ooooo00<0
0000ooooooooool0:oooool00`00003oooooooooo`16ooooo`0300000?oooooooooo01Oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0>?ooool00`00003oooooooooo`0:ooooo`0300000?oooooo
oooo02gooooo00<00000ooooooooool04?ooool2000002oooooo00<00000ooooooooool0A?ooool0
0`00003oooooooooo`0Hooooo`7o00000Oooool00003o`000?oooooooooo03Wooooo00<00000oooo
ooooool02_ooool00`00003oooooooooo`0]ooooo`0300000?oooooooooo00kooooo00<00000oooo
ooooool0;oooool00`00003oooooooooo`13ooooo`0300000?oooooooooo01Wooooo0Ol00001oooo
o`0000?o0000ooooooooool0>Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo02go
oooo00<00000ooooooooool03Oooool00`00003oooooooooo`0aooooo`0300000?oooooooooo04;o
oooo00<00000ooooooooool06Oooool1o`00007ooooo00000ol0003oooooooooo`0jooooo`030000
0?oooooooooo00Wooooo00<00000ooooooooool0;_ooool00`00003oooooooooo`0:ooooo`800000
=?ooool00`00003oooooooooo`11ooooo`0300000?oooooooooo01[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0>oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo02oooooo00<0
0000ooooooooool01_ooool2o`00000300000?oooooooooo03Gooooo00<00000ooooooooool0@?oo
ool00`00003oooooooooo`0Jooooo`7o00000Oooool00003o`000?oooooooooo03_ooooo00<00000
ooooooooool02Oooool00`00003oooooooooo`0^ooooo`0300000?l0003o000000?ooooo1@000000
0ol0003oooooooooo`0eooooo`0300000?oooooooooo03oooooo00<00000ooooooooool06oooool1
o`00007ooooo00000ol0003oooooooooo`0looooo`0300000?oooooooooo00Sooooo00<00000oooo
ooooool0;_ooool6000000?ooooo00?o000000000?l00000>?ooool00`00003oooooooooo`0noooo
o`0300000?oooooooooo01_ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool00`00003o
ooooooooo`07ooooo`0300000?oooooooooo02cooooo0P000003o`0000Sooooo00<00000oooooooo
ool0=_ooool00`00003oooooooooo`0mooooo`0300000?oooooooooo01cooooo0Ol00001ooooo`00
00?o0000ooooooooool0?Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo02Wooooo
0`00000=ooooo`0300000?oooooooooo03Oooooo00<00000ooooooooool0??ooool00`00003ooooo
ooooo`0Looooo`7o00000Oooool00003o`000?oooooooooo03kooooo00<00000ooooooooool01_oo
ool00`00003oooooooooo`0Wooooo`8000004?ooool00`00003oooooooooo`0gooooo`0300000?oo
oooooooo03_ooooo00<00000ooooooooool07Oooool1o`00007ooooo00000ol0003oooooooooo`0n
ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool09?ooool2000001?ooooo00<00000
ooooooooool0=oooool00`00003oooooooooo`0jooooo`0300000?oooooooooo01gooooo0Ol00001
ooooo`0000?o0000ooooooooool0?oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo
027ooooo0`00000Eooooo`0300000?oooooooooo03Oooooo00<00000ooooooooool0>Oooool00`00
003oooooooooo`0Nooooo`7o00000Oooool00003o`000?oooooooooo043ooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`0Oooooo`8000006Oooool00`00003oooooooooo`0fooooo`03
00000?oooooooooo03Wooooo00<00000ooooooooool07_ooool1o`00007ooooo00000ol0003ooooo
ooooo`10ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool07Oooool2000001_ooooo
00<00000ooooooooool0=oooool00`00003oooooooooo`0gooooo`0300000?oooooooooo01oooooo
0Ol00001ooooo`0000?o0000ooooooooool0@Oooool00`00003oooooooooo`04ooooo`0300000?oo
oooooooo01[ooooo0`00000Mooooo`0300000?oooooooooo03Oooooo00<00000ooooooooool0=ooo
ool00`00003oooooooooo`0Oooooo`7o00000Oooool00003o`000?oooooooooo047ooooo00<00000
ooooooooool01Oooool00`00003oooooooooo`0Gooooo`8000008Oooool00`00003oooooooooo`0g
ooooo`0300000?oooooooooo03Gooooo00<00000ooooooooool08?ooool1o`00007ooooo00000ol0
003oooooooooo`12ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool05Oooool20000
02?ooooo00<00000ooooooooool0=oooool00`00003oooooooooo`0eooooo`0300000?oooooooooo
023ooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool00`00003oooooooooo`03ooooo`03
00000?oooooooooo01?ooooo0P00000Vooooo`0300000?oooooooooo03Oooooo00<00000oooooooo
ool0<oooool00`00003oooooooooo`0Qooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo
00<00000ooooooooool00oooool00`00003oooooooooo`0@ooooo`<00000:?ooool00`00003ooooo
ooooo`0gooooo`0300000?oooooooooo03?ooooo00<00000ooooooooool08Oooool1o`00007ooooo
00000ol0003oooooooooo`14ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool03_oo
ool2000002_ooooo00<00000ooooooooool0>?ooool00`00003oooooooooo`0aooooo`0300000?oo
oooooooo02;ooooo0Ol00001ooooo`0000?o0000ooooooooool0A?ooool00`00003oooooooooo`03
ooooo`0300000?oooooooooo00_ooooo0P00000^ooooo`0300000?oooooooooo03Oooooo00<00000
ooooooooool0<Oooool00`00003oooooooooo`0Rooooo`7o00000Oooool00003o`000?oooooooooo
04Gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`08ooooo`<00000<?ooool00`00
003oooooooooo`0hooooo`0300000?oooooooooo02oooooo00<00000ooooooooool08oooool1o`00
007ooooo00000ol0003oooooooooo`16ooooo`0500000?ooooooooooooooo`0000002?ooool20000
03Cooooo00<00000ooooooooool0=oooool00`00003oooooooooo`0_ooooo`0300000?oooooooooo
02?ooooo0Ol00001ooooo`0000?o0000ooooooooool0A_ooool01@00003oooooooooooooool00000
00Kooooo0P00000fooooo`0300000?oooooooooo03Sooooo00<00000ooooooooool0;Oooool00`00
003oooooooooo`0Tooooo`7o00000Oooool00003o`000?oooooooooo04Oooooo00@00000oooooooo
ool000000oooool3000003Sooooo00<00000o`000?l00000>?ooool00`00003oooooooooo`0]oooo
o`0300000?oooooooooo02Cooooo0Ol00001ooooo`0000?o0000ooooooooool0Aoooool01000003o
ooooooooool00003000003_ooooo00?o000000000?l00000>Oooool00`00003oooooooooo`0[oooo
o`0300000?oooooooooo02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0B?ooool01@00003o
oooo00000000003o000003cooooo00?o000000000?l00000>Oooool00`00003oooooooooo`0[oooo
o`0300000?oooooooooo02Gooooo0Ol00001ooooo`0000?o0000ooooooooool0B?ooool00ol00000
0000o`000002o`0003gooooo0P00000jooooo`0300000?oooooooooo01Kooooo0ooo0?l@ooooo`03
00000?oooooooooo02Kooooo0Ol00001ooooo`0000?o0000ooooooooool0B?ooool00ol000000000
o`00000oooooo`0300000?ooool0000003Wooooo00<00000ooooooooool05Oooool5ool0o`oooooo
00<00000ooooooooool09_ooool1o`00007ooooo00000ol0003oooooooooo`18ooooo`0300000?l0
003o000003oooooo00@00000ooooooooool00000>Oooool00`00003oooooooooo`0Dooooo`Goo`3o
3_ooool00`00003oooooooooo`0Wooooo`7o00000Oooool00003o`000?oooooooooo04Oooooo00<0
0000ooooooooool0@?ooool01@00003oooooooooooooool0000003Sooooo00<00000ooooooooool0
5?ooool5ool0o`kooooo00<00000ooooooooool09oooool1o`00007ooooo00000ol0003ooooooooo
o`16ooooo`0300000?oooooooooo047ooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`0fooooo`0300000?oooooooooo01Cooooo0ooo0?l>ooooo`0300000?oooooooooo02Sooooo0Ol0
0001ooooo`0000?o0000ooooooooool0AOooool00`00003oooooooooo`12ooooo`0300000?oooooo
oooo00?ooooo00<00000ooooooooool0=Oooool00`00003oooooooooo`0Uooooo`0300000?oooooo
oooo02Sooooo0Ol00001ooooo`0000?o0000ooooooooool0A?ooool00`00003oooooooooo`13oooo
o`0300000?oooooooooo00Cooooo00<00000ooooooooool0=Oooool00`00003oooooooooo`0Soooo
o`0300000?oooooooooo02Wooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool00`00003o
ooooooooo`14ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0=Oooool00`00003o
ooooooooo`0Sooooo`0300000?oooooooooo02Wooooo0Ol00001ooooo`0000?o0000ooooooooool0
@_ooool00`00003oooooooooo`15ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0
=?ooool00`00003oooooooooo`0Rooooo`0300000?oooooooooo02[ooooo0Ol00001ooooo`0000?o
0000ooooooooool0@Oooool00`00003oooooooooo`16ooooo`0300000?oooooooooo00Kooooo00<0
0000ooooooooool0=?ooool00`00003oooooooooo`0Qooooo`0300000?oooooooooo02[ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0@?ooool00`00003oooooooooo`17ooooo`0300000?oooooo
oooo00Oooooo00<00000ooooooooool0<oooool00`00003oooooooooo`0Pooooo`0300000?oooooo
oooo02_ooooo0Ol00001ooooo`0000?o0000ooooooooool0?oooool00`00003oooooooooo`18oooo
o`0300000?oooooooooo00Sooooo00<00000ooooooooool0<oooool00`00003oooooooooo`0Ooooo
o`0300000?oooooooooo02_ooooo0Ol00001ooooo`0000?o0000ooooooooool0?_ooool00`00003o
ooooooooo`19ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0<_ooool00`00003o
ooooooooo`0Nooooo`0300000?oooooooooo02cooooo0Ol00001ooooo`0000?o0000ooooooooool0
?Oooool00`00003oooooooooo`1:ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool0
<_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00_ooooo0ooo0?lNooooo`7o0000
0Oooool00003o`000?oooooooooo03cooooo00<00000ooooooooool0Boooool00`00003ooooooooo
o`0:ooooo`0300000?oooooooooo03;ooooo00<00000ooooooooool07?ooool00`00003ooooooooo
o`0;ooooo`Goo`3o7Oooool1o`00007ooooo00000ol0003oooooooooo`0kooooo`0300000?oooooo
oooo04cooooo00<00000ooooooooool02oooool00`00003oooooooooo`0booooo`0300000?oooooo
oooo01_ooooo00<00000ooooooooool02oooool5ool0oagooooo0Ol00001ooooo`0000?o0000oooo
ooooool0>_ooool00`00003oooooooooo`1=ooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool0<?ooool00ol000000000o`00000Kooooo`0300000?oooooooooo00cooooo1Ooo0?lMoooo
o`7o00000Oooool00003o`000?oooooooooo03Wooooo00<00000ooooooooool0C_ooool00`00003o
ooooooooo`0=ooooo`0300000?oooooooooo02oooooo0_l00002000001[ooooo00<00000oooooooo
ool03Oooool3ool0oakooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool00`00003ooooo
ooooo`1?ooooo`0300000?oooooooooo00kooooo00<00000ooooooooool0;_ooool2o`0000040000
0?ooool00000000001Oooooo00<00000ooooooooool0;oooool1o`00007ooooo00000ol0003ooooo
ooooo`0gooooo`0300000?oooooooooo053ooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`0^ooooo`0300000?oooooooooo00;ooooo0P00000Eooooo`0300000?oooooooooo02oooooo
0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00`00003oooooooooo`1Aooooo`0300000?oo
oooooooo013ooooo00<00000ooooooooool05?ooool3ool0oaGooooo00<00000ooooooooool01Ooo
ool2000001;ooooo00<00000ooooooooool0<?ooool1o`00007ooooo00000ol0003oooooooooo`0e
ooooo`0300000?oooooooooo05;ooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0B
ooooo`Goo`3o4oooool00`00003oooooooooo`08ooooo`8000004?ooool00`00003oooooooooo`0`
ooooo`7o00000Oooool00003o`000?oooooooooo03Cooooo00<00000ooooooooool0Doooool00`00
003oooooooooo`0Aooooo`0300000?oooooooooo01;ooooo1Ooo0?lBooooo`0300000?oooooooooo
00_ooooo0P00000=ooooo`0300000?oooooooooo037ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0<oooool00`00003oooooooooo`1Dooooo`0300000?oooooooooo01;ooooo00<00000oooooooo
ool04Oooool5ool0oa7ooooo00<00000ooooooooool03_ooool2000000_ooooo00<00000oooooooo
ool0<Oooool1o`00007ooooo00000ol0003oooooooooo`0booooo`0300000?oooooooooo05Gooooo
00<00000ooooooooool04oooool00`00003oooooooooo`0Aooooo`?oo`3o4Oooool00`00003ooooo
ooooo`0Aooooo`8000002?ooool00`00003oooooooooo`0booooo`7o00000Oooool00003o`000?oo
oooooooo037ooooo00<00000ooooooooool0E_ooool00`00003oooooooooo`0Dooooo`0300000?oo
oooooooo02Cooooo00<00000ooooooooool04oooool2000000Kooooo00<00000ooooooooool0<_oo
ool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`0300000?oooooooooo05Oooooo00<00000
ooooooooool05Oooool00`00003oooooooooo`0Rooooo`0300000?oooooooooo01Kooooo0P000003
ooooo`0300000?oooooooooo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0;oooool00`00
003oooooooooo`1Hooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool08?ooool00`00
003oooooooooo`0Iooooo`80000000?o000000000?ooool0=?ooool1o`00007ooooo00000ol0003o
ooooooooo`0^ooooo`0300000?oooooooooo05Wooooo00<00000ooooooooool05oooool00`00003o
ooooooooo`0Nooooo`0300000?oooooooooo01_ooooo00?o000000000?l00000=Oooool1o`00007o
oooo00000ol0003oooooooooo`0]ooooo`0300000?oooooooooo05[ooooo00<00000ooooooooool0
5oooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01cooooo00?o000000000?l00000
=Oooool1o`00007ooooo00000ol0003oooooooooo`0/ooooo`0300000?oooooooooo05_ooooo00<0
0000ooooooooool06?ooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo01oooooo00<0
0000ooooooooool0<oooool1o`00007ooooo00000ol0003oooooooooo`0[ooooo`0300000?oooooo
oooo05cooooo00<00000ooooooooool06Oooool00`00003oooooooooo`0Iooooo`0300000?oooooo
oooo023ooooo00<00000ooooooooool0<oooool1o`00007ooooo00000ol0003oooooooooo`0Zoooo
o`0300000?oooooooooo05gooooo00<00000ooooooooool06_ooool00`00003oooooooooo`0Hoooo
o`0300000?oooooooooo027ooooo00<00000ooooooooool0<_ooool1o`00007ooooo00000ol0003o
ooooooooo`0Yooooo`0300000?oooooooooo05kooooo00<00000ooooooooool06oooool00`00003o
ooooooooo`0Fooooo`0300000?oooooooooo02?ooooo00<00000ooooooooool0<Oooool1o`00007o
oooo00000ol0003oooooooooo`0Xooooo`0300000?oooooooooo05oooooo00<00000ooooooooool0
7?ooool00`00003oooooooooo`0Dooooo`0300000?oooooooooo02Cooooo00<00000ooooooooool0
<Oooool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`0300000?oooooooooo063ooooo00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo02Kooooo00<0
0000ooooooooool0<?ooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`0300000?oooooo
oooo067ooooo00<00000ooooooooool07_ooool00`00003oooooooooo`0@ooooo`0300000?oooooo
oooo02Oooooo00<00000ooooooooool0<?ooool1o`00007ooooo00000ol0003oooooooooo`0Uoooo
o`0300000?oooooooooo06;ooooo00<00000ooooooooool07_ooool00`00003oooooooooo`0?oooo
o`0300000?oooooooooo02Wooooo00<00000ooooooooool0;oooool1o`00007ooooo00000ol0003o
ooooooooo`0Tooooo`0300000?oooooooooo06?ooooo00<00000ooooooooool07oooool00`00003o
ooooooooo`0=ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool0;oooool1o`00007o
oooo00000ol0003oooooooooo`0Sooooo`0300000?oooooooooo06Cooooo00<00000ooooooooool0
8?ooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo02_ooooo00<00000ooooooooool0
;_ooool1o`00007ooooo00000ol0003oooooooooo`0Rooooo`0300000?oooooooooo06Gooooo00<0
0000ooooooooool08Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00gooooo0ooo
0?l00ol0003oooooooooo`0Jooooo`0300000?oooooooooo02gooooo0Ol00001ooooo`0000?o0000
ooooooooool08Oooool00`00003oooooooooo`1Vooooo`0300000?oooooooooo02;ooooo00<00000
ooooooooool02?ooool00`00003oooooooooo`0=ooooo`Goo`3o7?ooool00`00003oooooooooo`0]
ooooo`7o00000Oooool00003o`000?oooooooooo023ooooo00<00000ooooooooool0Ioooool00`00
003oooooooooo`0Sooooo`0300000?l0003o000000Kooooo00<00000ooooooooool03_ooool5ool0
oagooooo00<00000ooooooooool0;?ooool1o`00007ooooo00000ol0003oooooooooo`0Oooooo`03
00000?oooooooooo05Oooooo0ooo0?l>ooooo`0300000?oooooooooo00cooooo0ooo0?lDooooo`<0
00001Oooool00`00003oooooooooo`0?ooooo`Goo`3o7Oooool00`00003oooooooooo`0/ooooo`7o
00000Oooool00003o`000?oooooooooo01kooooo00<00000ooooooooool0Eoooool5ool0o`gooooo
00<00000ooooooooool02oooool5ool0oa;ooooo00@00000o`000?l0003o00000`0000000ol00000
0000ooooo`0Booooo`?oo`3o7oooool00`00003oooooooooo`0[ooooo`7o00000Oooool00003o`00
0?oooooooooo01gooooo00<00000ooooooooool0F?ooool5ool0o`gooooo00<00000ooooooooool0
2oooool5ool0oa7ooooo00<00000ooooooooool01?ooool00ol000000000o`00000eooooo`030000
0?oooooooooo02_ooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool00`00003ooooooooo
o`1Iooooo`Goo`3o3Oooool00`00003oooooooooo`0;ooooo`Goo`3o4?ooool00`00003ooooooooo
o`05ooooo`03o`000000003o000003Kooooo00<00000ooooooooool0:_ooool1o`00007ooooo0000
0ol0003oooooooooo`0Kooooo`0300000?oooooooooo05_ooooo0ooo0?l>ooooo`0300000?oooooo
oooo00cooooo0ooo0?l@ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0=?ooool0
0`00003oooooooooo`0Zooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo00<00000oooo
ooooool0KOooool00`00003oooooooooo`0Mooooo`8000003?ooool00`00003oooooooooo`0doooo
o`0300000?oooooooooo02Wooooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool00`00003o
ooooooooo`1^ooooo`0300000?oooooooooo01cooooo00<00000ooooooooool03Oooool00`00003o
ooooooooo`0dooooo`0300000?oooooooooo02Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
6?ooool00`00003oooooooooo`1_ooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool0
3_ooool00`00003oooooooooo`0dooooo`0300000?oooooooooo02Sooooo0Ol00001ooooo`0000?o
0000ooooooooool05oooool00`00003oooooooooo`1`ooooo`0300000?oooooooooo01[ooooo00<0
0000ooooooooool04?ooool00`00003oooooooooo`0dooooo`0300000?oooooooooo02Oooooo0Ol0
0001ooooo`0000?o0000ooooooooool05_ooool00`00003oooooooooo`1aooooo`0300000?oooooo
oooo01Wooooo00<00000ooooooooool04_ooool00`00003oooooooooo`0cooooo`0300000?oooooo
oooo02Oooooo0Ol00001ooooo`0000?o0000ooooooooool05Oooool00`00003oooooooooo`1boooo
o`0300000?oooooooooo01Oooooo0P00000Eooooo`0300000?oooooooooo03Cooooo00<00000oooo
ooooool09_ooool1o`00007ooooo00000ol0003oooooooooo`0Dooooo`0300000?oooooooooo07?o
oooo00<00000ooooooooool05_ooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo03?o
oooo00<00000ooooooooool09_ooool1o`00007ooooo00000ol0003oooooooooo`0Aooooo`;o0000
00<00000ooooooooool0M?ooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo01Sooooo
00<00000ooooooooool0<oooool00`00003oooooooooo`0Uooooo`7o00000Oooool00003o`000?oo
oooooooo017ooooo3P00001[ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool06_oo
ool00`00003oooooooooo`0cooooo`0300000?oooooooooo02Cooooo0Ol00001ooooo`0000?o0000
ooooooooool04?ooool01000003o0000o`000?l0000;oooooaP00000Doooool00`00003ooooooooo
o`0Cooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool0<oooool00`00003ooooooooo
o`0Tooooo`7o00000Oooool00003o`000?oooooooooo00oooooo00<00000ooooooooool09OoooolH
000003_ooooo00<00000ooooooooool04_ooool00`00003oooooooooo`0Mooooo`0300000?oooooo
oooo03?ooooo00<00000ooooooooool08oooool1o`00007ooooo00000ol0003oooooooooo`0=oooo
o`800000@?oooolH000002?ooooo00<00000ooooooooool04?ooool20000027ooooo00<00000oooo
ooooool0<_ooool00`00003oooooooooo`0Sooooo`7o00000Oooool00003o`000?oooooooooo00co
oooo00<00000ooooooooool0F?oooolH000000[ooooo00?o000000000?l000004?ooool00`00003o
ooooooooo`0Qooooo`0300000?oooooooooo03?ooooo00<00000ooooooooool08_ooool1o`00007o
oooo00000ol0003oooooooooo`0;ooooo`0300000?oooooooooo077ooooo300000000ol0003ooooo
ooooo`0=ooooo`0300000?oooooooooo02?ooooo00<00000ooooooooool0<_ooool00`00003ooooo
ooooo`0Rooooo`7o00000Oooool00003o`000?oooooooooo00Wooooo0P00001nooooo`;o000000<0
0000ooooooooool03?ooool00`00003oooooooooo`0Uooooo`0300000?oooooooooo03;ooooo00<0
0000ooooooooool08Oooool1o`00007ooooo00000ol0003oooooooooo`08ooooo`0300000?oooooo
oooo087ooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0>ooooo`?oo`3o5_ooool0
0`00003oooooooooo`0booooo`0300000?oooooooooo023ooooo0Ol00001ooooo`0000?o0000oooo
ooooool01oooool00`00003oooooooooo`23ooooo`0300000?oooooooooo00Oooooo0P00000@oooo
o`Goo`3o5Oooool00`00003oooooooooo`0booooo`0300000?oooooooooo023ooooo0Ol00001oooo
o`0000?o0000ooooooooool01_ooool00`00003oooooooooo`25ooooo`0300000?oooooooooo00Go
oooo00<00000ooooooooool04?ooool5ool0oaKooooo00<00000ooooooooool0<_ooool00`00003o
ooooooooo`0Oooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo0P000029ooooo`030000
0?oooooooooo00?ooooo00<00000ooooooooool04Oooool5ool0oaOooooo00<00000ooooooooool0
<Oooool00`00003oooooooooo`0Oooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo00<0
0000ooooooooool0R_ooool01@00003oooooooooooooool0000001Gooooo0ooo0?lHooooo`030000
0?oooooooooo03;ooooo00<00000ooooooooool07_ooool1o`00007ooooo00000ol0003ooooooooo
o`02ooooo`0300000?oooooooooo08cooooo00<00000ooooo`000000<_ooool00`00003ooooooooo
o`0aooooo`0300000?oooooooooo01kooooo0Ol00001ooooo`0000?o0000ooooooooool00P00002?
ooooo`03o`000000003o000003?ooooo00<00000ooooooooool0<Oooool00`00003oooooooooo`0M
ooooo`7o00000Oooool00003o`000?ooool00000097ooooo0ol0000dooooo`0300000?oooooooooo
037ooooo00<00000ooooooooool07?ooool1o`00007ooooo00000ol000000000ooooo`2Aooooo`?o
0000=?ooool00`00003oooooooooo`0aooooo`0300000?oooooooooo01cooooo0Ol00001ooooo`00
00<00000ooooooooool0Toooool00ol0003oooooooooo`0cooooo`0300000?oooooooooo037ooooo
00<00000ooooooooool06oooool1o`00007ooooo00000ol0003oooooooooo`2Cooooo`03o`000?oo
oooooooo03Cooooo00<00000ooooooooool0<?ooool00`00003oooooooooo`0Kooooo`7o00000Ooo
ool00003o`000?oooooooooo07Oooooo0ooo0?lIooooo`03o`000?oooooooooo03Gooooo00<00000
ooooooooool0<?ooool00`00003oooooooooo`0Jooooo`7o00000Oooool00003o`000?oooooooooo
07Kooooo1Ooo0?lHooooo`03o`000?oooooooooo03Gooooo00<00000ooooooooool0<?ooool00`00
003oooooooooo`0Jooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo1Ooo0?lHooooo`03
o`000?oooooooooo03Kooooo00<00000ooooooooool0<?ooool00`00003oooooooooo`0Iooooo`7o
00000Oooool00003o`000?oooooooooo07Kooooo1Ooo0?lIooooo`03o`000?oooooooooo03Kooooo
00<00000ooooooooool0<?ooool00`00003oooooooooo`0Hooooo`7o00000Oooool00003o`000?oo
oooooooo07Oooooo0ooo0?lJooooo`03o`000?oooooooooo03Kooooo00<00000ooooooooool0<?oo
ool00`00003oooooooooo`0Hooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o0000
ooooooooool0=oooool00`00003oooooooooo`0`ooooo`0300000?oooooooooo01Oooooo0Ol00001
ooooo`0000?o0000ooooooooool0U?ooool00ol0003oooooooooo`0hooooo`0300000?oooooooooo
02oooooo00<00000ooooooooool05oooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03
o`000?oooooooooo03Wooooo00<00000ooooooooool0;oooool00`00003oooooooooo`0Fooooo`7o
00000Oooool00003o`000?oooooooooo09Gooooo00?o0000ooooooooool0>?ooool00`00003ooooo
ooooo`0_ooooo`0300000?oooooooooo01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool00ol0003oooooooooo`0iooooo`0300000?oooooooooo02oooooo00<00000ooooooooool05Ooo
ool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`000?oooooooooo03[ooooo00<00000
ooooooooool0;_ooool00`00003oooooooooo`0Eooooo`7o00000Oooool00003o`000?oooooooooo
09Gooooo00?o0000ooooooooool0>_ooool00`00003oooooooooo`0_ooooo`0300000?oooooooooo
01Cooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol0003oooooooooo`0kooooo`03
00000?oooooooooo02oooooo00<00000ooooooooool04oooool1o`00007ooooo00000ol0003ooooo
ooooo`2Fooooo`03o`000?oooooooooo03_ooooo00<00000ooooooooool0;_ooool00`00003ooooo
ooooo`0Cooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo00?o0000ooooooooool0??oo
ool00`00003oooooooooo`0^ooooo`0300000?oooooooooo01;ooooo0Ol00001ooooo`0000?o0000
ooooooooool0U_ooool00ol0003oooooooooo`0looooo`0300000?oooooooooo02kooooo00<00000
ooooooooool04_ooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`03o`000?oooooooooo
03gooooo00<00000ooooooooool0;_ooool00`00003oooooooooo`0Aooooo`7o00000Oooool00003
o`000?oooooooooo09Oooooo00?o0000ooooooooool0?Oooool00`00003oooooooooo`0]ooooo`03
00000?oooooooooo017ooooo0Ol00001ooooo`0000?o0000ooooooooool0Uoooool00ol0003ooooo
ooooo`0nooooo`0300000?oooooooooo02gooooo00<00000ooooooooool04?ooool1o`00007ooooo
00000ol0003oooooooooo`2Gooooo`03o`000?oooooooooo03kooooo00<00000ooooooooool0;_oo
ool00`00003oooooooooo`0?ooooo`7o00000Oooool00003o`000?oooooooooo09Oooooo00?o0000
ooooooooool0?oooool00`00003oooooooooo`0]ooooo`0300000?oooooooooo00oooooo0Ol00001
ooooo`0000?o0000ooooooooool0Uoooool00ol0003oooooooooo`10ooooo`0300000?oooooooooo
02gooooo00<00000ooooooooool03_ooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`03
o`000?oooooooooo03oooooo00<00000ooooooooool0;Oooool00`00003oooooooooo`0>ooooo`7o
00000Oooool00003o`000?oooooooooo09Sooooo00?o0000ooooooooool0@?ooool00`00003ooooo
ooooo`0]ooooo`0300000?oooooooooo00gooooo0Ol00001ooooo`0000?o0000ooooooooool0V?oo
ool00ol0003oooooooooo`11ooooo`0300000?oooooooooo02cooooo00<00000ooooooooool03Ooo
ool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`03o`000?oooooooooo04;ooooo00<00000
ooooooooool0;?ooool00`00003oooooooooo`0<ooooo`7o00000Oooool00003o`000?oooooooooo
09Sooooo00?o0000ooooooooool0@_ooool00`00003oooooooooo`0]ooooo`0300000?oooooooooo
00_ooooo0Ol00001ooooo`0000?o0000ooooooooool0VOooool00ol0003oooooooooo`12ooooo`03
00000?oooooooooo02cooooo00<00000ooooooooool02oooool1o`00007ooooo00000ol0003ooooo
ooooo`2Iooooo`03o`000?oooooooooo04?ooooo00<00000ooooooooool0;?ooool00`00003ooooo
ooooo`0:ooooo`7o00000Oooool00003o`000?oooooooooo09Wooooo00?o0000ooooooooool0@ooo
ool00`00003oooooooooo`0/ooooo`0300000?oooooooooo00[ooooo0Ol00001ooooo`0000?o0000
ooooooooool0VOooool00ol0003oooooooooo`14ooooo`0300000?oooooooooo02cooooo00<00000
ooooooooool02Oooool1o`00007ooooo00000ol0003oooooooooo`2Jooooo`03o`000?oooooooooo
04Cooooo00<00000ooooooooool0:oooool00`00003oooooooooo`09ooooo`7o00000Oooool00003
o`000?oooooooooo09[ooooo00?o0000ooooooooool0AOooool00`00003oooooooooo`0[ooooo`03
00000?oooooooooo00Sooooo0Ol00001ooooo`0000?o0000ooooooooool0V_ooool00ol0003ooooo
ooooo`15ooooo`0300000?oooooooooo02cooooo00<00000ooooooooool01oooool1o`00007ooooo
00000ol0003oooooooooo`2Jooooo`03o`000?oooooooooo04Kooooo00<00000ooooooooool0:ooo
ool00`00003oooooooooo`07ooooo`7o00000Oooool00003o`000?oooooooooo09[ooooo00?o0000
ooooooooool0Aoooool00`00003oooooooooo`0[ooooo`0300000?oooooooooo00Kooooo0Ol00001
ooooo`0000?o0000ooooooooool0Voooool00ol0003oooooooooo`16ooooo`0300000?oooooooooo
02_ooooo00<00000ooooooooool01_ooool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03
o`000?oooooooooo04Oooooo00<00000ooooooooool0:oooool00`00003oooooooooo`05ooooo`7o
00000Oooool00003o`000?oooooooooo09_ooooo00?o0000ooooooooool0B?ooool00`00003ooooo
ooooo`0Zooooo`0300000?oooooooooo00Gooooo0Ol00001ooooo`0000?o0000ooooooooool0Vooo
ool00ol0003oooooooooo`19ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool01?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Kooooo`03o`000?oooooooooo04Wooooo00<00000
ooooooooool0:_ooool00`00003oooooooooo`04ooooo`7o00000Oooool00003o`000?oooooooooo
09cooooo00?o0000ooooooooool0BOooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo
00?ooooo0Ol00001ooooo`0000?o0000ooooooooool0W?ooool00ol0003oooooooooo`1:ooooo`03
00000?oooooooooo02[ooooo00<00000ooooooooool00_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Looooo`03o`000?oooooooooo04_ooooo00<00000ooooooooool0:Oooool00`00003ooooo
ooooo`02ooooo`7o00000Oooool00003o`000?oooooooooo09cooooo00?o0000ooooooooool0Booo
ool00`00003oooooooooo`0Zooooo`0500000?ooooooooooooooool000000Oooool00003o`000?oo
oooooooo09cooooo00?o0000ooooooooool0C?ooool00`00003oooooooooo`0Yooooo`0500000?oo
ooooooooooooool000000Oooool00003o`000?oooooooooo09gooooo00?o0000ooooooooool0C?oo
ool00`00003oooooooooo`0Yooooo`0400000?ooooooooooo`00007ooooo00000ol0003ooooooooo
o`2Mooooo`03o`000?oooooooooo04cooooo00<00000ooooooooool0:Oooool01000003ooooooooo
ool00001ooooo`0000?o0000ooooooooool0kOooool00`00003oooooooooo`0Yooooo`0300000?oo
oooo0000007ooooo00000ol0003oooooooooo`3^ooooo`0300000?oooooooooo02Wooooo0@000001
o`00007ooooo00000ol0003oooooooooo`3_ooooo`0300000?oooooooooo02Sooooo0@000001o`00
007ooooo00000ol0003oooooooooo`3_ooooo`0300000?oooooooooo02Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0l?ooool00`00003oooooooooo`0Xooooo`7o00000Oooool00003o`000?oo
oooooooo0?7ooooo00<00000ooooooooool09oooool1o`00007ooooo00000ol0003oooooooooo`3a
ooooo`0300000?oooooooooo02Oooooo0Ol00001ooooo`0000?o0000ooooooooool0l_ooool00`00
003oooooooooo`0Vooooo`7o00000Oooool00003o`000?oooooooooo0??ooooo00<00000oooooooo
ool09Oooool1o`00007ooooo00000ol0003oooooooooo`3dooooo`0300000?oooooooooo02Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0m?ooool00`00003oooooooooo`0Tooooo`7o00000Ooo
ool00003o`000?oooooooooo0?Gooooo00<00000ooooooooool08oooool1o`00007ooooo00000ol0
003oooooooooo`3fooooo`0300000?oooooooooo02;ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0m_ooool00`00003oooooooooo`0Rooooo`7o00000Oooool00003o`000?oooooooooo0?Oooooo
00<00000ooooooooool08Oooool1o`00007ooooo00000ol0003oooooooooo`3hooooo`0300000?oo
oooooooo023ooooo0Ol00001ooooo`00o?l000000`00003o0000o`00000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.00088, -1.00088, 0.00697479, \
0.00697479}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New histograms for two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Compute histograms based on data-dependent centroids", "Subsubsection"],

Cell[BoxData[{
    \(\(h1\  = Histogram[data1, vqCentroids, pr, 50];\)\), "\n", 
    \(\(h2\  = Histogram[data2, vqCentroids, pr, 50];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize two histograms", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gh1\  = 
        DrawHistogram[h1, pr, \ nS, 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(gh2\  = 
        DrawHistogram[h2, pr, \ nS, 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gh1, gh2}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
%%ImageSize: 400 154.502 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.657 .75 .918 r
.39593 .68197 .40219 .68749 .41268 .6845 .40644 .67896 Mtetra
.40644 .67896 .41268 .6845 .42321 .68151 .417 .67594 Mtetra
.417 .67594 .42321 .68151 .43378 .6785 .4276 .67291 Mtetra
.4276 .67291 .43378 .6785 .4444 .67548 .43824 .66987 Mtetra
.43824 .66987 .4444 .67548 .45505 .67245 .44892 .66682 Mtetra
.44892 .66682 .45505 .67245 .46575 .6694 .45964 .66375 Mtetra
.45964 .66375 .46575 .6694 .47649 .66635 .47041 .66067 Mtetra
.47041 .66067 .47649 .66635 .48727 .66328 .48122 .65758 Mtetra
.48122 .65758 .48727 .66328 .49809 .6602 .49207 .65448 Mtetra
.49207 .65448 .49809 .6602 .50896 .6571 .50297 .65136 Mtetra
.50297 .65136 .50896 .6571 .51987 .654 .5139 .64824 Mtetra
.5139 .64824 .51987 .654 .53083 .65088 .52489 .64509 Mtetra
.52489 .64509 .53083 .65088 .54182 .64775 .53591 .64194 Mtetra
.53591 .64194 .54182 .64775 .55287 .64461 .54698 .63878 Mtetra
.54698 .63878 .55287 .64461 .56395 .64146 .5581 .6356 Mtetra
.5581 .6356 .56395 .64146 .57508 .63829 .56926 .63241 Mtetra
.56926 .63241 .57508 .63829 .58626 .63511 .58047 .6292 Mtetra
.58047 .6292 .58626 .63511 .59748 .63191 .59172 .62599 Mtetra
.59172 .62599 .59748 .63191 .60874 .62871 .60301 .62276 Mtetra
.60301 .62276 .60874 .62871 .62005 .62549 .61435 .61951 Mtetra
.61435 .61951 .62005 .62549 .63141 .62226 .62574 .61626 Mtetra
.62574 .61626 .63141 .62226 .64282 .61901 .63718 .61299 Mtetra
.63718 .61299 .64282 .61901 .65427 .61575 .64866 .6097 Mtetra
.64866 .6097 .65427 .61575 .66576 .61248 .66019 .60641 Mtetra
.66019 .60641 .66576 .61248 .67731 .6092 .67176 .6031 Mtetra
.67176 .6031 .67731 .6092 .6889 .6059 .68339 .59977 Mtetra
.68339 .59977 .6889 .6059 .70054 .60259 .69506 .59644 Mtetra
.69506 .59644 .70054 .60259 .71222 .59926 .70678 .59308 Mtetra
.904 .5 .103 r
.70678 .59308 .71222 .59926 .72628 .63575 .72081 .62963 Mtetra
.654 .754 .923 r
.72081 .62963 .72628 .63575 .7382 .63244 .73278 .6263 Mtetra
.73278 .6263 .7382 .63244 .75018 .62912 .74479 .62295 Mtetra
.74479 .62295 .75018 .62912 .76221 .62578 .75685 .61958 Mtetra
.75685 .61958 .76221 .62578 .77428 .62243 .76896 .61621 Mtetra
.76896 .61621 .77428 .62243 .78641 .61907 .78113 .61282 Mtetra
.78113 .61282 .78641 .61907 .79859 .61569 .79334 .60941 Mtetra
.79334 .60941 .79859 .61569 .81082 .61229 .80561 .60599 Mtetra
.80561 .60599 .81082 .61229 .8231 .60888 .81793 .60255 Mtetra
.81793 .60255 .8231 .60888 .83544 .60546 .8303 .5991 Mtetra
.8303 .5991 .83544 .60546 .84783 .60202 .84273 .59564 Mtetra
.84273 .59564 .84783 .60202 .86027 .59857 .85521 .59216 Mtetra
.85521 .59216 .86027 .59857 .87276 .59511 .86774 .58867 Mtetra
.86774 .58867 .87276 .59511 .88531 .59162 .88032 .58516 Mtetra
.88032 .58516 .88531 .59162 .89791 .58813 .89297 .58163 Mtetra
.831 .411 0 r
.89297 .58163 .89791 .58813 .91057 .58462 .91032 .61966 Mtetra
.529 .262 .454 r
.91032 .61966 .91057 .58462 .92814 .62262 .92323 .61615 Mtetra
.65 .758 .928 r
.92323 .61615 .92814 .62262 .94107 .61912 .93621 .61263 Mtetra
.93621 .61263 .94107 .61912 .95406 .61561 .94924 .60909 Mtetra
.94924 .60909 .95406 .61561 .9671 .61209 .96233 .60554 Mtetra
.96233 .60554 .9671 .61209 .98021 .60855 .97547 .60197 Mtetra
.97547 .60197 .98021 .60855 .99337 .60499 .98868 .59838 Mtetra
.657 .75 .918 r
.38962 .67641 .39593 .68197 .40644 .67896 .40016 .67338 Mtetra
.40016 .67338 .40644 .67896 .417 .67594 .41074 .67034 Mtetra
.41074 .67034 .417 .67594 .4276 .67291 .42137 .66729 Mtetra
.42137 .66729 .4276 .67291 .43824 .66987 .43203 .66422 Mtetra
.43203 .66422 .43824 .66987 .44892 .66682 .44274 .66115 Mtetra
.44274 .66115 .44892 .66682 .45964 .66375 .45349 .65806 Mtetra
.45349 .65806 .45964 .66375 .47041 .66067 .46429 .65496 Mtetra
.46429 .65496 .47041 .66067 .48122 .65758 .47512 .65184 Mtetra
.47512 .65184 .48122 .65758 .49207 .65448 .486 .64872 Mtetra
.486 .64872 .49207 .65448 .50297 .65136 .49693 .64558 Mtetra
.49693 .64558 .50297 .65136 .5139 .64824 .50789 .64243 Mtetra
.50789 .64243 .5139 .64824 .52489 .64509 .5189 .63926 Mtetra
.5189 .63926 .52489 .64509 .53591 .64194 .52996 .63609 Mtetra
.52996 .63609 .53591 .64194 .54698 .63878 .54106 .6329 Mtetra
.54106 .6329 .54698 .63878 .5581 .6356 .5522 .6297 Mtetra
.5522 .6297 .5581 .6356 .56926 .63241 .56339 .62648 Mtetra
.56339 .62648 .56926 .63241 .58047 .6292 .57463 .62325 Mtetra
.57463 .62325 .58047 .6292 .59172 .62599 .58591 .62001 Mtetra
.58591 .62001 .59172 .62599 .60301 .62276 .59724 .61676 Mtetra
.59724 .61676 .60301 .62276 .61435 .61951 .60861 .61349 Mtetra
.60861 .61349 .61435 .61951 .62574 .61626 .62003 .61021 Mtetra
.62003 .61021 .62574 .61626 .63718 .61299 .6315 .60691 Mtetra
.6315 .60691 .63718 .61299 .64866 .6097 .64301 .60361 Mtetra
.64301 .60361 .64866 .6097 .66019 .60641 .65457 .60028 Mtetra
.65457 .60028 .66019 .60641 .67176 .6031 .66618 .59695 Mtetra
.66618 .59695 .67176 .6031 .68339 .59977 .67784 .5936 Mtetra
.67784 .5936 .68339 .59977 .69506 .59644 .68954 .59024 Mtetra
.68954 .59024 .69506 .59644 .70678 .59308 .7013 .58686 Mtetra
.904 .5 .103 r
.7013 .58686 .70678 .59308 .72081 .62963 .71531 .62346 Mtetra
.654 .754 .923 r
.71531 .62346 .72081 .62963 .73278 .6263 .7273 .6201 Mtetra
.7273 .6201 .73278 .6263 .74479 .62295 .73935 .61673 Mtetra
.73935 .61673 .74479 .62295 .75685 .61958 .75145 .61334 Mtetra
.75145 .61334 .75685 .61958 .76896 .61621 .7636 .60993 Mtetra
.7636 .60993 .76896 .61621 .78113 .61282 .7758 .60652 Mtetra
.7758 .60652 .78113 .61282 .79334 .60941 .78805 .60308 Mtetra
.78805 .60308 .79334 .60941 .80561 .60599 .80035 .59964 Mtetra
.80035 .59964 .80561 .60599 .81793 .60255 .81271 .59617 Mtetra
.81271 .59617 .81793 .60255 .8303 .5991 .82512 .5927 Mtetra
.82512 .5927 .8303 .5991 .84273 .59564 .83759 .5892 Mtetra
.83759 .5892 .84273 .59564 .85521 .59216 .8501 .5857 Mtetra
.8501 .5857 .85521 .59216 .86774 .58867 .86267 .58218 Mtetra
.86267 .58218 .86774 .58867 .88032 .58516 .8753 .57864 Mtetra
.838 .419 0 r
.8753 .57864 .88032 .58516 .89297 .58163 .89243 .6167 Mtetra
.527 .259 .452 r
.89243 .6167 .89297 .58163 .91032 .61966 .90533 .61317 Mtetra
.65 .758 .928 r
.90533 .61317 .91032 .61966 .92323 .61615 .91829 .60964 Mtetra
.91829 .60964 .92323 .61615 .93621 .61263 .9313 .60609 Mtetra
.9313 .60609 .93621 .61263 .94924 .60909 .94438 .60252 Mtetra
.94438 .60252 .94924 .60909 .96233 .60554 .95751 .59894 Mtetra
.95751 .59894 .96233 .60554 .97547 .60197 .9707 .59534 Mtetra
.9707 .59534 .97547 .60197 .98868 .59838 .98395 .59172 Mtetra
.657 .75 .918 r
.38327 .67081 .38962 .67641 .40016 .67338 .39383 .66776 Mtetra
.39383 .66776 .40016 .67338 .41074 .67034 .40444 .6647 Mtetra
.40444 .6647 .41074 .67034 .42137 .66729 .41509 .66162 Mtetra
.41509 .66162 .42137 .66729 .43203 .66422 .42578 .65853 Mtetra
.42578 .65853 .43203 .66422 .44274 .66115 .43652 .65543 Mtetra
.43652 .65543 .44274 .66115 .45349 .65806 .4473 .65232 Mtetra
.4473 .65232 .45349 .65806 .46429 .65496 .45812 .6492 Mtetra
.45812 .6492 .46429 .65496 .47512 .65184 .46898 .64606 Mtetra
.46898 .64606 .47512 .65184 .486 .64872 .47989 .64291 Mtetra
.47989 .64291 .486 .64872 .49693 .64558 .49084 .63975 Mtetra
.49084 .63975 .49693 .64558 .50789 .64243 .50184 .63658 Mtetra
.50184 .63658 .50789 .64243 .5189 .63926 .51288 .63339 Mtetra
.51288 .63339 .5189 .63926 .52996 .63609 .52396 .63019 Mtetra
.52396 .63019 .52996 .63609 .54106 .6329 .53509 .62698 Mtetra
.53509 .62698 .54106 .6329 .5522 .6297 .54626 .62375 Mtetra
.54626 .62375 .5522 .6297 .56339 .62648 .55748 .62051 Mtetra
.55748 .62051 .56339 .62648 .57463 .62325 .56875 .61726 Mtetra
.56875 .61726 .57463 .62325 .58591 .62001 .58006 .61399 Mtetra
.58006 .61399 .58591 .62001 .59724 .61676 .59142 .61071 Mtetra
.59142 .61071 .59724 .61676 .60861 .61349 .60282 .60742 Mtetra
.60282 .60742 .60861 .61349 .62003 .61021 .61428 .60412 Mtetra
.61428 .60412 .62003 .61021 .6315 .60691 .62577 .6008 Mtetra
.62577 .6008 .6315 .60691 .64301 .60361 .63732 .59746 Mtetra
.63732 .59746 .64301 .60361 .65457 .60028 .64891 .59412 Mtetra
.64891 .59412 .65457 .60028 .66618 .59695 .66055 .59076 Mtetra
.66055 .59076 .66618 .59695 .67784 .5936 .67224 .58738 Mtetra
.67224 .58738 .67784 .5936 .68954 .59024 .68398 .58399 Mtetra
.907 .504 .113 r
.68398 .58399 .68954 .59024 .7013 .58686 .69778 .62062 Mtetra
.524 .254 .447 r
.69778 .62062 .7013 .58686 .71531 .62346 .70976 .61725 Mtetra
.654 .754 .923 r
.70976 .61725 .71531 .62346 .7273 .6201 .72179 .61386 Mtetra
.72179 .61386 .7273 .6201 .73935 .61673 .73387 .61046 Mtetra
.73387 .61046 .73935 .61673 .75145 .61334 .74601 .60704 Mtetra
.74601 .60704 .75145 .61334 .7636 .60993 .75819 .60361 Mtetra
.75819 .60361 .7636 .60993 .7758 .60652 .77043 .60017 Mtetra
.77043 .60017 .7758 .60652 .78805 .60308 .78272 .59671 Mtetra
.78272 .59671 .78805 .60308 .80035 .59964 .79506 .59323 Mtetra
.79506 .59323 .80035 .59964 .81271 .59617 .80745 .58974 Mtetra
.80745 .58974 .81271 .59617 .82512 .5927 .8199 .58624 Mtetra
.8199 .58624 .82512 .5927 .83759 .5892 .8324 .58272 Mtetra
.8324 .58272 .83759 .5892 .8501 .5857 .84496 .57918 Mtetra
.84496 .57918 .8501 .5857 .86267 .58218 .85757 .57563 Mtetra
.845 .427 0 r
.85757 .57563 .86267 .58218 .8753 .57864 .87447 .61372 Mtetra
.525 .256 .45 r
.87447 .61372 .8753 .57864 .89243 .6167 .88736 .61018 Mtetra
.65 .758 .928 r
.88736 .61018 .89243 .6167 .90533 .61317 .9003 .60663 Mtetra
.9003 .60663 .90533 .61317 .91829 .60964 .9133 .60307 Mtetra
.9133 .60307 .91829 .60964 .9313 .60609 .92636 .59949 Mtetra
.92636 .59949 .9313 .60609 .94438 .60252 .93948 .59589 Mtetra
.93948 .59589 .94438 .60252 .95751 .59894 .95265 .59228 Mtetra
.95265 .59228 .95751 .59894 .9707 .59534 .96589 .58865 Mtetra
.987 .72 .422 r
.96589 .58865 .9707 .59534 .98395 .59172 .96409 .47186 Mtetra
.657 .75 .918 r
.37687 .66517 .38327 .67081 .39383 .66776 .38746 .66209 Mtetra
.38746 .66209 .39383 .66776 .40444 .6647 .39809 .65901 Mtetra
.39809 .65901 .40444 .6647 .41509 .66162 .40877 .65591 Mtetra
.40877 .65591 .41509 .66162 .42578 .65853 .41949 .6528 Mtetra
.41949 .6528 .42578 .65853 .43652 .65543 .43025 .64968 Mtetra
.43025 .64968 .43652 .65543 .4473 .65232 .44106 .64655 Mtetra
.44106 .64655 .4473 .65232 .45812 .6492 .4519 .6434 Mtetra
.4519 .6434 .45812 .6492 .46898 .64606 .4628 .64024 Mtetra
.4628 .64024 .46898 .64606 .47989 .64291 .47373 .63707 Mtetra
.47373 .63707 .47989 .64291 .49084 .63975 .48471 .63388 Mtetra
.48471 .63388 .49084 .63975 .50184 .63658 .49574 .63068 Mtetra
.49574 .63068 .50184 .63658 .51288 .63339 .5068 .62747 Mtetra
.5068 .62747 .51288 .63339 .52396 .63019 .51792 .62425 Mtetra
.51792 .62425 .52396 .63019 .53509 .62698 .52908 .62101 Mtetra
.52908 .62101 .53509 .62698 .54626 .62375 .54028 .61776 Mtetra
.54028 .61776 .54626 .62375 .55748 .62051 .55153 .6145 Mtetra
.55153 .6145 .55748 .62051 .56875 .61726 .56283 .61122 Mtetra
.56283 .61122 .56875 .61726 .58006 .61399 .57417 .60793 Mtetra
.57417 .60793 .58006 .61399 .59142 .61071 .58556 .60463 Mtetra
.58556 .60463 .59142 .61071 .60282 .60742 .59699 .60131 Mtetra
.59699 .60131 .60282 .60742 .61428 .60412 .60848 .59798 Mtetra
.60848 .59798 .61428 .60412 .62577 .6008 .62001 .59463 Mtetra
.62001 .59463 .62577 .6008 .63732 .59746 .63158 .59127 Mtetra
.63158 .59127 .63732 .59746 .64891 .59412 .64321 .5879 Mtetra
.64321 .5879 .64891 .59412 .66055 .59076 .65488 .58451 Mtetra
.65488 .58451 .66055 .59076 .67224 .58738 .66661 .58111 Mtetra
.66661 .58111 .67224 .58738 .68398 .58399 .67838 .5777 Mtetra
.907 .504 .113 r
.67838 .5777 .68398 .58399 .69778 .62062 .69215 .61438 Mtetra
.654 .754 .923 r
.69215 .61438 .69778 .62062 .70976 .61725 .70417 .61098 Mtetra
.70417 .61098 .70976 .61725 .72179 .61386 .71623 .60757 Mtetra
.71623 .60757 .72179 .61386 .73387 .61046 .72835 .60414 Mtetra
.72835 .60414 .73387 .61046 .74601 .60704 .74052 .6007 Mtetra
.74052 .6007 .74601 .60704 .75819 .60361 .75274 .59724 Mtetra
.75274 .59724 .75819 .60361 .77043 .60017 .76502 .59377 Mtetra
.76502 .59377 .77043 .60017 .78272 .59671 .77734 .59028 Mtetra
.77734 .59028 .78272 .59671 .79506 .59323 .78972 .58678 Mtetra
.78972 .58678 .79506 .59323 .80745 .58974 .80215 .58326 Mtetra
.80215 .58326 .80745 .58974 .8199 .58624 .81464 .57973 Mtetra
.81464 .57973 .8199 .58624 .8324 .58272 .82718 .57618 Mtetra
.82718 .57618 .8324 .58272 .84496 .57918 .83978 .57262 Mtetra
.83978 .57262 .84496 .57918 .85757 .57563 .85243 .56904 Mtetra
.845 .427 0 r
.85243 .56904 .85757 .57563 .87447 .61372 .86932 .60718 Mtetra
.65 .758 .928 r
.86932 .60718 .87447 .61372 .88736 .61018 .88225 .60362 Mtetra
.88225 .60362 .88736 .61018 .9003 .60663 .89524 .60004 Mtetra
.89524 .60004 .9003 .60663 .9133 .60307 .90828 .59645 Mtetra
.90828 .59645 .9133 .60307 .92636 .59949 .92138 .59284 Mtetra
.92138 .59284 .92636 .59949 .93948 .59589 .93454 .58921 Mtetra
.93454 .58921 .93948 .59589 .95265 .59228 .94776 .58557 Mtetra
.94776 .58557 .95265 .59228 .96589 .58865 .96103 .58191 Mtetra
.987 .72 .422 r
.96103 .58191 .96589 .58865 .96409 .47186 .95938 .46486 Mtetra
.657 .75 .918 r
.37042 .65948 .37687 .66517 .38746 .66209 .38104 .65639 Mtetra
.38104 .65639 .38746 .66209 .39809 .65901 .3917 .65328 Mtetra
.3917 .65328 .39809 .65901 .40877 .65591 .4024 .65016 Mtetra
.4024 .65016 .40877 .65591 .41949 .6528 .41315 .64703 Mtetra
.41315 .64703 .41949 .6528 .43025 .64968 .42394 .64388 Mtetra
.42394 .64388 .43025 .64968 .44106 .64655 .43477 .64073 Mtetra
.43477 .64073 .44106 .64655 .4519 .6434 .44564 .63756 Mtetra
.44564 .63756 .4519 .6434 .4628 .64024 .45656 .63437 Mtetra
.45656 .63437 .4628 .64024 .47373 .63707 .46753 .63118 Mtetra
.46753 .63118 .47373 .63707 .48471 .63388 .47854 .62797 Mtetra
.47854 .62797 .48471 .63388 .49574 .63068 .48959 .62475 Mtetra
.48959 .62475 .49574 .63068 .5068 .62747 .50069 .62151 Mtetra
.50069 .62151 .5068 .62747 .51792 .62425 .51183 .61826 Mtetra
.51183 .61826 .51792 .62425 .52908 .62101 .52302 .615 Mtetra
.52302 .615 .52908 .62101 .54028 .61776 .53425 .61173 Mtetra
.53425 .61173 .54028 .61776 .55153 .6145 .54553 .60844 Mtetra
.54553 .60844 .55153 .6145 .56283 .61122 .55686 .60514 Mtetra
.55686 .60514 .56283 .61122 .57417 .60793 .56823 .60182 Mtetra
.56823 .60182 .57417 .60793 .58556 .60463 .57965 .59849 Mtetra
.57965 .59849 .58556 .60463 .59699 .60131 .59112 .59515 Mtetra
.59112 .59515 .59699 .60131 .60848 .59798 .60263 .59179 Mtetra
.60263 .59179 .60848 .59798 .62001 .59463 .61419 .58842 Mtetra
.61419 .58842 .62001 .59463 .63158 .59127 .6258 .58504 Mtetra
.6258 .58504 .63158 .59127 .64321 .5879 .63746 .58164 Mtetra
.63746 .58164 .64321 .5879 .65488 .58451 .64917 .57822 Mtetra
.64917 .57822 .65488 .58451 .66661 .58111 .66093 .5748 Mtetra
.66093 .5748 .66661 .58111 .67838 .5777 .67273 .57136 Mtetra
.907 .504 .113 r
.67273 .57136 .67838 .5777 .69215 .61438 .68648 .6081 Mtetra
.654 .754 .923 r
.68648 .6081 .69215 .61438 .70417 .61098 .69853 .60467 Mtetra
.69853 .60467 .70417 .61098 .71623 .60757 .71063 .60123 Mtetra
.71063 .60123 .71623 .60757 .72835 .60414 .72279 .59777 Mtetra
.72279 .59777 .72835 .60414 .74052 .6007 .73499 .5943 Mtetra
.73499 .5943 .74052 .6007 .75274 .59724 .74725 .59082 Mtetra
.74725 .59082 .75274 .59724 .76502 .59377 .75956 .58732 Mtetra
.75956 .58732 .76502 .59377 .77734 .59028 .77192 .5838 Mtetra
.77192 .5838 .77734 .59028 .78972 .58678 .78434 .58027 Mtetra
.78434 .58027 .78972 .58678 .80215 .58326 .79681 .57673 Mtetra
.79681 .57673 .80215 .58326 .81464 .57973 .80934 .57317 Mtetra
.80934 .57317 .81464 .57973 .82718 .57618 .82192 .56959 Mtetra
.82192 .56959 .82718 .57618 .83978 .57262 .83455 .566 Mtetra
.851 .434 0 r
.83455 .566 .83978 .57262 .85243 .56904 .85122 .60417 Mtetra
.522 .251 .445 r
.85122 .60417 .85243 .56904 .86932 .60718 .86413 .60059 Mtetra
.65 .758 .928 r
.86413 .60059 .86932 .60718 .88225 .60362 .8771 .597 Mtetra
.8771 .597 .88225 .60362 .89524 .60004 .89013 .59339 Mtetra
.89013 .59339 .89524 .60004 .90828 .59645 .90321 .58977 Mtetra
.90321 .58977 .90828 .59645 .92138 .59284 .91635 .58613 Mtetra
.91635 .58613 .92138 .59284 .93454 .58921 .92956 .58247 Mtetra
.92956 .58247 .93454 .58921 .94776 .58557 .94282 .5788 Mtetra
.986 .721 .428 r
.94282 .5788 .94776 .58557 .96103 .58191 .94174 .46163 Mtetra
.582 .393 .59 r
.94174 .46163 .96103 .58191 .95938 .46486 .95464 .4578 Mtetra
.657 .75 .918 r
.36392 .65376 .37042 .65948 .38104 .65639 .37457 .65064 Mtetra
.37457 .65064 .38104 .65639 .3917 .65328 .38525 .64751 Mtetra
.38525 .64751 .3917 .65328 .4024 .65016 .39598 .64437 Mtetra
.39598 .64437 .4024 .65016 .41315 .64703 .40676 .64121 Mtetra
.40676 .64121 .41315 .64703 .42394 .64388 .41757 .63804 Mtetra
.41757 .63804 .42394 .64388 .43477 .64073 .42843 .63486 Mtetra
.42843 .63486 .43477 .64073 .44564 .63756 .43934 .63167 Mtetra
.43934 .63167 .44564 .63756 .45656 .63437 .45028 .62846 Mtetra
.45028 .62846 .45656 .63437 .46753 .63118 .46128 .62524 Mtetra
.46128 .62524 .46753 .63118 .47854 .62797 .47231 .62201 Mtetra
.47231 .62201 .47854 .62797 .48959 .62475 .4834 .61876 Mtetra
.4834 .61876 .48959 .62475 .50069 .62151 .49452 .6155 Mtetra
.49452 .6155 .50069 .62151 .51183 .61826 .50569 .61223 Mtetra
.50569 .61223 .51183 .61826 .52302 .615 .51691 .60894 Mtetra
.51691 .60894 .52302 .615 .53425 .61173 .52818 .60564 Mtetra
.52818 .60564 .53425 .61173 .54553 .60844 .53949 .60233 Mtetra
.53949 .60233 .54553 .60844 .55686 .60514 .55084 .599 Mtetra
.55084 .599 .55686 .60514 .56823 .60182 .56225 .59566 Mtetra
.56225 .59566 .56823 .60182 .57965 .59849 .5737 .59231 Mtetra
.5737 .59231 .57965 .59849 .59112 .59515 .5852 .58894 Mtetra
.5852 .58894 .59112 .59515 .60263 .59179 .59674 .58556 Mtetra
.59674 .58556 .60263 .59179 .61419 .58842 .60834 .58216 Mtetra
.60834 .58216 .61419 .58842 .6258 .58504 .61998 .57875 Mtetra
.61998 .57875 .6258 .58504 .63746 .58164 .63167 .57533 Mtetra
.63167 .57533 .63746 .58164 .64917 .57822 .64341 .57189 Mtetra
.64341 .57189 .64917 .57822 .66093 .5748 .6552 .56843 Mtetra
.6552 .56843 .66093 .5748 .67273 .57136 .66704 .56497 Mtetra
.907 .504 .113 r
.66704 .56497 .67273 .57136 .68648 .6081 .68076 .60176 Mtetra
.654 .754 .923 r
.68076 .60176 .68648 .6081 .69853 .60467 .69285 .59831 Mtetra
.69285 .59831 .69853 .60467 .71063 .60123 .70499 .59484 Mtetra
.70499 .59484 .71063 .60123 .72279 .59777 .71718 .59136 Mtetra
.71718 .59136 .72279 .59777 .73499 .5943 .72942 .58786 Mtetra
.72942 .58786 .73499 .5943 .74725 .59082 .74171 .58434 Mtetra
.74171 .58434 .74725 .59082 .75956 .58732 .75406 .58082 Mtetra
.75406 .58082 .75956 .58732 .77192 .5838 .76646 .57727 Mtetra
.76646 .57727 .77192 .5838 .78434 .58027 .77892 .57371 Mtetra
.77892 .57371 .78434 .58027 .79681 .57673 .79143 .57014 Mtetra
.79143 .57014 .79681 .57673 .80934 .57317 .80399 .56655 Mtetra
.80399 .56655 .80934 .57317 .82192 .56959 .81661 .56295 Mtetra
.858 .441 0 r
.81661 .56295 .82192 .56959 .83455 .566 .83305 .60114 Mtetra
.52 .248 .443 r
.83305 .60114 .83455 .566 .85122 .60417 .84594 .59755 Mtetra
.65 .758 .928 r
.84594 .59755 .85122 .60417 .86413 .60059 .85889 .59395 Mtetra
.85889 .59395 .86413 .60059 .8771 .597 .87191 .59033 Mtetra
.87191 .59033 .8771 .597 .89013 .59339 .88497 .58669 Mtetra
.88497 .58669 .89013 .59339 .90321 .58977 .8981 .58304 Mtetra
.8981 .58304 .90321 .58977 .91635 .58613 .91129 .57937 Mtetra
.91129 .57937 .91635 .58613 .92956 .58247 .92453 .57568 Mtetra
.986 .721 .434 r
.92453 .57568 .92956 .58247 .94282 .5788 .92402 .45839 Mtetra
.581 .391 .59 r
.92402 .45839 .94282 .5788 .94174 .46163 .93691 .45455 Mtetra
.659 .747 .915 r
.93691 .45455 .94174 .46163 .95464 .4578 .94985 .45069 Mtetra
.657 .75 .918 r
.35738 .64799 .36392 .65376 .37457 .65064 .36805 .64485 Mtetra
.36805 .64485 .37457 .65064 .38525 .64751 .37876 .6417 Mtetra
.37876 .6417 .38525 .64751 .39598 .64437 .38952 .63853 Mtetra
.38952 .63853 .39598 .64437 .40676 .64121 .40032 .63535 Mtetra
.40032 .63535 .40676 .64121 .41757 .63804 .41116 .63216 Mtetra
.41116 .63216 .41757 .63804 .42843 .63486 .42205 .62896 Mtetra
.42205 .62896 .42843 .63486 .43934 .63167 .43298 .62574 Mtetra
.43298 .62574 .43934 .63167 .45028 .62846 .44396 .62251 Mtetra
.44396 .62251 .45028 .62846 .46128 .62524 .45498 .61926 Mtetra
.45498 .61926 .46128 .62524 .47231 .62201 .46604 .61601 Mtetra
.46604 .61601 .47231 .62201 .4834 .61876 .47716 .61273 Mtetra
.47716 .61273 .4834 .61876 .49452 .6155 .48831 .60945 Mtetra
.48831 .60945 .49452 .6155 .50569 .61223 .49951 .60615 Mtetra
.49951 .60615 .50569 .61223 .51691 .60894 .51076 .60284 Mtetra
.51076 .60284 .51691 .60894 .52818 .60564 .52206 .59952 Mtetra
.52206 .59952 .52818 .60564 .53949 .60233 .5334 .59618 Mtetra
.5334 .59618 .53949 .60233 .55084 .599 .54478 .59283 Mtetra
.54478 .59283 .55084 .599 .56225 .59566 .55622 .58946 Mtetra
.55622 .58946 .56225 .59566 .5737 .59231 .5677 .58608 Mtetra
.5677 .58608 .5737 .59231 .5852 .58894 .57923 .58268 Mtetra
.57923 .58268 .5852 .58894 .59674 .58556 .59081 .57928 Mtetra
.59081 .57928 .59674 .58556 .60834 .58216 .60244 .57585 Mtetra
.60244 .57585 .60834 .58216 .61998 .57875 .61411 .57242 Mtetra
.61411 .57242 .61998 .57875 .63167 .57533 .62584 .56897 Mtetra
.62584 .56897 .63167 .57533 .64341 .57189 .63761 .5655 Mtetra
.63761 .5655 .64341 .57189 .6552 .56843 .64943 .56202 Mtetra
.64943 .56202 .6552 .56843 .66704 .56497 .66131 .55852 Mtetra
.907 .504 .113 r
.66131 .55852 .66704 .56497 .68076 .60176 .675 .59537 Mtetra
.654 .754 .923 r
.675 .59537 .68076 .60176 .69285 .59831 .68712 .59189 Mtetra
.68712 .59189 .69285 .59831 .70499 .59484 .6993 .5884 Mtetra
.6993 .5884 .70499 .59484 .71718 .59136 .71152 .58489 Mtetra
.71152 .58489 .71718 .59136 .72942 .58786 .7238 .58136 Mtetra
.7238 .58136 .72942 .58786 .74171 .58434 .73613 .57782 Mtetra
.73613 .57782 .74171 .58434 .75406 .58082 .74852 .57426 Mtetra
.74852 .57426 .75406 .58082 .76646 .57727 .76096 .57069 Mtetra
.76096 .57069 .76646 .57727 .77892 .57371 .77345 .5671 Mtetra
.77345 .5671 .77892 .57371 .79143 .57014 .786 .5635 Mtetra
.786 .5635 .79143 .57014 .80399 .56655 .7986 .55988 Mtetra
.7986 .55988 .80399 .56655 .81661 .56295 .81126 .55625 Mtetra
.858 .441 0 r
.81126 .55625 .81661 .56295 .83305 .60114 .82768 .5945 Mtetra
.65 .758 .928 r
.82768 .5945 .83305 .60114 .84594 .59755 .84062 .59089 Mtetra
.84062 .59089 .84594 .59755 .85889 .59395 .85362 .58725 Mtetra
.85362 .58725 .85889 .59395 .87191 .59033 .86667 .5836 Mtetra
.86667 .5836 .87191 .59033 .88497 .58669 .87978 .57993 Mtetra
.87978 .57993 .88497 .58669 .8981 .58304 .89295 .57625 Mtetra
.89295 .57625 .8981 .58304 .91129 .57937 .90618 .57255 Mtetra
.90618 .57255 .91129 .57937 .92453 .57568 .91947 .56883 Mtetra
.986 .721 .434 r
.91947 .56883 .92453 .57568 .92402 .45839 .91911 .45128 Mtetra
.659 .747 .915 r
.91911 .45128 .92402 .45839 .93691 .45455 .93204 .44741 Mtetra
.93204 .44741 .93691 .45455 .94985 .45069 .94503 .44352 Mtetra
.657 .75 .918 r
.35079 .64219 .35738 .64799 .36805 .64485 .36148 .63902 Mtetra
.36148 .63902 .36805 .64485 .37876 .6417 .37222 .63584 Mtetra
.37222 .63584 .37876 .6417 .38952 .63853 .38301 .63265 Mtetra
.38301 .63265 .38952 .63853 .40032 .63535 .39384 .62945 Mtetra
.39384 .62945 .40032 .63535 .41116 .63216 .40471 .62623 Mtetra
.40471 .62623 .41116 .63216 .42205 .62896 .41562 .623 Mtetra
.41562 .623 .42205 .62896 .43298 .62574 .42658 .61976 Mtetra
.42658 .61976 .43298 .62574 .44396 .62251 .43759 .61651 Mtetra
.43759 .61651 .44396 .62251 .45498 .61926 .44863 .61324 Mtetra
.44863 .61324 .45498 .61926 .46604 .61601 .45973 .60996 Mtetra
.45973 .60996 .46604 .61601 .47716 .61273 .47087 .60666 Mtetra
.47087 .60666 .47716 .61273 .48831 .60945 .48205 .60335 Mtetra
.48205 .60335 .48831 .60945 .49951 .60615 .49329 .60003 Mtetra
.49329 .60003 .49951 .60615 .51076 .60284 .50456 .59669 Mtetra
.50456 .59669 .51076 .60284 .52206 .59952 .51589 .59334 Mtetra
.51589 .59334 .52206 .59952 .5334 .59618 .52726 .58998 Mtetra
.52726 .58998 .5334 .59618 .54478 .59283 .53868 .5866 Mtetra
.53868 .5866 .54478 .59283 .55622 .58946 .55014 .58321 Mtetra
.55014 .58321 .55622 .58946 .5677 .58608 .56166 .5798 Mtetra
.56166 .5798 .5677 .58608 .57923 .58268 .57322 .57638 Mtetra
.57322 .57638 .57923 .58268 .59081 .57928 .58483 .57295 Mtetra
.58483 .57295 .59081 .57928 .60244 .57585 .59649 .5695 Mtetra
.59649 .5695 .60244 .57585 .61411 .57242 .6082 .56603 Mtetra
.6082 .56603 .61411 .57242 .62584 .56897 .61996 .56256 Mtetra
.61996 .56256 .62584 .56897 .63761 .5655 .63176 .55906 Mtetra
.63176 .55906 .63761 .5655 .64943 .56202 .64362 .55555 Mtetra
.91 .509 .124 r
.64362 .55555 .64943 .56202 .66131 .55852 .65709 .59243 Mtetra
.514 .239 .435 r
.65709 .59243 .66131 .55852 .675 .59537 .6692 .58894 Mtetra
.654 .754 .923 r
.6692 .58894 .675 .59537 .68712 .59189 .68135 .58543 Mtetra
.68135 .58543 .68712 .59189 .6993 .5884 .69356 .5819 Mtetra
.69356 .5819 .6993 .5884 .71152 .58489 .70582 .57837 Mtetra
.70582 .57837 .71152 .58489 .7238 .58136 .71814 .57481 Mtetra
.71814 .57481 .7238 .58136 .73613 .57782 .73051 .57124 Mtetra
.73051 .57124 .73613 .57782 .74852 .57426 .74293 .56766 Mtetra
.74293 .56766 .74852 .57426 .76096 .57069 .75541 .56406 Mtetra
.75541 .56406 .76096 .57069 .77345 .5671 .76794 .56044 Mtetra
.76794 .56044 .77345 .5671 .786 .5635 .78053 .55681 Mtetra
.78053 .55681 .786 .5635 .7986 .55988 .79317 .55316 Mtetra
.863 .448 0 r
.79317 .55316 .7986 .55988 .81126 .55625 .80936 .59144 Mtetra
.516 .242 .438 r
.80936 .59144 .81126 .55625 .82768 .5945 .82228 .58781 Mtetra
.65 .758 .928 r
.82228 .58781 .82768 .5945 .84062 .59089 .83526 .58416 Mtetra
.83526 .58416 .84062 .59089 .85362 .58725 .84829 .5805 Mtetra
.84829 .5805 .85362 .58725 .86667 .5836 .86139 .57682 Mtetra
.86139 .57682 .86667 .5836 .87978 .57993 .87454 .57312 Mtetra
.87454 .57312 .87978 .57993 .89295 .57625 .88776 .5694 Mtetra
.88776 .5694 .89295 .57625 .90618 .57255 .90103 .56567 Mtetra
.985 .721 .439 r
.90103 .56567 .90618 .57255 .91947 .56883 .90125 .44801 Mtetra
.579 .389 .588 r
.90125 .44801 .91947 .56883 .91911 .45128 .91417 .44412 Mtetra
.659 .747 .915 r
.91417 .44412 .91911 .45128 .93204 .44741 .92714 .44021 Mtetra
.92714 .44021 .93204 .44741 .94503 .44352 .94016 .43629 Mtetra
.657 .75 .918 r
.34415 .63633 .35079 .64219 .36148 .63902 .35487 .63314 Mtetra
.35487 .63314 .36148 .63902 .37222 .63584 .36564 .62994 Mtetra
.36564 .62994 .37222 .63584 .38301 .63265 .37645 .62673 Mtetra
.37645 .62673 .38301 .63265 .39384 .62945 .3873 .6235 Mtetra
.3873 .6235 .39384 .62945 .40471 .62623 .3982 .62026 Mtetra
.3982 .62026 .40471 .62623 .41562 .623 .40914 .61701 Mtetra
.40914 .61701 .41562 .623 .42658 .61976 .42013 .61374 Mtetra
.42013 .61374 .42658 .61976 .43759 .61651 .43116 .61046 Mtetra
.43116 .61046 .43759 .61651 .44863 .61324 .44224 .60717 Mtetra
.44224 .60717 .44863 .61324 .45973 .60996 .45336 .60386 Mtetra
.45336 .60386 .45973 .60996 .47087 .60666 .46453 .60054 Mtetra
.46453 .60054 .47087 .60666 .48205 .60335 .47575 .59721 Mtetra
.47575 .59721 .48205 .60335 .49329 .60003 .48701 .59386 Mtetra
.48701 .59386 .49329 .60003 .50456 .59669 .49832 .5905 Mtetra
.49832 .5905 .50456 .59669 .51589 .59334 .50967 .58712 Mtetra
.50967 .58712 .51589 .59334 .52726 .58998 .52108 .58373 Mtetra
.52108 .58373 .52726 .58998 .53868 .5866 .53253 .58033 Mtetra
.53253 .58033 .53868 .5866 .55014 .58321 .54402 .57691 Mtetra
.54402 .57691 .55014 .58321 .56166 .5798 .55557 .57348 Mtetra
.55557 .57348 .56166 .5798 .57322 .57638 .56716 .57003 Mtetra
.56716 .57003 .57322 .57638 .58483 .57295 .57881 .56657 Mtetra
.57881 .56657 .58483 .57295 .59649 .5695 .5905 .56309 Mtetra
.5905 .56309 .59649 .5695 .6082 .56603 .60224 .5596 Mtetra
.60224 .5596 .6082 .56603 .61996 .56256 .61403 .5561 Mtetra
.61403 .5561 .61996 .56256 .63176 .55906 .62587 .55258 Mtetra
.62587 .55258 .63176 .55906 .64362 .55555 .63776 .54904 Mtetra
.91 .509 .124 r
.63776 .54904 .64362 .55555 .65709 .59243 .6512 .58597 Mtetra
.654 .754 .923 r
.6512 .58597 .65709 .59243 .6692 .58894 .66334 .58245 Mtetra
.66334 .58245 .6692 .58894 .68135 .58543 .67553 .57891 Mtetra
.67553 .57891 .68135 .58543 .69356 .5819 .68778 .57536 Mtetra
.68778 .57536 .69356 .5819 .70582 .57837 .70008 .57179 Mtetra
.70008 .57179 .70582 .57837 .71814 .57481 .71243 .56821 Mtetra
.71243 .56821 .71814 .57481 .73051 .57124 .72484 .56461 Mtetra
.72484 .56461 .73051 .57124 .74293 .56766 .7373 .561 Mtetra
.7373 .561 .74293 .56766 .75541 .56406 .74981 .55737 Mtetra
.74981 .55737 .75541 .56406 .76794 .56044 .76238 .55372 Mtetra
.76238 .55372 .76794 .56044 .78053 .55681 .77501 .55006 Mtetra
.869 .454 .011 r
.77501 .55006 .78053 .55681 .79317 .55316 .79096 .58837 Mtetra
.514 .239 .435 r
.79096 .58837 .79317 .55316 .80936 .59144 .80387 .58472 Mtetra
.65 .758 .928 r
.80387 .58472 .80936 .59144 .82228 .58781 .81683 .58106 Mtetra
.81683 .58106 .82228 .58781 .83526 .58416 .82985 .57738 Mtetra
.82985 .57738 .83526 .58416 .84829 .5805 .84293 .57369 Mtetra
.84293 .57369 .84829 .5805 .86139 .57682 .85606 .56997 Mtetra
.85606 .56997 .86139 .57682 .87454 .57312 .86926 .56625 Mtetra
.86926 .56625 .87454 .57312 .88776 .5694 .88252 .5625 Mtetra
.88252 .5625 .88776 .5694 .90103 .56567 .89583 .55874 Mtetra
.985 .721 .439 r
.89583 .55874 .90103 .56567 .90125 .44801 .89622 .44081 Mtetra
.659 .747 .915 r
.89622 .44081 .90125 .44801 .91417 .44412 .90918 .43689 Mtetra
.90918 .43689 .91417 .44412 .92714 .44021 .92219 .43295 Mtetra
.92219 .43295 .92714 .44021 .94016 .43629 .93526 .429 Mtetra
.657 .75 .918 r
.33746 .63044 .34415 .63633 .35487 .63314 .34821 .62722 Mtetra
.34821 .62722 .35487 .63314 .36564 .62994 .359 .624 Mtetra
.359 .624 .36564 .62994 .37645 .62673 .36984 .62076 Mtetra
.36984 .62076 .37645 .62673 .3873 .6235 .38072 .61751 Mtetra
.38072 .61751 .3873 .6235 .3982 .62026 .39165 .61425 Mtetra
.39165 .61425 .3982 .62026 .40914 .61701 .40262 .61097 Mtetra
.40262 .61097 .40914 .61701 .42013 .61374 .41363 .60768 Mtetra
.41363 .60768 .42013 .61374 .43116 .61046 .42469 .60437 Mtetra
.42469 .60437 .43116 .61046 .44224 .60717 .4358 .60105 Mtetra
.4358 .60105 .44224 .60717 .45336 .60386 .44695 .59772 Mtetra
.44695 .59772 .45336 .60386 .46453 .60054 .45815 .59437 Mtetra
.45815 .59437 .46453 .60054 .47575 .59721 .4694 .59101 Mtetra
.4694 .59101 .47575 .59721 .48701 .59386 .48069 .58764 Mtetra
.48069 .58764 .48701 .59386 .49832 .5905 .49203 .58425 Mtetra
.49203 .58425 .49832 .5905 .50967 .58712 .50341 .58085 Mtetra
.50341 .58085 .50967 .58712 .52108 .58373 .51484 .57744 Mtetra
.51484 .57744 .52108 .58373 .53253 .58033 .52632 .574 Mtetra
.52632 .574 .53253 .58033 .54402 .57691 .53785 .57056 Mtetra
.53785 .57056 .54402 .57691 .55557 .57348 .54943 .5671 Mtetra
.54943 .5671 .55557 .57348 .56716 .57003 .56106 .56363 Mtetra
.56106 .56363 .56716 .57003 .57881 .56657 .57273 .56014 Mtetra
.57273 .56014 .57881 .56657 .5905 .56309 .58446 .55664 Mtetra
.58446 .55664 .5905 .56309 .60224 .5596 .59623 .55312 Mtetra
.59623 .55312 .60224 .5596 .61403 .5561 .60806 .54958 Mtetra
.60806 .54958 .61403 .5561 .62587 .55258 .61993 .54604 Mtetra
.61993 .54604 .62587 .55258 .63776 .54904 .63185 .54247 Mtetra
.91 .509 .124 r
.63185 .54247 .63776 .54904 .6512 .58597 .64527 .57946 Mtetra
.654 .754 .923 r
.64527 .57946 .6512 .58597 .66334 .58245 .65744 .57591 Mtetra
.65744 .57591 .66334 .58245 .67553 .57891 .66967 .57234 Mtetra
.66967 .57234 .67553 .57891 .68778 .57536 .68195 .56876 Mtetra
.68195 .56876 .68778 .57536 .70008 .57179 .69429 .56517 Mtetra
.69429 .56517 .70008 .57179 .71243 .56821 .70668 .56155 Mtetra
.70668 .56155 .71243 .56821 .72484 .56461 .71912 .55793 Mtetra
.71912 .55793 .72484 .56461 .7373 .561 .73162 .55428 Mtetra
.73162 .55428 .7373 .561 .74981 .55737 .74417 .55062 Mtetra
.74417 .55062 .74981 .55737 .76238 .55372 .75678 .54695 Mtetra
.874 .461 .023 r
.75678 .54695 .76238 .55372 .77501 .55006 .7725 .58529 Mtetra
.512 .236 .433 r
.7725 .58529 .77501 .55006 .79096 .58837 .78539 .58163 Mtetra
.65 .758 .928 r
.78539 .58163 .79096 .58837 .80387 .58472 .79833 .57795 Mtetra
.79833 .57795 .80387 .58472 .81683 .58106 .81133 .57426 Mtetra
.81133 .57426 .81683 .58106 .82985 .57738 .82439 .57055 Mtetra
.82439 .57055 .82985 .57738 .84293 .57369 .83752 .56682 Mtetra
.83752 .56682 .84293 .57369 .85606 .56997 .8507 .56308 Mtetra
.8507 .56308 .85606 .56997 .86926 .56625 .86394 .55932 Mtetra
.86394 .55932 .86926 .56625 .88252 .5625 .87724 .55554 Mtetra
.984 .722 .444 r
.87724 .55554 .88252 .5625 .89583 .55874 .87821 .4375 Mtetra
.577 .386 .586 r
.87821 .4375 .89583 .55874 .89622 .44081 .89115 .43356 Mtetra
.659 .747 .915 r
.89115 .43356 .89622 .44081 .90918 .43689 .90415 .42961 Mtetra
.90415 .42961 .90918 .43689 .92219 .43295 .9172 .42564 Mtetra
.9172 .42564 .92219 .43295 .93526 .429 .93032 .42165 Mtetra
.657 .75 .918 r
.33072 .6245 .33746 .63044 .34821 .62722 .34149 .62126 Mtetra
.34149 .62126 .34821 .62722 .359 .624 .35231 .61801 Mtetra
.35231 .61801 .359 .624 .36984 .62076 .36318 .61475 Mtetra
.36318 .61475 .36984 .62076 .38072 .61751 .37409 .61147 Mtetra
.37409 .61147 .38072 .61751 .39165 .61425 .38504 .60818 Mtetra
.38504 .60818 .39165 .61425 .40262 .61097 .39604 .60488 Mtetra
.39604 .60488 .40262 .61097 .41363 .60768 .40708 .60156 Mtetra
.40708 .60156 .41363 .60768 .42469 .60437 .41817 .59823 Mtetra
.41817 .59823 .42469 .60437 .4358 .60105 .42931 .59489 Mtetra
.42931 .59489 .4358 .60105 .44695 .59772 .44049 .59153 Mtetra
.44049 .59153 .44695 .59772 .45815 .59437 .45172 .58816 Mtetra
.45172 .58816 .45815 .59437 .4694 .59101 .46299 .58478 Mtetra
.46299 .58478 .4694 .59101 .48069 .58764 .47431 .58138 Mtetra
.47431 .58138 .48069 .58764 .49203 .58425 .48568 .57796 Mtetra
.48568 .57796 .49203 .58425 .50341 .58085 .4971 .57453 Mtetra
.4971 .57453 .50341 .58085 .51484 .57744 .50856 .57109 Mtetra
.50856 .57109 .51484 .57744 .52632 .574 .52008 .56763 Mtetra
.52008 .56763 .52632 .574 .53785 .57056 .53164 .56416 Mtetra
.53164 .56416 .53785 .57056 .54943 .5671 .54325 .56068 Mtetra
.54325 .56068 .54943 .5671 .56106 .56363 .5549 .55718 Mtetra
.5549 .55718 .56106 .56363 .57273 .56014 .56661 .55366 Mtetra
.56661 .55366 .57273 .56014 .58446 .55664 .57837 .55013 Mtetra
.57837 .55013 .58446 .55664 .59623 .55312 .59018 .54658 Mtetra
.59018 .54658 .59623 .55312 .60806 .54958 .60203 .54302 Mtetra
.60203 .54302 .60806 .54958 .61993 .54604 .61394 .53945 Mtetra
.61394 .53945 .61993 .54604 .63185 .54247 .6259 .53586 Mtetra
.91 .509 .124 r
.6259 .53586 .63185 .54247 .64527 .57946 .63928 .57289 Mtetra
.654 .754 .923 r
.63928 .57289 .64527 .57946 .65744 .57591 .65149 .56931 Mtetra
.65149 .56931 .65744 .57591 .66967 .57234 .66376 .56572 Mtetra
.66376 .56572 .66967 .57234 .68195 .56876 .67608 .56211 Mtetra
.67608 .56211 .68195 .56876 .69429 .56517 .68845 .55849 Mtetra
.68845 .55849 .69429 .56517 .70668 .56155 .70088 .55485 Mtetra
.70088 .55485 .70668 .56155 .71912 .55793 .71336 .55119 Mtetra
.71336 .55119 .71912 .55793 .73162 .55428 .7259 .54752 Mtetra
.7259 .54752 .73162 .55428 .74417 .55062 .73849 .54383 Mtetra
.73849 .54383 .74417 .55062 .75678 .54695 .75113 .54012 Mtetra
.874 .461 .023 r
.75113 .54012 .75678 .54695 .7725 .58529 .76683 .57852 Mtetra
.65 .758 .928 r
.76683 .57852 .7725 .58529 .78539 .58163 .77976 .57483 Mtetra
.77976 .57483 .78539 .58163 .79833 .57795 .79275 .57112 Mtetra
.79275 .57112 .79833 .57795 .81133 .57426 .80579 .56739 Mtetra
.80579 .56739 .81133 .57426 .82439 .57055 .8189 .56365 Mtetra
.8189 .56365 .82439 .57055 .83752 .56682 .83206 .5599 Mtetra
.83206 .5599 .83752 .56682 .8507 .56308 .84528 .55612 Mtetra
.84528 .55612 .8507 .56308 .86394 .55932 .85856 .55233 Mtetra
.85856 .55233 .86394 .55932 .87724 .55554 .87191 .54852 Mtetra
.984 .722 .444 r
.87191 .54852 .87724 .55554 .87821 .4375 .87306 .43022 Mtetra
.659 .747 .915 r
.87306 .43022 .87821 .4375 .89115 .43356 .88604 .42625 Mtetra
.88604 .42625 .89115 .43356 .90415 .42961 .89908 .42226 Mtetra
.89908 .42226 .90415 .42961 .9172 .42564 .91218 .41826 Mtetra
.91218 .41826 .9172 .42564 .93032 .42165 .92533 .41424 Mtetra
0 0 .395 r
.32893 .53277 .33072 .6245 .34149 .62126 .33473 .61525 Mtetra
.657 .75 .918 r
.33473 .61525 .34149 .62126 .35231 .61801 .34558 .61198 Mtetra
.34558 .61198 .35231 .61801 .36318 .61475 .35647 .60869 Mtetra
.35647 .60869 .36318 .61475 .37409 .61147 .36741 .60539 Mtetra
.36741 .60539 .37409 .61147 .38504 .60818 .37839 .60208 Mtetra
.37839 .60208 .38504 .60818 .39604 .60488 .38941 .59875 Mtetra
.38941 .59875 .39604 .60488 .40708 .60156 .40049 .59541 Mtetra
.40049 .59541 .40708 .60156 .41817 .59823 .4116 .59205 Mtetra
.4116 .59205 .41817 .59823 .42931 .59489 .42277 .58868 Mtetra
.42277 .58868 .42931 .59489 .44049 .59153 .43398 .5853 Mtetra
.43398 .5853 .44049 .59153 .45172 .58816 .44524 .5819 Mtetra
.44524 .5819 .45172 .58816 .46299 .58478 .45654 .57849 Mtetra
.45654 .57849 .46299 .58478 .47431 .58138 .46789 .57506 Mtetra
.46789 .57506 .47431 .58138 .48568 .57796 .47929 .57162 Mtetra
.47929 .57162 .48568 .57796 .4971 .57453 .49074 .56817 Mtetra
.49074 .56817 .4971 .57453 .50856 .57109 .50223 .5647 Mtetra
.50223 .5647 .50856 .57109 .52008 .56763 .51378 .56121 Mtetra
.51378 .56121 .52008 .56763 .53164 .56416 .52537 .55772 Mtetra
.52537 .55772 .53164 .56416 .54325 .56068 .53701 .5542 Mtetra
.53701 .5542 .54325 .56068 .5549 .55718 .5487 .55067 Mtetra
.5487 .55067 .5549 .55718 .56661 .55366 .56044 .54713 Mtetra
.56044 .54713 .56661 .55366 .57837 .55013 .57223 .54357 Mtetra
.57223 .54357 .57837 .55013 .59018 .54658 .58408 .54 Mtetra
.58408 .54 .59018 .54658 .60203 .54302 .59597 .53641 Mtetra
.59597 .53641 .60203 .54302 .61394 .53945 .60791 .5328 Mtetra
.60791 .5328 .61394 .53945 .6259 .53586 .6199 .52919 Mtetra
.91 .509 .124 r
.6199 .52919 .6259 .53586 .63928 .57289 .63325 .56627 Mtetra
.654 .754 .923 r
.63325 .56627 .63928 .57289 .65149 .56931 .6455 .56267 Mtetra
.6455 .56267 .65149 .56931 .66376 .56572 .6578 .55905 Mtetra
.6578 .55905 .66376 .56572 .67608 .56211 .67016 .55541 Mtetra
.67016 .55541 .67608 .56211 .68845 .55849 .68257 .55175 Mtetra
.68257 .55175 .68845 .55849 .70088 .55485 .69503 .54808 Mtetra
.69503 .54808 .70088 .55485 .71336 .55119 .70755 .5444 Mtetra
.70755 .5444 .71336 .55119 .7259 .54752 .72012 .54069 Mtetra
.72012 .54069 .7259 .54752 .73849 .54383 .73275 .53697 Mtetra
.879 .467 .035 r
.73275 .53697 .73849 .54383 .75113 .54012 .74821 .57539 Mtetra
.508 .23 .427 r
.74821 .57539 .75113 .54012 .76683 .57852 .76112 .57169 Mtetra
.65 .758 .928 r
.76112 .57169 .76683 .57852 .77976 .57483 .77409 .56797 Mtetra
.77409 .56797 .77976 .57483 .79275 .57112 .78712 .56423 Mtetra
.78712 .56423 .79275 .57112 .80579 .56739 .8002 .56048 Mtetra
.8002 .56048 .80579 .56739 .8189 .56365 .81335 .5567 Mtetra
.81335 .5567 .8189 .56365 .83206 .5599 .82656 .55291 Mtetra
.82656 .55291 .83206 .5599 .84528 .55612 .83982 .54911 Mtetra
.83982 .54911 .84528 .55612 .85856 .55233 .85315 .54528 Mtetra
.984 .722 .449 r
.85315 .54528 .85856 .55233 .87191 .54852 .8549 .42686 Mtetra
.575 .384 .584 r
.8549 .42686 .87191 .54852 .87306 .43022 .86787 .42288 Mtetra
.659 .747 .915 r
.86787 .42288 .87306 .43022 .88604 .42625 .88089 .41888 Mtetra
.88089 .41888 .88604 .42625 .89908 .42226 .89397 .41486 Mtetra
.89397 .41486 .89908 .42226 .91218 .41826 .90711 .41082 Mtetra
.90711 .41082 .91218 .41826 .92533 .41424 .92031 .40677 Mtetra
.664 .741 .908 r
.32228 .52658 .32893 .53277 .33473 .61525 .33285 .5232 Mtetra
0 0 .395 r
.33285 .5232 .33473 .61525 .34558 .61198 .33879 .6059 Mtetra
.657 .75 .918 r
.33879 .6059 .34558 .61198 .35647 .60869 .34971 .60259 Mtetra
.34971 .60259 .35647 .60869 .36741 .60539 .36067 .59926 Mtetra
.36067 .59926 .36741 .60539 .37839 .60208 .37168 .59592 Mtetra
.37168 .59592 .37839 .60208 .38941 .59875 .38274 .59257 Mtetra
.38274 .59257 .38941 .59875 .40049 .59541 .39384 .5892 Mtetra
.39384 .5892 .40049 .59541 .4116 .59205 .40499 .58582 Mtetra
.40499 .58582 .4116 .59205 .42277 .58868 .41618 .58242 Mtetra
.41618 .58242 .42277 .58868 .43398 .5853 .42742 .57901 Mtetra
.42742 .57901 .43398 .5853 .44524 .5819 .43871 .57559 Mtetra
.43871 .57559 .44524 .5819 .45654 .57849 .45004 .57215 Mtetra
.45004 .57215 .45654 .57849 .46789 .57506 .46142 .5687 Mtetra
.46142 .5687 .46789 .57506 .47929 .57162 .47285 .56523 Mtetra
.47285 .56523 .47929 .57162 .49074 .56817 .48433 .56175 Mtetra
.48433 .56175 .49074 .56817 .50223 .5647 .49586 .55825 Mtetra
.49586 .55825 .50223 .5647 .51378 .56121 .50743 .55474 Mtetra
.50743 .55474 .51378 .56121 .52537 .55772 .51906 .55122 Mtetra
.51906 .55122 .52537 .55772 .53701 .5542 .53073 .54768 Mtetra
.53073 .54768 .53701 .5542 .5487 .55067 .54245 .54412 Mtetra
.54245 .54412 .5487 .55067 .56044 .54713 .55423 .54055 Mtetra
.55423 .54055 .56044 .54713 .57223 .54357 .56605 .53696 Mtetra
.56605 .53696 .57223 .54357 .58408 .54 .57793 .53336 Mtetra
.57793 .53336 .58408 .54 .59597 .53641 .58985 .52974 Mtetra
.58985 .52974 .59597 .53641 .60791 .5328 .60183 .52611 Mtetra
.957 .62 .316 r
.60183 .52611 .60791 .5328 .6199 .52919 .61605 .60499 Mtetra
.537 .293 .493 r
.61605 .60499 .6199 .52919 .63325 .56627 .62844 .60142 Mtetra
0 0 .17 r
.62844 .60142 .63325 .56627 .6455 .56267 .63945 .55597 Mtetra
.654 .754 .923 r
.63945 .55597 .6455 .56267 .6578 .55905 .65179 .55232 Mtetra
.65179 .55232 .6578 .55905 .67016 .55541 .66419 .54865 Mtetra
.66419 .54865 .67016 .55541 .68257 .55175 .67663 .54496 Mtetra
.67663 .54496 .68257 .55175 .69503 .54808 .68913 .54126 Mtetra
.68913 .54126 .69503 .54808 .70755 .5444 .70169 .53755 Mtetra
.70169 .53755 .70755 .5444 .72012 .54069 .71431 .53381 Mtetra
.884 .473 .047 r
.71431 .53381 .72012 .54069 .73275 .53697 .72952 .57226 Mtetra
.506 .227 .425 r
.72952 .57226 .73275 .53697 .74821 .57539 .74241 .56854 Mtetra
.65 .758 .928 r
.74241 .56854 .74821 .57539 .76112 .57169 .75536 .56481 Mtetra
.75536 .56481 .76112 .57169 .77409 .56797 .76837 .56105 Mtetra
.76837 .56105 .77409 .56797 .78712 .56423 .78144 .55728 Mtetra
.78144 .55728 .78712 .56423 .8002 .56048 .79457 .5535 Mtetra
.79457 .5535 .8002 .56048 .81335 .5567 .80776 .54969 Mtetra
.80776 .54969 .81335 .5567 .82656 .55291 .82101 .54587 Mtetra
.82101 .54587 .82656 .55291 .83982 .54911 .83432 .54203 Mtetra
.983 .722 .454 r
.83432 .54203 .83982 .54911 .85315 .54528 .83667 .42349 Mtetra
.574 .382 .583 r
.83667 .42349 .85315 .54528 .8549 .42686 .84962 .41949 Mtetra
.659 .747 .915 r
.84962 .41949 .8549 .42686 .86787 .42288 .86263 .41548 Mtetra
.86263 .41548 .86787 .42288 .88089 .41888 .87569 .41145 Mtetra
.87569 .41145 .88089 .41888 .89397 .41486 .88882 .40739 Mtetra
.88882 .40739 .89397 .41486 .90711 .41082 .902 .40332 Mtetra
.902 .40332 .90711 .41082 .92031 .40677 .91524 .39924 Mtetra
.664 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .33879 .6059 .33681 .51353 Mtetra
.577 .389 .59 r
.33681 .51353 .33879 .6059 .34971 .60259 .34749 .5101 Mtetra
0 0 .4 r
.34749 .5101 .34971 .60259 .36067 .59926 .35389 .59308 Mtetra
.657 .75 .918 r
.35389 .59308 .36067 .59926 .37168 .59592 .36493 .58972 Mtetra
.36493 .58972 .37168 .59592 .38274 .59257 .37601 .58634 Mtetra
.37601 .58634 .38274 .59257 .39384 .5892 .38714 .58295 Mtetra
.38714 .58295 .39384 .5892 .40499 .58582 .39831 .57954 Mtetra
.39831 .57954 .40499 .58582 .41618 .58242 .40954 .57612 Mtetra
.40954 .57612 .41618 .58242 .42742 .57901 .42081 .57268 Mtetra
.42081 .57268 .42742 .57901 .43871 .57559 .43212 .56923 Mtetra
.43212 .56923 .43871 .57559 .45004 .57215 .44349 .56577 Mtetra
.93 .732 .614 r
.44349 .56577 .45004 .57215 .46142 .5687 .45591 .51327 Mtetra
.588 .417 .618 r
.45591 .51327 .46142 .5687 .47285 .56523 .46721 .50972 Mtetra
.46721 .50972 .47285 .56523 .48433 .56175 .47855 .50616 Mtetra
.47855 .50616 .48433 .56175 .49586 .55825 .48995 .50259 Mtetra
.48995 .50259 .49586 .55825 .50743 .55474 .50138 .499 Mtetra
.50138 .499 .50743 .55474 .51906 .55122 .51287 .49539 Mtetra
.51287 .49539 .51906 .55122 .53073 .54768 .52441 .49177 Mtetra
.52441 .49177 .53073 .54768 .54245 .54412 .53599 .48814 Mtetra
.53599 .48814 .54245 .54412 .55423 .54055 .54762 .48448 Mtetra
.54762 .48448 .55423 .54055 .56605 .53696 .5593 .48082 Mtetra
.5593 .48082 .56605 .53696 .57793 .53336 .57103 .47714 Mtetra
.57103 .47714 .57793 .53336 .58985 .52974 .58281 .47344 Mtetra
.782 .558 0 r
.58281 .47344 .58985 .52974 .60183 .52611 .59745 .60197 Mtetra
.535 .291 .491 r
.59745 .60197 .60183 .52611 .61605 .60499 .60981 .59838 Mtetra
.65 .758 .928 r
.60981 .59838 .61605 .60499 .62844 .60142 .62223 .59478 Mtetra
.62223 .59478 .62844 .60142 .63945 .55597 .63471 .59116 Mtetra
0 0 .17 r
.63471 .59116 .63945 .55597 .65179 .55232 .64574 .54553 Mtetra
.654 .754 .923 r
.64574 .54553 .65179 .55232 .66419 .54865 .65817 .54183 Mtetra
.65817 .54183 .66419 .54865 .67663 .54496 .67065 .53812 Mtetra
.67065 .53812 .67663 .54496 .68913 .54126 .68319 .53439 Mtetra
.68319 .53439 .68913 .54126 .70169 .53755 .69579 .53064 Mtetra
.69579 .53064 .70169 .53755 .71431 .53381 .70844 .52688 Mtetra
.884 .473 .047 r
.70844 .52688 .71431 .53381 .72952 .57226 .72363 .56538 Mtetra
.65 .758 .928 r
.72363 .56538 .72952 .57226 .74241 .56854 .73656 .56163 Mtetra
.73656 .56163 .74241 .56854 .75536 .56481 .74955 .55787 Mtetra
.74955 .55787 .75536 .56481 .76837 .56105 .7626 .55408 Mtetra
.7626 .55408 .76837 .56105 .78144 .55728 .77572 .55028 Mtetra
.77572 .55028 .78144 .55728 .79457 .5535 .78889 .54646 Mtetra
.78889 .54646 .79457 .5535 .80776 .54969 .80212 .54262 Mtetra
.80212 .54262 .80776 .54969 .82101 .54587 .81541 .53877 Mtetra
.81541 .53877 .82101 .54587 .83432 .54203 .82876 .5349 Mtetra
.983 .722 .454 r
.82876 .5349 .83432 .54203 .83667 .42349 .83131 .4161 Mtetra
.659 .747 .915 r
.83131 .4161 .83667 .42349 .84962 .41949 .8443 .41207 Mtetra
.8443 .41207 .84962 .41949 .86263 .41548 .85734 .40802 Mtetra
.85734 .40802 .86263 .41548 .87569 .41145 .87045 .40395 Mtetra
.87045 .40395 .87569 .41145 .88882 .40739 .88362 .39987 Mtetra
.88362 .39987 .88882 .40739 .902 .40332 .89684 .39576 Mtetra
.89684 .39576 .902 .40332 .91524 .39924 .91013 .39164 Mtetra
.664 .741 .908 r
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.34082 .50374 .34749 .5101 .35389 .59308 .35157 .50027 Mtetra
.381 .237 .557 r
.35157 .50027 .35389 .59308 .36493 .58972 .3605 .53476 Mtetra
.587 .416 .617 r
.3605 .53476 .36493 .58972 .37601 .58634 .37146 .53131 Mtetra
.37146 .53131 .37601 .58634 .38714 .58295 .38246 .52784 Mtetra
.38246 .52784 .38714 .58295 .39831 .57954 .39351 .52435 Mtetra
.39351 .52435 .39831 .57954 .40954 .57612 .4046 .52085 Mtetra
.4046 .52085 .40954 .57612 .42081 .57268 .41574 .51734 Mtetra
.41574 .51734 .42081 .57268 .43212 .56923 .42693 .51381 Mtetra
.42693 .51381 .43212 .56923 .44349 .56577 .43816 .51027 Mtetra
.43816 .51027 .44349 .56577 .45591 .51327 .44944 .50671 Mtetra
.661 .745 .912 r
.44944 .50671 .45591 .51327 .46721 .50972 .46077 .50314 Mtetra
.46077 .50314 .46721 .50972 .47855 .50616 .47214 .49955 Mtetra
.47214 .49955 .47855 .50616 .48995 .50259 .48356 .49595 Mtetra
.48356 .49595 .48995 .50259 .50138 .499 .49503 .49233 Mtetra
.49503 .49233 .50138 .499 .51287 .49539 .50655 .4887 Mtetra
.50655 .4887 .51287 .49539 .52441 .49177 .51812 .48505 Mtetra
.51812 .48505 .52441 .49177 .53599 .48814 .52973 .48138 Mtetra
.52973 .48138 .53599 .48814 .54762 .48448 .5414 .4777 Mtetra
.5414 .4777 .54762 .48448 .5593 .48082 .55311 .47401 Mtetra
.55311 .47401 .5593 .48082 .57103 .47714 .56488 .4703 Mtetra
.56488 .4703 .57103 .47714 .58281 .47344 .57669 .46657 Mtetra
.964 .651 .377 r
.57669 .46657 .58281 .47344 .59745 .60197 .59112 .59534 Mtetra
.65 .758 .928 r
.59112 .59534 .59745 .60197 .60981 .59838 .60352 .59172 Mtetra
.60352 .59172 .60981 .59838 .62223 .59478 .61598 .58809 Mtetra
.61598 .58809 .62223 .59478 .63471 .59116 .6285 .58444 Mtetra
.6285 .58444 .63471 .59116 .64574 .54553 .64107 .58078 Mtetra
0 0 .17 r
.64107 .58078 .64574 .54553 .65817 .54183 .6521 .53496 Mtetra
.654 .754 .923 r
.6521 .53496 .65817 .54183 .67065 .53812 .66462 .53122 Mtetra
.66462 .53122 .67065 .53812 .68319 .53439 .6772 .52746 Mtetra
.6772 .52746 .68319 .53439 .69579 .53064 .68983 .52368 Mtetra
.888 .479 .058 r
.68983 .52368 .69579 .53064 .70844 .52688 .70477 .56221 Mtetra
.502 .22 .419 r
.70477 .56221 .70844 .52688 .72363 .56538 .71769 .55845 Mtetra
.65 .758 .928 r
.71769 .55845 .72363 .56538 .73656 .56163 .73066 .55466 Mtetra
.73066 .55466 .73656 .56163 .74955 .55787 .7437 .55087 Mtetra
.7437 .55087 .74955 .55787 .7626 .55408 .75679 .54705 Mtetra
.75679 .54705 .7626 .55408 .77572 .55028 .76994 .54322 Mtetra
.76994 .54322 .77572 .55028 .78889 .54646 .78315 .53936 Mtetra
.78315 .53936 .78889 .54646 .80212 .54262 .79643 .53549 Mtetra
.79643 .53549 .80212 .54262 .81541 .53877 .80977 .53161 Mtetra
.982 .722 .459 r
.80977 .53161 .81541 .53877 .82876 .5349 .81292 .41269 Mtetra
.572 .379 .581 r
.81292 .41269 .82876 .5349 .83131 .4161 .8259 .40864 Mtetra
.659 .747 .915 r
.8259 .40864 .83131 .4161 .8443 .41207 .83893 .40458 Mtetra
.83893 .40458 .8443 .41207 .85734 .40802 .85202 .4005 Mtetra
.85202 .4005 .85734 .40802 .87045 .40395 .86517 .39639 Mtetra
.86517 .39639 .87045 .40395 .88362 .39987 .87838 .39228 Mtetra
.87838 .39228 .88362 .39987 .89684 .39576 .89165 .38814 Mtetra
.89165 .38814 .89684 .39576 .91013 .39164 .90498 .38398 Mtetra
.664 .741 .908 r
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .5008 Mtetra
.32336 .5008 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49383 Mtetra
.34487 .49383 .35157 .50027 .3605 .53476 .35569 .49033 Mtetra
.045 .032 .516 r
.35569 .49033 .3605 .53476 .37146 .53131 .36473 .52489 Mtetra
.661 .745 .912 r
.36473 .52489 .37146 .53131 .38246 .52784 .37576 .52139 Mtetra
.37576 .52139 .38246 .52784 .39351 .52435 .38684 .51788 Mtetra
.38684 .51788 .39351 .52435 .4046 .52085 .39796 .51435 Mtetra
.39796 .51435 .4046 .52085 .41574 .51734 .40913 .51081 Mtetra
.40913 .51081 .41574 .51734 .42693 .51381 .42035 .50726 Mtetra
.42035 .50726 .42693 .51381 .43816 .51027 .43161 .50369 Mtetra
.43161 .50369 .43816 .51027 .44944 .50671 .44292 .5001 Mtetra
.44292 .5001 .44944 .50671 .46077 .50314 .45428 .4965 Mtetra
.45428 .4965 .46077 .50314 .47214 .49955 .46568 .49289 Mtetra
.46568 .49289 .47214 .49955 .48356 .49595 .47713 .48926 Mtetra
.47713 .48926 .48356 .49595 .49503 .49233 .48863 .48561 Mtetra
.48863 .48561 .49503 .49233 .50655 .4887 .50018 .48195 Mtetra
.50018 .48195 .50655 .4887 .51812 .48505 .51178 .47827 Mtetra
.51178 .47827 .51812 .48505 .52973 .48138 .52343 .47458 Mtetra
.52343 .47458 .52973 .48138 .5414 .4777 .53512 .47087 Mtetra
.53512 .47087 .5414 .4777 .55311 .47401 .54687 .46715 Mtetra
.54687 .46715 .55311 .47401 .56488 .4703 .55867 .46341 Mtetra
.55867 .46341 .56488 .4703 .57669 .46657 .57052 .45965 Mtetra
.964 .651 .377 r
.57052 .45965 .57669 .46657 .59112 .59534 .58474 .58865 Mtetra
.65 .758 .928 r
.58474 .58865 .59112 .59534 .60352 .59172 .59718 .58501 Mtetra
.59718 .58501 .60352 .59172 .61598 .58809 .60968 .58134 Mtetra
.60968 .58134 .61598 .58809 .6285 .58444 .62223 .57767 Mtetra
.62223 .57767 .6285 .58444 .64107 .58078 .63484 .57397 Mtetra
.63484 .57397 .64107 .58078 .6521 .53496 .6475 .57026 Mtetra
0 0 .17 r
.6475 .57026 .6521 .53496 .66462 .53122 .65854 .52426 Mtetra
.654 .754 .923 r
.65854 .52426 .66462 .53122 .6772 .52746 .67116 .52047 Mtetra
.893 .484 .07 r
.67116 .52047 .6772 .52746 .68983 .52368 .68585 .55903 Mtetra
.5 .217 .416 r
.68585 .55903 .68983 .52368 .70477 .56221 .69874 .55525 Mtetra
.65 .758 .928 r
.69874 .55525 .70477 .56221 .71769 .55845 .7117 .55145 Mtetra
.7117 .55145 .71769 .55845 .73066 .55466 .72471 .54764 Mtetra
.72471 .54764 .73066 .55466 .7437 .55087 .73779 .54381 Mtetra
.73779 .54381 .7437 .55087 .75679 .54705 .75092 .53996 Mtetra
.75092 .53996 .75679 .54705 .76994 .54322 .76412 .53609 Mtetra
.76412 .53609 .76994 .54322 .78315 .53936 .77737 .53221 Mtetra
.77737 .53221 .78315 .53936 .79643 .53549 .79069 .5283 Mtetra
.79069 .5283 .79643 .53549 .80977 .53161 .80407 .52438 Mtetra
.982 .722 .459 r
.80407 .52438 .80977 .53161 .81292 .41269 .80743 .4052 Mtetra
.659 .747 .915 r
.80743 .4052 .81292 .41269 .8259 .40864 .82044 .40112 Mtetra
.82044 .40112 .8259 .40864 .83893 .40458 .83352 .39703 Mtetra
.83352 .39703 .83893 .40458 .85202 .4005 .84665 .39291 Mtetra
.84665 .39291 .85202 .4005 .86517 .39639 .85984 .38877 Mtetra
.85984 .38877 .86517 .39639 .87838 .39228 .87309 .38462 Mtetra
.87309 .38462 .87838 .39228 .89165 .38814 .88641 .38045 Mtetra
.88641 .38045 .89165 .38814 .90498 .38398 .89978 .37626 Mtetra
.664 .741 .908 r
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49786 Mtetra
.30585 .49786 .31267 .50427 .32336 .5008 .31656 .49437 Mtetra
.31656 .49437 .32336 .5008 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49383 .33812 .48735 Mtetra
.33812 .48735 .34487 .49383 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36473 .52489 .35986 .48027 Mtetra
.045 .032 .516 r
.35986 .48027 .36473 .52489 .37576 .52139 .36902 .5149 Mtetra
.661 .745 .912 r
.36902 .5149 .37576 .52139 .38684 .51788 .38012 .51136 Mtetra
.38012 .51136 .38684 .51788 .39796 .51435 .39127 .50781 Mtetra
.39127 .50781 .39796 .51435 .40913 .51081 .40247 .50424 Mtetra
.40247 .50424 .40913 .51081 .42035 .50726 .41371 .50065 Mtetra
.41371 .50065 .42035 .50726 .43161 .50369 .42501 .49706 Mtetra
.42501 .49706 .43161 .50369 .44292 .5001 .43635 .49344 Mtetra
.43635 .49344 .44292 .5001 .45428 .4965 .44773 .48981 Mtetra
.44773 .48981 .45428 .4965 .46568 .49289 .45917 .48617 Mtetra
.45917 .48617 .46568 .49289 .47713 .48926 .47065 .48251 Mtetra
.47065 .48251 .47713 .48926 .48863 .48561 .48218 .47884 Mtetra
.48218 .47884 .48863 .48561 .50018 .48195 .49376 .47515 Mtetra
.49376 .47515 .50018 .48195 .51178 .47827 .50539 .47144 Mtetra
.50539 .47144 .51178 .47827 .52343 .47458 .51707 .46772 Mtetra
.51707 .46772 .52343 .47458 .53512 .47087 .5288 .46398 Mtetra
.5288 .46398 .53512 .47087 .54687 .46715 .54058 .46023 Mtetra
.54058 .46023 .54687 .46715 .55867 .46341 .55241 .45646 Mtetra
.55241 .45646 .55867 .46341 .57052 .45965 .56429 .45267 Mtetra
.964 .651 .377 r
.56429 .45267 .57052 .45965 .58474 .58865 .57831 .58191 Mtetra
.65 .758 .928 r
.57831 .58191 .58474 .58865 .59718 .58501 .59079 .57823 Mtetra
.59079 .57823 .59718 .58501 .60968 .58134 .60332 .57454 Mtetra
.60332 .57454 .60968 .58134 .62223 .57767 .61591 .57083 Mtetra
.61591 .57083 .62223 .57767 .63484 .57397 .62856 .56711 Mtetra
.62856 .56711 .63484 .57397 .6475 .57026 .64126 .56337 Mtetra
.64126 .56337 .6475 .57026 .65854 .52426 .65403 .55961 Mtetra
.753 .441 .457 r
.65403 .55961 .65854 .52426 .67116 .52047 .66867 .59933 Mtetra
.285 .093 .435 r
.66867 .59933 .67116 .52047 .68585 .55903 .67972 .55204 Mtetra
.65 .758 .928 r
.67972 .55204 .68585 .55903 .69874 .55525 .69266 .54823 Mtetra
.69266 .54823 .69874 .55525 .7117 .55145 .70566 .5444 Mtetra
.70566 .5444 .7117 .55145 .72471 .54764 .71871 .54055 Mtetra
.71871 .54055 .72471 .54764 .73779 .54381 .73183 .53669 Mtetra
.73183 .53669 .73779 .54381 .75092 .53996 .74501 .53281 Mtetra
.74501 .53281 .75092 .53996 .76412 .53609 .75825 .52891 Mtetra
.75825 .52891 .76412 .53609 .77737 .53221 .77155 .52499 Mtetra
.77155 .52499 .77737 .53221 .79069 .5283 .78491 .52105 Mtetra
.981 .722 .464 r
.78491 .52105 .79069 .5283 .80407 .52438 .78889 .40175 Mtetra
.57 .376 .579 r
.78889 .40175 .80407 .52438 .80743 .4052 .80188 .39766 Mtetra
.659 .747 .915 r
.80188 .39766 .80743 .4052 .82044 .40112 .81494 .39354 Mtetra
.81494 .39354 .82044 .40112 .83352 .39703 .82806 .38941 Mtetra
.82806 .38941 .83352 .39703 .84665 .39291 .84123 .38526 Mtetra
.84123 .38526 .84665 .39291 .85984 .38877 .85447 .38109 Mtetra
.85447 .38109 .85984 .38877 .87309 .38462 .86777 .3769 Mtetra
.86777 .3769 .87309 .38462 .88641 .38045 .88112 .37269 Mtetra
.88112 .37269 .88641 .38045 .89978 .37626 .89454 .36847 Mtetra
.664 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .36902 .5149 .36408 .47009 Mtetra
.045 .032 .516 r
.36408 .47009 .36902 .5149 .38012 .51136 .37335 .50479 Mtetra
.661 .745 .912 r
.37335 .50479 .38012 .51136 .39127 .50781 .38453 .50121 Mtetra
.38453 .50121 .39127 .50781 .40247 .50424 .39576 .49761 Mtetra
.39576 .49761 .40247 .50424 .41371 .50065 .40703 .494 Mtetra
.40703 .494 .41371 .50065 .42501 .49706 .41835 .49037 Mtetra
.41835 .49037 .42501 .49706 .43635 .49344 .42972 .48673 Mtetra
.42972 .48673 .43635 .49344 .44773 .48981 .44114 .48308 Mtetra
.44114 .48308 .44773 .48981 .45917 .48617 .4526 .4794 Mtetra
.4526 .4794 .45917 .48617 .47065 .48251 .46412 .47572 Mtetra
.46412 .47572 .47065 .48251 .48218 .47884 .47568 .47201 Mtetra
.47568 .47201 .48218 .47884 .49376 .47515 .48729 .46829 Mtetra
.48729 .46829 .49376 .47515 .50539 .47144 .49896 .46456 Mtetra
.49896 .46456 .50539 .47144 .51707 .46772 .51067 .46081 Mtetra
.51067 .46081 .51707 .46772 .5288 .46398 .52243 .45704 Mtetra
.52243 .45704 .5288 .46398 .54058 .46023 .53424 .45326 Mtetra
.53424 .45326 .54058 .46023 .55241 .45646 .54611 .44946 Mtetra
.54611 .44946 .55241 .45646 .56429 .45267 .55802 .44564 Mtetra
.964 .651 .377 r
.55802 .44564 .56429 .45267 .57831 .58191 .57183 .57511 Mtetra
.65 .758 .928 r
.57183 .57511 .57831 .58191 .59079 .57823 .58434 .5714 Mtetra
.58434 .5714 .59079 .57823 .60332 .57454 .59691 .56768 Mtetra
.59691 .56768 .60332 .57454 .61591 .57083 .60954 .56394 Mtetra
.60954 .56394 .61591 .57083 .62856 .56711 .62223 .56019 Mtetra
.62223 .56019 .62856 .56711 .64126 .56337 .63497 .55641 Mtetra
.904 .5 .103 r
.63497 .55641 .64126 .56337 .65403 .55961 .64936 .59616 Mtetra
.498 .214 .413 r
.64936 .59616 .65403 .55961 .66867 .59933 .66239 .59241 Mtetra
.646 .762 .934 r
.66239 .59241 .66867 .59933 .67972 .55204 .67548 .58863 Mtetra
0 0 .184 r
.67548 .58863 .67972 .55204 .69266 .54823 .68653 .54114 Mtetra
.65 .758 .928 r
.68653 .54114 .69266 .54823 .70566 .5444 .69957 .53728 Mtetra
.69957 .53728 .70566 .5444 .71871 .54055 .71266 .5334 Mtetra
.71266 .5334 .71871 .54055 .73183 .53669 .72582 .52951 Mtetra
.72582 .52951 .73183 .53669 .74501 .53281 .73904 .52559 Mtetra
.73904 .52559 .74501 .53281 .75825 .52891 .75232 .52166 Mtetra
.75232 .52166 .75825 .52891 .77155 .52499 .76567 .51771 Mtetra
.76567 .51771 .77155 .52499 .78491 .52105 .77907 .51374 Mtetra
.981 .722 .464 r
.77907 .51374 .78491 .52105 .78889 .40175 .78326 .39418 Mtetra
.659 .747 .915 r
.78326 .39418 .78889 .40175 .80188 .39766 .7963 .39005 Mtetra
.7963 .39005 .80188 .39766 .81494 .39354 .8094 .3859 Mtetra
.8094 .3859 .81494 .39354 .82806 .38941 .82255 .38173 Mtetra
.82255 .38173 .82806 .38941 .84123 .38526 .83577 .37755 Mtetra
.83577 .37755 .84123 .38526 .85447 .38109 .84905 .37334 Mtetra
.84905 .37334 .85447 .38109 .86777 .3769 .86239 .36912 Mtetra
.86239 .36912 .86777 .3769 .88112 .37269 .87579 .36487 Mtetra
.87579 .36487 .88112 .37269 .89454 .36847 .88926 .36061 Mtetra
.664 .741 .908 r
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.34633 .46705 .35312 .47368 .36408 .47009 .35732 .46343 Mtetra
.35732 .46343 .36408 .47009 .37335 .50479 .36835 .4598 Mtetra
.045 .032 .516 r
.36835 .4598 .37335 .50479 .38453 .50121 .37773 .49456 Mtetra
.661 .745 .912 r
.37773 .49456 .38453 .50121 .39576 .49761 .38899 .49093 Mtetra
.38899 .49093 .39576 .49761 .40703 .494 .40029 .48729 Mtetra
.40029 .48729 .40703 .494 .41835 .49037 .41165 .48364 Mtetra
.41165 .48364 .41835 .49037 .42972 .48673 .42304 .47997 Mtetra
.42304 .47997 .42972 .48673 .44114 .48308 .43449 .47628 Mtetra
.43449 .47628 .44114 .48308 .4526 .4794 .44599 .47258 Mtetra
.44599 .47258 .4526 .4794 .46412 .47572 .45753 .46887 Mtetra
.45753 .46887 .46412 .47572 .47568 .47201 .46913 .46513 Mtetra
.46913 .46513 .47568 .47201 .48729 .46829 .48077 .46139 Mtetra
.48077 .46139 .48729 .46829 .49896 .46456 .49247 .45762 Mtetra
.49247 .45762 .49896 .46456 .51067 .46081 .50421 .45384 Mtetra
.50421 .45384 .51067 .46081 .52243 .45704 .51601 .45004 Mtetra
.51601 .45004 .52243 .45704 .53424 .45326 .52785 .44623 Mtetra
.52785 .44623 .53424 .45326 .54611 .44946 .53975 .4424 Mtetra
.53975 .4424 .54611 .44946 .55802 .44564 .5517 .43855 Mtetra
.964 .651 .377 r
.5517 .43855 .55802 .44564 .57183 .57511 .56529 .56826 Mtetra
.65 .758 .928 r
.56529 .56826 .57183 .57511 .58434 .5714 .57784 .56452 Mtetra
.57784 .56452 .58434 .5714 .59691 .56768 .59045 .56076 Mtetra
.59045 .56076 .59691 .56768 .60954 .56394 .60312 .55699 Mtetra
.60312 .55699 .60954 .56394 .62223 .56019 .61584 .55321 Mtetra
.907 .504 .113 r
.61584 .55321 .62223 .56019 .63497 .55641 .62997 .59299 Mtetra
.495 .21 .41 r
.62997 .59299 .63497 .55641 .64936 .59616 .64298 .58922 Mtetra
.646 .762 .934 r
.64298 .58922 .64936 .59616 .66239 .59241 .65605 .58543 Mtetra
.65605 .58543 .66239 .59241 .67548 .58863 .66918 .58162 Mtetra
.66918 .58162 .67548 .58863 .68653 .54114 .68237 .5778 Mtetra
0 0 .184 r
.68237 .5778 .68653 .54114 .69957 .53728 .69342 .53011 Mtetra
.65 .758 .928 r
.69342 .53011 .69957 .53728 .71266 .5334 .70656 .5262 Mtetra
.70656 .5262 .71266 .5334 .72582 .52951 .71976 .52227 Mtetra
.71976 .52227 .72582 .52951 .73904 .52559 .73302 .51832 Mtetra
.73302 .51832 .73904 .52559 .75232 .52166 .74635 .51435 Mtetra
.74635 .51435 .75232 .52166 .76567 .51771 .75974 .51036 Mtetra
.98 .723 .468 r
.75974 .51036 .76567 .51771 .77907 .51374 .76456 .39069 Mtetra
.568 .373 .577 r
.76456 .39069 .77907 .51374 .78326 .39418 .77758 .38654 Mtetra
.659 .747 .915 r
.77758 .38654 .78326 .39418 .7963 .39005 .79066 .38238 Mtetra
.79066 .38238 .7963 .39005 .8094 .3859 .8038 .37819 Mtetra
.8038 .37819 .8094 .3859 .82255 .38173 .817 .37399 Mtetra
.817 .37399 .82255 .38173 .83577 .37755 .83027 .36977 Mtetra
.83027 .36977 .83577 .37755 .84905 .37334 .84359 .36553 Mtetra
.84359 .36553 .84905 .37334 .86239 .36912 .85697 .36127 Mtetra
.85697 .36127 .86239 .36912 .87579 .36487 .87042 .35699 Mtetra
.87042 .35699 .87579 .36487 .88926 .36061 .88393 .35269 Mtetra
.664 .741 .908 r
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.3285 .46399 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45671 Mtetra
.3505 .45671 .35732 .46343 .36835 .4598 .36156 .45306 Mtetra
.36156 .45306 .36835 .4598 .37773 .49456 .37268 .44938 Mtetra
.045 .032 .516 r
.37268 .44938 .37773 .49456 .38899 .49093 .38217 .4842 Mtetra
.661 .745 .912 r
.38217 .4842 .38899 .49093 .40029 .48729 .3935 .48054 Mtetra
.3935 .48054 .40029 .48729 .41165 .48364 .40489 .47685 Mtetra
.40489 .47685 .41165 .48364 .42304 .47997 .41632 .47315 Mtetra
.41632 .47315 .42304 .47997 .43449 .47628 .42779 .46944 Mtetra
.42779 .46944 .43449 .47628 .44599 .47258 .43932 .46571 Mtetra
.43932 .46571 .44599 .47258 .45753 .46887 .4509 .46196 Mtetra
.4509 .46196 .45753 .46887 .46913 .46513 .46253 .4582 Mtetra
.46253 .4582 .46913 .46513 .48077 .46139 .4742 .45442 Mtetra
.4742 .45442 .48077 .46139 .49247 .45762 .48593 .45063 Mtetra
.48593 .45063 .49247 .45762 .50421 .45384 .49771 .44682 Mtetra
.49771 .44682 .50421 .45384 .51601 .45004 .50953 .44299 Mtetra
.50953 .44299 .51601 .45004 .52785 .44623 .52141 .43915 Mtetra
.52141 .43915 .52785 .44623 .53975 .4424 .53334 .43528 Mtetra
.53334 .43528 .53975 .4424 .5517 .43855 .54533 .43141 Mtetra
.964 .651 .377 r
.54533 .43141 .5517 .43855 .56529 .56826 .5587 .56134 Mtetra
.65 .758 .928 r
.5587 .56134 .56529 .56826 .57784 .56452 .57129 .55757 Mtetra
.57129 .55757 .57784 .56452 .59045 .56076 .58393 .55379 Mtetra
.58393 .55379 .59045 .56076 .60312 .55699 .59664 .54999 Mtetra
.91 .509 .124 r
.59664 .54999 .60312 .55699 .61584 .55321 .6105 .5898 Mtetra
.493 .207 .407 r
.6105 .5898 .61584 .55321 .62997 .59299 .62349 .58601 Mtetra
.646 .762 .934 r
.62349 .58601 .62997 .59299 .64298 .58922 .63654 .58221 Mtetra
.63654 .58221 .64298 .58922 .65605 .58543 .64965 .57839 Mtetra
.64965 .57839 .65605 .58543 .66918 .58162 .66282 .57455 Mtetra
.66282 .57455 .66918 .58162 .68237 .5778 .67606 .57069 Mtetra
.67606 .57069 .68237 .5778 .69342 .53011 .68936 .56681 Mtetra
0 0 .184 r
.68936 .56681 .69342 .53011 .70656 .5262 .70041 .51893 Mtetra
.65 .758 .928 r
.70041 .51893 .70656 .5262 .71976 .52227 .71365 .51496 Mtetra
.71365 .51496 .71976 .52227 .73302 .51832 .72696 .51098 Mtetra
.963 .767 .592 r
.72696 .51098 .73302 .51832 .74635 .51435 .73754 .46397 Mtetra
.586 .423 .627 r
.73754 .46397 .74635 .51435 .75974 .51036 .75079 .4599 Mtetra
.833 .588 .569 r
.75079 .4599 .75974 .51036 .76456 .39069 .75879 .38302 Mtetra
.659 .747 .915 r
.75879 .38302 .76456 .39069 .77758 .38654 .77185 .37884 Mtetra
.77185 .37884 .77758 .38654 .79066 .38238 .78498 .37464 Mtetra
.78498 .37464 .79066 .38238 .8038 .37819 .79816 .37042 Mtetra
.79816 .37042 .8038 .37819 .817 .37399 .81141 .36618 Mtetra
.81141 .36618 .817 .37399 .83027 .36977 .82471 .36192 Mtetra
.82471 .36192 .83027 .36977 .84359 .36553 .83808 .35765 Mtetra
.83808 .35765 .84359 .36553 .85697 .36127 .85151 .35335 Mtetra
.85151 .35335 .85697 .36127 .87042 .35699 .865 .34903 Mtetra
.865 .34903 .87042 .35699 .88393 .35269 .87855 .3447 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.33258 .45362 .33948 .46036 .3505 .45671 .34363 .44995 Mtetra
.34363 .44995 .3505 .45671 .36156 .45306 .35472 .44626 Mtetra
.35472 .44626 .36156 .45306 .37268 .44938 .36586 .44256 Mtetra
.36586 .44256 .37268 .44938 .38217 .4842 .37705 .43884 Mtetra
.045 .032 .516 r
.37705 .43884 .38217 .4842 .3935 .48054 .38666 .47372 Mtetra
.661 .745 .912 r
.38666 .47372 .3935 .48054 .40489 .47685 .39807 .47001 Mtetra
.39807 .47001 .40489 .47685 .41632 .47315 .40953 .46628 Mtetra
.40953 .46628 .41632 .47315 .42779 .46944 .42104 .46254 Mtetra
.42104 .46254 .42779 .46944 .43932 .46571 .4326 .45878 Mtetra
.4326 .45878 .43932 .46571 .4509 .46196 .44421 .455 Mtetra
.44421 .455 .4509 .46196 .46253 .4582 .45587 .45121 Mtetra
.45587 .45121 .46253 .4582 .4742 .45442 .46758 .4474 Mtetra
.46758 .4474 .4742 .45442 .48593 .45063 .47934 .44358 Mtetra
.47934 .44358 .48593 .45063 .49771 .44682 .49115 .43974 Mtetra
.49115 .43974 .49771 .44682 .50953 .44299 .50301 .43588 Mtetra
.50301 .43588 .50953 .44299 .52141 .43915 .51492 .432 Mtetra
.51492 .432 .52141 .43915 .53334 .43528 .52688 .42811 Mtetra
.52688 .42811 .53334 .43528 .54533 .43141 .5389 .4242 Mtetra
.964 .651 .377 r
.5389 .4242 .54533 .43141 .5587 .56134 .55205 .55437 Mtetra
.65 .758 .928 r
.55205 .55437 .5587 .56134 .57129 .55757 .56468 .55057 Mtetra
.56468 .55057 .57129 .55757 .58393 .55379 .57736 .54675 Mtetra
.913 .513 .134 r
.57736 .54675 .58393 .55379 .59664 .54999 .59095 .58659 Mtetra
.491 .203 .404 r
.59095 .58659 .59664 .54999 .6105 .5898 .60392 .58279 Mtetra
.646 .762 .934 r
.60392 .58279 .6105 .5898 .62349 .58601 .61695 .57897 Mtetra
.61695 .57897 .62349 .58601 .63654 .58221 .63005 .57514 Mtetra
.63005 .57514 .63654 .58221 .64965 .57839 .6432 .57128 Mtetra
.6432 .57128 .64965 .57839 .66282 .57455 .65642 .56741 Mtetra
.65642 .56741 .66282 .57455 .67606 .57069 .66969 .56352 Mtetra
.66969 .56352 .67606 .57069 .68936 .56681 .68303 .55961 Mtetra
.68303 .55961 .68936 .56681 .70041 .51893 .69644 .55568 Mtetra
.759 .666 .112 r
.69644 .55568 .70041 .51893 .71365 .51496 .70513 .46459 Mtetra
.586 .422 .627 r
.70513 .46459 .71365 .51496 .72696 .51098 .7183 .46053 Mtetra
.7183 .46053 .72696 .51098 .73754 .46397 .73153 .45645 Mtetra
.654 .754 .923 r
.73153 .45645 .73754 .46397 .75079 .4599 .74482 .45234 Mtetra
.74482 .45234 .75079 .4599 .75879 .38302 .75818 .44822 Mtetra
0 0 .317 r
.75818 .44822 .75879 .38302 .77185 .37884 .76608 .37107 Mtetra
.659 .747 .915 r
.76608 .37107 .77185 .37884 .78498 .37464 .77925 .36684 Mtetra
.77925 .36684 .78498 .37464 .79816 .37042 .79247 .36258 Mtetra
.79247 .36258 .79816 .37042 .81141 .36618 .80576 .35831 Mtetra
.80576 .35831 .81141 .36618 .82471 .36192 .81911 .35401 Mtetra
.81911 .35401 .82471 .36192 .83808 .35765 .83252 .3497 Mtetra
.83252 .3497 .83808 .35765 .85151 .35335 .84599 .34537 Mtetra
.84599 .34537 .85151 .35335 .865 .34903 .85953 .34101 Mtetra
.85953 .34101 .865 .34903 .87855 .3447 .87313 .33664 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
.3146 .45051 .32158 .45728 .33258 .45362 .32563 .44683 Mtetra
.32563 .44683 .33258 .45362 .34363 .44995 .3367 .44313 Mtetra
.3367 .44313 .34363 .44995 .35472 .44626 .34783 .43941 Mtetra
.34783 .43941 .35472 .44626 .36586 .44256 .35899 .43568 Mtetra
.35899 .43568 .36586 .44256 .37705 .43884 .37021 .43193 Mtetra
.37021 .43193 .37705 .43884 .38666 .47372 .38147 .42817 Mtetra
.045 .032 .516 r
.38147 .42817 .38666 .47372 .39807 .47001 .39121 .46312 Mtetra
.661 .745 .912 r
.39121 .46312 .39807 .47001 .40953 .46628 .4027 .45936 Mtetra
.4027 .45936 .40953 .46628 .42104 .46254 .41424 .45559 Mtetra
.41424 .45559 .42104 .46254 .4326 .45878 .42583 .4518 Mtetra
.42583 .4518 .4326 .45878 .44421 .455 .43747 .44799 Mtetra
.43747 .44799 .44421 .455 .45587 .45121 .44916 .44417 Mtetra
.44916 .44417 .45587 .45121 .46758 .4474 .4609 .44033 Mtetra
.4609 .44033 .46758 .4474 .47934 .44358 .47269 .43647 Mtetra
.47269 .43647 .47934 .44358 .49115 .43974 .48453 .4326 Mtetra
.48453 .4326 .49115 .43974 .50301 .43588 .49643 .42871 Mtetra
.49643 .42871 .50301 .43588 .51492 .432 .50838 .42481 Mtetra
.50838 .42481 .51492 .432 .52688 .42811 .52037 .42088 Mtetra
.52037 .42088 .52688 .42811 .5389 .4242 .53243 .41694 Mtetra
.964 .651 .377 r
.53243 .41694 .5389 .4242 .55205 .55437 .54535 .54734 Mtetra
.65 .758 .928 r
.54535 .54734 .55205 .55437 .56468 .55057 .55801 .54351 Mtetra
.915 .518 .144 r
.55801 .54351 .56468 .55057 .57736 .54675 .57133 .58338 Mtetra
.488 .199 .401 r
.57133 .58338 .57736 .54675 .59095 .58659 .58428 .57956 Mtetra
.646 .762 .934 r
.58428 .57956 .59095 .58659 .60392 .58279 .59729 .57573 Mtetra
.59729 .57573 .60392 .58279 .61695 .57897 .61036 .57188 Mtetra
.61036 .57188 .61695 .57897 .63005 .57514 .6235 .56801 Mtetra
.6235 .56801 .63005 .57514 .6432 .57128 .63669 .56412 Mtetra
.63669 .56412 .6432 .57128 .65642 .56741 .64995 .56021 Mtetra
.64995 .56021 .65642 .56741 .66969 .56352 .66327 .55629 Mtetra
.66327 .55629 .66969 .56352 .68303 .55961 .67666 .55234 Mtetra
.67666 .55234 .68303 .55961 .69644 .55568 .6901 .54838 Mtetra
.974 .734 .511 r
.6901 .54838 .69644 .55568 .70513 .46459 .69898 .45708 Mtetra
.654 .754 .923 r
.69898 .45708 .70513 .46459 .7183 .46053 .71219 .45298 Mtetra
.71219 .45298 .7183 .46053 .73153 .45645 .72547 .44886 Mtetra
.72547 .44886 .73153 .45645 .74482 .45234 .7388 .44472 Mtetra
.7388 .44472 .74482 .45234 .75818 .44822 .7522 .44056 Mtetra
.978 .742 .511 r
.7522 .44056 .75818 .44822 .76608 .37107 .76026 .36324 Mtetra
.659 .747 .915 r
.76026 .36324 .76608 .37107 .77925 .36684 .77347 .35897 Mtetra
.77347 .35897 .77925 .36684 .79247 .36258 .78674 .35467 Mtetra
.78674 .35467 .79247 .36258 .80576 .35831 .80007 .35036 Mtetra
.80007 .35036 .80576 .35831 .81911 .35401 .81346 .34603 Mtetra
.81346 .34603 .81911 .35401 .83252 .3497 .82692 .34168 Mtetra
.82692 .34168 .83252 .3497 .84599 .34537 .84043 .33731 Mtetra
.84043 .33731 .84599 .34537 .85953 .34101 .85402 .33292 Mtetra
.85402 .33292 .85953 .34101 .87313 .33664 .86766 .32851 Mtetra
.664 .741 .908 r
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.28559 .45108 .29268 .45784 .30361 .45418 .29655 .4474 Mtetra
.29655 .4474 .30361 .45418 .3146 .45051 .30756 .4437 Mtetra
.30756 .4437 .3146 .45051 .32563 .44683 .31862 .43998 Mtetra
.31862 .43998 .32563 .44683 .3367 .44313 .32973 .43626 Mtetra
.32973 .43626 .3367 .44313 .34783 .43941 .34088 .43251 Mtetra
.34088 .43251 .34783 .43941 .35899 .43568 .35207 .42875 Mtetra
.35207 .42875 .35899 .43568 .37021 .43193 .36332 .42497 Mtetra
.36332 .42497 .37021 .43193 .38147 .42817 .37461 .42118 Mtetra
.37461 .42118 .38147 .42817 .39121 .46312 .38595 .41737 Mtetra
.045 .032 .516 r
.38595 .41737 .39121 .46312 .4027 .45936 .39581 .45238 Mtetra
.661 .745 .912 r
.39581 .45238 .4027 .45936 .41424 .45559 .40738 .44858 Mtetra
.40738 .44858 .41424 .45559 .42583 .4518 .419 .44476 Mtetra
.419 .44476 .42583 .4518 .43747 .44799 .43067 .44092 Mtetra
.43067 .44092 .43747 .44799 .44916 .44417 .4424 .43707 Mtetra
.4424 .43707 .44916 .44417 .4609 .44033 .45417 .4332 Mtetra
.45417 .4332 .4609 .44033 .47269 .43647 .46599 .42931 Mtetra
.46599 .42931 .47269 .43647 .48453 .4326 .47787 .42541 Mtetra
.47787 .42541 .48453 .4326 .49643 .42871 .4898 .42149 Mtetra
.4898 .42149 .49643 .42871 .50838 .42481 .50178 .41755 Mtetra
.50178 .41755 .50838 .42481 .52037 .42088 .51381 .4136 Mtetra
.51381 .4136 .52037 .42088 .53243 .41694 .5259 .40962 Mtetra
.964 .651 .377 r
.5259 .40962 .53243 .41694 .54535 .54734 .53858 .54025 Mtetra
.918 .522 .153 r
.53858 .54025 .54535 .54734 .55801 .54351 .55163 .58015 Mtetra
.486 .196 .398 r
.55163 .58015 .55801 .54351 .57133 .58338 .56456 .57632 Mtetra
.646 .762 .934 r
.56456 .57632 .57133 .58338 .58428 .57956 .57755 .57247 Mtetra
.57755 .57247 .58428 .57956 .59729 .57573 .5906 .5686 Mtetra
.5906 .5686 .59729 .57573 .61036 .57188 .60372 .56472 Mtetra
.60372 .56472 .61036 .57188 .6235 .56801 .61689 .56081 Mtetra
.61689 .56081 .6235 .56801 .63669 .56412 .63013 .55689 Mtetra
.63013 .55689 .63669 .56412 .64995 .56021 .64343 .55295 Mtetra
.64343 .55295 .64995 .56021 .66327 .55629 .65679 .54899 Mtetra
.65679 .54899 .66327 .55629 .67666 .55234 .67022 .54501 Mtetra
.973 .734 .515 r
.67022 .54501 .67666 .55234 .6901 .54838 .67959 .45361 Mtetra
.568 .379 .585 r
.67959 .45361 .6901 .54838 .69898 .45708 .69278 .44949 Mtetra
.654 .754 .923 r
.69278 .44949 .69898 .45708 .71219 .45298 .70603 .44536 Mtetra
.70603 .44536 .71219 .45298 .72547 .44886 .71935 .4412 Mtetra
.71935 .4412 .72547 .44886 .7388 .44472 .73273 .43703 Mtetra
.73273 .43703 .7388 .44472 .7522 .44056 .74617 .43283 Mtetra
.74617 .43283 .7522 .44056 .76026 .36324 .75968 .42862 Mtetra
0 0 .312 r
.75968 .42862 .76026 .36324 .77347 .35897 .76764 .35103 Mtetra
.659 .747 .915 r
.76764 .35103 .77347 .35897 .78674 .35467 .78095 .3467 Mtetra
.78095 .3467 .78674 .35467 .80007 .35036 .79433 .34235 Mtetra
.79433 .34235 .80007 .35036 .81346 .34603 .80776 .33799 Mtetra
.80776 .33799 .81346 .34603 .82692 .34168 .82126 .3336 Mtetra
.82126 .3336 .82692 .34168 .84043 .33731 .83483 .32919 Mtetra
.83483 .32919 .84043 .33731 .85402 .33292 .84845 .32476 Mtetra
.84845 .32476 .85402 .33292 .86766 .32851 .86214 .32031 Mtetra
.664 .741 .908 r
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .4437 .30048 .43683 Mtetra
.30048 .43683 .30756 .4437 .31862 .43998 .31156 .43309 Mtetra
.31156 .43309 .31862 .43998 .32973 .43626 .32269 .42933 Mtetra
.32269 .42933 .32973 .43626 .34088 .43251 .33387 .42556 Mtetra
.33387 .42556 .34088 .43251 .35207 .42875 .3451 .42177 Mtetra
.3451 .42177 .35207 .42875 .36332 .42497 .35637 .41796 Mtetra
.35637 .41796 .36332 .42497 .37461 .42118 .3677 .41414 Mtetra
.3677 .41414 .37461 .42118 .38595 .41737 .37907 .4103 Mtetra
.37907 .4103 .38595 .41737 .39581 .45238 .39048 .40644 Mtetra
.045 .032 .516 r
.39048 .40644 .39581 .45238 .40738 .44858 .40047 .44151 Mtetra
.661 .745 .912 r
.40047 .44151 .40738 .44858 .419 .44476 .41212 .43766 Mtetra
.41212 .43766 .419 .44476 .43067 .44092 .42382 .4338 Mtetra
.42382 .4338 .43067 .44092 .4424 .43707 .43558 .42991 Mtetra
.43558 .42991 .4424 .43707 .45417 .4332 .44738 .42601 Mtetra
.44738 .42601 .45417 .4332 .46599 .42931 .45924 .42209 Mtetra
.45924 .42209 .46599 .42931 .47787 .42541 .47115 .41816 Mtetra
.47115 .41816 .47787 .42541 .4898 .42149 .48311 .4142 Mtetra
.48311 .4142 .4898 .42149 .50178 .41755 .49513 .41023 Mtetra
.49513 .41023 .50178 .41755 .51381 .4136 .50719 .40625 Mtetra
.50719 .40625 .51381 .4136 .5259 .40962 .51931 .40224 Mtetra
.964 .651 .377 r
.51931 .40224 .5259 .40962 .53858 .54025 .53176 .5331 Mtetra
.918 .522 .153 r
.53176 .5331 .53858 .54025 .55163 .58015 .54476 .57306 Mtetra
.646 .762 .934 r
.54476 .57306 .55163 .58015 .56456 .57632 .55773 .5692 Mtetra
.55773 .5692 .56456 .57632 .57755 .57247 .57076 .56532 Mtetra
.57076 .56532 .57755 .57247 .5906 .5686 .58386 .56142 Mtetra
.58386 .56142 .5906 .5686 .60372 .56472 .59701 .5575 Mtetra
.59701 .5575 .60372 .56472 .61689 .56081 .61023 .55356 Mtetra
.61023 .55356 .61689 .56081 .63013 .55689 .62351 .5496 Mtetra
.62351 .5496 .63013 .55689 .64343 .55295 .63685 .54563 Mtetra
.63685 .54563 .64343 .55295 .65679 .54899 .65026 .54163 Mtetra
.65026 .54163 .65679 .54899 .67022 .54501 .66373 .53762 Mtetra
.973 .734 .515 r
.66373 .53762 .67022 .54501 .67959 .45361 .67329 .44599 Mtetra
.654 .754 .923 r
.67329 .44599 .67959 .45361 .69278 .44949 .68652 .44184 Mtetra
.68652 .44184 .69278 .44949 .70603 .44536 .69982 .43767 Mtetra
.69982 .43767 .70603 .44536 .71935 .4412 .71318 .43348 Mtetra
.71318 .43348 .71935 .4412 .73273 .43703 .72661 .42927 Mtetra
.72661 .42927 .73273 .43703 .74617 .43283 .74009 .42504 Mtetra
.74009 .42504 .74617 .43283 .75968 .42862 .75364 .42079 Mtetra
.979 .742 .508 r
.75364 .42079 .75968 .42862 .76764 .35103 .76176 .34302 Mtetra
.659 .747 .915 r
.76176 .34302 .76764 .35103 .78095 .3467 .77512 .33866 Mtetra
.77512 .33866 .78095 .3467 .79433 .34235 .78854 .33427 Mtetra
.78854 .33427 .79433 .34235 .80776 .33799 .80202 .32987 Mtetra
.80202 .32987 .80776 .33799 .82126 .3336 .81556 .32544 Mtetra
.81556 .32544 .82126 .3336 .83483 .32919 .82917 .32099 Mtetra
.82917 .32099 .83483 .32919 .84845 .32476 .84284 .31653 Mtetra
.84284 .31653 .84845 .32476 .86214 .32031 .85658 .31204 Mtetra
.664 .741 .908 r
.23846 .44853 .24574 .45531 .25659 .45164 .24934 .44484 Mtetra
.24934 .44484 .25659 .45164 .2675 .44796 .26027 .44113 Mtetra
.26027 .44113 .2675 .44796 .27844 .44427 .27124 .4374 Mtetra
.27124 .4374 .27844 .44427 .28944 .44056 .28226 .43366 Mtetra
.28226 .43366 .28944 .44056 .30048 .43683 .29333 .42991 Mtetra
.29333 .42991 .30048 .43683 .31156 .43309 .30445 .42614 Mtetra
.30445 .42614 .31156 .43309 .32269 .42933 .31561 .42235 Mtetra
.31561 .42235 .32269 .42933 .33387 .42556 .32681 .41855 Mtetra
.32681 .41855 .33387 .42556 .3451 .42177 .33807 .41473 Mtetra
.33807 .41473 .3451 .42177 .35637 .41796 .34937 .41089 Mtetra
.34937 .41089 .35637 .41796 .3677 .41414 .36072 .40704 Mtetra
.36072 .40704 .3677 .41414 .37907 .4103 .37213 .40317 Mtetra
.37213 .40317 .37907 .4103 .39048 .40644 .38357 .39928 Mtetra
.38357 .39928 .39048 .40644 .40047 .44151 .39507 .39538 Mtetra
.585 .421 .626 r
.39507 .39538 .40047 .44151 .41212 .43766 .40662 .39146 Mtetra
.052 .038 .52 r
.40662 .39146 .41212 .43766 .42382 .4338 .41692 .42661 Mtetra
.661 .745 .912 r
.41692 .42661 .42382 .4338 .43558 .42991 .42871 .4227 Mtetra
.42871 .4227 .43558 .42991 .44738 .42601 .44054 .41876 Mtetra
.44054 .41876 .44738 .42601 .45924 .42209 .45243 .41481 Mtetra
.45243 .41481 .45924 .42209 .47115 .41816 .46438 .41085 Mtetra
.46438 .41085 .47115 .41816 .48311 .4142 .47637 .40686 Mtetra
.47637 .40686 .48311 .4142 .49513 .41023 .48842 .40286 Mtetra
.48842 .40286 .49513 .41023 .50719 .40625 .50052 .39884 Mtetra
.50052 .39884 .50719 .40625 .51931 .40224 .51268 .3948 Mtetra
.965 .66 .397 r
.51268 .3948 .51931 .40224 .53176 .5331 .52489 .5698 Mtetra
.481 .188 .391 r
.52489 .5698 .53176 .5331 .54476 .57306 .53784 .56592 Mtetra
.646 .762 .934 r
.53784 .56592 .54476 .57306 .55773 .5692 .55085 .56202 Mtetra
.55085 .56202 .55773 .5692 .57076 .56532 .56392 .5581 Mtetra
.56392 .5581 .57076 .56532 .58386 .56142 .57705 .55417 Mtetra
.57705 .55417 .58386 .56142 .59701 .5575 .59025 .55021 Mtetra
.59025 .55021 .59701 .5575 .61023 .55356 .60351 .54624 Mtetra
.60351 .54624 .61023 .55356 .62351 .5496 .61683 .54225 Mtetra
.61683 .54225 .62351 .5496 .63685 .54563 .63021 .53824 Mtetra
.63021 .53824 .63685 .54563 .65026 .54163 .64366 .53421 Mtetra
.972 .733 .518 r
.64366 .53421 .65026 .54163 .66373 .53762 .65372 .44248 Mtetra
.566 .376 .583 r
.65372 .44248 .66373 .53762 .67329 .44599 .66694 .43831 Mtetra
.654 .754 .923 r
.66694 .43831 .67329 .44599 .68652 .44184 .68021 .43413 Mtetra
.68021 .43413 .68652 .44184 .69982 .43767 .69356 .42992 Mtetra
.69356 .42992 .69982 .43767 .71318 .43348 .70696 .42569 Mtetra
.70696 .42569 .71318 .43348 .72661 .42927 .72043 .42144 Mtetra
.72043 .42144 .72661 .42927 .74009 .42504 .73396 .41717 Mtetra
.73396 .41717 .74009 .42504 .75364 .42079 .74756 .41289 Mtetra
.74756 .41289 .75364 .42079 .76176 .34302 .76122 .40858 Mtetra
0 0 .306 r
.76122 .40858 .76176 .34302 .77512 .33866 .76923 .33055 Mtetra
.659 .747 .915 r
.76923 .33055 .77512 .33866 .78854 .33427 .78269 .32612 Mtetra
.78269 .32612 .78854 .33427 .80202 .32987 .79622 .32168 Mtetra
.79622 .32168 .80202 .32987 .81556 .32544 .80981 .31722 Mtetra
.80981 .31722 .81556 .32544 .82917 .32099 .82346 .31273 Mtetra
.82346 .31273 .82917 .32099 .84284 .31653 .83718 .30822 Mtetra
.83718 .30822 .84284 .31653 .85658 .31204 .85097 .30369 Mtetra
.664 .741 .908 r
.23112 .4417 .23846 .44853 .24934 .44484 .24203 .43798 Mtetra
.24203 .43798 .24934 .44484 .26027 .44113 .25299 .43424 Mtetra
.25299 .43424 .26027 .44113 .27124 .4374 .26399 .43049 Mtetra
.26399 .43049 .27124 .4374 .28226 .43366 .27504 .42672 Mtetra
.27504 .42672 .28226 .43366 .29333 .42991 .28613 .42293 Mtetra
.28613 .42293 .29333 .42991 .30445 .42614 .29727 .41913 Mtetra
.29727 .41913 .30445 .42614 .31561 .42235 .30846 .41532 Mtetra
.30846 .41532 .31561 .42235 .32681 .41855 .3197 .41148 Mtetra
.3197 .41148 .32681 .41855 .33807 .41473 .33099 .40763 Mtetra
.33099 .40763 .33807 .41473 .34937 .41089 .34232 .40377 Mtetra
.34232 .40377 .34937 .41089 .36072 .40704 .3537 .39988 Mtetra
.3537 .39988 .36072 .40704 .37213 .40317 .36513 .39598 Mtetra
.36513 .39598 .37213 .40317 .38357 .39928 .37661 .39207 Mtetra
.37661 .39207 .38357 .39928 .39507 .39538 .38814 .38814 Mtetra
.38814 .38814 .39507 .39538 .40662 .39146 .39972 .38419 Mtetra
.39972 .38419 .40662 .39146 .41692 .42661 .41135 .38022 Mtetra
.584 .42 .626 r
.41135 .38022 .41692 .42661 .42871 .4227 .42302 .37623 Mtetra
.058 .043 .523 r
.42302 .37623 .42871 .4227 .44054 .41876 .43365 .41146 Mtetra
.661 .745 .912 r
.43365 .41146 .44054 .41876 .45243 .41481 .44557 .40748 Mtetra
.44557 .40748 .45243 .41481 .46438 .41085 .45755 .40348 Mtetra
.45755 .40348 .46438 .41085 .47637 .40686 .46958 .39946 Mtetra
.46958 .39946 .47637 .40686 .48842 .40286 .48166 .39542 Mtetra
.48166 .39542 .48842 .40286 .50052 .39884 .4938 .39137 Mtetra
.4938 .39137 .50052 .39884 .51268 .3948 .50599 .3873 Mtetra
.965 .66 .397 r
.50599 .3873 .51268 .3948 .52489 .5698 .51786 .56262 Mtetra
.646 .762 .934 r
.51786 .56262 .52489 .5698 .53784 .56592 .53085 .5587 Mtetra
.53085 .5587 .53784 .56592 .55085 .56202 .5439 .55477 Mtetra
.5439 .55477 .55085 .56202 .56392 .5581 .55701 .55082 Mtetra
.55701 .55082 .56392 .5581 .57705 .55417 .57019 .54685 Mtetra
.57019 .54685 .57705 .55417 .59025 .55021 .58342 .54286 Mtetra
.58342 .54286 .59025 .55021 .60351 .54624 .59672 .53885 Mtetra
.59672 .53885 .60351 .54624 .61683 .54225 .61009 .53483 Mtetra
.61009 .53483 .61683 .54225 .63021 .53824 .62352 .53078 Mtetra
.62352 .53078 .63021 .53824 .64366 .53421 .63701 .52671 Mtetra
.972 .733 .518 r
.63701 .52671 .64366 .53421 .65372 .44248 .64727 .43477 Mtetra
.654 .754 .923 r
.64727 .43477 .65372 .44248 .66694 .43831 .66053 .43057 Mtetra
.66053 .43057 .66694 .43831 .68021 .43413 .67385 .42634 Mtetra
.67385 .42634 .68021 .43413 .69356 .42992 .68724 .4221 Mtetra
.68724 .4221 .69356 .42992 .70696 .42569 .70068 .41783 Mtetra
.70068 .41783 .70696 .42569 .72043 .42144 .71419 .41355 Mtetra
.71419 .41355 .72043 .42144 .73396 .41717 .72777 .40924 Mtetra
.72777 .40924 .73396 .41717 .74756 .41289 .74141 .40492 Mtetra
.74141 .40492 .74756 .41289 .76122 .40858 .75512 .40057 Mtetra
.98 .742 .504 r
.75512 .40057 .76122 .40858 .76923 .33055 .76329 .32237 Mtetra
.659 .747 .915 r
.76329 .32237 .76923 .33055 .78269 .32612 .7768 .3179 Mtetra
.7768 .3179 .78269 .32612 .79622 .32168 .79037 .31342 Mtetra
.79037 .31342 .79622 .32168 .80981 .31722 .80401 .30892 Mtetra
.80401 .30892 .80981 .31722 .82346 .31273 .81771 .30439 Mtetra
.81771 .30439 .82346 .31273 .83718 .30822 .83147 .29985 Mtetra
.83147 .29985 .83718 .30822 .85097 .30369 .84531 .29528 Mtetra
.664 .741 .908 r
.22373 .43482 .23112 .4417 .24203 .43798 .23467 .43107 Mtetra
.23467 .43107 .24203 .43798 .25299 .43424 .24565 .4273 Mtetra
.24565 .4273 .25299 .43424 .26399 .43049 .25668 .42352 Mtetra
.25668 .42352 .26399 .43049 .27504 .42672 .26775 .41972 Mtetra
.26775 .41972 .27504 .42672 .28613 .42293 .27888 .4159 Mtetra
.27888 .4159 .28613 .42293 .29727 .41913 .29005 .41207 Mtetra
.29005 .41207 .29727 .41913 .30846 .41532 .30127 .40823 Mtetra
.30127 .40823 .30846 .41532 .3197 .41148 .31253 .40436 Mtetra
.31253 .40436 .3197 .41148 .33099 .40763 .32384 .40048 Mtetra
.32384 .40048 .33099 .40763 .34232 .40377 .33521 .39659 Mtetra
.33521 .39659 .34232 .40377 .3537 .39988 .34662 .39267 Mtetra
.34662 .39267 .3537 .39988 .36513 .39598 .35808 .38874 Mtetra
.35808 .38874 .36513 .39598 .37661 .39207 .36959 .38479 Mtetra
.36959 .38479 .37661 .39207 .38814 .38814 .38115 .38083 Mtetra
.38115 .38083 .38814 .38814 .39972 .38419 .39276 .37685 Mtetra
.39276 .37685 .39972 .38419 .41135 .38022 .40442 .37285 Mtetra
.40442 .37285 .41135 .38022 .42302 .37623 .41613 .36883 Mtetra
.41613 .36883 .42302 .37623 .43365 .41146 .42789 .3648 Mtetra
.583 .419 .625 r
.42789 .3648 .43365 .41146 .44557 .40748 .43971 .36075 Mtetra
.065 .048 .526 r
.43971 .36075 .44557 .40748 .45755 .40348 .45066 .39605 Mtetra
.661 .745 .912 r
.45066 .39605 .45755 .40348 .46958 .39946 .46273 .392 Mtetra
.46273 .392 .46958 .39946 .48166 .39542 .47484 .38793 Mtetra
.47484 .38793 .48166 .39542 .4938 .39137 .48701 .38384 Mtetra
.964 .661 .402 r
.48701 .38384 .4938 .39137 .50599 .3873 .4978 .55931 Mtetra
.529 .292 .5 r
.4978 .55931 .50599 .3873 .51786 .56262 .51077 .55538 Mtetra
.646 .762 .934 r
.51077 .55538 .51786 .56262 .53085 .5587 .5238 .55143 Mtetra
.5238 .55143 .53085 .5587 .5439 .55477 .53689 .54746 Mtetra
.53689 .54746 .5439 .55477 .55701 .55082 .55004 .54348 Mtetra
.55004 .54348 .55701 .55082 .57019 .54685 .56326 .53947 Mtetra
.56326 .53947 .57019 .54685 .58342 .54286 .57654 .53545 Mtetra
.57654 .53545 .58342 .54286 .59672 .53885 .58988 .5314 Mtetra
.58988 .5314 .59672 .53885 .61009 .53483 .60329 .52734 Mtetra
.60329 .52734 .61009 .53483 .62352 .53078 .61676 .52326 Mtetra
.97 .733 .521 r
.61676 .52326 .62352 .53078 .63701 .52671 .62753 .43121 Mtetra
.563 .373 .581 r
.62753 .43121 .63701 .52671 .64727 .43477 .64077 .42699 Mtetra
.654 .754 .923 r
.64077 .42699 .64727 .43477 .66053 .43057 .65407 .42275 Mtetra
.65407 .42275 .66053 .43057 .67385 .42634 .66743 .41849 Mtetra
.66743 .41849 .67385 .42634 .68724 .4221 .68086 .41421 Mtetra
.68086 .41421 .68724 .4221 .70068 .41783 .69435 .40991 Mtetra
.69435 .40991 .70068 .41783 .71419 .41355 .70791 .40558 Mtetra
.70791 .40558 .71419 .41355 .72777 .40924 .72153 .40124 Mtetra
.72153 .40124 .72777 .40924 .74141 .40492 .73521 .39688 Mtetra
.73521 .39688 .74141 .40492 .75512 .40057 .74897 .39249 Mtetra
.74897 .39249 .75512 .40057 .76329 .32237 .76279 .38808 Mtetra
0 0 .301 r
.76279 .38808 .76329 .32237 .7768 .3179 .77086 .30961 Mtetra
.659 .747 .915 r
.77086 .30961 .7768 .3179 .79037 .31342 .78447 .30509 Mtetra
.78447 .30509 .79037 .31342 .80401 .30892 .79816 .30055 Mtetra
.79816 .30055 .80401 .30892 .81771 .30439 .8119 .29598 Mtetra
.8119 .29598 .81771 .30439 .83147 .29985 .82571 .29139 Mtetra
.82571 .29139 .83147 .29985 .84531 .29528 .83959 .28679 Mtetra
.664 .741 .908 r
.21628 .42788 .22373 .43482 .23467 .43107 .22724 .4241 Mtetra
.22724 .4241 .23467 .43107 .24565 .4273 .23825 .4203 Mtetra
.23825 .4203 .24565 .4273 .25668 .42352 .24931 .41649 Mtetra
.24931 .41649 .25668 .42352 .26775 .41972 .26041 .41266 Mtetra
.26041 .41266 .26775 .41972 .27888 .4159 .27156 .40882 Mtetra
.27156 .40882 .27888 .4159 .29005 .41207 .28276 .40496 Mtetra
.28276 .40496 .29005 .41207 .30127 .40823 .29401 .40108 Mtetra
.29401 .40108 .30127 .40823 .31253 .40436 .3053 .39719 Mtetra
.3053 .39719 .31253 .40436 .32384 .40048 .31665 .39327 Mtetra
.31665 .39327 .32384 .40048 .33521 .39659 .32804 .38935 Mtetra
.32804 .38935 .33521 .39659 .34662 .39267 .33948 .3854 Mtetra
.33948 .3854 .34662 .39267 .35808 .38874 .35097 .38144 Mtetra
.35097 .38144 .35808 .38874 .36959 .38479 .36251 .37746 Mtetra
.36251 .37746 .36959 .38479 .38115 .38083 .3741 .37347 Mtetra
.3741 .37347 .38115 .38083 .39276 .37685 .38574 .36945 Mtetra
.38574 .36945 .39276 .37685 .40442 .37285 .39744 .36542 Mtetra
.39744 .36542 .40442 .37285 .41613 .36883 .40918 .36137 Mtetra
.40918 .36137 .41613 .36883 .42789 .3648 .42097 .35731 Mtetra
.42097 .35731 .42789 .3648 .43971 .36075 .43282 .35322 Mtetra
.43282 .35322 .43971 .36075 .45066 .39605 .44472 .34912 Mtetra
.582 .418 .624 r
.44472 .34912 .45066 .39605 .46273 .392 .45667 .345 Mtetra
.45667 .345 .46273 .392 .47484 .38793 .46867 .34086 Mtetra
.077 .059 .532 r
.46867 .34086 .47484 .38793 .48701 .38384 .48018 .37625 Mtetra
.964 .661 .402 r
.48018 .37625 .48701 .38384 .4978 .55931 .49061 .55204 Mtetra
.646 .762 .934 r
.49061 .55204 .4978 .55931 .51077 .55538 .50362 .54807 Mtetra
.50362 .54807 .51077 .55538 .5238 .55143 .51669 .54409 Mtetra
.51669 .54409 .5238 .55143 .53689 .54746 .52982 .54009 Mtetra
.52982 .54009 .53689 .54746 .55004 .54348 .54301 .53607 Mtetra
.54301 .53607 .55004 .54348 .56326 .53947 .55627 .53203 Mtetra
.55627 .53203 .56326 .53947 .57654 .53545 .56959 .52797 Mtetra
.56959 .52797 .57654 .53545 .58988 .5314 .58298 .52389 Mtetra
.58298 .52389 .58988 .5314 .60329 .52734 .59643 .51979 Mtetra
.59643 .51979 .60329 .52734 .61676 .52326 .60995 .51567 Mtetra
.97 .733 .521 r
.60995 .51567 .61676 .52326 .62753 .43121 .62092 .42341 Mtetra
.654 .754 .923 r
.62092 .42341 .62753 .43121 .64077 .42699 .6342 .41915 Mtetra
.6342 .41915 .64077 .42699 .65407 .42275 .64755 .41487 Mtetra
.64755 .41487 .65407 .42275 .66743 .41849 .66095 .41057 Mtetra
.66095 .41057 .66743 .41849 .68086 .41421 .67443 .40625 Mtetra
.67443 .40625 .68086 .41421 .69435 .40991 .68796 .40191 Mtetra
.68796 .40191 .69435 .40991 .70791 .40558 .70156 .39755 Mtetra
.70156 .39755 .70791 .40558 .72153 .40124 .71523 .39317 Mtetra
.71523 .39317 .72153 .40124 .73521 .39688 .72896 .38876 Mtetra
.72896 .38876 .73521 .39688 .74897 .39249 .74276 .38434 Mtetra
.74276 .38434 .74897 .39249 .76279 .38808 .75663 .37989 Mtetra
.981 .743 .5 r
.75663 .37989 .76279 .38808 .77086 .30961 .76486 .30125 Mtetra
.659 .747 .915 r
.76486 .30125 .77086 .30961 .78447 .30509 .77852 .29668 Mtetra
.77852 .29668 .78447 .30509 .79816 .30055 .79225 .2921 Mtetra
.79225 .2921 .79816 .30055 .8119 .29598 .80604 .2875 Mtetra
.80604 .2875 .8119 .29598 .82571 .29139 .8199 .28287 Mtetra
.8199 .28287 .82571 .29139 .83959 .28679 .83383 .27822 Mtetra
.664 .741 .908 r
.20877 .42089 .21628 .42788 .22724 .4241 .21976 .41708 Mtetra
.21976 .41708 .22724 .4241 .23825 .4203 .2308 .41325 Mtetra
.2308 .41325 .23825 .4203 .24931 .41649 .24188 .40941 Mtetra
.24188 .40941 .24931 .41649 .26041 .41266 .25302 .40555 Mtetra
.25302 .40555 .26041 .41266 .27156 .40882 .26419 .40168 Mtetra
.26419 .40168 .27156 .40882 .28276 .40496 .27542 .39779 Mtetra
.27542 .39779 .28276 .40496 .29401 .40108 .2867 .39388 Mtetra
.2867 .39388 .29401 .40108 .3053 .39719 .29802 .38995 Mtetra
.29802 .38995 .3053 .39719 .31665 .39327 .30939 .38601 Mtetra
.30939 .38601 .31665 .39327 .32804 .38935 .32082 .38205 Mtetra
.32082 .38205 .32804 .38935 .33948 .3854 .33229 .37807 Mtetra
.33229 .37807 .33948 .3854 .35097 .38144 .34381 .37408 Mtetra
.34381 .37408 .35097 .38144 .36251 .37746 .35538 .37007 Mtetra
.35538 .37007 .36251 .37746 .3741 .37347 .367 .36604 Mtetra
.367 .36604 .3741 .37347 .38574 .36945 .37867 .362 Mtetra
.37867 .362 .38574 .36945 .39744 .36542 .3904 .35793 Mtetra
.3904 .35793 .39744 .36542 .40918 .36137 .40217 .35385 Mtetra
.40217 .35385 .40918 .36137 .42097 .35731 .414 .34975 Mtetra
.414 .34975 .42097 .35731 .43282 .35322 .42588 .34563 Mtetra
.42588 .34563 .43282 .35322 .44472 .34912 .43781 .3415 Mtetra
.43781 .3415 .44472 .34912 .45667 .345 .44979 .33734 Mtetra
.44979 .33734 .45667 .345 .46867 .34086 .46183 .33317 Mtetra
.46183 .33317 .46867 .34086 .48018 .37625 .47392 .32898 Mtetra
.581 .417 .624 r
.47392 .32898 .48018 .37625 .49061 .55204 .48607 .32477 Mtetra
0 0 .368 r
.48607 .32477 .49061 .55204 .50362 .54807 .4964 .54071 Mtetra
.646 .762 .934 r
.4964 .54071 .50362 .54807 .51669 .54409 .50951 .53669 Mtetra
.50951 .53669 .51669 .54409 .52982 .54009 .52269 .53265 Mtetra
.52269 .53265 .52982 .54009 .54301 .53607 .53592 .52859 Mtetra
.53592 .52859 .54301 .53607 .55627 .53203 .54922 .52452 Mtetra
.54922 .52452 .55627 .53203 .56959 .52797 .56259 .52042 Mtetra
.56259 .52042 .56959 .52797 .58298 .52389 .57602 .5163 Mtetra
.57602 .5163 .58298 .52389 .59643 .51979 .58951 .51217 Mtetra
.969 .732 .525 r
.58951 .51217 .59643 .51979 .60995 .51567 .601 .4198 Mtetra
.561 .369 .579 r
.601 .4198 .60995 .51567 .62092 .42341 .61426 .41553 Mtetra
.654 .754 .923 r
.61426 .41553 .62092 .42341 .6342 .41915 .62758 .41123 Mtetra
.62758 .41123 .6342 .41915 .64755 .41487 .64097 .40692 Mtetra
.64097 .40692 .64755 .41487 .66095 .41057 .65442 .40258 Mtetra
.65442 .40258 .66095 .41057 .67443 .40625 .66794 .39822 Mtetra
.66794 .39822 .67443 .40625 .68796 .40191 .68152 .39384 Mtetra
.68152 .39384 .68796 .40191 .70156 .39755 .69516 .38944 Mtetra
.69516 .38944 .70156 .39755 .71523 .39317 .70888 .38502 Mtetra
.70888 .38502 .71523 .39317 .72896 .38876 .72265 .38058 Mtetra
.72265 .38058 .72896 .38876 .74276 .38434 .7365 .37611 Mtetra
.7365 .37611 .74276 .38434 .75663 .37989 .75041 .37163 Mtetra
.75041 .37163 .75663 .37989 .76486 .30125 .76439 .36712 Mtetra
0 0 .295 r
.76439 .36712 .76486 .30125 .77852 .29668 .77252 .28821 Mtetra
.659 .747 .915 r
.77252 .28821 .77852 .29668 .79225 .2921 .7863 .28358 Mtetra
.7863 .28358 .79225 .2921 .80604 .2875 .80014 .27894 Mtetra
.80014 .27894 .80604 .2875 .8199 .28287 .81404 .27427 Mtetra
.81404 .27427 .8199 .28287 .83383 .27822 .82802 .26958 Mtetra
.664 .741 .908 r
.2012 .41384 .20877 .42089 .21976 .41708 .21222 .41 Mtetra
.21222 .41 .21976 .41708 .2308 .41325 .22329 .40615 Mtetra
.22329 .40615 .2308 .41325 .24188 .40941 .2344 .40227 Mtetra
.2344 .40227 .24188 .40941 .25302 .40555 .24556 .39839 Mtetra
.24556 .39839 .25302 .40555 .26419 .40168 .25677 .39448 Mtetra
.25677 .39448 .26419 .40168 .27542 .39779 .26802 .39056 Mtetra
.26802 .39056 .27542 .39779 .2867 .39388 .27933 .38662 Mtetra
.27933 .38662 .2867 .39388 .29802 .38995 .29068 .38266 Mtetra
.29068 .38266 .29802 .38995 .30939 .38601 .30208 .37869 Mtetra
.30208 .37869 .30939 .38601 .32082 .38205 .31353 .3747 Mtetra
.31353 .3747 .32082 .38205 .33229 .37807 .32503 .37069 Mtetra
.32503 .37069 .33229 .37807 .34381 .37408 .33659 .36666 Mtetra
.33659 .36666 .34381 .37408 .35538 .37007 .34819 .36262 Mtetra
.34819 .36262 .35538 .37007 .367 .36604 .35984 .35856 Mtetra
.35984 .35856 .367 .36604 .37867 .362 .37155 .35448 Mtetra
.37155 .35448 .37867 .362 .3904 .35793 .3833 .35038 Mtetra
.3833 .35038 .3904 .35793 .40217 .35385 .39511 .34627 Mtetra
.39511 .34627 .40217 .35385 .414 .34975 .40697 .34213 Mtetra
.40697 .34213 .414 .34975 .42588 .34563 .41888 .33798 Mtetra
.41888 .33798 .42588 .34563 .43781 .3415 .43084 .33381 Mtetra
.43084 .33381 .43781 .3415 .44979 .33734 .44286 .32963 Mtetra
.44286 .32963 .44979 .33734 .46183 .33317 .45493 .32542 Mtetra
.45493 .32542 .46183 .33317 .47392 .32898 .46706 .32119 Mtetra
.46706 .32119 .47392 .32898 .48607 .32477 .47924 .31695 Mtetra
.47924 .31695 .48607 .32477 .4964 .54071 .49147 .31268 Mtetra
.547 .336 .546 r
.49147 .31268 .4964 .54071 .50951 .53669 .50376 .3084 Mtetra
0 0 .373 r
.50376 .3084 .50951 .53669 .52269 .53265 .51549 .52515 Mtetra
.646 .762 .934 r
.51549 .52515 .52269 .53265 .53592 .52859 .52877 .52105 Mtetra
.52877 .52105 .53592 .52859 .54922 .52452 .54211 .51694 Mtetra
.54211 .51694 .54922 .52452 .56259 .52042 .55552 .51281 Mtetra
.55552 .51281 .56259 .52042 .57602 .5163 .56899 .50865 Mtetra
.56899 .50865 .57602 .5163 .58951 .51217 .58253 .50448 Mtetra
.969 .732 .525 r
.58253 .50448 .58951 .51217 .601 .4198 .59424 .41189 Mtetra
.654 .754 .923 r
.59424 .41189 .601 .4198 .61426 .41553 .60754 .40758 Mtetra
.60754 .40758 .61426 .41553 .62758 .41123 .6209 .40325 Mtetra
.6209 .40325 .62758 .41123 .64097 .40692 .63433 .39889 Mtetra
.63433 .39889 .64097 .40692 .65442 .40258 .64783 .39452 Mtetra
.64783 .39452 .65442 .40258 .66794 .39822 .66139 .39012 Mtetra
.66139 .39012 .66794 .39822 .68152 .39384 .67501 .3857 Mtetra
.67501 .3857 .68152 .39384 .69516 .38944 .68871 .38126 Mtetra
.68871 .38126 .69516 .38944 .70888 .38502 .70246 .3768 Mtetra
.70246 .3768 .70888 .38502 .72265 .38058 .71629 .37232 Mtetra
.71629 .37232 .72265 .38058 .7365 .37611 .73018 .36781 Mtetra
.73018 .36781 .7365 .37611 .75041 .37163 .74414 .36329 Mtetra
.74414 .36329 .75041 .37163 .76439 .36712 .75817 .35874 Mtetra
.983 .743 .496 r
.75817 .35874 .76439 .36712 .77252 .28821 .76647 .27965 Mtetra
.659 .747 .915 r
.76647 .27965 .77252 .28821 .7863 .28358 .78029 .27499 Mtetra
.78029 .27499 .7863 .28358 .80014 .27894 .79417 .2703 Mtetra
.79417 .2703 .80014 .27894 .81404 .27427 .80813 .26559 Mtetra
.80813 .26559 .81404 .27427 .82802 .26958 .82215 .26086 Mtetra
.664 .741 .908 r
.19358 .40674 .2012 .41384 .21222 .41 .20462 .40287 Mtetra
.20462 .40287 .21222 .41 .22329 .40615 .21571 .39899 Mtetra
.21571 .39899 .22329 .40615 .2344 .40227 .22685 .39508 Mtetra
.22685 .39508 .2344 .40227 .24556 .39839 .23804 .39116 Mtetra
.23804 .39116 .24556 .39839 .25677 .39448 .24928 .38723 Mtetra
.24928 .38723 .25677 .39448 .26802 .39056 .26056 .38327 Mtetra
.26056 .38327 .26802 .39056 .27933 .38662 .2719 .3793 Mtetra
.2719 .3793 .27933 .38662 .29068 .38266 .28328 .37531 Mtetra
.28328 .37531 .29068 .38266 .30208 .37869 .29471 .37131 Mtetra
.29471 .37131 .30208 .37869 .31353 .3747 .30619 .36728 Mtetra
.30619 .36728 .31353 .3747 .32503 .37069 .31772 .36324 Mtetra
.31772 .36324 .32503 .37069 .33659 .36666 .32931 .35918 Mtetra
.32931 .35918 .33659 .36666 .34819 .36262 .34094 .35511 Mtetra
.34094 .35511 .34819 .36262 .35984 .35856 .35262 .35101 Mtetra
.35262 .35101 .35984 .35856 .37155 .35448 .36436 .3469 Mtetra
.36436 .3469 .37155 .35448 .3833 .35038 .37615 .34277 Mtetra
.37615 .34277 .3833 .35038 .39511 .34627 .38799 .33862 Mtetra
.38799 .33862 .39511 .34627 .40697 .34213 .39988 .33446 Mtetra
.39988 .33446 .40697 .34213 .41888 .33798 .41182 .33027 Mtetra
.41182 .33027 .41888 .33798 .43084 .33381 .42382 .32607 Mtetra
.42382 .32607 .43084 .33381 .44286 .32963 .43587 .32184 Mtetra
.43587 .32184 .44286 .32963 .45493 .32542 .44798 .3176 Mtetra
.44798 .3176 .45493 .32542 .46706 .32119 .46014 .31334 Mtetra
.46014 .31334 .46706 .32119 .47924 .31695 .47236 .30906 Mtetra
.47236 .30906 .47924 .31695 .49147 .31268 .48463 .30476 Mtetra
.48463 .30476 .49147 .31268 .50376 .3084 .49695 .30044 Mtetra
.49695 .30044 .50376 .3084 .51549 .52515 .50933 .29611 Mtetra
0 0 .373 r
.50933 .29611 .51549 .52515 .52877 .52105 .52155 .51344 Mtetra
.646 .762 .934 r
.52155 .51344 .52877 .52105 .54211 .51694 .53493 .50929 Mtetra
.53493 .50929 .54211 .51694 .55552 .51281 .54838 .50512 Mtetra
.54838 .50512 .55552 .51281 .56899 .50865 .5619 .50093 Mtetra
.968 .732 .528 r
.5619 .50093 .56899 .50865 .58253 .50448 .57413 .40825 Mtetra
.558 .366 .577 r
.57413 .40825 .58253 .50448 .59424 .41189 .58741 .40391 Mtetra
.654 .754 .923 r
.58741 .40391 .59424 .41189 .60754 .40758 .60076 .39956 Mtetra
.60076 .39956 .60754 .40758 .6209 .40325 .61417 .39519 Mtetra
.61417 .39519 .6209 .40325 .63433 .39889 .62764 .3908 Mtetra
.62764 .3908 .63433 .39889 .64783 .39452 .64118 .38638 Mtetra
.64118 .38638 .64783 .39452 .66139 .39012 .65478 .38195 Mtetra
.65478 .38195 .66139 .39012 .67501 .3857 .66845 .37749 Mtetra
.66845 .37749 .67501 .3857 .68871 .38126 .68219 .37301 Mtetra
.68219 .37301 .68871 .38126 .70246 .3768 .69599 .36851 Mtetra
.69599 .36851 .70246 .3768 .71629 .37232 .70987 .36398 Mtetra
.70987 .36398 .71629 .37232 .73018 .36781 .72381 .35944 Mtetra
.72381 .35944 .73018 .36781 .74414 .36329 .73781 .35487 Mtetra
.73781 .35487 .74414 .36329 .75817 .35874 .75189 .35028 Mtetra
.75189 .35028 .75817 .35874 .76647 .27965 .76604 .34567 Mtetra
0 0 .289 r
.76604 .34567 .76647 .27965 .78029 .27499 .77422 .26631 Mtetra
.659 .747 .915 r
.77422 .26631 .78029 .27499 .79417 .2703 .78816 .26158 Mtetra
.78816 .26158 .79417 .2703 .80813 .26559 .80216 .25683 Mtetra
.80216 .25683 .80813 .26559 .82215 .26086 .81623 .25206 Mtetra
.664 .741 .908 r
.18589 .39958 .19358 .40674 .20462 .40287 .19696 .39568 Mtetra
.19696 .39568 .20462 .40287 .21571 .39899 .20808 .39177 Mtetra
.20808 .39177 .21571 .39899 .22685 .39508 .21925 .38783 Mtetra
.21925 .38783 .22685 .39508 .23804 .39116 .23047 .38388 Mtetra
.23047 .38388 .23804 .39116 .24928 .38723 .24173 .37991 Mtetra
.24173 .37991 .24928 .38723 .26056 .38327 .25304 .37593 Mtetra
.25304 .37593 .26056 .38327 .2719 .3793 .26441 .37192 Mtetra
.26441 .37192 .2719 .3793 .28328 .37531 .27582 .3679 Mtetra
.27582 .3679 .28328 .37531 .29471 .37131 .28728 .36387 Mtetra
.28728 .36387 .29471 .37131 .30619 .36728 .29879 .35981 Mtetra
.29879 .35981 .30619 .36728 .31772 .36324 .31035 .35574 Mtetra
.31035 .35574 .31772 .36324 .32931 .35918 .32197 .35165 Mtetra
.32197 .35165 .32931 .35918 .34094 .35511 .33363 .34754 Mtetra
.33363 .34754 .34094 .35511 .35262 .35101 .34535 .34341 Mtetra
.34535 .34341 .35262 .35101 .36436 .3469 .35711 .33926 Mtetra
.35711 .33926 .36436 .3469 .37615 .34277 .36893 .3351 Mtetra
.36893 .3351 .37615 .34277 .38799 .33862 .38081 .33092 Mtetra
.38081 .33092 .38799 .33862 .39988 .33446 .39273 .32671 Mtetra
.39273 .32671 .39988 .33446 .41182 .33027 .40471 .32249 Mtetra
.40471 .32249 .41182 .33027 .42382 .32607 .41674 .31826 Mtetra
.41674 .31826 .42382 .32607 .43587 .32184 .42883 .314 Mtetra
.42883 .314 .43587 .32184 .44798 .3176 .44097 .30972 Mtetra
.44097 .30972 .44798 .3176 .46014 .31334 .45316 .30543 Mtetra
.45316 .30543 .46014 .31334 .47236 .30906 .46541 .30111 Mtetra
.46541 .30111 .47236 .30906 .48463 .30476 .47772 .29677 Mtetra
.47772 .29677 .48463 .30476 .49695 .30044 .49008 .29242 Mtetra
.49008 .29242 .49695 .30044 .50933 .29611 .5025 .28804 Mtetra
.5025 .28804 .50933 .29611 .52155 .51344 .51497 .28365 Mtetra
.544 .332 .543 r
.51497 .28365 .52155 .51344 .53493 .50929 .5275 .27924 Mtetra
0 0 .379 r
.5275 .27924 .53493 .50929 .54838 .50512 .54118 .49737 Mtetra
.646 .762 .934 r
.54118 .49737 .54838 .50512 .5619 .50093 .55474 .49314 Mtetra
.968 .732 .528 r
.55474 .49314 .5619 .50093 .57413 .40825 .5672 .40023 Mtetra
.654 .754 .923 r
.5672 .40023 .57413 .40825 .58741 .40391 .58053 .39586 Mtetra
.58053 .39586 .58741 .40391 .60076 .39956 .59392 .39147 Mtetra
.59392 .39147 .60076 .39956 .61417 .39519 .60737 .38706 Mtetra
.60737 .38706 .61417 .39519 .62764 .3908 .62089 .38263 Mtetra
.62089 .38263 .62764 .3908 .64118 .38638 .63447 .37818 Mtetra
.63447 .37818 .64118 .38638 .65478 .38195 .64812 .3737 Mtetra
.64812 .3737 .65478 .38195 .66845 .37749 .66183 .3692 Mtetra
.66183 .3692 .66845 .37749 .68219 .37301 .67562 .36468 Mtetra
.67562 .36468 .68219 .37301 .69599 .36851 .68947 .36014 Mtetra
.68947 .36014 .69599 .36851 .70987 .36398 .70338 .35558 Mtetra
.70338 .35558 .70987 .36398 .72381 .35944 .71737 .35099 Mtetra
.71737 .35099 .72381 .35944 .73781 .35487 .73143 .34638 Mtetra
.73143 .34638 .73781 .35487 .75189 .35028 .74555 .34175 Mtetra
.74555 .34175 .75189 .35028 .76604 .34567 .75975 .33709 Mtetra
.984 .743 .492 r
.75975 .33709 .76604 .34567 .77422 .26631 .76811 .25756 Mtetra
.659 .747 .915 r
.76811 .25756 .77422 .26631 .78816 .26158 .78209 .25279 Mtetra
.78209 .25279 .78816 .26158 .80216 .25683 .79614 .248 Mtetra
.79614 .248 .80216 .25683 .81623 .25206 .81026 .24318 Mtetra
.664 .741 .908 r
.17814 .39237 .18589 .39958 .19696 .39568 .18924 .38844 Mtetra
.18924 .38844 .19696 .39568 .20808 .39177 .20039 .38449 Mtetra
.20039 .38449 .20808 .39177 .21925 .38783 .21158 .38052 Mtetra
.21158 .38052 .21925 .38783 .23047 .38388 .22283 .37654 Mtetra
.22283 .37654 .23047 .38388 .24173 .37991 .23412 .37254 Mtetra
.23412 .37254 .24173 .37991 .25304 .37593 .24546 .36852 Mtetra
.24546 .36852 .25304 .37593 .26441 .37192 .25686 .36449 Mtetra
.25686 .36449 .26441 .37192 .27582 .3679 .2683 .36043 Mtetra
.2683 .36043 .27582 .3679 .28728 .36387 .27979 .35636 Mtetra
.27979 .35636 .28728 .36387 .29879 .35981 .29133 .35228 Mtetra
.29133 .35228 .29879 .35981 .31035 .35574 .30292 .34817 Mtetra
.30292 .34817 .31035 .35574 .32197 .35165 .31457 .34404 Mtetra
.31457 .34404 .32197 .35165 .33363 .34754 .32626 .3399 Mtetra
.32626 .3399 .33363 .34754 .34535 .34341 .33801 .33574 Mtetra
.33801 .33574 .34535 .34341 .35711 .33926 .34981 .33156 Mtetra
.34981 .33156 .35711 .33926 .36893 .3351 .36166 .32736 Mtetra
.36166 .32736 .36893 .3351 .38081 .33092 .37357 .32315 Mtetra
.37357 .32315 .38081 .33092 .39273 .32671 .38553 .31891 Mtetra
.38553 .31891 .39273 .32671 .40471 .32249 .39754 .31465 Mtetra
.39754 .31465 .40471 .32249 .41674 .31826 .4096 .31038 Mtetra
.4096 .31038 .41674 .31826 .42883 .314 .42172 .30609 Mtetra
.42172 .30609 .42883 .314 .44097 .30972 .4339 .30177 Mtetra
.4339 .30177 .44097 .30972 .45316 .30543 .44613 .29744 Mtetra
.44613 .29744 .45316 .30543 .46541 .30111 .45841 .29309 Mtetra
.45841 .29309 .46541 .30111 .47772 .29677 .47075 .28872 Mtetra
.47075 .28872 .47772 .29677 .49008 .29242 .48315 .28433 Mtetra
.48315 .28433 .49008 .29242 .5025 .28804 .49561 .27992 Mtetra
.49561 .27992 .5025 .28804 .51497 .28365 .50812 .27548 Mtetra
.50812 .27548 .51497 .28365 .5275 .27924 .52068 .27103 Mtetra
.52068 .27103 .5275 .27924 .54118 .49737 .53331 .26656 Mtetra
.217 .086 .479 r
.53331 .26656 .54118 .49737 .55474 .49314 .54691 .39654 Mtetra
.556 .363 .574 r
.54691 .39654 .55474 .49314 .5672 .40023 .56022 .39215 Mtetra
.654 .754 .923 r
.56022 .39215 .5672 .40023 .58053 .39586 .57358 .38774 Mtetra
.57358 .38774 .58053 .39586 .59392 .39147 .58701 .38331 Mtetra
.58701 .38331 .59392 .39147 .60737 .38706 .60051 .37886 Mtetra
.60051 .37886 .60737 .38706 .62089 .38263 .61407 .37439 Mtetra
.61407 .37439 .62089 .38263 .63447 .37818 .6277 .3699 Mtetra
.6277 .3699 .63447 .37818 .64812 .3737 .64139 .36538 Mtetra
.64139 .36538 .64812 .3737 .66183 .3692 .65515 .36084 Mtetra
.65515 .36084 .66183 .3692 .67562 .36468 .66898 .35628 Mtetra
.66898 .35628 .67562 .36468 .68947 .36014 .68288 .3517 Mtetra
.68288 .3517 .68947 .36014 .70338 .35558 .69684 .34709 Mtetra
.69684 .34709 .70338 .35558 .71737 .35099 .71088 .34246 Mtetra
.71088 .34246 .71737 .35099 .73143 .34638 .72498 .33781 Mtetra
.72498 .33781 .73143 .34638 .74555 .34175 .73916 .33313 Mtetra
.73916 .33313 .74555 .34175 .75975 .33709 .7534 .32844 Mtetra
.7534 .32844 .75975 .33709 .76811 .25756 .76772 .32371 Mtetra
0 0 .283 r
.76772 .32371 .76811 .25756 .78209 .25279 .77596 .24392 Mtetra
.659 .747 .915 r
.77596 .24392 .78209 .25279 .79614 .248 .79006 .23908 Mtetra
.79006 .23908 .79614 .248 .81026 .24318 .80423 .23422 Mtetra
.664 .741 .908 r
.17033 .3851 .17814 .39237 .18924 .38844 .18146 .38114 Mtetra
.18146 .38114 .18924 .38844 .20039 .38449 .19263 .37715 Mtetra
.19263 .37715 .20039 .38449 .21158 .38052 .20386 .37316 Mtetra
.20386 .37316 .21158 .38052 .22283 .37654 .21513 .36914 Mtetra
.21513 .36914 .22283 .37654 .23412 .37254 .22645 .36511 Mtetra
.22645 .36511 .23412 .37254 .24546 .36852 .23782 .36106 Mtetra
.23782 .36106 .24546 .36852 .25686 .36449 .24924 .35699 Mtetra
.24924 .35699 .25686 .36449 .2683 .36043 .26072 .35291 Mtetra
.26072 .35291 .2683 .36043 .27979 .35636 .27224 .3488 Mtetra
.27224 .3488 .27979 .35636 .29133 .35228 .28381 .34468 Mtetra
.28381 .34468 .29133 .35228 .30292 .34817 .29543 .34054 Mtetra
.29543 .34054 .30292 .34817 .31457 .34404 .30711 .33638 Mtetra
.30711 .33638 .31457 .34404 .32626 .3399 .31884 .3322 Mtetra
.31884 .3322 .32626 .3399 .33801 .33574 .33061 .32801 Mtetra
.33061 .32801 .33801 .33574 .34981 .33156 .34245 .3238 Mtetra
.34245 .3238 .34981 .33156 .36166 .32736 .35433 .31956 Mtetra
.35433 .31956 .36166 .32736 .37357 .32315 .36627 .31531 Mtetra
.36627 .31531 .37357 .32315 .38553 .31891 .37826 .31104 Mtetra
.37826 .31104 .38553 .31891 .39754 .31465 .39031 .30675 Mtetra
.39031 .30675 .39754 .31465 .4096 .31038 .40241 .30244 Mtetra
.40241 .30244 .4096 .31038 .42172 .30609 .41456 .29811 Mtetra
.41456 .29811 .42172 .30609 .4339 .30177 .42677 .29376 Mtetra
.42677 .29376 .4339 .30177 .44613 .29744 .43903 .28939 Mtetra
.43903 .28939 .44613 .29744 .45841 .29309 .45135 .285 Mtetra
.45135 .285 .45841 .29309 .47075 .28872 .46373 .2806 Mtetra
.46373 .2806 .47075 .28872 .48315 .28433 .47617 .27617 Mtetra
.47617 .27617 .48315 .28433 .49561 .27992 .48866 .27172 Mtetra
.48866 .27172 .49561 .27992 .50812 .27548 .5012 .26725 Mtetra
.5012 .26725 .50812 .27548 .52068 .27103 .51381 .26276 Mtetra
.51381 .26276 .52068 .27103 .53331 .26656 .52647 .25825 Mtetra
.52647 .25825 .53331 .26656 .54691 .39654 .5392 .25372 Mtetra
0 0 .407 r
.5392 .25372 .54691 .39654 .56022 .39215 .55317 .384 Mtetra
.654 .754 .923 r
.55317 .384 .56022 .39215 .57358 .38774 .56657 .37955 Mtetra
.56657 .37955 .57358 .38774 .58701 .38331 .58005 .37508 Mtetra
.58005 .37508 .58701 .38331 .60051 .37886 .59359 .37059 Mtetra
.59359 .37059 .60051 .37886 .61407 .37439 .60719 .36607 Mtetra
.60719 .36607 .61407 .37439 .6277 .3699 .62087 .36154 Mtetra
.62087 .36154 .6277 .3699 .64139 .36538 .63461 .35698 Mtetra
.63461 .35698 .64139 .36538 .65515 .36084 .64841 .3524 Mtetra
.64841 .3524 .65515 .36084 .66898 .35628 .66229 .3478 Mtetra
.66229 .3478 .66898 .35628 .68288 .3517 .67623 .34317 Mtetra
.67623 .34317 .68288 .3517 .69684 .34709 .69025 .33853 Mtetra
.69025 .33853 .69684 .34709 .71088 .34246 .70433 .33385 Mtetra
.70433 .33385 .71088 .34246 .72498 .33781 .71848 .32916 Mtetra
.71848 .32916 .72498 .33781 .73916 .33313 .7327 .32444 Mtetra
.7327 .32444 .73916 .33313 .7534 .32844 .747 .3197 Mtetra
.747 .3197 .7534 .32844 .76772 .32371 .76137 .31493 Mtetra
.985 .743 .487 r
.76137 .31493 .76772 .32371 .77596 .24392 .76978 .23497 Mtetra
.659 .747 .915 r
.76978 .23497 .77596 .24392 .79006 .23908 .78393 .23009 Mtetra
.78393 .23009 .79006 .23908 .80423 .23422 .79815 .22518 Mtetra
.664 .741 .908 r
.16246 .37777 .17033 .3851 .18146 .38114 .17361 .37377 Mtetra
.17361 .37377 .18146 .38114 .19263 .37715 .18482 .36976 Mtetra
.18482 .36976 .19263 .37715 .20386 .37316 .19607 .36573 Mtetra
.19607 .36573 .20386 .37316 .21513 .36914 .20737 .36168 Mtetra
.20737 .36168 .21513 .36914 .22645 .36511 .21872 .35762 Mtetra
.21872 .35762 .22645 .36511 .23782 .36106 .23012 .35354 Mtetra
.23012 .35354 .23782 .36106 .24924 .35699 .24157 .34943 Mtetra
.24157 .34943 .24924 .35699 .26072 .35291 .25307 .34532 Mtetra
.25307 .34532 .26072 .35291 .27224 .3488 .26462 .34118 Mtetra
.26462 .34118 .27224 .3488 .28381 .34468 .27623 .33702 Mtetra
.27623 .33702 .28381 .34468 .29543 .34054 .28788 .33285 Mtetra
.28788 .33285 .29543 .34054 .30711 .33638 .29959 .32866 Mtetra
.29959 .32866 .30711 .33638 .31884 .3322 .31135 .32444 Mtetra
.31135 .32444 .31884 .3322 .33061 .32801 .32316 .32021 Mtetra
.32316 .32021 .33061 .32801 .34245 .3238 .33502 .31597 Mtetra
.33502 .31597 .34245 .3238 .35433 .31956 .34694 .3117 Mtetra
.34694 .3117 .35433 .31956 .36627 .31531 .35891 .30741 Mtetra
.35891 .30741 .36627 .31531 .37826 .31104 .37093 .3031 Mtetra
.37093 .3031 .37826 .31104 .39031 .30675 .38301 .29878 Mtetra
.38301 .29878 .39031 .30675 .40241 .30244 .39515 .29443 Mtetra
.39515 .29443 .40241 .30244 .41456 .29811 .40734 .29007 Mtetra
.40734 .29007 .41456 .29811 .42677 .29376 .41958 .28568 Mtetra
.41958 .28568 .42677 .29376 .43903 .28939 .43188 .28128 Mtetra
.43188 .28128 .43903 .28939 .45135 .285 .44424 .27685 Mtetra
.44424 .27685 .45135 .285 .46373 .2806 .45665 .2724 Mtetra
.45665 .2724 .46373 .2806 .47617 .27617 .46912 .26794 Mtetra
.46912 .26794 .47617 .27617 .48866 .27172 .48165 .26345 Mtetra
.48165 .26345 .48866 .27172 .5012 .26725 .49423 .25894 Mtetra
.49423 .25894 .5012 .26725 .51381 .26276 .50688 .25442 Mtetra
.50688 .25442 .51381 .26276 .52647 .25825 .51958 .24987 Mtetra
.51958 .24987 .52647 .25825 .5392 .25372 .53234 .2453 Mtetra
.53234 .2453 .5392 .25372 .55317 .384 .54516 .24071 Mtetra
0 0 .407 r
.54516 .24071 .55317 .384 .56657 .37955 .5595 .37128 Mtetra
.654 .754 .923 r
.5595 .37128 .56657 .37955 .58005 .37508 .57302 .36677 Mtetra
.57302 .36677 .58005 .37508 .59359 .37059 .5866 .36224 Mtetra
.5866 .36224 .59359 .37059 .60719 .36607 .60025 .35768 Mtetra
.60025 .35768 .60719 .36607 .62087 .36154 .61397 .35311 Mtetra
.61397 .35311 .62087 .36154 .63461 .35698 .62776 .34851 Mtetra
.62776 .34851 .63461 .35698 .64841 .3524 .64161 .34389 Mtetra
.64161 .34389 .64841 .3524 .66229 .3478 .65553 .33924 Mtetra
.65553 .33924 .66229 .3478 .67623 .34317 .66952 .33457 Mtetra
.66952 .33457 .67623 .34317 .69025 .33853 .68358 .32988 Mtetra
.68358 .32988 .69025 .33853 .70433 .33385 .69772 .32517 Mtetra
.69772 .32517 .70433 .33385 .71848 .32916 .71192 .32043 Mtetra
.71192 .32043 .71848 .32916 .7327 .32444 .72619 .31567 Mtetra
.72619 .31567 .7327 .32444 .747 .3197 .74054 .31088 Mtetra
.74054 .31088 .747 .3197 .76137 .31493 .75495 .30607 Mtetra
.75495 .30607 .76137 .31493 .76978 .23497 .76944 .30124 Mtetra
0 0 .277 r
.76944 .30124 .76978 .23497 .78393 .23009 .77774 .22101 Mtetra
.659 .747 .915 r
.77774 .22101 .78393 .23009 .79815 .22518 .79201 .21606 Mtetra
.664 .741 .908 r
.15452 .37038 .16246 .37777 .17361 .37377 .16571 .36635 Mtetra
.16571 .36635 .17361 .37377 .18482 .36976 .17694 .36231 Mtetra
.17694 .36231 .18482 .36976 .19607 .36573 .18822 .35825 Mtetra
.18822 .35825 .19607 .36573 .20737 .36168 .19955 .35416 Mtetra
.19955 .35416 .20737 .36168 .21872 .35762 .21093 .35007 Mtetra
.21093 .35007 .21872 .35762 .23012 .35354 .22236 .34595 Mtetra
.22236 .34595 .23012 .35354 .24157 .34943 .23384 .34182 Mtetra
.23384 .34182 .24157 .34943 .25307 .34532 .24537 .33766 Mtetra
.24537 .33766 .25307 .34532 .26462 .34118 .25695 .33349 Mtetra
.25695 .33349 .26462 .34118 .27623 .33702 .26858 .3293 Mtetra
.26858 .3293 .27623 .33702 .28788 .33285 .28027 .32509 Mtetra
.28027 .32509 .28788 .33285 .29959 .32866 .292 .32087 Mtetra
.292 .32087 .29959 .32866 .31135 .32444 .30379 .31662 Mtetra
.30379 .31662 .31135 .32444 .32316 .32021 .31564 .31236 Mtetra
.31564 .31236 .32316 .32021 .33502 .31597 .32753 .30807 Mtetra
.32753 .30807 .33502 .31597 .34694 .3117 .33948 .30377 Mtetra
.33948 .30377 .34694 .3117 .35891 .30741 .35149 .29944 Mtetra
.35149 .29944 .35891 .30741 .37093 .3031 .36355 .2951 Mtetra
.36355 .2951 .37093 .3031 .38301 .29878 .37566 .29074 Mtetra
.37566 .29074 .38301 .29878 .39515 .29443 .38783 .28636 Mtetra
.38783 .28636 .39515 .29443 .40734 .29007 .40005 .28195 Mtetra
.40005 .28195 .40734 .29007 .41958 .28568 .41233 .27753 Mtetra
.41233 .27753 .41958 .28568 .43188 .28128 .42467 .27309 Mtetra
.42467 .27309 .43188 .28128 .44424 .27685 .43706 .26863 Mtetra
.43706 .26863 .44424 .27685 .45665 .2724 .44951 .26414 Mtetra
.44951 .26414 .45665 .2724 .46912 .26794 .46201 .25964 Mtetra
.46201 .25964 .46912 .26794 .48165 .26345 .47458 .25511 Mtetra
.47458 .25511 .48165 .26345 .49423 .25894 .4872 .25057 Mtetra
.4872 .25057 .49423 .25894 .50688 .25442 .49988 .246 Mtetra
.49988 .246 .50688 .25442 .51958 .24987 .51262 .24141 Mtetra
.51262 .24141 .51958 .24987 .53234 .2453 .52542 .2368 Mtetra
.52542 .2368 .53234 .2453 .54516 .24071 .53828 .23217 Mtetra
.965 .639 .325 r
.53828 .23217 .54516 .24071 .5595 .37128 .55237 .36294 Mtetra
.654 .754 .923 r
.55237 .36294 .5595 .37128 .57302 .36677 .56593 .35839 Mtetra
.56593 .35839 .57302 .36677 .5866 .36224 .57956 .35381 Mtetra
.57956 .35381 .5866 .36224 .60025 .35768 .59325 .34922 Mtetra
.59325 .34922 .60025 .35768 .61397 .35311 .60702 .3446 Mtetra
.60702 .3446 .61397 .35311 .62776 .34851 .62085 .33996 Mtetra
.62085 .33996 .62776 .34851 .64161 .34389 .63475 .33529 Mtetra
.63475 .33529 .64161 .34389 .65553 .33924 .64871 .33061 Mtetra
.64871 .33061 .65553 .33924 .66952 .33457 .66275 .3259 Mtetra
.66275 .3259 .66952 .33457 .68358 .32988 .67686 .32116 Mtetra
.67686 .32116 .68358 .32988 .69772 .32517 .69104 .3164 Mtetra
.69104 .3164 .69772 .32517 .71192 .32043 .70529 .31162 Mtetra
.70529 .31162 .71192 .32043 .72619 .31567 .71962 .30682 Mtetra
.71962 .30682 .72619 .31567 .74054 .31088 .73401 .30198 Mtetra
.73401 .30198 .74054 .31088 .75495 .30607 .74848 .29713 Mtetra
.74848 .29713 .75495 .30607 .76944 .30124 .76302 .29225 Mtetra
.986 .744 .483 r
.76302 .29225 .76944 .30124 .77774 .22101 .7715 .21185 Mtetra
.659 .747 .915 r
.7715 .21185 .77774 .22101 .79201 .21606 .78582 .20685 Mtetra
.664 .741 .908 r
.14652 .36293 .15452 .37038 .16571 .36635 .15773 .35887 Mtetra
.15773 .35887 .16571 .36635 .17694 .36231 .16899 .35479 Mtetra
.16899 .35479 .17694 .36231 .18822 .35825 .1803 .3507 Mtetra
.1803 .3507 .18822 .35825 .19955 .35416 .19166 .34658 Mtetra
.19166 .34658 .19955 .35416 .21093 .35007 .20307 .34245 Mtetra
.20307 .34245 .21093 .35007 .22236 .34595 .21453 .3383 Mtetra
.21453 .3383 .22236 .34595 .23384 .34182 .22604 .33414 Mtetra
.22604 .33414 .23384 .34182 .24537 .33766 .2376 .32995 Mtetra
.2376 .32995 .24537 .33766 .25695 .33349 .24921 .32574 Mtetra
.24921 .32574 .25695 .33349 .26858 .3293 .26087 .32152 Mtetra
.26087 .32152 .26858 .3293 .28027 .32509 .27259 .31728 Mtetra
.27259 .31728 .28027 .32509 .292 .32087 .28436 .31301 Mtetra
.28436 .31301 .292 .32087 .30379 .31662 .29618 .30873 Mtetra
.29618 .30873 .30379 .31662 .31564 .31236 .30806 .30443 Mtetra
.30806 .30443 .31564 .31236 .32753 .30807 .31998 .30011 Mtetra
.31998 .30011 .32753 .30807 .33948 .30377 .33197 .29577 Mtetra
.33197 .29577 .33948 .30377 .35149 .29944 .344 .29141 Mtetra
.344 .29141 .35149 .29944 .36355 .2951 .3561 .28703 Mtetra
.3561 .28703 .36355 .2951 .37566 .29074 .36824 .28263 Mtetra
.36824 .28263 .37566 .29074 .38783 .28636 .38045 .27821 Mtetra
.38045 .27821 .38783 .28636 .40005 .28195 .3927 .27377 Mtetra
.3927 .27377 .40005 .28195 .41233 .27753 .40502 .26932 Mtetra
.40502 .26932 .41233 .27753 .42467 .27309 .41739 .26483 Mtetra
.41739 .26483 .42467 .27309 .43706 .26863 .42982 .26033 Mtetra
.42982 .26033 .43706 .26863 .44951 .26414 .4423 .25581 Mtetra
.4423 .25581 .44951 .26414 .46201 .25964 .45485 .25127 Mtetra
.45485 .25127 .46201 .25964 .47458 .25511 .46745 .24671 Mtetra
.46745 .24671 .47458 .25511 .4872 .25057 .48011 .24212 Mtetra
.48011 .24212 .4872 .25057 .49988 .246 .49283 .23751 Mtetra
.49283 .23751 .49988 .246 .51262 .24141 .50561 .23289 Mtetra
.50561 .23289 .51262 .24141 .52542 .2368 .51844 .22824 Mtetra
.51844 .22824 .52542 .2368 .53828 .23217 .53134 .22356 Mtetra
.53134 .22356 .53828 .23217 .55237 .36294 .5443 .21887 Mtetra
0 0 .402 r
.5443 .21887 .55237 .36294 .56593 .35839 .55877 .34993 Mtetra
.654 .754 .923 r
.55877 .34993 .56593 .35839 .57956 .35381 .57245 .34531 Mtetra
.57245 .34531 .57956 .35381 .59325 .34922 .58619 .34067 Mtetra
.58619 .34067 .59325 .34922 .60702 .3446 .59999 .33601 Mtetra
.59999 .33601 .60702 .3446 .62085 .33996 .61387 .33133 Mtetra
.61387 .33133 .62085 .33996 .63475 .33529 .62782 .32662 Mtetra
.62782 .32662 .63475 .33529 .64871 .33061 .64183 .32189 Mtetra
.64183 .32189 .64871 .33061 .66275 .3259 .65592 .31714 Mtetra
.65592 .31714 .66275 .3259 .67686 .32116 .67008 .31236 Mtetra
.67008 .31236 .67686 .32116 .69104 .3164 .68431 .30756 Mtetra
.68431 .30756 .69104 .3164 .70529 .31162 .69861 .30273 Mtetra
.69861 .30273 .70529 .31162 .71962 .30682 .71298 .29788 Mtetra
.71298 .29788 .71962 .30682 .73401 .30198 .72743 .293 Mtetra
.72743 .293 .73401 .30198 .74848 .29713 .74194 .2881 Mtetra
.74194 .2881 .74848 .29713 .76302 .29225 .75654 .28318 Mtetra
.75654 .28318 .76302 .29225 .7715 .21185 .77121 .27822 Mtetra
0 0 .271 r
.77121 .27822 .7715 .21185 .78582 .20685 .77957 .19756 Mtetra
.664 .741 .908 r
.13846 .35542 .14652 .36293 .15773 .35887 .1497 .35133 Mtetra
.1497 .35133 .15773 .35887 .16899 .35479 .16098 .34722 Mtetra
.16098 .34722 .16899 .35479 .1803 .3507 .17232 .34309 Mtetra
.17232 .34309 .1803 .3507 .19166 .34658 .18371 .33894 Mtetra
.18371 .33894 .19166 .34658 .20307 .34245 .19515 .33478 Mtetra
.19515 .33478 .20307 .34245 .21453 .3383 .20663 .33059 Mtetra
.20663 .33059 .21453 .3383 .22604 .33414 .21817 .32639 Mtetra
.21817 .32639 .22604 .33414 .2376 .32995 .22976 .32217 Mtetra
.22976 .32217 .2376 .32995 .24921 .32574 .24141 .31793 Mtetra
.24141 .31793 .24921 .32574 .26087 .32152 .2531 .31367 Mtetra
.2531 .31367 .26087 .32152 .27259 .31728 .26485 .30939 Mtetra
.26485 .30939 .27259 .31728 .28436 .31301 .27665 .30509 Mtetra
.27665 .30509 .28436 .31301 .29618 .30873 .2885 .30078 Mtetra
.2885 .30078 .29618 .30873 .30806 .30443 .30041 .29644 Mtetra
.30041 .29644 .30806 .30443 .31998 .30011 .31237 .29208 Mtetra
.31237 .29208 .31998 .30011 .33197 .29577 .32439 .28771 Mtetra
.32439 .28771 .33197 .29577 .344 .29141 .33646 .28331 Mtetra
.33646 .28331 .344 .29141 .3561 .28703 .34858 .2789 Mtetra
.34858 .2789 .3561 .28703 .36824 .28263 .36077 .27446 Mtetra
.36077 .27446 .36824 .28263 .38045 .27821 .373 .27 Mtetra
.373 .27 .38045 .27821 .3927 .27377 .3853 .26553 Mtetra
.3853 .26553 .3927 .27377 .40502 .26932 .39764 .26103 Mtetra
.39764 .26103 .40502 .26932 .41739 .26483 .41005 .25651 Mtetra
.41005 .25651 .41739 .26483 .42982 .26033 .42252 .25197 Mtetra
.42252 .25197 .42982 .26033 .4423 .25581 .43504 .24741 Mtetra
.43504 .24741 .4423 .25581 .45485 .25127 .44762 .24283 Mtetra
.44762 .24283 .45485 .25127 .46745 .24671 .46026 .23822 Mtetra
.46026 .23822 .46745 .24671 .48011 .24212 .47296 .2336 Mtetra
.47296 .2336 .48011 .24212 .49283 .23751 .48571 .22895 Mtetra
.48571 .22895 .49283 .23751 .50561 .23289 .49853 .22429 Mtetra
.49853 .22429 .50561 .23289 .51844 .22824 .51141 .2196 Mtetra
.51141 .2196 .51844 .22824 .53134 .22356 .52435 .21488 Mtetra
.52435 .21488 .53134 .22356 .5443 .21887 .53735 .21015 Mtetra
.53735 .21015 .5443 .21887 .55877 .34993 .55041 .20539 Mtetra
.541 .334 .548 r
.55041 .20539 .55877 .34993 .57245 .34531 .56353 .20061 Mtetra
0 0 .407 r
.56353 .20061 .57245 .34531 .58619 .34067 .57906 .33205 Mtetra
.654 .754 .923 r
.57906 .33205 .58619 .34067 .59999 .33601 .59291 .32735 Mtetra
.59291 .32735 .59999 .33601 .61387 .33133 .60683 .32262 Mtetra
.60683 .32262 .61387 .33133 .62782 .32662 .62083 .31787 Mtetra
.62083 .31787 .62782 .32662 .64183 .32189 .63489 .3131 Mtetra
.63489 .3131 .64183 .32189 .65592 .31714 .64902 .3083 Mtetra
.64902 .3083 .65592 .31714 .67008 .31236 .66323 .30347 Mtetra
.66323 .30347 .67008 .31236 .68431 .30756 .67751 .29863 Mtetra
.67751 .29863 .68431 .30756 .69861 .30273 .69186 .29375 Mtetra
.69186 .29375 .69861 .30273 .71298 .29788 .70628 .28886 Mtetra
.70628 .28886 .71298 .29788 .72743 .293 .72078 .28393 Mtetra
.72078 .28393 .72743 .293 .74194 .2881 .73535 .27899 Mtetra
.73535 .27899 .74194 .2881 .75654 .28318 .74999 .27402 Mtetra
.74999 .27402 .75654 .28318 .77121 .27822 .76472 .26902 Mtetra
.987 .744 .479 r
.76472 .26902 .77121 .27822 .77957 .19756 .77326 .18818 Mtetra
.664 .741 .908 r
.13033 .34785 .13846 .35542 .1497 .35133 .1416 .34373 Mtetra
.1416 .34373 .1497 .35133 .16098 .34722 .15291 .33958 Mtetra
.15291 .33958 .16098 .34722 .17232 .34309 .16428 .33542 Mtetra
.16428 .33542 .17232 .34309 .18371 .33894 .17569 .33124 Mtetra
.17569 .33124 .18371 .33894 .19515 .33478 .18716 .32704 Mtetra
.18716 .32704 .19515 .33478 .20663 .33059 .19868 .32282 Mtetra
.19868 .32282 .20663 .33059 .21817 .32639 .21025 .31858 Mtetra
.21025 .31858 .21817 .32639 .22976 .32217 .22187 .31433 Mtetra
.22187 .31433 .22976 .32217 .24141 .31793 .23354 .31005 Mtetra
.23354 .31005 .24141 .31793 .2531 .31367 .24527 .30576 Mtetra
.24527 .30576 .2531 .31367 .26485 .30939 .25704 .30144 Mtetra
.25704 .30144 .26485 .30939 .27665 .30509 .26888 .29711 Mtetra
.26888 .29711 .27665 .30509 .2885 .30078 .28076 .29276 Mtetra
.28076 .29276 .2885 .30078 .30041 .29644 .2927 .28838 Mtetra
.2927 .28838 .30041 .29644 .31237 .29208 .3047 .28399 Mtetra
.3047 .28399 .31237 .29208 .32439 .28771 .31674 .27958 Mtetra
.31674 .27958 .32439 .28771 .33646 .28331 .32885 .27514 Mtetra
.32885 .27514 .33646 .28331 .34858 .2789 .34101 .27069 Mtetra
.34101 .27069 .34858 .2789 .36077 .27446 .35322 .26622 Mtetra
.35322 .26622 .36077 .27446 .373 .27 .36549 .26172 Mtetra
.36549 .26172 .373 .27 .3853 .26553 .37782 .25721 Mtetra
.37782 .25721 .3853 .26553 .39764 .26103 .39021 .25267 Mtetra
.39021 .25267 .39764 .26103 .41005 .25651 .40265 .24811 Mtetra
.40265 .24811 .41005 .25651 .42252 .25197 .41515 .24353 Mtetra
.41515 .24353 .42252 .25197 .43504 .24741 .42771 .23893 Mtetra
.42771 .23893 .43504 .24741 .44762 .24283 .44033 .23431 Mtetra
.44033 .23431 .44762 .24283 .46026 .23822 .453 .22967 Mtetra
.453 .22967 .46026 .23822 .47296 .2336 .46574 .225 Mtetra
.46574 .225 .47296 .2336 .48571 .22895 .47854 .22032 Mtetra
.47854 .22032 .48571 .22895 .49853 .22429 .49139 .21561 Mtetra
.49139 .21561 .49853 .22429 .51141 .2196 .50431 .21088 Mtetra
.50431 .21088 .51141 .2196 .52435 .21488 .51729 .20612 Mtetra
.51729 .20612 .52435 .21488 .53735 .21015 .53033 .20135 Mtetra
.53033 .20135 .53735 .21015 .55041 .20539 .54343 .19655 Mtetra
.54343 .19655 .55041 .20539 .56353 .20061 .55659 .19173 Mtetra
.55659 .19173 .56353 .20061 .57906 .33205 .56982 .18688 Mtetra
0 0 .407 r
.56982 .18688 .57906 .33205 .59291 .32735 .58576 .3186 Mtetra
.654 .754 .923 r
.58576 .3186 .59291 .32735 .60683 .32262 .59973 .31383 Mtetra
.59973 .31383 .60683 .32262 .62083 .31787 .61377 .30904 Mtetra
.61377 .30904 .62083 .31787 .63489 .3131 .62788 .30422 Mtetra
.62788 .30422 .63489 .3131 .64902 .3083 .64206 .29937 Mtetra
.64206 .29937 .64902 .3083 .66323 .30347 .65632 .2945 Mtetra
.65632 .2945 .66323 .30347 .67751 .29863 .67064 .28961 Mtetra
.67064 .28961 .67751 .29863 .69186 .29375 .68505 .28469 Mtetra
.68505 .28469 .69186 .29375 .70628 .28886 .69952 .27975 Mtetra
.69952 .27975 .70628 .28886 .72078 .28393 .71407 .27478 Mtetra
.71407 .27478 .72078 .28393 .73535 .27899 .72869 .26979 Mtetra
.72869 .26979 .73535 .27899 .74999 .27402 .74339 .26477 Mtetra
.74339 .26477 .74999 .27402 .76472 .26902 .75816 .25972 Mtetra
.75816 .25972 .76472 .26902 .77326 .18818 .77301 .25465 Mtetra
.664 .741 .908 r
.12213 .34022 .13033 .34785 .1416 .34373 .13343 .33606 Mtetra
.13343 .33606 .1416 .34373 .15291 .33958 .14477 .33188 Mtetra
.14477 .33188 .15291 .33958 .16428 .33542 .15616 .32769 Mtetra
.15616 .32769 .16428 .33542 .17569 .33124 .16761 .32347 Mtetra
.16761 .32347 .17569 .33124 .18716 .32704 .17911 .31924 Mtetra
.17911 .31924 .18716 .32704 .19868 .32282 .19065 .31498 Mtetra
.19065 .31498 .19868 .32282 .21025 .31858 .20225 .31071 Mtetra
.20225 .31071 .21025 .31858 .22187 .31433 .2139 .30642 Mtetra
.2139 .30642 .22187 .31433 .23354 .31005 .22561 .30211 Mtetra
.22561 .30211 .23354 .31005 .24527 .30576 .23736 .29778 Mtetra
.23736 .29778 .24527 .30576 .25704 .30144 .24917 .29343 Mtetra
.24917 .29343 .25704 .30144 .26888 .29711 .26104 .28906 Mtetra
.26104 .28906 .26888 .29711 .28076 .29276 .27296 .28467 Mtetra
.27296 .28467 .28076 .29276 .2927 .28838 .28493 .28026 Mtetra
.28493 .28026 .2927 .28838 .3047 .28399 .29695 .27583 Mtetra
.29695 .27583 .3047 .28399 .31674 .27958 .30904 .27138 Mtetra
.30904 .27138 .31674 .27958 .32885 .27514 .32117 .26691 Mtetra
.32117 .26691 .32885 .27514 .34101 .27069 .33337 .26241 Mtetra
.33337 .26241 .34101 .27069 .35322 .26622 .34562 .2579 Mtetra
.34562 .2579 .35322 .26622 .36549 .26172 .35792 .25337 Mtetra
.35792 .25337 .36549 .26172 .37782 .25721 .37029 .24881 Mtetra
.37029 .24881 .37782 .25721 .39021 .25267 .38271 .24424 Mtetra
.38271 .24424 .39021 .25267 .40265 .24811 .39519 .23964 Mtetra
.39519 .23964 .40265 .24811 .41515 .24353 .40772 .23502 Mtetra
.40772 .23502 .41515 .24353 .42771 .23893 .42032 .23039 Mtetra
.42032 .23039 .42771 .23893 .44033 .23431 .43297 .22572 Mtetra
.43297 .22572 .44033 .23431 .453 .22967 .44569 .22104 Mtetra
.44569 .22104 .453 .22967 .46574 .225 .45846 .21634 Mtetra
.45846 .21634 .46574 .225 .47854 .22032 .4713 .21161 Mtetra
.4713 .21161 .47854 .22032 .49139 .21561 .48419 .20686 Mtetra
.48419 .20686 .49139 .21561 .50431 .21088 .49715 .20209 Mtetra
.49715 .20209 .50431 .21088 .51729 .20612 .51017 .19729 Mtetra
.51017 .19729 .51729 .20612 .53033 .20135 .52325 .19247 Mtetra
.52325 .19247 .53033 .20135 .54343 .19655 .53639 .18763 Mtetra
.53639 .18763 .54343 .19655 .55659 .19173 .5496 .18277 Mtetra
.5496 .18277 .55659 .19173 .56982 .18688 .56287 .17788 Mtetra
.56287 .17788 .56982 .18688 .58576 .3186 .5762 .17297 Mtetra
0 0 .407 r
.5762 .17297 .58576 .3186 .59973 .31383 .59256 .30496 Mtetra
.654 .754 .923 r
.59256 .30496 .59973 .31383 .61377 .30904 .60665 .30012 Mtetra
.60665 .30012 .61377 .30904 .62788 .30422 .62081 .29526 Mtetra
.62081 .29526 .62788 .30422 .64206 .29937 .63504 .29037 Mtetra
.63504 .29037 .64206 .29937 .65632 .2945 .64934 .28545 Mtetra
.64934 .28545 .65632 .2945 .67064 .28961 .66372 .28051 Mtetra
.66372 .28051 .67064 .28961 .68505 .28469 .67817 .27555 Mtetra
.67817 .27555 .68505 .28469 .69952 .27975 .69269 .27056 Mtetra
.69269 .27056 .69952 .27975 .71407 .27478 .70729 .26554 Mtetra
.70729 .26554 .71407 .27478 .72869 .26979 .72197 .2605 Mtetra
.72197 .2605 .72869 .26979 .74339 .26477 .73672 .25543 Mtetra
.73672 .25543 .74339 .26477 .75816 .25972 .75155 .25034 Mtetra
.75155 .25034 .75816 .25972 .77301 .25465 .76645 .24522 Mtetra
.664 .741 .908 r
.11387 .33253 .12213 .34022 .13343 .33606 .12519 .32833 Mtetra
.12519 .32833 .13343 .33606 .14477 .33188 .13656 .32412 Mtetra
.13656 .32412 .14477 .33188 .15616 .32769 .14799 .31989 Mtetra
.14799 .31989 .15616 .32769 .16761 .32347 .15946 .31564 Mtetra
.15946 .31564 .16761 .32347 .17911 .31924 .17099 .31137 Mtetra
.17099 .31137 .17911 .31924 .19065 .31498 .18256 .30708 Mtetra
.18256 .30708 .19065 .31498 .20225 .31071 .19419 .30277 Mtetra
.19419 .30277 .20225 .31071 .2139 .30642 .20587 .29844 Mtetra
.20587 .29844 .2139 .30642 .22561 .30211 .21761 .2941 Mtetra
.21761 .2941 .22561 .30211 .23736 .29778 .2294 .28973 Mtetra
.2294 .28973 .23736 .29778 .24917 .29343 .24124 .28534 Mtetra
.24124 .28534 .24917 .29343 .26104 .28906 .25313 .28094 Mtetra
.25313 .28094 .26104 .28906 .27296 .28467 .26508 .27651 Mtetra
.26508 .27651 .27296 .28467 .28493 .28026 .27709 .27206 Mtetra
.27709 .27206 .28493 .28026 .29695 .27583 .28915 .26759 Mtetra
.28915 .26759 .29695 .27583 .30904 .27138 .30126 .26311 Mtetra
.30126 .26311 .30904 .27138 .32117 .26691 .31343 .2586 Mtetra
.31343 .2586 .32117 .26691 .33337 .26241 .32566 .25407 Mtetra
.32566 .25407 .33337 .26241 .34562 .2579 .33795 .24952 Mtetra
.33795 .24952 .34562 .2579 .35792 .25337 .35029 .24494 Mtetra
.35029 .24494 .35792 .25337 .37029 .24881 .36269 .24035 Mtetra
.36269 .24035 .37029 .24881 .38271 .24424 .37514 .23574 Mtetra
.37514 .23574 .38271 .24424 .39519 .23964 .38766 .2311 Mtetra
.38766 .2311 .39519 .23964 .40772 .23502 .40023 .22644 Mtetra
.40023 .22644 .40772 .23502 .42032 .23039 .41286 .22176 Mtetra
.41286 .22176 .42032 .23039 .43297 .22572 .42556 .21706 Mtetra
.42556 .21706 .43297 .22572 .44569 .22104 .43831 .21234 Mtetra
.43831 .21234 .44569 .22104 .45846 .21634 .45112 .20759 Mtetra
.45112 .20759 .45846 .21634 .4713 .21161 .46399 .20282 Mtetra
.46399 .20282 .4713 .21161 .48419 .20686 .47693 .19803 Mtetra
.47693 .19803 .48419 .20686 .49715 .20209 .48993 .19321 Mtetra
.48993 .19321 .49715 .20209 .51017 .19729 .50298 .18838 Mtetra
.50298 .18838 .51017 .19729 .52325 .19247 .5161 .18352 Mtetra
.5161 .18352 .52325 .19247 .53639 .18763 .52929 .17863 Mtetra
.52929 .17863 .53639 .18763 .5496 .18277 .54254 .17372 Mtetra
.54254 .17372 .5496 .18277 .56287 .17788 .55585 .16879 Mtetra
.55585 .16879 .56287 .17788 .5762 .17297 .56922 .16384 Mtetra
.56922 .16384 .5762 .17297 .59256 .30496 .58266 .15886 Mtetra
0 0 .407 r
.58266 .15886 .59256 .30496 .60665 .30012 .59946 .29112 Mtetra
.654 .754 .923 r
.59946 .29112 .60665 .30012 .62081 .29526 .61366 .28621 Mtetra
.61366 .28621 .62081 .29526 .63504 .29037 .62794 .28127 Mtetra
.62794 .28127 .63504 .29037 .64934 .28545 .6423 .27631 Mtetra
.6423 .27631 .64934 .28545 .66372 .28051 .65672 .27133 Mtetra
.65672 .27133 .66372 .28051 .67817 .27555 .67123 .26632 Mtetra
.67123 .26632 .67817 .27555 .69269 .27056 .6858 .26128 Mtetra
.6858 .26128 .69269 .27056 .70729 .26554 .70045 .25621 Mtetra
.70045 .25621 .70729 .26554 .72197 .2605 .71518 .25112 Mtetra
.71518 .25112 .72197 .2605 .73672 .25543 .72999 .24601 Mtetra
.72999 .24601 .73672 .25543 .75155 .25034 .74487 .24086 Mtetra
.74487 .24086 .75155 .25034 .76645 .24522 .75983 .23569 Mtetra
.664 .741 .908 r
.10554 .32477 .11387 .33253 .12519 .32833 .11689 .32054 Mtetra
.11689 .32054 .12519 .32833 .13656 .32412 .12829 .31629 Mtetra
.12829 .31629 .13656 .32412 .14799 .31989 .13974 .31203 Mtetra
.13974 .31203 .14799 .31989 .15946 .31564 .15124 .30774 Mtetra
.15124 .30774 .15946 .31564 .17099 .31137 .1628 .30344 Mtetra
.1628 .30344 .17099 .31137 .18256 .30708 .1744 .29911 Mtetra
.1744 .29911 .18256 .30708 .19419 .30277 .18606 .29477 Mtetra
.18606 .29477 .19419 .30277 .20587 .29844 .19778 .2904 Mtetra
.19778 .2904 .20587 .29844 .21761 .2941 .20954 .28602 Mtetra
.20954 .28602 .21761 .2941 .2294 .28973 .22136 .28162 Mtetra
.22136 .28162 .2294 .28973 .24124 .28534 .23323 .27719 Mtetra
.23323 .27719 .24124 .28534 .25313 .28094 .24516 .27275 Mtetra
.24516 .27275 .25313 .28094 .26508 .27651 .25714 .26828 Mtetra
.25714 .26828 .26508 .27651 .27709 .27206 .26918 .2638 Mtetra
.26918 .2638 .27709 .27206 .28915 .26759 .28127 .25929 Mtetra
.28127 .25929 .28915 .26759 .30126 .26311 .29342 .25477 Mtetra
.29342 .25477 .30126 .26311 .31343 .2586 .30563 .25022 Mtetra
.30563 .25022 .31343 .2586 .32566 .25407 .31789 .24565 Mtetra
.31789 .24565 .32566 .25407 .33795 .24952 .33021 .24106 Mtetra
.33021 .24106 .33795 .24952 .35029 .24494 .34259 .23645 Mtetra
.34259 .23645 .35029 .24494 .36269 .24035 .35502 .23182 Mtetra
.35502 .23182 .36269 .24035 .37514 .23574 .36751 .22716 Mtetra
.36751 .22716 .37514 .23574 .38766 .2311 .38006 .22248 Mtetra
.38006 .22248 .38766 .2311 .40023 .22644 .39267 .21779 Mtetra
.39267 .21779 .40023 .22644 .41286 .22176 .40534 .21306 Mtetra
.40534 .21306 .41286 .22176 .42556 .21706 .41807 .20832 Mtetra
.41807 .20832 .42556 .21706 .43831 .21234 .43086 .20356 Mtetra
.43086 .20356 .43831 .21234 .45112 .20759 .44372 .19877 Mtetra
.44372 .19877 .45112 .20759 .46399 .20282 .45663 .19396 Mtetra
.45663 .19396 .46399 .20282 .47693 .19803 .4696 .18912 Mtetra
.4696 .18912 .47693 .19803 .48993 .19321 .48264 .18427 Mtetra
.48264 .18427 .48993 .19321 .50298 .18838 .49574 .17939 Mtetra
.49574 .17939 .50298 .18838 .5161 .18352 .5089 .17448 Mtetra
.5089 .17448 .5161 .18352 .52929 .17863 .52212 .16955 Mtetra
.52212 .16955 .52929 .17863 .54254 .17372 .53541 .1646 Mtetra
.53541 .1646 .54254 .17372 .55585 .16879 .54877 .15963 Mtetra
.54877 .15963 .55585 .16879 .56922 .16384 .56218 .15463 Mtetra
.56218 .15463 .56922 .16384 .58266 .15886 .57567 .1496 Mtetra
.57567 .1496 .58266 .15886 .59946 .29112 .58922 .14455 Mtetra
0 0 .407 r
.58922 .14455 .59946 .29112 .61366 .28621 .60646 .27708 Mtetra
.654 .754 .923 r
.60646 .27708 .61366 .28621 .62794 .28127 .62078 .2721 Mtetra
.62078 .2721 .62794 .28127 .6423 .27631 .63519 .26709 Mtetra
.63519 .26709 .6423 .27631 .65672 .27133 .64966 .26205 Mtetra
.64966 .26205 .65672 .27133 .67123 .26632 .66422 .25699 Mtetra
.66422 .25699 .67123 .26632 .6858 .26128 .67884 .25191 Mtetra
.67884 .25191 .6858 .26128 .70045 .25621 .69355 .2468 Mtetra
.69355 .2468 .70045 .25621 .71518 .25112 .70833 .24166 Mtetra
.70833 .24166 .71518 .25112 .72999 .24601 .72319 .23649 Mtetra
.72319 .23649 .72999 .24601 .74487 .24086 .73812 .2313 Mtetra
.73812 .2313 .74487 .24086 .75983 .23569 .75314 .22608 Mtetra
.664 .741 .908 r
.09714 .31695 .10554 .32477 .11689 .32054 .10852 .31268 Mtetra
.10852 .31268 .11689 .32054 .12829 .31629 .11995 .3084 Mtetra
.11995 .3084 .12829 .31629 .13974 .31203 .13143 .3041 Mtetra
.13143 .3041 .13974 .31203 .15124 .30774 .14296 .29978 Mtetra
.14296 .29978 .15124 .30774 .1628 .30344 .15454 .29544 Mtetra
.15454 .29544 .1628 .30344 .1744 .29911 .16618 .29108 Mtetra
.16618 .29108 .1744 .29911 .18606 .29477 .17787 .28669 Mtetra
.17787 .28669 .18606 .29477 .19778 .2904 .18961 .28229 Mtetra
.18961 .28229 .19778 .2904 .20954 .28602 .20141 .27787 Mtetra
.20141 .27787 .20954 .28602 .22136 .28162 .21326 .27343 Mtetra
.21326 .27343 .22136 .28162 .23323 .27719 .22516 .26897 Mtetra
.22516 .26897 .23323 .27719 .24516 .27275 .23712 .26449 Mtetra
.23712 .26449 .24516 .27275 .25714 .26828 .24914 .25999 Mtetra
.24914 .25999 .25714 .26828 .26918 .2638 .26121 .25546 Mtetra
.26121 .25546 .26918 .2638 .28127 .25929 .27333 .25092 Mtetra
.27333 .25092 .28127 .25929 .29342 .25477 .28552 .24635 Mtetra
.28552 .24635 .29342 .25477 .30563 .25022 .29776 .24177 Mtetra
.29776 .24177 .30563 .25022 .31789 .24565 .31005 .23716 Mtetra
.31005 .23716 .31789 .24565 .33021 .24106 .32241 .23253 Mtetra
.32241 .23253 .33021 .24106 .34259 .23645 .33482 .22788 Mtetra
.33482 .22788 .34259 .23645 .35502 .23182 .34729 .2232 Mtetra
.34729 .2232 .35502 .23182 .36751 .22716 .35982 .21851 Mtetra
.35982 .21851 .36751 .22716 .38006 .22248 .3724 .21379 Mtetra
.3724 .21379 .38006 .22248 .39267 .21779 .38505 .20905 Mtetra
.38505 .20905 .39267 .21779 .40534 .21306 .39776 .20429 Mtetra
.39776 .20429 .40534 .21306 .41807 .20832 .41053 .19951 Mtetra
.41053 .19951 .41807 .20832 .43086 .20356 .42335 .1947 Mtetra
.42335 .1947 .43086 .20356 .44372 .19877 .43624 .18987 Mtetra
.43624 .18987 .44372 .19877 .45663 .19396 .4492 .18501 Mtetra
.4492 .18501 .45663 .19396 .4696 .18912 .46221 .18014 Mtetra
.46221 .18014 .4696 .18912 .48264 .18427 .47529 .17524 Mtetra
.47529 .17524 .48264 .18427 .49574 .17939 .48843 .17031 Mtetra
.48843 .17031 .49574 .17939 .5089 .17448 .50163 .16537 Mtetra
.50163 .16537 .5089 .17448 .52212 .16955 .51489 .16039 Mtetra
.51489 .16039 .52212 .16955 .53541 .1646 .52823 .1554 Mtetra
.52823 .1554 .53541 .1646 .54877 .15963 .54162 .15038 Mtetra
.54162 .15038 .54877 .15963 .56218 .15463 .55508 .14533 Mtetra
.55508 .14533 .56218 .15463 .57567 .1496 .56861 .14026 Mtetra
.56861 .14026 .57567 .1496 .58922 .14455 .5822 .13517 Mtetra
.5822 .13517 .58922 .14455 .60646 .27708 .59586 .13005 Mtetra
0 0 .407 r
.59586 .13005 .60646 .27708 .62078 .2721 .61356 .26283 Mtetra
.654 .754 .923 r
.61356 .26283 .62078 .2721 .63519 .26709 .62801 .25777 Mtetra
.62801 .25777 .63519 .26709 .64966 .26205 .64254 .25269 Mtetra
.64254 .25269 .64966 .26205 .66422 .25699 .65714 .24758 Mtetra
.65714 .24758 .66422 .25699 .67884 .25191 .67182 .24245 Mtetra
.67182 .24245 .67884 .25191 .69355 .2468 .68658 .23729 Mtetra
.68658 .23729 .69355 .2468 .70833 .24166 .70141 .2321 Mtetra
.70141 .2321 .70833 .24166 .72319 .23649 .71632 .22688 Mtetra
.71632 .22688 .72319 .23649 .73812 .2313 .73131 .22164 Mtetra
.73131 .22164 .73812 .2313 .75314 .22608 .74638 .21637 Mtetra
.664 .741 .908 r
.08867 .30906 .09714 .31695 .10852 .31268 .10008 .30476 Mtetra
.10008 .30476 .10852 .31268 .11995 .3084 .11153 .30044 Mtetra
.11153 .30044 .11995 .3084 .13143 .3041 .12304 .29611 Mtetra
.12304 .29611 .13143 .3041 .14296 .29978 .1346 .29175 Mtetra
.1346 .29175 .14296 .29978 .15454 .29544 .14622 .28737 Mtetra
.14622 .28737 .15454 .29544 .16618 .29108 .15788 .28297 Mtetra
.15788 .28297 .16618 .29108 .17787 .28669 .1696 .27855 Mtetra
.1696 .27855 .17787 .28669 .18961 .28229 .18138 .27412 Mtetra
.18138 .27412 .18961 .28229 .20141 .27787 .1932 .26966 Mtetra
.1932 .26966 .20141 .27787 .21326 .27343 .20509 .26518 Mtetra
.20509 .26518 .21326 .27343 .22516 .26897 .21702 .26068 Mtetra
.21702 .26068 .22516 .26897 .23712 .26449 .22901 .25616 Mtetra
.22901 .25616 .23712 .26449 .24914 .25999 .24106 .25162 Mtetra
.24106 .25162 .24914 .25999 .26121 .25546 .25317 .24706 Mtetra
.25317 .24706 .26121 .25546 .27333 .25092 .26532 .24247 Mtetra
.26532 .24247 .27333 .25092 .28552 .24635 .27754 .23787 Mtetra
.27754 .23787 .28552 .24635 .29776 .24177 .28981 .23324 Mtetra
.28981 .23324 .29776 .24177 .31005 .23716 .30215 .22859 Mtetra
.30215 .22859 .31005 .23716 .32241 .23253 .31453 .22393 Mtetra
.31453 .22393 .32241 .23253 .33482 .22788 .32698 .21923 Mtetra
.32698 .21923 .33482 .22788 .34729 .2232 .33949 .21452 Mtetra
.33949 .21452 .34729 .2232 .35982 .21851 .35205 .20978 Mtetra
.35205 .20978 .35982 .21851 .3724 .21379 .36468 .20502 Mtetra
.36468 .20502 .3724 .21379 .38505 .20905 .37736 .20024 Mtetra
.37736 .20024 .38505 .20905 .39776 .20429 .39011 .19544 Mtetra
.39011 .19544 .39776 .20429 .41053 .19951 .40291 .19061 Mtetra
.40291 .19061 .41053 .19951 .42335 .1947 .41578 .18576 Mtetra
.41578 .18576 .42335 .1947 .43624 .18987 .42871 .18089 Mtetra
.42871 .18089 .43624 .18987 .4492 .18501 .4417 .17599 Mtetra
.4417 .17599 .4492 .18501 .46221 .18014 .45475 .17107 Mtetra
.45475 .17107 .46221 .18014 .47529 .17524 .46787 .16613 Mtetra
.46787 .16613 .47529 .17524 .48843 .17031 .48105 .16116 Mtetra
.48105 .16116 .48843 .17031 .50163 .16537 .49429 .15617 Mtetra
.49429 .15617 .50163 .16537 .51489 .16039 .5076 .15115 Mtetra
.5076 .15115 .51489 .16039 .52823 .1554 .52097 .14611 Mtetra
.52097 .14611 .52823 .1554 .54162 .15038 .53441 .14104 Mtetra
.53441 .14104 .54162 .15038 .55508 .14533 .54792 .13595 Mtetra
.54792 .13595 .55508 .14533 .56861 .14026 .56149 .13084 Mtetra
.56149 .13084 .56861 .14026 .5822 .13517 .57513 .1257 Mtetra
.57513 .1257 .5822 .13517 .59586 .13005 .58883 .12053 Mtetra
.58883 .12053 .59586 .13005 .61356 .26283 .60261 .11534 Mtetra
0 0 .407 r
.60261 .11534 .61356 .26283 .62801 .25777 .62076 .24837 Mtetra
.654 .754 .923 r
.62076 .24837 .62801 .25777 .64254 .25269 .63534 .24324 Mtetra
.63534 .24324 .64254 .25269 .65714 .24758 .65 .23808 Mtetra
.65 .23808 .65714 .24758 .67182 .24245 .66473 .2329 Mtetra
.66473 .2329 .67182 .24245 .68658 .23729 .67954 .22769 Mtetra
.67954 .22769 .68658 .23729 .70141 .2321 .69443 .22245 Mtetra
.69443 .22245 .70141 .2321 .71632 .22688 .70939 .21718 Mtetra
.70939 .21718 .71632 .22688 .73131 .22164 .72444 .21188 Mtetra
.72444 .21188 .73131 .22164 .74638 .21637 .73956 .20656 Mtetra
.664 .741 .908 r
.08013 .30111 .08867 .30906 .10008 .30476 .09156 .29677 Mtetra
.09156 .29677 .10008 .30476 .11153 .30044 .10305 .29242 Mtetra
.10305 .29242 .11153 .30044 .12304 .29611 .11459 .28804 Mtetra
.11459 .28804 .12304 .29611 .1346 .29175 .12618 .28365 Mtetra
.12618 .28365 .1346 .29175 .14622 .28737 .13782 .27924 Mtetra
.13782 .27924 .14622 .28737 .15788 .28297 .14952 .2748 Mtetra
.14952 .2748 .15788 .28297 .1696 .27855 .16127 .27035 Mtetra
.16127 .27035 .1696 .27855 .18138 .27412 .17307 .26587 Mtetra
.17307 .26587 .18138 .27412 .1932 .26966 .18493 .26137 Mtetra
.18493 .26137 .1932 .26966 .20509 .26518 .19684 .25686 Mtetra
.19684 .25686 .20509 .26518 .21702 .26068 .20881 .25232 Mtetra
.20881 .25232 .21702 .26068 .22901 .25616 .22084 .24776 Mtetra
.22084 .24776 .22901 .25616 .24106 .25162 .23292 .24318 Mtetra
.23292 .24318 .24106 .25162 .25317 .24706 .24505 .23858 Mtetra
.24505 .23858 .25317 .24706 .26532 .24247 .25725 .23396 Mtetra
.25725 .23396 .26532 .24247 .27754 .23787 .2695 .22931 Mtetra
.2695 .22931 .27754 .23787 .28981 .23324 .2818 .22464 Mtetra
.2818 .22464 .28981 .23324 .30215 .22859 .29417 .21996 Mtetra
.29417 .21996 .30215 .22859 .31453 .22393 .30659 .21525 Mtetra
.30659 .21525 .31453 .22393 .32698 .21923 .31908 .21051 Mtetra
.31908 .21051 .32698 .21923 .33949 .21452 .33162 .20576 Mtetra
.33162 .20576 .33949 .21452 .35205 .20978 .34422 .20098 Mtetra
.34422 .20098 .35205 .20978 .36468 .20502 .35688 .19618 Mtetra
.35688 .19618 .36468 .20502 .37736 .20024 .3696 .19136 Mtetra
.3696 .19136 .37736 .20024 .39011 .19544 .38239 .18651 Mtetra
.38239 .18651 .39011 .19544 .40291 .19061 .39523 .18164 Mtetra
.39523 .18164 .40291 .19061 .41578 .18576 .40813 .17675 Mtetra
.40813 .17675 .41578 .18576 .42871 .18089 .4211 .17183 Mtetra
.4211 .17183 .42871 .18089 .4417 .17599 .43413 .16689 Mtetra
.43413 .16689 .4417 .17599 .45475 .17107 .44723 .16193 Mtetra
.44723 .16193 .45475 .17107 .46787 .16613 .46038 .15694 Mtetra
.46038 .15694 .46787 .16613 .48105 .16116 .4736 .15192 Mtetra
.4736 .15192 .48105 .16116 .49429 .15617 .48689 .14689 Mtetra
.48689 .14689 .49429 .15617 .5076 .15115 .50024 .14183 Mtetra
.50024 .14183 .5076 .15115 .52097 .14611 .51366 .13674 Mtetra
.51366 .13674 .52097 .14611 .53441 .14104 .52714 .13163 Mtetra
.52714 .13163 .53441 .14104 .54792 .13595 .54069 .12649 Mtetra
.54069 .12649 .54792 .13595 .56149 .13084 .5543 .12133 Mtetra
.5543 .12133 .56149 .13084 .57513 .1257 .56798 .11614 Mtetra
.56798 .11614 .57513 .1257 .58883 .12053 .58173 .11093 Mtetra
.58173 .11093 .58883 .12053 .60261 .11534 .59555 .10569 Mtetra
.59555 .10569 .60261 .11534 .62076 .24837 .60944 .10042 Mtetra
0 0 .407 r
.60944 .10042 .62076 .24837 .63534 .24324 .62808 .2337 Mtetra
.654 .754 .923 r
.62808 .2337 .63534 .24324 .65 .23808 .64278 .22849 Mtetra
.64278 .22849 .65 .23808 .66473 .2329 .65757 .22325 Mtetra
.65757 .22325 .66473 .2329 .67954 .22769 .67243 .21799 Mtetra
.67243 .21799 .67954 .22769 .69443 .22245 .68737 .2127 Mtetra
.68737 .2127 .69443 .22245 .70939 .21718 .70239 .20738 Mtetra
.70239 .20738 .70939 .21718 .72444 .21188 .71749 .20204 Mtetra
.71749 .20204 .72444 .21188 .73956 .20656 .73267 .19666 Mtetra
.664 .741 .908 r
.07152 .29309 .08013 .30111 .09156 .29677 .08298 .28872 Mtetra
.08298 .28872 .09156 .29677 .10305 .29242 .09449 .28433 Mtetra
.09449 .28433 .10305 .29242 .11459 .28804 .10606 .27992 Mtetra
.10606 .27992 .11459 .28804 .12618 .28365 .11768 .27548 Mtetra
.11768 .27548 .12618 .28365 .13782 .27924 .12935 .27103 Mtetra
.12935 .27103 .13782 .27924 .14952 .2748 .14108 .26656 Mtetra
.14108 .26656 .14952 .2748 .16127 .27035 .15286 .26207 Mtetra
.15286 .26207 .16127 .27035 .17307 .26587 .1647 .25755 Mtetra
.1647 .25755 .17307 .26587 .18493 .26137 .17659 .25302 Mtetra
.17659 .25302 .18493 .26137 .19684 .25686 .18853 .24846 Mtetra
.18853 .24846 .19684 .25686 .20881 .25232 .20053 .24389 Mtetra
.20053 .24389 .20881 .25232 .22084 .24776 .21259 .23929 Mtetra
.21259 .23929 .22084 .24776 .23292 .24318 .2247 .23467 Mtetra
.2247 .23467 .23292 .24318 .24505 .23858 .23687 .23003 Mtetra
.23687 .23003 .24505 .23858 .25725 .23396 .2491 .22536 Mtetra
.2491 .22536 .25725 .23396 .2695 .22931 .26138 .22068 Mtetra
.26138 .22068 .2695 .22931 .2818 .22464 .27373 .21597 Mtetra
.27373 .21597 .2818 .22464 .29417 .21996 .28613 .21124 Mtetra
.28613 .21124 .29417 .21996 .30659 .21525 .29858 .20649 Mtetra
.29858 .20649 .30659 .21525 .31908 .21051 .3111 .20172 Mtetra
.3111 .20172 .31908 .21051 .33162 .20576 .32368 .19692 Mtetra
.32368 .19692 .33162 .20576 .34422 .20098 .33632 .1921 Mtetra
.33632 .1921 .34422 .20098 .35688 .19618 .34902 .18726 Mtetra
.34902 .18726 .35688 .19618 .3696 .19136 .36178 .18239 Mtetra
.36178 .18239 .3696 .19136 .38239 .18651 .3746 .1775 Mtetra
.3746 .1775 .38239 .18651 .39523 .18164 .38748 .17259 Mtetra
.38748 .17259 .39523 .18164 .40813 .17675 .40042 .16765 Mtetra
.40042 .16765 .40813 .17675 .4211 .17183 .41343 .16269 Mtetra
.41343 .16269 .4211 .17183 .43413 .16689 .4265 .15771 Mtetra
.4265 .15771 .43413 .16689 .44723 .16193 .43963 .1527 Mtetra
.43963 .1527 .44723 .16193 .46038 .15694 .45283 .14766 Mtetra
.45283 .14766 .46038 .15694 .4736 .15192 .46609 .14261 Mtetra
.46609 .14261 .4736 .15192 .48689 .14689 .47942 .13752 Mtetra
.47942 .13752 .48689 .14689 .50024 .14183 .49281 .13242 Mtetra
.49281 .13242 .50024 .14183 .51366 .13674 .50627 .12728 Mtetra
.50627 .12728 .51366 .13674 .52714 .13163 .5198 .12212 Mtetra
.5198 .12212 .52714 .13163 .54069 .12649 .53339 .11694 Mtetra
.53339 .11694 .54069 .12649 .5543 .12133 .54705 .11173 Mtetra
.54705 .11173 .5543 .12133 .56798 .11614 .56078 .1065 Mtetra
.56078 .1065 .56798 .11614 .58173 .11093 .57457 .10123 Mtetra
.57457 .10123 .58173 .11093 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10042 .60237 .09063 Mtetra
.60237 .09063 .60944 .10042 .62808 .2337 .61637 .08529 Mtetra
.528 .316 .536 r
.61637 .08529 .62808 .2337 .64278 .22849 .63045 .07992 Mtetra
0 0 .412 r
.63045 .07992 .64278 .22849 .65757 .22325 .65034 .21352 Mtetra
.654 .754 .923 r
.65034 .21352 .65757 .22325 .67243 .21799 .66525 .2082 Mtetra
.66525 .2082 .67243 .21799 .68737 .2127 .68025 .20286 Mtetra
.68025 .20286 .68737 .2127 .70239 .20738 .69532 .19749 Mtetra
.69532 .19749 .70239 .20738 .71749 .20204 .71048 .19209 Mtetra
.71048 .19209 .71749 .20204 .73267 .19666 .72572 .18666 Mtetra
.664 .741 .908 r
.06283 .285 .07152 .29309 .08298 .28872 .07432 .2806 Mtetra
.07432 .2806 .08298 .28872 .09449 .28433 .08587 .27617 Mtetra
.08587 .27617 .09449 .28433 .10606 .27992 .09746 .27172 Mtetra
.09746 .27172 .10606 .27992 .11768 .27548 .10911 .26725 Mtetra
.10911 .26725 .11768 .27548 .12935 .27103 .12082 .26276 Mtetra
.12082 .26276 .12935 .27103 .14108 .26656 .13257 .25825 Mtetra
.13257 .25825 .14108 .26656 .15286 .26207 .14438 .25372 Mtetra
.14438 .25372 .15286 .26207 .1647 .25755 .15625 .24917 Mtetra
.15625 .24917 .1647 .25755 .17659 .25302 .16817 .24459 Mtetra
.16817 .24459 .17659 .25302 .18853 .24846 .18015 .24 Mtetra
.18015 .24 .18853 .24846 .20053 .24389 .19218 .23538 Mtetra
.19218 .23538 .20053 .24389 .21259 .23929 .20427 .23074 Mtetra
.20427 .23074 .21259 .23929 .2247 .23467 .21642 .22608 Mtetra
.21642 .22608 .2247 .23467 .23687 .23003 .22862 .2214 Mtetra
.22862 .2214 .23687 .23003 .2491 .22536 .24088 .2167 Mtetra
.24088 .2167 .2491 .22536 .26138 .22068 .2532 .21197 Mtetra
.2532 .21197 .26138 .22068 .27373 .21597 .26558 .20722 Mtetra
.26558 .20722 .27373 .21597 .28613 .21124 .27801 .20245 Mtetra
.27801 .20245 .28613 .21124 .29858 .20649 .29051 .19766 Mtetra
.29051 .19766 .29858 .20649 .3111 .20172 .30306 .19284 Mtetra
.30306 .19284 .3111 .20172 .32368 .19692 .31567 .188 Mtetra
.31567 .188 .32368 .19692 .33632 .1921 .32835 .18314 Mtetra
.32835 .18314 .33632 .1921 .34902 .18726 .34108 .17826 Mtetra
.34108 .17826 .34902 .18726 .36178 .18239 .35388 .17335 Mtetra
.35388 .17335 .36178 .18239 .3746 .1775 .36674 .16841 Mtetra
.36674 .16841 .3746 .1775 .38748 .17259 .37966 .16346 Mtetra
.37966 .16346 .38748 .17259 .40042 .16765 .39264 .15847 Mtetra
.39264 .15847 .40042 .16765 .41343 .16269 .40569 .15347 Mtetra
.40569 .15347 .41343 .16269 .4265 .15771 .4188 .14844 Mtetra
.4188 .14844 .4265 .15771 .43963 .1527 .43197 .14339 Mtetra
.43197 .14339 .43963 .1527 .45283 .14766 .44521 .13831 Mtetra
.44521 .13831 .45283 .14766 .46609 .14261 .45852 .1332 Mtetra
.45852 .1332 .46609 .14261 .47942 .13752 .47188 .12807 Mtetra
.47188 .12807 .47942 .13752 .49281 .13242 .48532 .12292 Mtetra
.48532 .12292 .49281 .13242 .50627 .12728 .49882 .11774 Mtetra
.49882 .11774 .50627 .12728 .5198 .12212 .51239 .11253 Mtetra
.51239 .11253 .5198 .12212 .53339 .11694 .52603 .1073 Mtetra
.52603 .1073 .53339 .11694 .54705 .11173 .53973 .10205 Mtetra
.53973 .10205 .54705 .11173 .56078 .1065 .5535 .09676 Mtetra
.5535 .09676 .56078 .1065 .57457 .10123 .56734 .09145 Mtetra
.56734 .09145 .57457 .10123 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09063 .59523 .08075 Mtetra
.59523 .08075 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .65034 .21352 .6376 .0645 Mtetra
0 0 .412 r
.6376 .0645 .65034 .21352 .66525 .2082 .65801 .19832 Mtetra
.654 .754 .923 r
.65801 .19832 .66525 .2082 .68025 .20286 .67306 .19292 Mtetra
.67306 .19292 .68025 .20286 .69532 .19749 .68819 .1875 Mtetra
.68819 .1875 .69532 .19749 .71048 .19209 .7034 .18204 Mtetra
.7034 .18204 .71048 .19209 .72572 .18666 .71869 .17656 Mtetra
.664 .741 .908 r
.05408 .27685 .06283 .285 .07432 .2806 .06559 .2724 Mtetra
.06559 .2724 .07432 .2806 .08587 .27617 .07717 .26794 Mtetra
.07717 .26794 .08587 .27617 .09746 .27172 .08879 .26345 Mtetra
.08879 .26345 .09746 .27172 .10911 .26725 .10047 .25894 Mtetra
.10047 .25894 .10911 .26725 .12082 .26276 .1122 .25442 Mtetra
.1122 .25442 .12082 .26276 .13257 .25825 .12399 .24987 Mtetra
.12399 .24987 .13257 .25825 .14438 .25372 .13583 .2453 Mtetra
.13583 .2453 .14438 .25372 .15625 .24917 .14773 .24071 Mtetra
.14773 .24071 .15625 .24917 .16817 .24459 .15968 .23609 Mtetra
.15968 .23609 .16817 .24459 .18015 .24 .17169 .23146 Mtetra
.17169 .23146 .18015 .24 .19218 .23538 .18376 .2268 Mtetra
.18376 .2268 .19218 .23538 .20427 .23074 .19588 .22212 Mtetra
.19588 .22212 .20427 .23074 .21642 .22608 .20806 .21742 Mtetra
.20806 .21742 .21642 .22608 .22862 .2214 .2203 .2127 Mtetra
.2203 .2127 .22862 .2214 .24088 .2167 .23259 .20796 Mtetra
.23259 .20796 .24088 .2167 .2532 .21197 .24494 .20319 Mtetra
.24494 .20319 .2532 .21197 .26558 .20722 .25735 .1984 Mtetra
.25735 .1984 .26558 .20722 .27801 .20245 .26982 .19359 Mtetra
.26982 .19359 .27801 .20245 .29051 .19766 .28235 .18875 Mtetra
.28235 .18875 .29051 .19766 .30306 .19284 .29494 .18389 Mtetra
.29494 .18389 .30306 .19284 .31567 .188 .30759 .17901 Mtetra
.30759 .17901 .31567 .188 .32835 .18314 .32031 .1741 Mtetra
.32031 .1741 .32835 .18314 .34108 .17826 .33308 .16917 Mtetra
.33308 .16917 .34108 .17826 .35388 .17335 .34591 .16422 Mtetra
.34591 .16422 .35388 .17335 .36674 .16841 .35881 .15924 Mtetra
.35881 .15924 .36674 .16841 .37966 .16346 .37177 .15424 Mtetra
.37177 .15424 .37966 .16346 .39264 .15847 .38479 .14922 Mtetra
.38479 .14922 .39264 .15847 .40569 .15347 .39788 .14417 Mtetra
.39788 .14417 .40569 .15347 .4188 .14844 .41103 .13909 Mtetra
.41103 .13909 .4188 .14844 .43197 .14339 .42424 .13399 Mtetra
.42424 .13399 .43197 .14339 .44521 .13831 .43752 .12886 Mtetra
.43752 .12886 .44521 .13831 .45852 .1332 .45087 .12371 Mtetra
.45087 .12371 .45852 .1332 .47188 .12807 .46428 .11854 Mtetra
.46428 .11854 .47188 .12807 .48532 .12292 .47776 .11334 Mtetra
.47776 .11334 .48532 .12292 .49882 .11774 .4913 .10811 Mtetra
.4913 .10811 .49882 .11774 .51239 .11253 .50491 .10286 Mtetra
.50491 .10286 .51239 .11253 .52603 .1073 .51859 .09758 Mtetra
.51859 .09758 .52603 .1073 .53973 .10205 .53234 .09227 Mtetra
.53234 .09227 .53973 .10205 .5535 .09676 .54616 .08694 Mtetra
.54616 .08694 .5535 .09676 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65801 .19832 .64486 .04885 Mtetra
0 0 .412 r
.64486 .04885 .65801 .19832 .67306 .19292 .66579 .18288 Mtetra
.654 .754 .923 r
.66579 .18288 .67306 .19292 .68819 .1875 .68098 .17741 Mtetra
.68098 .17741 .68819 .1875 .7034 .18204 .69625 .1719 Mtetra
.69625 .1719 .7034 .18204 .71869 .17656 .7116 .16636 Mtetra
.664 .741 .908 r
.04524 .26863 .05408 .27685 .06559 .2724 .05679 .26414 Mtetra
.05679 .26414 .06559 .2724 .07717 .26794 .06839 .25964 Mtetra
.06839 .25964 .07717 .26794 .08879 .26345 .08005 .25511 Mtetra
.08005 .25511 .08879 .26345 .10047 .25894 .09176 .25057 Mtetra
.09176 .25057 .10047 .25894 .1122 .25442 .10352 .246 Mtetra
.10352 .246 .1122 .25442 .12399 .24987 .11534 .24141 Mtetra
.11534 .24141 .12399 .24987 .13583 .2453 .12721 .2368 Mtetra
.12721 .2368 .13583 .2453 .14773 .24071 .13914 .23217 Mtetra
.13914 .23217 .14773 .24071 .15968 .23609 .15112 .22752 Mtetra
.15112 .22752 .15968 .23609 .17169 .23146 .16316 .22284 Mtetra
.16316 .22284 .17169 .23146 .18376 .2268 .17526 .21815 Mtetra
.17526 .21815 .18376 .2268 .19588 .22212 .18742 .21343 Mtetra
.18742 .21343 .19588 .22212 .20806 .21742 .19963 .20869 Mtetra
.19963 .20869 .20806 .21742 .2203 .2127 .2119 .20392 Mtetra
.2119 .20392 .2203 .2127 .23259 .20796 .22423 .19914 Mtetra
.22423 .19914 .23259 .20796 .24494 .20319 .23661 .19433 Mtetra
.23661 .19433 .24494 .20319 .25735 .1984 .24906 .1895 Mtetra
.24906 .1895 .25735 .1984 .26982 .19359 .26157 .18464 Mtetra
.26157 .18464 .26982 .19359 .28235 .18875 .27413 .17976 Mtetra
.27413 .17976 .28235 .18875 .29494 .18389 .28676 .17486 Mtetra
.28676 .17486 .29494 .18389 .30759 .17901 .29944 .16993 Mtetra
.29944 .16993 .30759 .17901 .32031 .1741 .31219 .16498 Mtetra
.31219 .16498 .32031 .1741 .33308 .16917 .325 .16001 Mtetra
.325 .16001 .33308 .16917 .34591 .16422 .33788 .15501 Mtetra
.33788 .15501 .34591 .16422 .35881 .15924 .35081 .14999 Mtetra
.35081 .14999 .35881 .15924 .37177 .15424 .36381 .14494 Mtetra
.36381 .14494 .37177 .15424 .38479 .14922 .37687 .13987 Mtetra
.37687 .13987 .38479 .14922 .39788 .14417 .39 .13478 Mtetra
.39 .13478 .39788 .14417 .41103 .13909 .40319 .12965 Mtetra
.40319 .12965 .41103 .13909 .42424 .13399 .41644 .12451 Mtetra
.41644 .12451 .42424 .13399 .43752 .12886 .42976 .11934 Mtetra
.42976 .11934 .43752 .12886 .45087 .12371 .44315 .11414 Mtetra
.44315 .11414 .45087 .12371 .46428 .11854 .4566 .10892 Mtetra
.4566 .10892 .46428 .11854 .47776 .11334 .47013 .10367 Mtetra
.47013 .10367 .47776 .11334 .4913 .10811 .48371 .09839 Mtetra
.48371 .09839 .4913 .10811 .50491 .10286 .49737 .09309 Mtetra
.49737 .09309 .50491 .10286 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09227 .52489 .0824 Mtetra
.52489 .0824 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .66579 .18288 .65222 .03297 Mtetra
0 0 .412 r
.65222 .03297 .66579 .18288 .68098 .17741 .6737 .16721 Mtetra
.654 .754 .923 r
.6737 .16721 .68098 .17741 .69625 .1719 .68902 .16165 Mtetra
.68902 .16165 .69625 .1719 .7116 .16636 .70443 .15606 Mtetra
.664 .741 .908 r
.03634 .26033 .04524 .26863 .05679 .26414 .04791 .25581 Mtetra
.04791 .25581 .05679 .26414 .06839 .25964 .05954 .25127 Mtetra
.05954 .25127 .06839 .25964 .08005 .25511 .07123 .24671 Mtetra
.07123 .24671 .08005 .25511 .09176 .25057 .08297 .24212 Mtetra
.08297 .24212 .09176 .25057 .10352 .246 .09476 .23751 Mtetra
.09476 .23751 .10352 .246 .11534 .24141 .10661 .23289 Mtetra
.10661 .23289 .11534 .24141 .12721 .2368 .11851 .22824 Mtetra
.11851 .22824 .12721 .2368 .13914 .23217 .13047 .22356 Mtetra
.13047 .22356 .13914 .23217 .15112 .22752 .14249 .21887 Mtetra
.14249 .21887 .15112 .22752 .16316 .22284 .15456 .21416 Mtetra
.15456 .21416 .16316 .22284 .17526 .21815 .16669 .20942 Mtetra
.16669 .20942 .17526 .21815 .18742 .21343 .17888 .20466 Mtetra
.17888 .20466 .18742 .21343 .19963 .20869 .19112 .19987 Mtetra
.19112 .19987 .19963 .20869 .2119 .20392 .20343 .19507 Mtetra
.20343 .19507 .2119 .20392 .22423 .19914 .21579 .19024 Mtetra
.21579 .19024 .22423 .19914 .23661 .19433 .22821 .18539 Mtetra
.22821 .18539 .23661 .19433 .24906 .1895 .24069 .18051 Mtetra
.24069 .18051 .24906 .1895 .26157 .18464 .25323 .17561 Mtetra
.25323 .17561 .26157 .18464 .27413 .17976 .26583 .17069 Mtetra
.26583 .17069 .27413 .17976 .28676 .17486 .2785 .16575 Mtetra
.2785 .16575 .28676 .17486 .29944 .16993 .29122 .16078 Mtetra
.29122 .16078 .29944 .16993 .31219 .16498 .30401 .15578 Mtetra
.30401 .15578 .31219 .16498 .325 .16001 .31685 .15076 Mtetra
.31685 .15076 .325 .16001 .33788 .15501 .32977 .14572 Mtetra
.32977 .14572 .33788 .15501 .35081 .14999 .34274 .14065 Mtetra
.34274 .14065 .35081 .14999 .36381 .14494 .35578 .13556 Mtetra
.35578 .13556 .36381 .14494 .37687 .13987 .36888 .13044 Mtetra
.36888 .13044 .37687 .13987 .39 .13478 .38204 .1253 Mtetra
.38204 .1253 .39 .13478 .40319 .12965 .39527 .12013 Mtetra
.39527 .12013 .40319 .12965 .41644 .12451 .40857 .11494 Mtetra
.40857 .11494 .41644 .12451 .42976 .11934 .42193 .10972 Mtetra
.42193 .10972 .42976 .11934 .44315 .11414 .43536 .10448 Mtetra
.43536 .10448 .44315 .11414 .4566 .10892 .44886 .0992 Mtetra
.44886 .0992 .4566 .10892 .47013 .10367 .46242 .09391 Mtetra
.46242 .09391 .47013 .10367 .48371 .09839 .47605 .08858 Mtetra
.47605 .08858 .48371 .09839 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .0824 .51736 .07245 Mtetra
.51736 .07245 .52489 .0824 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .6737 .16721 .65969 .01685 Mtetra
0 0 .412 r
.65969 .01685 .6737 .16721 .68902 .16165 .68173 .1513 Mtetra
.654 .754 .923 r
.68173 .1513 .68902 .16165 .70443 .15606 .69719 .14565 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .57879 .48228 .57294 Mtetra
.48228 .57294 .48818 .57879 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57244 .5035 .56654 Mtetra
.5035 .56654 .50935 .57244 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .56009 Mtetra
.52489 .56009 .53068 .56605 .54141 .56283 .53564 .55685 Mtetra
.53564 .55685 .54141 .56283 .55218 .5596 .54644 .5536 Mtetra
.54644 .5536 .55218 .5596 .56299 .55635 .55728 .55033 Mtetra
.55728 .55033 .56299 .55635 .57385 .5531 .56816 .54705 Mtetra
.56816 .54705 .57385 .5531 .58474 .54983 .57909 .54376 Mtetra
.57909 .54376 .58474 .54983 .59568 .54654 .59006 .54045 Mtetra
.59006 .54045 .59568 .54654 .60667 .54325 .60107 .53713 Mtetra
.60107 .53713 .60667 .54325 .61769 .53994 .61213 .5338 Mtetra
.61213 .5338 .61769 .53994 .62876 .53662 .62323 .53045 Mtetra
.62323 .53045 .62876 .53662 .63988 .53329 .63437 .5271 Mtetra
.63437 .5271 .63988 .53329 .65104 .52994 .64556 .52372 Mtetra
.64556 .52372 .65104 .52994 .66224 .52658 .65679 .52034 Mtetra
.65679 .52034 .66224 .52658 .67349 .5232 .66807 .51694 Mtetra
.66807 .51694 .67349 .5232 .68478 .51982 .67939 .51353 Mtetra
.67939 .51353 .68478 .51982 .69612 .51641 .69076 .5101 Mtetra
.69076 .5101 .69612 .51641 .7075 .513 .70218 .50666 Mtetra
.70218 .50666 .7075 .513 .71893 .50957 .71364 .5032 Mtetra
.71364 .5032 .71893 .50957 .73041 .50613 .72515 .49974 Mtetra
.72515 .49974 .73041 .50613 .74193 .50267 .7367 .49625 Mtetra
.7367 .49625 .74193 .50267 .7535 .4992 .7483 .49276 Mtetra
.7483 .49276 .7535 .4992 .76511 .49572 .75995 .48925 Mtetra
.75995 .48925 .76511 .49572 .77677 .49222 .77165 .48572 Mtetra
.77165 .48572 .77677 .49222 .78848 .48871 .78339 .48218 Mtetra
.78339 .48218 .78848 .48871 .80024 .48518 .79518 .47863 Mtetra
.79518 .47863 .80024 .48518 .81205 .48164 .80702 .47506 Mtetra
.80702 .47506 .81205 .48164 .8239 .47808 .81891 .47148 Mtetra
.81891 .47148 .8239 .47808 .8358 .47451 .83085 .46788 Mtetra
.83085 .46788 .8358 .47451 .84775 .47092 .84283 .46427 Mtetra
.84283 .46427 .84775 .47092 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .45699 Mtetra
.86696 .45699 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57342 Mtetra
.45523 .57342 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55735 Mtetra
.50831 .55735 .51417 .56332 .52489 .56009 .51905 .5541 Mtetra
.51905 .5541 .52489 .56009 .53564 .55685 .52983 .55083 Mtetra
.52983 .55083 .53564 .55685 .54644 .5536 .54066 .54756 Mtetra
.54066 .54756 .54644 .5536 .55728 .55033 .55153 .54426 Mtetra
.55153 .54426 .55728 .55033 .56816 .54705 .56244 .54096 Mtetra
.56244 .54096 .56816 .54705 .57909 .54376 .57339 .53764 Mtetra
.57339 .53764 .57909 .54376 .59006 .54045 .58439 .53431 Mtetra
.58439 .53431 .59006 .54045 .60107 .53713 .59543 .53097 Mtetra
.59543 .53097 .60107 .53713 .61213 .5338 .60652 .52761 Mtetra
.60652 .52761 .61213 .5338 .62323 .53045 .61765 .52424 Mtetra
.61765 .52424 .62323 .53045 .63437 .5271 .62882 .52086 Mtetra
.62882 .52086 .63437 .5271 .64556 .52372 .64004 .51746 Mtetra
.64004 .51746 .64556 .52372 .65679 .52034 .6513 .51405 Mtetra
.6513 .51405 .65679 .52034 .66807 .51694 .66261 .51063 Mtetra
.66261 .51063 .66807 .51694 .67939 .51353 .67397 .50719 Mtetra
.67397 .50719 .67939 .51353 .69076 .5101 .68537 .50374 Mtetra
.68537 .50374 .69076 .5101 .70218 .50666 .69682 .50027 Mtetra
.69682 .50027 .70218 .50666 .71364 .5032 .70831 .49679 Mtetra
.70831 .49679 .71364 .5032 .72515 .49974 .71985 .4933 Mtetra
.71985 .4933 .72515 .49974 .7367 .49625 .73144 .48979 Mtetra
.73144 .48979 .7367 .49625 .7483 .49276 .74307 .48626 Mtetra
.74307 .48626 .7483 .49276 .75995 .48925 .75475 .48273 Mtetra
.75475 .48273 .75995 .48925 .77165 .48572 .76648 .47918 Mtetra
.76648 .47918 .77165 .48572 .78339 .48218 .77826 .47561 Mtetra
.77826 .47561 .78339 .48218 .79518 .47863 .79008 .47203 Mtetra
.79008 .47203 .79518 .47863 .80702 .47506 .80196 .46843 Mtetra
.80196 .46843 .80702 .47506 .81891 .47148 .81388 .46482 Mtetra
.81388 .46482 .81891 .47148 .83085 .46788 .82585 .4612 Mtetra
.82585 .4612 .83085 .46788 .84283 .46427 .83788 .45756 Mtetra
.83788 .45756 .84283 .46427 .85487 .46064 .84995 .4539 Mtetra
.84995 .4539 .85487 .46064 .86696 .45699 .86207 .45023 Mtetra
.86207 .45023 .86696 .45699 .87909 .45334 .87424 .44654 Mtetra
.87424 .44654 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57342 .44919 .56753 Mtetra
.44919 .56753 .45523 .57342 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .5546 Mtetra
.49168 .5546 .49761 .56059 .50831 .55735 .5024 .55134 Mtetra
.5024 .55134 .50831 .55735 .51905 .5541 .51317 .54806 Mtetra
.51317 .54806 .51905 .5541 .52983 .55083 .52398 .54477 Mtetra
.52398 .54477 .52983 .55083 .54066 .54756 .53484 .54147 Mtetra
.53484 .54147 .54066 .54756 .55153 .54426 .54573 .53815 Mtetra
.54573 .53815 .55153 .54426 .56244 .54096 .55667 .53483 Mtetra
.55667 .53483 .56244 .54096 .57339 .53764 .56766 .53149 Mtetra
.56766 .53149 .57339 .53764 .58439 .53431 .57868 .52813 Mtetra
.57868 .52813 .58439 .53431 .59543 .53097 .58975 .52476 Mtetra
.58975 .52476 .59543 .53097 .60652 .52761 .60087 .52138 Mtetra
.60087 .52138 .60652 .52761 .61765 .52424 .61203 .51799 Mtetra
.61203 .51799 .61765 .52424 .62882 .52086 .62323 .51458 Mtetra
.62323 .51458 .62882 .52086 .64004 .51746 .63448 .51115 Mtetra
.63448 .51115 .64004 .51746 .6513 .51405 .64578 .50772 Mtetra
.64578 .50772 .6513 .51405 .66261 .51063 .65712 .50427 Mtetra
.65712 .50427 .66261 .51063 .67397 .50719 .6685 .5008 Mtetra
.6685 .5008 .67397 .50719 .68537 .50374 .67993 .49733 Mtetra
.67993 .49733 .68537 .50374 .69682 .50027 .69141 .49383 Mtetra
.69141 .49383 .69682 .50027 .70831 .49679 .70294 .49033 Mtetra
.70294 .49033 .70831 .49679 .71985 .4933 .71451 .48681 Mtetra
.71451 .48681 .71985 .4933 .73144 .48979 .72613 .48327 Mtetra
.72613 .48327 .73144 .48979 .74307 .48626 .7378 .47972 Mtetra
.7378 .47972 .74307 .48626 .75475 .48273 .74951 .47616 Mtetra
.74951 .47616 .75475 .48273 .76648 .47918 .76127 .47258 Mtetra
.76127 .47258 .76648 .47918 .77826 .47561 .77309 .46899 Mtetra
.77309 .46899 .77826 .47561 .79008 .47203 .78495 .46538 Mtetra
.78495 .46538 .79008 .47203 .80196 .46843 .79686 .46176 Mtetra
.79686 .46176 .80196 .46843 .81388 .46482 .80881 .45812 Mtetra
.80881 .45812 .81388 .46482 .82585 .4612 .82082 .45446 Mtetra
.82082 .45446 .82585 .4612 .83788 .45756 .83288 .4508 Mtetra
.83288 .4508 .83788 .45756 .84995 .4539 .84499 .44711 Mtetra
.84499 .44711 .84995 .4539 .86207 .45023 .85715 .44341 Mtetra
.85715 .44341 .86207 .45023 .87424 .44654 .86936 .4397 Mtetra
.86936 .4397 .87424 .44654 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .5551 Mtetra
.46432 .5551 .47035 .56109 .48099 .55785 .47499 .55184 Mtetra
.47499 .55184 .48099 .55785 .49168 .5546 .4857 .54857 Mtetra
.4857 .54857 .49168 .5546 .5024 .55134 .49646 .54528 Mtetra
.49646 .54528 .5024 .55134 .51317 .54806 .50725 .54198 Mtetra
.50725 .54198 .51317 .54806 .52398 .54477 .51809 .53867 Mtetra
.51809 .53867 .52398 .54477 .53484 .54147 .52897 .53534 Mtetra
.52897 .53534 .53484 .54147 .54573 .53815 .5399 .532 Mtetra
.5399 .532 .54573 .53815 .55667 .53483 .55087 .52865 Mtetra
.55087 .52865 .55667 .53483 .56766 .53149 .56188 .52528 Mtetra
.56188 .52528 .56766 .53149 .57868 .52813 .57293 .5219 Mtetra
.57293 .5219 .57868 .52813 .58975 .52476 .58403 .51851 Mtetra
.58403 .51851 .58975 .52476 .60087 .52138 .59518 .5151 Mtetra
.59518 .5151 .60087 .52138 .61203 .51799 .60637 .51168 Mtetra
.60637 .51168 .61203 .51799 .62323 .51458 .6176 .50825 Mtetra
.6176 .50825 .62323 .51458 .63448 .51115 .62888 .5048 Mtetra
.62888 .5048 .63448 .51115 .64578 .50772 .64021 .50134 Mtetra
.64021 .50134 .64578 .50772 .65712 .50427 .65158 .49786 Mtetra
.65158 .49786 .65712 .50427 .6685 .5008 .663 .49437 Mtetra
.663 .49437 .6685 .5008 .67993 .49733 .67446 .49087 Mtetra
.67446 .49087 .67993 .49733 .69141 .49383 .68597 .48735 Mtetra
.68597 .48735 .69141 .49383 .70294 .49033 .69753 .48382 Mtetra
.69753 .48382 .70294 .49033 .71451 .48681 .70913 .48027 Mtetra
.70913 .48027 .71451 .48681 .72613 .48327 .72078 .47671 Mtetra
.72078 .47671 .72613 .48327 .7378 .47972 .73248 .47313 Mtetra
.73248 .47313 .7378 .47972 .74951 .47616 .74423 .46954 Mtetra
.74423 .46954 .74951 .47616 .76127 .47258 .75603 .46593 Mtetra
.75603 .46593 .76127 .47258 .77309 .46899 .76788 .46231 Mtetra
.76788 .46231 .77309 .46899 .78495 .46538 .77977 .45868 Mtetra
.77977 .45868 .78495 .46538 .79686 .46176 .79171 .45503 Mtetra
.79171 .45503 .79686 .46176 .80881 .45812 .80371 .45136 Mtetra
.80371 .45136 .80881 .45812 .82082 .45446 .81575 .44768 Mtetra
.81575 .44768 .82082 .45446 .83288 .4508 .82785 .44398 Mtetra
.82785 .44398 .83288 .4508 .84499 .44711 .83999 .44027 Mtetra
.83999 .44027 .84499 .44711 .85715 .44341 .85219 .43654 Mtetra
.85219 .43654 .85715 .44341 .86936 .4397 .86443 .4328 Mtetra
.86443 .4328 .86936 .4397 .88162 .43597 .87673 .42904 Mtetra
.87673 .42904 .88162 .43597 .89393 .43222 .88908 .42526 Mtetra
.88908 .42526 .89393 .43222 .9063 .42846 .90148 .42147 Mtetra
.90148 .42147 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .5556 Mtetra
.43698 .5556 .44311 .56159 .45369 .55835 .4476 .55234 Mtetra
.4476 .55234 .45369 .55835 .46432 .5551 .45825 .54907 Mtetra
.45825 .54907 .46432 .5551 .47499 .55184 .46895 .54579 Mtetra
.46895 .54579 .47499 .55184 .4857 .54857 .47968 .54249 Mtetra
.47968 .54249 .4857 .54857 .49646 .54528 .49046 .53918 Mtetra
.49046 .53918 .49646 .54528 .50725 .54198 .50129 .53585 Mtetra
.50129 .53585 .50725 .54198 .51809 .53867 .51215 .53251 Mtetra
.51215 .53251 .51809 .53867 .52897 .53534 .52306 .52916 Mtetra
.52306 .52916 .52897 .53534 .5399 .532 .53402 .5258 Mtetra
.53402 .5258 .5399 .532 .55087 .52865 .54501 .52242 Mtetra
.54501 .52242 .55087 .52865 .56188 .52528 .55606 .51903 Mtetra
.55606 .51903 .56188 .52528 .57293 .5219 .56714 .51563 Mtetra
.56714 .51563 .57293 .5219 .58403 .51851 .57827 .51221 Mtetra
.57827 .51221 .58403 .51851 .59518 .5151 .58944 .50878 Mtetra
.58944 .50878 .59518 .5151 .60637 .51168 .60066 .50533 Mtetra
.60066 .50533 .60637 .51168 .6176 .50825 .61193 .50187 Mtetra
.61193 .50187 .6176 .50825 .62888 .5048 .62324 .4984 Mtetra
.62324 .4984 .62888 .5048 .64021 .50134 .6346 .49491 Mtetra
.6346 .49491 .64021 .50134 .65158 .49786 .646 .49141 Mtetra
.646 .49141 .65158 .49786 .663 .49437 .65745 .48789 Mtetra
.65745 .48789 .663 .49437 .67446 .49087 .66894 .48436 Mtetra
.66894 .48436 .67446 .49087 .68597 .48735 .68049 .48082 Mtetra
.68049 .48082 .68597 .48735 .69753 .48382 .69208 .47726 Mtetra
.69208 .47726 .69753 .48382 .70913 .48027 .70371 .47368 Mtetra
.70371 .47368 .70913 .48027 .72078 .47671 .7154 .47009 Mtetra
.7154 .47009 .72078 .47671 .73248 .47313 .72713 .46649 Mtetra
.72713 .46649 .73248 .47313 .74423 .46954 .73891 .46287 Mtetra
.73891 .46287 .74423 .46954 .75603 .46593 .75075 .45924 Mtetra
.75075 .45924 .75603 .46593 .76788 .46231 .76263 .45559 Mtetra
.76263 .45559 .76788 .46231 .77977 .45868 .77455 .45193 Mtetra
.77455 .45193 .77977 .45868 .79171 .45503 .78653 .44825 Mtetra
.78653 .44825 .79171 .45503 .80371 .45136 .79856 .44455 Mtetra
.79856 .44455 .80371 .45136 .81575 .44768 .81064 .44084 Mtetra
.81064 .44084 .81575 .44768 .82785 .44398 .82277 .43712 Mtetra
.82277 .43712 .82785 .44398 .83999 .44027 .83495 .43338 Mtetra
.83495 .43338 .83999 .44027 .85219 .43654 .84719 .42962 Mtetra
.84719 .42962 .85219 .43654 .86443 .4328 .85947 .42585 Mtetra
.85947 .42585 .86443 .4328 .87673 .42904 .87181 .42206 Mtetra
.87181 .42206 .87673 .42904 .88908 .42526 .88419 .41825 Mtetra
.88419 .41825 .88908 .42526 .90148 .42147 .89664 .41443 Mtetra
.89664 .41443 .90148 .42147 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55284 Mtetra
.42022 .55284 .42641 .55885 .43698 .5556 .43081 .54957 Mtetra
.43081 .54957 .43698 .5556 .4476 .55234 .44145 .54629 Mtetra
.44145 .54629 .4476 .55234 .45825 .54907 .45213 .543 Mtetra
.45213 .543 .45825 .54907 .46895 .54579 .46286 .53969 Mtetra
.46286 .53969 .46895 .54579 .47968 .54249 .47362 .53636 Mtetra
.47362 .53636 .47968 .54249 .49046 .53918 .48443 .53303 Mtetra
.48443 .53303 .49046 .53918 .50129 .53585 .49528 .52968 Mtetra
.49528 .52968 .50129 .53585 .51215 .53251 .50617 .52632 Mtetra
.50617 .52632 .51215 .53251 .52306 .52916 .51711 .52294 Mtetra
.51711 .52294 .52306 .52916 .53402 .5258 .52809 .51955 Mtetra
.52809 .51955 .53402 .5258 .54501 .52242 .53912 .51615 Mtetra
.53912 .51615 .54501 .52242 .55606 .51903 .55019 .51274 Mtetra
.55019 .51274 .55606 .51903 .56714 .51563 .5613 .50931 Mtetra
.5613 .50931 .56714 .51563 .57827 .51221 .57246 .50586 Mtetra
.57246 .50586 .57827 .51221 .58944 .50878 .58367 .50241 Mtetra
.58367 .50241 .58944 .50878 .60066 .50533 .59492 .49893 Mtetra
.59492 .49893 .60066 .50533 .61193 .50187 .60621 .49545 Mtetra
.60621 .49545 .61193 .50187 .62324 .4984 .61755 .49195 Mtetra
.61755 .49195 .62324 .4984 .6346 .49491 .62894 .48843 Mtetra
.62894 .48843 .6346 .49491 .646 .49141 .64038 .48491 Mtetra
.64038 .48491 .646 .49141 .65745 .48789 .65186 .48136 Mtetra
.65186 .48136 .65745 .48789 .66894 .48436 .66338 .47781 Mtetra
.66338 .47781 .66894 .48436 .68049 .48082 .67496 .47423 Mtetra
.67496 .47423 .68049 .48082 .69208 .47726 .68658 .47065 Mtetra
.68658 .47065 .69208 .47726 .70371 .47368 .69825 .46705 Mtetra
.69825 .46705 .70371 .47368 .7154 .47009 .70997 .46343 Mtetra
.70997 .46343 .7154 .47009 .72713 .46649 .72174 .4598 Mtetra
.72174 .4598 .72713 .46649 .73891 .46287 .73355 .45615 Mtetra
.73355 .45615 .73891 .46287 .75075 .45924 .74542 .45249 Mtetra
.74542 .45249 .75075 .45924 .76263 .45559 .75733 .44881 Mtetra
.75733 .44881 .76263 .45559 .77455 .45193 .7693 .44512 Mtetra
.7693 .44512 .77455 .45193 .78653 .44825 .78131 .44141 Mtetra
.78131 .44141 .78653 .44825 .79856 .44455 .79338 .43769 Mtetra
.79338 .43769 .79856 .44455 .81064 .44084 .80549 .43395 Mtetra
.80549 .43395 .81064 .44084 .82277 .43712 .81766 .4302 Mtetra
.81766 .4302 .82277 .43712 .83495 .43338 .82988 .42643 Mtetra
.82988 .42643 .83495 .43338 .84719 .42962 .84215 .42264 Mtetra
.84215 .42264 .84719 .42962 .85947 .42585 .85447 .41884 Mtetra
.85447 .41884 .85947 .42585 .87181 .42206 .86684 .41502 Mtetra
.86684 .41502 .87181 .42206 .88419 .41825 .87927 .41119 Mtetra
.87927 .41119 .88419 .41825 .89664 .41443 .89175 .40734 Mtetra
.89175 .40734 .89664 .41443 .90913 .4106 .90428 .40347 Mtetra
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39958 Mtetra
.91687 .39958 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55984 Mtetra
.37189 .55984 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55284 .41397 .5468 Mtetra
.41397 .5468 .42022 .55284 .43081 .54957 .4246 .5435 Mtetra
.4246 .5435 .43081 .54957 .44145 .54629 .43526 .5402 Mtetra
.43526 .5402 .44145 .54629 .45213 .543 .44597 .53688 Mtetra
.44597 .53688 .45213 .543 .46286 .53969 .45672 .53354 Mtetra
.45672 .53354 .46286 .53969 .47362 .53636 .46751 .5302 Mtetra
.46751 .5302 .47362 .53636 .48443 .53303 .47835 .52684 Mtetra
.47835 .52684 .48443 .53303 .49528 .52968 .48923 .52346 Mtetra
.48923 .52346 .49528 .52968 .50617 .52632 .50015 .52008 Mtetra
.50015 .52008 .50617 .52632 .51711 .52294 .51112 .51668 Mtetra
.51112 .51668 .51711 .52294 .52809 .51955 .52213 .51326 Mtetra
.52213 .51326 .52809 .51955 .53912 .51615 .53318 .50983 Mtetra
.53318 .50983 .53912 .51615 .55019 .51274 .54428 .50639 Mtetra
.54428 .50639 .55019 .51274 .5613 .50931 .55543 .50294 Mtetra
.55543 .50294 .5613 .50931 .57246 .50586 .56661 .49947 Mtetra
.56661 .49947 .57246 .50586 .58367 .50241 .57785 .49599 Mtetra
.57785 .49599 .58367 .50241 .59492 .49893 .58913 .49249 Mtetra
.58913 .49249 .59492 .49893 .60621 .49545 .60045 .48898 Mtetra
.60045 .48898 .60621 .49545 .61755 .49195 .61183 .48545 Mtetra
.61183 .48545 .61755 .49195 .62894 .48843 .62325 .48191 Mtetra
.62325 .48191 .62894 .48843 .64038 .48491 .63471 .47835 Mtetra
.63471 .47835 .64038 .48491 .65186 .48136 .64622 .47478 Mtetra
.64622 .47478 .65186 .48136 .66338 .47781 .65778 .4712 Mtetra
.65778 .4712 .66338 .47781 .67496 .47423 .66939 .4676 Mtetra
.66939 .4676 .67496 .47423 .68658 .47065 .68105 .46399 Mtetra
.68105 .46399 .68658 .47065 .69825 .46705 .69275 .46036 Mtetra
.69275 .46036 .69825 .46705 .70997 .46343 .7045 .45671 Mtetra
.7045 .45671 .70997 .46343 .72174 .4598 .7163 .45306 Mtetra
.7163 .45306 .72174 .4598 .73355 .45615 .72815 .44938 Mtetra
.72815 .44938 .73355 .45615 .74542 .45249 .74005 .44569 Mtetra
.74005 .44569 .74542 .45249 .75733 .44881 .752 .44199 Mtetra
.752 .44199 .75733 .44881 .7693 .44512 .764 .43827 Mtetra
.764 .43827 .7693 .44512 .78131 .44141 .77605 .43453 Mtetra
.77605 .43453 .78131 .44141 .79338 .43769 .78815 .43078 Mtetra
.78815 .43078 .79338 .43769 .80549 .43395 .8003 .42701 Mtetra
.8003 .42701 .80549 .43395 .81766 .4302 .81251 .42323 Mtetra
.81251 .42323 .81766 .4302 .82988 .42643 .82476 .41943 Mtetra
.82476 .41943 .82988 .42643 .84215 .42264 .83707 .41561 Mtetra
.83707 .41561 .84215 .42264 .85447 .41884 .84943 .41178 Mtetra
.84943 .41178 .85447 .41884 .86684 .41502 .86184 .40793 Mtetra
.86184 .40793 .86684 .41502 .87927 .41119 .8743 .40406 Mtetra
.8743 .40406 .87927 .41119 .89175 .40734 .88682 .40018 Mtetra
.88682 .40018 .89175 .40734 .90428 .40347 .89939 .39628 Mtetra
.89939 .39628 .90428 .40347 .91687 .39958 .91202 .39237 Mtetra
.91202 .39237 .91687 .39958 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.35506 .5571 .36148 .56307 .37189 .55984 .3655 .55385 Mtetra
.3655 .55385 .37189 .55984 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .5435 .41834 .53739 Mtetra
.41834 .53739 .4246 .5435 .43526 .5402 .42903 .53406 Mtetra
.42903 .53406 .43526 .5402 .44597 .53688 .43976 .53071 Mtetra
.43976 .53071 .44597 .53688 .45672 .53354 .45054 .52735 Mtetra
.45054 .52735 .45672 .53354 .46751 .5302 .46136 .52398 Mtetra
.46136 .52398 .46751 .5302 .47835 .52684 .47222 .5206 Mtetra
.47222 .5206 .47835 .52684 .48923 .52346 .48313 .5172 Mtetra
.48313 .5172 .48923 .52346 .50015 .52008 .49408 .51379 Mtetra
.49408 .51379 .50015 .52008 .51112 .51668 .50508 .51036 Mtetra
.50508 .51036 .51112 .51668 .52213 .51326 .51612 .50692 Mtetra
.51612 .50692 .52213 .51326 .53318 .50983 .5272 .50347 Mtetra
.5272 .50347 .53318 .50983 .54428 .50639 .53833 .5 Mtetra
.53833 .5 .54428 .50639 .55543 .50294 .5495 .49652 Mtetra
.5495 .49652 .55543 .50294 .56661 .49947 .56072 .49303 Mtetra
.56072 .49303 .56661 .49947 .57785 .49599 .57199 .48952 Mtetra
.57199 .48952 .57785 .49599 .58913 .49249 .5833 .48599 Mtetra
.5833 .48599 .58913 .49249 .60045 .48898 .59465 .48245 Mtetra
.59465 .48245 .60045 .48898 .61183 .48545 .60606 .4789 Mtetra
.60606 .4789 .61183 .48545 .62325 .48191 .61751 .47533 Mtetra
.61751 .47533 .62325 .48191 .63471 .47835 .629 .47175 Mtetra
.629 .47175 .63471 .47835 .64622 .47478 .64055 .46816 Mtetra
.64055 .46816 .64622 .47478 .65778 .4712 .65214 .46454 Mtetra
.65214 .46454 .65778 .4712 .66939 .4676 .66378 .46092 Mtetra
.66378 .46092 .66939 .4676 .68105 .46399 .67547 .45728 Mtetra
.67547 .45728 .68105 .46399 .69275 .46036 .68721 .45362 Mtetra
.68721 .45362 .69275 .46036 .7045 .45671 .69899 .44995 Mtetra
.69899 .44995 .7045 .45671 .7163 .45306 .71083 .44626 Mtetra
.71083 .44626 .7163 .45306 .72815 .44938 .72271 .44256 Mtetra
.72271 .44256 .72815 .44938 .74005 .44569 .73465 .43884 Mtetra
.73465 .43884 .74005 .44569 .752 .44199 .74663 .4351 Mtetra
.74663 .4351 .752 .44199 .764 .43827 .75866 .43136 Mtetra
.75866 .43136 .764 .43827 .77605 .43453 .77075 .42759 Mtetra
.77075 .42759 .77605 .43453 .78815 .43078 .78289 .42381 Mtetra
.78289 .42381 .78815 .43078 .8003 .42701 .79507 .42001 Mtetra
.79507 .42001 .8003 .42701 .81251 .42323 .80731 .4162 Mtetra
.80731 .4162 .81251 .42323 .82476 .41943 .81961 .41237 Mtetra
.81961 .41237 .82476 .41943 .83707 .41561 .83195 .40852 Mtetra
.83195 .40852 .83707 .41561 .84943 .41178 .84435 .40466 Mtetra
.84435 .40466 .84943 .41178 .86184 .40793 .8568 .40078 Mtetra
.8568 .40078 .86184 .40793 .8743 .40406 .8693 .39689 Mtetra
.8693 .39689 .8743 .40406 .88682 .40018 .88186 .39297 Mtetra
.88186 .39297 .88682 .40018 .89939 .39628 .89447 .38904 Mtetra
.89447 .38904 .89939 .39628 .91202 .39237 .90713 .3851 Mtetra
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37715 Mtetra
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53457 Mtetra
.40135 .53457 .40769 .54071 .41834 .53739 .41203 .53123 Mtetra
.41203 .53123 .41834 .53739 .42903 .53406 .42275 .52787 Mtetra
.42275 .52787 .42903 .53406 .43976 .53071 .43351 .5245 Mtetra
.43351 .5245 .43976 .53071 .45054 .52735 .44432 .52112 Mtetra
.44432 .52112 .45054 .52735 .46136 .52398 .45516 .51772 Mtetra
.45516 .51772 .46136 .52398 .47222 .5206 .46605 .51431 Mtetra
.46605 .51431 .47222 .5206 .48313 .5172 .47699 .51089 Mtetra
.47699 .51089 .48313 .5172 .49408 .51379 .48797 .50745 Mtetra
.48797 .50745 .49408 .51379 .50508 .51036 .49899 .504 Mtetra
.49899 .504 .50508 .51036 .51612 .50692 .51006 .50054 Mtetra
.51006 .50054 .51612 .50692 .5272 .50347 .52117 .49706 Mtetra
.52117 .49706 .5272 .50347 .53833 .5 .53233 .49357 Mtetra
.53233 .49357 .53833 .5 .5495 .49652 .54353 .49006 Mtetra
.54353 .49006 .5495 .49652 .56072 .49303 .55478 .48654 Mtetra
.55478 .48654 .56072 .49303 .57199 .48952 .56608 .483 Mtetra
.56608 .483 .57199 .48952 .5833 .48599 .57742 .47945 Mtetra
.57742 .47945 .5833 .48599 .59465 .48245 .58881 .47588 Mtetra
.58881 .47588 .59465 .48245 .60606 .4789 .60024 .4723 Mtetra
.60024 .4723 .60606 .4789 .61751 .47533 .61172 .46871 Mtetra
.61172 .46871 .61751 .47533 .629 .47175 .62325 .4651 Mtetra
.62325 .4651 .629 .47175 .64055 .46816 .63483 .46148 Mtetra
.63483 .46148 .64055 .46816 .65214 .46454 .64645 .45784 Mtetra
.64645 .45784 .65214 .46454 .66378 .46092 .65813 .45418 Mtetra
.65813 .45418 .66378 .46092 .67547 .45728 .66985 .45051 Mtetra
.66985 .45051 .67547 .45728 .68721 .45362 .68162 .44683 Mtetra
.68162 .44683 .68721 .45362 .69899 .44995 .69344 .44313 Mtetra
.69344 .44313 .69899 .44995 .71083 .44626 .70531 .43941 Mtetra
.70531 .43941 .71083 .44626 .72271 .44256 .71723 .43568 Mtetra
.71723 .43568 .72271 .44256 .73465 .43884 .7292 .43193 Mtetra
.7292 .43193 .73465 .43884 .74663 .4351 .74122 .42817 Mtetra
.74122 .42817 .74663 .4351 .75866 .43136 .75329 .42439 Mtetra
.75329 .42439 .75866 .43136 .77075 .42759 .76541 .4206 Mtetra
.76541 .4206 .77075 .42759 .78289 .42381 .77758 .41679 Mtetra
.77758 .41679 .78289 .42381 .79507 .42001 .7898 .41296 Mtetra
.7898 .41296 .79507 .42001 .80731 .4162 .80208 .40912 Mtetra
.80208 .40912 .80731 .4162 .81961 .41237 .81441 .40526 Mtetra
.81441 .40526 .81961 .41237 .83195 .40852 .82679 .40138 Mtetra
.82679 .40138 .83195 .40852 .84435 .40466 .83923 .39749 Mtetra
.83923 .39749 .84435 .40466 .8568 .40078 .85171 .39358 Mtetra
.85171 .39358 .8568 .40078 .8693 .39689 .86426 .38965 Mtetra
.86426 .38965 .8693 .39689 .88186 .39297 .87685 .38571 Mtetra
.87685 .38571 .88186 .39297 .89447 .38904 .8895 .38175 Mtetra
.8895 .38175 .89447 .38904 .90713 .3851 .90221 .37777 Mtetra
.90221 .37777 .90713 .3851 .91985 .38114 .91497 .37377 Mtetra
.91497 .37377 .91985 .38114 .93263 .37715 .92778 .36976 Mtetra
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53508 Mtetra
.3737 .53508 .38013 .54122 .39072 .5379 .38431 .53174 Mtetra
.38431 .53174 .39072 .5379 .40135 .53457 .39497 .52839 Mtetra
.39497 .52839 .40135 .53457 .41203 .53123 .40568 .52502 Mtetra
.40568 .52502 .41203 .53123 .42275 .52787 .41642 .52164 Mtetra
.41642 .52164 .42275 .52787 .43351 .5245 .42721 .51825 Mtetra
.42721 .51825 .43351 .5245 .44432 .52112 .43804 .51484 Mtetra
.43804 .51484 .44432 .52112 .45516 .51772 .44892 .51142 Mtetra
.44892 .51142 .45516 .51772 .46605 .51431 .45984 .50798 Mtetra
.45984 .50798 .46605 .51431 .47699 .51089 .4708 .50453 Mtetra
.4708 .50453 .47699 .51089 .48797 .50745 .48181 .50107 Mtetra
.48181 .50107 .48797 .50745 .49899 .504 .49286 .49759 Mtetra
.49286 .49759 .49899 .504 .51006 .50054 .50396 .4941 Mtetra
.50396 .4941 .51006 .50054 .52117 .49706 .5151 .4906 Mtetra
.5151 .4906 .52117 .49706 .53233 .49357 .52629 .48708 Mtetra
.52629 .48708 .53233 .49357 .54353 .49006 .53752 .48355 Mtetra
.53752 .48355 .54353 .49006 .55478 .48654 .5488 .48 Mtetra
.5488 .48 .55478 .48654 .56608 .483 .56013 .47643 Mtetra
.56013 .47643 .56608 .483 .57742 .47945 .5715 .47286 Mtetra
.5715 .47286 .57742 .47945 .58881 .47588 .58292 .46926 Mtetra
.58292 .46926 .58881 .47588 .60024 .4723 .59438 .46566 Mtetra
.59438 .46566 .60024 .4723 .61172 .46871 .6059 .46203 Mtetra
.6059 .46203 .61172 .46871 .62325 .4651 .61746 .4584 Mtetra
.61746 .4584 .62325 .4651 .63483 .46148 .62907 .45475 Mtetra
.62907 .45475 .63483 .46148 .64645 .45784 .64072 .45108 Mtetra
.64072 .45108 .64645 .45784 .65813 .45418 .65243 .4474 Mtetra
.65243 .4474 .65813 .45418 .66985 .45051 .66418 .4437 Mtetra
.66418 .4437 .66985 .45051 .68162 .44683 .67599 .43998 Mtetra
.67599 .43998 .68162 .44683 .69344 .44313 .68784 .43626 Mtetra
.68784 .43626 .69344 .44313 .70531 .43941 .69975 .43251 Mtetra
.69975 .43251 .70531 .43941 .71723 .43568 .7117 .42875 Mtetra
.7117 .42875 .71723 .43568 .7292 .43193 .7237 .42497 Mtetra
.7237 .42497 .7292 .43193 .74122 .42817 .73576 .42118 Mtetra
.73576 .42118 .74122 .42817 .75329 .42439 .74786 .41737 Mtetra
.74786 .41737 .75329 .42439 .76541 .4206 .76002 .41355 Mtetra
.76002 .41355 .76541 .4206 .77758 .41679 .77223 .40971 Mtetra
.77223 .40971 .77758 .41679 .7898 .41296 .78449 .40585 Mtetra
.78449 .40585 .7898 .41296 .80208 .40912 .79681 .40198 Mtetra
.79681 .40198 .80208 .40912 .81441 .40526 .80917 .39809 Mtetra
.80917 .39809 .81441 .40526 .82679 .40138 .82159 .39418 Mtetra
.82159 .39418 .82679 .40138 .83923 .39749 .83406 .39025 Mtetra
.83406 .39025 .83923 .39749 .85171 .39358 .84659 .38631 Mtetra
.84659 .38631 .85171 .39358 .86426 .38965 .85917 .38236 Mtetra
.85917 .38236 .86426 .38965 .87685 .38571 .87181 .37838 Mtetra
.87181 .37838 .87685 .38571 .8895 .38175 .8845 .37439 Mtetra
.8845 .37439 .8895 .38175 .90221 .37777 .89724 .37038 Mtetra
.89724 .37038 .90221 .37777 .91497 .37377 .91004 .36635 Mtetra
.91004 .36635 .91497 .37377 .92778 .36976 .9229 .36231 Mtetra
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53508 .36722 .52891 Mtetra
.36722 .52891 .3737 .53508 .38431 .53174 .37786 .52554 Mtetra
.37786 .52554 .38431 .53174 .39497 .52839 .38855 .52216 Mtetra
.38855 .52216 .39497 .52839 .40568 .52502 .39928 .51877 Mtetra
.39928 .51877 .40568 .52502 .41642 .52164 .41005 .51537 Mtetra
.41005 .51537 .41642 .52164 .42721 .51825 .42087 .51195 Mtetra
.42087 .51195 .42721 .51825 .43804 .51484 .43173 .50851 Mtetra
.43173 .50851 .43804 .51484 .44892 .51142 .44263 .50507 Mtetra
.44263 .50507 .44892 .51142 .45984 .50798 .45358 .50161 Mtetra
.45358 .50161 .45984 .50798 .4708 .50453 .46457 .49813 Mtetra
.46457 .49813 .4708 .50453 .48181 .50107 .4756 .49464 Mtetra
.4756 .49464 .48181 .50107 .49286 .49759 .48668 .49114 Mtetra
.48668 .49114 .49286 .49759 .50396 .4941 .49781 .48762 Mtetra
.49781 .48762 .50396 .4941 .5151 .4906 .50898 .48409 Mtetra
.50898 .48409 .5151 .4906 .52629 .48708 .5202 .48054 Mtetra
.5202 .48054 .52629 .48708 .53752 .48355 .53146 .47698 Mtetra
.53146 .47698 .53752 .48355 .5488 .48 .54277 .47341 Mtetra
.54277 .47341 .5488 .48 .56013 .47643 .55413 .46982 Mtetra
.55413 .46982 .56013 .47643 .5715 .47286 .56553 .46621 Mtetra
.56553 .46621 .5715 .47286 .58292 .46926 .57698 .46259 Mtetra
.57698 .46259 .58292 .46926 .59438 .46566 .58848 .45896 Mtetra
.58848 .45896 .59438 .46566 .6059 .46203 .60002 .45531 Mtetra
.60002 .45531 .6059 .46203 .61746 .4584 .61162 .45164 Mtetra
.61162 .45164 .61746 .4584 .62907 .45475 .62326 .44796 Mtetra
.62326 .44796 .62907 .45475 .64072 .45108 .63495 .44427 Mtetra
.63495 .44427 .64072 .45108 .65243 .4474 .64669 .44056 Mtetra
.64669 .44056 .65243 .4474 .66418 .4437 .65848 .43683 Mtetra
.65848 .43683 .66418 .4437 .67599 .43998 .67031 .43309 Mtetra
.67031 .43309 .67599 .43998 .68784 .43626 .6822 .42933 Mtetra
.6822 .42933 .68784 .43626 .69975 .43251 .69414 .42556 Mtetra
.69414 .42556 .69975 .43251 .7117 .42875 .70613 .42177 Mtetra
.70613 .42177 .7117 .42875 .7237 .42497 .71817 .41796 Mtetra
.71817 .41796 .7237 .42497 .73576 .42118 .73026 .41414 Mtetra
.73026 .41414 .73576 .42118 .74786 .41737 .7424 .4103 Mtetra
.7424 .4103 .74786 .41737 .76002 .41355 .75459 .40644 Mtetra
.75459 .40644 .76002 .41355 .77223 .40971 .76684 .40257 Mtetra
.76684 .40257 .77223 .40971 .78449 .40585 .77914 .39869 Mtetra
.77914 .39869 .78449 .40585 .79681 .40198 .79149 .39478 Mtetra
.79149 .39478 .79681 .40198 .80917 .39809 .80389 .39086 Mtetra
.80389 .39086 .80917 .39809 .82159 .39418 .81635 .38692 Mtetra
.81635 .38692 .82159 .39418 .83406 .39025 .82886 .38297 Mtetra
.82886 .38297 .83406 .39025 .84659 .38631 .84143 .37899 Mtetra
.84143 .37899 .84659 .38631 .85917 .38236 .85405 .375 Mtetra
.85405 .375 .85917 .38236 .87181 .37838 .86672 .371 Mtetra
.86672 .371 .87181 .37838 .8845 .37439 .87945 .36697 Mtetra
.87945 .36697 .8845 .37439 .89724 .37038 .89224 .36293 Mtetra
.89224 .36293 .89724 .37038 .91004 .36635 .90508 .35887 Mtetra
.90508 .35887 .91004 .36635 .9229 .36231 .91798 .35479 Mtetra
0 0 .08 r
.32506 .59908 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.664 .741 .908 r
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52268 Mtetra
.36069 .52268 .36722 .52891 .37786 .52554 .37136 .51929 Mtetra
.37136 .51929 .37786 .52554 .38855 .52216 .38207 .51589 Mtetra
.38207 .51589 .38855 .52216 .39928 .51877 .39283 .51247 Mtetra
.39283 .51247 .39928 .51877 .41005 .51537 .40363 .50904 Mtetra
.40363 .50904 .41005 .51537 .42087 .51195 .41447 .5056 Mtetra
.41447 .5056 .42087 .51195 .43173 .50851 .42536 .50214 Mtetra
.42536 .50214 .43173 .50851 .44263 .50507 .43629 .49867 Mtetra
.43629 .49867 .44263 .50507 .45358 .50161 .44727 .49518 Mtetra
.44727 .49518 .45358 .50161 .46457 .49813 .45829 .49168 Mtetra
.45829 .49168 .46457 .49813 .4756 .49464 .46935 .48816 Mtetra
.46935 .48816 .4756 .49464 .48668 .49114 .48046 .48463 Mtetra
.48046 .48463 .48668 .49114 .49781 .48762 .49162 .48109 Mtetra
.49162 .48109 .49781 .48762 .50898 .48409 .50282 .47753 Mtetra
.50282 .47753 .50898 .48409 .5202 .48054 .51406 .47396 Mtetra
.51406 .47396 .5202 .48054 .53146 .47698 .52536 .47037 Mtetra
.52536 .47037 .53146 .47698 .54277 .47341 .5367 .46677 Mtetra
.5367 .46677 .54277 .47341 .55413 .46982 .54809 .46315 Mtetra
.54809 .46315 .55413 .46982 .56553 .46621 .55952 .45952 Mtetra
.55952 .45952 .56553 .46621 .57698 .46259 .571 .45587 Mtetra
.571 .45587 .57698 .46259 .58848 .45896 .58253 .45221 Mtetra
.58253 .45221 .58848 .45896 .60002 .45531 .59411 .44853 Mtetra
.59411 .44853 .60002 .45531 .61162 .45164 .60573 .44484 Mtetra
.60573 .44484 .61162 .45164 .62326 .44796 .61741 .44113 Mtetra
.61741 .44113 .62326 .44796 .63495 .44427 .62913 .4374 Mtetra
.62913 .4374 .63495 .44427 .64669 .44056 .6409 .43366 Mtetra
.6409 .43366 .64669 .44056 .65848 .43683 .65272 .42991 Mtetra
.65272 .42991 .65848 .43683 .67031 .43309 .6646 .42614 Mtetra
.6646 .42614 .67031 .43309 .6822 .42933 .67652 .42235 Mtetra
.67652 .42235 .6822 .42933 .69414 .42556 .68849 .41855 Mtetra
.68849 .41855 .69414 .42556 .70613 .42177 .70051 .41473 Mtetra
.70051 .41473 .70613 .42177 .71817 .41796 .71259 .41089 Mtetra
.71259 .41089 .71817 .41796 .73026 .41414 .72471 .40704 Mtetra
.72471 .40704 .73026 .41414 .7424 .4103 .73689 .40317 Mtetra
.73689 .40317 .7424 .4103 .75459 .40644 .74912 .39928 Mtetra
.74912 .39928 .75459 .40644 .76684 .40257 .76141 .39538 Mtetra
.76141 .39538 .76684 .40257 .77914 .39869 .77374 .39146 Mtetra
.77374 .39146 .77914 .39869 .79149 .39478 .78613 .38753 Mtetra
.78613 .38753 .79149 .39478 .80389 .39086 .79857 .38358 Mtetra
.79857 .38358 .80389 .39086 .81635 .38692 .81107 .37961 Mtetra
.81107 .37961 .81635 .38692 .82886 .38297 .82362 .37562 Mtetra
.82362 .37562 .82886 .38297 .84143 .37899 .83622 .37161 Mtetra
.83622 .37161 .84143 .37899 .85405 .375 .84888 .36759 Mtetra
.84888 .36759 .85405 .375 .86672 .371 .8616 .36355 Mtetra
.8616 .36355 .86672 .371 .87945 .36697 .87437 .3595 Mtetra
.87437 .3595 .87945 .36697 .89224 .36293 .88719 .35542 Mtetra
.88719 .35542 .89224 .36293 .90508 .35887 .90008 .35133 Mtetra
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.659 .748 .916 r
.31826 .59301 .32506 .59908 .33948 .52942 .32903 .58971 Mtetra
0 0 .08 r
.32903 .58971 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.664 .741 .908 r
.34346 .51982 .35006 .52606 .36069 .52268 .35411 .51641 Mtetra
.35411 .51641 .36069 .52268 .37136 .51929 .36481 .513 Mtetra
.36481 .513 .37136 .51929 .38207 .51589 .37555 .50957 Mtetra
.37555 .50957 .38207 .51589 .39283 .51247 .38633 .50613 Mtetra
.38633 .50613 .39283 .51247 .40363 .50904 .39716 .50267 Mtetra
.39716 .50267 .40363 .50904 .41447 .5056 .40803 .4992 Mtetra
.40803 .4992 .41447 .5056 .42536 .50214 .41895 .49572 Mtetra
.41895 .49572 .42536 .50214 .43629 .49867 .42991 .49222 Mtetra
.42991 .49222 .43629 .49867 .44727 .49518 .44091 .48871 Mtetra
.44091 .48871 .44727 .49518 .45829 .49168 .45196 .48518 Mtetra
.45196 .48518 .45829 .49168 .46935 .48816 .46305 .48164 Mtetra
.46305 .48164 .46935 .48816 .48046 .48463 .47419 .47808 Mtetra
.47419 .47808 .48046 .48463 .49162 .48109 .48538 .47451 Mtetra
.48538 .47451 .49162 .48109 .50282 .47753 .49661 .47092 Mtetra
.49661 .47092 .50282 .47753 .51406 .47396 .50788 .46732 Mtetra
.50788 .46732 .51406 .47396 .52536 .47037 .51921 .46371 Mtetra
.51921 .46371 .52536 .47037 .5367 .46677 .53058 .46008 Mtetra
.53058 .46008 .5367 .46677 .54809 .46315 .542 .45643 Mtetra
.542 .45643 .54809 .46315 .55952 .45952 .55346 .45277 Mtetra
.55346 .45277 .55952 .45952 .571 .45587 .56497 .4491 Mtetra
.56497 .4491 .571 .45587 .58253 .45221 .57654 .44541 Mtetra
.57654 .44541 .58253 .45221 .59411 .44853 .58814 .4417 Mtetra
.58814 .4417 .59411 .44853 .60573 .44484 .5998 .43798 Mtetra
.5998 .43798 .60573 .44484 .61741 .44113 .61151 .43424 Mtetra
.61151 .43424 .61741 .44113 .62913 .4374 .62327 .43049 Mtetra
.62327 .43049 .62913 .4374 .6409 .43366 .63507 .42672 Mtetra
.63507 .42672 .6409 .43366 .65272 .42991 .64693 .42293 Mtetra
.64693 .42293 .65272 .42991 .6646 .42614 .65883 .41913 Mtetra
.65883 .41913 .6646 .42614 .67652 .42235 .67079 .41532 Mtetra
.67079 .41532 .67652 .42235 .68849 .41855 .6828 .41148 Mtetra
.6828 .41148 .68849 .41855 .70051 .41473 .69486 .40763 Mtetra
.69486 .40763 .70051 .41473 .71259 .41089 .70697 .40377 Mtetra
.70697 .40377 .71259 .41089 .72471 .40704 .71913 .39988 Mtetra
.71913 .39988 .72471 .40704 .73689 .40317 .73134 .39598 Mtetra
.73134 .39598 .73689 .40317 .74912 .39928 .74361 .39207 Mtetra
.74361 .39207 .74912 .39928 .76141 .39538 .75593 .38814 Mtetra
.75593 .38814 .76141 .39538 .77374 .39146 .7683 .38419 Mtetra
.7683 .38419 .77374 .39146 .78613 .38753 .78073 .38022 Mtetra
.78073 .38022 .78613 .38753 .79857 .38358 .79321 .37623 Mtetra
.79321 .37623 .79857 .38358 .81107 .37961 .80574 .37223 Mtetra
.80574 .37223 .81107 .37961 .82362 .37562 .81833 .36821 Mtetra
.81833 .36821 .82362 .37562 .83622 .37161 .83097 .36418 Mtetra
.83097 .36418 .83622 .37161 .84888 .36759 .84367 .36012 Mtetra
.84367 .36012 .84888 .36759 .8616 .36355 .85643 .35605 Mtetra
.85643 .35605 .8616 .36355 .87437 .3595 .86924 .35196 Mtetra
.86924 .35196 .87437 .3595 .88719 .35542 .88211 .34785 Mtetra
.88211 .34785 .88719 .35542 .90008 .35133 .89503 .34373 Mtetra
.89503 .34373 .90008 .35133 .91302 .34722 .90801 .33958 Mtetra
.659 .748 .916 r
.31141 .5869 .31826 .59301 .32903 .58971 .32221 .58357 Mtetra
.32221 .58357 .32903 .58971 .34346 .51982 .33305 .58022 Mtetra
.529 .278 .479 r
.33305 .58022 .34346 .51982 .35411 .51641 .34394 .57687 Mtetra
0 0 .089 r
.34394 .57687 .35411 .51641 .36481 .513 .35821 .50666 Mtetra
.664 .741 .908 r
.35821 .50666 .36481 .513 .37555 .50957 .36898 .5032 Mtetra
.36898 .5032 .37555 .50957 .38633 .50613 .37979 .49974 Mtetra
.37979 .49974 .38633 .50613 .39716 .50267 .39065 .49625 Mtetra
.39065 .49625 .39716 .50267 .40803 .4992 .40154 .49276 Mtetra
.40154 .49276 .40803 .4992 .41895 .49572 .41249 .48925 Mtetra
.41249 .48925 .41895 .49572 .42991 .49222 .42347 .48572 Mtetra
.42347 .48572 .42991 .49222 .44091 .48871 .4345 .48218 Mtetra
.4345 .48218 .44091 .48871 .45196 .48518 .44558 .47863 Mtetra
.44558 .47863 .45196 .48518 .46305 .48164 .4567 .47506 Mtetra
.4567 .47506 .46305 .48164 .47419 .47808 .46787 .47148 Mtetra
.46787 .47148 .47419 .47808 .48538 .47451 .47909 .46788 Mtetra
.47909 .46788 .48538 .47451 .49661 .47092 .49035 .46427 Mtetra
.49035 .46427 .49661 .47092 .50788 .46732 .50166 .46064 Mtetra
.50166 .46064 .50788 .46732 .51921 .46371 .51301 .45699 Mtetra
.51301 .45699 .51921 .46371 .53058 .46008 .52441 .45334 Mtetra
.52441 .45334 .53058 .46008 .542 .45643 .53586 .44966 Mtetra
.53586 .44966 .542 .45643 .55346 .45277 .54736 .44598 Mtetra
.54736 .44598 .55346 .45277 .56497 .4491 .5589 .44227 Mtetra
.5589 .44227 .56497 .4491 .57654 .44541 .57049 .43855 Mtetra
.57049 .43855 .57654 .44541 .58814 .4417 .58214 .43482 Mtetra
.58214 .43482 .58814 .4417 .5998 .43798 .59383 .43107 Mtetra
.59383 .43107 .5998 .43798 .61151 .43424 .60557 .4273 Mtetra
.60557 .4273 .61151 .43424 .62327 .43049 .61736 .42352 Mtetra
.61736 .42352 .62327 .43049 .63507 .42672 .6292 .41972 Mtetra
.6292 .41972 .63507 .42672 .64693 .42293 .64109 .4159 Mtetra
.64109 .4159 .64693 .42293 .65883 .41913 .65303 .41207 Mtetra
.65303 .41207 .65883 .41913 .67079 .41532 .66502 .40823 Mtetra
.66502 .40823 .67079 .41532 .6828 .41148 .67706 .40436 Mtetra
.67706 .40436 .6828 .41148 .69486 .40763 .68915 .40048 Mtetra
.68915 .40048 .69486 .40763 .70697 .40377 .7013 .39659 Mtetra
.7013 .39659 .70697 .40377 .71913 .39988 .7135 .39267 Mtetra
.7135 .39267 .71913 .39988 .73134 .39598 .72575 .38874 Mtetra
.72575 .38874 .73134 .39598 .74361 .39207 .73805 .38479 Mtetra
.73805 .38479 .74361 .39207 .75593 .38814 .75041 .38083 Mtetra
.75041 .38083 .75593 .38814 .7683 .38419 .76282 .37685 Mtetra
.76282 .37685 .7683 .38419 .78073 .38022 .77528 .37285 Mtetra
.77528 .37285 .78073 .38022 .79321 .37623 .7878 .36883 Mtetra
.7878 .36883 .79321 .37623 .80574 .37223 .80037 .3648 Mtetra
.80037 .3648 .80574 .37223 .81833 .36821 .813 .36075 Mtetra
.813 .36075 .81833 .36821 .83097 .36418 .82568 .35668 Mtetra
.82568 .35668 .83097 .36418 .84367 .36012 .83842 .35259 Mtetra
.83842 .35259 .84367 .36012 .85643 .35605 .85122 .34849 Mtetra
.85122 .34849 .85643 .35605 .86924 .35196 .86407 .34436 Mtetra
.86407 .34436 .86924 .35196 .88211 .34785 .87698 .34022 Mtetra
.87698 .34022 .88211 .34785 .89503 .34373 .88994 .33606 Mtetra
.88994 .33606 .89503 .34373 .90801 .33958 .90297 .33188 Mtetra
.659 .748 .916 r
.30451 .58074 .31141 .5869 .32221 .58357 .31533 .57738 Mtetra
.31533 .57738 .32221 .58357 .33305 .58022 .3262 .57401 Mtetra
.3262 .57401 .33305 .58022 .34394 .57687 .33712 .57063 Mtetra
.33712 .57063 .34394 .57687 .35821 .50666 .34807 .56723 Mtetra
0 0 .089 r
.34807 .56723 .35821 .50666 .36898 .5032 .36236 .49679 Mtetra
.664 .741 .908 r
.36236 .49679 .36898 .5032 .37979 .49974 .3732 .4933 Mtetra
.3732 .4933 .37979 .49974 .39065 .49625 .38408 .48979 Mtetra
.38408 .48979 .39065 .49625 .40154 .49276 .39501 .48626 Mtetra
.39501 .48626 .40154 .49276 .41249 .48925 .40598 .48273 Mtetra
.40598 .48273 .41249 .48925 .42347 .48572 .41699 .47918 Mtetra
.41699 .47918 .42347 .48572 .4345 .48218 .42805 .47561 Mtetra
.42805 .47561 .4345 .48218 .44558 .47863 .43916 .47203 Mtetra
.43916 .47203 .44558 .47863 .4567 .47506 .45031 .46843 Mtetra
.45031 .46843 .4567 .47506 .46787 .47148 .46151 .46482 Mtetra
.46151 .46482 .46787 .47148 .47909 .46788 .47275 .4612 Mtetra
.47275 .4612 .47909 .46788 .49035 .46427 .48404 .45756 Mtetra
.48404 .45756 .49035 .46427 .50166 .46064 .49538 .4539 Mtetra
.49538 .4539 .50166 .46064 .51301 .45699 .50676 .45023 Mtetra
.50676 .45023 .51301 .45699 .52441 .45334 .5182 .44654 Mtetra
.5182 .44654 .52441 .45334 .53586 .44966 .52968 .44284 Mtetra
.52968 .44284 .53586 .44966 .54736 .44598 .5412 .43913 Mtetra
.5412 .43913 .54736 .44598 .5589 .44227 .55278 .43539 Mtetra
.55278 .43539 .5589 .44227 .57049 .43855 .56441 .43164 Mtetra
.56441 .43164 .57049 .43855 .58214 .43482 .57608 .42788 Mtetra
.57608 .42788 .58214 .43482 .59383 .43107 .5878 .4241 Mtetra
.5878 .4241 .59383 .43107 .60557 .4273 .59958 .4203 Mtetra
.59958 .4203 .60557 .4273 .61736 .42352 .6114 .41649 Mtetra
.6114 .41649 .61736 .42352 .6292 .41972 .62327 .41266 Mtetra
.62327 .41266 .6292 .41972 .64109 .4159 .6352 .40882 Mtetra
.6352 .40882 .64109 .4159 .65303 .41207 .64717 .40496 Mtetra
.64717 .40496 .65303 .41207 .66502 .40823 .6592 .40108 Mtetra
.6592 .40108 .66502 .40823 .67706 .40436 .67128 .39719 Mtetra
.67128 .39719 .67706 .40436 .68915 .40048 .6834 .39327 Mtetra
.6834 .39327 .68915 .40048 .7013 .39659 .69559 .38935 Mtetra
.69559 .38935 .7013 .39659 .7135 .39267 .70782 .3854 Mtetra
.70782 .3854 .7135 .39267 .72575 .38874 .72011 .38144 Mtetra
.72011 .38144 .72575 .38874 .73805 .38479 .73245 .37746 Mtetra
.73245 .37746 .73805 .38479 .75041 .38083 .74484 .37347 Mtetra
.74484 .37347 .75041 .38083 .76282 .37685 .75729 .36945 Mtetra
.75729 .36945 .76282 .37685 .77528 .37285 .76979 .36542 Mtetra
.76979 .36542 .77528 .37285 .7878 .36883 .78235 .36137 Mtetra
.78235 .36137 .7878 .36883 .80037 .3648 .79496 .35731 Mtetra
.79496 .35731 .80037 .3648 .813 .36075 .80763 .35322 Mtetra
.80763 .35322 .813 .36075 .82568 .35668 .82035 .34912 Mtetra
.82035 .34912 .82568 .35668 .83842 .35259 .83313 .345 Mtetra
.83313 .345 .83842 .35259 .85122 .34849 .84597 .34086 Mtetra
.84597 .34086 .85122 .34849 .86407 .34436 .85886 .3367 Mtetra
.85886 .3367 .86407 .34436 .87698 .34022 .87181 .33253 Mtetra
.87181 .33253 .87698 .34022 .88994 .33606 .88482 .32833 Mtetra
.88482 .32833 .88994 .33606 .90297 .33188 .89788 .32412 Mtetra
.659 .748 .916 r
.29755 .57453 .30451 .58074 .31533 .57738 .30841 .57115 Mtetra
.30841 .57115 .31533 .57738 .3262 .57401 .3193 .56775 Mtetra
.3193 .56775 .3262 .57401 .33712 .57063 .33024 .56434 Mtetra
.33024 .56434 .33712 .57063 .34807 .56723 .34123 .56092 Mtetra
.34123 .56092 .34807 .56723 .36236 .49679 .35226 .55748 Mtetra
0 0 .089 r
.35226 .55748 .36236 .49679 .3732 .4933 .36656 .48681 Mtetra
.664 .741 .908 r
.36656 .48681 .3732 .4933 .38408 .48979 .37746 .48327 Mtetra
.37746 .48327 .38408 .48979 .39501 .48626 .38842 .47972 Mtetra
.38842 .47972 .39501 .48626 .40598 .48273 .39942 .47616 Mtetra
.39942 .47616 .40598 .48273 .41699 .47918 .41046 .47258 Mtetra
.41046 .47258 .41699 .47918 .42805 .47561 .42155 .46899 Mtetra
.42155 .46899 .42805 .47561 .43916 .47203 .43268 .46538 Mtetra
.43268 .46538 .43916 .47203 .45031 .46843 .44386 .46176 Mtetra
.44386 .46176 .45031 .46843 .46151 .46482 .45509 .45812 Mtetra
.45509 .45812 .46151 .46482 .47275 .4612 .46637 .45446 Mtetra
.46637 .45446 .47275 .4612 .48404 .45756 .47769 .4508 Mtetra
.47769 .4508 .48404 .45756 .49538 .4539 .48905 .44711 Mtetra
.48905 .44711 .49538 .4539 .50676 .45023 .50047 .44341 Mtetra
.50047 .44341 .50676 .45023 .5182 .44654 .51193 .4397 Mtetra
.51193 .4397 .5182 .44654 .52968 .44284 .52344 .43597 Mtetra
.52344 .43597 .52968 .44284 .5412 .43913 .535 .43222 Mtetra
.535 .43222 .5412 .43913 .55278 .43539 .54661 .42846 Mtetra
.54661 .42846 .55278 .43539 .56441 .43164 .55827 .42468 Mtetra
.55827 .42468 .56441 .43164 .57608 .42788 .56998 .42089 Mtetra
.56998 .42089 .57608 .42788 .5878 .4241 .58173 .41708 Mtetra
.58173 .41708 .5878 .4241 .59958 .4203 .59354 .41325 Mtetra
.59354 .41325 .59958 .4203 .6114 .41649 .6054 .40941 Mtetra
.6054 .40941 .6114 .41649 .62327 .41266 .6173 .40555 Mtetra
.6173 .40555 .62327 .41266 .6352 .40882 .62926 .40168 Mtetra
.62926 .40168 .6352 .40882 .64717 .40496 .64127 .39779 Mtetra
.64127 .39779 .64717 .40496 .6592 .40108 .65333 .39388 Mtetra
.65333 .39388 .6592 .40108 .67128 .39719 .66545 .38995 Mtetra
.66545 .38995 .67128 .39719 .6834 .39327 .67761 .38601 Mtetra
.67761 .38601 .6834 .39327 .69559 .38935 .68983 .38205 Mtetra
.68983 .38205 .69559 .38935 .70782 .3854 .7021 .37807 Mtetra
.7021 .37807 .70782 .3854 .72011 .38144 .71442 .37408 Mtetra
.71442 .37408 .72011 .38144 .73245 .37746 .7268 .37007 Mtetra
.7268 .37007 .73245 .37746 .74484 .37347 .73923 .36604 Mtetra
.73923 .36604 .74484 .37347 .75729 .36945 .75172 .362 Mtetra
.75172 .362 .75729 .36945 .76979 .36542 .76426 .35793 Mtetra
.76426 .35793 .76979 .36542 .78235 .36137 .77685 .35385 Mtetra
.77685 .35385 .78235 .36137 .79496 .35731 .78951 .34975 Mtetra
.78951 .34975 .79496 .35731 .80763 .35322 .80221 .34563 Mtetra
.80221 .34563 .80763 .35322 .82035 .34912 .81498 .3415 Mtetra
.81498 .3415 .82035 .34912 .83313 .345 .82779 .33734 Mtetra
.82779 .33734 .83313 .345 .84597 .34086 .84067 .33317 Mtetra
.84067 .33317 .84597 .34086 .85886 .3367 .8536 .32898 Mtetra
.8536 .32898 .85886 .3367 .87181 .33253 .8666 .32477 Mtetra
.8666 .32477 .87181 .33253 .88482 .32833 .87965 .32054 Mtetra
.87965 .32054 .88482 .32833 .89788 .32412 .89275 .31629 Mtetra
.659 .748 .916 r
.29055 .56828 .29755 .57453 .30841 .57115 .30143 .56487 Mtetra
.30143 .56487 .30841 .57115 .3193 .56775 .31235 .56145 Mtetra
.31235 .56145 .3193 .56775 .33024 .56434 .32332 .55801 Mtetra
.32332 .55801 .33024 .56434 .34123 .56092 .33433 .55456 Mtetra
.33433 .55456 .34123 .56092 .35226 .55748 .34539 .5511 Mtetra
.34539 .5511 .35226 .55748 .36656 .48681 .3565 .54762 Mtetra
0 0 .089 r
.3565 .54762 .36656 .48681 .37746 .48327 .3708 .47671 Mtetra
.664 .741 .908 r
.3708 .47671 .37746 .48327 .38842 .47972 .38178 .47313 Mtetra
.38178 .47313 .38842 .47972 .39942 .47616 .39281 .46954 Mtetra
.39281 .46954 .39942 .47616 .41046 .47258 .40388 .46593 Mtetra
.40388 .46593 .41046 .47258 .42155 .46899 .415 .46231 Mtetra
.415 .46231 .42155 .46899 .43268 .46538 .42616 .45868 Mtetra
.42616 .45868 .43268 .46538 .44386 .46176 .43737 .45503 Mtetra
.43737 .45503 .44386 .46176 .45509 .45812 .44863 .45136 Mtetra
.44863 .45136 .45509 .45812 .46637 .45446 .45993 .44768 Mtetra
.45993 .44768 .46637 .45446 .47769 .4508 .47128 .44398 Mtetra
.47128 .44398 .47769 .4508 .48905 .44711 .48268 .44027 Mtetra
.48268 .44027 .48905 .44711 .50047 .44341 .49413 .43654 Mtetra
.49413 .43654 .50047 .44341 .51193 .4397 .50562 .4328 Mtetra
.50562 .4328 .51193 .4397 .52344 .43597 .51716 .42904 Mtetra
.51716 .42904 .52344 .43597 .535 .43222 .52876 .42526 Mtetra
.52876 .42526 .535 .43222 .54661 .42846 .5404 .42147 Mtetra
.5404 .42147 .54661 .42846 .55827 .42468 .55209 .41767 Mtetra
.55209 .41767 .55827 .42468 .56998 .42089 .56383 .41384 Mtetra
.56383 .41384 .56998 .42089 .58173 .41708 .57562 .41 Mtetra
.57562 .41 .58173 .41708 .59354 .41325 .58746 .40615 Mtetra
.58746 .40615 .59354 .41325 .6054 .40941 .59935 .40227 Mtetra
.59935 .40227 .6054 .40941 .6173 .40555 .61129 .39839 Mtetra
.61129 .39839 .6173 .40555 .62926 .40168 .62328 .39448 Mtetra
.62328 .39448 .62926 .40168 .64127 .39779 .63532 .39056 Mtetra
.63532 .39056 .64127 .39779 .65333 .39388 .64742 .38662 Mtetra
.64742 .38662 .65333 .39388 .66545 .38995 .65957 .38266 Mtetra
.65957 .38266 .66545 .38995 .67761 .38601 .67177 .37869 Mtetra
.67177 .37869 .67761 .38601 .68983 .38205 .68402 .3747 Mtetra
.68402 .3747 .68983 .38205 .7021 .37807 .69633 .37069 Mtetra
.69633 .37069 .7021 .37807 .71442 .37408 .70869 .36666 Mtetra
.70869 .36666 .71442 .37408 .7268 .37007 .72111 .36262 Mtetra
.72111 .36262 .7268 .37007 .73923 .36604 .73358 .35856 Mtetra
.73358 .35856 .73923 .36604 .75172 .362 .7461 .35448 Mtetra
.7461 .35448 .75172 .362 .76426 .35793 .75868 .35038 Mtetra
.75868 .35038 .76426 .35793 .77685 .35385 .77131 .34627 Mtetra
.77131 .34627 .77685 .35385 .78951 .34975 .78401 .34213 Mtetra
.78401 .34213 .78951 .34975 .80221 .34563 .79675 .33798 Mtetra
.79675 .33798 .80221 .34563 .81498 .3415 .80955 .33381 Mtetra
.80955 .33381 .81498 .3415 .82779 .33734 .82241 .32963 Mtetra
.82241 .32963 .82779 .33734 .84067 .33317 .83533 .32542 Mtetra
.83533 .32542 .84067 .33317 .8536 .32898 .84831 .32119 Mtetra
.84831 .32119 .8536 .32898 .8666 .32477 .86134 .31695 Mtetra
.86134 .31695 .8666 .32477 .87965 .32054 .87443 .31268 Mtetra
.87443 .31268 .87965 .32054 .89275 .31629 .88758 .3084 Mtetra
.659 .748 .916 r
.28349 .56198 .29055 .56828 .30143 .56487 .29439 .55854 Mtetra
.29439 .55854 .30143 .56487 .31235 .56145 .30534 .55509 Mtetra
.30534 .55509 .31235 .56145 .32332 .55801 .31634 .55163 Mtetra
.31634 .55163 .32332 .55801 .33433 .55456 .32738 .54815 Mtetra
.32738 .54815 .33433 .55456 .34539 .5511 .33847 .54466 Mtetra
.33847 .54466 .34539 .5511 .3565 .54762 .3496 .54116 Mtetra
.3496 .54116 .3565 .54762 .3708 .47671 .36079 .53764 Mtetra
0 0 .089 r
.36079 .53764 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.664 .741 .908 r
.37509 .46649 .38178 .47313 .39281 .46954 .38615 .46287 Mtetra
.38615 .46287 .39281 .46954 .40388 .46593 .39725 .45924 Mtetra
.39725 .45924 .40388 .46593 .415 .46231 .4084 .45559 Mtetra
.4084 .45559 .415 .46231 .42616 .45868 .41959 .45193 Mtetra
.41959 .45193 .42616 .45868 .43737 .45503 .43083 .44825 Mtetra
.43083 .44825 .43737 .45503 .44863 .45136 .44211 .44455 Mtetra
.44211 .44455 .44863 .45136 .45993 .44768 .45345 .44084 Mtetra
.45345 .44084 .45993 .44768 .47128 .44398 .46483 .43712 Mtetra
.46483 .43712 .47128 .44398 .48268 .44027 .47626 .43338 Mtetra
.47626 .43338 .48268 .44027 .49413 .43654 .48774 .42962 Mtetra
.48774 .42962 .49413 .43654 .50562 .4328 .49926 .42585 Mtetra
.49926 .42585 .50562 .4328 .51716 .42904 .51084 .42206 Mtetra
.51084 .42206 .51716 .42904 .52876 .42526 .52246 .41825 Mtetra
.52246 .41825 .52876 .42526 .5404 .42147 .53413 .41443 Mtetra
.53413 .41443 .5404 .42147 .55209 .41767 .54585 .4106 Mtetra
.54585 .4106 .55209 .41767 .56383 .41384 .55763 .40674 Mtetra
.55763 .40674 .56383 .41384 .57562 .41 .56945 .40287 Mtetra
.56945 .40287 .57562 .41 .58746 .40615 .58132 .39899 Mtetra
.58132 .39899 .58746 .40615 .59935 .40227 .59325 .39508 Mtetra
.59325 .39508 .59935 .40227 .61129 .39839 .60522 .39116 Mtetra
.60522 .39116 .61129 .39839 .62328 .39448 .61725 .38723 Mtetra
.61725 .38723 .62328 .39448 .63532 .39056 .62933 .38327 Mtetra
.62933 .38327 .63532 .39056 .64742 .38662 .64146 .3793 Mtetra
.64146 .3793 .64742 .38662 .65957 .38266 .65365 .37531 Mtetra
.65365 .37531 .65957 .38266 .67177 .37869 .66588 .37131 Mtetra
.66588 .37131 .67177 .37869 .68402 .3747 .67817 .36728 Mtetra
.67817 .36728 .68402 .3747 .69633 .37069 .69052 .36324 Mtetra
.69052 .36324 .69633 .37069 .70869 .36666 .70292 .35918 Mtetra
.70292 .35918 .70869 .36666 .72111 .36262 .71537 .35511 Mtetra
.71537 .35511 .72111 .36262 .73358 .35856 .72788 .35101 Mtetra
.72788 .35101 .73358 .35856 .7461 .35448 .74044 .3469 Mtetra
.74044 .3469 .7461 .35448 .75868 .35038 .75306 .34277 Mtetra
.75306 .34277 .75868 .35038 .77131 .34627 .76573 .33862 Mtetra
.76573 .33862 .77131 .34627 .78401 .34213 .77846 .33446 Mtetra
.77846 .33446 .78401 .34213 .79675 .33798 .79125 .33027 Mtetra
.79125 .33027 .79675 .33798 .80955 .33381 .80409 .32607 Mtetra
.80409 .32607 .80955 .33381 .82241 .32963 .81699 .32184 Mtetra
.81699 .32184 .82241 .32963 .83533 .32542 .82995 .3176 Mtetra
.82995 .3176 .83533 .32542 .84831 .32119 .84297 .31334 Mtetra
.84297 .31334 .84831 .32119 .86134 .31695 .85604 .30906 Mtetra
.85604 .30906 .86134 .31695 .87443 .31268 .86918 .30476 Mtetra
.86918 .30476 .87443 .31268 .88758 .3084 .88237 .30044 Mtetra
.659 .748 .916 r
.27637 .55562 .28349 .56198 .29439 .55854 .2873 .55216 Mtetra
.2873 .55216 .29439 .55854 .30534 .55509 .29828 .54869 Mtetra
.29828 .54869 .30534 .55509 .31634 .55163 .30931 .5452 Mtetra
.30931 .5452 .31634 .55163 .32738 .54815 .32038 .5417 Mtetra
.32038 .5417 .32738 .54815 .33847 .54466 .33149 .53818 Mtetra
.33149 .53818 .33847 .54466 .3496 .54116 .34266 .53465 Mtetra
.34266 .53465 .3496 .54116 .36079 .53764 .35387 .5311 Mtetra
.35387 .5311 .36079 .53764 .37509 .46649 .36512 .52753 Mtetra
0 0 .089 r
.36512 .52753 .37509 .46649 .38615 .46287 .37944 .45615 Mtetra
.664 .741 .908 r
.37944 .45615 .38615 .46287 .39725 .45924 .39057 .45249 Mtetra
.39057 .45249 .39725 .45924 .4084 .45559 .40174 .44881 Mtetra
.40174 .44881 .4084 .45559 .41959 .45193 .41296 .44512 Mtetra
.41296 .44512 .41959 .45193 .43083 .44825 .42423 .44141 Mtetra
.42423 .44141 .43083 .44825 .44211 .44455 .43555 .43769 Mtetra
.43555 .43769 .44211 .44455 .45345 .44084 .44691 .43395 Mtetra
.44691 .43395 .45345 .44084 .46483 .43712 .45833 .4302 Mtetra
.45833 .4302 .46483 .43712 .47626 .43338 .46979 .42643 Mtetra
.46979 .42643 .47626 .43338 .48774 .42962 .48129 .42264 Mtetra
.48129 .42264 .48774 .42962 .49926 .42585 .49285 .41884 Mtetra
.49285 .41884 .49926 .42585 .51084 .42206 .50446 .41502 Mtetra
.50446 .41502 .51084 .42206 .52246 .41825 .51611 .41119 Mtetra
.51611 .41119 .52246 .41825 .53413 .41443 .52782 .40734 Mtetra
.52782 .40734 .53413 .41443 .54585 .4106 .53957 .40347 Mtetra
.53957 .40347 .54585 .4106 .55763 .40674 .55138 .39958 Mtetra
.55138 .39958 .55763 .40674 .56945 .40287 .56323 .39568 Mtetra
.56323 .39568 .56945 .40287 .58132 .39899 .57514 .39177 Mtetra
.57514 .39177 .58132 .39899 .59325 .39508 .5871 .38783 Mtetra
.5871 .38783 .59325 .39508 .60522 .39116 .59911 .38388 Mtetra
.59911 .38388 .60522 .39116 .61725 .38723 .61117 .37991 Mtetra
.61117 .37991 .61725 .38723 .62933 .38327 .62329 .37593 Mtetra
.62329 .37593 .62933 .38327 .64146 .3793 .63545 .37192 Mtetra
.63545 .37192 .64146 .3793 .65365 .37531 .64767 .3679 Mtetra
.64767 .3679 .65365 .37531 .66588 .37131 .65995 .36387 Mtetra
.65995 .36387 .66588 .37131 .67817 .36728 .67228 .35981 Mtetra
.67228 .35981 .67817 .36728 .69052 .36324 .68466 .35574 Mtetra
.68466 .35574 .69052 .36324 .70292 .35918 .69709 .35165 Mtetra
.69709 .35165 .70292 .35918 .71537 .35511 .70958 .34754 Mtetra
.70958 .34754 .71537 .35511 .72788 .35101 .72213 .34341 Mtetra
.72213 .34341 .72788 .35101 .74044 .3469 .73473 .33926 Mtetra
.73473 .33926 .74044 .3469 .75306 .34277 .74739 .3351 Mtetra
.74739 .3351 .75306 .34277 .76573 .33862 .7601 .33092 Mtetra
.7601 .33092 .76573 .33862 .77846 .33446 .77287 .32671 Mtetra
.77287 .32671 .77846 .33446 .79125 .33027 .7857 .32249 Mtetra
.7857 .32249 .79125 .33027 .80409 .32607 .79858 .31826 Mtetra
.79858 .31826 .80409 .32607 .81699 .32184 .81152 .314 Mtetra
.81152 .314 .81699 .32184 .82995 .3176 .82452 .30972 Mtetra
.82452 .30972 .82995 .3176 .84297 .31334 .83758 .30543 Mtetra
.83758 .30543 .84297 .31334 .85604 .30906 .8507 .30111 Mtetra
.8507 .30111 .85604 .30906 .86918 .30476 .86387 .29677 Mtetra
.86387 .29677 .86918 .30476 .88237 .30044 .87711 .29242 Mtetra
.659 .748 .916 r
.2692 .54923 .27637 .55562 .2873 .55216 .28016 .54574 Mtetra
.28016 .54574 .2873 .55216 .29828 .54869 .29117 .54224 Mtetra
.29117 .54224 .29828 .54869 .30931 .5452 .30222 .53872 Mtetra
.30222 .53872 .30931 .5452 .32038 .5417 .31332 .53519 Mtetra
.31332 .53519 .32038 .5417 .33149 .53818 .32446 .53164 Mtetra
.32446 .53164 .33149 .53818 .34266 .53465 .33565 .52808 Mtetra
.33565 .52808 .34266 .53465 .35387 .5311 .34689 .52451 Mtetra
.34689 .52451 .35387 .5311 .36512 .52753 .35818 .52092 Mtetra
.35818 .52092 .36512 .52753 .37944 .45615 .36952 .51731 Mtetra
0 0 .089 r
.36952 .51731 .37944 .45615 .39057 .45249 .38383 .44569 Mtetra
.664 .741 .908 r
.38383 .44569 .39057 .45249 .40174 .44881 .39504 .44199 Mtetra
.39504 .44199 .40174 .44881 .41296 .44512 .40629 .43827 Mtetra
.40629 .43827 .41296 .44512 .42423 .44141 .41759 .43453 Mtetra
.41759 .43453 .42423 .44141 .43555 .43769 .42893 .43078 Mtetra
.42893 .43078 .43555 .43769 .44691 .43395 .44033 .42701 Mtetra
.44033 .42701 .44691 .43395 .45833 .4302 .45177 .42323 Mtetra
.45177 .42323 .45833 .4302 .46979 .42643 .46326 .41943 Mtetra
.46326 .41943 .46979 .42643 .48129 .42264 .4748 .41561 Mtetra
.4748 .41561 .48129 .42264 .49285 .41884 .48639 .41178 Mtetra
.48639 .41178 .49285 .41884 .50446 .41502 .49803 .40793 Mtetra
.49803 .40793 .50446 .41502 .51611 .41119 .50972 .40406 Mtetra
.50972 .40406 .51611 .41119 .52782 .40734 .52145 .40018 Mtetra
.52145 .40018 .52782 .40734 .53957 .40347 .53324 .39628 Mtetra
.53324 .39628 .53957 .40347 .55138 .39958 .54508 .39237 Mtetra
.54508 .39237 .55138 .39958 .56323 .39568 .55697 .38844 Mtetra
.55697 .38844 .56323 .39568 .57514 .39177 .56891 .38449 Mtetra
.56891 .38449 .57514 .39177 .5871 .38783 .5809 .38052 Mtetra
.5809 .38052 .5871 .38783 .59911 .38388 .59295 .37654 Mtetra
.59295 .37654 .59911 .38388 .61117 .37991 .60505 .37254 Mtetra
.60505 .37254 .61117 .37991 .62329 .37593 .6172 .36852 Mtetra
.6172 .36852 .62329 .37593 .63545 .37192 .6294 .36449 Mtetra
.6294 .36449 .63545 .37192 .64767 .3679 .64166 .36043 Mtetra
.64166 .36043 .64767 .3679 .65995 .36387 .65397 .35636 Mtetra
.65397 .35636 .65995 .36387 .67228 .35981 .66633 .35228 Mtetra
.66633 .35228 .67228 .35981 .68466 .35574 .67875 .34817 Mtetra
.67875 .34817 .68466 .35574 .69709 .35165 .69122 .34404 Mtetra
.69122 .34404 .69709 .35165 .70958 .34754 .70375 .3399 Mtetra
.70375 .3399 .70958 .34754 .72213 .34341 .71633 .33574 Mtetra
.71633 .33574 .72213 .34341 .73473 .33926 .72897 .33156 Mtetra
.72897 .33156 .73473 .33926 .74739 .3351 .74167 .32736 Mtetra
.74167 .32736 .74739 .3351 .7601 .33092 .75442 .32315 Mtetra
.75442 .32315 .7601 .33092 .77287 .32671 .76723 .31891 Mtetra
.76723 .31891 .77287 .32671 .7857 .32249 .7801 .31465 Mtetra
.7801 .31465 .7857 .32249 .79858 .31826 .79302 .31038 Mtetra
.79302 .31038 .79858 .31826 .81152 .314 .80601 .30609 Mtetra
.80601 .30609 .81152 .314 .82452 .30972 .81905 .30177 Mtetra
.81905 .30177 .82452 .30972 .83758 .30543 .83215 .29744 Mtetra
.83215 .29744 .83758 .30543 .8507 .30111 .84531 .29309 Mtetra
.84531 .29309 .8507 .30111 .86387 .29677 .85853 .28872 Mtetra
.85853 .28872 .86387 .29677 .87711 .29242 .87181 .28433 Mtetra
.659 .748 .916 r
.26198 .54278 .2692 .54923 .28016 .54574 .27296 .53926 Mtetra
.27296 .53926 .28016 .54574 .29117 .54224 .284 .53573 Mtetra
.284 .53573 .29117 .54224 .30222 .53872 .29508 .53219 Mtetra
.29508 .53219 .30222 .53872 .31332 .53519 .3062 .52863 Mtetra
.3062 .52863 .31332 .53519 .32446 .53164 .31738 .52506 Mtetra
.31738 .52506 .32446 .53164 .33565 .52808 .3286 .52147 Mtetra
.3286 .52147 .33565 .52808 .34689 .52451 .33987 .51787 Mtetra
.33987 .51787 .34689 .52451 .35818 .52092 .35118 .51425 Mtetra
.35118 .51425 .35818 .52092 .36952 .51731 .36255 .51061 Mtetra
.36255 .51061 .36952 .51731 .38383 .44569 .37396 .50696 Mtetra
0 0 .089 r
.37396 .50696 .38383 .44569 .39504 .44199 .38828 .4351 Mtetra
.664 .741 .908 r
.38828 .4351 .39504 .44199 .40629 .43827 .39956 .43136 Mtetra
.39956 .43136 .40629 .43827 .41759 .43453 .41089 .42759 Mtetra
.41089 .42759 .41759 .43453 .42893 .43078 .42227 .42381 Mtetra
.42227 .42381 .42893 .43078 .44033 .42701 .43369 .42001 Mtetra
.43369 .42001 .44033 .42701 .45177 .42323 .44517 .4162 Mtetra
.44517 .4162 .45177 .42323 .46326 .41943 .45669 .41237 Mtetra
.45669 .41237 .46326 .41943 .4748 .41561 .46826 .40852 Mtetra
.46826 .40852 .4748 .41561 .48639 .41178 .47988 .40466 Mtetra
.47988 .40466 .48639 .41178 .49803 .40793 .49155 .40078 Mtetra
.49155 .40078 .49803 .40793 .50972 .40406 .50327 .39689 Mtetra
.50327 .39689 .50972 .40406 .52145 .40018 .51504 .39297 Mtetra
.51504 .39297 .52145 .40018 .53324 .39628 .52686 .38904 Mtetra
.52686 .38904 .53324 .39628 .54508 .39237 .53873 .3851 Mtetra
.53873 .3851 .54508 .39237 .55697 .38844 .55066 .38114 Mtetra
.55066 .38114 .55697 .38844 .56891 .38449 .56263 .37715 Mtetra
.56263 .37715 .56891 .38449 .5809 .38052 .57466 .37316 Mtetra
.57466 .37316 .5809 .38052 .59295 .37654 .58674 .36914 Mtetra
.58674 .36914 .59295 .37654 .60505 .37254 .59887 .36511 Mtetra
.59887 .36511 .60505 .37254 .6172 .36852 .61106 .36106 Mtetra
.61106 .36106 .6172 .36852 .6294 .36449 .62329 .35699 Mtetra
.62329 .35699 .6294 .36449 .64166 .36043 .63559 .35291 Mtetra
.63559 .35291 .64166 .36043 .65397 .35636 .64793 .3488 Mtetra
.64793 .3488 .65397 .35636 .66633 .35228 .66033 .34468 Mtetra
.66033 .34468 .66633 .35228 .67875 .34817 .67279 .34054 Mtetra
.67279 .34054 .67875 .34817 .69122 .34404 .6853 .33638 Mtetra
.6853 .33638 .69122 .34404 .70375 .3399 .69787 .3322 Mtetra
.69787 .3322 .70375 .3399 .71633 .33574 .71049 .32801 Mtetra
.71049 .32801 .71633 .33574 .72897 .33156 .72317 .3238 Mtetra
.72317 .3238 .72897 .33156 .74167 .32736 .73591 .31956 Mtetra
.73591 .31956 .74167 .32736 .75442 .32315 .7487 .31531 Mtetra
.7487 .31531 .75442 .32315 .76723 .31891 .76155 .31104 Mtetra
.76155 .31104 .76723 .31891 .7801 .31465 .77446 .30675 Mtetra
.77446 .30675 .7801 .31465 .79302 .31038 .78742 .30244 Mtetra
.78742 .30244 .79302 .31038 .80601 .30609 .80045 .29811 Mtetra
.80045 .29811 .80601 .30609 .81905 .30177 .81353 .29376 Mtetra
.81353 .29376 .81905 .30177 .83215 .29744 .82667 .28939 Mtetra
.82667 .28939 .83215 .29744 .84531 .29309 .83988 .285 Mtetra
.83988 .285 .84531 .29309 .85853 .28872 .85314 .2806 Mtetra
.85314 .2806 .85853 .28872 .87181 .28433 .86646 .27617 Mtetra
.659 .748 .916 r
.2547 .53628 .26198 .54278 .27296 .53926 .26571 .53274 Mtetra
.26571 .53274 .27296 .53926 .284 .53573 .27677 .52918 Mtetra
.27677 .52918 .284 .53573 .29508 .53219 .28788 .52561 Mtetra
.28788 .52561 .29508 .53219 .3062 .52863 .29903 .52202 Mtetra
.29903 .52202 .3062 .52863 .31738 .52506 .31023 .51842 Mtetra
.31023 .51842 .31738 .52506 .3286 .52147 .32148 .5148 Mtetra
.32148 .5148 .3286 .52147 .33987 .51787 .33278 .51117 Mtetra
.33278 .51117 .33987 .51787 .35118 .51425 .34413 .50752 Mtetra
.34413 .50752 .35118 .51425 .36255 .51061 .35552 .50386 Mtetra
.35552 .50386 .36255 .51061 .37396 .50696 .36697 .50018 Mtetra
.36697 .50018 .37396 .50696 .38828 .4351 .37846 .49648 Mtetra
0 0 .089 r
.37846 .49648 .38828 .4351 .39956 .43136 .39278 .42439 Mtetra
.664 .741 .908 r
.39278 .42439 .39956 .43136 .41089 .42759 .40414 .4206 Mtetra
.40414 .4206 .41089 .42759 .42227 .42381 .41555 .41679 Mtetra
.41555 .41679 .42227 .42381 .43369 .42001 .427 .41296 Mtetra
.427 .41296 .43369 .42001 .44517 .4162 .43851 .40912 Mtetra
.43851 .40912 .44517 .4162 .45669 .41237 .45006 .40526 Mtetra
.45006 .40526 .45669 .41237 .46826 .40852 .46166 .40138 Mtetra
.46166 .40138 .46826 .40852 .47988 .40466 .47332 .39749 Mtetra
.47332 .39749 .47988 .40466 .49155 .40078 .48502 .39358 Mtetra
.48502 .39358 .49155 .40078 .50327 .39689 .49677 .38965 Mtetra
.49677 .38965 .50327 .39689 .51504 .39297 .50857 .38571 Mtetra
.50857 .38571 .51504 .39297 .52686 .38904 .52043 .38175 Mtetra
.52043 .38175 .52686 .38904 .53873 .3851 .53233 .37777 Mtetra
.53233 .37777 .53873 .3851 .55066 .38114 .54429 .37377 Mtetra
.54429 .37377 .55066 .38114 .56263 .37715 .5563 .36976 Mtetra
.5563 .36976 .56263 .37715 .57466 .37316 .56836 .36573 Mtetra
.56836 .36573 .57466 .37316 .58674 .36914 .58048 .36168 Mtetra
.58048 .36168 .58674 .36914 .59887 .36511 .59265 .35762 Mtetra
.59265 .35762 .59887 .36511 .61106 .36106 .60487 .35354 Mtetra
.60487 .35354 .61106 .36106 .62329 .35699 .61714 .34943 Mtetra
.61714 .34943 .62329 .35699 .63559 .35291 .62947 .34532 Mtetra
.62947 .34532 .63559 .35291 .64793 .3488 .64185 .34118 Mtetra
.64185 .34118 .64793 .3488 .66033 .34468 .65429 .33702 Mtetra
.65429 .33702 .66033 .34468 .67279 .34054 .66679 .33285 Mtetra
.66679 .33285 .67279 .34054 .6853 .33638 .67933 .32866 Mtetra
.67933 .32866 .6853 .33638 .69787 .3322 .69194 .32444 Mtetra
.69194 .32444 .69787 .3322 .71049 .32801 .7046 .32021 Mtetra
.7046 .32021 .71049 .32801 .72317 .3238 .71732 .31597 Mtetra
.71732 .31597 .72317 .3238 .73591 .31956 .73009 .3117 Mtetra
.73009 .3117 .73591 .31956 .7487 .31531 .74293 .30741 Mtetra
.74293 .30741 .7487 .31531 .76155 .31104 .75582 .3031 Mtetra
.75582 .3031 .76155 .31104 .77446 .30675 .76877 .29878 Mtetra
.76877 .29878 .77446 .30675 .78742 .30244 .78177 .29443 Mtetra
.78177 .29443 .78742 .30244 .80045 .29811 .79484 .29007 Mtetra
.79484 .29007 .80045 .29811 .81353 .29376 .80797 .28568 Mtetra
.80797 .28568 .81353 .29376 .82667 .28939 .82115 .28128 Mtetra
.82115 .28128 .82667 .28939 .83988 .285 .8344 .27685 Mtetra
.8344 .27685 .83988 .285 .85314 .2806 .8477 .2724 Mtetra
.8477 .2724 .85314 .2806 .86646 .27617 .86107 .26794 Mtetra
.659 .748 .916 r
.24736 .52973 .2547 .53628 .26571 .53274 .2584 .52616 Mtetra
.2584 .52616 .26571 .53274 .27677 .52918 .26949 .52258 Mtetra
.26949 .52258 .27677 .52918 .28788 .52561 .28062 .51898 Mtetra
.28062 .51898 .28788 .52561 .29903 .52202 .29181 .51536 Mtetra
.29181 .51536 .29903 .52202 .31023 .51842 .30304 .51173 Mtetra
.30304 .51173 .31023 .51842 .32148 .5148 .31432 .50809 Mtetra
.31432 .50809 .32148 .5148 .33278 .51117 .32564 .50442 Mtetra
.32564 .50442 .33278 .51117 .34413 .50752 .33702 .50075 Mtetra
.33702 .50075 .34413 .50752 .35552 .50386 .34844 .49705 Mtetra
.34844 .49705 .35552 .50386 .36697 .50018 .35992 .49335 Mtetra
.35992 .49335 .36697 .50018 .37846 .49648 .37144 .48962 Mtetra
.37144 .48962 .37846 .49648 .39278 .42439 .38301 .48588 Mtetra
0 0 .089 r
.38301 .48588 .39278 .42439 .40414 .4206 .39734 .41355 Mtetra
.664 .741 .908 r
.39734 .41355 .40414 .4206 .41555 .41679 .40878 .40971 Mtetra
.40878 .40971 .41555 .41679 .427 .41296 .42026 .40585 Mtetra
.42026 .40585 .427 .41296 .43851 .40912 .4318 .40198 Mtetra
.4318 .40198 .43851 .40912 .45006 .40526 .44338 .39809 Mtetra
.44338 .39809 .45006 .40526 .46166 .40138 .45502 .39418 Mtetra
.45502 .39418 .46166 .40138 .47332 .39749 .4667 .39025 Mtetra
.4667 .39025 .47332 .39749 .48502 .39358 .47843 .38631 Mtetra
.47843 .38631 .48502 .39358 .49677 .38965 .49022 .38236 Mtetra
.49022 .38236 .49677 .38965 .50857 .38571 .50206 .37838 Mtetra
.50206 .37838 .50857 .38571 .52043 .38175 .51394 .37439 Mtetra
.51394 .37439 .52043 .38175 .53233 .37777 .52588 .37038 Mtetra
.52588 .37038 .53233 .37777 .54429 .37377 .53788 .36635 Mtetra
.53788 .36635 .54429 .37377 .5563 .36976 .54992 .36231 Mtetra
.54992 .36231 .5563 .36976 .56836 .36573 .56202 .35825 Mtetra
.56202 .35825 .56836 .36573 .58048 .36168 .57417 .35416 Mtetra
.57417 .35416 .58048 .36168 .59265 .35762 .58637 .35007 Mtetra
.58637 .35007 .59265 .35762 .60487 .35354 .59863 .34595 Mtetra
.59863 .34595 .60487 .35354 .61714 .34943 .61094 .34182 Mtetra
.61094 .34182 .61714 .34943 .62947 .34532 .6233 .33766 Mtetra
.6233 .33766 .62947 .34532 .64185 .34118 .63572 .33349 Mtetra
.63572 .33349 .64185 .34118 .65429 .33702 .6482 .3293 Mtetra
.6482 .3293 .65429 .33702 .66679 .33285 .66073 .32509 Mtetra
.66073 .32509 .66679 .33285 .67933 .32866 .67332 .32087 Mtetra
.67332 .32087 .67933 .32866 .69194 .32444 .68596 .31662 Mtetra
.68596 .31662 .69194 .32444 .7046 .32021 .69866 .31236 Mtetra
.69866 .31236 .7046 .32021 .71732 .31597 .71142 .30807 Mtetra
.71142 .30807 .71732 .31597 .73009 .3117 .72423 .30377 Mtetra
.72423 .30377 .73009 .3117 .74293 .30741 .73711 .29944 Mtetra
.73711 .29944 .74293 .30741 .75582 .3031 .75004 .2951 Mtetra
.75004 .2951 .75582 .3031 .76877 .29878 .76303 .29074 Mtetra
.76303 .29074 .76877 .29878 .78177 .29443 .77608 .28636 Mtetra
.77608 .28636 .78177 .29443 .79484 .29007 .78919 .28195 Mtetra
.78919 .28195 .79484 .29007 .80797 .28568 .80235 .27753 Mtetra
.80235 .27753 .80797 .28568 .82115 .28128 .81558 .27309 Mtetra
.81558 .27309 .82115 .28128 .8344 .27685 .82887 .26863 Mtetra
.82887 .26863 .8344 .27685 .8477 .2724 .84222 .26414 Mtetra
.84222 .26414 .8477 .2724 .86107 .26794 .85563 .25964 Mtetra
.659 .748 .916 r
.23996 .52313 .24736 .52973 .2584 .52616 .25103 .51953 Mtetra
.25103 .51953 .2584 .52616 .26949 .52258 .26215 .51592 Mtetra
.26215 .51592 .26949 .52258 .28062 .51898 .27331 .51229 Mtetra
.27331 .51229 .28062 .51898 .29181 .51536 .28452 .50865 Mtetra
.28452 .50865 .29181 .51536 .30304 .51173 .29578 .50499 Mtetra
.29578 .50499 .30304 .51173 .31432 .50809 .30709 .50131 Mtetra
.30709 .50131 .31432 .50809 .32564 .50442 .31845 .49762 Mtetra
.31845 .49762 .32564 .50442 .33702 .50075 .32985 .49392 Mtetra
.32985 .49392 .33702 .50075 .34844 .49705 .34131 .4902 Mtetra
.34131 .4902 .34844 .49705 .35992 .49335 .35281 .48646 Mtetra
.35281 .48646 .35992 .49335 .37144 .48962 .36437 .4827 Mtetra
.36437 .4827 .37144 .48962 .38301 .48588 .37597 .47893 Mtetra
.37597 .47893 .38301 .48588 .39734 .41355 .38762 .47514 Mtetra
0 0 .089 r
.38762 .47514 .39734 .41355 .40878 .40971 .40195 .40257 Mtetra
.664 .741 .908 r
.40195 .40257 .40878 .40971 .42026 .40585 .41347 .39869 Mtetra
.41347 .39869 .42026 .40585 .4318 .40198 .42503 .39478 Mtetra
.42503 .39478 .4318 .40198 .44338 .39809 .43665 .39086 Mtetra
.43665 .39086 .44338 .39809 .45502 .39418 .44832 .38692 Mtetra
.44832 .38692 .45502 .39418 .4667 .39025 .46003 .38297 Mtetra
.46003 .38297 .4667 .39025 .47843 .38631 .4718 .37899 Mtetra
.4718 .37899 .47843 .38631 .49022 .38236 .48362 .375 Mtetra
.48362 .375 .49022 .38236 .50206 .37838 .49549 .371 Mtetra
.49549 .371 .50206 .37838 .51394 .37439 .50741 .36697 Mtetra
.50741 .36697 .51394 .37439 .52588 .37038 .51938 .36293 Mtetra
.51938 .36293 .52588 .37038 .53788 .36635 .53141 .35887 Mtetra
.53141 .35887 .53788 .36635 .54992 .36231 .54349 .35479 Mtetra
.54349 .35479 .54992 .36231 .56202 .35825 .55562 .3507 Mtetra
.55562 .3507 .56202 .35825 .57417 .35416 .5678 .34658 Mtetra
.5678 .34658 .57417 .35416 .58637 .35007 .58004 .34245 Mtetra
.58004 .34245 .58637 .35007 .59863 .34595 .59233 .3383 Mtetra
.59233 .3383 .59863 .34595 .61094 .34182 .60468 .33414 Mtetra
.60468 .33414 .61094 .34182 .6233 .33766 .61708 .32995 Mtetra
.61708 .32995 .6233 .33766 .63572 .33349 .62954 .32574 Mtetra
.62954 .32574 .63572 .33349 .6482 .3293 .64206 .32152 Mtetra
.64206 .32152 .6482 .3293 .66073 .32509 .65462 .31728 Mtetra
.65462 .31728 .66073 .32509 .67332 .32087 .66725 .31301 Mtetra
.66725 .31301 .67332 .32087 .68596 .31662 .67993 .30873 Mtetra
.67993 .30873 .68596 .31662 .69866 .31236 .69267 .30443 Mtetra
.69267 .30443 .69866 .31236 .71142 .30807 .70547 .30011 Mtetra
.70547 .30011 .71142 .30807 .72423 .30377 .71832 .29577 Mtetra
.71832 .29577 .72423 .30377 .73711 .29944 .73124 .29141 Mtetra
.73124 .29141 .73711 .29944 .75004 .2951 .74421 .28703 Mtetra
.74421 .28703 .75004 .2951 .76303 .29074 .75724 .28263 Mtetra
.75724 .28263 .76303 .29074 .77608 .28636 .77033 .27821 Mtetra
.77033 .27821 .77608 .28636 .78919 .28195 .78348 .27377 Mtetra
.78348 .27377 .78919 .28195 .80235 .27753 .79669 .26932 Mtetra
.79669 .26932 .80235 .27753 .81558 .27309 .80997 .26483 Mtetra
.80997 .26483 .81558 .27309 .82887 .26863 .8233 .26033 Mtetra
.8233 .26033 .82887 .26863 .84222 .26414 .83669 .25581 Mtetra
.83669 .25581 .84222 .26414 .85563 .25964 .85015 .25127 Mtetra
.659 .748 .916 r
.23251 .51647 .23996 .52313 .25103 .51953 .24361 .51285 Mtetra
.24361 .51285 .25103 .51953 .26215 .51592 .25475 .50921 Mtetra
.25475 .50921 .26215 .51592 .27331 .51229 .26594 .50555 Mtetra
.26594 .50555 .27331 .51229 .28452 .50865 .27718 .50188 Mtetra
.27718 .50188 .28452 .50865 .29578 .50499 .28847 .49819 Mtetra
.28847 .49819 .29578 .50499 .30709 .50131 .29981 .49449 Mtetra
.29981 .49449 .30709 .50131 .31845 .49762 .31119 .49077 Mtetra
.31119 .49077 .31845 .49762 .32985 .49392 .32263 .48703 Mtetra
.32263 .48703 .32985 .49392 .34131 .4902 .33411 .48328 Mtetra
.33411 .48328 .34131 .4902 .35281 .48646 .34565 .47951 Mtetra
.34565 .47951 .35281 .48646 .36437 .4827 .35723 .47573 Mtetra
.35723 .47573 .36437 .4827 .37597 .47893 .36887 .47193 Mtetra
.921 .527 .193 r
.36887 .47193 .37597 .47893 .38762 .47514 .379 .50364 Mtetra
.872 .577 .486 r
.379 .50364 .38762 .47514 .40195 .40257 .38636 .6113 Mtetra
.534 .302 .509 r
.38636 .6113 .40195 .40257 .41347 .39869 .39867 .60762 Mtetra
0 0 .232 r
.39867 .60762 .41347 .39869 .42503 .39478 .41822 .38753 Mtetra
.664 .741 .908 r
.41822 .38753 .42503 .39478 .43665 .39086 .42986 .38358 Mtetra
.42986 .38358 .43665 .39086 .44832 .38692 .44156 .37961 Mtetra
.44156 .37961 .44832 .38692 .46003 .38297 .45331 .37562 Mtetra
.45331 .37562 .46003 .38297 .4718 .37899 .46511 .37161 Mtetra
.46511 .37161 .4718 .37899 .48362 .375 .47696 .36759 Mtetra
.47696 .36759 .48362 .375 .49549 .371 .48886 .36355 Mtetra
.48886 .36355 .49549 .371 .50741 .36697 .50082 .3595 Mtetra
.50082 .3595 .50741 .36697 .51938 .36293 .51283 .35542 Mtetra
.51283 .35542 .51938 .36293 .53141 .35887 .52489 .35133 Mtetra
.52489 .35133 .53141 .35887 .54349 .35479 .537 .34722 Mtetra
.537 .34722 .54349 .35479 .55562 .3507 .54917 .34309 Mtetra
.54917 .34309 .55562 .3507 .5678 .34658 .56139 .33894 Mtetra
.56139 .33894 .5678 .34658 .58004 .34245 .57366 .33478 Mtetra
.57366 .33478 .58004 .34245 .59233 .3383 .58599 .33059 Mtetra
.58599 .33059 .59233 .3383 .60468 .33414 .59838 .32639 Mtetra
.59838 .32639 .60468 .33414 .61708 .32995 .61082 .32217 Mtetra
.61082 .32217 .61708 .32995 .62954 .32574 .62331 .31793 Mtetra
.62331 .31793 .62954 .32574 .64206 .32152 .63586 .31367 Mtetra
.63586 .31367 .64206 .32152 .65462 .31728 .64847 .30939 Mtetra
.64847 .30939 .65462 .31728 .66725 .31301 .66113 .30509 Mtetra
.66113 .30509 .66725 .31301 .67993 .30873 .67385 .30078 Mtetra
.67385 .30078 .67993 .30873 .69267 .30443 .68663 .29644 Mtetra
.68663 .29644 .69267 .30443 .70547 .30011 .69947 .29208 Mtetra
.69947 .29208 .70547 .30011 .71832 .29577 .71237 .28771 Mtetra
.71237 .28771 .71832 .29577 .73124 .29141 .72532 .28331 Mtetra
.72532 .28331 .73124 .29141 .74421 .28703 .73833 .2789 Mtetra
.73833 .2789 .74421 .28703 .75724 .28263 .75141 .27446 Mtetra
.75141 .27446 .75724 .28263 .77033 .27821 .76454 .27 Mtetra
.76454 .27 .77033 .27821 .78348 .27377 .77773 .26553 Mtetra
.77773 .26553 .78348 .27377 .79669 .26932 .79099 .26103 Mtetra
.79099 .26103 .79669 .26932 .80997 .26483 .8043 .25651 Mtetra
.8043 .25651 .80997 .26483 .8233 .26033 .81768 .25197 Mtetra
.81768 .25197 .8233 .26033 .83669 .25581 .83112 .24741 Mtetra
.83112 .24741 .83669 .25581 .85015 .25127 .84462 .24283 Mtetra
.659 .748 .916 r
.225 .50977 .23251 .51647 .24361 .51285 .23612 .50612 Mtetra
.23612 .50612 .24361 .51285 .25475 .50921 .24729 .50245 Mtetra
.24729 .50245 .25475 .50921 .26594 .50555 .25851 .49876 Mtetra
.25851 .49876 .26594 .50555 .27718 .50188 .26978 .49506 Mtetra
.26978 .49506 .27718 .50188 .28847 .49819 .2811 .49134 Mtetra
.2811 .49134 .28847 .49819 .29981 .49449 .29247 .48761 Mtetra
.29247 .48761 .29981 .49449 .31119 .49077 .30388 .48386 Mtetra
.30388 .48386 .31119 .49077 .32263 .48703 .31535 .48009 Mtetra
.31535 .48009 .32263 .48703 .33411 .48328 .32686 .47631 Mtetra
.32686 .47631 .33411 .48328 .34565 .47951 .33843 .47251 Mtetra
.33843 .47251 .34565 .47951 .35723 .47573 .35004 .4687 Mtetra
.35004 .4687 .35723 .47573 .36887 .47193 .36171 .46487 Mtetra
.921 .527 .193 r
.36171 .46487 .36887 .47193 .379 .50364 .37179 .49661 Mtetra
.955 .65 .417 r
.37179 .49661 .379 .50364 .38636 .6113 .37892 .60448 Mtetra
.646 .762 .934 r
.37892 .60448 .38636 .6113 .39867 .60762 .39126 .60076 Mtetra
.39126 .60076 .39867 .60762 .41822 .38753 .40366 .59703 Mtetra
.533 .3 .507 r
.40366 .59703 .41822 .38753 .42986 .38358 .41611 .59328 Mtetra
0 0 .239 r
.41611 .59328 .42986 .38358 .44156 .37961 .43475 .37223 Mtetra
.664 .741 .908 r
.43475 .37223 .44156 .37961 .45331 .37562 .44654 .36821 Mtetra
.44654 .36821 .45331 .37562 .46511 .37161 .45837 .36418 Mtetra
.45837 .36418 .46511 .37161 .47696 .36759 .47025 .36012 Mtetra
.47025 .36012 .47696 .36759 .48886 .36355 .48219 .35605 Mtetra
.48219 .35605 .48886 .36355 .50082 .3595 .49418 .35196 Mtetra
.49418 .35196 .50082 .3595 .51283 .35542 .50622 .34785 Mtetra
.50622 .34785 .51283 .35542 .52489 .35133 .51831 .34373 Mtetra
.51831 .34373 .52489 .35133 .537 .34722 .53046 .33958 Mtetra
.53046 .33958 .537 .34722 .54917 .34309 .54266 .33542 Mtetra
.54266 .33542 .54917 .34309 .56139 .33894 .55492 .33124 Mtetra
.55492 .33124 .56139 .33894 .57366 .33478 .56723 .32704 Mtetra
.56723 .32704 .57366 .33478 .58599 .33059 .5796 .32282 Mtetra
.5796 .32282 .58599 .33059 .59838 .32639 .59202 .31858 Mtetra
.59202 .31858 .59838 .32639 .61082 .32217 .60449 .31433 Mtetra
.60449 .31433 .61082 .32217 .62331 .31793 .61703 .31005 Mtetra
.61703 .31005 .62331 .31793 .63586 .31367 .62962 .30576 Mtetra
.62962 .30576 .63586 .31367 .64847 .30939 .64226 .30144 Mtetra
.64226 .30144 .64847 .30939 .66113 .30509 .65497 .29711 Mtetra
.65497 .29711 .66113 .30509 .67385 .30078 .66773 .29276 Mtetra
.66773 .29276 .67385 .30078 .68663 .29644 .68054 .28838 Mtetra
.68054 .28838 .68663 .29644 .69947 .29208 .69342 .28399 Mtetra
.69342 .28399 .69947 .29208 .71237 .28771 .70636 .27958 Mtetra
.70636 .27958 .71237 .28771 .72532 .28331 .71935 .27514 Mtetra
.71935 .27514 .72532 .28331 .73833 .2789 .73241 .27069 Mtetra
.73241 .27069 .73833 .2789 .75141 .27446 .74552 .26622 Mtetra
.74552 .26622 .75141 .27446 .76454 .27 .7587 .26172 Mtetra
.7587 .26172 .76454 .27 .77773 .26553 .77193 .25721 Mtetra
.77193 .25721 .77773 .26553 .79099 .26103 .78523 .25267 Mtetra
.78523 .25267 .79099 .26103 .8043 .25651 .79859 .24811 Mtetra
.79859 .24811 .8043 .25651 .81768 .25197 .81201 .24353 Mtetra
.81201 .24353 .81768 .25197 .83112 .24741 .82549 .23893 Mtetra
.82549 .23893 .83112 .24741 .84462 .24283 .83904 .23431 Mtetra
.659 .748 .916 r
.21742 .50301 .225 .50977 .23612 .50612 .22858 .49933 Mtetra
.22858 .49933 .23612 .50612 .24729 .50245 .23978 .49563 Mtetra
.23978 .49563 .24729 .50245 .25851 .49876 .25103 .49192 Mtetra
.25103 .49192 .25851 .49876 .26978 .49506 .26232 .48818 Mtetra
.26232 .48818 .26978 .49506 .2811 .49134 .27367 .48444 Mtetra
.27367 .48444 .2811 .49134 .29247 .48761 .28507 .48067 Mtetra
.28507 .48067 .29247 .48761 .30388 .48386 .29651 .47689 Mtetra
.29651 .47689 .30388 .48386 .31535 .48009 .30801 .4731 Mtetra
.30801 .4731 .31535 .48009 .32686 .47631 .31955 .46929 Mtetra
.31955 .46929 .32686 .47631 .33843 .47251 .33115 .46546 Mtetra
.33115 .46546 .33843 .47251 .35004 .4687 .3428 .46161 Mtetra
.922 .53 .201 r
.3428 .46161 .35004 .4687 .36171 .46487 .35264 .49337 Mtetra
.454 .142 .346 r
.35264 .49337 .36171 .46487 .37179 .49661 .36452 .48953 Mtetra
.955 .65 .417 r
.36452 .48953 .37179 .49661 .37892 .60448 .37142 .5976 Mtetra
.646 .762 .934 r
.37142 .5976 .37892 .60448 .39126 .60076 .3838 .59385 Mtetra
.3838 .59385 .39126 .60076 .40366 .59703 .39623 .59009 Mtetra
.39623 .59009 .40366 .59703 .41611 .59328 .40872 .5863 Mtetra
.40872 .5863 .41611 .59328 .43475 .37223 .42127 .5825 Mtetra
.531 .297 .506 r
.42127 .5825 .43475 .37223 .44654 .36821 .43387 .57868 Mtetra
0 0 .246 r
.43387 .57868 .44654 .36821 .45837 .36418 .45157 .35668 Mtetra
.664 .741 .908 r
.45157 .35668 .45837 .36418 .47025 .36012 .46349 .35259 Mtetra
.46349 .35259 .47025 .36012 .48219 .35605 .47546 .34849 Mtetra
.47546 .34849 .48219 .35605 .49418 .35196 .48748 .34436 Mtetra
.48748 .34436 .49418 .35196 .50622 .34785 .49956 .34022 Mtetra
.49956 .34022 .50622 .34785 .51831 .34373 .51169 .33606 Mtetra
.51169 .33606 .51831 .34373 .53046 .33958 .52387 .33188 Mtetra
.52387 .33188 .53046 .33958 .54266 .33542 .53611 .32769 Mtetra
.53611 .32769 .54266 .33542 .55492 .33124 .5484 .32347 Mtetra
.5484 .32347 .55492 .33124 .56723 .32704 .56075 .31924 Mtetra
.56075 .31924 .56723 .32704 .5796 .32282 .57315 .31498 Mtetra
.57315 .31498 .5796 .32282 .59202 .31858 .58561 .31071 Mtetra
.58561 .31071 .59202 .31858 .60449 .31433 .59812 .30642 Mtetra
.59812 .30642 .60449 .31433 .61703 .31005 .61069 .30211 Mtetra
.61069 .30211 .61703 .31005 .62962 .30576 .62332 .29778 Mtetra
.62332 .29778 .62962 .30576 .64226 .30144 .636 .29343 Mtetra
.636 .29343 .64226 .30144 .65497 .29711 .64874 .28906 Mtetra
.64874 .28906 .65497 .29711 .66773 .29276 .66155 .28467 Mtetra
.66155 .28467 .66773 .29276 .68054 .28838 .6744 .28026 Mtetra
.6744 .28026 .68054 .28838 .69342 .28399 .68732 .27583 Mtetra
.68732 .27583 .69342 .28399 .70636 .27958 .7003 .27138 Mtetra
.7003 .27138 .70636 .27958 .71935 .27514 .71333 .26691 Mtetra
.71333 .26691 .71935 .27514 .73241 .27069 .72643 .26241 Mtetra
.72643 .26241 .73241 .27069 .74552 .26622 .73959 .2579 Mtetra
.73959 .2579 .74552 .26622 .7587 .26172 .7528 .25337 Mtetra
.7528 .25337 .7587 .26172 .77193 .25721 .76608 .24881 Mtetra
.76608 .24881 .77193 .25721 .78523 .25267 .77942 .24424 Mtetra
.77942 .24424 .78523 .25267 .79859 .24811 .79283 .23964 Mtetra
.79283 .23964 .79859 .24811 .81201 .24353 .80629 .23502 Mtetra
.80629 .23502 .81201 .24353 .82549 .23893 .81982 .23039 Mtetra
.81982 .23039 .82549 .23893 .83904 .23431 .83341 .22572 Mtetra
.659 .748 .916 r
.20979 .4962 .21742 .50301 .22858 .49933 .22097 .49249 Mtetra
.22097 .49249 .22858 .49933 .23978 .49563 .2322 .48876 Mtetra
.2322 .48876 .23978 .49563 .25103 .49192 .24348 .48501 Mtetra
.24348 .48501 .25103 .49192 .26232 .48818 .25481 .48125 Mtetra
.25481 .48125 .26232 .48818 .27367 .48444 .26618 .47748 Mtetra
.26618 .47748 .27367 .48444 .28507 .48067 .27761 .47368 Mtetra
.27761 .47368 .28507 .48067 .29651 .47689 .28908 .46987 Mtetra
.28908 .46987 .29651 .47689 .30801 .4731 .30061 .46605 Mtetra
.30061 .46605 .30801 .4731 .31955 .46929 .31218 .4622 Mtetra
.31218 .4622 .31955 .46929 .33115 .46546 .32381 .45834 Mtetra
.923 .533 .209 r
.32381 .45834 .33115 .46546 .3428 .46161 .33343 .49012 Mtetra
.451 .137 .342 r
.33343 .49012 .3428 .46161 .35264 .49337 .34528 .48626 Mtetra
.954 .651 .421 r
.34528 .48626 .35264 .49337 .36452 .48953 .3515 .59443 Mtetra
.518 .27 .479 r
.3515 .59443 .36452 .48953 .37142 .5976 .36386 .59067 Mtetra
.646 .762 .934 r
.36386 .59067 .37142 .5976 .3838 .59385 .37627 .58689 Mtetra
.37627 .58689 .3838 .59385 .39623 .59009 .38873 .58309 Mtetra
.38873 .58309 .39623 .59009 .40872 .5863 .40126 .57927 Mtetra
.40126 .57927 .40872 .5863 .42127 .5825 .41385 .57543 Mtetra
.41385 .57543 .42127 .5825 .43387 .57868 .42649 .57158 Mtetra
.42649 .57158 .43387 .57868 .45157 .35668 .43919 .56771 Mtetra
.529 .295 .504 r
.43919 .56771 .45157 .35668 .46349 .35259 .45196 .56382 Mtetra
.212 .043 .422 r
.45196 .56382 .46349 .35259 .47546 .34849 .46695 .43763 Mtetra
0 0 .187 r
.46695 .43763 .47546 .34849 .48748 .34436 .48073 .3367 Mtetra
.664 .741 .908 r
.48073 .3367 .48748 .34436 .49956 .34022 .49284 .33253 Mtetra
.49284 .33253 .49956 .34022 .51169 .33606 .505 .32833 Mtetra
.505 .32833 .51169 .33606 .52387 .33188 .51722 .32412 Mtetra
.51722 .32412 .52387 .33188 .53611 .32769 .5295 .31989 Mtetra
.5295 .31989 .53611 .32769 .5484 .32347 .54182 .31564 Mtetra
.54182 .31564 .5484 .32347 .56075 .31924 .55421 .31137 Mtetra
.55421 .31137 .56075 .31924 .57315 .31498 .56665 .30708 Mtetra
.56665 .30708 .57315 .31498 .58561 .31071 .57914 .30277 Mtetra
.57914 .30277 .58561 .31071 .59812 .30642 .59169 .29844 Mtetra
.59169 .29844 .59812 .30642 .61069 .30211 .6043 .2941 Mtetra
.6043 .2941 .61069 .30211 .62332 .29778 .61697 .28973 Mtetra
.61697 .28973 .62332 .29778 .636 .29343 .62969 .28534 Mtetra
.62969 .28534 .636 .29343 .64874 .28906 .64247 .28094 Mtetra
.64247 .28094 .64874 .28906 .66155 .28467 .65531 .27651 Mtetra
.65531 .27651 .66155 .28467 .6744 .28026 .66821 .27206 Mtetra
.66821 .27206 .6744 .28026 .68732 .27583 .68117 .26759 Mtetra
.68117 .26759 .68732 .27583 .7003 .27138 .69419 .26311 Mtetra
.69419 .26311 .7003 .27138 .71333 .26691 .70726 .2586 Mtetra
.70726 .2586 .71333 .26691 .72643 .26241 .7204 .25407 Mtetra
.7204 .25407 .72643 .26241 .73959 .2579 .7336 .24952 Mtetra
.7336 .24952 .73959 .2579 .7528 .25337 .74686 .24494 Mtetra
.74686 .24494 .7528 .25337 .76608 .24881 .76018 .24035 Mtetra
.76018 .24035 .76608 .24881 .77942 .24424 .77357 .23574 Mtetra
.77357 .23574 .77942 .24424 .79283 .23964 .78702 .2311 Mtetra
.78702 .2311 .79283 .23964 .80629 .23502 .80053 .22644 Mtetra
.80053 .22644 .80629 .23502 .81982 .23039 .8141 .22176 Mtetra
.8141 .22176 .81982 .23039 .83341 .22572 .82774 .21706 Mtetra
.659 .748 .916 r
.2021 .48933 .20979 .4962 .22097 .49249 .21331 .48559 Mtetra
.21331 .48559 .22097 .49249 .2322 .48876 .22457 .48183 Mtetra
.22457 .48183 .2322 .48876 .24348 .48501 .23587 .47806 Mtetra
.23587 .47806 .24348 .48501 .25481 .48125 .24723 .47427 Mtetra
.24723 .47427 .25481 .48125 .26618 .47748 .25863 .47046 Mtetra
.25863 .47046 .26618 .47748 .27761 .47368 .27009 .46664 Mtetra
.27009 .46664 .27761 .47368 .28908 .46987 .28159 .46279 Mtetra
.28159 .46279 .28908 .46987 .30061 .46605 .29315 .45894 Mtetra
.29315 .45894 .30061 .46605 .31218 .4622 .30476 .45506 Mtetra
.30476 .45506 .31218 .4622 .32381 .45834 .31641 .45117 Mtetra
.923 .533 .209 r
.31641 .45117 .32381 .45834 .33343 .49012 .32597 .48299 Mtetra
.656 .751 .92 r
.32597 .48299 .33343 .49012 .34528 .48626 .33786 .4791 Mtetra
.954 .651 .421 r
.33786 .4791 .34528 .48626 .3515 .59443 .34384 .58747 Mtetra
.646 .762 .934 r
.34384 .58747 .3515 .59443 .36386 .59067 .35622 .58367 Mtetra
.35622 .58367 .36386 .59067 .37627 .58689 .36867 .57986 Mtetra
.36867 .57986 .37627 .58689 .38873 .58309 .38117 .57602 Mtetra
.38117 .57602 .38873 .58309 .40126 .57927 .39374 .57217 Mtetra
.39374 .57217 .40126 .57927 .41385 .57543 .40636 .56831 Mtetra
.40636 .56831 .41385 .57543 .42649 .57158 .41904 .56442 Mtetra
.41904 .56442 .42649 .57158 .43919 .56771 .43178 .56051 Mtetra
.43178 .56051 .43919 .56771 .45196 .56382 .44458 .55659 Mtetra
.957 .716 .532 r
.44458 .55659 .45196 .56382 .46695 .43763 .45989 .43011 Mtetra
.657 .751 .919 r
.45989 .43011 .46695 .43763 .48073 .3367 .47235 .42601 Mtetra
.512 .259 .469 r
.47235 .42601 .48073 .3367 .49284 .33253 .48487 .4219 Mtetra
0 0 .195 r
.48487 .4219 .49284 .33253 .505 .32833 .49827 .32054 Mtetra
.664 .741 .908 r
.49827 .32054 .505 .32833 .51722 .32412 .51052 .31629 Mtetra
.51052 .31629 .51722 .32412 .5295 .31989 .52283 .31203 Mtetra
.52283 .31203 .5295 .31989 .54182 .31564 .53519 .30774 Mtetra
.53519 .30774 .54182 .31564 .55421 .31137 .54761 .30344 Mtetra
.54761 .30344 .55421 .31137 .56665 .30708 .56009 .29911 Mtetra
.56009 .29911 .56665 .30708 .57914 .30277 .57262 .29477 Mtetra
.57262 .29477 .57914 .30277 .59169 .29844 .58521 .2904 Mtetra
.58521 .2904 .59169 .29844 .6043 .2941 .59786 .28602 Mtetra
.59786 .28602 .6043 .2941 .61697 .28973 .61056 .28162 Mtetra
.61056 .28162 .61697 .28973 .62969 .28534 .62333 .27719 Mtetra
.62333 .27719 .62969 .28534 .64247 .28094 .63615 .27275 Mtetra
.63615 .27275 .64247 .28094 .65531 .27651 .64903 .26828 Mtetra
.64903 .26828 .65531 .27651 .66821 .27206 .66197 .2638 Mtetra
.66197 .2638 .66821 .27206 .68117 .26759 .67496 .25929 Mtetra
.67496 .25929 .68117 .26759 .69419 .26311 .68802 .25477 Mtetra
.68802 .25477 .69419 .26311 .70726 .2586 .70114 .25022 Mtetra
.70114 .25022 .70726 .2586 .7204 .25407 .71432 .24565 Mtetra
.71432 .24565 .7204 .25407 .7336 .24952 .72756 .24106 Mtetra
.72756 .24106 .7336 .24952 .74686 .24494 .74087 .23645 Mtetra
.74087 .23645 .74686 .24494 .76018 .24035 .75423 .23182 Mtetra
.75423 .23182 .76018 .24035 .77357 .23574 .76766 .22716 Mtetra
.76766 .22716 .77357 .23574 .78702 .2311 .78115 .22248 Mtetra
.78115 .22248 .78702 .2311 .80053 .22644 .79471 .21779 Mtetra
.79471 .21779 .80053 .22644 .8141 .22176 .80833 .21306 Mtetra
.80833 .21306 .8141 .22176 .82774 .21706 .82201 .20832 Mtetra
.144 .186 .647 r
.19609 .465 .2021 .48933 .21331 .48559 .20558 .47864 Mtetra
.659 .748 .916 r
.20558 .47864 .21331 .48559 .22457 .48183 .21687 .47485 Mtetra
.21687 .47485 .22457 .48183 .23587 .47806 .2282 .47105 Mtetra
.2282 .47105 .23587 .47806 .24723 .47427 .23959 .46723 Mtetra
.23959 .46723 .24723 .47427 .25863 .47046 .25102 .46339 Mtetra
.25102 .46339 .25863 .47046 .27009 .46664 .26251 .45953 Mtetra
.26251 .45953 .27009 .46664 .28159 .46279 .27404 .45566 Mtetra
.27404 .45566 .28159 .46279 .29315 .45894 .28563 .45177 Mtetra
.28563 .45177 .29315 .45894 .30476 .45506 .29727 .44786 Mtetra
.924 .536 .217 r
.29727 .44786 .30476 .45506 .31641 .45117 .30659 .4797 Mtetra
.444 .128 .333 r
.30659 .4797 .31641 .45117 .32597 .48299 .31846 .47579 Mtetra
.656 .751 .92 r
.31846 .47579 .32597 .48299 .33786 .4791 .33037 .47187 Mtetra
.954 .651 .421 r
.33037 .47187 .33786 .4791 .34384 .58747 .3361 .58045 Mtetra
.646 .762 .934 r
.3361 .58045 .34384 .58747 .35622 .58367 .34853 .57662 Mtetra
.34853 .57662 .35622 .58367 .36867 .57986 .36101 .57277 Mtetra
.36101 .57277 .36867 .57986 .38117 .57602 .37355 .5689 Mtetra
.37355 .5689 .38117 .57602 .39374 .57217 .38615 .56502 Mtetra
.38615 .56502 .39374 .57217 .40636 .56831 .39881 .56111 Mtetra
.39881 .56111 .40636 .56831 .41904 .56442 .41153 .55719 Mtetra
.41153 .55719 .41904 .56442 .43178 .56051 .42431 .55325 Mtetra
.956 .716 .534 r
.42431 .55325 .43178 .56051 .44458 .55659 .44034 .42665 Mtetra
.554 .353 .563 r
.44034 .42665 .44458 .55659 .45989 .43011 .45278 .42253 Mtetra
.657 .751 .919 r
.45278 .42253 .45989 .43011 .47235 .42601 .46527 .4184 Mtetra
.46527 .4184 .47235 .42601 .48487 .4219 .47783 .41425 Mtetra
.47783 .41425 .48487 .4219 .49827 .32054 .49044 .41008 Mtetra
.51 .256 .466 r
.49044 .41008 .49827 .32054 .51052 .31629 .50311 .40589 Mtetra
0 0 .202 r
.50311 .40589 .51052 .31629 .52283 .31203 .51611 .3041 Mtetra
.664 .741 .908 r
.51611 .3041 .52283 .31203 .53519 .30774 .52851 .29978 Mtetra
.52851 .29978 .53519 .30774 .54761 .30344 .54097 .29544 Mtetra
.54097 .29544 .54761 .30344 .56009 .29911 .55348 .29108 Mtetra
.55348 .29108 .56009 .29911 .57262 .29477 .56605 .28669 Mtetra
.56605 .28669 .57262 .29477 .58521 .2904 .57868 .28229 Mtetra
.57868 .28229 .58521 .2904 .59786 .28602 .59136 .27787 Mtetra
.59136 .27787 .59786 .28602 .61056 .28162 .60411 .27343 Mtetra
.60411 .27343 .61056 .28162 .62333 .27719 .61691 .26897 Mtetra
.61691 .26897 .62333 .27719 .63615 .27275 .62977 .26449 Mtetra
.62977 .26449 .63615 .27275 .64903 .26828 .64269 .25999 Mtetra
.64269 .25999 .64903 .26828 .66197 .2638 .65567 .25546 Mtetra
.65567 .25546 .66197 .2638 .67496 .25929 .66871 .25092 Mtetra
.66871 .25092 .67496 .25929 .68802 .25477 .68181 .24635 Mtetra
.68181 .24635 .68802 .25477 .70114 .25022 .69497 .24177 Mtetra
.69497 .24177 .70114 .25022 .71432 .24565 .70819 .23716 Mtetra
.70819 .23716 .71432 .24565 .72756 .24106 .72148 .23253 Mtetra
.72148 .23253 .72756 .24106 .74087 .23645 .73482 .22788 Mtetra
.73482 .22788 .74087 .23645 .75423 .23182 .74823 .2232 Mtetra
.74823 .2232 .75423 .23182 .76766 .22716 .7617 .21851 Mtetra
.7617 .21851 .76766 .22716 .78115 .22248 .77524 .21379 Mtetra
.77524 .21379 .78115 .22248 .79471 .21779 .78884 .20905 Mtetra
.78884 .20905 .79471 .21779 .80833 .21306 .80251 .20429 Mtetra
.80251 .20429 .80833 .21306 .82201 .20832 .81623 .19951 Mtetra
.66 .746 .914 r
.18832 .45799 .19609 .465 .20558 .47864 .19953 .45417 Mtetra
.144 .186 .647 r
.19953 .45417 .20558 .47864 .21687 .47485 .20911 .46781 Mtetra
.659 .748 .916 r
.20911 .46781 .21687 .47485 .2282 .47105 .22047 .46398 Mtetra
.22047 .46398 .2282 .47105 .23959 .46723 .23189 .46013 Mtetra
.23189 .46013 .23959 .46723 .25102 .46339 .24335 .45626 Mtetra
.24335 .45626 .25102 .46339 .26251 .45953 .25486 .45237 Mtetra
.25486 .45237 .26251 .45953 .27404 .45566 .26643 .44847 Mtetra
.26643 .44847 .27404 .45566 .28563 .45177 .27805 .44454 Mtetra
.27805 .44454 .28563 .45177 .29727 .44786 .28972 .44061 Mtetra
.924 .536 .217 r
.28972 .44061 .29727 .44786 .30659 .4797 .29898 .47248 Mtetra
.656 .751 .92 r
.29898 .47248 .30659 .4797 .31846 .47579 .31088 .46854 Mtetra
.31088 .46854 .31846 .47579 .33037 .47187 .32283 .46458 Mtetra
.954 .651 .421 r
.32283 .46458 .33037 .47187 .3361 .58045 .3283 .57336 Mtetra
.646 .762 .934 r
.3283 .57336 .3361 .58045 .34853 .57662 .34076 .5695 Mtetra
.34076 .5695 .34853 .57662 .36101 .57277 .35328 .56562 Mtetra
.35328 .56562 .36101 .57277 .37355 .5689 .36586 .56172 Mtetra
.36586 .56172 .37355 .5689 .38615 .56502 .37849 .5578 Mtetra
.37849 .5578 .38615 .56502 .39881 .56111 .39119 .55386 Mtetra
.39119 .55386 .39881 .56111 .41153 .55719 .40395 .54991 Mtetra
.955 .715 .537 r
.40395 .54991 .41153 .55719 .42431 .55325 .42071 .42317 Mtetra
.552 .351 .562 r
.42071 .42317 .42431 .55325 .44034 .42665 .43312 .41904 Mtetra
.657 .751 .919 r
.43312 .41904 .44034 .42665 .45278 .42253 .4456 .41489 Mtetra
.4456 .41489 .45278 .42253 .46527 .4184 .45813 .41072 Mtetra
.45813 .41072 .46527 .4184 .47783 .41425 .47072 .40653 Mtetra
.47072 .40653 .47783 .41425 .49044 .41008 .48337 .40232 Mtetra
.48337 .40232 .49044 .41008 .50311 .40589 .49608 .3981 Mtetra
.49608 .3981 .50311 .40589 .51611 .3041 .50884 .39385 Mtetra
0 0 .202 r
.50884 .39385 .51611 .3041 .52851 .29978 .52177 .29175 Mtetra
.664 .741 .908 r
.52177 .29175 .52851 .29978 .54097 .29544 .53426 .28737 Mtetra
.53426 .28737 .54097 .29544 .55348 .29108 .54681 .28297 Mtetra
.54681 .28297 .55348 .29108 .56605 .28669 .55942 .27855 Mtetra
.55942 .27855 .56605 .28669 .57868 .28229 .57209 .27412 Mtetra
.57209 .27412 .57868 .28229 .59136 .27787 .58481 .26966 Mtetra
.58481 .26966 .59136 .27787 .60411 .27343 .59759 .26518 Mtetra
.59759 .26518 .60411 .27343 .61691 .26897 .61043 .26068 Mtetra
.61043 .26068 .61691 .26897 .62977 .26449 .62333 .25616 Mtetra
.62333 .25616 .62977 .26449 .64269 .25999 .63629 .25162 Mtetra
.63629 .25162 .64269 .25999 .65567 .25546 .64932 .24706 Mtetra
.64932 .24706 .65567 .25546 .66871 .25092 .6624 .24247 Mtetra
.6624 .24247 .66871 .25092 .68181 .24635 .67554 .23787 Mtetra
.67554 .23787 .68181 .24635 .69497 .24177 .68874 .23324 Mtetra
.68874 .23324 .69497 .24177 .70819 .23716 .70201 .22859 Mtetra
.70201 .22859 .70819 .23716 .72148 .23253 .71533 .22393 Mtetra
.71533 .22393 .72148 .23253 .73482 .22788 .72872 .21923 Mtetra
.72872 .21923 .73482 .22788 .74823 .2232 .74218 .21452 Mtetra
.74218 .21452 .74823 .2232 .7617 .21851 .75569 .20978 Mtetra
.75569 .20978 .7617 .21851 .77524 .21379 .76928 .20502 Mtetra
.76928 .20502 .77524 .21379 .78884 .20905 .78292 .20024 Mtetra
.78292 .20024 .78884 .20905 .80251 .20429 .79663 .19544 Mtetra
.79663 .19544 .80251 .20429 .81623 .19951 .81041 .19061 Mtetra
.66 .746 .914 r
.18049 .45092 .18832 .45799 .19953 .45417 .19173 .44707 Mtetra
.19173 .44707 .19953 .45417 .20911 .46781 .20301 .44321 Mtetra
.144 .186 .647 r
.20301 .44321 .20911 .46781 .22047 .46398 .21268 .45685 Mtetra
.659 .748 .916 r
.21268 .45685 .22047 .46398 .23189 .46013 .22412 .45297 Mtetra
.22412 .45297 .23189 .46013 .24335 .45626 .23562 .44907 Mtetra
.23562 .44907 .24335 .45626 .25486 .45237 .24716 .44515 Mtetra
.24716 .44515 .25486 .45237 .26643 .44847 .25876 .44121 Mtetra
.25876 .44121 .26643 .44847 .27805 .44454 .2704 .43726 Mtetra
.925 .539 .225 r
.2704 .43726 .27805 .44454 .28972 .44061 .27943 .46915 Mtetra
.437 .118 .324 r
.27943 .46915 .28972 .44061 .29898 .47248 .2913 .46519 Mtetra
.656 .751 .92 r
.2913 .46519 .29898 .47248 .31088 .46854 .30323 .46122 Mtetra
.30323 .46122 .31088 .46854 .32283 .46458 .31522 .45724 Mtetra
.954 .651 .421 r
.31522 .45724 .32283 .46458 .3283 .57336 .32044 .56621 Mtetra
.646 .762 .934 r
.32044 .56621 .3283 .57336 .34076 .5695 .33293 .56232 Mtetra
.33293 .56232 .34076 .5695 .35328 .56562 .34549 .5584 Mtetra
.34549 .5584 .35328 .56562 .36586 .56172 .3581 .55447 Mtetra
.3581 .55447 .36586 .56172 .37849 .5578 .37077 .55052 Mtetra
.37077 .55052 .37849 .5578 .39119 .55386 .38351 .54654 Mtetra
.38351 .54654 .39119 .55386 .40395 .54991 .3963 .54255 Mtetra
.955 .715 .537 r
.3963 .54255 .40395 .54991 .42071 .42317 .41339 .41553 Mtetra
.657 .751 .919 r
.41339 .41553 .42071 .42317 .43312 .41904 .42585 .41136 Mtetra
.42585 .41136 .43312 .41904 .4456 .41489 .43836 .40718 Mtetra
.43836 .40718 .4456 .41489 .45813 .41072 .45093 .40297 Mtetra
.45093 .40297 .45813 .41072 .47072 .40653 .46355 .39875 Mtetra
.46355 .39875 .47072 .40653 .48337 .40232 .47624 .39451 Mtetra
.47624 .39451 .48337 .40232 .49608 .3981 .48899 .39024 Mtetra
.48899 .39024 .49608 .3981 .50884 .39385 .50179 .38596 Mtetra
.50179 .38596 .50884 .39385 .52177 .29175 .51466 .38166 Mtetra
.505 .25 .461 r
.51466 .38166 .52177 .29175 .53426 .28737 .52758 .37733 Mtetra
0 0 .21 r
.52758 .37733 .53426 .28737 .54681 .28297 .54009 .2748 Mtetra
.664 .741 .908 r
.54009 .2748 .54681 .28297 .55942 .27855 .55274 .27035 Mtetra
.55274 .27035 .55942 .27855 .57209 .27412 .56544 .26587 Mtetra
.56544 .26587 .57209 .27412 .58481 .26966 .5782 .26137 Mtetra
.5782 .26137 .58481 .26966 .59759 .26518 .59102 .25686 Mtetra
.59102 .25686 .59759 .26518 .61043 .26068 .60391 .25232 Mtetra
.60391 .25232 .61043 .26068 .62333 .25616 .61685 .24776 Mtetra
.61685 .24776 .62333 .25616 .63629 .25162 .62985 .24318 Mtetra
.62985 .24318 .63629 .25162 .64932 .24706 .64291 .23858 Mtetra
.64291 .23858 .64932 .24706 .6624 .24247 .65603 .23396 Mtetra
.65603 .23396 .6624 .24247 .67554 .23787 .66921 .22931 Mtetra
.66921 .22931 .67554 .23787 .68874 .23324 .68246 .22464 Mtetra
.68246 .22464 .68874 .23324 .70201 .22859 .69577 .21996 Mtetra
.69577 .21996 .70201 .22859 .71533 .22393 .70914 .21525 Mtetra
.70914 .21525 .71533 .22393 .72872 .21923 .72257 .21051 Mtetra
.72257 .21051 .72872 .21923 .74218 .21452 .73607 .20576 Mtetra
.73607 .20576 .74218 .21452 .75569 .20978 .74963 .20098 Mtetra
.74963 .20098 .75569 .20978 .76928 .20502 .76326 .19618 Mtetra
.76326 .19618 .76928 .20502 .78292 .20024 .77695 .19136 Mtetra
.77695 .19136 .78292 .20024 .79663 .19544 .79071 .18651 Mtetra
.79071 .18651 .79663 .19544 .81041 .19061 .80453 .18164 Mtetra
.66 .746 .914 r
.17259 .4438 .18049 .45092 .19173 .44707 .18386 .43992 Mtetra
.18386 .43992 .19173 .44707 .20301 .44321 .19517 .43602 Mtetra
.19517 .43602 .20301 .44321 .21268 .45685 .20654 .4321 Mtetra
.144 .186 .647 r
.20654 .4321 .21268 .45685 .22412 .45297 .21629 .44575 Mtetra
.659 .748 .916 r
.21629 .44575 .22412 .45297 .23562 .44907 .22782 .44182 Mtetra
.22782 .44182 .23562 .44907 .24716 .44515 .23939 .43787 Mtetra
.23939 .43787 .24716 .44515 .25876 .44121 .25102 .4339 Mtetra
.926 .542 .233 r
.25102 .4339 .25876 .44121 .2704 .43726 .2598 .4658 Mtetra
.434 .112 .32 r
.2598 .4658 .2704 .43726 .27943 .46915 .27166 .46184 Mtetra
.656 .751 .92 r
.27166 .46184 .27943 .46915 .2913 .46519 .28356 .45785 Mtetra
.28356 .45785 .2913 .46519 .30323 .46122 .29553 .45385 Mtetra
.953 .652 .425 r
.29553 .45385 .30323 .46122 .31522 .45724 .30003 .56292 Mtetra
.508 .256 .467 r
.30003 .56292 .31522 .45724 .32044 .56621 .3125 .55901 Mtetra
.646 .762 .934 r
.3125 .55901 .32044 .56621 .33293 .56232 .32503 .55507 Mtetra
.32503 .55507 .33293 .56232 .34549 .5584 .33762 .55113 Mtetra
.33762 .55113 .34549 .5584 .3581 .55447 .35027 .54716 Mtetra
.35027 .54716 .3581 .55447 .37077 .55052 .36298 .54317 Mtetra
.36298 .54317 .37077 .55052 .38351 .54654 .37575 .53916 Mtetra
.953 .715 .54 r
.37575 .53916 .38351 .54654 .3963 .54255 .39359 .412 Mtetra
.55 .348 .559 r
.39359 .412 .3963 .54255 .41339 .41553 .40602 .40782 Mtetra
.657 .751 .919 r
.40602 .40782 .41339 .41553 .42585 .41136 .41851 .40362 Mtetra
.41851 .40362 .42585 .41136 .43836 .40718 .43106 .3994 Mtetra
.43106 .3994 .43836 .40718 .45093 .40297 .44366 .39516 Mtetra
.44366 .39516 .45093 .40297 .46355 .39875 .45633 .3909 Mtetra
.45633 .3909 .46355 .39875 .47624 .39451 .46905 .38662 Mtetra
.46905 .38662 .47624 .39451 .48899 .39024 .48184 .38232 Mtetra
.48184 .38232 .48899 .39024 .50179 .38596 .49468 .378 Mtetra
.49468 .378 .50179 .38596 .51466 .38166 .50759 .37366 Mtetra
.50759 .37366 .51466 .38166 .52758 .37733 .52055 .3693 Mtetra
.52055 .3693 .52758 .37733 .54009 .2748 .53358 .36492 Mtetra
0 0 .21 r
.53358 .36492 .54009 .2748 .55274 .27035 .54599 .26207 Mtetra
.664 .741 .908 r
.54599 .26207 .55274 .27035 .56544 .26587 .55874 .25755 Mtetra
.55874 .25755 .56544 .26587 .5782 .26137 .57154 .25302 Mtetra
.57154 .25302 .5782 .26137 .59102 .25686 .5844 .24846 Mtetra
.5844 .24846 .59102 .25686 .60391 .25232 .59732 .24389 Mtetra
.59732 .24389 .60391 .25232 .61685 .24776 .6103 .23929 Mtetra
.6103 .23929 .61685 .24776 .62985 .24318 .62334 .23467 Mtetra
.62334 .23467 .62985 .24318 .64291 .23858 .63645 .23003 Mtetra
.63645 .23003 .64291 .23858 .65603 .23396 .64961 .22536 Mtetra
.64961 .22536 .65603 .23396 .66921 .22931 .66284 .22068 Mtetra
.66284 .22068 .66921 .22931 .68246 .22464 .67612 .21597 Mtetra
.67612 .21597 .68246 .22464 .69577 .21996 .68948 .21124 Mtetra
.68948 .21124 .69577 .21996 .70914 .21525 .70289 .20649 Mtetra
.70289 .20649 .70914 .21525 .72257 .21051 .71637 .20172 Mtetra
.71637 .20172 .72257 .21051 .73607 .20576 .72991 .19692 Mtetra
.72991 .19692 .73607 .20576 .74963 .20098 .74352 .1921 Mtetra
.74352 .1921 .74963 .20098 .76326 .19618 .75719 .18726 Mtetra
.75719 .18726 .76326 .19618 .77695 .19136 .77093 .18239 Mtetra
.77093 .18239 .77695 .19136 .79071 .18651 .78473 .1775 Mtetra
.78473 .1775 .79071 .18651 .80453 .18164 .7986 .17259 Mtetra
.66 .746 .914 r
.16464 .43662 .17259 .4438 .18386 .43992 .17593 .43271 Mtetra
.17593 .43271 .18386 .43992 .19517 .43602 .18727 .42878 Mtetra
.18727 .42878 .19517 .43602 .20654 .4321 .19867 .42483 Mtetra
.19867 .42483 .20654 .4321 .21629 .44575 .21011 .42086 Mtetra
.144 .186 .647 r
.21011 .42086 .21629 .44575 .22782 .44182 .21995 .43451 Mtetra
.659 .748 .916 r
.21995 .43451 .22782 .44182 .23939 .43787 .23156 .43053 Mtetra
.23156 .43053 .23939 .43787 .25102 .4339 .24322 .42653 Mtetra
.926 .542 .233 r
.24322 .42653 .25102 .4339 .2598 .4658 .25193 .45846 Mtetra
.656 .751 .92 r
.25193 .45846 .2598 .4658 .27166 .46184 .26382 .45446 Mtetra
.26382 .45446 .27166 .46184 .28356 .45785 .27576 .45045 Mtetra
.27576 .45045 .28356 .45785 .29553 .45385 .28775 .44641 Mtetra
.953 .652 .425 r
.28775 .44641 .29553 .45385 .30003 .56292 .29199 .55568 Mtetra
.646 .762 .934 r
.29199 .55568 .30003 .56292 .3125 .55901 .3045 .55173 Mtetra
.3045 .55173 .3125 .55901 .32503 .55507 .31706 .54777 Mtetra
.31706 .54777 .32503 .55507 .33762 .55113 .32969 .54378 Mtetra
.32969 .54378 .33762 .55113 .35027 .54716 .34238 .53978 Mtetra
.34238 .53978 .35027 .54716 .36298 .54317 .35512 .53576 Mtetra
.35512 .53576 .36298 .54317 .37575 .53916 .36793 .53172 Mtetra
.953 .715 .54 r
.36793 .53172 .37575 .53916 .39359 .412 .38611 .40427 Mtetra
.657 .751 .919 r
.38611 .40427 .39359 .412 .40602 .40782 .39858 .40005 Mtetra
.39858 .40005 .40602 .40782 .41851 .40362 .41111 .39581 Mtetra
.41111 .39581 .41851 .40362 .43106 .3994 .42369 .39156 Mtetra
.42369 .39156 .43106 .3994 .44366 .39516 .43633 .38728 Mtetra
.43633 .38728 .44366 .39516 .45633 .3909 .44904 .38298 Mtetra
.44904 .38298 .45633 .3909 .46905 .38662 .4618 .37867 Mtetra
.4618 .37867 .46905 .38662 .48184 .38232 .47462 .37433 Mtetra
.47462 .37433 .48184 .38232 .49468 .378 .48751 .36997 Mtetra
.48751 .36997 .49468 .378 .50759 .37366 .50045 .36559 Mtetra
.50045 .36559 .50759 .37366 .52055 .3693 .51346 .36119 Mtetra
.51346 .36119 .52055 .3693 .53358 .36492 .52652 .35677 Mtetra
.52652 .35677 .53358 .36492 .54599 .26207 .53965 .35233 Mtetra
0 0 .21 r
.53965 .35233 .54599 .26207 .55874 .25755 .55198 .24917 Mtetra
.664 .741 .908 r
.55198 .24917 .55874 .25755 .57154 .25302 .56482 .24459 Mtetra
.56482 .24459 .57154 .25302 .5844 .24846 .57772 .24 Mtetra
.57772 .24 .5844 .24846 .59732 .24389 .59068 .23538 Mtetra
.59068 .23538 .59732 .24389 .6103 .23929 .6037 .23074 Mtetra
.6037 .23074 .6103 .23929 .62334 .23467 .61678 .22608 Mtetra
.61678 .22608 .62334 .23467 .63645 .23003 .62993 .2214 Mtetra
.62993 .2214 .63645 .23003 .64961 .22536 .64313 .2167 Mtetra
.64313 .2167 .64961 .22536 .66284 .22068 .6564 .21197 Mtetra
.6564 .21197 .66284 .22068 .67612 .21597 .66973 .20722 Mtetra
.66973 .20722 .67612 .21597 .68948 .21124 .68313 .20245 Mtetra
.68313 .20245 .68948 .21124 .70289 .20649 .69659 .19766 Mtetra
.69659 .19766 .70289 .20649 .71637 .20172 .71011 .19284 Mtetra
.71011 .19284 .71637 .20172 .72991 .19692 .72369 .188 Mtetra
.72369 .188 .72991 .19692 .74352 .1921 .73735 .18314 Mtetra
.73735 .18314 .74352 .1921 .75719 .18726 .75106 .17826 Mtetra
.75106 .17826 .75719 .18726 .77093 .18239 .76485 .17335 Mtetra
.76485 .17335 .77093 .18239 .78473 .1775 .7787 .16841 Mtetra
.7787 .16841 .78473 .1775 .7986 .17259 .79262 .16346 Mtetra
.66 .746 .914 r
.15661 .42938 .16464 .43662 .17593 .43271 .16794 .42544 Mtetra
.16794 .42544 .17593 .43271 .18727 .42878 .17931 .42147 Mtetra
.17931 .42147 .18727 .42878 .19867 .42483 .19073 .41749 Mtetra
.19073 .41749 .19867 .42483 .21011 .42086 .2022 .41349 Mtetra
.2022 .41349 .21011 .42086 .21995 .43451 .21373 .40948 Mtetra
.606 .493 .698 r
.21373 .40948 .21995 .43451 .23156 .43053 .2253 .40544 Mtetra
.919 .616 .136 r
.2253 .40544 .23156 .43053 .24322 .42653 .23214 .45508 Mtetra
.426 .102 .31 r
.23214 .45508 .24322 .42653 .25193 .45846 .244 .45106 Mtetra
.656 .751 .92 r
.244 .45106 .25193 .45846 .26382 .45446 .25592 .44703 Mtetra
.25592 .44703 .26382 .45446 .27576 .45045 .26789 .44298 Mtetra
.26789 .44298 .27576 .45045 .28775 .44641 .27992 .43891 Mtetra
.953 .652 .425 r
.27992 .43891 .28775 .44641 .29199 .55568 .28388 .54838 Mtetra
.646 .762 .934 r
.28388 .54838 .29199 .55568 .3045 .55173 .29642 .5444 Mtetra
.29642 .5444 .3045 .55173 .31706 .54777 .30902 .5404 Mtetra
.30902 .5404 .31706 .54777 .32969 .54378 .32169 .53638 Mtetra
.32169 .53638 .32969 .54378 .34238 .53978 .33441 .53234 Mtetra
.33441 .53234 .34238 .53978 .35512 .53576 .3472 .52828 Mtetra
.952 .714 .542 r
.3472 .52828 .35512 .53576 .36793 .53172 .36613 .4007 Mtetra
.547 .344 .557 r
.36613 .4007 .36793 .53172 .38611 .40427 .37857 .39647 Mtetra
.657 .751 .919 r
.37857 .39647 .38611 .40427 .39858 .40005 .39108 .39221 Mtetra
.39108 .39221 .39858 .40005 .41111 .39581 .40364 .38794 Mtetra
.40364 .38794 .41111 .39581 .42369 .39156 .41626 .38365 Mtetra
.41626 .38365 .42369 .39156 .43633 .38728 .42894 .37933 Mtetra
.42894 .37933 .43633 .38728 .44904 .38298 .44168 .375 Mtetra
.44168 .375 .44904 .38298 .4618 .37867 .45448 .37064 Mtetra
.45448 .37064 .4618 .37867 .47462 .37433 .46734 .36627 Mtetra
.46734 .36627 .47462 .37433 .48751 .36997 .48027 .36187 Mtetra
.48027 .36187 .48751 .36997 .50045 .36559 .49325 .35745 Mtetra
.49325 .35745 .50045 .36559 .51346 .36119 .5063 .35301 Mtetra
.5063 .35301 .51346 .36119 .52652 .35677 .51941 .34856 Mtetra
.51941 .34856 .52652 .35677 .53965 .35233 .53258 .34407 Mtetra
.53258 .34407 .53965 .35233 .55198 .24917 .54581 .33957 Mtetra
0 0 .21 r
.54581 .33957 .55198 .24917 .56482 .24459 .55804 .23609 Mtetra
.664 .741 .908 r
.55804 .23609 .56482 .24459 .57772 .24 .57098 .23146 Mtetra
.57098 .23146 .57772 .24 .59068 .23538 .58398 .2268 Mtetra
.58398 .2268 .59068 .23538 .6037 .23074 .59704 .22212 Mtetra
.59704 .22212 .6037 .23074 .61678 .22608 .61017 .21742 Mtetra
.61017 .21742 .61678 .22608 .62993 .2214 .62335 .2127 Mtetra
.62335 .2127 .62993 .2214 .64313 .2167 .6366 .20796 Mtetra
.6366 .20796 .64313 .2167 .6564 .21197 .64991 .20319 Mtetra
.64991 .20319 .6564 .21197 .66973 .20722 .66328 .1984 Mtetra
.66328 .1984 .66973 .20722 .68313 .20245 .67672 .19359 Mtetra
.67672 .19359 .68313 .20245 .69659 .19766 .69023 .18875 Mtetra
.69023 .18875 .69659 .19766 .71011 .19284 .70379 .18389 Mtetra
.70379 .18389 .71011 .19284 .72369 .188 .71742 .17901 Mtetra
.71742 .17901 .72369 .188 .73735 .18314 .73112 .1741 Mtetra
.73112 .1741 .73735 .18314 .75106 .17826 .74489 .16917 Mtetra
.74489 .16917 .75106 .17826 .76485 .17335 .75872 .16422 Mtetra
.75872 .16422 .76485 .17335 .7787 .16841 .77261 .15924 Mtetra
.77261 .15924 .7787 .16841 .79262 .16346 .78658 .15424 Mtetra
.66 .746 .914 r
.14853 .42208 .15661 .42938 .16794 .42544 .15988 .41811 Mtetra
.15988 .41811 .16794 .42544 .17931 .42147 .17128 .41411 Mtetra
.17128 .41411 .17931 .42147 .19073 .41749 .18273 .4101 Mtetra
.18273 .4101 .19073 .41749 .2022 .41349 .19423 .40607 Mtetra
.19423 .40607 .2022 .41349 .21373 .40948 .20579 .40202 Mtetra
.20579 .40202 .21373 .40948 .2253 .40544 .21739 .39795 Mtetra
.945 .608 .352 r
.21739 .39795 .2253 .40544 .23214 .45508 .2241 .44765 Mtetra
.656 .751 .92 r
.2241 .44765 .23214 .45508 .244 .45106 .236 .4436 Mtetra
.236 .4436 .244 .45106 .25592 .44703 .24795 .43953 Mtetra
.24795 .43953 .25592 .44703 .26789 .44298 .25995 .43545 Mtetra
.25995 .43545 .26789 .44298 .27992 .43891 .27201 .43134 Mtetra
.953 .652 .425 r
.27201 .43134 .27992 .43891 .28388 .54838 .2757 .54101 Mtetra
.646 .762 .934 r
.2757 .54101 .28388 .54838 .29642 .5444 .28827 .537 Mtetra
.28827 .537 .29642 .5444 .30902 .5404 .30091 .53296 Mtetra
.30091 .53296 .30902 .5404 .32169 .53638 .31361 .52891 Mtetra
.31361 .52891 .32169 .53638 .33441 .53234 .32637 .52483 Mtetra
.32637 .52483 .33441 .53234 .3472 .52828 .3392 .52074 Mtetra
.952 .714 .542 r
.3392 .52074 .3472 .52828 .36613 .4007 .35849 .39287 Mtetra
.657 .751 .919 r
.35849 .39287 .36613 .4007 .37857 .39647 .37097 .3886 Mtetra
.37097 .3886 .37857 .39647 .39108 .39221 .38351 .38431 Mtetra
.38351 .38431 .39108 .39221 .40364 .38794 .39611 .38 Mtetra
.39611 .38 .40364 .38794 .41626 .38365 .40877 .37567 Mtetra
.40877 .37567 .41626 .38365 .42894 .37933 .42149 .37131 Mtetra
.42149 .37131 .42894 .37933 .44168 .375 .43426 .36694 Mtetra
.43426 .36694 .44168 .375 .45448 .37064 .4471 .36255 Mtetra
.4471 .36255 .45448 .37064 .46734 .36627 .46 .35813 Mtetra
.46 .35813 .46734 .36627 .48027 .36187 .47297 .3537 Mtetra
.47297 .3537 .48027 .36187 .49325 .35745 .48599 .34924 Mtetra
.48599 .34924 .49325 .35745 .5063 .35301 .49908 .34477 Mtetra
.49908 .34477 .5063 .35301 .51941 .34856 .51223 .34027 Mtetra
.51223 .34027 .51941 .34856 .53258 .34407 .52544 .33575 Mtetra
.52544 .33575 .53258 .34407 .54581 .33957 .53872 .3312 Mtetra
.969 .725 .513 r
.53872 .3312 .54581 .33957 .55804 .23609 .5512 .22752 Mtetra
.664 .741 .908 r
.5512 .22752 .55804 .23609 .57098 .23146 .56418 .22284 Mtetra
.56418 .22284 .57098 .23146 .58398 .2268 .57722 .21815 Mtetra
.57722 .21815 .58398 .2268 .59704 .22212 .59033 .21343 Mtetra
.59033 .21343 .59704 .22212 .61017 .21742 .60349 .20869 Mtetra
.60349 .20869 .61017 .21742 .62335 .2127 .61672 .20392 Mtetra
.61672 .20392 .62335 .2127 .6366 .20796 .63001 .19914 Mtetra
.63001 .19914 .6366 .20796 .64991 .20319 .64336 .19433 Mtetra
.64336 .19433 .64991 .20319 .66328 .1984 .65678 .1895 Mtetra
.65678 .1895 .66328 .1984 .67672 .19359 .67026 .18464 Mtetra
.67026 .18464 .67672 .19359 .69023 .18875 .68381 .17976 Mtetra
.68381 .17976 .69023 .18875 .70379 .18389 .69742 .17486 Mtetra
.69742 .17486 .70379 .18389 .71742 .17901 .7111 .16993 Mtetra
.7111 .16993 .71742 .17901 .73112 .1741 .72484 .16498 Mtetra
.72484 .16498 .73112 .1741 .74489 .16917 .73865 .16001 Mtetra
.73865 .16001 .74489 .16917 .75872 .16422 .75253 .15501 Mtetra
.75253 .15501 .75872 .16422 .77261 .15924 .76647 .14999 Mtetra
.76647 .14999 .77261 .15924 .78658 .15424 .78049 .14494 Mtetra
.66 .746 .914 r
.14037 .41473 .14853 .42208 .15988 .41811 .15175 .41072 Mtetra
.15175 .41072 .15988 .41811 .17128 .41411 .16318 .40669 Mtetra
.16318 .40669 .17128 .41411 .18273 .4101 .17466 .40264 Mtetra
.17466 .40264 .18273 .4101 .19423 .40607 .18619 .39858 Mtetra
.18619 .39858 .19423 .40607 .20579 .40202 .19778 .39449 Mtetra
.19778 .39449 .20579 .40202 .21739 .39795 .20941 .39039 Mtetra
.945 .608 .352 r
.20941 .39039 .21739 .39795 .2241 .44765 .216 .44016 Mtetra
.656 .751 .92 r
.216 .44016 .2241 .44765 .236 .4436 .22793 .43608 Mtetra
.22793 .43608 .236 .4436 .24795 .43953 .23991 .43197 Mtetra
.23991 .43197 .24795 .43953 .25995 .43545 .25194 .42785 Mtetra
.924 .536 .217 r
.25194 .42785 .25995 .43545 .27201 .43134 .26106 .46081 Mtetra
.837 .531 .471 r
.26106 .46081 .27201 .43134 .2757 .54101 .26744 .53358 Mtetra
.646 .762 .934 r
.26744 .53358 .2757 .54101 .28827 .537 .28005 .52953 Mtetra
.28005 .52953 .28827 .537 .30091 .53296 .29273 .52546 Mtetra
.29273 .52546 .30091 .53296 .31361 .52891 .30547 .52137 Mtetra
.30547 .52137 .31361 .52891 .32637 .52483 .31827 .51726 Mtetra
.951 .714 .545 r
.31827 .51726 .32637 .52483 .3392 .52074 .33832 .38926 Mtetra
.544 .34 .554 r
.33832 .38926 .3392 .52074 .35849 .39287 .35078 .38497 Mtetra
.657 .751 .919 r
.35078 .38497 .35849 .39287 .37097 .3886 .3633 .38066 Mtetra
.3633 .38066 .37097 .3886 .38351 .38431 .37588 .37633 Mtetra
.37588 .37633 .38351 .38431 .39611 .38 .38851 .37198 Mtetra
.38851 .37198 .39611 .38 .40877 .37567 .40121 .36762 Mtetra
.40121 .36762 .40877 .37567 .42149 .37131 .41396 .36323 Mtetra
.41396 .36323 .42149 .37131 .43426 .36694 .42678 .35881 Mtetra
.42678 .35881 .43426 .36694 .4471 .36255 .43966 .35438 Mtetra
.43966 .35438 .4471 .36255 .46 .35813 .4526 .34993 Mtetra
.4526 .34993 .46 .35813 .47297 .3537 .4656 .34546 Mtetra
.4656 .34546 .47297 .3537 .48599 .34924 .47866 .34096 Mtetra
.47866 .34096 .48599 .34924 .49908 .34477 .49179 .33644 Mtetra
.49179 .33644 .49908 .34477 .51223 .34027 .50498 .3319 Mtetra
.50498 .3319 .51223 .34027 .52544 .33575 .51824 .32734 Mtetra
.51824 .32734 .52544 .33575 .53872 .3312 .53155 .32276 Mtetra
.96 .748 .573 r
.53155 .32276 .53872 .3312 .5512 .22752 .54459 .26321 Mtetra
0 0 .022 r
.54459 .26321 .5512 .22752 .56418 .22284 .55732 .21416 Mtetra
.664 .741 .908 r
.55732 .21416 .56418 .22284 .57722 .21815 .57041 .20942 Mtetra
.57041 .20942 .57722 .21815 .59033 .21343 .58355 .20466 Mtetra
.58355 .20466 .59033 .21343 .60349 .20869 .59676 .19987 Mtetra
.59676 .19987 .60349 .20869 .61672 .20392 .61003 .19507 Mtetra
.61003 .19507 .61672 .20392 .63001 .19914 .62336 .19024 Mtetra
.62336 .19024 .63001 .19914 .64336 .19433 .63676 .18539 Mtetra
.63676 .18539 .64336 .19433 .65678 .1895 .65022 .18051 Mtetra
.65022 .18051 .65678 .1895 .67026 .18464 .66374 .17561 Mtetra
.66374 .17561 .67026 .18464 .68381 .17976 .67734 .17069 Mtetra
.67734 .17069 .68381 .17976 .69742 .17486 .69099 .16575 Mtetra
.69099 .16575 .69742 .17486 .7111 .16993 .70472 .16078 Mtetra
.70472 .16078 .7111 .16993 .72484 .16498 .7185 .15578 Mtetra
.7185 .15578 .72484 .16498 .73865 .16001 .73236 .15076 Mtetra
.73236 .15076 .73865 .16001 .75253 .15501 .74629 .14572 Mtetra
.74629 .14572 .75253 .15501 .76647 .14999 .76028 .14065 Mtetra
.76028 .14065 .76647 .14999 .78049 .14494 .77434 .13556 Mtetra
.66 .746 .914 r
.13215 .40731 .14037 .41473 .15175 .41072 .14356 .40326 Mtetra
.14356 .40326 .15175 .41072 .16318 .40669 .15502 .3992 Mtetra
.15502 .3992 .16318 .40669 .17466 .40264 .16653 .39512 Mtetra
.16653 .39512 .17466 .40264 .18619 .39858 .17809 .39102 Mtetra
.17809 .39102 .18619 .39858 .19778 .39449 .1897 .38691 Mtetra
.1897 .38691 .19778 .39449 .20941 .39039 .20137 .38277 Mtetra
.949 .646 .427 r
.20137 .38277 .20941 .39039 .216 .44016 .20422 .46962 Mtetra
.419 .091 .3 r
.20422 .46962 .216 .44016 .22793 .43608 .21631 .46554 Mtetra
.21631 .46554 .22793 .43608 .23991 .43197 .22845 .46144 Mtetra
.22845 .46144 .23991 .43197 .25194 .42785 .24065 .45733 Mtetra
.24065 .45733 .25194 .42785 .26106 .46081 .25291 .45319 Mtetra
.653 .755 .925 r
.25291 .45319 .26106 .46081 .26744 .53358 .26523 .44903 Mtetra
0 0 .337 r
.26523 .44903 .26744 .53358 .28005 .52953 .27176 .522 Mtetra
.936 .734 .605 r
.27176 .522 .28005 .52953 .29273 .52546 .28867 .45963 Mtetra
.56 .379 .594 r
.28867 .45963 .29273 .52546 .30547 .52137 .30123 .45544 Mtetra
.30123 .45544 .30547 .52137 .31827 .51726 .31385 .45122 Mtetra
.782 .548 .583 r
.31385 .45122 .31827 .51726 .33832 .38926 .33051 .38133 Mtetra
.657 .751 .919 r
.33051 .38133 .33832 .38926 .35078 .38497 .34301 .377 Mtetra
.34301 .377 .35078 .38497 .3633 .38066 .35556 .37265 Mtetra
.35556 .37265 .3633 .38066 .37588 .37633 .36817 .36829 Mtetra
.36817 .36829 .37588 .37633 .38851 .37198 .38085 .3639 Mtetra
.38085 .3639 .38851 .37198 .40121 .36762 .39358 .35949 Mtetra
.39358 .35949 .40121 .36762 .41396 .36323 .40638 .35507 Mtetra
.40638 .35507 .41396 .36323 .42678 .35881 .41923 .35062 Mtetra
.41923 .35062 .42678 .35881 .43966 .35438 .43215 .34615 Mtetra
.43215 .34615 .43966 .35438 .4526 .34993 .44513 .34165 Mtetra
.44513 .34165 .4526 .34993 .4656 .34546 .45817 .33714 Mtetra
.45817 .33714 .4656 .34546 .47866 .34096 .47127 .3326 Mtetra
.47127 .3326 .47866 .34096 .49179 .33644 .48444 .32805 Mtetra
.955 .745 .58 r
.48444 .32805 .49179 .33644 .50498 .3319 .49815 .26858 Mtetra
.562 .383 .596 r
.49815 .26858 .50498 .3319 .51824 .32734 .51121 .26393 Mtetra
.51121 .26393 .51824 .32734 .53155 .32276 .52434 .25925 Mtetra
.52434 .25925 .53155 .32276 .54459 .26321 .53753 .25456 Mtetra
.661 .745 .913 r
.53753 .25456 .54459 .26321 .55732 .21416 .55078 .24984 Mtetra
.438 .129 .343 r
.55078 .24984 .55732 .21416 .57041 .20942 .5641 .24509 Mtetra
0 0 .031 r
.5641 .24509 .57041 .20942 .58355 .20466 .57672 .19581 Mtetra
.664 .741 .908 r
.57672 .19581 .58355 .20466 .59676 .19987 .58996 .19098 Mtetra
.58996 .19098 .59676 .19987 .61003 .19507 .60328 .18614 Mtetra
.60328 .18614 .61003 .19507 .62336 .19024 .61665 .18126 Mtetra
.61665 .18126 .62336 .19024 .63676 .18539 .63009 .17637 Mtetra
.63009 .17637 .63676 .18539 .65022 .18051 .6436 .17145 Mtetra
.6436 .17145 .65022 .18051 .66374 .17561 .65717 .16651 Mtetra
.65717 .16651 .66374 .17561 .67734 .17069 .6708 .16154 Mtetra
.6708 .16154 .67734 .17069 .69099 .16575 .68451 .15655 Mtetra
.68451 .15655 .69099 .16575 .70472 .16078 .69828 .15154 Mtetra
.69828 .15154 .70472 .16078 .7185 .15578 .71211 .1465 Mtetra
.71211 .1465 .7185 .15578 .73236 .15076 .72601 .14144 Mtetra
.72601 .14144 .73236 .15076 .74629 .14572 .73999 .13635 Mtetra
.73999 .13635 .74629 .14572 .76028 .14065 .75403 .13123 Mtetra
.75403 .13123 .76028 .14065 .77434 .13556 .76814 .12609 Mtetra
.66 .746 .914 r
.12386 .39983 .13215 .40731 .14356 .40326 .1353 .39575 Mtetra
.1353 .39575 .14356 .40326 .15502 .3992 .14679 .39166 Mtetra
.14679 .39166 .15502 .3992 .16653 .39512 .15832 .38754 Mtetra
.15832 .38754 .16653 .39512 .17809 .39102 .16992 .38341 Mtetra
.16992 .38341 .17809 .39102 .1897 .38691 .18156 .37926 Mtetra
.948 .646 .431 r
.18156 .37926 .1897 .38691 .20137 .38277 .18381 .46617 Mtetra
.487 .221 .436 r
.18381 .46617 .20137 .38277 .20422 .46962 .19587 .46208 Mtetra
.653 .755 .925 r
.19587 .46208 .20422 .46962 .21631 .46554 .20799 .45796 Mtetra
.20799 .45796 .21631 .46554 .22845 .46144 .22017 .45383 Mtetra
.22017 .45383 .22845 .46144 .24065 .45733 .2324 .44967 Mtetra
.2324 .44967 .24065 .45733 .25291 .45319 .24469 .4455 Mtetra
.24469 .4455 .25291 .45319 .26523 .44903 .25704 .44131 Mtetra
.701 .202 0 r
.25704 .44131 .26523 .44903 .27176 .522 .26796 .45608 Mtetra
.558 .378 .593 r
.26796 .45608 .27176 .522 .28867 .45963 .2805 .45187 Mtetra
.651 .757 .927 r
.2805 .45187 .28867 .45963 .30123 .45544 .2931 .44764 Mtetra
.2931 .44764 .30123 .45544 .31385 .45122 .30575 .44338 Mtetra
.30575 .44338 .31385 .45122 .33051 .38133 .31847 .43911 Mtetra
0 0 0 r
.31847 .43911 .33051 .38133 .34301 .377 .33517 .36896 Mtetra
.657 .751 .919 r
.33517 .36896 .34301 .377 .35556 .37265 .34776 .36458 Mtetra
.34776 .36458 .35556 .37265 .36817 .36829 .36041 .36017 Mtetra
.36041 .36017 .36817 .36829 .38085 .3639 .37312 .35575 Mtetra
.37312 .35575 .38085 .3639 .39358 .35949 .38589 .3513 Mtetra
.38589 .3513 .39358 .35949 .40638 .35507 .39872 .34683 Mtetra
.39872 .34683 .40638 .35507 .41923 .35062 .41162 .34235 Mtetra
.41162 .34235 .41923 .35062 .43215 .34615 .42457 .33783 Mtetra
.42457 .33783 .43215 .34615 .44513 .34165 .43759 .3333 Mtetra
.43759 .3333 .44513 .34165 .45817 .33714 .45067 .32875 Mtetra
.952 .744 .584 r
.45067 .32875 .45817 .33714 .47127 .3326 .46488 .26929 Mtetra
.561 .381 .595 r
.46488 .26929 .47127 .3326 .48444 .32805 .47786 .26465 Mtetra
.47786 .26465 .48444 .32805 .49815 .26858 .4909 .25997 Mtetra
.661 .745 .913 r
.4909 .25997 .49815 .26858 .51121 .26393 .50401 .25528 Mtetra
.50401 .25528 .51121 .26393 .52434 .25925 .51718 .25056 Mtetra
.51718 .25056 .52434 .25925 .53753 .25456 .53041 .24582 Mtetra
.53041 .24582 .53753 .25456 .55078 .24984 .5437 .24106 Mtetra
.5437 .24106 .55078 .24984 .5641 .24509 .55706 .23628 Mtetra
.55706 .23628 .5641 .24509 .57672 .19581 .57049 .23147 Mtetra
0 0 .031 r
.57049 .23147 .57672 .19581 .58996 .19098 .58311 .18202 Mtetra
.664 .741 .908 r
.58311 .18202 .58996 .19098 .60328 .18614 .59647 .17712 Mtetra
.59647 .17712 .60328 .18614 .61665 .18126 .60989 .17221 Mtetra
.60989 .17221 .61665 .18126 .63009 .17637 .62337 .16727 Mtetra
.62337 .16727 .63009 .17637 .6436 .17145 .63692 .16231 Mtetra
.63692 .16231 .6436 .17145 .65717 .16651 .65053 .15732 Mtetra
.65053 .15732 .65717 .16651 .6708 .16154 .66421 .15231 Mtetra
.66421 .15231 .6708 .16154 .68451 .15655 .67796 .14728 Mtetra
.67796 .14728 .68451 .15655 .69828 .15154 .69178 .14222 Mtetra
.69178 .14222 .69828 .15154 .71211 .1465 .70566 .13713 Mtetra
.70566 .13713 .71211 .1465 .72601 .14144 .71961 .13202 Mtetra
.71961 .13202 .72601 .14144 .73999 .13635 .73363 .12689 Mtetra
.73363 .12689 .73999 .13635 .75403 .13123 .74772 .12173 Mtetra
.74772 .12173 .75403 .13123 .76814 .12609 .76188 .11654 Mtetra
.66 .746 .914 r
.1155 .39229 .12386 .39983 .1353 .39575 .12697 .38818 Mtetra
.12697 .38818 .1353 .39575 .14679 .39166 .13849 .38405 Mtetra
.13849 .38405 .14679 .39166 .15832 .38754 .15005 .3799 Mtetra
.15005 .3799 .15832 .38754 .16992 .38341 .16167 .37573 Mtetra
.947 .646 .435 r
.16167 .37573 .16992 .38341 .18156 .37926 .16332 .46271 Mtetra
.484 .217 .433 r
.16332 .46271 .18156 .37926 .18381 .46617 .17535 .4586 Mtetra
.653 .755 .925 r
.17535 .4586 .18381 .46617 .19587 .46208 .18745 .45446 Mtetra
.18745 .45446 .19587 .46208 .20799 .45796 .1996 .45031 Mtetra
.1996 .45031 .20799 .45796 .22017 .45383 .21181 .44614 Mtetra
.21181 .44614 .22017 .45383 .2324 .44967 .22408 .44195 Mtetra
.22408 .44195 .2324 .44967 .24469 .4455 .2364 .43774 Mtetra
.2364 .43774 .24469 .4455 .25704 .44131 .24879 .43351 Mtetra
.701 .202 0 r
.24879 .43351 .25704 .44131 .26796 .45608 .25969 .44829 Mtetra
.651 .757 .927 r
.25969 .44829 .26796 .45608 .2805 .45187 .27226 .44404 Mtetra
.27226 .44404 .2805 .45187 .2931 .44764 .28489 .43977 Mtetra
.28489 .43977 .2931 .44764 .30575 .44338 .29759 .43548 Mtetra
.29759 .43548 .30575 .44338 .31847 .43911 .31034 .43117 Mtetra
.943 .731 .586 r
.31034 .43117 .31847 .43911 .33517 .36896 .32726 .36085 Mtetra
.657 .751 .919 r
.32726 .36085 .33517 .36896 .34776 .36458 .33988 .35643 Mtetra
.33988 .35643 .34776 .36458 .36041 .36017 .35257 .35199 Mtetra
.35257 .35199 .36041 .36017 .37312 .35575 .36532 .34752 Mtetra
.36532 .34752 .37312 .35575 .38589 .3513 .37813 .34304 Mtetra
.37813 .34304 .38589 .3513 .39872 .34683 .391 .33853 Mtetra
.391 .33853 .39872 .34683 .41162 .34235 .40393 .334 Mtetra
.948 .741 .59 r
.40393 .334 .41162 .34235 .42457 .33783 .4188 .27463 Mtetra
.56 .38 .594 r
.4188 .27463 .42457 .33783 .43759 .3333 .43164 .27001 Mtetra
.43164 .27001 .43759 .3333 .45067 .32875 .44454 .26536 Mtetra
.44454 .26536 .45067 .32875 .46488 .26929 .45749 .26069 Mtetra
.661 .745 .913 r
.45749 .26069 .46488 .26929 .47786 .26465 .47051 .256 Mtetra
.47051 .256 .47786 .26465 .4909 .25997 .4836 .25129 Mtetra
.4836 .25129 .4909 .25997 .50401 .25528 .49674 .24655 Mtetra
.49674 .24655 .50401 .25528 .51718 .25056 .50995 .2418 Mtetra
.50995 .2418 .51718 .25056 .53041 .24582 .52322 .23701 Mtetra
.52322 .23701 .53041 .24582 .5437 .24106 .53656 .23221 Mtetra
.53656 .23221 .5437 .24106 .55706 .23628 .54996 .22738 Mtetra
.54996 .22738 .55706 .23628 .57049 .23147 .56343 .22253 Mtetra
.56343 .22253 .57049 .23147 .58311 .18202 .57696 .21765 Mtetra
0 0 .031 r
.57696 .21765 .58311 .18202 .59647 .17712 .5896 .16803 Mtetra
.664 .741 .908 r
.5896 .16803 .59647 .17712 .60989 .17221 .60306 .16307 Mtetra
.60306 .16307 .60989 .17221 .62337 .16727 .61659 .15809 Mtetra
.61659 .15809 .62337 .16727 .63692 .16231 .63018 .15308 Mtetra
.63018 .15308 .63692 .16231 .65053 .15732 .64384 .14805 Mtetra
.64384 .14805 .65053 .15732 .66421 .15231 .65757 .143 Mtetra
.65757 .143 .66421 .15231 .67796 .14728 .67136 .13792 Mtetra
.67136 .13792 .67796 .14728 .69178 .14222 .68522 .13281 Mtetra
.68522 .13281 .69178 .14222 .70566 .13713 .69915 .12768 Mtetra
.69915 .12768 .70566 .13713 .71961 .13202 .71315 .12252 Mtetra
.71315 .12252 .71961 .13202 .73363 .12689 .72722 .11734 Mtetra
.72722 .11734 .73363 .12689 .74772 .12173 .74135 .11213 Mtetra
.74135 .11213 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.66 .746 .914 r
.10708 .38468 .1155 .39229 .12697 .38818 .11857 .38054 Mtetra
.11857 .38054 .12697 .38818 .13849 .38405 .13012 .37637 Mtetra
.13012 .37637 .13849 .38405 .15005 .3799 .14171 .37219 Mtetra
.14171 .37219 .15005 .3799 .16167 .37573 .15336 .36799 Mtetra
.947 .646 .435 r
.15336 .36799 .16167 .37573 .16332 .46271 .15475 .4551 Mtetra
.653 .755 .925 r
.15475 .4551 .16332 .46271 .17535 .4586 .16683 .45095 Mtetra
.16683 .45095 .17535 .4586 .18745 .45446 .17895 .44679 Mtetra
.17895 .44679 .18745 .45446 .1996 .45031 .19114 .4426 Mtetra
.19114 .4426 .1996 .45031 .21181 .44614 .20338 .43839 Mtetra
.20338 .43839 .21181 .44614 .22408 .44195 .21568 .43417 Mtetra
.21568 .43417 .22408 .44195 .2364 .43774 .22804 .42992 Mtetra
.22804 .42992 .2364 .43774 .24879 .43351 .24046 .42565 Mtetra
.701 .202 0 r
.24046 .42565 .24879 .43351 .25969 .44829 .25134 .44043 Mtetra
.651 .757 .927 r
.25134 .44043 .25969 .44829 .27226 .44404 .26395 .43614 Mtetra
.26395 .43614 .27226 .44404 .28489 .43977 .27662 .43183 Mtetra
.27662 .43183 .28489 .43977 .29759 .43548 .28935 .4275 Mtetra
.28935 .4275 .29759 .43548 .31034 .43117 .30214 .42315 Mtetra
.943 .731 .586 r
.30214 .42315 .31034 .43117 .32726 .36085 .31928 .35267 Mtetra
.657 .751 .919 r
.31928 .35267 .32726 .36085 .33988 .35643 .33194 .34821 Mtetra
.33194 .34821 .33988 .35643 .35257 .35199 .34466 .34373 Mtetra
.34466 .34373 .35257 .35199 .36532 .34752 .35745 .33922 Mtetra
.35745 .33922 .36532 .34752 .37813 .34304 .3703 .3347 Mtetra
.945 .739 .593 r
.3703 .3347 .37813 .34304 .391 .33853 .38567 .27534 Mtetra
.559 .378 .593 r
.38567 .27534 .391 .33853 .40393 .334 .39842 .27072 Mtetra
.39842 .27072 .40393 .334 .4188 .27463 .41123 .26608 Mtetra
.661 .745 .913 r
.41123 .26608 .4188 .27463 .43164 .27001 .42411 .26141 Mtetra
.42411 .26141 .43164 .27001 .44454 .26536 .43704 .25673 Mtetra
.43704 .25673 .44454 .26536 .45749 .26069 .45004 .25202 Mtetra
.45004 .25202 .45749 .26069 .47051 .256 .4631 .24728 Mtetra
.4631 .24728 .47051 .256 .4836 .25129 .47622 .24253 Mtetra
.47622 .24253 .4836 .25129 .49674 .24655 .48941 .23775 Mtetra
.48941 .23775 .49674 .24655 .50995 .2418 .50266 .23295 Mtetra
.50266 .23295 .50995 .2418 .52322 .23701 .51597 .22813 Mtetra
.51597 .22813 .52322 .23701 .53656 .23221 .52935 .22328 Mtetra
.52935 .22328 .53656 .23221 .54996 .22738 .5428 .21841 Mtetra
.5428 .21841 .54996 .22738 .56343 .22253 .55631 .21351 Mtetra
.55631 .21351 .56343 .22253 .57696 .21765 .56989 .20859 Mtetra
.56989 .20859 .57696 .21765 .5896 .16803 .58353 .20365 Mtetra
0 0 .031 r
.58353 .20365 .5896 .16803 .60306 .16307 .59617 .15386 Mtetra
.664 .741 .908 r
.59617 .15386 .60306 .16307 .61659 .15809 .60974 .14883 Mtetra
.60974 .14883 .61659 .15809 .63018 .15308 .62338 .14378 Mtetra
.62338 .14378 .63018 .15308 .64384 .14805 .63708 .1387 Mtetra
.63708 .1387 .64384 .14805 .65757 .143 .65086 .1336 Mtetra
.65086 .1336 .65757 .143 .67136 .13792 .6647 .12847 Mtetra
.6647 .12847 .67136 .13792 .68522 .13281 .6786 .12332 Mtetra
.6786 .12332 .68522 .13281 .69915 .12768 .69258 .11814 Mtetra
.69258 .11814 .69915 .12768 .71315 .12252 .70663 .11294 Mtetra
.70663 .11294 .71315 .12252 .72722 .11734 .72074 .10771 Mtetra
.72074 .10771 .72722 .11734 .74135 .11213 .73493 .10245 Mtetra
.73493 .10245 .74135 .11213 .75556 .1069 .74918 .09717 Mtetra
.66 .746 .914 r
.09858 .37702 .10708 .38468 .11857 .38054 .1101 .37283 Mtetra
.1101 .37283 .11857 .38054 .13012 .37637 .12168 .36864 Mtetra
.12168 .36864 .13012 .37637 .14171 .37219 .1333 .36442 Mtetra
.946 .647 .439 r
.1333 .36442 .14171 .37219 .15336 .36799 .13407 .45159 Mtetra
.479 .21 .427 r
.13407 .45159 .15336 .36799 .15475 .4551 .14612 .44743 Mtetra
.653 .755 .925 r
.14612 .44743 .15475 .4551 .16683 .45095 .15822 .44324 Mtetra
.15822 .44324 .16683 .45095 .17895 .44679 .17038 .43904 Mtetra
.17038 .43904 .17895 .44679 .19114 .4426 .1826 .43482 Mtetra
.1826 .43482 .19114 .4426 .20338 .43839 .19488 .43057 Mtetra
.19488 .43057 .20338 .43839 .21568 .43417 .20721 .42631 Mtetra
.20721 .42631 .21568 .43417 .22804 .42992 .21961 .42202 Mtetra
.21961 .42202 .22804 .42992 .24046 .42565 .23206 .41772 Mtetra
.701 .202 0 r
.23206 .41772 .24046 .42565 .25134 .44043 .24292 .4325 Mtetra
.651 .757 .927 r
.24292 .4325 .25134 .44043 .26395 .43614 .25556 .42817 Mtetra
.25556 .42817 .26395 .43614 .27662 .43183 .26827 .42382 Mtetra
.26827 .42382 .27662 .43183 .28935 .4275 .28104 .41945 Mtetra
.28104 .41945 .28935 .4275 .30214 .42315 .29387 .41507 Mtetra
.943 .731 .586 r
.29387 .41507 .30214 .42315 .31928 .35267 .31123 .34442 Mtetra
.657 .751 .919 r
.31123 .34442 .31928 .35267 .33194 .34821 .32393 .33992 Mtetra
.32393 .33992 .33194 .34821 .34466 .34373 .33669 .3354 Mtetra
.943 .738 .597 r
.33669 .3354 .34466 .34373 .35745 .33922 .35256 .27605 Mtetra
.557 .376 .592 r
.35256 .27605 .35745 .33922 .3703 .3347 .36523 .27143 Mtetra
.36523 .27143 .3703 .3347 .38567 .27534 .37796 .26679 Mtetra
.661 .745 .913 r
.37796 .26679 .38567 .27534 .39842 .27072 .39075 .26213 Mtetra
.39075 .26213 .39842 .27072 .41123 .26608 .4036 .25745 Mtetra
.4036 .25745 .41123 .26608 .42411 .26141 .41651 .25274 Mtetra
.41651 .25274 .42411 .26141 .43704 .25673 .42948 .24801 Mtetra
.42948 .24801 .43704 .25673 .45004 .25202 .44252 .24326 Mtetra
.44252 .24326 .45004 .25202 .4631 .24728 .45562 .23849 Mtetra
.45562 .23849 .4631 .24728 .47622 .24253 .46878 .23369 Mtetra
.46878 .23369 .47622 .24253 .48941 .23775 .48201 .22887 Mtetra
.48201 .22887 .48941 .23775 .50266 .23295 .4953 .22403 Mtetra
.4953 .22403 .50266 .23295 .51597 .22813 .50866 .21916 Mtetra
.50866 .21916 .51597 .22813 .52935 .22328 .52208 .21427 Mtetra
.52208 .21427 .52935 .22328 .5428 .21841 .53557 .20935 Mtetra
.53557 .20935 .5428 .21841 .55631 .21351 .54912 .20441 Mtetra
.54912 .20441 .55631 .21351 .56989 .20859 .56275 .19944 Mtetra
.56275 .19944 .56989 .20859 .58353 .20365 .57643 .19446 Mtetra
.57643 .19446 .58353 .20365 .59617 .15386 .59019 .18944 Mtetra
0 0 .031 r
.59019 .18944 .59617 .15386 .60974 .14883 .60283 .13948 Mtetra
.664 .741 .908 r
.60283 .13948 .60974 .14883 .62338 .14378 .61652 .13438 Mtetra
.61652 .13438 .62338 .14378 .63708 .1387 .63027 .12926 Mtetra
.63027 .12926 .63708 .1387 .65086 .1336 .64408 .12411 Mtetra
.64408 .12411 .65086 .1336 .6647 .12847 .65797 .11894 Mtetra
.65797 .11894 .6647 .12847 .6786 .12332 .67193 .11374 Mtetra
.67193 .11374 .6786 .12332 .69258 .11814 .68595 .10851 Mtetra
.68595 .10851 .69258 .11814 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.66 .746 .914 r
.09001 .36928 .09858 .37702 .1101 .37283 .10156 .36507 Mtetra
.10156 .36507 .1101 .37283 .12168 .36864 .11316 .36083 Mtetra
.945 .647 .443 r
.11316 .36083 .12168 .36864 .1333 .36442 .11331 .44807 Mtetra
.476 .206 .424 r
.11331 .44807 .1333 .36442 .13407 .45159 .12533 .44389 Mtetra
.653 .755 .925 r
.12533 .44389 .13407 .45159 .14612 .44743 .13741 .43969 Mtetra
.13741 .43969 .14612 .44743 .15822 .44324 .14954 .43547 Mtetra
.14954 .43547 .15822 .44324 .17038 .43904 .16174 .43123 Mtetra
.16174 .43123 .17038 .43904 .1826 .43482 .17399 .42697 Mtetra
.17399 .42697 .1826 .43482 .19488 .43057 .1863 .42268 Mtetra
.1863 .42268 .19488 .43057 .20721 .42631 .19867 .41838 Mtetra
.19867 .41838 .20721 .42631 .21961 .42202 .2111 .41406 Mtetra
.709 .21 0 r
.2111 .41406 .21961 .42202 .23206 .41772 .2218 .42884 Mtetra
.182 0 0 r
.2218 .42884 .23206 .41772 .24292 .4325 .23442 .42449 Mtetra
.651 .757 .927 r
.23442 .42449 .24292 .4325 .25556 .42817 .2471 .42013 Mtetra
.2471 .42013 .25556 .42817 .26827 .42382 .25984 .41574 Mtetra
.25984 .41574 .26827 .42382 .28104 .41945 .27265 .41133 Mtetra
.27265 .41133 .28104 .41945 .29387 .41507 .28552 .40691 Mtetra
.951 .714 .543 r
.28552 .40691 .29387 .41507 .31123 .34442 .30695 .28135 Mtetra
.556 .375 .591 r
.30695 .28135 .31123 .34442 .32393 .33992 .31947 .27676 Mtetra
.31947 .27676 .32393 .33992 .33669 .3354 .33206 .27214 Mtetra
.33206 .27214 .33669 .3354 .35256 .27605 .3447 .26751 Mtetra
.661 .745 .913 r
.3447 .26751 .35256 .27605 .36523 .27143 .35741 .26285 Mtetra
.35741 .26285 .36523 .27143 .37796 .26679 .37017 .25817 Mtetra
.37017 .25817 .37796 .26679 .39075 .26213 .383 .25347 Mtetra
.383 .25347 .39075 .26213 .4036 .25745 .39589 .24874 Mtetra
.39589 .24874 .4036 .25745 .41651 .25274 .40884 .244 Mtetra
.40884 .244 .41651 .25274 .42948 .24801 .42186 .23922 Mtetra
.42186 .23922 .42948 .24801 .44252 .24326 .43493 .23443 Mtetra
.43493 .23443 .44252 .24326 .45562 .23849 .44807 .22961 Mtetra
.44807 .22961 .45562 .23849 .46878 .23369 .46128 .22477 Mtetra
.46128 .22477 .46878 .23369 .48201 .22887 .47455 .21991 Mtetra
.47455 .21991 .48201 .22887 .4953 .22403 .48788 .21502 Mtetra
.48788 .21502 .4953 .22403 .50866 .21916 .50128 .21011 Mtetra
.50128 .21011 .50866 .21916 .52208 .21427 .51474 .20517 Mtetra
.51474 .20517 .52208 .21427 .53557 .20935 .52828 .20021 Mtetra
.52828 .20021 .53557 .20935 .54912 .20441 .54187 .19522 Mtetra
.54187 .19522 .54912 .20441 .56275 .19944 .55554 .19022 Mtetra
.55554 .19022 .56275 .19944 .57643 .19446 .56927 .18518 Mtetra
.56927 .18518 .57643 .19446 .59019 .18944 .58308 .18012 Mtetra
.58308 .18012 .59019 .18944 .60283 .13948 .59695 .17504 Mtetra
0 0 .031 r
.59695 .17504 .60283 .13948 .61652 .13438 .60959 .12491 Mtetra
.664 .741 .908 r
.60959 .12491 .61652 .13438 .63027 .12926 .62339 .11974 Mtetra
.62339 .11974 .63027 .12926 .64408 .12411 .63725 .11454 Mtetra
.63725 .11454 .64408 .12411 .65797 .11894 .65119 .10932 Mtetra
.65119 .10932 .65797 .11894 .67193 .11374 .66519 .10407 Mtetra
.66519 .10407 .67193 .11374 .68595 .10851 .67926 .0988 Mtetra
.67926 .0988 .68595 .10851 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.66 .746 .914 r
.08137 .36149 .09001 .36928 .10156 .36507 .09295 .35723 Mtetra
.09295 .35723 .10156 .36507 .11316 .36083 .10458 .35296 Mtetra
.945 .647 .443 r
.10458 .35296 .11316 .36083 .11331 .44807 .10446 .44034 Mtetra
.653 .755 .925 r
.10446 .44034 .11331 .44807 .12533 .44389 .11651 .43612 Mtetra
.11651 .43612 .12533 .44389 .13741 .43969 .12862 .43188 Mtetra
.12862 .43188 .13741 .43969 .14954 .43547 .14079 .42762 Mtetra
.14079 .42762 .14954 .43547 .16174 .43123 .15301 .42334 Mtetra
.15301 .42334 .16174 .43123 .17399 .42697 .1653 .41905 Mtetra
.1653 .41905 .17399 .42697 .1863 .42268 .17764 .41473 Mtetra
.17764 .41473 .1863 .42268 .19867 .41838 .19005 .41039 Mtetra
.19005 .41039 .19867 .41838 .2111 .41406 .20251 .40603 Mtetra
.709 .21 0 r
.20251 .40603 .2111 .41406 .2218 .42884 .21319 .4208 Mtetra
.651 .757 .927 r
.21319 .4208 .2218 .42884 .23442 .42449 .22585 .41642 Mtetra
.22585 .41642 .23442 .42449 .2471 .42013 .23856 .41201 Mtetra
.23856 .41201 .2471 .42013 .25984 .41574 .25134 .40759 Mtetra
.25134 .40759 .25984 .41574 .27265 .41133 .26418 .40314 Mtetra
.26418 .40314 .27265 .41133 .28552 .40691 .27709 .39867 Mtetra
.951 .714 .543 r
.27709 .39867 .28552 .40691 .30695 .28135 .29891 .27286 Mtetra
.661 .745 .913 r
.29891 .27286 .30695 .28135 .31947 .27676 .31148 .26822 Mtetra
.31148 .26822 .31947 .27676 .33206 .27214 .3241 .26357 Mtetra
.3241 .26357 .33206 .27214 .3447 .26751 .33678 .25889 Mtetra
.33678 .25889 .3447 .26751 .35741 .26285 .34952 .25419 Mtetra
.34952 .25419 .35741 .26285 .37017 .25817 .36232 .24947 Mtetra
.36232 .24947 .37017 .25817 .383 .25347 .37519 .24473 Mtetra
.37519 .24473 .383 .25347 .39589 .24874 .38812 .23996 Mtetra
.38812 .23996 .39589 .24874 .40884 .244 .40111 .23517 Mtetra
.40111 .23517 .40884 .244 .42186 .23922 .41416 .23036 Mtetra
.41416 .23036 .42186 .23922 .43493 .23443 .42728 .22552 Mtetra
.42728 .22552 .43493 .23443 .44807 .22961 .44046 .22066 Mtetra
.44046 .22066 .44807 .22961 .46128 .22477 .4537 .21577 Mtetra
.4537 .21577 .46128 .22477 .47455 .21991 .46701 .21086 Mtetra
.46701 .21086 .47455 .21991 .48788 .21502 .48039 .20593 Mtetra
.48039 .20593 .48788 .21502 .50128 .21011 .49383 .20097 Mtetra
.49383 .20097 .50128 .21011 .51474 .20517 .50734 .19599 Mtetra
.50734 .19599 .51474 .20517 .52828 .20021 .52091 .19099 Mtetra
.52091 .19099 .52828 .20021 .54187 .19522 .53456 .18596 Mtetra
.53456 .18596 .54187 .19522 .55554 .19022 .54827 .1809 Mtetra
.54827 .1809 .55554 .19022 .56927 .18518 .56205 .17582 Mtetra
.56205 .17582 .56927 .18518 .58308 .18012 .57589 .17071 Mtetra
.57589 .17071 .58308 .18012 .59695 .17504 .58981 .16558 Mtetra
.58981 .16558 .59695 .17504 .60959 .12491 .6038 .16042 Mtetra
0 0 .031 r
.6038 .16042 .60959 .12491 .62339 .11974 .61645 .11012 Mtetra
.664 .741 .908 r
.61645 .11012 .62339 .11974 .63725 .11454 .63036 .10488 Mtetra
.63036 .10488 .63725 .11454 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09431 Mtetra
.65839 .09431 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.66 .746 .914 r
.07265 .35362 .08137 .36149 .09295 .35723 .08426 .34933 Mtetra
.944 .648 .447 r
.08426 .34933 .09295 .35723 .10458 .35296 .0835 .43677 Mtetra
.471 .198 .417 r
.0835 .43677 .10458 .35296 .10446 .44034 .09553 .43253 Mtetra
.653 .755 .925 r
.09553 .43253 .10446 .44034 .11651 .43612 .10761 .42828 Mtetra
.10761 .42828 .11651 .43612 .12862 .43188 .11976 .424 Mtetra
.11976 .424 .12862 .43188 .14079 .42762 .13196 .41971 Mtetra
.13196 .41971 .14079 .42762 .15301 .42334 .14422 .41539 Mtetra
.14422 .41539 .15301 .42334 .1653 .41905 .15653 .41106 Mtetra
.15653 .41106 .1653 .41905 .17764 .41473 .16891 .4067 Mtetra
.16891 .4067 .17764 .41473 .19005 .41039 .18135 .40232 Mtetra
.18135 .40232 .19005 .41039 .20251 .40603 .19385 .39792 Mtetra
.709 .21 0 r
.19385 .39792 .20251 .40603 .21319 .4208 .2045 .41269 Mtetra
.651 .757 .927 r
.2045 .41269 .21319 .4208 .22585 .41642 .21719 .40827 Mtetra
.21719 .40827 .22585 .41642 .23856 .41201 .22995 .40383 Mtetra
.22995 .40383 .23856 .41201 .25134 .40759 .24276 .39936 Mtetra
.24276 .39936 .25134 .40759 .26418 .40314 .25564 .39487 Mtetra
.95 .714 .546 r
.25564 .39487 .26418 .40314 .27709 .39867 .27827 .26894 Mtetra
.532 .323 .542 r
.27827 .26894 .27709 .39867 .29891 .27286 .29081 .26429 Mtetra
.661 .745 .913 r
.29081 .26429 .29891 .27286 .31148 .26822 .30341 .25961 Mtetra
.30341 .25961 .31148 .26822 .3241 .26357 .31606 .25492 Mtetra
.31606 .25492 .3241 .26357 .33678 .25889 .32878 .2502 Mtetra
.32878 .2502 .33678 .25889 .34952 .25419 .34156 .24546 Mtetra
.34156 .24546 .34952 .25419 .36232 .24947 .3544 .24069 Mtetra
.3544 .24069 .36232 .24947 .37519 .24473 .36731 .23591 Mtetra
.36731 .23591 .37519 .24473 .38812 .23996 .38027 .2311 Mtetra
.38027 .2311 .38812 .23996 .40111 .23517 .3933 .22626 Mtetra
.3933 .22626 .40111 .23517 .41416 .23036 .4064 .22141 Mtetra
.4064 .22141 .41416 .23036 .42728 .22552 .41955 .21653 Mtetra
.41955 .21653 .42728 .22552 .44046 .22066 .43278 .21162 Mtetra
.43278 .21162 .44046 .22066 .4537 .21577 .44606 .20669 Mtetra
.44606 .20669 .4537 .21577 .46701 .21086 .45941 .20174 Mtetra
.45941 .20174 .46701 .21086 .48039 .20593 .47283 .19676 Mtetra
.47283 .19676 .48039 .20593 .49383 .20097 .48632 .19176 Mtetra
.48632 .19176 .49383 .20097 .50734 .19599 .49987 .18673 Mtetra
.49987 .18673 .50734 .19599 .52091 .19099 .51349 .18168 Mtetra
.51349 .18168 .52091 .19099 .53456 .18596 .52717 .1766 Mtetra
.52717 .1766 .53456 .18596 .54827 .1809 .54093 .1715 Mtetra
.54093 .1715 .54827 .1809 .56205 .17582 .55475 .16637 Mtetra
.55475 .16637 .56205 .17582 .57589 .17071 .56865 .16122 Mtetra
.56865 .16122 .57589 .17071 .58981 .16558 .58261 .15604 Mtetra
.58261 .15604 .58981 .16558 .6038 .16042 .59664 .15083 Mtetra
.59664 .15083 .6038 .16042 .61645 .11012 .61075 .1456 Mtetra
0 0 .031 r
.61075 .1456 .61645 .11012 .63036 .10488 .6234 .09513 Mtetra
.664 .741 .908 r
.6234 .09513 .63036 .10488 .64434 .09961 .63742 .08981 Mtetra
.63742 .08981 .64434 .09961 .65839 .09431 .65152 .08447 Mtetra
.65152 .08447 .65839 .09431 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.943 .648 .45 r
.06386 .34569 .07265 .35362 .08426 .34933 .06246 .43319 Mtetra
.468 .194 .414 r
.06246 .43319 .08426 .34933 .0835 .43677 .07446 .42894 Mtetra
.653 .755 .925 r
.07446 .42894 .0835 .43677 .09553 .43253 .08652 .42466 Mtetra
.08652 .42466 .09553 .43253 .10761 .42828 .09864 .42037 Mtetra
.09864 .42037 .10761 .42828 .11976 .424 .11081 .41606 Mtetra
.11081 .41606 .11976 .424 .13196 .41971 .12305 .41172 Mtetra
.12305 .41172 .13196 .41971 .14422 .41539 .13534 .40737 Mtetra
.13534 .40737 .14422 .41539 .15653 .41106 .14769 .40299 Mtetra
.14769 .40299 .15653 .41106 .16891 .4067 .1601 .3986 Mtetra
.1601 .3986 .16891 .4067 .18135 .40232 .17257 .39418 Mtetra
.17257 .39418 .18135 .40232 .19385 .39792 .18511 .38974 Mtetra
.709 .21 0 r
.18511 .38974 .19385 .39792 .2045 .41269 .19574 .40451 Mtetra
.651 .757 .927 r
.19574 .40451 .2045 .41269 .21719 .40827 .20846 .40005 Mtetra
.20846 .40005 .21719 .40827 .22995 .40383 .22125 .39556 Mtetra
.22125 .39556 .22995 .40383 .24276 .39936 .23411 .39106 Mtetra
.949 .713 .548 r
.23411 .39106 .24276 .39936 .25564 .39487 .25755 .265 Mtetra
.53 .321 .541 r
.25755 .265 .25564 .39487 .27827 .26894 .27006 .26033 Mtetra
.661 .745 .913 r
.27006 .26033 .27827 .26894 .29081 .26429 .28263 .25564 Mtetra
.28263 .25564 .29081 .26429 .30341 .25961 .29527 .25093 Mtetra
.29527 .25093 .30341 .25961 .31606 .25492 .30796 .24619 Mtetra
.30796 .24619 .31606 .25492 .32878 .2502 .32072 .24143 Mtetra
.32072 .24143 .32878 .2502 .34156 .24546 .33353 .23665 Mtetra
.33353 .23665 .34156 .24546 .3544 .24069 .34641 .23184 Mtetra
.34641 .23184 .3544 .24069 .36731 .23591 .35935 .22701 Mtetra
.35935 .22701 .36731 .23591 .38027 .2311 .37236 .22216 Mtetra
.37236 .22216 .38027 .2311 .3933 .22626 .38543 .21728 Mtetra
.38543 .21728 .3933 .22626 .4064 .22141 .39856 .21238 Mtetra
.39856 .21238 .4064 .22141 .41955 .21653 .41176 .20745 Mtetra
.41176 .20745 .41955 .21653 .43278 .21162 .42502 .2025 Mtetra
.42502 .2025 .43278 .21162 .44606 .20669 .43835 .19753 Mtetra
.43835 .19753 .44606 .20669 .45941 .20174 .45174 .19253 Mtetra
.45174 .19253 .45941 .20174 .47283 .19676 .4652 .18751 Mtetra
.4652 .18751 .47283 .19676 .48632 .19176 .47873 .18246 Mtetra
.47873 .18246 .48632 .19176 .49987 .18673 .49233 .17739 Mtetra
.49233 .17739 .49987 .18673 .51349 .18168 .50599 .17229 Mtetra
.50599 .17229 .51349 .18168 .52717 .1766 .51972 .16716 Mtetra
.51972 .16716 .52717 .1766 .54093 .1715 .53352 .16201 Mtetra
.53352 .16201 .54093 .1715 .55475 .16637 .54739 .15684 Mtetra
.54739 .15684 .55475 .16637 .56865 .16122 .56133 .15163 Mtetra
.56133 .15163 .56865 .16122 .58261 .15604 .57534 .14641 Mtetra
.57534 .14641 .58261 .15604 .59664 .15083 .58942 .14115 Mtetra
.58942 .14115 .59664 .15083 .61075 .1456 .60357 .13587 Mtetra
.60357 .13587 .61075 .1456 .6234 .09513 .6178 .13056 Mtetra
.407 .085 .304 r
.6178 .13056 .6234 .09513 .63742 .08981 .6321 .12522 Mtetra
0 0 .04 r
.6321 .12522 .63742 .08981 .65152 .08447 .64459 .07453 Mtetra
.664 .741 .908 r
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.943 .648 .45 r
.055 .33769 .06386 .34569 .06246 .43319 .05331 .42532 Mtetra
.653 .755 .925 r
.05331 .42532 .06246 .43319 .07446 .42894 .06534 .42103 Mtetra
.06534 .42103 .07446 .42894 .08652 .42466 .07743 .41672 Mtetra
.07743 .41672 .08652 .42466 .09864 .42037 .08958 .41239 Mtetra
.08958 .41239 .09864 .42037 .11081 .41606 .10179 .40804 Mtetra
.10179 .40804 .11081 .41606 .12305 .41172 .11406 .40367 Mtetra
.11406 .40367 .12305 .41172 .13534 .40737 .12638 .39927 Mtetra
.12638 .39927 .13534 .40737 .14769 .40299 .13877 .39486 Mtetra
.13877 .39486 .14769 .40299 .1601 .3986 .15121 .39042 Mtetra
.15121 .39042 .1601 .3986 .17257 .39418 .16372 .38597 Mtetra
.16372 .38597 .17257 .39418 .18511 .38974 .17629 .38149 Mtetra
.709 .21 0 r
.17629 .38149 .18511 .38974 .19574 .40451 .18689 .39625 Mtetra
.651 .757 .927 r
.18689 .39625 .19574 .40451 .20846 .40005 .19965 .39175 Mtetra
.19965 .39175 .20846 .40005 .22125 .39556 .21248 .38723 Mtetra
.21248 .38723 .22125 .39556 .23411 .39106 .22537 .38268 Mtetra
.949 .713 .548 r
.22537 .38268 .23411 .39106 .25755 .265 .24922 .25636 Mtetra
.661 .745 .913 r
.24922 .25636 .25755 .265 .27006 .26033 .26177 .25165 Mtetra
.26177 .25165 .27006 .26033 .28263 .25564 .27438 .24692 Mtetra
.27438 .24692 .28263 .25564 .29527 .25093 .28705 .24216 Mtetra
.28705 .24216 .29527 .25093 .30796 .24619 .29978 .23738 Mtetra
.29978 .23738 .30796 .24619 .32072 .24143 .31258 .23258 Mtetra
.31258 .23258 .32072 .24143 .33353 .23665 .32543 .22775 Mtetra
.32543 .22775 .33353 .23665 .34641 .23184 .33835 .2229 Mtetra
.33835 .2229 .34641 .23184 .35935 .22701 .35133 .21803 Mtetra
.35133 .21803 .35935 .22701 .37236 .22216 .36437 .21313 Mtetra
.36437 .21313 .37236 .22216 .38543 .21728 .37748 .20821 Mtetra
.37748 .20821 .38543 .21728 .39856 .21238 .39066 .20327 Mtetra
.39066 .20327 .39856 .21238 .41176 .20745 .40389 .1983 Mtetra
.40389 .1983 .41176 .20745 .42502 .2025 .4172 .1933 Mtetra
.4172 .1933 .42502 .2025 .43835 .19753 .43057 .18828 Mtetra
.43057 .18828 .43835 .19753 .45174 .19253 .444 .18324 Mtetra
.444 .18324 .45174 .19253 .4652 .18751 .45751 .17817 Mtetra
.45751 .17817 .4652 .18751 .47873 .18246 .47108 .17307 Mtetra
.47108 .17307 .47873 .18246 .49233 .17739 .48472 .16795 Mtetra
.48472 .16795 .49233 .17739 .50599 .17229 .49842 .16281 Mtetra
.49842 .16281 .50599 .17229 .51972 .16716 .5122 .15763 Mtetra
.5122 .15763 .51972 .16716 .53352 .16201 .52604 .15244 Mtetra
.52604 .15244 .53352 .16201 .54739 .15684 .53996 .14721 Mtetra
.53996 .14721 .54739 .15684 .56133 .15163 .55394 .14196 Mtetra
.55394 .14196 .56133 .15163 .57534 .14641 .568 .13668 Mtetra
.568 .13668 .57534 .14641 .58942 .14115 .58213 .13138 Mtetra
.58213 .13138 .58942 .14115 .60357 .13587 .59633 .12605 Mtetra
.59633 .12605 .60357 .13587 .6178 .13056 .61061 .12069 Mtetra
.61061 .12069 .6178 .13056 .6321 .12522 .62495 .1153 Mtetra
.62495 .1153 .6321 .12522 .64459 .07453 .63937 .10989 Mtetra
0 0 .04 r
.63937 .10989 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.664 .741 .908 r
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.462 .185 .407 r
.03207 .42169 .055 .33769 .05331 .42532 .04408 .41739 Mtetra
.653 .755 .925 r
.04408 .41739 .05331 .42532 .06534 .42103 .05614 .41306 Mtetra
.05614 .41306 .06534 .42103 .07743 .41672 .06827 .40871 Mtetra
.06827 .40871 .07743 .41672 .08958 .41239 .08045 .40434 Mtetra
.08045 .40434 .08958 .41239 .10179 .40804 .09269 .39995 Mtetra
.09269 .39995 .10179 .40804 .11406 .40367 .10498 .39554 Mtetra
.10498 .39554 .11406 .40367 .12638 .39927 .11734 .39111 Mtetra
.11734 .39111 .12638 .39927 .13877 .39486 .12976 .38665 Mtetra
.12976 .38665 .13877 .39486 .15121 .39042 .14224 .38218 Mtetra
.14224 .38218 .15121 .39042 .16372 .38597 .15478 .37768 Mtetra
.717 .218 0 r
.15478 .37768 .16372 .38597 .17629 .38149 .16523 .39245 Mtetra
.138 0 0 r
.16523 .39245 .17629 .38149 .18689 .39625 .17796 .38792 Mtetra
.651 .757 .927 r
.17796 .38792 .18689 .39625 .19965 .39175 .19076 .38338 Mtetra
.19076 .38338 .19965 .39175 .21248 .38723 .20363 .37881 Mtetra
.947 .713 .55 r
.20363 .37881 .21248 .38723 .22537 .38268 .2283 .25238 Mtetra
.526 .316 .537 r
.2283 .25238 .22537 .38268 .24922 .25636 .24083 .24765 Mtetra
.661 .745 .913 r
.24083 .24765 .24922 .25636 .26177 .25165 .25341 .2429 Mtetra
.25341 .2429 .26177 .25165 .27438 .24692 .26606 .23812 Mtetra
.26606 .23812 .27438 .24692 .28705 .24216 .27876 .23332 Mtetra
.27876 .23332 .28705 .24216 .29978 .23738 .29153 .2285 Mtetra
.29153 .2285 .29978 .23738 .31258 .23258 .30436 .22365 Mtetra
.30436 .22365 .31258 .23258 .32543 .22775 .31726 .21878 Mtetra
.31726 .21878 .32543 .22775 .33835 .2229 .33021 .21389 Mtetra
.33021 .21389 .33835 .2229 .35133 .21803 .34323 .20897 Mtetra
.34323 .20897 .35133 .21803 .36437 .21313 .35632 .20403 Mtetra
.35632 .20403 .36437 .21313 .37748 .20821 .36946 .19906 Mtetra
.36946 .19906 .37748 .20821 .39066 .20327 .38268 .19407 Mtetra
.38268 .19407 .39066 .20327 .40389 .1983 .39596 .18906 Mtetra
.39596 .18906 .40389 .1983 .4172 .1933 .4093 .18401 Mtetra
.4093 .18401 .4172 .1933 .43057 .18828 .42271 .17895 Mtetra
.42271 .17895 .43057 .18828 .444 .18324 .43619 .17386 Mtetra
.43619 .17386 .444 .18324 .45751 .17817 .44974 .16874 Mtetra
.44974 .16874 .45751 .17817 .47108 .17307 .46335 .1636 Mtetra
.46335 .1636 .47108 .17307 .48472 .16795 .47703 .15843 Mtetra
.47703 .15843 .48472 .16795 .49842 .16281 .49078 .15324 Mtetra
.49078 .15324 .49842 .16281 .5122 .15763 .50461 .14802 Mtetra
.50461 .14802 .5122 .15763 .52604 .15244 .5185 .14277 Mtetra
.5185 .14277 .52604 .15244 .53996 .14721 .53246 .1375 Mtetra
.53246 .1375 .53996 .14721 .55394 .14196 .54649 .1322 Mtetra
.54649 .1322 .55394 .14196 .568 .13668 .5606 .12687 Mtetra
.5606 .12687 .568 .13668 .58213 .13138 .57477 .12151 Mtetra
.57477 .12151 .58213 .13138 .59633 .12605 .58902 .11613 Mtetra
.58902 .11613 .59633 .12605 .61061 .12069 .60334 .11072 Mtetra
.60334 .11072 .61061 .12069 .62495 .1153 .61774 .10528 Mtetra
.61774 .10528 .62495 .1153 .63937 .10989 .63221 .09982 Mtetra
.63221 .09982 .63937 .10989 .65187 .05902 .64676 .09432 Mtetra
0 0 .04 r
.64676 .09432 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.664 .741 .908 r
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.653 .755 .925 r
.02273 .41373 .03207 .42169 .04408 .41739 .03477 .40938 Mtetra
.03477 .40938 .04408 .41739 .05614 .41306 .04686 .40502 Mtetra
.04686 .40502 .05614 .41306 .06827 .40871 .05902 .40063 Mtetra
.05902 .40063 .06827 .40871 .08045 .40434 .07123 .39622 Mtetra
.07123 .39622 .08045 .40434 .09269 .39995 .0835 .39179 Mtetra
.0835 .39179 .09269 .39995 .10498 .39554 .09583 .38734 Mtetra
.09583 .38734 .10498 .39554 .11734 .39111 .10822 .38287 Mtetra
.10822 .38287 .11734 .39111 .12976 .38665 .12068 .37837 Mtetra
.12068 .37837 .12976 .38665 .14224 .38218 .13319 .37385 Mtetra
.13319 .37385 .14224 .38218 .15478 .37768 .14577 .36931 Mtetra
.717 .218 0 r
.14577 .36931 .15478 .37768 .16523 .39245 .15618 .38408 Mtetra
.651 .757 .927 r
.15618 .38408 .16523 .39245 .17796 .38792 .16895 .37951 Mtetra
.16895 .37951 .17796 .38792 .19076 .38338 .18179 .37493 Mtetra
.18179 .37493 .19076 .38338 .20363 .37881 .19469 .37032 Mtetra
.947 .713 .55 r
.19469 .37032 .20363 .37881 .2283 .25238 .2198 .24363 Mtetra
.661 .745 .913 r
.2198 .24363 .2283 .25238 .24083 .24765 .23236 .23886 Mtetra
.23236 .23886 .24083 .24765 .25341 .2429 .24498 .23406 Mtetra
.24498 .23406 .25341 .2429 .26606 .23812 .25766 .22924 Mtetra
.25766 .22924 .26606 .23812 .27876 .23332 .2704 .2244 Mtetra
.2704 .2244 .27876 .23332 .29153 .2285 .28321 .21953 Mtetra
.28321 .21953 .29153 .2285 .30436 .22365 .29608 .21464 Mtetra
.29608 .21464 .30436 .22365 .31726 .21878 .30901 .20973 Mtetra
.30901 .20973 .31726 .21878 .33021 .21389 .322 .20479 Mtetra
.322 .20479 .33021 .21389 .34323 .20897 .33506 .19983 Mtetra
.33506 .19983 .34323 .20897 .35632 .20403 .34818 .19484 Mtetra
.34818 .19484 .35632 .20403 .36946 .19906 .36137 .18983 Mtetra
.36137 .18983 .36946 .19906 .38268 .19407 .37463 .18479 Mtetra
.37463 .18479 .38268 .19407 .39596 .18906 .38795 .17973 Mtetra
.38795 .17973 .39596 .18906 .4093 .18401 .40133 .17464 Mtetra
.40133 .17464 .4093 .18401 .42271 .17895 .41479 .16953 Mtetra
.41479 .16953 .42271 .17895 .43619 .17386 .42831 .16439 Mtetra
.42831 .16439 .43619 .17386 .44974 .16874 .4419 .15923 Mtetra
.4419 .15923 .44974 .16874 .46335 .1636 .45555 .15404 Mtetra
.45555 .15404 .46335 .1636 .47703 .15843 .46928 .14882 Mtetra
.46928 .14882 .47703 .15843 .49078 .15324 .48308 .14358 Mtetra
.48308 .14358 .49078 .15324 .50461 .14802 .49694 .13831 Mtetra
.49694 .13831 .50461 .14802 .5185 .14277 .51088 .13301 Mtetra
.51088 .13301 .5185 .14277 .53246 .1375 .52489 .12769 Mtetra
.52489 .12769 .53246 .1375 .54649 .1322 .53897 .12234 Mtetra
.53897 .12234 .54649 .1322 .5606 .12687 .55312 .11696 Mtetra
.55312 .11696 .5606 .12687 .57477 .12151 .56734 .11156 Mtetra
.56734 .11156 .57477 .12151 .58902 .11613 .58164 .10612 Mtetra
.58164 .10612 .58902 .11613 .60334 .11072 .59601 .10066 Mtetra
.59601 .10066 .60334 .11072 .61774 .10528 .61046 .09517 Mtetra
.61046 .09517 .61774 .10528 .63221 .09982 .62498 .08965 Mtetra
.62498 .08965 .63221 .09982 .64676 .09432 .63958 .08411 Mtetra
.63958 .08411 .64676 .09432 .65925 .04329 .65425 .07853 Mtetra
0 0 .04 r
.65425 .07853 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.664 .741 .908 r
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.653 .755 .925 r
.0133 .40569 .02273 .41373 .03477 .40938 .02537 .40131 Mtetra
.02537 .40131 .03477 .40938 .04686 .40502 .0375 .3969 Mtetra
.0375 .3969 .04686 .40502 .05902 .40063 .04968 .39247 Mtetra
.04968 .39247 .05902 .40063 .07123 .39622 .06193 .38803 Mtetra
.06193 .38803 .07123 .39622 .0835 .39179 .07423 .38356 Mtetra
.07423 .38356 .0835 .39179 .09583 .38734 .0866 .37906 Mtetra
.0866 .37906 .09583 .38734 .10822 .38287 .09902 .37455 Mtetra
.09902 .37455 .10822 .38287 .12068 .37837 .11151 .37001 Mtetra
.11151 .37001 .12068 .37837 .13319 .37385 .12406 .36546 Mtetra
.12406 .36546 .13319 .37385 .14577 .36931 .13667 .36088 Mtetra
.717 .218 0 r
.13667 .36088 .14577 .36931 .15618 .38408 .14705 .37563 Mtetra
.651 .757 .927 r
.14705 .37563 .15618 .38408 .16895 .37951 .15986 .37103 Mtetra
.15986 .37103 .16895 .37951 .18179 .37493 .17273 .3664 Mtetra
.946 .712 .553 r
.17273 .3664 .18179 .37493 .19469 .37032 .19868 .23959 Mtetra
.523 .311 .534 r
.19868 .23959 .19469 .37032 .2198 .24363 .21122 .2348 Mtetra
.661 .745 .913 r
.21122 .2348 .2198 .24363 .23236 .23886 .22381 .22998 Mtetra
.22381 .22998 .23236 .23886 .24498 .23406 .23647 .22515 Mtetra
.23647 .22515 .24498 .23406 .25766 .22924 .24919 .22028 Mtetra
.24919 .22028 .25766 .22924 .2704 .2244 .26197 .2154 Mtetra
.26197 .2154 .2704 .2244 .28321 .21953 .27481 .21049 Mtetra
.27481 .21049 .28321 .21953 .29608 .21464 .28771 .20555 Mtetra
.28771 .20555 .29608 .21464 .30901 .20973 .30068 .20059 Mtetra
.30068 .20059 .30901 .20973 .322 .20479 .31372 .19561 Mtetra
.31372 .19561 .322 .20479 .33506 .19983 .32681 .1906 Mtetra
.32681 .1906 .33506 .19983 .34818 .19484 .33998 .18557 Mtetra
.33998 .18557 .34818 .19484 .36137 .18983 .35321 .18051 Mtetra
.35321 .18051 .36137 .18983 .37463 .18479 .3665 .17543 Mtetra
.3665 .17543 .37463 .18479 .38795 .17973 .37986 .17032 Mtetra
.37986 .17032 .38795 .17973 .40133 .17464 .39329 .16518 Mtetra
.39329 .16518 .40133 .17464 .41479 .16953 .40679 .16002 Mtetra
.40679 .16002 .41479 .16953 .42831 .16439 .42035 .15484 Mtetra
.42035 .15484 .42831 .16439 .4419 .15923 .43398 .14963 Mtetra
.43398 .14963 .4419 .15923 .45555 .15404 .44768 .14439 Mtetra
.44768 .14439 .45555 .15404 .46928 .14882 .46145 .13912 Mtetra
.46145 .13912 .46928 .14882 .48308 .14358 .47529 .13383 Mtetra
.47529 .13383 .48308 .14358 .49694 .13831 .48921 .12851 Mtetra
.48921 .12851 .49694 .13831 .51088 .13301 .50319 .12316 Mtetra
.50319 .12316 .51088 .13301 .52489 .12769 .51724 .11779 Mtetra
.51724 .11779 .52489 .12769 .53897 .12234 .53137 .11239 Mtetra
.53137 .11239 .53897 .12234 .55312 .11696 .54557 .10696 Mtetra
.54557 .10696 .55312 .11696 .56734 .11156 .55984 .1015 Mtetra
.55984 .1015 .56734 .11156 .58164 .10612 .57419 .09602 Mtetra
.57419 .09602 .58164 .10612 .59601 .10066 .58861 .0905 Mtetra
.58861 .0905 .59601 .10066 .61046 .09517 .60311 .08496 Mtetra
.60311 .08496 .61046 .09517 .62498 .08965 .61768 .07939 Mtetra
.61768 .07939 .62498 .08965 .63958 .08411 .63233 .07379 Mtetra
.63233 .07379 .63958 .08411 .65425 .07853 .64706 .06816 Mtetra
.64706 .06816 .65425 .07853 .66673 .02733 .66186 .0625 Mtetra
0 0 .04 r
.66186 .0625 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.664 .741 .908 r
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 154.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000VR000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00QOooool2o`000<Cooooo0_l0
0013ooooo`00P_ooool3o`000003ooooool0003ooooo0<3ooooo0ol000000ooooooo0000ooooo`12
ooooo`00P?ooool2o`0000Cooooo0_l0002nooooo`;o00000oooool00onY_NSo0000o`000012oooo
o`00OOooool3o`0000Kooooo00?o0000ooooool00000^_ooool3o`0000Cooooo0_nY_NP00ol0003o
ooooo`000011ooooo`00N_ooool3o`0000?ooooo00?oZKgXooooooooool00oooool00ol0003ooooo
o`00002hooooo`;o00001oooool01Ol000[oZKgXo`000?nY_NSo0000047ooooo001hooooo`;o0000
0oooool4ojVmj0Gooooo00Co0000oooooooooooo0000]?ooool3o`0000Sooooo00Co000:ojVmj?nY
_NSo00000_nY_NP00ol0003oooooooooo`0nooooo`00MOooool3o`0000;ooooo1onY_NP5ooooo`05
o`000?ooooooooooooooool00000/?ooool3o`0000[ooooo00Go000:ojVmj?nY_NSoZKgXo`000003
ojVmj003o`000?oooooooooo03gooooo001cooooo`;o00000oooool9ojVmj003o`00JOoooooooooo
00;ooooo00Go0000ooooooooooooooooo`00002^ooooo`;o00003Oooool01Ol000[oZKgXojVmj?nY
_NSo000000?oZKgX00?o0000ooooooooool0?Oooool0073ooooo0ol00002ooooo`coZKgX00?o001Y
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Sooooo0ol0000?
ooooo`GoZKgX00Go0000ojVmj?nY_NSoZKgXo`00000nooooo`00K_ooool2o`0000?ooooo3_nY_NP0
0ol006Woooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0YOooool2
o`00017ooooo00?oZKkYojVmj?nY_NP00onY_NP01_l0003oZKgXojVmj?nY_NSoooooo`0003gooooo
001[ooooo`?o00000_ooool?ojVmj003o`00JOnY_NSo001Y00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2Rooooo`?o00004oooool00ol000[oZKgXojVmj003ojVmj003o`000?nY
_NSoZKgX00;oZKgX00?o0000ooooooooool0>oooool006Sooooo0ol00003oooooaCoZKgX1?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo09oooooo0_l0000Dooooo`;o000:1_nY_NP0
0ol0003oZKgXojVmj002ojVmj003ooooool0003ooooo03_ooooo001Vooooo`;o00000ooooolGojVm
j0Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Looooo`?o00005_ooool00ol0
00[oZKkYojVmj005ojVmj003o`000?nY_NSoZKgX00?oZKgX00?oooooo`000?ooool0>_ooool006?o
oooo0ol00002oooooaKoZKgX00Go001YojVmj?nY_NSoZKgXo`00J@04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0VOooool2o`0001Sooooo0onY_^T6ojVmj003o`000?nY_NSoZKgX
00CoZKgX00?o0000ooooooooool0>Oooool0067ooooo0_l00003oooooaSoZKgX00Go001YojVmj?nY
_NSoZKgXo`00J@04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0UOooool3o`00
01Oooooo1OnY_^T7ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ooooooooool0>?ooool005ko
oooo0ol00002oooooaOoZKgX00GoQe29ojVmj?nY_NSoZKgXo`00J@03ojVmj003o`00JOoooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Cooooo`;o00005oooool8ojVn
j@OoZKgX00?o0000ojVmj?nY_NP01_nY_NP00ol0003oooooooooo`0gooooo`00G?ooool2o`0000?o
oooo6?nY_NP2ohM@R@;oZKgX00Ko001YojVmj?nY_NSo001YojVmj?l006T4ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Soooool3o`0001Oooooo2_nY_^T7ojVmj003o`000?nY_NSo
ZKgX00KoZKgX00?o0000ooooooooool0=oooool005Wooooo0ol00003oooooa[oZKgX0_n7D8T2ojVm
j006o`00JOnY_NSoZKgXo`00JOnY_NSo001Y1?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo08_ooooo0ol0000Gooooo`coZKkY2?nY_NP00ol0003oZKgXojVmj007ojVmj003o`000?oo
oooooooo03Kooooo001Gooooo`;o00000ooooolMojVmj0;oQe2900?o001YojVmj?l006T00_nY_NP0
0ol006WoZKgXo`00J@04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ROooool2
o`0001Oooooo3_nY_^T9ojVmj003o`000?nY_NSoZKgX00OoZKgX00?oooooo`000?ooool0=_ooool0
05Cooooo0ol00003oooooaooZKgX0on7D8T3ojVmj0;o001Y00?oZKgXo`00JOl006T00oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo08Gooooo0ol0000Gooooo`ooZKkY2_nY_NP00ol0
003oZKgXojVmj008ojVmj003o`000?oooooooooo03Gooooo001Aooooo`?o000000?oooooojVmj?nY
_NP08_nY_NP3ohM@R@?oZKgX00?o001YojVmj?nY_NP00_l006T3ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0P_ooool2o`0001Oooooo4_nY_^T:ojVmj003o`000?nY_NSoZKgX00So
ZKgX00?oooooo`000?ooool0=Oooool004oooooo0_l000000oooooooZKgXojVmj00UojVmj0?oQe29
0onY_NP00ol006WoZKgXojVmj002o`00J@?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1oooooo`?o00005ooooolDojVnj@[oZKgX00?o0000ojVmj?nY_NP02OnY_NP00ooooooo0000
ooooo`0dooooo`00C?ooool3o`000003oooooonY_NSoZKgX02OoZKgX0on7D8T3ojVmj003o`00JOnY
_NSo001Y00;o001Y0oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07cooooo0_l0
000GoooooaKoZKkY2onY_NP00ol0003oZKgXojVmj00:ojVmj003o`000?oooooooooo03?ooooo001:
ooooo`;o00000_oooolZojVmj004o`00J?nY_NSoQe29ohM@R@?oZKgX00?o001YojVmj?l006T00_l0
06T3ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0N?ooool3o`0001Oooooo5onY
_^T=ojVmj003o`000?nY_NSoZKgX00[oZKgX00?o0000ooooooooool0<_ooool004Oooooo0ol00000
0oooooooZKgXojVmj00YojVmj004o`00J?nY_NSo001XojVmj0;oQe2900So001YojVmj?l006Wo001Y
ojVmj?l006WoZKgXo`00J@?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1foooo
o`;o00005ooooolHojVnj@ooZKgX00?o0000ojVmj?nY_NP02onY_NP00ol0003oooooooooo`0aoooo
o`00AOooool2o`0000;ooooo;OnY_NP01?l006SoZKgXojVmj?nY_NP2ohM@R@03o`00JOnY_NSo001Y
00?o001Y00?oZKgXo`00JOl006T00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
07;ooooo0ol0000Goooooa[oZKkY3onY_NP00ol0003oZKgXojVmj00;ojVmj003o`000?oooooooooo
037ooooo0012ooooo`?o00000_ooool_ojVmj004o`00J?nY_NSoZKgXojVmj0;oQe2900?o001YojVm
j?l006T00ol006T00onY_NSo001Yo`00J@02ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0Koooool2o`0001Oooooo7?nY_^T@ojVmj003o`000?nY_NSoZKgX00coZKgX00?o0000oooo
ooooool0<?ooool003oooooo0ol00002oooooc;oZKgX00Co001XojVmj?nY_NSoZKgX0_n7D8T00ol0
06WoZKgXo`00J@03o`00J@06ojVmj?l006Wo001YoooooonW`Nco00003oooool00ol0003ooooooooo
o`1/ooooo`?o00005ooooolNojVnjA3oZKgX00?o0000ojVmj?nY_NP03OnY_NP00ol0003ooooooooo
o`0_ooooo`00?Oooool2o`0000?ooooo<onY_NP00ol006SoZKgXojVmj002ojVmj0?oQe2900?oZKgX
o`00JOl006T01Ol006T2ojO1k003o`000?nW`Ncooooo00kooooo00?o0000ooooooooool0JOooool2
o`0001Oooooo8OnY_^T@ojVmj003o`000?nY_NSoZKgX00goZKgX00?o0000ooooooooool0;oooool0
03[ooooo0ol00003ooooocGoZKgX00?o001XojVmj?nY_NP00_nY_NP3ohM@R@05ojVmj?l006WoZKgX
o`00JOnY_NP01?l006T00onW`Nco0000ojO1k00@ooooo`03o`000?oooooooooo06Gooooo0ol0000G
ooooob;oZKkY4OnY_NP00ol0003oZKgXojVmj00>ojVmj003o`000?oooooooooo02kooooo000hoooo
o`;o00000ooooolhojVmj003o`00J?nY_NSo001X00;oZKgX0on7D8T2o`00J@03ojVmj?l006WoZKgX
00?o001Y0_nW`N`00ol0003oYl7/ojO1k00?ooooo`03o`000?oooooooooo06;ooooo0ol0000Eoooo
obOoZKkY4OnY_NP00ol0003oZKgXojVmj00>ojVmj003ooooool0003ooooo02kooooo000eooooo`?o
000000?oooooojVmj?nY_NP0>OnY_NP01_l006SoZKgXojVmj?l006SoZKgXo`00J0?oQe290_l006T0
1?nY_NSo001Yo`00JOl006T4ojO1k003o`000?nW`NcoYl7/013ooooo00?o0000ooooooooool0Gooo
ool2o`0001Gooooo:OnY_^TBojVmj003o`000?nY_NSoZKgX00ooZKgX00?o0000ooooooooool0;Ooo
ool003?ooooo0_l000000oooooooZKgXojVmj00lojVmj006o`00J?nY_NSoZKgXo`00J?nY_NSo001X
0on7D8T00ol006WoZKgXo`00J@04o`00J@?oYl7/00Co0000ojO1k?nW`NcoYl7/3oooool00ol0003o
ooooooooo`1Looooo`?o00005OoooolZojVnjA?oZKgX00?o0000ojVmj?nY_NP04?nY_NP00ol0003o
ooooooooo`0/ooooo`00<?ooool3o`000003oooooonY_NSoZKgX03goZKgX00Oo001XojVmj?nY_NSo
ZKgXo`00J?nY_NSo001X00?oQe2900?o001YojVmj?l006T00ol006T4ojO1k003o`000?nW`NcoYl7/
00?oYl7/3_ooool00ol0003oooooooooo`1Iooooo`;o00005_ooool/ojVnjA?oZKgX00?o0000ojVm
j?nY_NP04?nY_NP00ooooooo0000ooooo`0/ooooo`00;Oooool3o`0000;ooooo@OnY_NP01ol006So
ZKgXojVmj?nY_NSo001XojVmj?l006P00on7D8T00ol006WoZKgXo`00J@03o`00J@GoYl7/00?o0000
ojO1k?nW`N`00_nW`N`?ooooo`03o`000?oooooooooo05Gooooo0ol0000EooooobkoZKkY5?nY_NP0
0ol0003oZKgXojVmj00AojVmj003o`000?oooooooooo02_ooooo000[ooooo`;o00000ooooom3ojVm
j007o`00J?nY_NSoZKgXojVmj?l006SoZKgXo`00J003ohM@R@03o`00JOnY_NSo001Y00;o001Y1_nW
`N`00ol0003oYl7/ojO1k003ojO1k0Oooooo00?oo;ijooooooooool01?ooool00ol0003ooooooooo
o`1Cooooo`;o00005_ooool`ojVnjACoZKgX00?o0000ojVmj?nY_NP04OnY_NP00ooooooo0000oooo
o`0[ooooo`00:?ooool3o`0000;oooooAOnY_NP01?l006SoZKgXojVmj?nY_NP4o`00J003ojVmj?n7
D8WoQe2900Co001Y1onW`N`00ol0003oYl7/ojO1k003ojO1k0Oooooo00?oo;ijooooooooool01Ooo
ool00ol0003oooooooooo`1?ooooo`?o00005_oooolaojVnjAGoZKgX00?o0000ojVmj?nY_NP04_nY
_NP00ooooooo0000ooooo`0Zooooo`009_ooool2o`0000?ooooo@onY_NP01On:EHcoZKgXojVmj?nY
_NSo001X00?oZKgX1?l006P01?nY_NSoQe29ohM@ROn7D8T4o`00J@KoYl7/00?o0000ojO1k?nW`N`0
1?nW`N`6ooooo`03oobnN_l004Gooooo00Kooooo00?o0000ooooooooool0C?ooool2o`0001Kooooo
=?nY_^TEojVmj003o`000?nY_NSoZKgX01?oZKgX00?o0000ooooooooool0:Oooool002?ooooo0ol0
00000oooooooZKgXojVmj014ojVmj0;oRUF<00CoZKgXo`00J?nY_NSo001X0onY_NP3o`00J0;oZKgX
0on7D8T3o`00J@OoYl7/00?o0000ojO1k?nW`N`01?nW`N`6ooooo`03oobnN_nX_n[ooooo00Kooooo
00?o0000ooooooooool0BOooool3o`0001Kooooo=_nY_^TFojVmj003o`000?nY_NSoZKgX01;oZKgX
00?oooooo`000?ooool0:Oooool0027ooooo0_l00002ooooodSoZKgX0_n:EH`01?nY_NSo001XojVm
j?l006P2ojVmj0Co001X00?oZKgXo`00J?n7D8T00_n7D8T00ol006WoYl7/ojO1k007ojO1k003o`00
0?nW`NcoYl7/00GoYl7/1Oooool00ool_W[oZ;oZojRojP07ooooo`03o`000?oooooooooo04Kooooo
0_l0000GooooocOoZKkY5onY_NP00ol0003oZKgXojVmj00CojVmj003ooooool0003ooooo02Sooooo
000Nooooo`?o000000?oooooojVmj?nY_NP0BOnY_NP2ohYES004ojVmj?l006SoZKgXo`00J0;oZKgX
1?l006P00onY_NSo001XohM@R@02ohM@R@;o001Y2?nW`N`00ol0003oYl7/ojO1k006ojO1k0Cooooo
00?oo;ijojRoj_nX_nX00_nX_nX6ooooo`03o`000?oooooooooo04;ooooo0ol0000DoooooccoZKkY
5onY_NP00ol0003oZKgXojVmj00DojVmj003o`000?oooooooooo02Oooooo000Looooo`;o00000_oo
oom=ojVmj0;oRUF<00Go001XojVmj?nY_NSo001XojVmj003o`00J004ojVmj?l006SoZKgXo`00J0?o
Qe2900?o001YojO1k?nW`N`01onW`N`00ol0003oYl7/ojO1k007ojO1k0?ooooo00?oo;ijo`00A_nX
_nX00_nX_nX6ooooo`03o`000?oooooooooo03oooooo0ol0000EooooocgoZKkY6?nY_NP00ol0003o
ZKgXojVmj00DojVmj003ooooool0003ooooo02Oooooo000Iooooo`?o00000_oooom?ojVmj0;oRUF<
00Go001XojVmj?nY_NSo001XojVmj003o`00J004ojVmj?l006So001Xo`00J0;oQe292onW`N`00ol0
003oYl7/ojO1k008ojO1k0;ooooo00?oo;ijojRoj_nX_nX00onX_nX6ooooo`03o`000?oooooooooo
03cooooo0_l0000Eoooood3oZKkY6?nY_NP00ol0003oZKgXojVmj00EojVmj003o`000?oooooooooo
02Kooooo000Fooooo`?o000000?oooooojVmj?nY_NP0DOnY_NP3ohYES0;oZKgX00?o001XojVmj?l0
06P00_l006P01?nY_NSo001Xo`00J?l006P=ojO1k003o`000?nW`NcoYl7/00SoYl7/00?oooooojO1
k?ol_WX01OnX_nX7ooooo`03o`000?oooooooooo03Sooooo0ol0000Eooooo`;oQDn8@?nY_^THojVm
j003o`000?nY_NSoZKgX01KoZKgX00?o0000ooooooooool09Oooool001Cooooo0_l00002oooooeGo
ZKgX0on:EH`2ojVmj0Co001X00?oZKgXo`00J?l006P00ol006P;ojO1k0;o00003?nW`N`00ool_W_o
Z;oZojRojP04ojRojPKooooo00?o0000ooooooooool0=_ooool2o`0001Oooooo1?n5ChPnojVnjASo
ZKgX0_l0000HojVmj003ooooool0003ooooo02Gooooo000Aooooo`?o00000_oooomGojVmj0?oRUF<
0onY_NP3o`00J004ojVmj?l006So001Xo`00J0[oYl7/0ol000000onW`Nco0000ojO1k00;ojO1k003
oobnO?l004SoZ;oZ00GoZ;oZ1_ooool00ol0003oooooooooo`0booooo`?o00006Oooool4ohE?R004
oo:fS?nY_^WoQU29ohI@RCWoZKkY5_nY_NP3o`000003ojVmj?l0003oZKgX01SoZKgX00?o0000oooo
ooooool09?ooool0013ooooo0_l000000oooooooZKgXojVmj01GojVmj007o`00I_n:EHcoRUF<ohYE
S?nY_NSo001XojVmj002o`00J0;oZKgX1?l006P6ojO1k0?o00001OnW`N`00ol0003oYl7/ojO1k009
ojO1k003oobnO?nX_n[oZ;oZ00GoZ;oZ1oooool00ol0003oooooooooo`0`ooooo`;o00006oooool4
ohE?R003oo:fS?n6D8WoQU2900;oQU29=_nY_^T2ooRiPa?oZKgX0ol00005ojVmj003o`000?nY_NSo
ZKgX01OoZKgX00?o0000ooooooooool08oooool0013ooooo00?o0000ojVmj?nY_NP0FOnY_NP01ol0
06KoRUF<ohYES?n:EHcoZKgXo`00J?nY_NP00_l006P00onY_NSo001Xo`00J002o`00J0CoYl7/0ol0
0009ojO1k003o`000?nW`NcoYl7/00OoYl7/00?oo;ijoobnO?nX_nX01onX_nX6ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooool000006Oooool00oob]XgoQDn8ohE?R002ohE?R003oo:fS?n6
D8WoQU2900;oQU2900?ol[J<ojVnjOnY_^T0;OnY_^T5ohmRV0;on;V34OnY_NP3o`0000WoZKgX00?o
0000ojVmj?nY_NP05_nY_NP00ooooooo0000ooooo`0Sooooo`004?ooool00ol0003oooooojVmj01I
ojVmj007o`00I_n:EHcoRUF<ohYES?nY_NSo001XojVmj002o`00J004ojVmj?l006So001Xo`00J0;o
Yl7/0ol0000=ojO1k003o`000?nW`NcoYl7/00KoYl7/00?oo;ijoobnO?nX_nX02?nX_nX6ooooo`03
o`000?oooooooooo02oooooo00Co0000oooooooooooo00006?ooool01?ob]XgoQDn8ohE?R?n5ChP2
oo:fS0CoQU2900?ol[J<ohMBR_n7DXX00_n7DXX00onY_^WoR5::ohQBRP0LojVnj@?oSf6H00?oZKkY
ohmQV?n?HIP00on?HIP00onY_^WoSf:HohmRV005ohmRV0;on;V33_nY_NP3o`0000goZKgX00?o0000
ojVmj?nY_NP05_nY_NP00ol0003oooooooooo`0Rooooo`004?ooool00ol0003oooooojVmj01IojVm
j004o`00I_n:EHcoRUF<ohYES0;o001X00?oZKgXo`00J?nY_NP00ol006P3o`00013oYl7/00?o0000
ojO1k?nW`N`01_nW`N`00ool_W[o0019ojRojP08ojRojPKooooo00?o0000ooooooooool0;oooool0
1Ol0003ooooooooooooooooo000001Oooooo00Col[J=ohE?R?n5ChSoQDn80_ob]X`4ohI@R@03oo:f
S?n7DX[oQe::00;oQe::1?n8DXX7ojVnj@?oSUnG0onY_^T2ohiPU`;oZKkY1?n?H9L2ojVnj@goSf6H
2?n?HYP2ooRiP`_oZKgX0ol0000@ojVmj003o`000?nY_NSoZKgX01OoZKgX00?o0000ooooooooool0
8Oooool000oooooo00Co0000ooooooooooooooooFOnY_NP01?l006KoRUF<ohYES?n:EH`2o`00J003
ojVmj?l006SoZKgX00?o000000?o001XojO1k?nW`N`04OnW`N`00ol0003oYl7/ojO1k006ojO1k0_o
Z;oZ1_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05?ooool01?ob]XgoQDn8ohE?R?n5ChP2oo:fS0CoQU2900?ol[J<ohMBR_n7DXX00_n7DXX4ohQB
RP03oo>fRonY_^WoZKkY00;oZKkY1On>GiL5ohiPU`KoSf2G3on?HIP8ohmRV0;on;V32?nY_NP3o`00
01CoZKgX00?o0000ojVmj?nY_NP05_nY_NP00ooooooo0000ooooo`0Qooooo`003oooool00ol0003o
ooooooooo`03oooooe?oZKgX00KoReB;ojVmj?nY_NSoZKgXo`00I_nY_NP2ohYES0;o001X00?oZKgX
o`000?l000000ol006PEojO1k003o`000?nW`NcoYl7/00CoYl7/00?oo;ikojRoj_nX_nX02_nX_nX6
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0C
ooooo`04oo:fSOn5ChSoQDn8ohE?R0;ol[J<0on6D8T2oo:fS0CoQe::1?n8DXX00ooc]X_oSUnGohiO
U`07ohiOU`GoSV2G1_n?H9L?ohmQV0SoSf:H0_oh^H<5ojVmj0?o00006?nY_NP00ol0003oZKgXojVm
j00FojVmj003o`000?oooooooooo023ooooo000?ooooo`03o`000?oooooooooo00CoooooDOnY_NP2
oh]DR`;oZKgX00?o001Xo`00I_nY_NP00_n:EH`3o`0000Co001X5onW`N`00ol0003oYl7/ojO1k002
ojO1k003oobnNool_WcoZ;oZ00_oZ;oZ1_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04Oooool2oo:fS@?oQDn80_ob]X`3ohI@R@;ol[J<1?n7DXX4
ohQBRP03oo>fRon>GiOoSUnG00OoSUnG1On>H9L6ohmPU`SoSf6H00?olkjEohmQV?n?HIP00on?HIP0
0ood_YCoSf:HohmRV005ohmRV003ooFoT_oh^H?on;V300;oZKgX0ol0000KojVmj003o`000?nY_NSo
ZKgX01OoZKgX00?o0000ooooooooool07oooool000oooooo00?o0000ooooooooool01Ooooom@ojVm
j0;oReB;0_nY_NP00ol006SoZKgXo`000002o`0000;o001X00CoZKgXo`00J?l006So001X6?nW`N`0
0ol0003oYl7/ojO1k002ojO1k003oobnNool_Wco001;00coZ;oZ1_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool2oo:fS@;oQDn80oob]X`3
ohI@R@;ol[J<0on7DXX00ooc]X_oR5::ohQBRP02ohQBRP03oo>fRon>GiOoSUnG00KoSUnG00?olKbH
ohiPUon>H9L00on>H9L6ohmPU`03oo:mUon?HISoSf6H00GoSf6H00?olkjEohmQV?n?HIP00on?HIP0
0ood_YCoSf:HohmRV005ohmRV003ooFoT_oh^H?oZKgX00;o00007onY_NP00ol0003oZKgXojVmj00F
ojVmj003ooooool0003ooooo01oooooo000?ooooo`03o`000?oooooooooo00KoooooConY_NP2oh]D
R`05ojVmj?l0003o0000o`000?nY_NP00_n:EH`00ol006SoZKgXo`00J004o`00J1SoYl7/00?o0000
ojO1k?nW`N`00_nW`N`00ool_WcoZ;oZojRojP0<ojRojPKooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo0_ob]Xd2ohE?R0?ol[J<0on6D8T2
oo:fS0?oQe::00ColkJ;ohQBR_n8DX[oR5::0_oc]X/8ohiOU`03oo6lV?n>H9OoSV2G00;oSV2G00?o
lKfGohmPUon?H9L00on?H9L2oo:mU`OoSf6H00?olkjEohmQV?n?HIP00on?HIP00ood_YCoSf:HohmR
V005ohmRV0?o00008_nY_NP00ol0003oZKgXojVmj00FojVmj003o`000?oooooooooo01kooooo000?
ooooo`03o`000?oooooooooo00SoooooCOnY_NP3o`000004ocLFN_l006SoZKgXojVmj0;oRUF<00?o
001XojVmj?l006P00ol006PJojO1k003o`000?nW`NcoYl7/00;oo;il3_nX_nX6ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`;ol[J=0_n5
ChP3oo:fS0?oQU290_ob]X`3ohMBRP04oo>fRon8DX[oR5::ohQBRP;olkJ;2?n>GiL00ooa_9SoSV2G
ohiPU`02ohiPU`03oo6mUon?H9OoSf2G00?oSf2G0_ob_IL6ohmQV0?olkjE0on?HIP3ooBnU0?oSf:H
0ol000000ooe_i;on;V3ojVmj00SojVmj003o`000?nY_NSoZKgX01KoZKgX00?o0000ooooooooool0
7Oooool000oooooo00?o0000ooooooooool02?oooom:ojVmj0?o00000_n;E8/00onY_NSo=aIjo`00
J002ojVmj0?oRUF<00?oZKgXo`00J?l006P00_l006PKojO1k004o`000?nW`Ncoo;iloo^nO@ooZ;oZ
1_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3?ooool2oo:fS@?oQDn80oob]X`3ohI@R@;ol[J<0on7DXX01?oc]X_oR5::ohQBR_n8DXX2oo>fR`Oo
SUnG0_oa_9P4ohiPU`;olKfG1?n?H9L2oo:mU`KoSf6H0ooc_YD3ohmQV0?om;jD0ol00003ohmRV0;o
n;V39?nY_NP00ol0003oZKgXojVmj00FojVmj003ooooool0003ooooo01gooooo000>ooooo`03o`00
0?oooooooooo00[oooooA_nY_NP3o`000003ohaFRonY_NSoZKgX00;oReB;00?oZKgXocLFN_l006P0
0_nY_NP3ohYES0Co001X7?nW`N`01Ol0003oYl7/oobnO?ok_Woo001=00ooZ;oZ1_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2oo:fS@;o
QDn81?ob]X`2ohI@R@?ol[J<0on7DXX01?oc]X_oR5::ohQBR_n8DXX3oo>fR`KoSUnG0_oa_9P4ohiP
U`;olKfG1?n?H9L2oo:mU`KoSf6H0ooc_YD3ohmQV0?o00001On?HYP00ooe_i;on;V3ooRiP`0UojVm
j003o`000?nY_NSoZKgX01KoZKgX00?o0000ooooooooool07?ooool000kooooo00?o0000oooooooo
ool03?oooom1ojVmj0?o000000CoZKgXohaFRon<EX_oS5J;0_nY_NP2oh]DR`05ojVmj?lg5W[o001X
ojVmj?l006H00on:EH`3o`00J1koYl7/00?o0000ojO1k?ok_Wl04?nX_nX6ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`;ol[J=0_n5ChP4
oo:fS0;oQU290oob]X`3ohMBRP04oo>fRon8DX[oR5::ohQBRP?olkJ;1_n>GiL2oo6lV0CoSV2G0_oa
_IL4ohmPU`;ol[fG1_n?HIP3oo>nU@?o00000ood_Y@5ohmRV003ooFoT_oh^H?on;V302KoZKgX00?o
0000ojVmj?nY_NP05_nY_NP00ol0003oooooooooo`0Kooooo`003_ooool00ol0003oooooooooo`0<
ooooocooZKgX0_l00002ojVmj003oiAZWonY_NSoS5J;00;oS5J;0_nY_NP2oh]DR`05ojVmj?lg5W[o
ZKgXojVmj?l006H00on:EH`4o`00J1koYl7/00?o0000oo^nOonX_nX04?nX_nX6ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`;ol[J=0_n5
ChP4oo:fS0;oQU290oob]X`2ohMBRP;olkJ;0on8DXX3oo>fR`KoSUnG0_oa_9P3ohiPU`?olKfG0on?
H9L4oo:mU`CoSf6H00ColkjEo`000?l0003o00000_n?HIP4ooBnU0CoSf:H0_nX`>/2ooRiPbOoZKgX
00?o0000ojVmj?nY_NP05OnY_NP00ooooooo0000ooooo`0Kooooo`003_ooool00ol0003ooooooooo
o`0=oooooc_oZKgX0ol00003ojVmj0;oU6ZO00CoZKgXohaFRon<EX_oS5J;0_nY_NP2oh]DR`05ojVm
j?lg5W[oZKgXojVmj?l006H00on:EH`3o`00J1ooYl7/00?o0000oo^nOonX_nX04OnX_nX6ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`;o
l[J=0_n5ChP4oo:fS0;oQU290oob]X`2ohMBRP;olkJ;0_n8DXX4oo>fR`GoSUnG0ooa_9P3ohiPU`?o
lKfG0on?H9L4oo:mU`;oSf6H0ol000001?nX`>_olkjEoo>nUOn?HIP3ojS0j`;om;jD00?oSf:HojS0
jonX`>/00onX`>/00ooh^H?oZKgXojVmj00VojVmj003o`000?nY_NSoZKgX01KoZKgX00?o0000oooo
ooooool06_ooool000kooooo00?o0000ooooooooool03ooooolfojVmj0?o00001_nY_NP2oiAZW`04
ojVmj?n<EX_oS5J;ohaFR`;oZKgX0_n;E8/01Ol0067o=aIjojVmj?nY_NSo001V00?oRUF<0_l006PP
ojO1k003oo^nOOl0003oZ;oZ017oZ;oZ1_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00oooooo0_l00007ooooo`?ol[J=00?oQDn8oo:fS?ob]X`00oob]X`2ohI@R@?ol[J<0_n7DXX2
oo>fR`;oR5::1?oc]X/4ohiOU`04ojS0jooa_9SolKbHoo6lV0;oSV2G00CoZ<3[oo6mUooa_IOolKfG
0_n?H9L2ojS0j`;ol[fG0ol0000CojS0jbWoZKgX00?o0000ojVmj?nY_NP05_nY_NP00ol0003ooooo
ooooo`0Iooooo`003_ooool00ol0003oooooooooo`0@oooooc;oZKgX0ol00007ojVmj005oiA[WonY
_NSoU6ZOoiAZWonY_NP00on<EX/2ojVmj0;oReB;00Go001QocLFN_nY_NSoZKgXo`00IP03ohYES003
o`00J?nW`NcoYl7/023oYl7/00?oZ;oZo`000?nX_nX04OnX_nX6ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool00oooool2oo6UL`gooooo00?o0000ooooooooool01?ooool3oo:fS@03
ohE?R?ob]Xcol[J<00?ol[J<00?oQU29oo:fS?ob]X`00_ob]X`2ohMBRP;olkJ;0_n8DXX4oo>fR`03
ohiOUonX`>_oZ<3[00?oZ<3[00?olKbHojS0jonX`>/00onX`>/00ooa_IOoZ<3[ojS0j`03ojS0j`;o
00005OnX`>/[ojVmj003o`000?nY_NSoZKgX01KoZKgX00?o0000ooooooooool06?ooool000kooooo
00?o0000ooooooooool04Oooool^ojVmj0?o00002?nY_NP3oiA[W`04oa<?R?nDJYooU6ZOojVmj0?o
S5J;0_nY_NP2oh]DR`05o`00HOlg5W[oZKgXojVmj?l006H00_n:EH`SojO1k004oo^nO_nX_n[oZ;oZ
o`0001;oZ;oZ1_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo0ooaYG<=
ooooo`03o`000?oooooooooo00?ooooo0oob]Xd00on5ChSol[J<oo:fS003oo:fS003ohI@ROob]Xco
l[J<00;ol[J<0_n7DXX2oo>fR`;oR5::1?oc]X/2oo6kUPgoZ<3[0ol0000GojS0jb_oZKgX00?o0000
ojVmj?nY_NP05_nY_NP00ol0003oooooooooo`0Hooooo`003Oooool00ol0003oooooooooo`0Coooo
ob[oZKgX0ol0000:ojVmj0CoU6^O00Co4`n8ojVmj?nDJYooZKgX0on<EX/02?nY_NSo001Ooh]DRon;
E8_o001QocLFN_nY_NSo001X0ol006HRojO1k005oo^nO_ok_Woo001?ojRoj_l000004_nX_nX6oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool5oo6UL`;olJEb00?ooooooo6U
L_ooool01oooool00ol0003oooooooooo`02ooooo`?ol[J=00?oQDn8oo:fS?ob]X`00oob]X`00on6
D8Wol[J<oo:fS002oo:fS004ohMBR_oc]X_olkJ;oo>fR`;oR5::1?oc]X/2oo6kUP[oZ<3[0ol0000I
ojS0jbgoZKgX00?o0000ojVmj?nY_NP05OnY_NP00ooooooo0000ooooo`0Hooooo`003Oooool00ol0
003oooooooooo`0DooooobKoZKgX0ol0000=ojVmj0CoU6^O00Co4`n8ojVmj?nDJYooZKgX0on<EX/0
2?nY_NSo001Ooh]DRon;E8_o001QocLFN_nY_NSo001X0_l006HSojO1k003oo^nO_ok_WooZ;oZ00;o
Z;oZ00?o0000ojRoj_nX_nX04?nX_nX6ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool00_ooool00omf;fSolJEcoo6UL`03oo6UL`ColJEb00?olJEaooooooooool01_ooool01?l0003o
ooooooooooooool3oo:fS@03ohE?R?ob]Xcol[J<00?ol[J<00?oQU29oo:fS?ob]X`00_ob]X`01On7
DX[olkJ;oo>fRooc]X_oR5::00GolkJ;0ooa^iH6ojS0j`?o00007?nX`>/^ojVmj003o`000?nY_NSo
ZKgX01GoZKgX00?oooooo`000?ooool05oooool000gooooo00?o0000ooooooooool05_oooolRojVm
j0;o00003OnY_NP2oiE[W`03ojVmj?nDJiooU6^O00?oU6^O00?o4`n8oiAZWonY_NP00on<EX/2o`00
G`;oReB;00?o001QocLFN_lg5WX00_l006PUojO1k003oo^nOonX_n[oZ;oZ00;oZ;oZ00?o0000ojRo
j_nX_nX04?nX_nX6ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00_ooool00omf
;fSolJEcoo6UL`03oo6UL`ColJEb0ooaYG401?oooooolJEaojO1k?ng=`03ooooo`03o`000?oooooo
l[J=00?ol[J=1_ob]X`00on6D8Wol[J<oo:fS002oo:fS005ohMBR_oc]X_olkJ;oo>fRon8DXX01?oc
]X/5oo6kUP;oZ<3[0ol0000NojS0jc3oZKgX00?o0000ojVmj?nY_NP05OnY_NP00ol0003ooooooooo
o`0Fooooo`003Oooool00ol0003oooooooooo`0FoooooaooZKgX0ol0000?ojVmj0;oUF^O00?o40b6
oiA[WonDJil00onDJil00olC3hSoU6ZOojVmj003ohaFR`;o001O0_n;E8/00ol0067o=aIjocLFNP03
o`00J2?oYl7/0_ok_Wl5ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ1Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00;ooooo00?oMRmXoo6ULooaYG<00_oaYG<01Omg<FWolJEboo6UL_oa
YG;oN39Z00OoYl7/00Co]cL0oo:UL?obYFoooooo0onV`Nd00oob]XgoY/7]ojK1k@05oo:fS003ohI@
ROob]Xcol[J<00;ol[J<00GoQe::oo>fRooc]X_olkJ;ohQBRP04oo>fR`ColK^F0ol0000QojS0jc3o
ZKgX00?o0000ojVmj?nY_NP05OnY_NP00ooooooo0000ooooo`0Fooooo`003Oooool00ol0003ooooo
ooooo`0Goooooa_oZKgX0ol0000@ojVmj006oiE[X?nY_NSoUF^OoiE[Wol@38KoZKgX1?nDJil00olC
3hSoU6ZOojVmj003ohaFR`;o001O0_n;E8/00ol0067o=aIjocLFNP04o`00J2;oYl7/00?onkioooZm
P_l005401?nX_nX00ol0003oZ;oZojRojP0@ojRojPKooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`03ooooo`03ogH_J?oaYG?olJEc00;olJEc00?oMc5Yoo6UL_oaYG802_nW`N`:ojK1
k@Wol[J<00GoQe::oo>fRooc]X_olkJ;ohQBRP04oo>fR`05oo6kU_l0003o0000o`000?oa^iH00_l0
000QojS0jc7oZKgX00?o0000ojVmj?nY_NP05OnY_NP00ooooooo0000ooooo`0Eooooo`003Oooool0
0ol0003oooooooooo`0HoooooaOoZKgX0ol0000BojVmj0;oUF^P00GoZKgXoiE[WonEJioo40b6ojVm
j004oiA[W`03oa<?R?nDJYoo001N00?oS5J;0_l005l2oh]DR`03o`00HOnY_NSo=aIj00?o001X8onW
`N`00ook_Woon[f2ojRojP05ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ1Oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00;ooooo0_mf;fP4oo6UL`03ogLaJOnW`NcoYl7/00_oYl7/2_nV
`Nd8oo:fS005ohMBR_oc]X_olkJ;oo>fRon8DXX00_oc]X/3o`0000ColK^F8?nX`>/eojVmj003o`00
0?nY_NSoZKgX01GoZKgX00?o0000ooooooooool05?ooool000gooooo00?o0000ooooooooool06_oo
oolBojVmj0?o00005OnY_NP2oiE[X005o`h;QOnY_NSoUF^OoiE[Wol@38H01?nDJil00olC3hSoU6ZO
o`00GP03ohaFR`;o001O0_n;E8/00ol0067oZKgXocLFNP03o`00J2CoYl7/00?on[f2ojRoj_nAGi<0
1OnX_nX00ol0003oZ;oZojRojP0@ojRojPGooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`02ooooo`;oMRmX0_oaYG<BojO1k0coY/7]1?ob]X`4oo>fR`04ohQBR_l0003o0000oo>fR`Go
lK^F00?o0000olR<UOnX`>/00on;EhdKojS0jcKoZKgX00?o0000ojVmj?nY_NP05OnY_NP00ol0003o
ooooooooo`0Cooooo`003?ooool00ol0003oooooooooo`0Kooooo`ooZKgX0ol0000FojVmj006oiE[
X?nY_NSoUF^PoiE[X?l>2hGoZKgX0_nEJil00ol@38KoU6^OojVnj@03ojVnj@03oiAZWol005koS5J;
00;oS5J;0_l005l3oh]DR`05ojVmj?lg5W[o001Xo`00J?n>G9808onW`N`00ooj_H7on[f2oi5OT`02
oi5OT`GoZ;oZ00?o0000ojRoj_nX_nX03onX_nX6ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00_oooolIojO1k003okDe0?nV`NgoY/7]00OoY/7]0oob]X`2oo>fR`?o00000ooc]X/5
oo6kUP03o`000?o8S9GoReN=00?oReN=6onX`>/fojVmj003o`000?nY_NSoZKgX01GoZKgX00?ooooo
o`000?ooool04oooool000cooooo00?o0000ooooooooool07?ooool;ojVmj0?o00006?nY_NP2oiE[
X005ojVmj?nEJj3oUF^PoiE[X?nY_NP00_nEJil2oa0<QPCoZKkY00?oU6ZOo`00G_n<EX/00_n<EX/2
o`00G`05ojVmj?n;E8_oReB;ojVmj?lg5WX01?n>G98RojO1k003ooZmPOoEUY7oTEnC00;oTEnC00?o
nkQfojRoj_nAH9@00_nX_nX00ol0003oZ;oZojRojP0@ojRojPGooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0LojO1k0[oY/7]00Col[J<o`000?l0003o00001_oc]X/5oo6kUP;ob8bE
1?n;Ehd01?oc]X[oZ<3[ohaHS_n<F8hFojS0jcSoZKgX00?o0000ojVmj?nY_NP05OnY_NP00ol0003o
ooooooooo`0Booooo`003?ooool00ol0003oooooooooo`0Nooooo`OoZKgX0_l0000KojVmj0;oUF^P
00Go3@V5ojVmj?nEJj3oUF^Po`h;Q@02oiE[W`03oa0<Q_nY_^WoZKkY00?oZKkY00?oU6ZOo`00G_n<
EX/00_n<EX/2o`00G`05ojVmj?n;E8_oReB;ojVmj?lg5WX01?n>G9801?og^hOoYl7/ojO1k?n>GI<O
ojO1k005omFFTOnAGi?oTEnCoi5OTook^7H00onAH9@2ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ1Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?nW`NcoYl7/01goYl7/1onV`Nd3o`0000KoY/7]0ooc
]X/5oo6kUP;ob8bE1?n;Ehd00ooc]X[oS5R>ohaHSP02ohaHSQGoZ<3[>OnY_NP00ol0003oZKgXojVm
j00DojVmj003ooooool0003ooooo01;ooooo000<ooooo`03o`000?oooooooooo01oooooo0onY_NP3
o`0001goZKgX0_nEJj001_l=2HGoZKgXoiE[X?nEJj3o3P^5oiE[W`OoZKkY00?oU6ZOo`00G_n<EX/0
0_n<EX/00ol005ooZKgXojVmj002oh]DR`03ojVmj?lg5W[oSUbB00?oSUbB00?omk^7ohiMTon>GI<0
0_n>GI<MojO1k003ooZmP_oEUY7oTEnC00;oTEnC00GonkQfoi5PU?nAH9CoTF2Doo^hM@02ojRojP03
o`000?nX_n[oZ;oZ00ooZ;oZ1_ooool00ol0003oooooooooo`0Iooooo`03o`000?ooooooYl7/01oo
Yl7/00?o]CD0ojK1kOnV`Nd00ol0000;ojK1k@GolK^F00?o0000olR<UOo8S9D01?n;Ehd00ooc]X[o
S5R>ohaHSP02ohaHSP03oo>gR_nX`>_oS5V?017oZ<3[>_nY_NP00ol0003oZKgXojVmj00EojVmj003
ooooool0003ooooo017ooooo000<ooooo`03o`000?oooooooooo01oooooo0ol0000OojVmj005o`/8
Q?nEJj3oUF^PoiE[X?nY_NP00_nEJj02o`h;Q@OoZKkY00?oU6ZOo`00G_n<EX/00_n<EX/00ol005oo
ZKgXojVmj002oh]DR`03ojVmj?lg5W[oSUbB00?oSUbB00?omk^7ohiMTon>GI<00_n>GI<00ooh^hKo
Yl7/ojO1k00JojO1k003ooZmP_oEUY7oTEnC00;oTEnC00GonkQfoi5PU?nAH9CoTF2Doo^hM@03oi9Q
U003o`000?nX_n[oZ;oZ00koZ;oZ1_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01ooYl7/0ol0000>ojK1k@GolK^F00?oY/7]olR<UOoc]X/00on;Ehd2oo>fRPCoS5R>00ColkN:ohaI
Son<FHooS5V?3OnX`>/nojVmj003o`000?nY_NSoZKgX01GoZKgX00?o0000ooooooooool04?ooool0
00cooooo00?o0000ooooooooool07?ooool3o`000003oooooonY_NSoZKgX01ooZKgX00Go2`R4ojVm
j?nEJj3oUF^Po`d9Q@02oiE[X003o`h;QOnY_^WoZKkY00OoZKkY00?o001NohaFRon<EX/00_n<EX/2
ojVmj0;oReB;00?oZKgXocLFN_lg5WX00on>G9800oog^hOoSUfCohiMT`02ohiMT`03ooRkQ_n?GYCo
SejD00;oSejD6?nW`N`00ooj_H;oeIJAooZiM`02oi5OT`05oo^hM_nAH9CoTF2Doi5PU?ok^7D00onB
HI@01?l0003onkQdojRoj_nBHID>ojRojPKooooo00?o0000ooooooooool06?ooool01Ol0003ooooo
ooooooooooooYl7/00?ooooo5onW`N`3o`0000;oYl7/4?nV`Nd4oo6kUP;ob8bE00ColkJ;oh]GSOn;
EhgoReN=0_oc]XX4ohaHSP04oo>gR_n<FHooS5V?ohaIS`;om;N900?oZ<3[oheISonX`>/02?nX`>/o
ojVmj003o`000?nY_NSoZKgX01CoZKgX00?oooooo`000?ooool04?ooool000cooooo00?o0000oooo
ooooool06Oooool3o`0000Kooooo7_nY_NP2o`/8Q005ojVmj?nEJj3oUF^Po`d9QOnEJj002onY_^T0
0ol005koZKgXohaFR`02ohaFR`;oZKgX0_n;E8/00onY_NSo=aIjocLFNP03ohiLTP03ooNkQon>GI?o
SUfC00;oSUfC00?on;^6ohmNU?n?GY@00_n?GY@00ooh^hGoYl7/ojO1k00FojO1k004omFFTOoj^GOo
TEnCoi5OT`;onkQf0_nAH9@00ook^7GoTV6Doi9QU002oi9QU005o`000?nBHIGoTV6Eoi9QUOnX_nX0
0_nCHYD;ojRojPCooooo0ol0000Iooooo`03o`000?oooooooooo00Gooooo5?nW`N`3o`0000OoYl7/
00?oY/7]ojO1k?nW`N`03OnV`Nd2oo6kUP;ob8bE00ColkJ;oh]GSOn;EhgoReN=0_oc]XX4ohaHSP04
oo>gR_n<FHooS5V?ohaIS`;om;N90on=FHl2ojS0j`;oSEZ@0_nX`>]2ojVmj003o`000?nY_NSoZKgX
01CoZKgX0_l0000@ooooo`002oooool00ol0003oooooooooo`0Gooooo`?o00002_oooolMojVmj003
o`/8Q?nY_NSo2`R400;oUF^P0_l=2HD;ojVnj@03o`00G_nY_NSoS5J;00;oS5J;0_nY_NP2oh]DR`03
ojVmj?lg5W[o=aIj00;oSUbB0oog^hL3ohiMT`03ooRkQ_n?GYCoSejD00;oSejD00Con;^5oi1OU?n@
GiCoT5nD5?nW`N`00ooj_H;oeIJAooZiM`02oi5OT`;onkQf0_nAH9@00ook^7GoTV6Doi9QU002oi9Q
U004oo^hM?l0003oTV6Eoi9QU@?oTf:E3?nX_nX3o`0000;ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`06ooooo`04ojO1k?ooooooooooooooo`coYl7/0ol0000>ojO1k0coY/7]0_oa
^iH2olR<U@04oo>fRon;EhgoReN=oh]GS@;olkJ:0on<F8h2oo>gRP?oS5V?0_od]hT3oheIS`CoSEZ@
00?oZ<3[ojVmj?nY_NP0@OnY_NP00ol0003oZKgXojVmj00EojVmj003o`000?oooooooooo00kooooo
000;ooooo`03o`000?oooooooooo01Cooooo0ol0000>oooooa_oZKgX0_l;28@01OnY_NSo2`R4oiE[
X?nEJj3o3@V500coZKkY00?oU6ZOojVmj?n<EX/00_n<EX/2ojVmj0;oReB;00?oZKgXocLFN_lg5WX0
0_n>G983ooNkQ`?oSUfC00?on;^6ohmNU?n?GY@00_n?GY@01?oh^hGoT5nDoi1OU?n@Gi@2ooRkQ17o
Yl7/00Con[f2omFFTOoEUY7on[Ug0_nAGi<2oo^hMP;oTF2D0_ok^7D3oi9QU004oo^hM?nBHIGo0000
oi9QU@?oTf:E00ConkQaojRoj_nCHYKoTf:F2?nX_nX5ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool03_ooool6ojO1k0;o00004_nW`N`=ojK1k@;ob8bE00ColkJ;oh]GSOn;EhgoReN=
0_oc]XX3ohaHSP;olkN:0on<FHl2ooBgR@?oSEV?1?n=FY000ood]hSoZKgXojVmj012ojVmj003o`00
0?nY_NSoZKgX01?oZKgX00?oooooo`000?ooool03oooool000_ooooo00?o0000ooooooooool04Ooo
ool3o`0001;ooooo6_nY_NP01?l;28CoZKgXo`/8Q?l;28@?ojVnj@03oiAZWonY_NSoS5J;00;oS5J;
0_nY_NP2oh]DR`03o`00HOlg5W[o=aIj00;oSUbB0oog^hL2ohiMT`?on;^60on?GY@01?oh^hGoT5nD
oi1OU?n@Gi@2ooRkQ0?oT62E3onW`N`2omFFT@03ooZiMonAGi?oTEnC00;onkQf0_nAH9@2oo^hM@?o
TV6D00ConkQdoi9QUOl0003oTV6E0onCHYD01Ook^77oTf:Foi=RU_nCHYKoo;Q`00SoZ;oZ1?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo0_nW`N`3o`0001GoYl7/00?o/c<0
ojK1kOnV`Nd02OnV`Nd2olR<U@04oo>fRon;EhgoReN=oh]GS@;olkJ:0on<F8h2oo>gRP?oS5V?0_od
]hT3oheIS`CoSEZ@00?om;N8ojVmj?nY_NP0@onY_NP00ol0003oZKgXojVmj00=ojVmj0Kooooo00?o
0000ooooooooool03_ooool000_ooooo00?o0000ooooooooool03oooool2o`0001Kooooo6OnY_NP0
0ol;28CoZKgXo`/8Q002o`/8Q0koZKkY00?oU6ZOojVmj?n<EX/00_n<EX/2ojVmj0;oReB;00?o001Q
ocLFN_lg5WX00_n>G983ooNkQ`;oSUfC0ooh^hH3ohmNU004ooRkQOn@GiCoT5nDoi1OU0;on;^40on@
H9D00ooi^h?oYl7/ojO1k00;ojO1k0?oeIJA00?on[Ugoi5OTonAGi<00_ok^7H2oi5PU0;onkQe0onB
HI@01?ok^7CoTV6Eoi9QUOl00003oi=RU@05oo^hLOnCHYKoTf:Foi=RU_ol^7000onDHiH6ojRojPCo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0?ooooo`?o00000_ooool00onW`Nco
ooooooooo`0DojO1k0[oY/7]0_o8S9D2oo>fR`;oReN=0ooc]XX3ohaHSP;olkN:0_n<FHl3ooBgR@?o
SEV?1?n=FY000ood]hSoZKgXojVmj014ojVmj003o`000?nY_NSoZKgX00[oZKgX2?ooool00ol0003o
ooooooooo`0>ooooo`002oooool00ol0003oooooooooo`0<ooooo`?o00006OoooolIojVmj0?o2`R4
3onY_^T00onDJYooZKgXohaFR`02ohaFR`;oZKgX0_n;E8/00ol0067o=aIjocLFNP02ohiLTP?omk^7
0_n>GI<3ooRkQP;oSejD0ooh^hD2oi1OU0;on;^40on@H9D00ooi^h?oTF6Eoi5QU@02oi5QU@WoYl7/
0ooEUY400ooj^GOoTEnCoi5OT`02oo^hMP;oTF2D0_ok^7D3oi9QU0;onkQd0_nBHID01?l0003oTf:E
oi=RUOok^743oi=RUP05oobhL?nDHiKoU6>FoiASU_ol^6l01_nX_nX3ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool03?ooool3o`0000Wooooo4OnW`N`00onW`>_oYl7/ojO1k002ojK1
k@03ohiPUonV`NgoY/7]00?oY/7]00?oSf6HolR<UOo8S9D00_oc]X/2oh]GS@?olkJ:0on<F8h2oo>g
RP;oS5V?0ood]hT3oheIS`CoSEZ@00?om;N8ojVmj?nY_NP0A?nY_NP00ol0003oZKgXojVmj006ojVm
j0gooooo00?o0000ooooooooool03Oooool000_ooooo00?o0000ooooooooool02Oooool3o`0001go
oooo5_nY_NP4o`/8Q13oZKkY00?oU6ZOojVmj?n<EX/00_n<EX/01OnY_NSo001Ooh]DRon;E8_o001Q
00;o=aIj0_n>G983ooNkQ`;oSUfC0ooh^hH2ohmNU0?on;^50_n@Gi@2ooRkQ0?oT62E00?onK^3oi5Q
UOnAHID00_nAHID00ooi^h;oYl7/ojO1k002ojO1k0;oUVbP0_nW`N`2omFFT@;on[Ug00CoTEnCoo^h
M_ok^7KonkQf0_nAH9@2oo^hM@?oTV6D0_ok^7@2oi9QU@03o`000?nCHYGoTf:E00;onkQa0_nCHYH0
1Ool^73oU6>FoiASU_nDHiKoo;Q_00?oU6BG0_nX_nX2oiATU`;ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`09ooooo`?o00003Oooool2ojO1k003oooooonW`NcoYl7/00SoYl7/1?nX
_nX00onW`>_oYl7/ohiPU`03ohiPU`03ojK1kOn?HISoSf6H00;oSf6H0_o8S9D2oo>fR`;oReN=0ooc
]XX3ohaHSP;olkN:0_n<FHl3ooBgR@;oSEV?00Com;N8oheJT?n=FY3oSEZ@0_od]hQ7ojVmj003o`00
0?nY_NSoZKgX00;oZKgX4?ooool00ol0003oooooooooo`0=ooooo`002oooool00ol0003ooooooooo
o`06ooooo`?o00008_oooolDojVmj004o`/8Q?nY_NSo2`R4o`/8Q13oZKkY00?oU6ZOojVmj?n<EX/0
0_n<EX/01OnY_NSo001Ooh]DRon;E8_o001Q00;o=aIj0_n>G983ooNkQ`;oSUfC0ooh^hH2ohmNU0?o
n;^50_n@Gi@2ooRkQ0?oT62E00?onK^3oi5QUOnAHID00_nAHID00ooi^h;oUVbPoiI/X006oiI/X0;o
eIJA0_oj^GL00onAGi?onkQfoo^hMP02oo^hMP03oi5PU?ok^7GonkQe00?oTV6D0_ok^7@2oi9QU@03
oo^hL_l0003oTf:E00;onkQa0_nCHYH01Ool^73oU6>FoiASU_nDHiKoo;Q_00OoU6BG0_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo0ol0000Dooooo`04ojO1k?ooooooZ;kY
ob@_Y@?oYl7/1onX_nX00onW`NcoSV2GohiPU`02ohiPU`GoSf6H0_o8S9D2oo>fR`;oReN=0ooc]XX2
ohaHSP?olkN:0_n<FHl3ooBgR@;oSEV?00Com;N8oheJT?n=FY3oSEZ@0_od]hQ8ojVmj003o`000?oo
oooooooo017ooooo00?o0000ooooooooool03Oooool000[ooooo00?o0000ooooooooool01?ooool3
o`0002Kooooo4_nY_NP2o`/8Q003ojVmj?l;28CoZKkY013oZKkY00?oU6ZOojVmj?n<EX/00_n<EX/2
o`00G`;oReB;00Go001QocLFN_lg5W[o=aIjohiLTP03ooNkQ`;oSUfC0ooh^hH2ohmNU0?on;^50_n@
Gi@2ooRkQ0?oT62E00?onK^3oi5QUOnAHID00_nAHID00ooi^h;oUVbPoiI/X006oiI/X0;oeIJA0_oj
^GL00onAGi?onkQfoo^hMP02oo^hMP03oi5PU?ok^7GonkQe00?oTV6D0_ok^7@2oi9QU@03oo^hL_nC
HYGo000000;onkQa0_nCHYH2oobhL0;oU6>F00?oo;Q_oiATUonDI9L01OnDI9L2ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00oooool3o`0001Wooooo00Co92nUojRnjOlT;jGo92nU
2?nX_nX00onW`NcoSV2GohiPU`02ohiPU`GoSf6H0_o8S9D2oo>fR`;oReN=0ooc]XX2ohaHSP?olkN:
0_n<FHl3ooBgR@;oSEV?00Gom;N8oheJT?n=FY3oSEZ@ooBgR017ojVmj0;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0=ooooo`002_ooool01?l0003oooooooooooooool3o`0002Wo
oooo4_nY_NP00ol;28CoZKgXo`/8Q002o`/8Q13oZKkY00?oU6ZOojVmj?n<EX/00_n<EX/2o`00G`;o
ReB;00Go001QocLFN_lg5W[o=aIjohiLTP03ooNkQ`;oSUfC0ooh^hH2ohmNU0?on;^50_n@Gi@2ooRk
Q0;oT62E0ooi^h<3oi5QU@03ooVkP_nFK:3oUVbP00OoUVbP00CoeIJAooZiMooj^GOoTEnC1?ok^7H0
1?nAH9ConkQeoo^hMOok^7D2oi9QU0;onkQd0_nBHID01Ook^7;oTf:Eoi=RUOl0003onkQa00;oTf:F
0_ol^702oiASUP;oo;Q_1_nDI9L2ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo
oooo0ol0000Mooooo`;o92nU2OnX_nX00onW`NcoSV2GohiPU`02ohiPU`GoSf6H00Cob8bEoo>fRooc
]X_olkJ;0_n;Ehd3oo>fRP;oS5R>0ooc]hX2ohaIS`?om;N90_n=FHl01Ood]hSoSEZ@oheJT?n=FY3o
m;N804?oZKgX1oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo000:oooo
o`Co0000;Oooool@ojVmj0;o2`R400?oZKgXo`/8Q?l;28@04OnY_^T00onDJYooZKgXohaFR`02ohaF
R`;o001O0_n;E8/01?l0067o=aIjocLFN_lg5WX5ooNkQ`04ohiMTooh^hKon;^6ooRkQP;oSejD0ooh
^hD2oi1OU0;on;^40_n@H9D3ooVkP`?oTF6E00?onK^2oiI/X?nFK:000onFK:001Oofa9OoUVbPoiI/
X?nFK:3oeIJA00?on[Ug1?ok^7H01OnAH9ConkQeoo^hMOok^7GoTV6D00?onkQd0_nBHID01Ook^7;o
Tf:Eoi=RUOl0003onkQa00;oTf:F0_ol^702oiASUP;oo;Q_0_nDI9L01?ol^6goU6BGoiATUonDI9L2
ooooo`03o`000?oooooooooo01Cooooo1?l0000Pooooo`;o92nU2OnX_nX01OnW`NcoSV2GohiPUon>
H9Ookk^J00GoSf6H00Gob8bEoo>fRooc]X_olkJ;oh]GS@04oo>fRP;oS5R>0ooc]hX2ohaIS`?om;N9
0_n=FHl01Ood]hSoSEZ@oheJT?n=FY3om;N803koZKgX3Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00gooooo000:ooooo`;o0000<?ooool?ojVmj003o`/8Q?nY_NSo2`R400;o2`R4
4OnY_^T00onDJYoo001NohaFR`02ohaFR`;o001O0_n;E8/01?l0067o=aIjocLFN_lg5WX5ooNkQ`04
ohiMTooh^hKon;^6ooRkQP;oSejD0ooh^hD01?n@GiCon;^4ooRkQ?oh^h@2oi1PU@?onK^30_nAHID2
ooVkPP03ol:Z7?nFK:3oUVbP00;oUVbP0_ofa9L2oiI/X004omFFTOoj^GOon[UgooZiM`ConkQf00Go
TF2Doo^hMOok^7GonkQeoi9QU003oo^hM0;oTV6E00GonkQboi=RUOnCHYGonkQao`000002oi=RUP;o
o;Q`0_nDHiH2oobhK`;oU6BG00Coo;Q]oiATUonDI9OoU6BG0oooool00ol0003oooooooooo`0Coooo
o`;o00008_ooool00olT;jGoZ;oZojRojP08ojRojP05ojO1k?n>H9OoSV2GohiPUoo_^iX01On?HIP0
1Oo8S9GolkJ;oo>fRooc]X_oReN=00ColkJ:0_n<F8h3oo>gRP03ohaISood]hWom;N900;om;N90_n=
FHl01Ood]hSoSEZ@oheJT?n=FY3om;N803coZKgX4?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo000<ooooo`03o`000?oooooooooo02oooooo3onY_NP2o`/8Q1;oZKkY00?o
U6ZOo`00G_n<EX/00_n<EX/2o`00G`;oReB;00Co001QocLFN_lg5W[o=aIj1Oog^hL5ooRkQP05ohmN
U?oh^hGon;^5ooRkQOn@Gi@01?oh^h@01?n@H9GonK^3ooVkPooi^h<2oi5QU@03ooVkP_o2ZQco`ZXL
00CoUVbP0_ofa9L2oiI/X004omFFTOoj^GOon[UgooZiM`ConkQf00GoTF2Doo^hMOok^7GonkQeoi9Q
U003oo^hM005oi9QUOok^7;onkQboo^hL_nCHYD00_ok^7401?l0003oTf:FoobhL?ol^702oiASUP;o
o;Q_0_nDI9L01Ool^6goU6BGoiATUonDI9Ooo;Q/00;ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Qooooo`WoZ;oZ00CoYl7/o`00E_n>H9OoSV2G0_o_^iX4ohmQV005olR<UOoc]X_o
lkJ;oo>fRon;Ehd01?oc]XX00on<F8kolkN:oo>gRP02oo>gRP03ohaISood]hWom;N900;om;N90_n=
FHl2ooBgR0;oSEZ@00?om;N8ojVmj?nY_NP0=_nY_NPDooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03Oooool000gooooo00?o0000ooooooooool0;oooool<ojVmj0Co2`R44_nY_^T0
0onDJYoo001NohaFR`02ohaFR`;o001O0_n;E8/2o`00H@?oYL?_1?og^hL5ooRkQP05ohmNU?oh^hGo
n;^5ooRkQOn@Gi@01?oh^h@01?n@H9GonK^3ooVkPooi^h<2oi5QU@03ooVkP_o2ZQco`ZXL00CoUVbP
0_ofa9L2oiI/X004omFFTOoj^GOon[UgooZiM`ConkQf00GoTF2Doo^hMOok^7GonkQeoi9QU003oo^h
M005oi9QUOok^7;onkQboo^hL_nCHYD00ook^7400ol0003oo;Q`oobhL002oiASUP;oo;Q_0_nDI9L0
1Ool^6goU6BGoiATUonDI9Ooo;Q/00;ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Qooooo`WoZ;oZ00?o001FohiPUoo_^iX00_o_^iX4ohmQV005olR<UOoc]X_olkJ;oo>fRon;Ehd0
1?oc]XX00on<F8kolkN:oo>gRP02oo>gRP03ohaISood]hWom;N900;om;N900GoSEV?ooBgR?od]hSo
m;N8oheJT002ooBgR3KoZKgX5oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00co
oooo000>ooooo`03o`000?oooooooooo02oooooo2onY_NP3o`/8Q1?oZKkY00?oU6ZOo`00G_n<EX/0
0_n<EX/2o`00G`;oReB;0ol00643ojG3k`?omk^71Ooh^hH5ooRkQ@Con;^400CoT62EooVkPooi^h?o
nK^30_nAHID00ooi^h;o`ZXLol:Z7004oiI/X0;om/BG0onFK:03ooZiM`GonkQf0ook^7D01OnBHICo
nkQdoo^hM?ok^7CoTV6E00?onkQb00GoTf:Eoo^hLOok^77onkQao`000002oobhL0;oU6>F0ool^6l0
0onDI9Ooo;Q]oiATU`02oiATU`04oobhK?ooooooooooo`0001Wooooo00?o0000ooooooooool08Ooo
ool8ojRojP03o`00E_n>H9Ookk^J00;okk^J1?n?HIP01Oo8S9GolkJ;oo>fRooc]X_oReN=00ColkJ:
00?oS5R>oo>gR_oc]hX00_oc]hX00on<FHoom;N9ooBgR@02ooBgR@05oheISood]hSom;N8ooBgR?n=
FY000_od]hPbojVmj1cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`00
3oooool2o`00033ooooo2?nY_NP00omQ?8ko2`R4o`/8Q002o`/8Q0coZKkY0_nFJYd3ojVnj@?oUVZN
00Co001NohaFRon<EX_oS5J;0_l005l00on;E8_oYL?_ojG3k`09ojG3k`Con;^61Ooh^hD4ooRkQ004
oi1PUOoi^h?onK^3ooVkP`;oTF6E00?onK^2ol:Z7?o2ZQ`00onFK:03ooK4U`?oUVbP0ooj^GL5oo^h
MP?onkQe00GoTV6Doo^hM?ok^7ConkQdoi9QU@03oo^hLP06oi=RUOok^77onkQaoo^hLOnCHYKo0000
0_ol^7001OnDHiKoo;Q_oobhKool^6ooU6BG00;oo;Q]0_nDI9L01?ol^6coooooooooool0000Joooo
o`;o00008_ooool7ojRojP03o`00E_n>H9Ookk^J00;okk^J1?n?HIP4oo>fR`03oh]GSOoc]X[olkJ:
00;olkJ:00?oS5R>oo>gR_oc]hX00_oc]hX00on<FHoom;N9ooBgR@02ooBgR@06oheISood]hSom;N8
ooBgR?n=FY3om;N8<OnY_NPNooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool0017ooooo00?o0000ooooooooool0;oooool3ojVmj0;oTf>G00CoZKgXof4lS_nY_NSo2`R42_nY
_^T6oiIZW@KoUVZN00Co001NohaFRon<EX_oS5J;0_l005l=ojG3k`?on;^61Ooh^hD4ooRkQ004oi1P
UOoi^h?onK^3ooVkP`;oTF6E00?onK^2ol:Z7?nV`^d01?nV`^d00oofa9OoY/;]ojK2k@03ojK2k@03
ooZiMonV`^gonkQf00ConkQf1?ok^7D4oo^hM0?onkQb00WoTf:Eoo^hLOok^77onkQaoi=RU_ol^73o
0000oobhL?nDHiH00ool^6l00onDI9Ooo;Q]oobhK@02oiATU`04oobhK?ooooooooooo`0001cooooo
00?o0000ooooooooool08?ooool6ojRojP03o`00E_n>H9Ookk^J00;okk^J1?n?HIP4oo>fR`GolkJ:
00?oS5R>oo>gR_oc]hX00_oc]hX00on<FHoom;N9ooBgR@02ooBgR@06oheISood]hSom;N8ooBgR?n=
FY3om;N8;?nY_NPTooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool001;o
oooo00?o0000ooooooooool0;_ooool3ojVmj0;oTf>G00?oZKgXof4lS_nY_NP00_l;28@7ojVnj@So
UVZM1_nFJYh01?l005koS5J;ohaFRon<EX/3o`00Ga3oYL?_1?oh^hD4ooRkQ004oi1PUOoi^h?onK^3
ooVkP`;oTF6E00?onK^2ojK2kOnV`^d03OnV`^d4oo^hMPConkQe1?ok^7@3oo^hLP05oi=RUOok^77o
nkQaoo^hLOnCHYH00_ol^7000ol0003oU6>FoobhK`02oobhK`;oU6BG00?oo;Q]oiATUonDI9L00_ol
^6`00ooooooo0000ooooo`0Looooo`03o`000?oooooooooo023ooooo1OnX_nX00ol005Kokk^Jonnk
VP02onnkVP?oSf6H0onU`nl2oo>fR`GolkJ:00?oS5R>oo>gR_oc]hX00_oc]hX00on<FHoom;N9ooBg
R@02ooBgR@06oheISood]hSom;N8ooBgR?n=FY3om;N8:?nY_NPYooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool001?ooooo00?o0000ooooooooool0;_ooool2ojVmj0;oTf>G
00?oZKgXof4lS_mQ?8h00_l;28@3ojVnj@coUVZM1_nFJYh01Ol005koS5J;ohaFRon<EX_o001O01?o
YL?_0ooh^hD4ooRkQ0GonK^300?oTF6EooVkP_l002l03onV`^d2oo^hMP;oY/;]0ook^7D4oo^hM0?o
nkQb00GoTf:Eoo^hLOok^77onkQaoi=RUP02oobhL003o`000?nDHiKoo;Q_00;oo;Q_0_nDI9L00ool
^6goU6BGoiATU`02oobhK0;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Qoooo
o`?oZ;oZ0_l005H2onnkVP_oYL?_0ooc]XX5oo>gRPGom;N900KoSEV?ooBgR?od]hSom;N8oheJT?od
]hPVojVmj2cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`005?ooool0
0ol0003oooooooooo`0^ooooo`04ojVmj?nCHiOoTf>GojVmj0;oHCb>00?o2`R4oiIZWOnFJYd03OnF
JYd00oo^^igoUVZNoiIZWP04oiIZWP04o`00G_n<EX_oS5J;ohaFR`;o001O5_nU`nl3ooRkQ0GonK^3
00?oTF6EooVkP_nV`^d04onV`^d3oo^hM@ConkQd1?ok^783oo^hL@05oi=RU_ol^73oo;Q`oobhL?l0
00000ool^6l2oiATU`03oobhKOnDI9OoU6BG00;oo;Q/0_ooool00ol0003oooooooooo`0Looooo`;o
00008_ooool2ojRojP03o`00E_nU`nooYL?_00goYL?_0_oc]XX5oo>gRPGom;N900KoSEV?ooBgR?od
]hSom;N8oheJT?od]hPRojVmj33ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<
ooooo`005Oooool2o`0002kooooo00CoZKgXoi=SUonCHiOo001V0_mQ?8h@oiIZW@03onjkWOnFJYko
UVZN00CoUVZN00?o001NohaFRon<EX/06_nU`nl2ooRkQ0GonK^30_oi^h8EojK2k@03oo^hMOnV`^go
Y/;]00?onkQd1?ok^784oo^hL@?oo;Q`00?oU6>Fo`000?ol^6l00_ol^6l01?nDI9Ooo;Q]oiATUonD
I9L2oobhK0;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`CoZ;oZ4_nU
`nl3oo>gRPGom;N91?od]hP00on=FY3om;N8ojVmj00MojVmj3Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0<ooooo`005oooool00ol0003oooooooooo`0[ooooo`04ojVmj?nCHiOo
Tf>Go`00IP;oHCb>4?nFJYd2onjkW@GoUVZN0_l005hOojG3k`?onK^300?onK^2ojK2kOnV`^d05onV
`^d3oo^hM0ConkQb1?ok^743oobhL003oiASU_ol^6oo000000;oo;Q_00CoU6BGoobhKOol^6goU6BG
0_ol^6`2ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07oooool3ojRojQ?oYL?_
00?olkN:ojG3konU`nl01?od]hT6ooBgR1coZKgX>?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo000Hooooo`03o`000?oooooooooo02[ooooo00KoZKgXoi=SUonCHiOo001V
ojVmj?mQ?8h@oiIZW@;ok[^M1OnFJYh00ol005koYL?_ojG3k`0OojG3k`;onK^300?onK^2ojK2kOnV
`^d06?nV`^d00ook^7CoY/;]ojK2k@03oo^hLPConkQa1?ol^7001Ool^6oo0000oobhKool^6ooU6BG
00;oo;Q]00KoU6BGoobhK?ol^6coo;Q/ooooool0000Rooooo`03o`000?oooooooooo023ooooo0_nX
_nXFojG3k`?om;N91Ood]hPIojVmj3gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0;ooooo`006Oooool00ol0003oooooooooo`0Yooooo`06ojVmj?nCHiOoTf>Go`00I_nY_NSoHCb>
4?nFJYd2onjkW@KoUVZN9?nU`nlQojK2k@?onkQa1?ol^702oobhK`03o`000?ol^6ooU6BG00;oo;Q]
00KoU6BGoobhK?ol^6coo;Q/ooooool0000Sooooo`;o00008Oooool3ojRojQGoYL?_00?om;N9ojG3
konU`nl01?od]hPEojVmj47ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;oooo
o`006_ooool2o`0002Wooooo0_nY_NP2oi=SU`03ojVmj?mQ?8koUVZM00koUVZM0oo^^id5oiIZWPGo
Z;o[8?nU`nl2ojO1k003ojK2kOnW`NcoY/;]01goY/;]00?onkQaojK2kOol^7000ool^703oobhK`05
o`000?nDI9Ooo;Q]oobhKOnDI9L00ool^6`2ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool07oooool3ojRojP03ojG3konX_n[oZ;oZ01GoYL?_00?om;N8ojG3konU`nl04onY_NQ4oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool001cooooo00?o0000oooooooo
ool09_ooool01OnY_NSo001Uoi=SUonCHiOoZKgX00;oHCb>3_nFJYd3onjkW@?oUVZN2?nX_n/NojG3
k`KoYl7/8?nV`^d3oobhL0Coo;Q_00Co0000oobhKOol^6goU6BG0ool^6`2ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool07oooool6ojRojQKoYL?_4OnY_NQ8ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02oooool001gooooo00?o0000ooooooooool09Oooool01OnY
_NSo001Uoi=SUonCHiOoZKgX00;oHCb>2onFJYd4ojRoj`03onjkWOnX_n_oZ;o[00koZ;o[6_nU`nl7
ojO1k0;oY/;]0_nW`N`LojK2k@03oobhL?nV`^goY/;]00?oo;Q_00Co0000oobhKOol^6goo;Q]0ool
^6`2ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08?ooool5ojRojQ?oYL?_3onY
_NQ<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool001kooooo00?o0000
ooooooooool09?ooool2o`00I@;oTf>G00?o001Vof4lS_mQ?8h02OnFJYdHojRojaSoYL?_3onW`N`L
ojK2k@Coo;Q_00?o0000oobhKOol^6d01?ol^6`00ooooooo0000ooooo`0Vooooo`03o`000?oooooo
oooo023ooooo1_nX_nXAojG3k`_oZKgXDOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00_ooooo000Oooooo`03o`000?oooooooooo02?ooooo0_l006D2oi=SU`03o`00I_mQ?8koHCb>
00GoUVZM8?nX_n/00onU`nooY/;]ojK2k@0@ojG3ka7oYl7/7?nV`^d2oobhK`;oY/;]00?o0000oobh
KOol^6`00ool^6`00ooooooo0000ooooo`0Wooooo`;o00008Oooool4ojRojP03oooooonU`nooYL?_
00koYL?_2_nY_NQDooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool0023o
oooo0_l0000Sooooo`;o001U0_nCHiL01?l006KoHCb>of4lS_nFJYdVojRoj`GoY/;]00?oYL?_ojK2
kOnU`nl02?nU`nlEojO1k0;oY/;]0_nW`N`IojK2k@03o`000?nV`^goY/;]00?oo;Q/00?oooooo`00
0?ooool0:Oooool00ol0003oooooooooo`0Nooooo`CoZ;oZ0_ooool=ojG3k`SoZKgXFOooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo000Rooooo`03o`000?oooooooooo023o
oooo0_l006D2oi=SU`03o`00I_mQ?8koZ;o[02SoZ;o[1onV`^d2ojG3k`;oZ;o[00CoYL?_ojRojonU
`nooYL?_7?nW`N`GojK2k@07o`000?nV`^goY/;]oobhK?nV`^goooooo`00000[ooooo`03o`000?oo
oooooooo01kooooo0_nX_nX4ooooo`;oYL?_0_ooool8ojG3k`GoZKgXG?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo01oooooo0_l006D2
oi=SU`;o001V:_nX_n/6ojK2k@WoZ;o[7?nW`N`00onV`^goYl7/ojK2k@0DojK2k@03o`000?nV`^go
Y/;]00;oY/;]00?oooooo`000?ooool0:_ooool00ol0003oooooooooo`0Wooooo`GoYL?_00Cooooo
ojVmj?nY_NSoZKgXHOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo000T
ooooo`03o`000?oooooooooo01kooooo0_l006D00onCHiOoZ;o[ojRoj`0_ojRoj`03ojK2kOnX_n_o
Z;o[00WoZ;o[7OnW`N`01?ooooooY/;]oooooooooolBojK2k@03o`000?nV`^goY/;]00;oY/;]00?o
0000ooooooooool0:_ooool2o`0002Sooooo1?nU`nl00ooooooo0000ooooo`1Sooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool002Gooooo0_l0000Nooooo`?o001U>onX_n/3
oooooaOoYl7/2_oooolAojK2k@03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0Wooooo`04ojG3koooooooooooo`0006Gooooo00Go0000oooooooooooooooo
o`00000<ooooo`009oooool00ol0003oooooooooo`0Kooooo`;o001U>_nX_n/5oooooaGoYl7/4?oo
ool00onV`^goooooooooo`09ojK2k@;ooooo00Go0000ooooooooooooooooo`00000_ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0Hoooool01Ol0003ooooooooooooooooo000000co
oooo000Xooooo`03o`000?oooooooooo01[ooooo0_l006DfojRoj`[ooooo0_nW`N`2ooooo`_oYl7/
6oooool00onV`^goooooooooo`06ooooo`04o`000?ooooooooooo`00033ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1Tooooo`04o`000?ooooooooooo`0000cooooo000Yooooo`03
o`000?oooooooooo01_ooooo<OnX_n/Dooooo`KoYl7/:Oooool00ol0003oooooo`00000aooooo`;o
0000:?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo000000cooooo000Zooooo`03o`00
0?oooooooooo01_ooooo;_nX_n/Gooooo`?oYl7/:oooool00ol0003oooooo`00000cooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0IOooool01?l0003oooooooooool0000;ooooo`00
:oooool2o`0001cooooo:OnX_n]:ooooo`03o`000?oooooo000003?ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo000000_ooooo000]ooooo`03o`000?oo
oooooooo01[ooooo9?nX_n]?ooooo`;o0000=?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo06Oooooo0_l0000;ooooo`00;_ooool00ol0003oooooooooo`0JoooooaooZ;o[D_ooool3
o`0003Gooooo0_l0000Sooooo`03o`000?oooooooooo06Kooooo0ol0000;ooooo`00;oooool00ol0
003oooooooooo`0IoooooagoZ;o[D?ooool4o`0003[ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1Rooooo`Co00003_ooool0033ooooo0_l0000JoooooaWoZ;o[D?ooool3o`0003oo
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Oooooo`?o00004_ooool003;ooooo
00?o0000ooooooooool06OoooolCojRoje3ooooo1?l00013ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0Foooool4o`0001Gooooo000cooooo`03o`000?oooooooooo01Wooooo3_nX
_n]@ooooo`Co0000B?ooool2o`0001kooooo00?o0000ooooooooool0Eoooool4o`0001Wooooo000d
ooooo`03o`000?oooooooooo01Wooooo2OnX_n]@ooooo`Co0000C_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo05Cooooo0ol0000Mooooo`00=Oooool00ol0003oooooooooo`0Ioooo
o`CoZ;o[DOooool3o`0005?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1@oooo
o`Co00008?ooool003Kooooo0_l0000Jooooo`03ojRojooooooooooo04gooooo1?l0001Gooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0C?ooool4o`0002Cooooo000hooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0BOooool4o`0005cooooo0_l0000Iooooo`03o`00
0?oooooooooo04Sooooo1?l0000Xooooo`00>Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo04Gooooo1?l0001Rooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0AOoo
ool3o`0002cooooo000jooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool3
o`0006Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`11ooooo`Co0000;oooool0
03_ooooo0_l0000Eooooo`03o`000?oooooooooo03kooooo1?l0001[ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0?_ooool4o`0003?ooooo000mooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0>_ooool4o`00073ooooo0_l0000Cooooo`03o`000?oooooooooo03[o
oooo1?l0000gooooo`00?_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Kooooo
1?l0001fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=oooool3o`0003_ooooo
000oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool4o`0007_ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`Co0000?_ooool0043ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0_ooooo`?o0000P?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo02oooooo1?l00012ooooo`00@Oooool2o`0000oooooo00?o0000oooo
ooooool0:oooool4o`0008Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/oooo
o`?o0000A_ooool004?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`Co
0000ROooool2o`0000gooooo00?o0000ooooooooool0:?ooool4o`0004Wooooo0014ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool08oooool4o`0008oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Tooooo`Co0000COooool004Gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Pooooo`?o0000U?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo023ooooo1?l0001Aooooo`00A_ooool2o`0000Wooooo00?o0000ooooooooool07Oooool4
o`0009Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`?o0000EOooool0
04Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`Co0000WOooool2o`00
00Sooooo00?o0000ooooooooool06Oooool4o`0005Sooooo0019ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05Oooool4o`000:?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`Co0000G?ooool004[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Booooo`?o0000Z?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo
1?l0001Pooooo`00Boooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0
002/ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool3o`0006Cooooo001<
ooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000/Oooool2o`0000?ooooo00?o0000
ooooooooool02_ooool4o`0006Oooooo001>ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002g
ooooo`04o`000?ooooooooooo`0000Sooooo1?l0001[ooooo`00Coooool00ol0003oooooo`000005
ooooo`?o0000_?ooool00ol0003oooooo`000005ooooo`?o0000Koooool0053ooooo0_l000000ooo
oooo0000o`000002o`000<3ooooo0_l000000ooooooo0000o`000002o`0007;ooooo001Aooooo`;o
0000aOooool2o`0007Kooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {153.5, 0}} -> {-0.0542361, -0.0193168, \
0.0052844, 0.0052844}, {{10.25, 190.438}, {149.812, 3.625}} -> {-0.0541935, \
0.0451583, 0.00528671, 0.00528671}, {{208.5, 388.688}, {149.812, 3.625}} -> \
{-1.10228, 0.0451583, 0.00528671, 0.00528671}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New classification of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gdnoFrame\  = \ 
        Show[gd, \ Frame \[Rule] False, \ nS];\)\), "\[IndentingNewLine]", 
    \(\(gclass\  = \ 
        DrawHistogramClass[{h1, h2}, \ {class1Color, class2Color}, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gdnoFrame, gclass}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.5902 .67744 Mdot
.46312 .69733 Mdot
.59214 .53131 Mdot
.46047 .74158 Mdot
.56465 .66203 Mdot
.8086 .66246 Mdot
.66851 .63894 Mdot
.6967 .72251 Mdot
.72341 .60342 Mdot
.71878 .66901 Mdot
.54356 .73479 Mdot
.70809 .62644 Mdot
.73555 .57647 Mdot
.51893 .72568 Mdot
.69445 .68162 Mdot
.86374 .51921 Mdot
.60122 .65645 Mdot
.79267 .44651 Mdot
.60333 .65744 Mdot
.57936 .65105 Mdot
.43142 .65685 Mdot
.40946 .79986 Mdot
.69034 .70844 Mdot
.46457 .79237 Mdot
.61399 .71665 Mdot
.75952 .57432 Mdot
.88123 .63337 Mdot
.8185 .55277 Mdot
.39649 .75812 Mdot
.76087 .66901 Mdot
.85397 .50058 Mdot
.51365 .7029 Mdot
.54694 .8159 Mdot
.80613 .6079 Mdot
.73421 .63919 Mdot
.49962 .61552 Mdot
.65331 .63926 Mdot
.60361 .59322 Mdot
.63024 .63471 Mdot
.59731 .51057 Mdot
.69356 .6664 Mdot
.54871 .67263 Mdot
.66198 .71319 Mdot
.90975 .55629 Mdot
.80431 .52758 Mdot
.75625 .58565 Mdot
.69275 .57438 Mdot
.58929 .74095 Mdot
.75998 .59643 Mdot
.43925 .66107 Mdot
.60718 .71259 Mdot
.88537 .43158 Mdot
.66189 .65123 Mdot
.57667 .76942 Mdot
.7947 .53318 Mdot
.62389 .76832 Mdot
.98273 .4782 Mdot
.60896 .73721 Mdot
.72618 .69634 Mdot
.67495 .63315 Mdot
.70492 .67363 Mdot
.60561 .69606 Mdot
.68617 .6044 Mdot
.56563 .69788 Mdot
.6306 .62978 Mdot
.74147 .67165 Mdot
.68223 .553 Mdot
.8317 .47934 Mdot
.68727 .54651 Mdot
.5451 .66571 Mdot
.41576 .67613 Mdot
.56079 .65155 Mdot
.49359 .76175 Mdot
.64288 .69711 Mdot
.52028 .67776 Mdot
.65653 .62883 Mdot
.73958 .55973 Mdot
.5496 .64292 Mdot
.8551 .61587 Mdot
.64292 .55537 Mdot
.61093 .71583 Mdot
.71202 .66146 Mdot
.6145 .60683 Mdot
.33066 .77464 Mdot
.61427 .77847 Mdot
.61824 .76947 Mdot
.60947 .61414 Mdot
.44477 .76145 Mdot
.77685 .43763 Mdot
.70438 .58177 Mdot
.63668 .62325 Mdot
.78474 .63249 Mdot
.43564 .82125 Mdot
.74993 .58211 Mdot
.60741 .59623 Mdot
.54654 .7276 Mdot
.46181 .78419 Mdot
.75383 .66573 Mdot
.63838 .58889 Mdot
.50919 .60134 Mdot
0 0 1 r
.34627 .18054 Mdot
.30961 .15807 Mdot
.27877 .28141 Mdot
.24307 .23825 Mdot
.28126 .1827 Mdot
.26246 .15953 Mdot
.25401 .25216 Mdot
.19332 .32918 Mdot
.20476 .24262 Mdot
.32488 .31113 Mdot
.43744 .10485 Mdot
.36357 .1943 Mdot
.23122 .21897 Mdot
.26625 .21923 Mdot
.33078 .21361 Mdot
.39658 .18052 Mdot
.25803 .30573 Mdot
.37693 .15396 Mdot
.26102 .24521 Mdot
.24428 .30309 Mdot
.23991 .23367 Mdot
.18879 .3284 Mdot
.27406 .26595 Mdot
.07351 .45426 Mdot
.08025 .35445 Mdot
.07781 .3011 Mdot
.13429 .32289 Mdot
.19345 .26896 Mdot
.25682 .26574 Mdot
.18025 .23875 Mdot
.2392 .27217 Mdot
.20549 .29636 Mdot
.08646 .26333 Mdot
.40762 .19309 Mdot
.09606 .36719 Mdot
.18278 .21378 Mdot
.54494 .06818 Mdot
.41223 .24141 Mdot
.14142 .31164 Mdot
.10444 .30398 Mdot
.2448 .30784 Mdot
.30016 .21057 Mdot
.34137 .18945 Mdot
.2036 .32631 Mdot
.17641 .2968 Mdot
.3693 .14734 Mdot
.28549 .17826 Mdot
.39086 .15238 Mdot
.19443 .21863 Mdot
.18672 .29753 Mdot
.40011 .26151 Mdot
.32658 .29642 Mdot
.26558 .32834 Mdot
.25593 .30277 Mdot
.22802 .18142 Mdot
.47629 .08051 Mdot
.25036 .31205 Mdot
.33176 .22013 Mdot
.36174 .23539 Mdot
.26844 .19855 Mdot
.19761 .241 Mdot
.18624 .24387 Mdot
.12632 .32736 Mdot
.12715 .35725 Mdot
.26082 .27556 Mdot
.15578 .19966 Mdot
.23157 .2924 Mdot
.16002 .32183 Mdot
.21901 .37384 Mdot
.35656 .1897 Mdot
.28885 .27257 Mdot
.26726 .26384 Mdot
.02331 .34732 Mdot
.11706 .29957 Mdot
.34142 .22452 Mdot
.40696 .27004 Mdot
.28679 .20446 Mdot
.22887 .26714 Mdot
.22333 .26459 Mdot
.38478 .20154 Mdot
.25202 .28039 Mdot
.3077 .23751 Mdot
.42243 .20874 Mdot
.28383 .22173 Mdot
.04772 .32528 Mdot
.19952 .32635 Mdot
.1306 .31796 Mdot
.29542 .28512 Mdot
.20571 .24033 Mdot
.23693 .20504 Mdot
.30538 .25448 Mdot
.18219 .19592 Mdot
.28891 .21704 Mdot
.14445 .25356 Mdot
.28102 .20049 Mdot
.24852 .18777 Mdot
.24467 .3047 Mdot
.20496 .29045 Mdot
.28214 .14275 Mdot
.2754 .31139 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.0238095 0.0186741 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
153 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00e?oooonV
o`00o`Ooo`003oooool00=CoooooY_l00?l7ool000oooooo003DooooojKo003o1ooo000?ooooo`00
e?oooonSo`00o`[oo`003oooool00=CoooooXol00?l:ool000oooooo003Doooooj?o003o2_oo000?
ooooo`00Joooool3o`00ofKoooooXol00?l:ool000oooooo001[ooooo`?o003oI_oooonPo`00o`go
o`003oooool005kooooo0ol00?l:ooooo`?o003oI_oooonPo`00o`goo`003oooool005kooooo0ol0
0?mcoooooj3o003o3Ooo000?ooooo`00G_ooool3o`00og?oooooW?l00?lAool000oooooo003Doooo
oico003o4Ooo000?ooooo`00e?oooonLo`00oa7oo`003oooool005Oooooo0ol00?mjoooooiWo003o
5?oo000?ooooo`00Eoooool3o`00og[oooooVOl00?lDool000oooooo001Gooooo`?o003oN_oooonI
o`00oaCoo`003oooool00=CoooooVOl00?lDool000oooooo003Doooooi;o003o6ooo000?ooooo`00
e?oooonBo`00oa_oo`003oooool00=CoooooT_l00?lKool000oooooo000kooooo`?o003o3Oooool3
o`00ohKoooooSol00?lNool000oooooo000kooooo`?o003o3Oooool3o`00o`04ooooool00?oo003o
o`00oh;oooooSol00?lNool000oooooo000kooooo`?o003o0_ooool3o`00o`Sooooo1ol00?n2oooo
ohoo003o7_oo000?ooooo`00>?ooool3o`00o`Gooooo0ol00?l9ooooo`Ko003oP_oooon;o`00ob;o
o`003oooool003Sooooo0ol00?l5ooooo`?o003o2Oooool3o`00ohGoooooRol00?lRool000oooooo
000hooooo`?o003oVOoooon;o`00ob;oo`003oooool003cooooo0ol00?l8ooooo`?o003o1_ooool3
o`00oh7oooooRol00?lRool000oooooo000aooooo`?o003o1oooool4o`00o`Sooooo0ol00?l6oooo
o`?o003oPOoooon8o`00obGoo`003oooool0037ooooo0ol00?l01?oooooo003oo`00ool00?l3oooo
o`Co003o1oooool6o`00o`Cooooo0ol00?n1ooooohSo003o9Ooo000?ooooo`00:Oooool3o`00o`Go
oooo0ol00?l01?oooooo003oo`00ool00?l3ooooo`?o003o2?ooool7o`00o`Gooooo0ol00?mooooo
ohSo003o9Ooo000?ooooo`009?ooool3o`00o`;ooooo0ol00?l9ooooo`?o003o00?oooooo`00ool0
0?l00ol00?l8ooooo`Oo003o00Goooooo`00ool00?oo003oooooo`03o`00ogooooooQ?l00?lYool0
00oooooo000Tooooo`?o003o0_ooool3o`00o`Oooooo0ol00?l3ooooo`Ko003o2oooool3o`00o`05
ooooool00?oo003oo`00ooooool00ol00?moooooohCo003o:Ooo000?ooooo`009?ooool3o`00o`;o
oooo0ol00?l7ooooo`?o003o0oooool8o`00o`?ooooo0ol00?l7ooooo`?o003o1?ooool3o`00ogco
ooooQ?l00?lYool000oooooo000Yooooo`Go003o1?ooool4o`00o`;ooooo0ol00?l00ooooooo003o
o`00o`03o`00o`?ooooo0ol00?l>ooooo`?o003oO?oooon1o`00obcoo`003oooool002Wooooo1Ol0
0?l4ooooo`?o003o0oooool3o`00o`03ooooool00?oo003o00?o003o0oooool5o`00o`cooooo0ol0
0?mloooooh7o003o;?oo000?ooooo`00:oooool3o`00o`Cooooo0ol00?l3ooooo`?o003o00Cooooo
o`00ool00?oo003o1Oooool5o`00oh_oooooPOl00?l/ool000oooooo000dooooo`?o003o1Oooool3
o`00o`Gooooo1Ol00?l01?oooooo003oo`00ool00?n7oooooh7o003o;?oo000?ooooo`00:Oooool7
o`00o`Cooooo0ol00?l9ooooo`?o003o1oooool3o`00o`Kooooo0ol00?mnooooogko003o;ooo000?
ooooo`00:Oooool7o`00o`Cooooo1_l00?l6ooooo`?o003o1oooool3o`00o`Kooooo0ol00?mnoooo
ogko003o;ooo000?ooooo`00:Oooool7o`00o`Cooooo1_l00?l6ooooo`?o003o4?ooool3o`00ogko
ooooO_l00?l_ool000oooooo000Rooooo`?o003o1Oooool6o`00o`Kooooo1?l00?l5ooooo`?o003o
T_oooomjo`00oc?oo`003oooool001Sooooo0ol00?l7ooooo`?o003o4Oooool6o`00o`?ooooo0ol0
0?l>ooooo`?o003oPOoooomjo`00oc?oo`003oooool001Sooooo0ol00?l7ooooo`?o003o1_ooool3
o`00o`?ooooo1?l00?l2ooooo`Ko003o0_ooool3o`00o`kooooo0ol00?n1ooooog[o003o<ooo000?
ooooo`006?ooool3o`00oa3ooooo0ol00?l3ooooo`Go003o00?oooooo`00ool00?l01_l00?lAoooo
o`Go003oOooooomco`00oc[oo`003oooool002_ooooo0ol00?l3ooooo`ko003o4oooool3o`00ogoo
ooooLol00?ljool000oooooo000cooooo`Oo003o00?oooooo`00ool00?l01?l00?lAooooo`?o003o
Oooooomco`00oc[oo`003oooool002gooooo0ol00?l6ooooo`Co003o00?oooooo`00ool00?l01?l0
0?nCooooog?o003o>_oo000?ooooo`00:?ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o1_ooool6
o`00o`;ooooo0ol00?n>ooooog3o003o?Ooo000?ooooo`005_ooool3o`00o`Cooooo0ol00?l8oooo
o`So003o0_ooool3o`00o`04ooooool00?oo003oo`00o`[ooooo0ol00?n>ooooog3o003o?Ooo000?
ooooo`005_ooool3o`00o`;ooooo1Ol00?l8ooooo`So003o0_ooool8o`00o`Wooooo0ol00?n>oooo
og3o003o?Ooo000?ooooo`005_ooool3o`00o`;ooooo1Ol00?l2ooooo`?o003o1Oooool3o`00o`Oo
oooo2Ol00?l6ooooo`?o003oS_oooom`o`00ocgoo`003oooool001_ooooo0ol00?l2ooooo`Go003o
3oooool9o`00o`Kooooo0ol00?n>ooooog3o003o?Ooo000?ooooo`008?ooool8o`00o`gooooo0ol0
0?l2ooooo`?o003o1_ooool3o`00ohkoooooL?l00?lmool000oooooo000Aooooo`?o003o2oooool5
o`00o`04ooooool00?oo003oo`00o`;ooooo1_l00?l8ooooo`?o003oVOoooom`o`00ocgoo`003ooo
ool0017ooooo0ol00?l;ooooo`Go003o00Coooooo`00ool00?oo003o0_ooool6o`00o`Sooooo0ol0
0?nIooooofgo003o@?oo000?ooooo`004Oooool3o`00o`_ooooo0ol00?l8ooooo`Ko003o2?ooool3
o`00oiWoooooKOl00?m0ool000oooooo003Dooooofgo003o@?oo000?ooooo`003Oooool3o`00olCo
ooooJOl00?m4ool000oooooo000=ooooo`?o003o1oooool3o`00o`Gooooo0ol00?nbooooofWo003o
A?oo000?ooooo`003Oooool3o`00o`Oooooo0ol00?l5ooooo`?o003o/_oooomYo`00odCoo`003ooo
ool001Oooooo1_l00?l2ooooo`?o003o/_oooomVo`00odOoo`003oooool001[ooooo0ol00?lCoooo
o`?o003oXOoooomVo`00odOoo`003oooool001[ooooo0ol00?lCooooo`?o003oXOoooomVo`00odOo
o`003oooool0033ooooo0ol00?nQooooofKo003oAooo000?ooooo`00e?oooomOo`00odkoo`003ooo
ool00=CoooooGol00?m>ool000oooooo003Doooooeoo003oC_oo000?ooooo`00e?oooomLo`00oe7o
o`003oooool00=CoooooG?l00?mAool000oooooo003Doooooeco003oDOoo000?ooooo`00e?oooomE
o`00oeSoo`003oooool00=CoooooEOl00?mHool000oooooo002Xooooo`?oo`00:OoooomEo`00oeSo
o`003oooool009Cooooo0ooo000Aooooo`?oo`00:OoooomEo`00oeSoo`003oooool009Cooooo1_oo
000>ooooo`?oo`00:Ooooom>o`00oeooo`003oooool009Cooooo1_oo000jooooodko003oGooo000?
ooooo`005_ooool3o`00ogkooooo0ooo000jooooodko003oGooo000?ooooo`005_ooool3o`00ok_o
ooooA?l00?mYool000oooooo000Fooooo`?o003o^ooooom4o`00ofWoo`003oooool00=CoooooA?l0
0?mYool000oooooo002Nooooo`?oo`006Oooool3ool001Oooooo?Ol00?m`ool000oooooo002Noooo
o`?oo`006Oooool3ool001Oooooo?Ol00?m`ool000oooooo002Nooooo`?oo`006Oooool3ool001Oo
oooo?Ol00?m`ool000oooooo003Dooooocgo003oL?oo000?ooooo`00X_ooool3ool002oooooo=ol0
0?mfool000oooooo002Rooooo`?oo`00;ooooolgo`00ogKoo`003oooool007Cooooo0ooo000[oooo
o`?oo`00;ooooolgo`00ogKoo`003oooool007Cooooo0ooo001Moooooc3o003oOOoo000?ooooo`00
M?ooool3ool002gooooo0ooo000]oooooc3o003oOOoo000?ooooo`00VOooool3ool000Sooooo0ooo
000]oooooc3o003oOOoo000?ooooo`00Loooool3ool002;ooooo1?oo0008ooooo`?oo`00;Oooool/
o`00oh7oo`003oooool007?ooooo0ooo000Rooooo`Coo`00>?ooool/o`00oh7oo`003oooool007?o
oooo0ooo000>ooooo`?oo`004Oooool3ool003Wooooo;?l00?n1ool000oooooo0024ooooo`?oo`00
COooool/o`00oh7oo`003oooool007cooooo0ooo0004ooooo`Coo`005Oooool3ool000gooooo0ooo
000UooooobWo003oQ?oo000?ooooo`00O?ooool3ool000Cooooo0ooo0008ooooo`?oo`002oooool3
ool000gooooo0ooo000UooooobWo003oQ?oo000?ooooo`00O?ooool3ool000Cooooo0ooo0008oooo
o`?oo`002oooool3ool000gooooo0ooo000UooooobWo003oQ?oo000?ooooo`00QOooool3ool000Ko
oooo1_oo0010ooooobKo003oQooo000?ooooo`00QOooool3ool000Gooooo0ooo00001?ooooooo`00
ool00?oo0010ooooobKo003oQooo000?ooooo`00QOooool5ool000?ooooo1ooo0010ooooobKo003o
Qooo000?ooooo`00Noooool3ool000Wooooo0ooo0003ooooo`Ooo`00@?oooolRo`00oh_oo`003ooo
ool007Gooooo1?oo0002ooooo`?oo`002Oooool3ool000Kooooo1?oo0010ooooob;o003oRooo000?
ooooo`00I?ooool3ool000kooooo1?oo0002ooooo`?oo`004oooool3ool0043ooooo8_l00?n;ool0
00oooooo001Tooooo`?oo`003_ooool5ool000[ooooo0ooo0004ooooo`?oo`000oooool3ool0043o
oooo8_l00?n;ool000oooooo001Tooooo`?oo`004?ooool3ool000[ooooo0ooo0004ooooo`?oo`00
3?ooool3ool003Oooooo7ol00?n>ool000oooooo001Rooooo`?oo`004Oooool4ool000[ooooo0ooo
0004ooooo`?oo`003?ooool3ool000Kooooo0ooo000^oooooaoo003oS_oo000?ooooo`00H_ooool3
ool0017ooooo0ooo0002ooooo`?oo`007?ooool3ool000Kooooo0ooo000^oooooaoo003oS_oo000?
ooooo`00H_ooool3ool0017ooooo0ooo00000oooooooo`00ool00002ool00004oooooooo003oo`00
ool000Kooooo0ooo000Hooooo`?oo`00;_oooolKo`00oi;oo`003oooool007[ooooo1?oo00000ooo
ooooo`00ool00004ool000?ooooo0ooo000;ooooo`?oo`003_ooool3ool002[ooooo6ol00?nBool0
00oooooo001jooooo`?oo`0000?oooooool00?oo00001Ooo0003ooooo`?oo`000_ooool3ool000Ko
oooo0ooo000>ooooo`?oo`00:_oooolKo`00oi;oo`003oooool006_ooooo0ooo000<ooooo`?oo`00
00?oooooool00?oo00001Ooo0008ooooo`?oo`001_ooool3ool000kooooo0ooo000ZoooooaSo003o
UOoo000?ooooo`00Joooool5ool00004oooooooo003oo`00ool000[ooooo1_oo0009ooooo`?oo`00
A?oooolHo`00oiGoo`003oooool005Kooooo0ooo000Booooo`Goo`0000Goooooool00?oo003oo`00
ooooo`03ool000Sooooo0ooo001AoooooaSo003oUOoo000?ooooo`00E_ooool5ool001;ooooo1ooo
00001?ooooooo`00ool00?oo0008ooooo`?oo`001_ooool3ool000kooooo0ooo000goooooaSo003o
UOoo000?ooooo`00E_ooool5ool0013ooooo1_oo0004ooooo`?oo`003Oooool3ool00004oooooooo
003oo`00ool000Cooooo0ooo0007ooooo`?oo`00=ooooolEo`00oiSoo`003oooool005Sooooo0ooo
000@ooooo`Koo`005?ooool8ool00003oooooooo003oo`0000Goo`001Oooool3ool003Oooooo5Ol0
0?nHool000oooooo001Cooooo`?oo`004?ooool3ool000;ooooo0ooo0005ooooo`?oo`003oooool8
ool00003oooooooo003oo`0000Goo`00?ooooolEo`00oiSoo`003oooool005?ooooo0ooo000@oooo
o`?oo`000_ooool3ool000Gooooo0ooo000@ooooo`Ooo`0000Goooooool00?oo003oo`00ooooo`03
ool003oooooo4Ol00?nLool000oooooo001Cooooo`?oo`004?ooool3ool000[ooooo0ooo000@oooo
o`?oo`00BooooolAo`00oicoo`003oooool007Kooooo0ooo000=ooooo`?oo`000_ooool3ool004Ko
oooo4Ol00?nLool000oooooo001Looooo`?oo`003oooool3ool000Gooooo0ooo0003ooooo`?oo`00
3?ooool3ool004Kooooo4Ol00?nLool000oooooo001Looooo`?oo`001_ooool3ool000Kooooo0ooo
0005ooooo`?oo`000oooool3ool000cooooo0ooo0016ooooo`ko003oWooo000?ooooo`00G?ooool3
ool000Kooooo0ooo0006ooooo`?oo`001Oooool3ool000?ooooo0ooo0006ooooo`?oo`00C?ooool>
o`00oiooo`003oooool006Gooooo0ooo000>ooooo`Coo`001_ooool3ool000;ooooo0ooo001<oooo
o`ko003oWooo000?ooooo`00M_ooool4ool000Kooooo0ooo0002ooooo`Coo`00Boooool7o`00ojKo
o`003oooool006Kooooo0ooo0002ooooo`?oo`002Oooool3ool000Kooooo0ooo0003ooooo`?oo`00
Boooool7o`00ojKoo`003oooool006Kooooo0ooo00000oooooooo`00ool00002ool001Sooooo0ooo
001;ooooo`Oo003oY_oo000?ooooo`00I_ooool3ool00003oooooooo003oo`0000;oo`002?ooool3
ool005_ooooo1?l00?nYool000oooooo001Kooooo`?oo`003?ooool3ool000Kooooo1_oo001Koooo
o`Co003oZOoo000?ooooo`00Foooool3ool001Gooooo1_oo001Kooooo`Co003oZOoo000?ooooo`00
Foooool3ool001Gooooo0ooo001Nooooo`Co003oZOoo000?ooooo`00D?ooool3ool000Kooooo0ooo
0005ooooo`?oo`00L?oooon]ool000oooooo001@ooooo`?oo`001_ooool3ool000Gooooo0ooo000E
ooooo`?oo`00F?oooon]ool000oooooo001@ooooo`?oo`001_ooool3ool000Gooooo0ooo000<oooo
o`?oo`001Oooool4ool005Sooooo[Ooo000?ooooo`00A?ooool3ool002Wooooo0ooo0004ooooo`Go
o`00F?oooon]ool000oooooo0014ooooo`?oo`005Oooool3ool0017ooooo0ooo0004ooooo`Coo`00
FOoooon]ool000oooooo0014ooooo`?oo`005Oooool3ool001Sooooo0ooo001Jooooojgoo`003ooo
ool005cooooo0ooo001eooooojgoo`003oooool005;ooooo0ooo0007ooooo`?oo`00MOoooon]ool0
00oooooo001Booooo`?oo`001oooool3ool007Gooooo[Ooo000?ooooo`00D_ooool3ool007oooooo
[Ooo000?ooooo`00Joooool3ool006Kooooo[Ooo000?ooooo`00Eoooool3ool0017ooooo0ooo001V
ooooojgoo`003oooool005Oooooo0ooo000Aooooo`?oo`00I_oooon]ool000oooooo001Gooooo`?o
o`00N_oooon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00e?oooon]
ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00e?oooon]ool000oooooo
003Dooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00e?oooon]ool000oooooo003Dooooojgo
o`003oooool00=Cooooo[Ooo000?ooooo`00e?oooon]ool000oooooo003Dooooojgoo`003oooool0
0=Cooooo[Ooo000?ooooo`00e?oooon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo
000?ooooo`00e?oooon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00
e?oooon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00e?oooon]ool0
00oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-1.1227, \
-1.0611, 0.011199, 0.011199}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-63.1851, -2.62981, 0.296885, 0.296885}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example D: different Gaussian distributions", "Section"],

Cell[CellGroupData[{

Cell["Generate data from two Gaussian classes", "Subsection"],

Cell[CellGroupData[{

Cell["Definition of Gaussians", "Subsubsection"],

Cell[BoxData[{
    \(\(\[Mu]1\  = \ { .3,  .3};\)\), "\n", 
    \(\(\[CapitalSigma]1\  = \  .07 {{1. , \(- .5\)}, {\(- .5\),  \
.5}};\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\(\[Mu]2\  = \ {\(- .5\), \(- .5\)};\)\), "\n", 
    \(\(\[CapitalSigma]2\  = \  .06 {{1. ,  .5}, { .5,  .5}};\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[{
    \(\(n1\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(n2\  = \ 100;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = \ 
        Table[rgBounded[{\[Mu]1, \ \[CapitalSigma]1}, pr], {n1}];\)\), "\n", 
    \(\(data2\  = \ 
        Table[rgBounded[{\[Mu]2, \ \[CapitalSigma]2}, 
            pr], {n2}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[data2, pr, style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ 
        Show[gd1, gd2, \ yS, \ FrameTicks \[Rule] None];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.76921 .64295 Mdot
.56704 .69013 Mdot
.75295 .59186 Mdot
.68704 .57554 Mdot
.7077 .64248 Mdot
.72536 .69368 Mdot
.56743 .81534 Mdot
.6185 .66989 Mdot
.7966 .59181 Mdot
.91874 .53216 Mdot
.63443 .74925 Mdot
.67714 .58782 Mdot
.68619 .65385 Mdot
.63347 .67867 Mdot
.78301 .68453 Mdot
.431 .75982 Mdot
.83512 .58625 Mdot
.62213 .69227 Mdot
.65099 .52892 Mdot
.68982 .60815 Mdot
.62373 .60539 Mdot
.70365 .5862 Mdot
.46149 .7704 Mdot
.96423 .55213 Mdot
.58757 .75816 Mdot
.66269 .50089 Mdot
.77416 .67256 Mdot
.64296 .68883 Mdot
.68658 .64317 Mdot
.6796 .62759 Mdot
.59038 .7189 Mdot
.93142 .57169 Mdot
.43749 .63803 Mdot
.69974 .72659 Mdot
.69326 .67323 Mdot
.77793 .6757 Mdot
.78924 .5041 Mdot
.4401 .83425 Mdot
.58603 .51263 Mdot
.78866 .65554 Mdot
.44366 .65311 Mdot
.727 .70103 Mdot
.62042 .75592 Mdot
.80902 .64126 Mdot
.51964 .63381 Mdot
.6647 .635 Mdot
.51329 .73266 Mdot
.65075 .59886 Mdot
.47075 .68029 Mdot
.56864 .73715 Mdot
.80079 .49161 Mdot
.67625 .72883 Mdot
.65021 .77721 Mdot
.97719 .52753 Mdot
.73793 .59678 Mdot
.73021 .58639 Mdot
.56985 .75537 Mdot
.73744 .60898 Mdot
.6851 .61125 Mdot
.61857 .83447 Mdot
.62482 .71998 Mdot
.79441 .52571 Mdot
.50075 .76869 Mdot
.51028 .57576 Mdot
.75974 .68296 Mdot
.40991 .62938 Mdot
.70963 .69078 Mdot
.59779 .56609 Mdot
.65813 .63733 Mdot
.5929 .59807 Mdot
.94806 .4805 Mdot
.49059 .76358 Mdot
.5947 .59351 Mdot
.26742 .80621 Mdot
.55099 .89452 Mdot
.67095 .62172 Mdot
.72009 .64925 Mdot
.65949 .66589 Mdot
.85005 .50774 Mdot
.53748 .70428 Mdot
.83179 .61265 Mdot
.72058 .50966 Mdot
.83562 .62877 Mdot
.59405 .70406 Mdot
.56972 .71403 Mdot
.69442 .59167 Mdot
.71954 .64562 Mdot
.71914 .61218 Mdot
.65898 .61832 Mdot
.73796 .61888 Mdot
.6014 .78205 Mdot
.79683 .55767 Mdot
.62126 .66387 Mdot
.77326 .50924 Mdot
.8496 .62908 Mdot
.51148 .73852 Mdot
.63201 .75524 Mdot
.60299 .71066 Mdot
.63009 .7393 Mdot
.59565 .71558 Mdot
0 0 1 r
.1162 .19077 Mdot
.24801 .25894 Mdot
.30902 .37049 Mdot
.18551 .28447 Mdot
.21993 .14635 Mdot
.02549 .16303 Mdot
.08225 .09379 Mdot
.37208 .31797 Mdot
.21305 .25985 Mdot
.22133 .20287 Mdot
.39469 .36398 Mdot
.10113 .29615 Mdot
.20089 .20862 Mdot
.51363 .42542 Mdot
.1511 .2407 Mdot
.23301 .18202 Mdot
.16033 .11693 Mdot
.2447 .32645 Mdot
.5096 .43276 Mdot
.25586 .29169 Mdot
.20055 .12342 Mdot
.24726 .24881 Mdot
.19842 .19721 Mdot
.26062 .2788 Mdot
.29485 .27788 Mdot
.28462 .29833 Mdot
.13895 .13094 Mdot
.064 .19115 Mdot
.49848 .34485 Mdot
.2812 .30219 Mdot
.50266 .28702 Mdot
.26402 .2562 Mdot
.28044 .30149 Mdot
.24434 .25201 Mdot
.39987 .44812 Mdot
.46729 .35465 Mdot
.33173 .26109 Mdot
.21507 .22824 Mdot
.36508 .28363 Mdot
.09954 .2719 Mdot
.38085 .3301 Mdot
.04621 .21355 Mdot
.30535 .23911 Mdot
.49027 .39152 Mdot
.23274 .29061 Mdot
.43262 .23807 Mdot
.25424 .1969 Mdot
.29699 .25132 Mdot
.2794 .24928 Mdot
.22965 .26337 Mdot
.41048 .29125 Mdot
.33432 .28509 Mdot
.31801 .25888 Mdot
.14785 .18068 Mdot
.53255 .43691 Mdot
.11549 .17091 Mdot
.27123 .17228 Mdot
.17499 .14652 Mdot
.35782 .30983 Mdot
.28877 .2093 Mdot
.30443 .31716 Mdot
.14287 .20794 Mdot
.27211 .34369 Mdot
.18753 .21951 Mdot
.18918 .27159 Mdot
.4538 .31739 Mdot
.22019 .29944 Mdot
.16333 .23401 Mdot
.04671 .13445 Mdot
.25109 .1515 Mdot
.11931 .18207 Mdot
.35414 .28788 Mdot
.20382 .26025 Mdot
.3703 .36834 Mdot
.48294 .35325 Mdot
.27007 .2202 Mdot
.29123 .27611 Mdot
.04322 .15197 Mdot
.1047 .11027 Mdot
.26397 .25715 Mdot
.2582 .25228 Mdot
.10358 .19648 Mdot
.41186 .28622 Mdot
.34047 .33201 Mdot
.07782 .20346 Mdot
.45474 .34458 Mdot
.01792 .17003 Mdot
.29718 .34707 Mdot
.05681 .20874 Mdot
.19923 .12606 Mdot
.26693 .23785 Mdot
.23707 .14248 Mdot
.2935 .26349 Mdot
.23856 .28659 Mdot
.37127 .31719 Mdot
.36967 .41544 Mdot
.09343 .12923 Mdot
.27573 .28996 Mdot
.40644 .40736 Mdot
.40734 .32038 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`0Cooooo`?o003oooooool6ooooo`7o00000Oooool00003
o`000?oooooooooo01;ooooo1Ol00?ooooooo`Gooooo0Ol00001ooooo`0000?o0000ooooooooool0
4_ooool5o`00oooooooo1Oooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`Go003ooooo
ool5ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo0ol00?ooooooo`Kooooo0Ol00001
ooooo`0000?o0000ooooooooool06Oooool3o`00oooooooo0Ol00001ooooo`0000?o0000oooooooo
ool06?ooool5o`00o`cooooo0ol00?o_ooooo`7o00000Oooool00003o`000?oooooooooo01Sooooo
1Ol00?l;ooooo`Go003ok_ooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`Go003o2ooo
ool5o`00o`Sooooo0ol00?oSooooo`7o00000Oooool00003o`000?oooooooooo01Wooooo0ol00?l<
ooooo`Go003o1oooool5o`00on;ooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool3o`00
o`[ooooo0ol00?l3ooooo`?o003o1oooool6o`00on;ooooo0Ol00001ooooo`0000?o0000oooooooo
ool02Oooool3o`00o`Wooooo1Ol00?l8ooooo`Go003o3?ooool6o`00on;ooooo0Ol00001ooooo`00
00?o0000ooooooooool02?ooool5o`00o`Sooooo1Ol00?l8ooooo`Go003o3?ooool5o`00on?ooooo
0Ol00001ooooo`0000?o0000ooooooooool02?ooool5o`00o`Sooooo1Ol00?l8ooooo`Go003o3Ooo
ool3o`00onCooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool5o`00o`Wooooo0ol00?l:
ooooo`?o003o6Oooool3o`00omWooooo0Ol00001ooooo`0000?o0000ooooooooool02Oooool3o`00
ob7ooooo0ol00?l:ooooo`?o003o00?oooooo`00ool00?l00ol00?oHooooo`7o00000Oooool00003
o`000?oooooooooo02cooooo1Ol00?l8ooooo`go003oeOooool1o`00007ooooo00000ol0003ooooo
ooooo`08ooooo`?o003o8Oooool5o`00o`Sooooo3_l00?oDooooo`7o00000Oooool00003o`000?oo
oooooooo00Oooooo1Ol00?lPooooo`Go003o2?ooool5o`00o`03ooooool00?oo003o00Ko003oe?oo
ool1o`00007ooooo00000ol0003oooooooooo`07ooooo`Go003o8Oooool3o`00o`[ooooo0ol00?l5
ooooo`Go003oe?ooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`?o003o00?oooooo`00
ool00?l00ol00?lgooooo`?o003oeOooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`Go
003o00Coooooo`00ool00?oo003ooooooolAooooo`7o00000Oooool00003o`000?oooooooooo00Oo
003o5Oooool3o`00ob[ooooo0ol00?o?ooooo`7o00000Oooool00003o`000?oooooo003o00Oo003o
5?ooool5o`00obSooooo1Ol00?o>ooooo`7o00000Oooool00003o`000?oooooo003o00Ko003o5Ooo
ool5o`00obSooooo1Ol00?o>ooooo`7o00000Oooool00003o`000?oooooo003o00Co003o5oooool6
o`00o`Gooooo0ol00?lEooooo`?o003o1oooool5o`00olkooooo0Ol00001ooooo`0000?o0000oooo
ooooool00ol00?lIooooo`Ko003o0oooool5o`00oa?ooooo1Ol00?l7ooooo`?o003ocoooool1o`00
007ooooo00000ol0003oooooooooo`0Mooooo`Go003o0oooool5o`00oa?ooooo1Ol00?oIooooo`7o
00000Oooool00003o`000?oooooooooo00kooooo0ol00?l<ooooo`Go003o0oooool5o`00oa?ooooo
1Ol00?oIooooo`7o00000Oooool00003o`000?oooooooooo00gooooo1Ol00?l7ooooo`So003o1Ooo
ool3o`00o`_ooooo0ol00?l7ooooo`?o003o0oooool3o`00omCooooo0Ol00001ooooo`0000?o0000
ooooooooool03Oooool5o`00o`Kooooo2Ol00?lBooooo`Go003o2oooool5o`00om?ooooo0Ol00001
ooooo`0000?o0000ooooooooool03Oooool8o`00o`?ooooo2Ol00?lBooooo`Go003o0oooool3o`00
o`Gooooo1Ol00?oCooooo`7o00000Oooool00003o`000?oooooooooo00kooooo2?l00?l2ooooo`So
003o4oooool5o`00o`;ooooo1Ol00?l4ooooo`Go003odoooool1o`00007ooooo00000ol0003ooooo
ooooo`0<ooooo`?o003o0_ooool5o`00o`?ooooo0ol00?l8ooooo`?o003o3Oooool4o`00o`;ooooo
1Ol00?l5ooooo`?o003o1oooool3o`00ol[ooooo0Ol00001ooooo`0000?o0000ooooooooool02Ooo
ool7o`00o`03ooooool00?oo003o00?o003o3Oooool5o`00o`cooooo1Ol00?l00ooooooo003oo`00
o`03o`00o`kooooo1Ol00?o9ooooo`7o00000Oooool00003o`000?oooooooooo00Sooooo2?l00?l2
ooooo`?o003o3_ooool5o`00o`cooooo1Ol00?l2ooooo`?o003o3oooool5o`00olWooooo0Ol00001
ooooo`0000?o0000ooooooooool02?ooool8o`00oa?ooooo1Ol00?l9ooooo`So003o4?ooool3o`00
o`03ooooool00?oo003o00?o003obOooool1o`00007ooooo00000ol0003oooooooooo`08ooooo`Oo
003o5Oooool3o`00o`Wooooo2?l00?l@ooooo`Go003o00Coooooo`00ool00?oo003ob_ooool1o`00
007ooooo00000ol0003oooooooooo`09ooooo`?o003o9?ooool5o`00o`Cooooo0ol00?l<ooooo`Go
003oc_ooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Go003o0oooool5o`00o`_ooooo
1Ol00?o>ooooo`7o00000Oooool00003o`000?oooooooooo02[ooooo0ol00?l4ooooo`?o003o1?oo
ool5o`00o`cooooo0ol00?o?ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo1Ol00?l:
ooooo`Go003o2oooool3o`00obcooooo0ol00?nQooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo1ol00?l;ooooo`?o003o2oooool5o`00o`Oooooo0ol00?lPooooo`Go003oX?ooool1o`00
007ooooo00000ol0003oooooooooo`0Vooooo`So003o6Oooool5o`00o`Kooooo1Ol00?lOooooo`Go
003oX?ooool1o`00007ooooo00000ol0003oooooooooo`0Vooooo`Oo003o5Oooool3o`00o`;ooooo
1ol00?l4ooooo`Go003o7oooool5o`00oj3ooooo0Ol00001ooooo`0000?o0000ooooooooool09_oo
ool5o`00oaKooooo3_l00?l00ooooooo003oo`00o`05o`00ob3ooooo0ol00?nQooooo`7o00000Ooo
ool00003o`000?oooooooooo02Oooooo0ol00?lFoooooaKo003oaOooool1o`00007ooooo00000ol0
003oooooooooo`0hooooo`?o003o1OoooolDo`00o`?ooooo0ol00?o1ooooo`7o00000Oooool00003
o`000?oooooooooo03Kooooo1_l00?l00ooooooo003oo`00o`0?o`00o`03ooooool00?oo003o00?o
003o0_ooool7o`00okkooooo0Ol00001ooooo`0000?o0000ooooooooool0=OoooolFo`00o`?ooooo
1Ol00?l3ooooo`So003o_Oooool1o`00007ooooo00000ol0003oooooooooo`0eoooooaKo003o0ooo
ool5o`00o`?ooooo2?l00?nmooooo`7o00000Oooool00003o`000?oooooooooo01Sooooo0ol00?lG
ooooo`Wo003o00?oooooo`00ool00?l00ol00?l01?oooooo003oo`00ool00?l2ooooo`?o003o1?oo
ool5o`00o`Cooooo1ol00?nmooooo`7o00000Oooool00003o`000?oooooooooo01Oooooo1Ol00?lE
ooooo`So003o1?ooool3o`00o`oooooo0ol00?l8ooooo`?o003o__ooool1o`00007ooooo00000ol0
003oooooooooo`0Gooooo`Go003o5Oooool5o`00oa3ooooo0ol00?l5ooooo`Go003ob?ooool1o`00
007ooooo00000ol0003oooooooooo`0Gooooo`Go003o5Oooool5o`00o`oooooo1Ol00?l4ooooo`Ko
003o4?ooool3o`00okCooooo0Ol00001ooooo`0000?o0000ooooooooool06?ooool3o`00oaKooooo
1?l00?l;ooooo`?o003o0_ooool5o`00o`Cooooo1_l00?l7ooooo`?o003o0oooool7o`00o`Wooooo
0ol00?lGooooo`?o003oSOooool1o`00007ooooo00000ol0003oooooooooo`0`ooooo`Go003o2Ooo
ool6o`00o`03ooooool00?oo003o00Ko003o0_ooool5o`00o`Kooooo1Ol00?l00ooooooo003oo`00
o`06o`00o`Sooooo1Ol00?lEooooo`Go003oS?ooool1o`00007ooooo00000ol0003oooooooooo`0`
ooooo`Go003o2?ooool7o`00o`03ooooool00?oo003o00Oo003o0_ooool3o`00o`Oooooo1Ol00?l0
0ooooooo003oo`00o`06o`00o`Sooooo1Ol00?lEooooo`Go003oS?ooool1o`00007ooooo00000ol0
003oooooooooo`0Hooooo`?o003o5Oooool5o`00o`Sooooo4ol00?l:ooooo`Go003o00?oooooo`00
ool00?l01Ol00?l9ooooo`Go003o5Oooool5o`00ohcooooo0Ol00001ooooo`0000?o0000oooooooo
ool05oooool5o`00oaGooooo0ol00?l6ooooo`Wo003o00?oooooo`00ool00?l02ol00?l:ooooo`?o
003o0oooool3o`00o`cooooo1Ol00?lFooooo`?o003oSOooool1o`00007ooooo00000ol0003ooooo
ooooo`0Gooooo`Go003o7Oooool8o`00o`?ooooo1Ol00?l00ooooooo003oo`00o`05o`00ob3ooooo
0ol00?nWooooo`7o00000Oooool00003o`000?oooooooooo01Oooooo1Ol00?lMooooo`Go003o1ooo
ool3o`00o`?ooooo1_l00?o:ooooo`7o00000Oooool00003o`000?oooooooooo01Sooooo0ol00?lN
ooooo`Go003o3Oooool5o`00oa;ooooo0ol00?nfooooo`7o00000Oooool00003o`000?oooooooooo
03[ooooo0ol00?l>ooooo`Go003o4Oooool5o`00okGooooo0Ol00001ooooo`0000?o0000oooooooo
ool0C?ooool3o`00o`Cooooo0ol00?l;ooooo`So003o5?ooool3o`00oi_ooooo0Ol00001ooooo`00
00?o0000ooooooooool0D_ooool5o`00o`[ooooo2Ol00?l6ooooo`?o003o2Oooool5o`00oi[ooooo
0Ol00001ooooo`0000?o0000ooooooooool0D_ooool5o`00o`_ooooo2?l00?l5ooooo`Go003o2?oo
ool5o`00oi[ooooo0Ol00001ooooo`0000?o0000ooooooooool0@Oooool3o`00o`kooooo1Ol00?l>
ooooo`Go003o1Oooool5o`00o`Sooooo1Ol00?nJooooo`7o00000Oooool00003o`000?oooooooooo
043ooooo1Ol00?l>ooooo`?o003o1oooool3o`00o`Kooooo1_l00?l3ooooo`Go003o2Oooool3o`00
oi_ooooo0Ol00001ooooo`0000?o0000ooooooooool0@?ooool5o`00oaOooooo1Ol00?l7ooooo`Go
003o0oooool3o`00ojSooooo0Ol00001ooooo`0000?o0000ooooooooool0@?ooool5o`00oaOooooo
1Ol00?l7ooooo`Go003o[_ooool1o`00007ooooo00000ol0003oooooooooo`11ooooo`?o003o1Ooo
ool3o`00oa3ooooo1Ol00?l7ooooo`Go003o[_ooool1o`00007ooooo00000ol0003oooooooooo`18
ooooo`Go003o1?ooool3o`00o`Wooooo0ol00?l9ooooo`?o003o4_ooool3o`00o`Wooooo0ol00?n>
ooooo`7o00000Oooool00003o`000?oooooooooo04Sooooo1Ol00?l3ooooo`Go003o:?ooool5o`00
o`Oooooo1Ol00?n=ooooo`7o00000Oooool00003o`000?oooooooooo04Sooooo1Ol00?l3ooooo`Go
003o:?ooool5o`00o`Cooooo2?l00?n=ooooo`7o00000Oooool00003o`000?oooooooooo04Wooooo
0ol00?l4ooooo`Go003o:?ooool7o`00o`03ooooool00?oo003o00Oo003oSOooool1o`00007ooooo
00000ol0003oooooooooo`1Aooooo`?o003o:_ooool?o`00ohkooooo0Ol00001ooooo`0000?o0000
ooooooooool0K?ooool3o`00oa7ooooo2_l00?nAooooo`7o00000Oooool00003o`000?oooooooooo
06_ooooo1Ol00?l@ooooo`Go003o00Coooooo`00ool00?oo003oT_ooool1o`00007ooooo00000ol0
003oooooooooo`1Dooooo`?o003o3_ooool3o`00o`?ooooo1Ol00?lAooooo`?o003oUoooool1o`00
007ooooo00000ol0003oooooooooo`1Cooooo`Go003o3?ooool5o`00o`;ooooo1Ol00?n[ooooo`7o
00000Oooool00003o`000?oooooooooo05?ooooo1Ol00?l<ooooo`Go003o0oooool3o`00ojcooooo
0Ol00001ooooo`0000?o0000ooooooooool0Doooool5o`00o`cooooo1Ol00?nbooooo`7o00000Ooo
ool00003o`000?oooooooooo05Cooooo0ol00?l>ooooo`?o003o/oooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0R?ooool3o`00oi3o
oooo0Ol00001ooooo`0000?o0000ooooooooool0Qoooool5o`00ohoooooo0Ol00001ooooo`0000?o
0000ooooooooool0Qoooool5o`00ohoooooo0Ol00001ooooo`0000?o0000ooooooooool0Qoooool5
o`00ohoooooo0Ol00001ooooo`0000?o0000ooooooooool0R?ooool3o`00oi3ooooo0Ol00001oooo
o`0000?o0000ooooooooool0L?ooool3o`00ojSooooo0Ol00001ooooo`0000?o0000ooooooooool0
Koooool5o`00ojOooooo0Ol00001ooooo`0000?o0000ooooooooool0IOooool3o`00o`Oooooo1Ol0
0?nWooooo`7o00000Oooool00003o`000?oooooooooo06Cooooo1Ol00?l6ooooo`Go003oYoooool1
o`00007ooooo00000ol0003oooooooooo`1Tooooo`Go003o1oooool3o`00ojSooooo0Ol00001oooo
o`0000?o0000ooooooooool0I?ooool5o`00obKooooo0ol00?n9ooooo`7o00000Oooool00003o`00
0?oooooooooo06Gooooo0ol00?lVooooo`Go003oR?ooool1o`00007ooooo00000ol0003ooooooooo
o`2=ooooo`Ko003oR?ooool1o`00007ooooo00000ol0003oooooooooo`2<ooooo`Oo003o00Cooooo
o`00ool00?oo003oQ?ooool1o`00007ooooo00000ol0003oooooooooo`2<ooooo`Ko003o00?ooooo
o`00ool00?l00ol00?n3ooooo`7o00000Oooool00003o`000?oooooooooo08cooooo1Ol00?l2oooo
o`Go003oPoooool1o`00007ooooo00000ol0003oooooooooo`1^ooooo`?o003o7?ooool3o`00o`?o
oooo1Ol00?n3ooooo`7o00000Oooool00003o`000?oooooooooo06gooooo1Ol00?lRooooo`?o003o
Q?ooool1o`00007ooooo00000ol0003oooooooooo`1]ooooo`Go003oZOooool1o`00007ooooo0000
0ol0003oooooooooo`1]ooooo`Go003oZOooool1o`00007ooooo00000ol0003oooooooooo`1^oooo
o`?o003oZ_ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo3?ooool3ool000go
oooo0Ol00001ooooo`0000?o0000ooooooooool0ooooool;ooooo`Goo`003?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooo`_ooooo1Ooo000<ooooo`7o00000Oooool00003o`000?oooooo
oooo0>7ooooo0ooo000Vooooo`Goo`003?ooool1o`00007ooooo00000ol0003oooooooooo`3Poooo
o`Goo`009_ooool3ool000gooooo0Ol00001ooooo`0000?o0000ooooooooool0h?ooool5ool003Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0^Oooool3ool002;ooooo1ooo000fooooo`7o0000
0Oooool00003o`000?oooooooooo0;Sooooo1Ooo000Pooooo`Ooo`00=oooool1o`00007ooooo0000
0ol0003oooooooooo`2hooooo`Goo`003Oooool3ool000cooooo0ooo00000oooooooo`00ool00003
ool000gooooo0ooo000Yooooo`7o00000Oooool00003o`000?oooooooooo0:?ooooo0ooo000Boooo
o`Goo`003?ooool5ool000[ooooo2_oo000<ooooo`Goo`00:?ooool1o`00007ooooo00000ol0003o
ooooooooo`2Rooooo`Goo`004_ooool3ool000gooooo1Ooo000:ooooo`Goo`0000Coooooool00?oo
003oo`003Oooool5ool002Sooooo0Ol00001ooooo`0000?o0000ooooooooool0X_ooool5ool002;o
oooo1Ooo000:ooooo`Goo`004Oooool5ool002Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
X_ooool5ool002?ooooo0ooo000<ooooo`?oo`004oooool3ool002Wooooo0Ol00001ooooo`0000?o
0000ooooooooool0Xoooool3ool003Wooooo0ooo000booooo`?oo`001?ooool1o`00007ooooo0000
0ol0003oooooooooo`2fooooo`?oo`009Oooool5ool0033ooooo1Ooo0003ooooo`7o00000Oooool0
0003o`000?oooooooooo0;Gooooo1Ooo000Tooooo`Goo`008?ooool3ool000gooooo1Ooo0003oooo
o`7o00000Oooool00003o`000?oooooooooo0;Gooooo1Ooo000Tooooo`Goo`007oooool5ool000co
oooo1Ooo0003ooooo`7o00000Oooool00003o`000?oooooooooo0;Gooooo1Ooo000Uooooo`?oo`00
8?ooool5ool000gooooo0ooo0004ooooo`7o00000Oooool00003o`000?oooooooooo0;Kooooo0ooo
0019ooooo`Goo`005?ooool1o`00007ooooo00000ol0003oooooooooo`3oooooo`Cooooo0ooo000E
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo4Oooool3ool000Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0ooooool@ooooo`Goo`001oooool1o`00007ooooo00000ol0003ooooo
ooooo`3Pooooo`?oo`00;?ooool5ool000Oooooo0Ol00001ooooo`0000?o0000ooooooooool0gooo
ool5ool002_ooooo1Ooo0007ooooo`7o00000Oooool00003o`000?oooooooooo0:Oooooo0ooo000e
ooooo`Goo`00;?ooool3ool000Sooooo0Ol00001ooooo`0000?o0000ooooooooool0Y_ooool5ool0
03Cooooo1Ooo000gooooo`7o00000Oooool00003o`000?oooooooooo0:Kooooo1Ooo000eooooo`?o
o`008oooool3ool001;ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool3ool001Gooooo
1Ooo000Eooooo`?oo`00@_ooool5ool0017ooooo0Ol00001ooooo`0000?o0000ooooooooool0SOoo
ool5ool001Gooooo0ooo000Eooooo`Goo`00@Oooool5ool0017ooooo0Ol00001ooooo`0000?o0000
ooooooooool0SOooool5ool002gooooo1Ooo0011ooooo`Goo`004Oooool1o`00007ooooo00000ol0
003oooooooooo`2=ooooo`Goo`00:oooool7ool00004oooooooo003oo`00ool000Gooooo0ooo000K
ooooo`?oo`006?ooool3ool001;ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool3ool0
02_ooooo1ooo00000oooooooo`00ool00003ool000?ooooo1Ooo000Iooooo`Goo`00;?ooool1o`00
007ooooo00000ol0003oooooooooo`2Vooooo`?oo`004oooool5ool00003oooooooo003oo`0000Go
o`000oooool5ool000;ooooo0ooo000:ooooo`?oo`001oooool5ool002cooooo0Ol00001ooooo`00
00?o0000ooooooooool0YOooool5ool001;ooooo3Ooo0003ooooo`_oo`002?ooool5ool000Kooooo
1Ooo000/ooooo`7o00000Oooool00003o`000?oooooooooo0:Cooooo1_oo000<ooooo`?oo`001?oo
ool3ool00003oooooooo003oo`0000Goo`001Oooool:ool000Sooooo1Ooo0007ooooo`?oo`00;Ooo
ool1o`00007ooooo00000ol0003oooooooooo`2Tooooo`Koo`002oooool5ool000Oooooo1Ooo0008
ooooo`Woo`002?ooool5ool003Oooooo0Ol00001ooooo`0000?o0000ooooooooool0Y?ooool5ool0
00Gooooo0ooo0004ooooo`Goo`001oooool4ool000Wooooo2?oo000:ooooo`?oo`00>?ooool1o`00
007ooooo00000ol0003oooooooooo`2Uooooo`?oo`001Oooool5ool000?ooooo1Ooo0006ooooo`Go
o`001Oooool3ool000;ooooo0ooo0019ooooo`7o00000Oooool00003o`000?oooooooooo0:gooooo
1Ooo0004ooooo`?oo`001_ooool6ool000Cooooo2_oo000Gooooo`?oo`00;_ooool1o`00007ooooo
00000ol0003oooooooooo`2]ooooo`Goo`001_ooool3ool000Cooooo1_oo0004ooooo`[oo`005_oo
ool5ool002gooooo0Ol00001ooooo`0000?o0000ooooooooool0[_ooool3ool000Kooooo3Ooo0005
ooooo`[oo`005_ooool5ool002gooooo0Ol00001ooooo`0000?o0000ooooooooool0]oooool<ool0
00Oooooo0ooo00000oooooooo`00ool00003ool001Kooooo1Ooo000]ooooo`7o00000Oooool00003
o`000?oooooooooo077ooooo0ooo0013ooooo`[oo`003Oooool5ool001Oooooo1?oo00001?oooooo
o`00ool00?oo000Yooooo`7o00000Oooool00003o`000?oooooooooo073ooooo1Ooo0013ooooo`[o
o`003Oooool3ool001Sooooo2Ooo000Xooooo`7o00000Oooool00003o`000?oooooooooo073ooooo
1Ooo000Kooooo`?oo`009oooool8ool002Sooooo2Ooo000Xooooo`7o00000Oooool00003o`000?oo
oooooooo073ooooo1Ooo0004ooooo`?oo`004oooool5ool002Cooooo2_oo000Xooooo`Woo`00:?oo
ool1o`00007ooooo00000ol0003oooooooooo`1aooooo`?oo`001?ooool5ool001;ooooo1Ooo000S
ooooo`coo`000oooool3ool000oooooo0ooo0008ooooo`?oo`001Oooool3ool00004oooooooo003o
o`00ool002Wooooo0Ol00001ooooo`0000?o0000ooooooooool0N?ooool5ool001;ooooo1Ooo000S
ooooo`Ooo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00006ool000[ooooo1Ooo0006
ooooo`Goo`00=?ooool1o`00007ooooo00000ol0003oooooooooo`1hooooo`Goo`004oooool3ool0
02Cooooo1_oo0002ooooo`Goo`0000?oooooool00?oo00001ooo0009ooooo`Goo`001_ooool5ool0
03Cooooo0Ol00001ooooo`0000?o0000ooooooooool0NOooool5ool003[ooooo0ooo0004ooooo`Go
o`0000?oooooool00?oo00001ooo0009ooooo`Goo`001_ooool5ool003Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0N_ooool5ool0043ooooo1Ooo0002ooooo`Soo`002_ooool3ool000;ooooo
0ooo0003ooooo`?oo`00=Oooool1o`00007ooooo00000ol0003oooooooooo`1jooooo`Goo`00@?oo
ool5ool000Gooooo1Ooo000>ooooo`Goo`00>_ooool1o`00007ooooo00000ol0003oooooooooo`1j
ooooo`Goo`00;_ooool3ool000oooooo1Ooo0006ooooo`?oo`003oooool5ool003[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0Noooool3ool002kooooo1Ooo0007ooooo`?oo`001Oooool3ool0
01Wooooo1Ooo000jooooo`7o00000Oooool00003o`000?oooooooooo0:cooooo1Ooo0006ooooo`Go
o`008Oooool3ool003_ooooo0Ol00001ooooo`0000?o0000ooooooooool0[?ooool5ool000Kooooo
1Ooo0006ooooo`?oo`005?ooool3ool003oooooo0Ol00001ooooo`0000?o0000ooooooooool0[?oo
ool5ool000Kooooo1Ooo0005ooooo`Goo`004_ooool5ool003kooooo0Ol00001ooooo`0000?o0000
ooooooooool0P_ooool3ool002Oooooo2?oo0004ooooo`?oo`001_ooool5ool001;ooooo1_oo000m
ooooo`7o00000Oooool00003o`000?oooooooooo087ooooo1Ooo000Wooooo`Soo`003?ooool5ool0
00oooooo2_oo000looooo`7o00000Oooool00003o`000?oooooooooo087ooooo1Ooo000Zooooo`Oo
o`002oooool3ool000oooooo3?oo000kooooo`7o00000Oooool00003o`000?oooooooooo087ooooo
1Ooo000Hooooo`?oo`003Oooool:ool000oooooo0ooo000:ooooo`Goo`0000?oooooool00?oo0000
1?oo000kooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo0ooo000Hooooo`Goo`002ooo
ool;ool000kooooo2?oo0006ooooo`Goo`000_ooool5ool003_ooooo0Ol00001ooooo`0000?o0000
ooooooooool0WOooool5ool000_ooooo1Ooo00000oooooooo`00ool00003ool000kooooo2Ooo0006
ooooo`?oo`001?ooool3ool003cooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool5ool0
00_ooooo1Ooo0002ooooo`?oo`003oooool9ool004cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0UOooool3ool000Kooooo0ooo0005ooooo`?oo`001Oooool3ool001Kooooo2Ooo001;ooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo1Ooo000<ooooo`Goo`008Oooool5ool004_ooooo
0Ol00001ooooo`0000?o0000ooooooooool0U?ooool5ool000cooooo1_oo000Pooooo`Goo`00Booo
ool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`Goo`001_ooool3ool000?ooooo1ooo000P
ooooo`?oo`00C?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`?oo`001_ooool5ool0
00;ooooo1ooo0002ooooo`?oo`00J_ooool1o`00007ooooo00000ol0003oooooooooo`2Nooooo`Go
o`0000?oooooool00?oo00001_oo00000oooooooo`00ool00003ool006Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0W_ooool5ool00003oooooooo003oo`0000Goo`000_ooool5ool001;ooooo
0ooo001Dooooo`7o00000Oooool00003o`000?oooooooooo09oooooo0ooo0002ooooo`Goo`001?oo
ool5ool000_ooooo0ooo0003ooooo`Goo`00Doooool1o`00007ooooo00000ol0003oooooooooo`2?
ooooo`?oo`004oooool3ool000Kooooo0ooo000;ooooo`Goo`000_ooool5ool005?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0S_ooool5ool000_ooooo0ooo000Kooooo`Goo`000_ooool5ool0
05?ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool5ool000[ooooo1Ooo000>ooooo`?o
o`002Oooool5ool000?ooooo0ooo001Dooooo`7o00000Oooool00003o`000?oooooooooo08gooooo
1_oo000:ooooo`Goo`003Oooool5ool000Wooooo0ooo001Kooooo`7o00000Oooool00003o`000?oo
oooooooo08gooooo1Ooo000;ooooo`Goo`003Oooool5ool006Oooooo0Ol00001ooooo`0000?o0000
ooooooooool0SOooool5ool000cooooo0ooo000>ooooo`Goo`00Ioooool1o`00007ooooo00000ol0
003oooooooooo`2>ooooo`?oo`007oooool5ool006Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Woooool3ool000;ooooo0ooo0006ooooo`Soo`00I_ooool1o`00007ooooo00000ol0003ooooo
ooooo`1gooooo`?oo`009?ooool:ool000Cooooo2Ooo001Vooooo`7o00000Oooool00003o`000?oo
oooooooo07Kooooo1Ooo000=ooooo`?oo`004oooool:ool000Cooooo2Ooo001Vooooo`7o00000Ooo
ool00003o`000?oooooooooo07Kooooo1Ooo000<ooooo`Ooo`004?ooool:ool000Cooooo2?oo001W
ooooo`7o00000Oooool00003o`000?oooooooooo07Kooooo1Ooo0005ooooo`?oo`001?ooool8ool0
013ooooo0ooo0002ooooo`?oo`001_ooool3ool006_ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Moooool3ool000Gooooo1Ooo0003ooooo`Soo`00S?ooool1o`00007ooooo00000ol0003ooooo
ooooo`1oooooo`Goo`001?ooool7ool002Oooooo0ooo001Rooooo`7o00000Oooool00003o`000?oo
oooooooo07oooooo1Ooo0007ooooo`?oo`006_ooool3ool000[ooooo1Ooo001Qooooo`7o00000Ooo
ool00003o`000?oooooooooo083ooooo0ooo000Tooooo`Goo`002Oooool5ool0067ooooo0Ol00001
ooooo`0000?o0000ooooooooool0Yoooool5ool000Wooooo1Ooo001Qooooo`7o00000Oooool00003
o`000?oooooooooo0:Oooooo1Ooo000:ooooo`?oo`00H_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Xooooo`?oo`00L?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
04Sooooo0ooo003@ooooo`7o00000Oooool00003o`000?oooooooooo04Oooooo1Ooo003?ooooo`7o
00000Oooool00003o`000?oooooooooo04Oooooo1Ooo003?ooooo`7o00000Oooool00003o`000?oo
oooooooo04Oooooo1Ooo001Booooo`?oo`00N_ooool1o`00007ooooo00000ol0003oooooooooo`18
ooooo`?oo`00D_ooool5ool007Wooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool5ool0
07Wooooo0Ol00001ooooo`0000?o0000ooooooooool0WOooool5ool007Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0W_ooool3ool007[ooooo0Ol00001ooooo`0000?o0000ooooooooool0N_oo
ool3ool0033ooooo0ooo001[ooooo`7o00000Oooool00003o`000?oooooooooo07Wooooo1Ooo000^
ooooo`Goo`00J_ooool1o`00007ooooo00000ol0003oooooooooo`1iooooo`Goo`00;_ooool5ool0
06[ooooo0Ol00001ooooo`0000?o0000ooooooooool0NOooool5ool002kooooo1Ooo001Zooooo`7o
00000Oooool00003o`000?oooooooooo07[ooooo0ooo000`ooooo`?oo`00Joooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`?oo`00Ooooool1o`00
007ooooo00000ol0003oooooooooo`2Hooooo`Goo`00O_ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Hooooo`Goo`00O_ooool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`Goo`00O_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Iooooo`?oo`00Ooooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Uniform quantization", "Subsection"],

Cell[CellGroupData[{

Cell["Number of centroids in each direction", "Subsubsection"],

Cell[BoxData[
    \(\(nCentroids\  = \ 4;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute uniformly distributed centroids", "Subsubsection"],

Cell[BoxData[
    \(\(uniformCentroids\  = \ 
        UniformQuantization[pr[\([1]\)], pr[\([2]\)], 
          nCentroids];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gCentroids = \ 
        PlotData2D[uniformCentroids, pr, \ centroidStyle];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[.00495 -0.0125 -6 -9 ]
[.00495 -0.0125 6 0 ]
[.25248 -0.0125 -12 -9 ]
[.25248 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74752 -0.0125 -9 -9 ]
[.74752 -0.0125 9 0 ]
[.99505 -0.0125 -3 -9 ]
[.99505 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00495 -12 -4.5 ]
[-0.0125 .00495 0 4.5 ]
[-0.0125 .25248 -24 -4.5 ]
[-0.0125 .25248 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74752 -18 -4.5 ]
[-0.0125 .74752 0 4.5 ]
[-0.0125 .99505 -6 -4.5 ]
[-0.0125 .99505 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00495 0 m
.00495 .00625 L
s
[(-1)] .00495 -0.0125 0 1 Mshowa
.25248 0 m
.25248 .00625 L
s
[(-0.5)] .25248 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.74752 0 m
.74752 .00625 L
s
[(0.5)] .74752 -0.0125 0 1 Mshowa
.99505 0 m
.99505 .00625 L
s
[(1)] .99505 -0.0125 0 1 Mshowa
.125 Mabswid
.05446 0 m
.05446 .00375 L
s
.10396 0 m
.10396 .00375 L
s
.15347 0 m
.15347 .00375 L
s
.20297 0 m
.20297 .00375 L
s
.30198 0 m
.30198 .00375 L
s
.35149 0 m
.35149 .00375 L
s
.40099 0 m
.40099 .00375 L
s
.4505 0 m
.4505 .00375 L
s
.5495 0 m
.5495 .00375 L
s
.59901 0 m
.59901 .00375 L
s
.64851 0 m
.64851 .00375 L
s
.69802 0 m
.69802 .00375 L
s
.79703 0 m
.79703 .00375 L
s
.84653 0 m
.84653 .00375 L
s
.89604 0 m
.89604 .00375 L
s
.94554 0 m
.94554 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00495 m
.00625 .00495 L
s
[(-1)] -0.0125 .00495 1 0 Mshowa
0 .25248 m
.00625 .25248 L
s
[(-0.5)] -0.0125 .25248 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .74752 m
.00625 .74752 L
s
[(0.5)] -0.0125 .74752 1 0 Mshowa
0 .99505 m
.00625 .99505 L
s
[(1)] -0.0125 .99505 1 0 Mshowa
.125 Mabswid
0 .05446 m
.00375 .05446 L
s
0 .10396 m
.00375 .10396 L
s
0 .15347 m
.00375 .15347 L
s
0 .20297 m
.00375 .20297 L
s
0 .30198 m
.00375 .30198 L
s
0 .35149 m
.00375 .35149 L
s
0 .40099 m
.00375 .40099 L
s
0 .4505 m
.00375 .4505 L
s
0 .5495 m
.00375 .5495 L
s
0 .59901 m
.00375 .59901 L
s
0 .64851 m
.00375 .64851 L
s
0 .69802 m
.00375 .69802 L
s
0 .79703 m
.00375 .79703 L
s
0 .84653 m
.00375 .84653 L
s
0 .89604 m
.00375 .89604 L
s
0 .94554 m
.00375 .94554 L
s
.25 Mabswid
0 0 m
0 1 L
s
.00495 .99375 m
.00495 1 L
s
.25248 .99375 m
.25248 1 L
s
.5 .99375 m
.5 1 L
s
.74752 .99375 m
.74752 1 L
s
.99505 .99375 m
.99505 1 L
s
.125 Mabswid
.05446 .99625 m
.05446 1 L
s
.10396 .99625 m
.10396 1 L
s
.15347 .99625 m
.15347 1 L
s
.20297 .99625 m
.20297 1 L
s
.30198 .99625 m
.30198 1 L
s
.35149 .99625 m
.35149 1 L
s
.40099 .99625 m
.40099 1 L
s
.4505 .99625 m
.4505 1 L
s
.5495 .99625 m
.5495 1 L
s
.59901 .99625 m
.59901 1 L
s
.64851 .99625 m
.64851 1 L
s
.69802 .99625 m
.69802 1 L
s
.79703 .99625 m
.79703 1 L
s
.84653 .99625 m
.84653 1 L
s
.89604 .99625 m
.89604 1 L
s
.94554 .99625 m
.94554 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .00495 m
1 .00495 L
s
.99375 .25248 m
1 .25248 L
s
.99375 .5 m
1 .5 L
s
.99375 .74752 m
1 .74752 L
s
.99375 .99505 m
1 .99505 L
s
.125 Mabswid
.99625 .05446 m
1 .05446 L
s
.99625 .10396 m
1 .10396 L
s
.99625 .15347 m
1 .15347 L
s
.99625 .20297 m
1 .20297 L
s
.99625 .30198 m
1 .30198 L
s
.99625 .35149 m
1 .35149 L
s
.99625 .40099 m
1 .40099 L
s
.99625 .4505 m
1 .4505 L
s
.99625 .5495 m
1 .5495 L
s
.99625 .59901 m
1 .59901 L
s
.99625 .64851 m
1 .64851 L
s
.99625 .69802 m
1 .69802 L
s
.99625 .79703 m
1 .79703 L
s
.99625 .84653 m
1 .84653 L
s
.99625 .89604 m
1 .89604 L
s
.99625 .94554 m
1 .94554 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 1 r
.02 w
.12871 .12871 Mdot
.12871 .37624 Mdot
.12871 .62377 Mdot
.12871 .8713 Mdot
.37624 .12871 Mdot
.37624 .37624 Mdot
.37624 .62377 Mdot
.37624 .8713 Mdot
.62377 .12871 Mdot
.62377 .37624 Mdot
.62377 .62377 Mdot
.62377 .8713 Mdot
.8713 .12871 Mdot
.8713 .37624 Mdot
.8713 .62377 Mdot
.8713 .8713 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`007Oooool3o`0003Sooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000eooooo`;o0000>?ooool2o`0000Cooooo00?o0000ooooooooool0
0_ooool3o`0003Oooooo0ol00003ooooo`007_ooool00ol0003oooooooooo`0fooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000cooooo`04o`000?ooooooooooo`00
03Kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000003Oooooo00?o
0000ooooooooool00_ooool001Kooooo1Ol00003ooooo`03o`000?oooooooooo02oooooo1Ol00002
ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0<Oooool01?l0003ooooooooo
ool0000fooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0000_o
oooo00?o0000ooooooooool0<Oooool01?l0003oooooooooool0000fooooo`04o`000?oooooooooo
o`0000_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02ooooo`007_ooool00ol0
003oooooooooo`0fooooo`04o`000?ooooooooooo`0000Oooooo1?l0000dooooo`04o`000?oooooo
ooooo`0003Kooooo00Co0000oooooooooooo00001oooool4o`0003Sooooo00?o0000ooooooooool0
0_ooool001gooooo0_l0000hooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
=Oooool01?l0003oooooooooool0000fooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ooooool0>?ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l00008ooooo`Go
0000=?ooool2o`0003Sooooo0_l00008ooooo`Go0000=oooool00ol0003oooooooooo`02ooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`004oooool3o`000?oooooo2oooool001Co
oooo00?o0000ooooooooool01?oooooo000000@000000_ooool000cooooo1Ol00003ooooo`03o`00
0?oooooooooo00Cooooo00<00000o`000?ooool02oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`030000
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00`00003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`800000
0_ooool001Cooooo00?o0000ooooooooool01?ooool00`00003o0000ooooo`0nooooo`0300000?oo
oooooooo03gooooo00<00000ooooooooool0?Oooool00`00003oooooooooo`0looooo`<000000_oo
ool001Cooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`3oooooo`4000000Oooool1
ooooo`004oooool2o`0000Kooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001Co
oooo00?o0000ooooooooool01?ooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`00
6oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003ooooooooo
o`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1
ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003o
ooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`400000
0Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool0
0`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3ooooo
o`4000000Oooool1ooooo`006oooool00`00003o0000ooooo`3nooooo`03o`000000003ooooo007o
oooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oo
oooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001
ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`03
00000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo
0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000K
ooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo
0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7o
oooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?l0
003ooooo0?kooooo00?o000000000?ooool00Oooool001_ooooo00<00000ooooooooool0ooooool1
0000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_o
oooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0
ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool07Oooool3ool0ocgooooo0ooo
0?lmooooo`?oo`3o?Oooool3ool0oaoooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooo
oooo01cooooo1Ooo0?lkooooo`Goo`3o>oooool5ool0oc_ooooo1Ooo0?lNooooo`4000000Oooool1
ooooo`006oooool00`00003oooooooooo`0Looooo`Goo`3o>oooool5ool0oc_ooooo1Ooo0?lkoooo
o`Goo`3o7_ooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool07?ooool5ool0oc_o
oooo1Ooo0?lkooooo`Goo`3o>oooool5ool0oakooooo0@000001ooooo`7ooooo000Kooooo`030000
0?oooooooooo01gooooo0ooo0?lmooooo`?oo`3o?Oooool3ool0ocgooooo0ooo0?lOooooo`400000
0Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool0
0`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3ooooo
o`4000000Oooool1ooooo`006oooool00`00003o0000ooooo`3nooooo`03o`000000003ooooo007o
oooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oo
oooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001
ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`03
00000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo
0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000K
ooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo
0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7o
oooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oo
oooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?l0003ooooo0?kooooo00?o0000
00000?ooool00Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_o
oooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0
ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Ooo
ool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000oooo
ooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007o
oooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<0
0000ooooooooool0ooooool10000007ooooo0Oooool000Sooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo0007oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`0300000?oo
oooooooo0?oooooo0@000001ooooo`7ooooo0005o`0000;ooooo00Co0000oooooooooooo00002ooo
ool00ol0003oooooooooo`02ooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo0007
ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00`00003o0000oooo
o`3mooooo`<000000_ooool000Oooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo00<0
0000ooooooooool0ooooool10000007ooooo0Oooool000Oooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`06ooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo0008
ooooo`;o00002?ooool5o`0000Cooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool0
01_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000oooooooo
ool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo
0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000
ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000
007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo
00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000o`000?ooool0o_oo
ool00ol000000000ooooo`01ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1
ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003o
ooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`400000
0Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool0
0`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3ooooo
o`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`00
6oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003ooooooooo
o`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1
ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003o
0000ooooo`3nooooo`03o`000000003ooooo007ooooo000Kooooo`0300000?oooooooooo0?oooooo
0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000K
ooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo
0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo01gooooo0ooo0?lmooooo`?o
o`3o?Oooool3ool0ocgooooo0ooo0?lOooooo`4000000Oooool1ooooo`006oooool00`00003ooooo
ooooo`0Looooo`Goo`3o>oooool5ool0oc_ooooo1Ooo0?lkooooo`Goo`3o7_ooool10000007ooooo
0Oooool001_ooooo00<00000ooooooooool07?ooool5ool0oc_ooooo1Ooo0?lkooooo`Goo`3o>ooo
ool5ool0oakooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo01cooooo1Ooo0?lk
ooooo`Goo`3o>oooool5ool0oc_ooooo1Ooo0?lNooooo`4000000Oooool1ooooo`006oooool00`00
003oooooooooo`0Mooooo`?oo`3o?Oooool3ool0ocgooooo0ooo0?lmooooo`?oo`3o7oooool10000
007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo
00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0oooo
ool10000007ooooo0Oooool001_ooooo00<00000o`000?ooool0o_ooool00ol000000000ooooo`01
ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003o
ooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`400000
0Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool0
0`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3ooooo
o`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`00
6oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003ooooooooo
o`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1
ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003o
ooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003o0000ooooo`3nooooo`03o`00
0000003ooooo007ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000K
ooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo
0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7o
oooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oo
oooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001
ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`03
00000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Dooooo`;o00001Oooool00`00003ooooo
ooooo`3oooooo`4000000Oooool1ooooo`004oooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo0?oooooo0@000001ooooo`7ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo
00<00000o`000?ooool0oOooool3000000;ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool0ooooool10000007ooooo0Oooool001?ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Dooooo`;o00001Ooo
ool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3o
ooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1oooo
o`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003ooooo
ooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Ooo
ool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00
003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`40
00000Oooool1ooooo`006oooool00`00003o0000ooooo`3nooooo`03o`000000003ooooo007ooooo
000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooo
oooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001oooo
o`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`030000
0?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@00
0001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Koooo
o`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oo
oooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo
000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooo
oooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?l0003ooooo0?kooooo00?o00000000
0?ooool00Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo
00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0oooo
ool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool0
01_ooooo00<00000ooooooooool07Oooool3ool0ocgooooo0ooo0?lmooooo`?oo`3o?Oooool3ool0
oaoooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo01cooooo1Ooo0?lkooooo`Go
o`3o>oooool5ool0oc_ooooo1Ooo0?lNooooo`4000000Oooool1ooooo`006oooool00`00003ooooo
ooooo`0Looooo`Goo`3o>oooool5ool0oc_ooooo1Ooo0?lkooooo`Goo`3o7_ooool10000007ooooo
0Oooool001_ooooo00<00000ooooooooool07?ooool5ool0oc_ooooo1Ooo0?lkooooo`Goo`3o>ooo
ool5ool0oakooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo01gooooo0ooo0?lm
ooooo`?oo`3o?Oooool3ool0ocgooooo0ooo0?lOooooo`4000000Oooool1ooooo`006oooool00`00
003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`40
00000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006ooo
ool00`00003o0000ooooo`3nooooo`03o`000000003ooooo007ooooo000Kooooo`0300000?oooooo
oooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001oooo
o`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`030000
0?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@00
0001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Koooo
o`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oo
oooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo
000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooo
oooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001oooo
o`7ooooo000Kooooo`0300000?l0003ooooo0?kooooo00?o000000000?ooool00Oooool001_ooooo
00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0oooo
ool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool0
01_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000oooooooo
ool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo
0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000
ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000
007ooooo0Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
00000?oooooooooo0?oooooo0@000001ooooo`7ooooo0007ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000004ooooo`0300000?oooooooooo0?oooooo0@000001oooo
o`7ooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00`00
003o0000ooooo`3mooooo`<000000_ooool000Oooooo00Co0000oooooooooooo00002oooool00ol0
003oooooooooo`02ooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo1?l00005ooooo`0300000?oooooooooo0?oooooo0@000001oooo
o`7ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00`00
003oooooooooo`3oooooo`4000000Oooool1ooooo`002?ooool2o`0000Sooooo1Ol00004ooooo`03
00000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo
0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000K
ooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo
0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7o
oooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oo
oooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001
ooooo`7ooooo000Kooooo`0300000?l0003ooooo0?kooooo00?o000000000?ooool00Oooool001_o
oooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0
ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Ooo
ool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000oooo
ooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007o
oooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<0
0000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool1
0000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_o
oooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0
ooooool10000007ooooo0Oooool001_ooooo00<00000o`000?ooool0o_ooool00ol000000000oooo
o`01ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00
003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`40
00000Oooool1ooooo`006oooool00`00003oooooooooo`0Mooooo`?oo`3o?Oooool3ool0ocgooooo
0ooo0?lmooooo`?oo`3o7oooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool07?oo
ool5ool0oc_ooooo1Ooo0?lkooooo`Goo`3o>oooool5ool0oakooooo0@000001ooooo`7ooooo000K
ooooo`0300000?oooooooooo01cooooo1Ooo0?lkooooo`Goo`3o>oooool5ool0oc_ooooo1Ooo0?lN
ooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`0Looooo`Goo`3o>oooool5ool0
oc_ooooo1Ooo0?lkooooo`Goo`3o7_ooool10000007ooooo0Oooool001_ooooo00<00000oooooooo
ool07Oooool3ool0ocgooooo0ooo0?lmooooo`?oo`3o?Oooool3ool0oaoooooo0@000001ooooo`7o
oooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oo
oooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001
ooooo`7ooooo000Kooooo`0300000?oooooooooo0?oooooo0@000001ooooo`7ooooo000Kooooo`03
00000?l0003ooooo0?kooooo00?o000000000?ooool00Oooool001_ooooo00<00000ooooooooool0
ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Ooo
ool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000oooo
ooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007o
oooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<0
0000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool1
0000007ooooo0Oooool001_ooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_o
oooo00<00000ooooooooool0ooooool10000007ooooo0Oooool001_ooooo00<00000ooooooooool0
ooooool10000007ooooo0Oooool001_ooooo00<00000o`000?ooool0o_ooool00ol000000000oooo
o`01ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00
003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`40
00000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006ooo
ool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3o
ooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1oooo
o`006oooool00`00003oooooooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003ooooo
ooooo`3oooooo`4000000Oooool1ooooo`006oooool00`00003oooooooooo`3oooooo`4000000Ooo
ool1ooooo`004oooool3o`0000Gooooo00<00000ooooooooool0ooooool10000007ooooo0Oooool0
01Cooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`3oooooo`4000000Oooool1oooo
o`005?ooool00ol0003oooooooooo`04ooooo`800000?oooool00`00003oooooooooo`0mooooo`03
00000?oooooooooo03gooooo00<00000ooooooooool0??ooool3000000;ooooo000Dooooo`03o`00
0?oooooooooo00Cooooo0P00000<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00<00000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo0P000002ooooo`005?oo
ool00ol0003oooooooooo`04ooooool0000010000002ooooo`004oooool2o`000?oooooo3?ooool0
01Cooooo00?o0000ooooooooool0ooooool:ooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.22313, -1.15855, 0.00782796, \
0.00782796}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Histograms for two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Compute histograms based on uniform centroids", "Subsubsection"],

Cell[BoxData[{
    \(\(h1\  = Histogram[data1, uniformCentroids, pr, 50];\)\), "\n", 
    \(\(h2\  = Histogram[data2, uniformCentroids, pr, 50];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize two histograms", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gh1\  = 
        DrawHistogram[h1, pr, \ nS, 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(gh2\  = 
        DrawHistogram[h2, pr, \ nS, 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gh1, gh2}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
%%ImageSize: 400 154.502 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .57879 .48228 .57294 Mtetra
.48228 .57294 .48818 .57879 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57244 .5035 .56654 Mtetra
.5035 .56654 .50935 .57244 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .56009 Mtetra
.684 .192 0 r
.52489 .56009 .53068 .56605 .54149 .58018 .5357 .57423 Mtetra
.662 .743 .91 r
.5357 .57423 .54149 .58018 .55232 .57696 .54655 .571 Mtetra
.54655 .571 .55232 .57696 .56319 .57374 .55745 .56775 Mtetra
.55745 .56775 .56319 .57374 .5741 .5705 .56839 .56448 Mtetra
.56839 .56448 .5741 .5705 .58505 .56724 .57937 .56121 Mtetra
.57937 .56121 .58505 .56724 .59605 .56398 .5904 .55792 Mtetra
.5904 .55792 .59605 .56398 .60709 .5607 .60147 .55462 Mtetra
.60147 .55462 .60709 .5607 .61818 .55741 .61258 .5513 Mtetra
.61258 .5513 .61818 .55741 .6293 .55411 .62374 .54797 Mtetra
.62374 .54797 .6293 .55411 .64048 .55079 .63494 .54463 Mtetra
.63494 .54463 .64048 .55079 .6517 .54746 .64619 .54128 Mtetra
.64619 .54128 .6517 .54746 .66296 .54412 .65749 .53791 Mtetra
.65749 .53791 .66296 .54412 .67427 .54076 .66883 .53453 Mtetra
.699 .227 0 r
.66883 .53453 .67427 .54076 .68664 .55873 .6812 .55251 Mtetra
.661 .745 .913 r
.6812 .55251 .68664 .55873 .69812 .55537 .69271 .54912 Mtetra
.69271 .54912 .69812 .55537 .70964 .55199 .70426 .54572 Mtetra
.70426 .54572 .70964 .55199 .7212 .5486 .71586 .54231 Mtetra
.71586 .54231 .7212 .5486 .73282 .5452 .72751 .53888 Mtetra
.72751 .53888 .73282 .5452 .74448 .54178 .7392 .53543 Mtetra
.7392 .53543 .74448 .54178 .75619 .53835 .75094 .53198 Mtetra
.75094 .53198 .75619 .53835 .76795 .5349 .76274 .5285 Mtetra
.76274 .5285 .76795 .5349 .77975 .53144 .77458 .52502 Mtetra
.77458 .52502 .77975 .53144 .79161 .52797 .78647 .52152 Mtetra
.78647 .52152 .79161 .52797 .80351 .52448 .7984 .518 Mtetra
.7984 .518 .80351 .52448 .81547 .52098 .81039 .51447 Mtetra
.958 .761 .596 r
.81039 .51447 .81547 .52098 .8239 .47808 .81891 .47148 Mtetra
.664 .741 .908 r
.81891 .47148 .8239 .47808 .8358 .47451 .83085 .46788 Mtetra
.83085 .46788 .8358 .47451 .84775 .47092 .84283 .46427 Mtetra
.84283 .46427 .84775 .47092 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .45699 Mtetra
.86696 .45699 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57342 Mtetra
.45523 .57342 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55735 Mtetra
.50831 .55735 .51417 .56332 .52489 .56009 .51905 .5541 Mtetra
.684 .192 0 r
.51905 .5541 .52489 .56009 .5357 .57423 .52986 .56825 Mtetra
.662 .743 .91 r
.52986 .56825 .5357 .57423 .54655 .571 .54074 .56499 Mtetra
.54074 .56499 .54655 .571 .55745 .56775 .55167 .56171 Mtetra
.55167 .56171 .55745 .56775 .56839 .56448 .56263 .55843 Mtetra
.56263 .55843 .56839 .56448 .57937 .56121 .57365 .55513 Mtetra
.57365 .55513 .57937 .56121 .5904 .55792 .5847 .55181 Mtetra
.5847 .55181 .5904 .55792 .60147 .55462 .5958 .54849 Mtetra
.5958 .54849 .60147 .55462 .61258 .5513 .60695 .54515 Mtetra
.60695 .54515 .61258 .5513 .62374 .54797 .61813 .5418 Mtetra
.61813 .5418 .62374 .54797 .63494 .54463 .62937 .53843 Mtetra
.62937 .53843 .63494 .54463 .64619 .54128 .64065 .53505 Mtetra
.64065 .53505 .64619 .54128 .65749 .53791 .65197 .53166 Mtetra
.65197 .53166 .65749 .53791 .66883 .53453 .66334 .52825 Mtetra
.699 .227 0 r
.66334 .52825 .66883 .53453 .6812 .55251 .67572 .54625 Mtetra
.661 .745 .913 r
.67572 .54625 .6812 .55251 .69271 .54912 .68726 .54283 Mtetra
.68726 .54283 .69271 .54912 .70426 .54572 .69884 .53941 Mtetra
.69884 .53941 .70426 .54572 .71586 .54231 .71047 .53596 Mtetra
.71047 .53596 .71586 .54231 .72751 .53888 .72215 .53251 Mtetra
.72215 .53251 .72751 .53888 .7392 .53543 .73388 .52904 Mtetra
.73388 .52904 .7392 .53543 .75094 .53198 .74566 .52556 Mtetra
.74566 .52556 .75094 .53198 .76274 .5285 .75749 .52206 Mtetra
.75749 .52206 .76274 .5285 .77458 .52502 .76936 .51855 Mtetra
.76936 .51855 .77458 .52502 .78647 .52152 .78128 .51502 Mtetra
.78128 .51502 .78647 .52152 .7984 .518 .79326 .51148 Mtetra
.79326 .51148 .7984 .518 .81039 .51447 .80528 .50792 Mtetra
.958 .761 .596 r
.80528 .50792 .81039 .51447 .81891 .47148 .81388 .46482 Mtetra
.664 .741 .908 r
.81388 .46482 .81891 .47148 .83085 .46788 .82585 .4612 Mtetra
.82585 .4612 .83085 .46788 .84283 .46427 .83788 .45756 Mtetra
.83788 .45756 .84283 .46427 .85487 .46064 .84995 .4539 Mtetra
.84995 .4539 .85487 .46064 .86696 .45699 .86207 .45023 Mtetra
.86207 .45023 .86696 .45699 .87909 .45334 .87424 .44654 Mtetra
.87424 .44654 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57342 .44919 .56753 Mtetra
.44919 .56753 .45523 .57342 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .5546 Mtetra
.49168 .5546 .49761 .56059 .50831 .55735 .5024 .55134 Mtetra
.5024 .55134 .50831 .55735 .51905 .5541 .51317 .54806 Mtetra
.684 .192 0 r
.51317 .54806 .51905 .5541 .52986 .56825 .52398 .56222 Mtetra
.662 .743 .91 r
.52398 .56222 .52986 .56825 .54074 .56499 .53489 .55893 Mtetra
.53489 .55893 .54074 .56499 .55167 .56171 .54584 .55563 Mtetra
.54584 .55563 .55167 .56171 .56263 .55843 .55684 .55232 Mtetra
.55684 .55232 .56263 .55843 .57365 .55513 .56788 .549 Mtetra
.56788 .549 .57365 .55513 .5847 .55181 .57896 .54566 Mtetra
.57896 .54566 .5847 .55181 .5958 .54849 .59009 .54231 Mtetra
.59009 .54231 .5958 .54849 .60695 .54515 .60127 .53895 Mtetra
.60127 .53895 .60695 .54515 .61813 .5418 .61249 .53557 Mtetra
.61249 .53557 .61813 .5418 .62937 .53843 .62375 .53218 Mtetra
.62375 .53218 .62937 .53843 .64065 .53505 .63506 .52877 Mtetra
.63506 .52877 .64065 .53505 .65197 .53166 .64642 .52536 Mtetra
.64642 .52536 .65197 .53166 .66334 .52825 .65782 .52192 Mtetra
.699 .227 0 r
.65782 .52192 .66334 .52825 .67572 .54625 .67019 .53993 Mtetra
.661 .745 .913 r
.67019 .53993 .67572 .54625 .68726 .54283 .68176 .53649 Mtetra
.68176 .53649 .68726 .54283 .69884 .53941 .69338 .53304 Mtetra
.69338 .53304 .69884 .53941 .71047 .53596 .70505 .52957 Mtetra
.70505 .52957 .71047 .53596 .72215 .53251 .71676 .52609 Mtetra
.71676 .52609 .72215 .53251 .73388 .52904 .72852 .5226 Mtetra
.72852 .5226 .73388 .52904 .74566 .52556 .74033 .51909 Mtetra
.74033 .51909 .74566 .52556 .75749 .52206 .75219 .51556 Mtetra
.75219 .51556 .75749 .52206 .76936 .51855 .7641 .51202 Mtetra
.7641 .51202 .76936 .51855 .78128 .51502 .77606 .50847 Mtetra
.77606 .50847 .78128 .51502 .79326 .51148 .78807 .5049 Mtetra
.78807 .5049 .79326 .51148 .80528 .50792 .80013 .50131 Mtetra
.958 .761 .596 r
.80013 .50131 .80528 .50792 .81388 .46482 .80881 .45812 Mtetra
.664 .741 .908 r
.80881 .45812 .81388 .46482 .82585 .4612 .82082 .45446 Mtetra
.82082 .45446 .82585 .4612 .83788 .45756 .83288 .4508 Mtetra
.83288 .4508 .83788 .45756 .84995 .4539 .84499 .44711 Mtetra
.84499 .44711 .84995 .4539 .86207 .45023 .85715 .44341 Mtetra
.85715 .44341 .86207 .45023 .87424 .44654 .86936 .4397 Mtetra
.86936 .4397 .87424 .44654 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .5551 Mtetra
.46432 .5551 .47035 .56109 .48099 .55785 .47499 .55184 Mtetra
.47499 .55184 .48099 .55785 .49168 .5546 .4857 .54857 Mtetra
.4857 .54857 .49168 .5546 .5024 .55134 .49646 .54528 Mtetra
.49646 .54528 .5024 .55134 .51317 .54806 .50725 .54198 Mtetra
.684 .192 0 r
.50725 .54198 .51317 .54806 .52398 .56222 .51806 .55614 Mtetra
.662 .743 .91 r
.51806 .55614 .52398 .56222 .53489 .55893 .52899 .55283 Mtetra
.52899 .55283 .53489 .55893 .54584 .55563 .53998 .54951 Mtetra
.53998 .54951 .54584 .55563 .55684 .55232 .551 .54618 Mtetra
.551 .54618 .55684 .55232 .56788 .549 .56207 .54283 Mtetra
.56207 .54283 .56788 .549 .57896 .54566 .57319 .53947 Mtetra
.57319 .53947 .57896 .54566 .59009 .54231 .58434 .53609 Mtetra
.58434 .53609 .59009 .54231 .60127 .53895 .59555 .5327 Mtetra
.59555 .5327 .60127 .53895 .61249 .53557 .6068 .5293 Mtetra
.6068 .5293 .61249 .53557 .62375 .53218 .61809 .52588 Mtetra
.61809 .52588 .62375 .53218 .63506 .52877 .62943 .52245 Mtetra
.62943 .52245 .63506 .52877 .64642 .52536 .64082 .51901 Mtetra
.64082 .51901 .64642 .52536 .65782 .52192 .65225 .51555 Mtetra
.699 .227 0 r
.65225 .51555 .65782 .52192 .67019 .53993 .66463 .53357 Mtetra
.661 .745 .913 r
.66463 .53357 .67019 .53993 .68176 .53649 .67623 .53011 Mtetra
.67623 .53011 .68176 .53649 .69338 .53304 .68788 .52663 Mtetra
.68788 .52663 .69338 .53304 .70505 .52957 .69958 .52314 Mtetra
.69958 .52314 .70505 .52957 .71676 .52609 .71133 .51963 Mtetra
.71133 .51963 .71676 .52609 .72852 .5226 .72312 .51611 Mtetra
.72312 .51611 .72852 .5226 .74033 .51909 .73497 .51257 Mtetra
.73497 .51257 .74033 .51909 .75219 .51556 .74686 .50902 Mtetra
.74686 .50902 .75219 .51556 .7641 .51202 .75881 .50545 Mtetra
.75881 .50545 .7641 .51202 .77606 .50847 .7708 .50187 Mtetra
.7708 .50187 .77606 .50847 .78807 .5049 .78285 .49827 Mtetra
.78285 .49827 .78807 .5049 .80013 .50131 .79494 .49466 Mtetra
.958 .761 .596 r
.79494 .49466 .80013 .50131 .80881 .45812 .80371 .45136 Mtetra
.664 .741 .908 r
.80371 .45136 .80881 .45812 .82082 .45446 .81575 .44768 Mtetra
.81575 .44768 .82082 .45446 .83288 .4508 .82785 .44398 Mtetra
.82785 .44398 .83288 .4508 .84499 .44711 .83999 .44027 Mtetra
.83999 .44027 .84499 .44711 .85715 .44341 .85219 .43654 Mtetra
.85219 .43654 .85715 .44341 .86936 .4397 .86443 .4328 Mtetra
.86443 .4328 .86936 .4397 .88162 .43597 .87673 .42904 Mtetra
.87673 .42904 .88162 .43597 .89393 .43222 .88908 .42526 Mtetra
.88908 .42526 .89393 .43222 .9063 .42846 .90148 .42147 Mtetra
.90148 .42147 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .5556 Mtetra
.43698 .5556 .44311 .56159 .45369 .55835 .4476 .55234 Mtetra
.4476 .55234 .45369 .55835 .46432 .5551 .45825 .54907 Mtetra
.45825 .54907 .46432 .5551 .47499 .55184 .46895 .54579 Mtetra
.46895 .54579 .47499 .55184 .4857 .54857 .47968 .54249 Mtetra
.47968 .54249 .4857 .54857 .49646 .54528 .49046 .53918 Mtetra
.49046 .53918 .49646 .54528 .50725 .54198 .50129 .53585 Mtetra
.684 .192 0 r
.50129 .53585 .50725 .54198 .51806 .55614 .51209 .55002 Mtetra
.662 .743 .91 r
.51209 .55002 .51806 .55614 .52899 .55283 .52305 .54669 Mtetra
.52305 .54669 .52899 .55283 .53998 .54951 .53407 .54334 Mtetra
.53407 .54334 .53998 .54951 .551 .54618 .54512 .53998 Mtetra
.54512 .53998 .551 .54618 .56207 .54283 .55622 .53661 Mtetra
.55622 .53661 .56207 .54283 .57319 .53947 .56736 .53322 Mtetra
.56736 .53322 .57319 .53947 .58434 .53609 .57855 .52982 Mtetra
.57855 .52982 .58434 .53609 .59555 .5327 .58979 .52641 Mtetra
.58979 .52641 .59555 .5327 .6068 .5293 .60107 .52298 Mtetra
.60107 .52298 .6068 .5293 .61809 .52588 .61239 .51954 Mtetra
.61239 .51954 .61809 .52588 .62943 .52245 .62376 .51608 Mtetra
.62376 .51608 .62943 .52245 .64082 .51901 .63518 .51261 Mtetra
.63518 .51261 .64082 .51901 .65225 .51555 .64665 .50913 Mtetra
.699 .227 0 r
.64665 .50913 .65225 .51555 .66463 .53357 .65902 .52717 Mtetra
.661 .745 .913 r
.65902 .52717 .66463 .53357 .67623 .53011 .67066 .52367 Mtetra
.67066 .52367 .67623 .53011 .68788 .52663 .68234 .52017 Mtetra
.68234 .52017 .68788 .52663 .69958 .52314 .69407 .51665 Mtetra
.69407 .51665 .69958 .52314 .71133 .51963 .70585 .51311 Mtetra
.70585 .51311 .71133 .51963 .72312 .51611 .71768 .50956 Mtetra
.71768 .50956 .72312 .51611 .73497 .51257 .72956 .506 Mtetra
.72956 .506 .73497 .51257 .74686 .50902 .74149 .50242 Mtetra
.74149 .50242 .74686 .50902 .75881 .50545 .75347 .49882 Mtetra
.75347 .49882 .75881 .50545 .7708 .50187 .7655 .49521 Mtetra
.7655 .49521 .7708 .50187 .78285 .49827 .77758 .49159 Mtetra
.77758 .49159 .78285 .49827 .79494 .49466 .78971 .48795 Mtetra
.958 .761 .596 r
.78971 .48795 .79494 .49466 .80371 .45136 .79856 .44455 Mtetra
.664 .741 .908 r
.79856 .44455 .80371 .45136 .81575 .44768 .81064 .44084 Mtetra
.81064 .44084 .81575 .44768 .82785 .44398 .82277 .43712 Mtetra
.82277 .43712 .82785 .44398 .83999 .44027 .83495 .43338 Mtetra
.83495 .43338 .83999 .44027 .85219 .43654 .84719 .42962 Mtetra
.84719 .42962 .85219 .43654 .86443 .4328 .85947 .42585 Mtetra
.85947 .42585 .86443 .4328 .87673 .42904 .87181 .42206 Mtetra
.87181 .42206 .87673 .42904 .88908 .42526 .88419 .41825 Mtetra
.88419 .41825 .88908 .42526 .90148 .42147 .89664 .41443 Mtetra
.89664 .41443 .90148 .42147 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55284 Mtetra
.42022 .55284 .42641 .55885 .43698 .5556 .43081 .54957 Mtetra
.43081 .54957 .43698 .5556 .4476 .55234 .44145 .54629 Mtetra
.44145 .54629 .4476 .55234 .45825 .54907 .45213 .543 Mtetra
.45213 .543 .45825 .54907 .46895 .54579 .46286 .53969 Mtetra
.46286 .53969 .46895 .54579 .47968 .54249 .47362 .53636 Mtetra
.47362 .53636 .47968 .54249 .49046 .53918 .48443 .53303 Mtetra
.48443 .53303 .49046 .53918 .50129 .53585 .49528 .52968 Mtetra
.684 .192 0 r
.49528 .52968 .50129 .53585 .51209 .55002 .50608 .54386 Mtetra
.662 .743 .91 r
.50608 .54386 .51209 .55002 .52305 .54669 .51707 .5405 Mtetra
.51707 .5405 .52305 .54669 .53407 .54334 .52811 .53713 Mtetra
.52811 .53713 .53407 .54334 .54512 .53998 .5392 .53375 Mtetra
.5392 .53375 .54512 .53998 .55622 .53661 .55032 .53035 Mtetra
.55032 .53035 .55622 .53661 .56736 .53322 .5615 .52694 Mtetra
.5615 .52694 .56736 .53322 .57855 .52982 .57272 .52351 Mtetra
.57272 .52351 .57855 .52982 .58979 .52641 .58398 .52007 Mtetra
.58398 .52007 .58979 .52641 .60107 .52298 .59529 .51662 Mtetra
.59529 .51662 .60107 .52298 .61239 .51954 .60665 .51315 Mtetra
.60665 .51315 .61239 .51954 .62376 .51608 .61805 .50966 Mtetra
.61805 .50966 .62376 .51608 .63518 .51261 .6295 .50617 Mtetra
.6295 .50617 .63518 .51261 .64665 .50913 .641 .50266 Mtetra
.699 .227 0 r
.641 .50266 .64665 .50913 .65902 .52717 .65337 .52071 Mtetra
.661 .745 .913 r
.65337 .52071 .65902 .52717 .67066 .52367 .66504 .51719 Mtetra
.66504 .51719 .67066 .52367 .68234 .52017 .67675 .51366 Mtetra
.67675 .51366 .68234 .52017 .69407 .51665 .68852 .51011 Mtetra
.68852 .51011 .69407 .51665 .70585 .51311 .70033 .50655 Mtetra
.70033 .50655 .70585 .51311 .71768 .50956 .7122 .50297 Mtetra
.7122 .50297 .71768 .50956 .72956 .506 .72411 .49938 Mtetra
.72411 .49938 .72956 .506 .74149 .50242 .73608 .49577 Mtetra
.73608 .49577 .74149 .50242 .75347 .49882 .74809 .49215 Mtetra
.74809 .49215 .75347 .49882 .7655 .49521 .76016 .48851 Mtetra
.76016 .48851 .7655 .49521 .77758 .49159 .77227 .48486 Mtetra
.77227 .48486 .77758 .49159 .78971 .48795 .78444 .48119 Mtetra
.958 .761 .596 r
.78444 .48119 .78971 .48795 .79856 .44455 .79338 .43769 Mtetra
.664 .741 .908 r
.79338 .43769 .79856 .44455 .81064 .44084 .80549 .43395 Mtetra
.80549 .43395 .81064 .44084 .82277 .43712 .81766 .4302 Mtetra
.81766 .4302 .82277 .43712 .83495 .43338 .82988 .42643 Mtetra
.82988 .42643 .83495 .43338 .84719 .42962 .84215 .42264 Mtetra
.84215 .42264 .84719 .42962 .85947 .42585 .85447 .41884 Mtetra
.85447 .41884 .85947 .42585 .87181 .42206 .86684 .41502 Mtetra
.86684 .41502 .87181 .42206 .88419 .41825 .87927 .41119 Mtetra
.87927 .41119 .88419 .41825 .89664 .41443 .89175 .40734 Mtetra
.89175 .40734 .89664 .41443 .90913 .4106 .90428 .40347 Mtetra
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39958 Mtetra
.91687 .39958 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55984 Mtetra
.37189 .55984 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55284 .41397 .5468 Mtetra
.41397 .5468 .42022 .55284 .43081 .54957 .4246 .5435 Mtetra
.4246 .5435 .43081 .54957 .44145 .54629 .43526 .5402 Mtetra
.43526 .5402 .44145 .54629 .45213 .543 .44597 .53688 Mtetra
.44597 .53688 .45213 .543 .46286 .53969 .45672 .53354 Mtetra
.45672 .53354 .46286 .53969 .47362 .53636 .46751 .5302 Mtetra
.46751 .5302 .47362 .53636 .48443 .53303 .47835 .52684 Mtetra
.47835 .52684 .48443 .53303 .49528 .52968 .48923 .52346 Mtetra
.684 .192 0 r
.48923 .52346 .49528 .52968 .50608 .54386 .50002 .53765 Mtetra
.662 .743 .91 r
.50002 .53765 .50608 .54386 .51707 .5405 .51104 .53427 Mtetra
.51104 .53427 .51707 .5405 .52811 .53713 .52211 .53087 Mtetra
.52211 .53087 .52811 .53713 .5392 .53375 .53323 .52746 Mtetra
.53323 .52746 .5392 .53375 .55032 .53035 .54438 .52404 Mtetra
.54438 .52404 .55032 .53035 .5615 .52694 .55559 .5206 Mtetra
.55559 .5206 .5615 .52694 .57272 .52351 .56684 .51715 Mtetra
.56684 .51715 .57272 .52351 .58398 .52007 .57813 .51368 Mtetra
.57813 .51368 .58398 .52007 .59529 .51662 .58947 .5102 Mtetra
.58947 .5102 .59529 .51662 .60665 .51315 .60086 .50671 Mtetra
.60086 .50671 .60665 .51315 .61805 .50966 .61229 .5032 Mtetra
.61229 .5032 .61805 .50966 .6295 .50617 .62377 .49968 Mtetra
.62377 .49968 .6295 .50617 .641 .50266 .6353 .49614 Mtetra
.699 .227 0 r
.6353 .49614 .641 .50266 .65337 .52071 .64767 .5142 Mtetra
.661 .745 .913 r
.64767 .5142 .65337 .52071 .66504 .51719 .65938 .51066 Mtetra
.65938 .51066 .66504 .51719 .67675 .51366 .67113 .5071 Mtetra
.67113 .5071 .67675 .51366 .68852 .51011 .68292 .50352 Mtetra
.68292 .50352 .68852 .51011 .70033 .50655 .69477 .49993 Mtetra
.69477 .49993 .70033 .50655 .7122 .50297 .70667 .49633 Mtetra
.70667 .49633 .7122 .50297 .72411 .49938 .71862 .49271 Mtetra
.71862 .49271 .72411 .49938 .73608 .49577 .73062 .48907 Mtetra
.73062 .48907 .73608 .49577 .74809 .49215 .74267 .48542 Mtetra
.74267 .48542 .74809 .49215 .76016 .48851 .75477 .48175 Mtetra
.75477 .48175 .76016 .48851 .77227 .48486 .76692 .47807 Mtetra
.76692 .47807 .77227 .48486 .78444 .48119 .77912 .47438 Mtetra
.958 .761 .596 r
.77912 .47438 .78444 .48119 .79338 .43769 .78815 .43078 Mtetra
.664 .741 .908 r
.78815 .43078 .79338 .43769 .80549 .43395 .8003 .42701 Mtetra
.8003 .42701 .80549 .43395 .81766 .4302 .81251 .42323 Mtetra
.81251 .42323 .81766 .4302 .82988 .42643 .82476 .41943 Mtetra
.82476 .41943 .82988 .42643 .84215 .42264 .83707 .41561 Mtetra
.83707 .41561 .84215 .42264 .85447 .41884 .84943 .41178 Mtetra
.84943 .41178 .85447 .41884 .86684 .41502 .86184 .40793 Mtetra
.86184 .40793 .86684 .41502 .87927 .41119 .8743 .40406 Mtetra
.8743 .40406 .87927 .41119 .89175 .40734 .88682 .40018 Mtetra
.88682 .40018 .89175 .40734 .90428 .40347 .89939 .39628 Mtetra
.89939 .39628 .90428 .40347 .91687 .39958 .91202 .39237 Mtetra
.91202 .39237 .91687 .39958 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.35506 .5571 .36148 .56307 .37189 .55984 .3655 .55385 Mtetra
.3655 .55385 .37189 .55984 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .5435 .41834 .53739 Mtetra
.41834 .53739 .4246 .5435 .43526 .5402 .42903 .53406 Mtetra
.42903 .53406 .43526 .5402 .44597 .53688 .43976 .53071 Mtetra
.43976 .53071 .44597 .53688 .45672 .53354 .45054 .52735 Mtetra
.45054 .52735 .45672 .53354 .46751 .5302 .46136 .52398 Mtetra
.46136 .52398 .46751 .5302 .47835 .52684 .47222 .5206 Mtetra
.47222 .5206 .47835 .52684 .48923 .52346 .48313 .5172 Mtetra
.684 .192 0 r
.48313 .5172 .48923 .52346 .50002 .53765 .49392 .5314 Mtetra
.662 .743 .91 r
.49392 .5314 .50002 .53765 .51104 .53427 .50497 .52799 Mtetra
.50497 .52799 .51104 .53427 .52211 .53087 .51607 .52457 Mtetra
.51607 .52457 .52211 .53087 .53323 .52746 .52721 .52113 Mtetra
.52721 .52113 .53323 .52746 .54438 .52404 .5384 .51768 Mtetra
.5384 .51768 .54438 .52404 .55559 .5206 .54963 .51422 Mtetra
.54963 .51422 .55559 .5206 .56684 .51715 .56091 .51074 Mtetra
.56091 .51074 .56684 .51715 .57813 .51368 .57224 .50725 Mtetra
.57224 .50725 .57813 .51368 .58947 .5102 .58361 .50374 Mtetra
.58361 .50374 .58947 .5102 .60086 .50671 .59503 .50022 Mtetra
.59503 .50022 .60086 .50671 .61229 .5032 .60649 .49668 Mtetra
.60649 .49668 .61229 .5032 .62377 .49968 .61801 .49313 Mtetra
.61801 .49313 .62377 .49968 .6353 .49614 .62957 .48957 Mtetra
.699 .227 0 r
.62957 .48957 .6353 .49614 .64767 .5142 .64194 .50765 Mtetra
.661 .745 .913 r
.64194 .50765 .64767 .5142 .65938 .51066 .65367 .50407 Mtetra
.65367 .50407 .65938 .51066 .67113 .5071 .66545 .50049 Mtetra
.66545 .50049 .67113 .5071 .68292 .50352 .67729 .49688 Mtetra
.67729 .49688 .68292 .50352 .69477 .49993 .68917 .49326 Mtetra
.68917 .49326 .69477 .49993 .70667 .49633 .7011 .48963 Mtetra
.7011 .48963 .70667 .49633 .71862 .49271 .71309 .48598 Mtetra
.71309 .48598 .71862 .49271 .73062 .48907 .72512 .48232 Mtetra
.72512 .48232 .73062 .48907 .74267 .48542 .73721 .47864 Mtetra
.73721 .47864 .74267 .48542 .75477 .48175 .74934 .47495 Mtetra
.74934 .47495 .75477 .48175 .76692 .47807 .76153 .47123 Mtetra
.76153 .47123 .76692 .47807 .77912 .47438 .77377 .46751 Mtetra
.958 .761 .596 r
.77377 .46751 .77912 .47438 .78815 .43078 .78289 .42381 Mtetra
.664 .741 .908 r
.78289 .42381 .78815 .43078 .8003 .42701 .79507 .42001 Mtetra
.79507 .42001 .8003 .42701 .81251 .42323 .80731 .4162 Mtetra
.80731 .4162 .81251 .42323 .82476 .41943 .81961 .41237 Mtetra
.81961 .41237 .82476 .41943 .83707 .41561 .83195 .40852 Mtetra
.83195 .40852 .83707 .41561 .84943 .41178 .84435 .40466 Mtetra
.84435 .40466 .84943 .41178 .86184 .40793 .8568 .40078 Mtetra
.8568 .40078 .86184 .40793 .8743 .40406 .8693 .39689 Mtetra
.8693 .39689 .8743 .40406 .88682 .40018 .88186 .39297 Mtetra
.88186 .39297 .88682 .40018 .89939 .39628 .89447 .38904 Mtetra
.89447 .38904 .89939 .39628 .91202 .39237 .90713 .3851 Mtetra
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37715 Mtetra
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53457 Mtetra
.40135 .53457 .40769 .54071 .41834 .53739 .41203 .53123 Mtetra
.41203 .53123 .41834 .53739 .42903 .53406 .42275 .52787 Mtetra
.42275 .52787 .42903 .53406 .43976 .53071 .43351 .5245 Mtetra
.43351 .5245 .43976 .53071 .45054 .52735 .44432 .52112 Mtetra
.44432 .52112 .45054 .52735 .46136 .52398 .45516 .51772 Mtetra
.45516 .51772 .46136 .52398 .47222 .5206 .46605 .51431 Mtetra
.46605 .51431 .47222 .5206 .48313 .5172 .47699 .51089 Mtetra
.684 .192 0 r
.47699 .51089 .48313 .5172 .49392 .5314 .48777 .52509 Mtetra
.662 .743 .91 r
.48777 .52509 .49392 .5314 .50497 .52799 .49885 .52166 Mtetra
.49885 .52166 .50497 .52799 .51607 .52457 .50998 .51821 Mtetra
.50998 .51821 .51607 .52457 .52721 .52113 .52115 .51475 Mtetra
.52115 .51475 .52721 .52113 .5384 .51768 .53237 .51127 Mtetra
.53237 .51127 .5384 .51768 .54963 .51422 .54363 .50778 Mtetra
.54363 .50778 .54963 .51422 .56091 .51074 .55494 .50428 Mtetra
.55494 .50428 .56091 .51074 .57224 .50725 .5663 .50076 Mtetra
.5663 .50076 .57224 .50725 .58361 .50374 .5777 .49723 Mtetra
.5777 .49723 .58361 .50374 .59503 .50022 .58915 .49368 Mtetra
.58915 .49368 .59503 .50022 .60649 .49668 .60065 .49012 Mtetra
.60065 .49012 .60649 .49668 .61801 .49313 .61219 .48654 Mtetra
.61219 .48654 .61801 .49313 .62957 .48957 .62379 .48295 Mtetra
.699 .227 0 r
.62379 .48295 .62957 .48957 .64194 .50765 .63615 .50104 Mtetra
.661 .745 .913 r
.63615 .50104 .64194 .50765 .65367 .50407 .64792 .49744 Mtetra
.64792 .49744 .65367 .50407 .66545 .50049 .65974 .49382 Mtetra
.65974 .49382 .66545 .50049 .67729 .49688 .67161 .49019 Mtetra
.67161 .49019 .67729 .49688 .68917 .49326 .68352 .48655 Mtetra
.68352 .48655 .68917 .49326 .7011 .48963 .69549 .48288 Mtetra
.69549 .48288 .7011 .48963 .71309 .48598 .70751 .47921 Mtetra
.70751 .47921 .71309 .48598 .72512 .48232 .71958 .47551 Mtetra
.71958 .47551 .72512 .48232 .73721 .47864 .7317 .47181 Mtetra
.7317 .47181 .73721 .47864 .74934 .47495 .74387 .46808 Mtetra
.74387 .46808 .74934 .47495 .76153 .47123 .7561 .46434 Mtetra
.7561 .46434 .76153 .47123 .77377 .46751 .76837 .46059 Mtetra
.958 .761 .596 r
.76837 .46059 .77377 .46751 .78289 .42381 .77758 .41679 Mtetra
.664 .741 .908 r
.77758 .41679 .78289 .42381 .79507 .42001 .7898 .41296 Mtetra
.7898 .41296 .79507 .42001 .80731 .4162 .80208 .40912 Mtetra
.80208 .40912 .80731 .4162 .81961 .41237 .81441 .40526 Mtetra
.81441 .40526 .81961 .41237 .83195 .40852 .82679 .40138 Mtetra
.82679 .40138 .83195 .40852 .84435 .40466 .83923 .39749 Mtetra
.83923 .39749 .84435 .40466 .8568 .40078 .85171 .39358 Mtetra
.85171 .39358 .8568 .40078 .8693 .39689 .86426 .38965 Mtetra
.86426 .38965 .8693 .39689 .88186 .39297 .87685 .38571 Mtetra
.87685 .38571 .88186 .39297 .89447 .38904 .8895 .38175 Mtetra
.8895 .38175 .89447 .38904 .90713 .3851 .90221 .37777 Mtetra
.90221 .37777 .90713 .3851 .91985 .38114 .91497 .37377 Mtetra
.91497 .37377 .91985 .38114 .93263 .37715 .92778 .36976 Mtetra
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53508 Mtetra
.3737 .53508 .38013 .54122 .39072 .5379 .38431 .53174 Mtetra
.38431 .53174 .39072 .5379 .40135 .53457 .39497 .52839 Mtetra
.39497 .52839 .40135 .53457 .41203 .53123 .40568 .52502 Mtetra
.40568 .52502 .41203 .53123 .42275 .52787 .41642 .52164 Mtetra
.41642 .52164 .42275 .52787 .43351 .5245 .42721 .51825 Mtetra
.42721 .51825 .43351 .5245 .44432 .52112 .43804 .51484 Mtetra
.43804 .51484 .44432 .52112 .45516 .51772 .44892 .51142 Mtetra
.44892 .51142 .45516 .51772 .46605 .51431 .45984 .50798 Mtetra
.45984 .50798 .46605 .51431 .47699 .51089 .4708 .50453 Mtetra
.684 .192 0 r
.4708 .50453 .47699 .51089 .48777 .52509 .48158 .51874 Mtetra
.662 .743 .91 r
.48158 .51874 .48777 .52509 .49885 .52166 .49269 .51528 Mtetra
.49269 .51528 .49885 .52166 .50998 .51821 .50385 .51181 Mtetra
.50385 .51181 .50998 .51821 .52115 .51475 .51505 .50832 Mtetra
.51505 .50832 .52115 .51475 .53237 .51127 .5263 .50482 Mtetra
.5263 .50482 .53237 .51127 .54363 .50778 .53759 .5013 Mtetra
.53759 .5013 .54363 .50778 .55494 .50428 .54893 .49777 Mtetra
.54893 .49777 .55494 .50428 .5663 .50076 .56032 .49423 Mtetra
.56032 .49423 .5663 .50076 .5777 .49723 .57175 .49067 Mtetra
.57175 .49067 .5777 .49723 .58915 .49368 .58323 .48709 Mtetra
.58323 .48709 .58915 .49368 .60065 .49012 .59476 .4835 Mtetra
.59476 .4835 .60065 .49012 .61219 .48654 .60634 .4799 Mtetra
.60634 .4799 .61219 .48654 .62379 .48295 .61796 .47628 Mtetra
.699 .227 0 r
.61796 .47628 .62379 .48295 .63615 .50104 .63033 .49438 Mtetra
.661 .745 .913 r
.63033 .49438 .63615 .50104 .64792 .49744 .64213 .49075 Mtetra
.64213 .49075 .64792 .49744 .65974 .49382 .65398 .48711 Mtetra
.65398 .48711 .65974 .49382 .67161 .49019 .66588 .48345 Mtetra
.66588 .48345 .67161 .49019 .68352 .48655 .67783 .47977 Mtetra
.67783 .47977 .68352 .48655 .69549 .48288 .68983 .47608 Mtetra
.68983 .47608 .69549 .48288 .70751 .47921 .70189 .47238 Mtetra
.70189 .47238 .70751 .47921 .71958 .47551 .71399 .46866 Mtetra
.71399 .46866 .71958 .47551 .7317 .47181 .72615 .46492 Mtetra
.72615 .46492 .7317 .47181 .74387 .46808 .73836 .46117 Mtetra
.73836 .46117 .74387 .46808 .7561 .46434 .75062 .4574 Mtetra
.75062 .4574 .7561 .46434 .76837 .46059 .76293 .45361 Mtetra
.958 .761 .596 r
.76293 .45361 .76837 .46059 .77758 .41679 .77223 .40971 Mtetra
.664 .741 .908 r
.77223 .40971 .77758 .41679 .7898 .41296 .78449 .40585 Mtetra
.78449 .40585 .7898 .41296 .80208 .40912 .79681 .40198 Mtetra
.79681 .40198 .80208 .40912 .81441 .40526 .80917 .39809 Mtetra
.80917 .39809 .81441 .40526 .82679 .40138 .82159 .39418 Mtetra
.82159 .39418 .82679 .40138 .83923 .39749 .83406 .39025 Mtetra
.83406 .39025 .83923 .39749 .85171 .39358 .84659 .38631 Mtetra
.84659 .38631 .85171 .39358 .86426 .38965 .85917 .38236 Mtetra
.85917 .38236 .86426 .38965 .87685 .38571 .87181 .37838 Mtetra
.87181 .37838 .87685 .38571 .8895 .38175 .8845 .37439 Mtetra
.8845 .37439 .8895 .38175 .90221 .37777 .89724 .37038 Mtetra
.89724 .37038 .90221 .37777 .91497 .37377 .91004 .36635 Mtetra
.91004 .36635 .91497 .37377 .92778 .36976 .9229 .36231 Mtetra
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53508 .36722 .52891 Mtetra
.36722 .52891 .3737 .53508 .38431 .53174 .37786 .52554 Mtetra
.37786 .52554 .38431 .53174 .39497 .52839 .38855 .52216 Mtetra
.38855 .52216 .39497 .52839 .40568 .52502 .39928 .51877 Mtetra
.39928 .51877 .40568 .52502 .41642 .52164 .41005 .51537 Mtetra
.41005 .51537 .41642 .52164 .42721 .51825 .42087 .51195 Mtetra
.42087 .51195 .42721 .51825 .43804 .51484 .43173 .50851 Mtetra
.43173 .50851 .43804 .51484 .44892 .51142 .44263 .50507 Mtetra
.44263 .50507 .44892 .51142 .45984 .50798 .45358 .50161 Mtetra
.45358 .50161 .45984 .50798 .4708 .50453 .46457 .49813 Mtetra
.684 .192 0 r
.46457 .49813 .4708 .50453 .48158 .51874 .47534 .51234 Mtetra
.662 .743 .91 r
.47534 .51234 .48158 .51874 .49269 .51528 .48648 .50886 Mtetra
.48648 .50886 .49269 .51528 .50385 .51181 .49767 .50536 Mtetra
.49767 .50536 .50385 .51181 .51505 .50832 .5089 .50185 Mtetra
.5089 .50185 .51505 .50832 .5263 .50482 .52017 .49832 Mtetra
.52017 .49832 .5263 .50482 .53759 .5013 .5315 .49477 Mtetra
.5315 .49477 .53759 .5013 .54893 .49777 .54287 .49122 Mtetra
.54287 .49122 .54893 .49777 .56032 .49423 .55429 .48764 Mtetra
.55429 .48764 .56032 .49423 .57175 .49067 .56575 .48406 Mtetra
.56575 .48406 .57175 .49067 .58323 .48709 .57726 .48045 Mtetra
.57726 .48045 .58323 .48709 .59476 .4835 .58883 .47684 Mtetra
.58883 .47684 .59476 .4835 .60634 .4799 .60043 .4732 Mtetra
.60043 .4732 .60634 .4799 .61796 .47628 .61209 .46956 Mtetra
.699 .227 0 r
.61209 .46956 .61796 .47628 .63033 .49438 .62445 .48767 Mtetra
.661 .745 .913 r
.62445 .48767 .63033 .49438 .64213 .49075 .63629 .48401 Mtetra
.63629 .48401 .64213 .49075 .65398 .48711 .64817 .48034 Mtetra
.64817 .48034 .65398 .48711 .66588 .48345 .66011 .47665 Mtetra
.66011 .47665 .66588 .48345 .67783 .47977 .6721 .47295 Mtetra
.6721 .47295 .67783 .47977 .68983 .47608 .68413 .46923 Mtetra
.68413 .46923 .68983 .47608 .70189 .47238 .69622 .4655 Mtetra
.69622 .4655 .70189 .47238 .71399 .46866 .70836 .46174 Mtetra
.70836 .46174 .71399 .46866 .72615 .46492 .72055 .45798 Mtetra
.72055 .45798 .72615 .46492 .73836 .46117 .7328 .45419 Mtetra
.7328 .45419 .73836 .46117 .75062 .4574 .7451 .45039 Mtetra
.7451 .45039 .75062 .4574 .76293 .45361 .75745 .44658 Mtetra
.958 .761 .596 r
.75745 .44658 .76293 .45361 .77223 .40971 .76684 .40257 Mtetra
.664 .741 .908 r
.76684 .40257 .77223 .40971 .78449 .40585 .77914 .39869 Mtetra
.77914 .39869 .78449 .40585 .79681 .40198 .79149 .39478 Mtetra
.79149 .39478 .79681 .40198 .80917 .39809 .80389 .39086 Mtetra
.80389 .39086 .80917 .39809 .82159 .39418 .81635 .38692 Mtetra
.81635 .38692 .82159 .39418 .83406 .39025 .82886 .38297 Mtetra
.82886 .38297 .83406 .39025 .84659 .38631 .84143 .37899 Mtetra
.84143 .37899 .84659 .38631 .85917 .38236 .85405 .375 Mtetra
.85405 .375 .85917 .38236 .87181 .37838 .86672 .371 Mtetra
.86672 .371 .87181 .37838 .8845 .37439 .87945 .36697 Mtetra
.87945 .36697 .8845 .37439 .89724 .37038 .89224 .36293 Mtetra
.89224 .36293 .89724 .37038 .91004 .36635 .90508 .35887 Mtetra
.90508 .35887 .91004 .36635 .9229 .36231 .91798 .35479 Mtetra
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52268 Mtetra
.36069 .52268 .36722 .52891 .37786 .52554 .37136 .51929 Mtetra
.37136 .51929 .37786 .52554 .38855 .52216 .38207 .51589 Mtetra
.38207 .51589 .38855 .52216 .39928 .51877 .39283 .51247 Mtetra
.39283 .51247 .39928 .51877 .41005 .51537 .40363 .50904 Mtetra
.40363 .50904 .41005 .51537 .42087 .51195 .41447 .5056 Mtetra
.41447 .5056 .42087 .51195 .43173 .50851 .42536 .50214 Mtetra
.42536 .50214 .43173 .50851 .44263 .50507 .43629 .49867 Mtetra
.43629 .49867 .44263 .50507 .45358 .50161 .44727 .49518 Mtetra
.44727 .49518 .45358 .50161 .46457 .49813 .45829 .49168 Mtetra
.684 .192 0 r
.45829 .49168 .46457 .49813 .47534 .51234 .46905 .5059 Mtetra
.662 .743 .91 r
.46905 .5059 .47534 .51234 .48648 .50886 .48022 .50239 Mtetra
.48022 .50239 .48648 .50886 .49767 .50536 .49144 .49886 Mtetra
.49144 .49886 .49767 .50536 .5089 .50185 .5027 .49532 Mtetra
.5027 .49532 .5089 .50185 .52017 .49832 .51401 .49176 Mtetra
.51401 .49176 .52017 .49832 .5315 .49477 .52536 .48819 Mtetra
.52536 .48819 .5315 .49477 .54287 .49122 .53676 .48461 Mtetra
.53676 .48461 .54287 .49122 .55429 .48764 .54821 .48101 Mtetra
.54821 .48101 .55429 .48764 .56575 .48406 .55971 .47739 Mtetra
.55971 .47739 .56575 .48406 .57726 .48045 .57125 .47376 Mtetra
.57125 .47376 .57726 .48045 .58883 .47684 .58285 .47012 Mtetra
.58285 .47012 .58883 .47684 .60043 .4732 .59449 .46646 Mtetra
.59449 .46646 .60043 .4732 .61209 .46956 .60618 .46278 Mtetra
.699 .227 0 r
.60618 .46278 .61209 .46956 .62445 .48767 .61853 .48091 Mtetra
.661 .745 .913 r
.61853 .48091 .62445 .48767 .63629 .48401 .6304 .47722 Mtetra
.6304 .47722 .63629 .48401 .64817 .48034 .64232 .47352 Mtetra
.64232 .47352 .64817 .48034 .66011 .47665 .65429 .4698 Mtetra
.65429 .4698 .66011 .47665 .6721 .47295 .66631 .46607 Mtetra
.66631 .46607 .6721 .47295 .68413 .46923 .67839 .46232 Mtetra
.67839 .46232 .68413 .46923 .69622 .4655 .69051 .45856 Mtetra
.69051 .45856 .69622 .4655 .70836 .46174 .70269 .45478 Mtetra
.70269 .45478 .70836 .46174 .72055 .45798 .71492 .45098 Mtetra
.71492 .45098 .72055 .45798 .7328 .45419 .7272 .44717 Mtetra
.7272 .44717 .7328 .45419 .7451 .45039 .73953 .44334 Mtetra
.73953 .44334 .7451 .45039 .75745 .44658 .75192 .43949 Mtetra
.958 .761 .596 r
.75192 .43949 .75745 .44658 .76684 .40257 .76141 .39538 Mtetra
.664 .741 .908 r
.76141 .39538 .76684 .40257 .77914 .39869 .77374 .39146 Mtetra
.77374 .39146 .77914 .39869 .79149 .39478 .78613 .38753 Mtetra
.78613 .38753 .79149 .39478 .80389 .39086 .79857 .38358 Mtetra
.79857 .38358 .80389 .39086 .81635 .38692 .81107 .37961 Mtetra
.81107 .37961 .81635 .38692 .82886 .38297 .82362 .37562 Mtetra
.82362 .37562 .82886 .38297 .84143 .37899 .83622 .37161 Mtetra
.83622 .37161 .84143 .37899 .85405 .375 .84888 .36759 Mtetra
.84888 .36759 .85405 .375 .86672 .371 .8616 .36355 Mtetra
.8616 .36355 .86672 .371 .87945 .36697 .87437 .3595 Mtetra
.87437 .3595 .87945 .36697 .89224 .36293 .88719 .35542 Mtetra
.88719 .35542 .89224 .36293 .90508 .35887 .90008 .35133 Mtetra
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .5232 Mtetra
.33285 .5232 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52268 .35411 .51641 Mtetra
.35411 .51641 .36069 .52268 .37136 .51929 .36481 .513 Mtetra
.36481 .513 .37136 .51929 .38207 .51589 .37555 .50957 Mtetra
.37555 .50957 .38207 .51589 .39283 .51247 .38633 .50613 Mtetra
.38633 .50613 .39283 .51247 .40363 .50904 .39716 .50267 Mtetra
.39716 .50267 .40363 .50904 .41447 .5056 .40803 .4992 Mtetra
.40803 .4992 .41447 .5056 .42536 .50214 .41895 .49572 Mtetra
.41895 .49572 .42536 .50214 .43629 .49867 .42991 .49222 Mtetra
.42991 .49222 .43629 .49867 .44727 .49518 .44091 .48871 Mtetra
.44091 .48871 .44727 .49518 .45829 .49168 .45196 .48518 Mtetra
0 .021 .527 r
.45196 .48518 .45829 .49168 .46905 .5059 .46279 .49583 Mtetra
.655 .651 .834 r
.46279 .49583 .46905 .5059 .48022 .50239 .47397 .49229 Mtetra
.47397 .49229 .48022 .50239 .49144 .49886 .48521 .48874 Mtetra
.48521 .48874 .49144 .49886 .5027 .49532 .49648 .48516 Mtetra
.49648 .48516 .5027 .49532 .51401 .49176 .50781 .48158 Mtetra
.50781 .48158 .51401 .49176 .52536 .48819 .51918 .47798 Mtetra
.51918 .47798 .52536 .48819 .53676 .48461 .5306 .47436 Mtetra
.5306 .47436 .53676 .48461 .54821 .48101 .54207 .47073 Mtetra
.54207 .47073 .54821 .48101 .55971 .47739 .55359 .46708 Mtetra
.55359 .46708 .55971 .47739 .57125 .47376 .56515 .46342 Mtetra
.56515 .46342 .57125 .47376 .58285 .47012 .57676 .45974 Mtetra
.57676 .45974 .58285 .47012 .59449 .46646 .58842 .45605 Mtetra
.58842 .45605 .59449 .46646 .60618 .46278 .60013 .45234 Mtetra
.97 .667 .39 r
.60013 .45234 .60618 .46278 .61853 .48091 .61719 .6478 Mtetra
.55 .323 .524 r
.61719 .6478 .61853 .48091 .6304 .47722 .62973 .64428 Mtetra
.62973 .64428 .6304 .47722 .64232 .47352 .64233 .64074 Mtetra
.64233 .64074 .64232 .47352 .65429 .4698 .65498 .63719 Mtetra
.65498 .63719 .65429 .4698 .66631 .46607 .6677 .63362 Mtetra
.6677 .63362 .66631 .46607 .67839 .46232 .68047 .63004 Mtetra
.68047 .63004 .67839 .46232 .69051 .45856 .69329 .62644 Mtetra
.69329 .62644 .69051 .45856 .70269 .45478 .70618 .62282 Mtetra
.70618 .62282 .70269 .45478 .71492 .45098 .71912 .61919 Mtetra
.71912 .61919 .71492 .45098 .7272 .44717 .73213 .61553 Mtetra
.73213 .61553 .7272 .44717 .73953 .44334 .74519 .61187 Mtetra
.74519 .61187 .73953 .44334 .75192 .43949 .75831 .60818 Mtetra
.196 .061 .459 r
.75831 .60818 .75192 .43949 .76141 .39538 .7618 .46979 Mtetra
.536 .292 .493 r
.7618 .46979 .76141 .39538 .77374 .39146 .7745 .46592 Mtetra
.7745 .46592 .77374 .39146 .78613 .38753 .78726 .46203 Mtetra
.78726 .46203 .78613 .38753 .79857 .38358 .80008 .45813 Mtetra
.80008 .45813 .79857 .38358 .81107 .37961 .81295 .45421 Mtetra
.81295 .45421 .81107 .37961 .82362 .37562 .82588 .45027 Mtetra
.82588 .45027 .82362 .37562 .83622 .37161 .83886 .44631 Mtetra
.83886 .44631 .83622 .37161 .84888 .36759 .85191 .44233 Mtetra
.85191 .44233 .84888 .36759 .8616 .36355 .86501 .43834 Mtetra
.86501 .43834 .8616 .36355 .87437 .3595 .87817 .43433 Mtetra
.87817 .43433 .87437 .3595 .88719 .35542 .8914 .4303 Mtetra
.8914 .4303 .88719 .35542 .90008 .35133 .90468 .42626 Mtetra
.90468 .42626 .90008 .35133 .91302 .34722 .91802 .42219 Mtetra
.664 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .34346 .51982 .33681 .51353 Mtetra
.33681 .51353 .34346 .51982 .35411 .51641 .34749 .5101 Mtetra
.34749 .5101 .35411 .51641 .36481 .513 .35821 .50666 Mtetra
.35821 .50666 .36481 .513 .37555 .50957 .36898 .5032 Mtetra
.36898 .5032 .37555 .50957 .38633 .50613 .37979 .49974 Mtetra
.37979 .49974 .38633 .50613 .39716 .50267 .39065 .49625 Mtetra
.39065 .49625 .39716 .50267 .40803 .4992 .40154 .49276 Mtetra
.40154 .49276 .40803 .4992 .41895 .49572 .41249 .48925 Mtetra
.41249 .48925 .41895 .49572 .42991 .49222 .42347 .48572 Mtetra
.42347 .48572 .42991 .49222 .44091 .48871 .4345 .48218 Mtetra
.4345 .48218 .44091 .48871 .45196 .48518 .44558 .47863 Mtetra
0 .021 .527 r
.44558 .47863 .45196 .48518 .46279 .49583 .45641 .48928 Mtetra
.663 .743 .91 r
.45641 .48928 .46279 .49583 .47397 .49229 .46763 .48571 Mtetra
.46763 .48571 .47397 .49229 .48521 .48874 .47889 .48213 Mtetra
.47889 .48213 .48521 .48874 .49648 .48516 .4902 .47853 Mtetra
.4902 .47853 .49648 .48516 .50781 .48158 .50155 .47492 Mtetra
.50155 .47492 .50781 .48158 .51918 .47798 .51296 .47129 Mtetra
.51296 .47129 .51918 .47798 .5306 .47436 .52441 .46764 Mtetra
.52441 .46764 .5306 .47436 .54207 .47073 .53591 .46399 Mtetra
.53591 .46399 .54207 .47073 .55359 .46708 .54745 .46031 Mtetra
.54745 .46031 .55359 .46708 .56515 .46342 .55905 .45662 Mtetra
.55905 .45662 .56515 .46342 .57676 .45974 .57069 .45291 Mtetra
.57069 .45291 .57676 .45974 .58842 .45605 .58239 .44919 Mtetra
.58239 .44919 .58842 .45605 .60013 .45234 .59413 .44546 Mtetra
.966 .663 .399 r
.59413 .44546 .60013 .45234 .61719 .6478 .61088 .64129 Mtetra
.646 .762 .934 r
.61088 .64129 .61719 .6478 .62973 .64428 .62346 .63774 Mtetra
.62346 .63774 .62973 .64428 .64233 .64074 .63609 .63417 Mtetra
.63609 .63417 .64233 .64074 .65498 .63719 .64879 .63059 Mtetra
.64879 .63059 .65498 .63719 .6677 .63362 .66154 .62699 Mtetra
.66154 .62699 .6677 .63362 .68047 .63004 .67435 .62338 Mtetra
.67435 .62338 .68047 .63004 .69329 .62644 .68722 .61975 Mtetra
.68722 .61975 .69329 .62644 .70618 .62282 .70014 .6161 Mtetra
.70014 .6161 .70618 .62282 .71912 .61919 .71313 .61243 Mtetra
.71313 .61243 .71912 .61919 .73213 .61553 .72617 .60875 Mtetra
.72617 .60875 .73213 .61553 .74519 .61187 .73928 .60505 Mtetra
.73928 .60505 .74519 .61187 .75831 .60818 .75244 .60134 Mtetra
.978 .718 .469 r
.75244 .60134 .75831 .60818 .7618 .46979 .75617 .46263 Mtetra
.658 .749 .918 r
.75617 .46263 .7618 .46979 .7745 .46592 .76891 .45873 Mtetra
.76891 .45873 .7745 .46592 .78726 .46203 .7817 .45481 Mtetra
.7817 .45481 .78726 .46203 .80008 .45813 .79456 .45087 Mtetra
.79456 .45087 .80008 .45813 .81295 .45421 .80747 .44692 Mtetra
.80747 .44692 .81295 .45421 .82588 .45027 .82044 .44295 Mtetra
.82044 .44295 .82588 .45027 .83886 .44631 .83347 .43896 Mtetra
.83347 .43896 .83886 .44631 .85191 .44233 .84656 .43495 Mtetra
.84656 .43495 .85191 .44233 .86501 .43834 .8597 .43092 Mtetra
.8597 .43092 .86501 .43834 .87817 .43433 .87291 .42688 Mtetra
.87291 .42688 .87817 .43433 .8914 .4303 .88617 .42282 Mtetra
.88617 .42282 .8914 .4303 .90468 .42626 .8995 .41874 Mtetra
.8995 .41874 .90468 .42626 .91802 .42219 .91289 .41464 Mtetra
.664 .741 .908 r
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.34082 .50374 .34749 .5101 .35821 .50666 .35157 .50027 Mtetra
.35157 .50027 .35821 .50666 .36898 .5032 .36236 .49679 Mtetra
.36236 .49679 .36898 .5032 .37979 .49974 .3732 .4933 Mtetra
.3732 .4933 .37979 .49974 .39065 .49625 .38408 .48979 Mtetra
.38408 .48979 .39065 .49625 .40154 .49276 .39501 .48626 Mtetra
.39501 .48626 .40154 .49276 .41249 .48925 .40598 .48273 Mtetra
.40598 .48273 .41249 .48925 .42347 .48572 .41699 .47918 Mtetra
.41699 .47918 .42347 .48572 .4345 .48218 .42805 .47561 Mtetra
.42805 .47561 .4345 .48218 .44558 .47863 .43916 .47203 Mtetra
0 .021 .527 r
.43916 .47203 .44558 .47863 .45641 .48928 .44999 .48268 Mtetra
.663 .743 .91 r
.44999 .48268 .45641 .48928 .46763 .48571 .46123 .47909 Mtetra
.46123 .47909 .46763 .48571 .47889 .48213 .47252 .47547 Mtetra
.47252 .47547 .47889 .48213 .4902 .47853 .48386 .47185 Mtetra
.48386 .47185 .4902 .47853 .50155 .47492 .49525 .46821 Mtetra
.49525 .46821 .50155 .47492 .51296 .47129 .50668 .46455 Mtetra
.50668 .46455 .51296 .47129 .52441 .46764 .51817 .46088 Mtetra
.51817 .46088 .52441 .46764 .53591 .46399 .5297 .45719 Mtetra
.5297 .45719 .53591 .46399 .54745 .46031 .54128 .45349 Mtetra
.54128 .45349 .54745 .46031 .55905 .45662 .5529 .44977 Mtetra
.5529 .44977 .55905 .45662 .57069 .45291 .56458 .44603 Mtetra
.56458 .44603 .57069 .45291 .58239 .44919 .57631 .44228 Mtetra
.57631 .44228 .58239 .44919 .59413 .44546 .58808 .43852 Mtetra
.966 .663 .399 r
.58808 .43852 .59413 .44546 .61088 .64129 .60452 .63472 Mtetra
.646 .762 .934 r
.60452 .63472 .61088 .64129 .62346 .63774 .61713 .63114 Mtetra
.61713 .63114 .62346 .63774 .63609 .63417 .62981 .62755 Mtetra
.62981 .62755 .63609 .63417 .64879 .63059 .64254 .62393 Mtetra
.64254 .62393 .64879 .63059 .66154 .62699 .65533 .62031 Mtetra
.65533 .62031 .66154 .62699 .67435 .62338 .66818 .61666 Mtetra
.66818 .61666 .67435 .62338 .68722 .61975 .68109 .613 Mtetra
.68109 .613 .68722 .61975 .70014 .6161 .69405 .60932 Mtetra
.69405 .60932 .70014 .6161 .71313 .61243 .70708 .60562 Mtetra
.70708 .60562 .71313 .61243 .72617 .60875 .72017 .60191 Mtetra
.72017 .60191 .72617 .60875 .73928 .60505 .73331 .59818 Mtetra
.73331 .59818 .73928 .60505 .75244 .60134 .74652 .59443 Mtetra
.978 .718 .469 r
.74652 .59443 .75244 .60134 .75617 .46263 .75048 .45541 Mtetra
.658 .749 .918 r
.75048 .45541 .75617 .46263 .76891 .45873 .76326 .45148 Mtetra
.76326 .45148 .76891 .45873 .7817 .45481 .7761 .44753 Mtetra
.7761 .44753 .7817 .45481 .79456 .45087 .789 .44356 Mtetra
.789 .44356 .79456 .45087 .80747 .44692 .80195 .43957 Mtetra
.80195 .43957 .80747 .44692 .82044 .44295 .81496 .43557 Mtetra
.81496 .43557 .82044 .44295 .83347 .43896 .82803 .43154 Mtetra
.82803 .43154 .83347 .43896 .84656 .43495 .84116 .4275 Mtetra
.84116 .4275 .84656 .43495 .8597 .43092 .85435 .42344 Mtetra
.85435 .42344 .8597 .43092 .87291 .42688 .8676 .41937 Mtetra
.8676 .41937 .87291 .42688 .88617 .42282 .88091 .41527 Mtetra
.88091 .41527 .88617 .42282 .8995 .41874 .89428 .41115 Mtetra
.89428 .41115 .8995 .41874 .91289 .41464 .90771 .40702 Mtetra
.664 .741 .908 r
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .5008 Mtetra
.32336 .5008 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49383 Mtetra
.34487 .49383 .35157 .50027 .36236 .49679 .35569 .49033 Mtetra
.35569 .49033 .36236 .49679 .3732 .4933 .36656 .48681 Mtetra
.36656 .48681 .3732 .4933 .38408 .48979 .37746 .48327 Mtetra
.37746 .48327 .38408 .48979 .39501 .48626 .38842 .47972 Mtetra
.38842 .47972 .39501 .48626 .40598 .48273 .39942 .47616 Mtetra
.39942 .47616 .40598 .48273 .41699 .47918 .41046 .47258 Mtetra
.41046 .47258 .41699 .47918 .42805 .47561 .42155 .46899 Mtetra
.42155 .46899 .42805 .47561 .43916 .47203 .43268 .46538 Mtetra
0 .021 .527 r
.43268 .46538 .43916 .47203 .44999 .48268 .44351 .47603 Mtetra
.663 .743 .91 r
.44351 .47603 .44999 .48268 .46123 .47909 .45479 .47241 Mtetra
.45479 .47241 .46123 .47909 .47252 .47547 .46611 .46877 Mtetra
.46611 .46877 .47252 .47547 .48386 .47185 .47748 .46511 Mtetra
.47748 .46511 .48386 .47185 .49525 .46821 .4889 .46144 Mtetra
.4889 .46144 .49525 .46821 .50668 .46455 .50036 .45776 Mtetra
.50036 .45776 .50668 .46455 .51817 .46088 .51188 .45406 Mtetra
.51188 .45406 .51817 .46088 .5297 .45719 .52344 .45034 Mtetra
.52344 .45034 .5297 .45719 .54128 .45349 .53505 .44661 Mtetra
.53505 .44661 .54128 .45349 .5529 .44977 .54671 .44286 Mtetra
.54671 .44286 .5529 .44977 .56458 .44603 .55842 .4391 Mtetra
.55842 .4391 .56458 .44603 .57631 .44228 .57018 .43532 Mtetra
.57018 .43532 .57631 .44228 .58808 .43852 .58199 .43152 Mtetra
.966 .663 .399 r
.58199 .43152 .58808 .43852 .60452 .63472 .5981 .6281 Mtetra
.646 .762 .934 r
.5981 .6281 .60452 .63472 .61713 .63114 .61075 .62449 Mtetra
.61075 .62449 .61713 .63114 .62981 .62755 .62347 .62086 Mtetra
.62347 .62086 .62981 .62755 .64254 .62393 .63624 .61722 Mtetra
.63624 .61722 .64254 .62393 .65533 .62031 .64907 .61356 Mtetra
.64907 .61356 .65533 .62031 .66818 .61666 .66196 .60989 Mtetra
.66196 .60989 .66818 .61666 .68109 .613 .67491 .60619 Mtetra
.67491 .60619 .68109 .613 .69405 .60932 .68791 .60248 Mtetra
.68791 .60248 .69405 .60932 .70708 .60562 .70098 .59875 Mtetra
.70098 .59875 .70708 .60562 .72017 .60191 .71411 .59501 Mtetra
.71411 .59501 .72017 .60191 .73331 .59818 .7273 .59125 Mtetra
.7273 .59125 .73331 .59818 .74652 .59443 .74055 .58747 Mtetra
.978 .718 .469 r
.74055 .58747 .74652 .59443 .75048 .45541 .74475 .44814 Mtetra
.658 .749 .918 r
.74475 .44814 .75048 .45541 .76326 .45148 .75757 .44417 Mtetra
.75757 .44417 .76326 .45148 .7761 .44753 .77045 .44019 Mtetra
.77045 .44019 .7761 .44753 .789 .44356 .78339 .43618 Mtetra
.78339 .43618 .789 .44356 .80195 .43957 .79638 .43216 Mtetra
.79638 .43216 .80195 .43957 .81496 .43557 .80943 .42813 Mtetra
.80943 .42813 .81496 .43557 .82803 .43154 .82255 .42407 Mtetra
.82255 .42407 .82803 .43154 .84116 .4275 .83572 .41999 Mtetra
.83572 .41999 .84116 .4275 .85435 .42344 .84895 .4159 Mtetra
.84895 .4159 .85435 .42344 .8676 .41937 .86224 .41179 Mtetra
.86224 .41179 .8676 .41937 .88091 .41527 .87559 .40766 Mtetra
.87559 .40766 .88091 .41527 .89428 .41115 .88901 .40351 Mtetra
.88901 .40351 .89428 .41115 .90771 .40702 .90249 .39934 Mtetra
.664 .741 .908 r
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49786 Mtetra
.30585 .49786 .31267 .50427 .32336 .5008 .31656 .49437 Mtetra
.31656 .49437 .32336 .5008 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49383 .33812 .48735 Mtetra
.33812 .48735 .34487 .49383 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36656 .48681 .35986 .48027 Mtetra
.35986 .48027 .36656 .48681 .37746 .48327 .3708 .47671 Mtetra
.3708 .47671 .37746 .48327 .38842 .47972 .38178 .47313 Mtetra
.38178 .47313 .38842 .47972 .39942 .47616 .39281 .46954 Mtetra
.39281 .46954 .39942 .47616 .41046 .47258 .40388 .46593 Mtetra
.40388 .46593 .41046 .47258 .42155 .46899 .415 .46231 Mtetra
.415 .46231 .42155 .46899 .43268 .46538 .42616 .45868 Mtetra
0 .021 .527 r
.42616 .45868 .43268 .46538 .44351 .47603 .43699 .46933 Mtetra
.663 .743 .91 r
.43699 .46933 .44351 .47603 .45479 .47241 .44829 .46568 Mtetra
.44829 .46568 .45479 .47241 .46611 .46877 .45965 .46201 Mtetra
.45965 .46201 .46611 .46877 .47748 .46511 .47105 .45833 Mtetra
.47105 .45833 .47748 .46511 .4889 .46144 .4825 .45463 Mtetra
.4825 .45463 .4889 .46144 .50036 .45776 .49399 .45091 Mtetra
.49399 .45091 .50036 .45776 .51188 .45406 .50554 .44718 Mtetra
.50554 .44718 .51188 .45406 .52344 .45034 .51713 .44344 Mtetra
.51713 .44344 .52344 .45034 .53505 .44661 .52877 .43968 Mtetra
.52877 .43968 .53505 .44661 .54671 .44286 .54047 .4359 Mtetra
.54047 .4359 .54671 .44286 .55842 .4391 .55221 .43211 Mtetra
.55221 .43211 .55842 .4391 .57018 .43532 .564 .4283 Mtetra
.564 .4283 .57018 .43532 .58199 .43152 .57584 .42447 Mtetra
.966 .663 .399 r
.57584 .42447 .58199 .43152 .5981 .6281 .59163 .62142 Mtetra
.646 .762 .934 r
.59163 .62142 .5981 .6281 .61075 .62449 .60432 .61778 Mtetra
.60432 .61778 .61075 .62449 .62347 .62086 .61707 .61413 Mtetra
.61707 .61413 .62347 .62086 .63624 .61722 .62989 .61045 Mtetra
.62989 .61045 .63624 .61722 .64907 .61356 .64276 .60676 Mtetra
.64276 .60676 .64907 .61356 .66196 .60989 .65568 .60305 Mtetra
.65568 .60305 .66196 .60989 .67491 .60619 .66867 .59933 Mtetra
.66867 .59933 .67491 .60619 .68791 .60248 .68172 .59559 Mtetra
.68172 .59559 .68791 .60248 .70098 .59875 .69483 .59183 Mtetra
.69483 .59183 .70098 .59875 .71411 .59501 .708 .58805 Mtetra
.708 .58805 .71411 .59501 .7273 .59125 .72123 .58426 Mtetra
.72123 .58426 .7273 .59125 .74055 .58747 .73453 .58045 Mtetra
.978 .718 .469 r
.73453 .58045 .74055 .58747 .74475 .44814 .73897 .4408 Mtetra
.658 .749 .918 r
.73897 .4408 .74475 .44814 .75757 .44417 .75183 .4368 Mtetra
.75183 .4368 .75757 .44417 .77045 .44019 .76475 .43278 Mtetra
.76475 .43278 .77045 .44019 .78339 .43618 .77773 .42875 Mtetra
.77773 .42875 .78339 .43618 .79638 .43216 .79076 .42469 Mtetra
.79076 .42469 .79638 .43216 .80943 .42813 .80386 .42062 Mtetra
.80386 .42062 .80943 .42813 .82255 .42407 .81701 .41653 Mtetra
.81701 .41653 .82255 .42407 .83572 .41999 .83023 .41242 Mtetra
.83023 .41242 .83572 .41999 .84895 .4159 .8435 .40829 Mtetra
.8435 .40829 .84895 .4159 .86224 .41179 .85684 .40415 Mtetra
.85684 .40415 .86224 .41179 .87559 .40766 .87024 .39998 Mtetra
.87024 .39998 .87559 .40766 .88901 .40351 .8837 .39579 Mtetra
.8837 .39579 .88901 .40351 .90249 .39934 .89722 .39159 Mtetra
.664 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .3708 .47671 .36408 .47009 Mtetra
.36408 .47009 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.37509 .46649 .38178 .47313 .39281 .46954 .38615 .46287 Mtetra
.38615 .46287 .39281 .46954 .40388 .46593 .39725 .45924 Mtetra
.39725 .45924 .40388 .46593 .415 .46231 .4084 .45559 Mtetra
.4084 .45559 .415 .46231 .42616 .45868 .41959 .45193 Mtetra
0 .021 .527 r
.41959 .45193 .42616 .45868 .43699 .46933 .43042 .46257 Mtetra
.663 .743 .91 r
.43042 .46257 .43699 .46933 .44829 .46568 .44175 .45889 Mtetra
.44175 .45889 .44829 .46568 .45965 .46201 .45313 .4552 Mtetra
.45313 .4552 .45965 .46201 .47105 .45833 .46456 .45149 Mtetra
.46456 .45149 .47105 .45833 .4825 .45463 .47604 .44776 Mtetra
.47604 .44776 .4825 .45463 .49399 .45091 .48757 .44402 Mtetra
.48757 .44402 .49399 .45091 .50554 .44718 .49915 .44026 Mtetra
.49915 .44026 .50554 .44718 .51713 .44344 .51077 .43648 Mtetra
.51077 .43648 .51713 .44344 .52877 .43968 .52245 .43269 Mtetra
.52245 .43269 .52877 .43968 .54047 .4359 .53417 .42888 Mtetra
.53417 .42888 .54047 .4359 .55221 .43211 .54595 .42506 Mtetra
.54595 .42506 .55221 .43211 .564 .4283 .55777 .42122 Mtetra
.55777 .42122 .564 .4283 .57584 .42447 .56965 .41736 Mtetra
.966 .663 .399 r
.56965 .41736 .57584 .42447 .59163 .62142 .5851 .61469 Mtetra
.646 .762 .934 r
.5851 .61469 .59163 .62142 .60432 .61778 .59784 .61102 Mtetra
.59784 .61102 .60432 .61778 .61707 .61413 .61063 .60733 Mtetra
.61063 .60733 .61707 .61413 .62989 .61045 .62348 .60363 Mtetra
.62348 .60363 .62989 .61045 .64276 .60676 .63639 .5999 Mtetra
.63639 .5999 .64276 .60676 .65568 .60305 .64936 .59616 Mtetra
.64936 .59616 .65568 .60305 .66867 .59933 .66239 .59241 Mtetra
.66239 .59241 .66867 .59933 .68172 .59559 .67548 .58863 Mtetra
.67548 .58863 .68172 .59559 .69483 .59183 .68863 .58484 Mtetra
.68863 .58484 .69483 .59183 .708 .58805 .70184 .58103 Mtetra
.70184 .58103 .708 .58805 .72123 .58426 .71511 .57721 Mtetra
.71511 .57721 .72123 .58426 .73453 .58045 .72845 .57336 Mtetra
.978 .718 .469 r
.72845 .57336 .73453 .58045 .73897 .4408 .73315 .4334 Mtetra
.658 .749 .918 r
.73315 .4334 .73897 .4408 .75183 .4368 .74605 .42937 Mtetra
.74605 .42937 .75183 .4368 .76475 .43278 .75901 .42532 Mtetra
.75901 .42532 .76475 .43278 .77773 .42875 .77202 .42125 Mtetra
.77202 .42125 .77773 .42875 .79076 .42469 .7851 .41716 Mtetra
.7851 .41716 .79076 .42469 .80386 .42062 .79824 .41305 Mtetra
.79824 .41305 .80386 .42062 .81701 .41653 .81144 .40893 Mtetra
.81144 .40893 .81701 .41653 .83023 .41242 .8247 .40478 Mtetra
.8247 .40478 .83023 .41242 .8435 .40829 .83801 .40062 Mtetra
.83801 .40062 .8435 .40829 .85684 .40415 .85139 .39644 Mtetra
.85139 .39644 .85684 .40415 .87024 .39998 .86484 .39224 Mtetra
.86484 .39224 .87024 .39998 .8837 .39579 .87834 .38802 Mtetra
.87834 .38802 .8837 .39579 .89722 .39159 .89191 .38377 Mtetra
.664 .741 .908 r
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.34633 .46705 .35312 .47368 .36408 .47009 .35732 .46343 Mtetra
.35732 .46343 .36408 .47009 .37509 .46649 .36835 .4598 Mtetra
.36835 .4598 .37509 .46649 .38615 .46287 .37944 .45615 Mtetra
.37944 .45615 .38615 .46287 .39725 .45924 .39057 .45249 Mtetra
.39057 .45249 .39725 .45924 .4084 .45559 .40174 .44881 Mtetra
.40174 .44881 .4084 .45559 .41959 .45193 .41296 .44512 Mtetra
0 .021 .527 r
.41296 .44512 .41959 .45193 .43042 .46257 .42379 .45577 Mtetra
.663 .743 .91 r
.42379 .45577 .43042 .46257 .44175 .45889 .43516 .45206 Mtetra
.43516 .45206 .44175 .45889 .45313 .4552 .44657 .44833 Mtetra
.44657 .44833 .45313 .4552 .46456 .45149 .45803 .44459 Mtetra
.45803 .44459 .46456 .45149 .47604 .44776 .46954 .44084 Mtetra
.46954 .44084 .47604 .44776 .48757 .44402 .4811 .43706 Mtetra
.4811 .43706 .48757 .44402 .49915 .44026 .49271 .43327 Mtetra
.49271 .43327 .49915 .44026 .51077 .43648 .50437 .42947 Mtetra
.50437 .42947 .51077 .43648 .52245 .43269 .51607 .42565 Mtetra
.51607 .42565 .52245 .43269 .53417 .42888 .52783 .42181 Mtetra
.52783 .42181 .53417 .42888 .54595 .42506 .53964 .41796 Mtetra
.53964 .41796 .54595 .42506 .55777 .42122 .5515 .41409 Mtetra
.5515 .41409 .55777 .42122 .56965 .41736 .56341 .4102 Mtetra
.966 .663 .399 r
.56341 .4102 .56965 .41736 .5851 .61469 .57852 .6079 Mtetra
.646 .762 .934 r
.57852 .6079 .5851 .61469 .59784 .61102 .59129 .6042 Mtetra
.59129 .6042 .59784 .61102 .61063 .60733 .60412 .60048 Mtetra
.60412 .60048 .61063 .60733 .62348 .60363 .61702 .59674 Mtetra
.61702 .59674 .62348 .60363 .63639 .5999 .62997 .59299 Mtetra
.62997 .59299 .63639 .5999 .64936 .59616 .64298 .58922 Mtetra
.64298 .58922 .64936 .59616 .66239 .59241 .65605 .58543 Mtetra
.65605 .58543 .66239 .59241 .67548 .58863 .66918 .58162 Mtetra
.66918 .58162 .67548 .58863 .68863 .58484 .68237 .5778 Mtetra
.68237 .5778 .68863 .58484 .70184 .58103 .69563 .57395 Mtetra
.69563 .57395 .70184 .58103 .71511 .57721 .70894 .57009 Mtetra
.70894 .57009 .71511 .57721 .72845 .57336 .72232 .56621 Mtetra
.978 .718 .469 r
.72232 .56621 .72845 .57336 .73315 .4334 .72727 .42594 Mtetra
.658 .749 .918 r
.72727 .42594 .73315 .4334 .74605 .42937 .74021 .42188 Mtetra
.74021 .42188 .74605 .42937 .75901 .42532 .75321 .41779 Mtetra
.75321 .41779 .75901 .42532 .77202 .42125 .76627 .41369 Mtetra
.76627 .41369 .77202 .42125 .7851 .41716 .77939 .40957 Mtetra
.77939 .40957 .7851 .41716 .79824 .41305 .79257 .40542 Mtetra
.79257 .40542 .79824 .41305 .81144 .40893 .80581 .40126 Mtetra
.80581 .40126 .81144 .40893 .8247 .40478 .81911 .39708 Mtetra
.81911 .39708 .8247 .40478 .83801 .40062 .83248 .39288 Mtetra
.83248 .39288 .83801 .40062 .85139 .39644 .8459 .38867 Mtetra
.8459 .38867 .85139 .39644 .86484 .39224 .85939 .38443 Mtetra
.85939 .38443 .86484 .39224 .87834 .38802 .87294 .38017 Mtetra
.87294 .38017 .87834 .38802 .89191 .38377 .88655 .37589 Mtetra
.664 .741 .908 r
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.3285 .46399 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45671 Mtetra
.3505 .45671 .35732 .46343 .36835 .4598 .36156 .45306 Mtetra
.36156 .45306 .36835 .4598 .37944 .45615 .37268 .44938 Mtetra
.37268 .44938 .37944 .45615 .39057 .45249 .38383 .44569 Mtetra
.38383 .44569 .39057 .45249 .40174 .44881 .39504 .44199 Mtetra
.39504 .44199 .40174 .44881 .41296 .44512 .40629 .43827 Mtetra
0 .021 .527 r
.40629 .43827 .41296 .44512 .42379 .45577 .41711 .44891 Mtetra
.663 .743 .91 r
.41711 .44891 .42379 .45577 .43516 .45206 .42851 .44517 Mtetra
.42851 .44517 .43516 .45206 .44657 .44833 .43995 .44141 Mtetra
.43995 .44141 .44657 .44833 .45803 .44459 .45145 .43764 Mtetra
.45145 .43764 .45803 .44459 .46954 .44084 .46299 .43386 Mtetra
.46299 .43386 .46954 .44084 .4811 .43706 .47458 .43006 Mtetra
.47458 .43006 .4811 .43706 .49271 .43327 .48622 .42624 Mtetra
.48622 .42624 .49271 .43327 .50437 .42947 .49791 .4224 Mtetra
.49791 .4224 .50437 .42947 .51607 .42565 .50965 .41855 Mtetra
.50965 .41855 .51607 .42565 .52783 .42181 .52144 .41468 Mtetra
.52144 .41468 .52783 .42181 .53964 .41796 .53328 .4108 Mtetra
.53328 .4108 .53964 .41796 .5515 .41409 .54517 .4069 Mtetra
.54517 .4069 .5515 .41409 .56341 .4102 .55712 .40298 Mtetra
.966 .663 .399 r
.55712 .40298 .56341 .4102 .57852 .6079 .57188 .60105 Mtetra
.646 .762 .934 r
.57188 .60105 .57852 .6079 .59129 .6042 .5847 .59732 Mtetra
.5847 .59732 .59129 .6042 .60412 .60048 .59757 .59357 Mtetra
.59757 .59357 .60412 .60048 .61702 .59674 .6105 .5898 Mtetra
.6105 .5898 .61702 .59674 .62997 .59299 .62349 .58601 Mtetra
.62349 .58601 .62997 .59299 .64298 .58922 .63654 .58221 Mtetra
.63654 .58221 .64298 .58922 .65605 .58543 .64965 .57839 Mtetra
.64965 .57839 .65605 .58543 .66918 .58162 .66282 .57455 Mtetra
.66282 .57455 .66918 .58162 .68237 .5778 .67606 .57069 Mtetra
.67606 .57069 .68237 .5778 .69563 .57395 .68936 .56681 Mtetra
.68936 .56681 .69563 .57395 .70894 .57009 .70272 .56292 Mtetra
.70272 .56292 .70894 .57009 .72232 .56621 .71614 .55901 Mtetra
.978 .718 .469 r
.71614 .55901 .72232 .56621 .72727 .42594 .72135 .41842 Mtetra
.658 .749 .918 r
.72135 .41842 .72727 .42594 .74021 .42188 .73433 .41432 Mtetra
.73433 .41432 .74021 .42188 .75321 .41779 .74737 .4102 Mtetra
.74737 .4102 .75321 .41779 .76627 .41369 .76047 .40606 Mtetra
.76047 .40606 .76627 .41369 .77939 .40957 .77363 .4019 Mtetra
.77363 .4019 .77939 .40957 .79257 .40542 .78686 .39773 Mtetra
.78686 .39773 .79257 .40542 .80581 .40126 .80014 .39353 Mtetra
.80014 .39353 .80581 .40126 .81911 .39708 .81349 .38932 Mtetra
.81349 .38932 .81911 .39708 .83248 .39288 .82689 .38508 Mtetra
.82689 .38508 .83248 .39288 .8459 .38867 .84036 .38083 Mtetra
.84036 .38083 .8459 .38867 .85939 .38443 .85389 .37655 Mtetra
.85389 .37655 .85939 .38443 .87294 .38017 .86749 .37226 Mtetra
.86749 .37226 .87294 .38017 .88655 .37589 .88115 .36794 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.33258 .45362 .33948 .46036 .3505 .45671 .34363 .44995 Mtetra
.34363 .44995 .3505 .45671 .36156 .45306 .35472 .44626 Mtetra
.35472 .44626 .36156 .45306 .37268 .44938 .36586 .44256 Mtetra
.36586 .44256 .37268 .44938 .38383 .44569 .37705 .43884 Mtetra
.37705 .43884 .38383 .44569 .39504 .44199 .38828 .4351 Mtetra
.38828 .4351 .39504 .44199 .40629 .43827 .39956 .43136 Mtetra
0 .021 .527 r
.39956 .43136 .40629 .43827 .41711 .44891 .41039 .44199 Mtetra
.663 .743 .91 r
.41039 .44199 .41711 .44891 .42851 .44517 .42181 .43823 Mtetra
.42181 .43823 .42851 .44517 .43995 .44141 .43329 .43444 Mtetra
.43329 .43444 .43995 .44141 .45145 .43764 .44481 .43064 Mtetra
.44481 .43064 .45145 .43764 .46299 .43386 .45638 .42683 Mtetra
.45638 .42683 .46299 .43386 .47458 .43006 .468 .42299 Mtetra
.468 .42299 .47458 .43006 .48622 .42624 .47968 .41915 Mtetra
.47968 .41915 .48622 .42624 .49791 .4224 .4914 .41528 Mtetra
.4914 .41528 .49791 .4224 .50965 .41855 .50317 .4114 Mtetra
.50317 .4114 .50965 .41855 .52144 .41468 .51499 .4075 Mtetra
.51499 .4075 .52144 .41468 .53328 .4108 .52687 .40358 Mtetra
.52687 .40358 .53328 .4108 .54517 .4069 .5388 .39965 Mtetra
.5388 .39965 .54517 .4069 .55712 .40298 .55077 .3957 Mtetra
.966 .663 .399 r
.55077 .3957 .55712 .40298 .57188 .60105 .56519 .59414 Mtetra
.646 .762 .934 r
.56519 .59414 .57188 .60105 .5847 .59732 .57804 .59038 Mtetra
.57804 .59038 .5847 .59732 .59757 .59357 .59095 .58659 Mtetra
.59095 .58659 .59757 .59357 .6105 .5898 .60392 .58279 Mtetra
.60392 .58279 .6105 .5898 .62349 .58601 .61695 .57897 Mtetra
.61695 .57897 .62349 .58601 .63654 .58221 .63005 .57514 Mtetra
.63005 .57514 .63654 .58221 .64965 .57839 .6432 .57128 Mtetra
.6432 .57128 .64965 .57839 .66282 .57455 .65642 .56741 Mtetra
.65642 .56741 .66282 .57455 .67606 .57069 .66969 .56352 Mtetra
.66969 .56352 .67606 .57069 .68936 .56681 .68303 .55961 Mtetra
.68303 .55961 .68936 .56681 .70272 .56292 .69644 .55568 Mtetra
.69644 .55568 .70272 .56292 .71614 .55901 .70991 .55173 Mtetra
.978 .718 .469 r
.70991 .55173 .71614 .55901 .72135 .41842 .71537 .41084 Mtetra
.658 .749 .918 r
.71537 .41084 .72135 .41842 .73433 .41432 .72839 .4067 Mtetra
.72839 .4067 .73433 .41432 .74737 .4102 .74148 .40255 Mtetra
.74148 .40255 .74737 .4102 .76047 .40606 .75462 .39837 Mtetra
.75462 .39837 .76047 .40606 .77363 .4019 .76783 .39418 Mtetra
.76783 .39418 .77363 .4019 .78686 .39773 .78109 .38997 Mtetra
.78109 .38997 .78686 .39773 .80014 .39353 .79442 .38573 Mtetra
.79442 .38573 .80014 .39353 .81349 .38932 .80781 .38148 Mtetra
.80781 .38148 .81349 .38932 .82689 .38508 .82126 .37721 Mtetra
.82126 .37721 .82689 .38508 .84036 .38083 .83477 .37292 Mtetra
.83477 .37292 .84036 .38083 .85389 .37655 .84835 .36861 Mtetra
.84835 .36861 .85389 .37655 .86749 .37226 .86199 .36428 Mtetra
.86199 .36428 .86749 .37226 .88115 .36794 .8757 .35993 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
.3146 .45051 .32158 .45728 .33258 .45362 .32563 .44683 Mtetra
.32563 .44683 .33258 .45362 .34363 .44995 .3367 .44313 Mtetra
.3367 .44313 .34363 .44995 .35472 .44626 .34783 .43941 Mtetra
.34783 .43941 .35472 .44626 .36586 .44256 .35899 .43568 Mtetra
.35899 .43568 .36586 .44256 .37705 .43884 .37021 .43193 Mtetra
.37021 .43193 .37705 .43884 .38828 .4351 .38147 .42817 Mtetra
.38147 .42817 .38828 .4351 .39956 .43136 .39278 .42439 Mtetra
0 .021 .527 r
.39278 .42439 .39956 .43136 .41039 .44199 .4036 .43503 Mtetra
.663 .743 .91 r
.4036 .43503 .41039 .44199 .42181 .43823 .41506 .43123 Mtetra
.41506 .43123 .42181 .43823 .43329 .43444 .42657 .42741 Mtetra
.42657 .42741 .43329 .43444 .44481 .43064 .43812 .42358 Mtetra
.43812 .42358 .44481 .43064 .45638 .42683 .44973 .41974 Mtetra
.44973 .41974 .45638 .42683 .468 .42299 .46138 .41588 Mtetra
.46138 .41588 .468 .42299 .47968 .41915 .47308 .412 Mtetra
.47308 .412 .47968 .41915 .4914 .41528 .48484 .4081 Mtetra
.48484 .4081 .4914 .41528 .50317 .4114 .49664 .40419 Mtetra
.49664 .40419 .50317 .4114 .51499 .4075 .5085 .40026 Mtetra
.5085 .40026 .51499 .4075 .52687 .40358 .52041 .39631 Mtetra
.52041 .39631 .52687 .40358 .5388 .39965 .53237 .39235 Mtetra
.53237 .39235 .5388 .39965 .55077 .3957 .54438 .38837 Mtetra
.966 .663 .399 r
.54438 .38837 .55077 .3957 .56519 .59414 .55844 .58718 Mtetra
.646 .762 .934 r
.55844 .58718 .56519 .59414 .57804 .59038 .57133 .58338 Mtetra
.57133 .58338 .57804 .59038 .59095 .58659 .58428 .57956 Mtetra
.58428 .57956 .59095 .58659 .60392 .58279 .59729 .57573 Mtetra
.59729 .57573 .60392 .58279 .61695 .57897 .61036 .57188 Mtetra
.61036 .57188 .61695 .57897 .63005 .57514 .6235 .56801 Mtetra
.6235 .56801 .63005 .57514 .6432 .57128 .63669 .56412 Mtetra
.63669 .56412 .6432 .57128 .65642 .56741 .64995 .56021 Mtetra
.64995 .56021 .65642 .56741 .66969 .56352 .66327 .55629 Mtetra
.66327 .55629 .66969 .56352 .68303 .55961 .67666 .55234 Mtetra
.67666 .55234 .68303 .55961 .69644 .55568 .6901 .54838 Mtetra
.6901 .54838 .69644 .55568 .70991 .55173 .70361 .5444 Mtetra
.978 .718 .469 r
.70361 .5444 .70991 .55173 .71537 .41084 .70935 .40319 Mtetra
.658 .749 .918 r
.70935 .40319 .71537 .41084 .72839 .4067 .72241 .39902 Mtetra
.72241 .39902 .72839 .4067 .74148 .40255 .73554 .39483 Mtetra
.73554 .39483 .74148 .40255 .75462 .39837 .74872 .39062 Mtetra
.74872 .39062 .75462 .39837 .76783 .39418 .76197 .38639 Mtetra
.76197 .38639 .76783 .39418 .78109 .38997 .77528 .38214 Mtetra
.77528 .38214 .78109 .38997 .79442 .38573 .78865 .37787 Mtetra
.78865 .37787 .79442 .38573 .80781 .38148 .80208 .37358 Mtetra
.80208 .37358 .80781 .38148 .82126 .37721 .81558 .36927 Mtetra
.81558 .36927 .82126 .37721 .83477 .37292 .82914 .36495 Mtetra
.82914 .36495 .83477 .37292 .84835 .36861 .84276 .3606 Mtetra
.84276 .3606 .84835 .36861 .86199 .36428 .85645 .35623 Mtetra
.85645 .35623 .86199 .36428 .8757 .35993 .8702 .35184 Mtetra
.664 .741 .908 r
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.28559 .45108 .29268 .45784 .30361 .45418 .29655 .4474 Mtetra
.29655 .4474 .30361 .45418 .3146 .45051 .30756 .4437 Mtetra
.30756 .4437 .3146 .45051 .32563 .44683 .31862 .43998 Mtetra
.31862 .43998 .32563 .44683 .3367 .44313 .32973 .43626 Mtetra
.32973 .43626 .3367 .44313 .34783 .43941 .34088 .43251 Mtetra
.34088 .43251 .34783 .43941 .35899 .43568 .35207 .42875 Mtetra
.35207 .42875 .35899 .43568 .37021 .43193 .36332 .42497 Mtetra
.36332 .42497 .37021 .43193 .38147 .42817 .37461 .42118 Mtetra
.37461 .42118 .38147 .42817 .39278 .42439 .38595 .41737 Mtetra
0 .021 .527 r
.38595 .41737 .39278 .42439 .4036 .43503 .39677 .428 Mtetra
.663 .743 .91 r
.39677 .428 .4036 .43503 .41506 .43123 .40826 .42418 Mtetra
.40826 .42418 .41506 .43123 .42657 .42741 .41979 .42033 Mtetra
.41979 .42033 .42657 .42741 .43812 .42358 .43138 .41647 Mtetra
.43138 .41647 .43812 .42358 .44973 .41974 .44301 .41259 Mtetra
.44301 .41259 .44973 .41974 .46138 .41588 .4547 .4087 Mtetra
.4547 .4087 .46138 .41588 .47308 .412 .46644 .40479 Mtetra
.46644 .40479 .47308 .412 .48484 .4081 .47822 .40086 Mtetra
.47822 .40086 .48484 .4081 .49664 .40419 .49006 .39692 Mtetra
.49006 .39692 .49664 .40419 .5085 .40026 .50195 .39296 Mtetra
.50195 .39296 .5085 .40026 .52041 .39631 .51389 .38898 Mtetra
.51389 .38898 .52041 .39631 .53237 .39235 .52589 .38498 Mtetra
.52589 .38498 .53237 .39235 .54438 .38837 .53793 .38097 Mtetra
.966 .663 .399 r
.53793 .38097 .54438 .38837 .55844 .58718 .55163 .58015 Mtetra
.646 .762 .934 r
.55163 .58015 .55844 .58718 .57133 .58338 .56456 .57632 Mtetra
.56456 .57632 .57133 .58338 .58428 .57956 .57755 .57247 Mtetra
.57755 .57247 .58428 .57956 .59729 .57573 .5906 .5686 Mtetra
.5906 .5686 .59729 .57573 .61036 .57188 .60372 .56472 Mtetra
.60372 .56472 .61036 .57188 .6235 .56801 .61689 .56081 Mtetra
.61689 .56081 .6235 .56801 .63669 .56412 .63013 .55689 Mtetra
.63013 .55689 .63669 .56412 .64995 .56021 .64343 .55295 Mtetra
.64343 .55295 .64995 .56021 .66327 .55629 .65679 .54899 Mtetra
.65679 .54899 .66327 .55629 .67666 .55234 .67022 .54501 Mtetra
.67022 .54501 .67666 .55234 .6901 .54838 .68371 .54101 Mtetra
.68371 .54101 .6901 .54838 .70361 .5444 .69727 .537 Mtetra
.978 .718 .469 r
.69727 .537 .70361 .5444 .70935 .40319 .70327 .39547 Mtetra
.658 .749 .918 r
.70327 .39547 .70935 .40319 .72241 .39902 .71638 .39126 Mtetra
.71638 .39126 .72241 .39902 .73554 .39483 .72954 .38704 Mtetra
.72954 .38704 .73554 .39483 .74872 .39062 .74277 .38279 Mtetra
.74277 .38279 .74872 .39062 .76197 .38639 .75606 .37853 Mtetra
.75606 .37853 .76197 .38639 .77528 .38214 .76942 .37424 Mtetra
.76942 .37424 .77528 .38214 .78865 .37787 .78283 .36994 Mtetra
.78283 .36994 .78865 .37787 .80208 .37358 .79631 .36561 Mtetra
.79631 .36561 .80208 .37358 .81558 .36927 .80985 .36127 Mtetra
.80985 .36127 .81558 .36927 .82914 .36495 .82345 .3569 Mtetra
.82345 .3569 .82914 .36495 .84276 .3606 .83712 .35252 Mtetra
.83712 .35252 .84276 .3606 .85645 .35623 .85085 .34811 Mtetra
.85085 .34811 .85645 .35623 .8702 .35184 .86465 .34368 Mtetra
.664 .741 .908 r
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .4437 .30048 .43683 Mtetra
.30048 .43683 .30756 .4437 .31862 .43998 .31156 .43309 Mtetra
.31156 .43309 .31862 .43998 .32973 .43626 .32269 .42933 Mtetra
.32269 .42933 .32973 .43626 .34088 .43251 .33387 .42556 Mtetra
.33387 .42556 .34088 .43251 .35207 .42875 .3451 .42177 Mtetra
.3451 .42177 .35207 .42875 .36332 .42497 .35637 .41796 Mtetra
.35637 .41796 .36332 .42497 .37461 .42118 .3677 .41414 Mtetra
.3677 .41414 .37461 .42118 .38595 .41737 .37907 .4103 Mtetra
0 .021 .527 r
.37907 .4103 .38595 .41737 .39677 .428 .38988 .42092 Mtetra
.663 .743 .91 r
.38988 .42092 .39677 .428 .40826 .42418 .4014 .41707 Mtetra
.4014 .41707 .40826 .42418 .41979 .42033 .41297 .41319 Mtetra
.41297 .41319 .41979 .42033 .43138 .41647 .42458 .4093 Mtetra
.42458 .4093 .43138 .41647 .44301 .41259 .43625 .40539 Mtetra
.43625 .40539 .44301 .41259 .4547 .4087 .44797 .40147 Mtetra
.44797 .40147 .4547 .4087 .46644 .40479 .45974 .39753 Mtetra
.45974 .39753 .46644 .40479 .47822 .40086 .47156 .39357 Mtetra
.47156 .39357 .47822 .40086 .49006 .39692 .48343 .38959 Mtetra
.48343 .38959 .49006 .39692 .50195 .39296 .49535 .3856 Mtetra
.49535 .3856 .50195 .39296 .51389 .38898 .50733 .38159 Mtetra
.50733 .38159 .51389 .38898 .52589 .38498 .51936 .37756 Mtetra
.51936 .37756 .52589 .38498 .53793 .38097 .53144 .37351 Mtetra
.966 .663 .399 r
.53144 .37351 .53793 .38097 .55163 .58015 .54476 .57306 Mtetra
.646 .762 .934 r
.54476 .57306 .55163 .58015 .56456 .57632 .55773 .5692 Mtetra
.55773 .5692 .56456 .57632 .57755 .57247 .57076 .56532 Mtetra
.57076 .56532 .57755 .57247 .5906 .5686 .58386 .56142 Mtetra
.58386 .56142 .5906 .5686 .60372 .56472 .59701 .5575 Mtetra
.59701 .5575 .60372 .56472 .61689 .56081 .61023 .55356 Mtetra
.61023 .55356 .61689 .56081 .63013 .55689 .62351 .5496 Mtetra
.62351 .5496 .63013 .55689 .64343 .55295 .63685 .54563 Mtetra
.63685 .54563 .64343 .55295 .65679 .54899 .65026 .54163 Mtetra
.65026 .54163 .65679 .54899 .67022 .54501 .66373 .53762 Mtetra
.66373 .53762 .67022 .54501 .68371 .54101 .67726 .53358 Mtetra
.67726 .53358 .68371 .54101 .69727 .537 .69087 .52953 Mtetra
.978 .718 .469 r
.69087 .52953 .69727 .537 .70327 .39547 .69714 .38769 Mtetra
.658 .749 .918 r
.69714 .38769 .70327 .39547 .71638 .39126 .71029 .38345 Mtetra
.71029 .38345 .71638 .39126 .72954 .38704 .7235 .37919 Mtetra
.7235 .37919 .72954 .38704 .74277 .38279 .73677 .3749 Mtetra
.73677 .3749 .74277 .38279 .75606 .37853 .7501 .3706 Mtetra
.7501 .3706 .75606 .37853 .76942 .37424 .7635 .36628 Mtetra
.7635 .36628 .76942 .37424 .78283 .36994 .77696 .36194 Mtetra
.77696 .36194 .78283 .36994 .79631 .36561 .79048 .35757 Mtetra
.79048 .35757 .79631 .36561 .80985 .36127 .80407 .35319 Mtetra
.80407 .35319 .80985 .36127 .82345 .3569 .81772 .34879 Mtetra
.81772 .34879 .82345 .3569 .83712 .35252 .83143 .34436 Mtetra
.83143 .34436 .83712 .35252 .85085 .34811 .84521 .33992 Mtetra
.84521 .33992 .85085 .34811 .86465 .34368 .85906 .33545 Mtetra
.664 .741 .908 r
.23846 .44853 .24574 .45531 .25659 .45164 .24934 .44484 Mtetra
.24934 .44484 .25659 .45164 .2675 .44796 .26027 .44113 Mtetra
.26027 .44113 .2675 .44796 .27844 .44427 .27124 .4374 Mtetra
.27124 .4374 .27844 .44427 .28944 .44056 .28226 .43366 Mtetra
.28226 .43366 .28944 .44056 .30048 .43683 .29333 .42991 Mtetra
.29333 .42991 .30048 .43683 .31156 .43309 .30445 .42614 Mtetra
.30445 .42614 .31156 .43309 .32269 .42933 .31561 .42235 Mtetra
.31561 .42235 .32269 .42933 .33387 .42556 .32681 .41855 Mtetra
.32681 .41855 .33387 .42556 .3451 .42177 .33807 .41473 Mtetra
.33807 .41473 .3451 .42177 .35637 .41796 .34937 .41089 Mtetra
.34937 .41089 .35637 .41796 .3677 .41414 .36072 .40704 Mtetra
.36072 .40704 .3677 .41414 .37907 .4103 .37213 .40317 Mtetra
.37213 .40317 .37907 .4103 .38988 .42092 .38357 .39928 Mtetra
.619 .516 .715 r
.38357 .39928 .38988 .42092 .4014 .41707 .39507 .39538 Mtetra
.39507 .39538 .4014 .41707 .41297 .41319 .40662 .39146 Mtetra
.40662 .39146 .41297 .41319 .42458 .4093 .41822 .38753 Mtetra
.41822 .38753 .42458 .4093 .43625 .40539 .42986 .38358 Mtetra
.42986 .38358 .43625 .40539 .44797 .40147 .44156 .37961 Mtetra
.44156 .37961 .44797 .40147 .45974 .39753 .45331 .37562 Mtetra
.45331 .37562 .45974 .39753 .47156 .39357 .46511 .37161 Mtetra
.46511 .37161 .47156 .39357 .48343 .38959 .47696 .36759 Mtetra
.47696 .36759 .48343 .38959 .49535 .3856 .48886 .36355 Mtetra
.48886 .36355 .49535 .3856 .50733 .38159 .50082 .3595 Mtetra
.50082 .3595 .50733 .38159 .51936 .37756 .51283 .35542 Mtetra
.51283 .35542 .51936 .37756 .53144 .37351 .52489 .35133 Mtetra
.52489 .35133 .53144 .37351 .54476 .57306 .537 .34722 Mtetra
.554 .346 .553 r
.537 .34722 .54476 .57306 .55773 .5692 .54917 .34309 Mtetra
.54917 .34309 .55773 .5692 .57076 .56532 .56139 .33894 Mtetra
.56139 .33894 .57076 .56532 .58386 .56142 .57366 .33478 Mtetra
.57366 .33478 .58386 .56142 .59701 .5575 .58599 .33059 Mtetra
.58599 .33059 .59701 .5575 .61023 .55356 .59838 .32639 Mtetra
.59838 .32639 .61023 .55356 .62351 .5496 .61082 .32217 Mtetra
.61082 .32217 .62351 .5496 .63685 .54563 .62331 .31793 Mtetra
.62331 .31793 .63685 .54563 .65026 .54163 .63586 .31367 Mtetra
.63586 .31367 .65026 .54163 .66373 .53762 .64847 .30939 Mtetra
.64847 .30939 .66373 .53762 .67726 .53358 .66113 .30509 Mtetra
.66113 .30509 .67726 .53358 .69087 .52953 .67385 .30078 Mtetra
.542 .337 .553 r
.67385 .30078 .69087 .52953 .69714 .38769 .68702 .30384 Mtetra
.569 .381 .588 r
.68702 .30384 .69714 .38769 .71029 .38345 .69989 .29949 Mtetra
.69989 .29949 .71029 .38345 .7235 .37919 .71281 .29512 Mtetra
.71281 .29512 .7235 .37919 .73677 .3749 .7258 .29073 Mtetra
.7258 .29073 .73677 .3749 .7501 .3706 .73884 .28632 Mtetra
.73884 .28632 .7501 .3706 .7635 .36628 .75195 .28189 Mtetra
.75195 .28189 .7635 .36628 .77696 .36194 .76512 .27744 Mtetra
.76512 .27744 .77696 .36194 .79048 .35757 .77834 .27297 Mtetra
.77834 .27297 .79048 .35757 .80407 .35319 .79163 .26848 Mtetra
.79163 .26848 .80407 .35319 .81772 .34879 .80498 .26397 Mtetra
.80498 .26397 .81772 .34879 .83143 .34436 .81839 .25944 Mtetra
.81839 .25944 .83143 .34436 .84521 .33992 .83186 .25488 Mtetra
.83186 .25488 .84521 .33992 .85906 .33545 .8454 .25031 Mtetra
.664 .741 .908 r
.23112 .4417 .23846 .44853 .24934 .44484 .24203 .43798 Mtetra
.24203 .43798 .24934 .44484 .26027 .44113 .25299 .43424 Mtetra
.25299 .43424 .26027 .44113 .27124 .4374 .26399 .43049 Mtetra
.26399 .43049 .27124 .4374 .28226 .43366 .27504 .42672 Mtetra
.27504 .42672 .28226 .43366 .29333 .42991 .28613 .42293 Mtetra
.28613 .42293 .29333 .42991 .30445 .42614 .29727 .41913 Mtetra
.29727 .41913 .30445 .42614 .31561 .42235 .30846 .41532 Mtetra
.30846 .41532 .31561 .42235 .32681 .41855 .3197 .41148 Mtetra
.3197 .41148 .32681 .41855 .33807 .41473 .33099 .40763 Mtetra
.33099 .40763 .33807 .41473 .34937 .41089 .34232 .40377 Mtetra
.34232 .40377 .34937 .41089 .36072 .40704 .3537 .39988 Mtetra
.3537 .39988 .36072 .40704 .37213 .40317 .36513 .39598 Mtetra
.36513 .39598 .37213 .40317 .38357 .39928 .37661 .39207 Mtetra
.37661 .39207 .38357 .39928 .39507 .39538 .38814 .38814 Mtetra
.38814 .38814 .39507 .39538 .40662 .39146 .39972 .38419 Mtetra
.39972 .38419 .40662 .39146 .41822 .38753 .41135 .38022 Mtetra
.41135 .38022 .41822 .38753 .42986 .38358 .42302 .37623 Mtetra
.42302 .37623 .42986 .38358 .44156 .37961 .43475 .37223 Mtetra
.43475 .37223 .44156 .37961 .45331 .37562 .44654 .36821 Mtetra
.44654 .36821 .45331 .37562 .46511 .37161 .45837 .36418 Mtetra
.45837 .36418 .46511 .37161 .47696 .36759 .47025 .36012 Mtetra
.47025 .36012 .47696 .36759 .48886 .36355 .48219 .35605 Mtetra
.48219 .35605 .48886 .36355 .50082 .3595 .49418 .35196 Mtetra
.49418 .35196 .50082 .3595 .51283 .35542 .50622 .34785 Mtetra
.50622 .34785 .51283 .35542 .52489 .35133 .51831 .34373 Mtetra
.51831 .34373 .52489 .35133 .537 .34722 .53046 .33958 Mtetra
.53046 .33958 .537 .34722 .54917 .34309 .54266 .33542 Mtetra
.54266 .33542 .54917 .34309 .56139 .33894 .55492 .33124 Mtetra
.55492 .33124 .56139 .33894 .57366 .33478 .56723 .32704 Mtetra
.56723 .32704 .57366 .33478 .58599 .33059 .5796 .32282 Mtetra
.5796 .32282 .58599 .33059 .59838 .32639 .59202 .31858 Mtetra
.59202 .31858 .59838 .32639 .61082 .32217 .60449 .31433 Mtetra
.60449 .31433 .61082 .32217 .62331 .31793 .61703 .31005 Mtetra
.61703 .31005 .62331 .31793 .63586 .31367 .62962 .30576 Mtetra
.62962 .30576 .63586 .31367 .64847 .30939 .64226 .30144 Mtetra
.64226 .30144 .64847 .30939 .66113 .30509 .65497 .29711 Mtetra
.65497 .29711 .66113 .30509 .67385 .30078 .66773 .29276 Mtetra
.329 .576 .931 r
.66773 .29276 .67385 .30078 .68702 .30384 .68092 .2958 Mtetra
.663 .742 .909 r
.68092 .2958 .68702 .30384 .69989 .29949 .69382 .29141 Mtetra
.69382 .29141 .69989 .29949 .71281 .29512 .70679 .287 Mtetra
.70679 .287 .71281 .29512 .7258 .29073 .71982 .28258 Mtetra
.71982 .28258 .7258 .29073 .73884 .28632 .73291 .27813 Mtetra
.73291 .27813 .73884 .28632 .75195 .28189 .74605 .27366 Mtetra
.74605 .27366 .75195 .28189 .76512 .27744 .75926 .26917 Mtetra
.75926 .26917 .76512 .27744 .77834 .27297 .77253 .26466 Mtetra
.77253 .26466 .77834 .27297 .79163 .26848 .78586 .26013 Mtetra
.78586 .26013 .79163 .26848 .80498 .26397 .79925 .25558 Mtetra
.79925 .25558 .80498 .26397 .81839 .25944 .81271 .25101 Mtetra
.81271 .25101 .81839 .25944 .83186 .25488 .82623 .24642 Mtetra
.82623 .24642 .83186 .25488 .8454 .25031 .83981 .2418 Mtetra
.664 .741 .908 r
.22373 .43482 .23112 .4417 .24203 .43798 .23467 .43107 Mtetra
.23467 .43107 .24203 .43798 .25299 .43424 .24565 .4273 Mtetra
.24565 .4273 .25299 .43424 .26399 .43049 .25668 .42352 Mtetra
.25668 .42352 .26399 .43049 .27504 .42672 .26775 .41972 Mtetra
.26775 .41972 .27504 .42672 .28613 .42293 .27888 .4159 Mtetra
.27888 .4159 .28613 .42293 .29727 .41913 .29005 .41207 Mtetra
.29005 .41207 .29727 .41913 .30846 .41532 .30127 .40823 Mtetra
.30127 .40823 .30846 .41532 .3197 .41148 .31253 .40436 Mtetra
.31253 .40436 .3197 .41148 .33099 .40763 .32384 .40048 Mtetra
.32384 .40048 .33099 .40763 .34232 .40377 .33521 .39659 Mtetra
.33521 .39659 .34232 .40377 .3537 .39988 .34662 .39267 Mtetra
.34662 .39267 .3537 .39988 .36513 .39598 .35808 .38874 Mtetra
.35808 .38874 .36513 .39598 .37661 .39207 .36959 .38479 Mtetra
.36959 .38479 .37661 .39207 .38814 .38814 .38115 .38083 Mtetra
.38115 .38083 .38814 .38814 .39972 .38419 .39276 .37685 Mtetra
.39276 .37685 .39972 .38419 .41135 .38022 .40442 .37285 Mtetra
.40442 .37285 .41135 .38022 .42302 .37623 .41613 .36883 Mtetra
.41613 .36883 .42302 .37623 .43475 .37223 .42789 .3648 Mtetra
.42789 .3648 .43475 .37223 .44654 .36821 .43971 .36075 Mtetra
.43971 .36075 .44654 .36821 .45837 .36418 .45157 .35668 Mtetra
.45157 .35668 .45837 .36418 .47025 .36012 .46349 .35259 Mtetra
.46349 .35259 .47025 .36012 .48219 .35605 .47546 .34849 Mtetra
.47546 .34849 .48219 .35605 .49418 .35196 .48748 .34436 Mtetra
.48748 .34436 .49418 .35196 .50622 .34785 .49956 .34022 Mtetra
.49956 .34022 .50622 .34785 .51831 .34373 .51169 .33606 Mtetra
.51169 .33606 .51831 .34373 .53046 .33958 .52387 .33188 Mtetra
.52387 .33188 .53046 .33958 .54266 .33542 .53611 .32769 Mtetra
.53611 .32769 .54266 .33542 .55492 .33124 .5484 .32347 Mtetra
.5484 .32347 .55492 .33124 .56723 .32704 .56075 .31924 Mtetra
.56075 .31924 .56723 .32704 .5796 .32282 .57315 .31498 Mtetra
.57315 .31498 .5796 .32282 .59202 .31858 .58561 .31071 Mtetra
.58561 .31071 .59202 .31858 .60449 .31433 .59812 .30642 Mtetra
.59812 .30642 .60449 .31433 .61703 .31005 .61069 .30211 Mtetra
.61069 .30211 .61703 .31005 .62962 .30576 .62332 .29778 Mtetra
.62332 .29778 .62962 .30576 .64226 .30144 .636 .29343 Mtetra
.636 .29343 .64226 .30144 .65497 .29711 .64874 .28906 Mtetra
.64874 .28906 .65497 .29711 .66773 .29276 .66155 .28467 Mtetra
.329 .576 .931 r
.66155 .28467 .66773 .29276 .68092 .2958 .67476 .28768 Mtetra
.663 .742 .909 r
.67476 .28768 .68092 .2958 .69382 .29141 .68771 .28326 Mtetra
.68771 .28326 .69382 .29141 .70679 .287 .70072 .27881 Mtetra
.70072 .27881 .70679 .287 .71982 .28258 .71379 .27435 Mtetra
.71379 .27435 .71982 .28258 .73291 .27813 .72692 .26987 Mtetra
.72692 .26987 .73291 .27813 .74605 .27366 .74011 .26536 Mtetra
.74011 .26536 .74605 .27366 .75926 .26917 .75336 .26083 Mtetra
.75336 .26083 .75926 .26917 .77253 .26466 .76667 .25628 Mtetra
.76667 .25628 .77253 .26466 .78586 .26013 .78004 .25172 Mtetra
.78004 .25172 .78586 .26013 .79925 .25558 .79348 .24713 Mtetra
.79348 .24713 .79925 .25558 .81271 .25101 .80698 .24251 Mtetra
.80698 .24251 .81271 .25101 .82623 .24642 .82054 .23788 Mtetra
.82054 .23788 .82623 .24642 .83981 .2418 .83417 .23323 Mtetra
.664 .741 .908 r
.21628 .42788 .22373 .43482 .23467 .43107 .22724 .4241 Mtetra
.22724 .4241 .23467 .43107 .24565 .4273 .23825 .4203 Mtetra
.23825 .4203 .24565 .4273 .25668 .42352 .24931 .41649 Mtetra
.24931 .41649 .25668 .42352 .26775 .41972 .26041 .41266 Mtetra
.26041 .41266 .26775 .41972 .27888 .4159 .27156 .40882 Mtetra
.27156 .40882 .27888 .4159 .29005 .41207 .28276 .40496 Mtetra
.28276 .40496 .29005 .41207 .30127 .40823 .29401 .40108 Mtetra
.29401 .40108 .30127 .40823 .31253 .40436 .3053 .39719 Mtetra
.3053 .39719 .31253 .40436 .32384 .40048 .31665 .39327 Mtetra
.31665 .39327 .32384 .40048 .33521 .39659 .32804 .38935 Mtetra
.32804 .38935 .33521 .39659 .34662 .39267 .33948 .3854 Mtetra
.33948 .3854 .34662 .39267 .35808 .38874 .35097 .38144 Mtetra
.35097 .38144 .35808 .38874 .36959 .38479 .36251 .37746 Mtetra
.36251 .37746 .36959 .38479 .38115 .38083 .3741 .37347 Mtetra
.3741 .37347 .38115 .38083 .39276 .37685 .38574 .36945 Mtetra
.38574 .36945 .39276 .37685 .40442 .37285 .39744 .36542 Mtetra
.39744 .36542 .40442 .37285 .41613 .36883 .40918 .36137 Mtetra
.40918 .36137 .41613 .36883 .42789 .3648 .42097 .35731 Mtetra
.42097 .35731 .42789 .3648 .43971 .36075 .43282 .35322 Mtetra
.43282 .35322 .43971 .36075 .45157 .35668 .44472 .34912 Mtetra
.44472 .34912 .45157 .35668 .46349 .35259 .45667 .345 Mtetra
.45667 .345 .46349 .35259 .47546 .34849 .46867 .34086 Mtetra
.46867 .34086 .47546 .34849 .48748 .34436 .48073 .3367 Mtetra
.48073 .3367 .48748 .34436 .49956 .34022 .49284 .33253 Mtetra
.49284 .33253 .49956 .34022 .51169 .33606 .505 .32833 Mtetra
.505 .32833 .51169 .33606 .52387 .33188 .51722 .32412 Mtetra
.51722 .32412 .52387 .33188 .53611 .32769 .5295 .31989 Mtetra
.5295 .31989 .53611 .32769 .5484 .32347 .54182 .31564 Mtetra
.54182 .31564 .5484 .32347 .56075 .31924 .55421 .31137 Mtetra
.55421 .31137 .56075 .31924 .57315 .31498 .56665 .30708 Mtetra
.56665 .30708 .57315 .31498 .58561 .31071 .57914 .30277 Mtetra
.57914 .30277 .58561 .31071 .59812 .30642 .59169 .29844 Mtetra
.59169 .29844 .59812 .30642 .61069 .30211 .6043 .2941 Mtetra
.6043 .2941 .61069 .30211 .62332 .29778 .61697 .28973 Mtetra
.61697 .28973 .62332 .29778 .636 .29343 .62969 .28534 Mtetra
.62969 .28534 .636 .29343 .64874 .28906 .64247 .28094 Mtetra
.64247 .28094 .64874 .28906 .66155 .28467 .65531 .27651 Mtetra
.329 .576 .931 r
.65531 .27651 .66155 .28467 .67476 .28768 .66856 .2795 Mtetra
.663 .742 .909 r
.66856 .2795 .67476 .28768 .68771 .28326 .68155 .27504 Mtetra
.68155 .27504 .68771 .28326 .70072 .27881 .6946 .27056 Mtetra
.6946 .27056 .70072 .27881 .71379 .27435 .70771 .26605 Mtetra
.70771 .26605 .71379 .27435 .72692 .26987 .72088 .26153 Mtetra
.72088 .26153 .72692 .26987 .74011 .26536 .73411 .25699 Mtetra
.73411 .25699 .74011 .26536 .75336 .26083 .7474 .25242 Mtetra
.7474 .25242 .75336 .26083 .76667 .25628 .76076 .24783 Mtetra
.76076 .24783 .76667 .25628 .78004 .25172 .77418 .24322 Mtetra
.77418 .24322 .78004 .25172 .79348 .24713 .78766 .23859 Mtetra
.78766 .23859 .79348 .24713 .80698 .24251 .8012 .23394 Mtetra
.8012 .23394 .80698 .24251 .82054 .23788 .81481 .22927 Mtetra
.81481 .22927 .82054 .23788 .83417 .23323 .82848 .22457 Mtetra
.664 .741 .908 r
.20877 .42089 .21628 .42788 .22724 .4241 .21976 .41708 Mtetra
.21976 .41708 .22724 .4241 .23825 .4203 .2308 .41325 Mtetra
.2308 .41325 .23825 .4203 .24931 .41649 .24188 .40941 Mtetra
.24188 .40941 .24931 .41649 .26041 .41266 .25302 .40555 Mtetra
.25302 .40555 .26041 .41266 .27156 .40882 .26419 .40168 Mtetra
.26419 .40168 .27156 .40882 .28276 .40496 .27542 .39779 Mtetra
.27542 .39779 .28276 .40496 .29401 .40108 .2867 .39388 Mtetra
.2867 .39388 .29401 .40108 .3053 .39719 .29802 .38995 Mtetra
.29802 .38995 .3053 .39719 .31665 .39327 .30939 .38601 Mtetra
.30939 .38601 .31665 .39327 .32804 .38935 .32082 .38205 Mtetra
.32082 .38205 .32804 .38935 .33948 .3854 .33229 .37807 Mtetra
.33229 .37807 .33948 .3854 .35097 .38144 .34381 .37408 Mtetra
.34381 .37408 .35097 .38144 .36251 .37746 .35538 .37007 Mtetra
.35538 .37007 .36251 .37746 .3741 .37347 .367 .36604 Mtetra
.367 .36604 .3741 .37347 .38574 .36945 .37867 .362 Mtetra
.37867 .362 .38574 .36945 .39744 .36542 .3904 .35793 Mtetra
.3904 .35793 .39744 .36542 .40918 .36137 .40217 .35385 Mtetra
.40217 .35385 .40918 .36137 .42097 .35731 .414 .34975 Mtetra
.414 .34975 .42097 .35731 .43282 .35322 .42588 .34563 Mtetra
.42588 .34563 .43282 .35322 .44472 .34912 .43781 .3415 Mtetra
.43781 .3415 .44472 .34912 .45667 .345 .44979 .33734 Mtetra
.44979 .33734 .45667 .345 .46867 .34086 .46183 .33317 Mtetra
.46183 .33317 .46867 .34086 .48073 .3367 .47392 .32898 Mtetra
.47392 .32898 .48073 .3367 .49284 .33253 .48607 .32477 Mtetra
.48607 .32477 .49284 .33253 .505 .32833 .49827 .32054 Mtetra
.49827 .32054 .505 .32833 .51722 .32412 .51052 .31629 Mtetra
.51052 .31629 .51722 .32412 .5295 .31989 .52283 .31203 Mtetra
.52283 .31203 .5295 .31989 .54182 .31564 .53519 .30774 Mtetra
.53519 .30774 .54182 .31564 .55421 .31137 .54761 .30344 Mtetra
.54761 .30344 .55421 .31137 .56665 .30708 .56009 .29911 Mtetra
.56009 .29911 .56665 .30708 .57914 .30277 .57262 .29477 Mtetra
.57262 .29477 .57914 .30277 .59169 .29844 .58521 .2904 Mtetra
.58521 .2904 .59169 .29844 .6043 .2941 .59786 .28602 Mtetra
.59786 .28602 .6043 .2941 .61697 .28973 .61056 .28162 Mtetra
.61056 .28162 .61697 .28973 .62969 .28534 .62333 .27719 Mtetra
.62333 .27719 .62969 .28534 .64247 .28094 .63615 .27275 Mtetra
.63615 .27275 .64247 .28094 .65531 .27651 .64903 .26828 Mtetra
.329 .576 .931 r
.64903 .26828 .65531 .27651 .66856 .2795 .6623 .27125 Mtetra
.663 .742 .909 r
.6623 .27125 .66856 .2795 .68155 .27504 .67533 .26675 Mtetra
.67533 .26675 .68155 .27504 .6946 .27056 .68842 .26223 Mtetra
.68842 .26223 .6946 .27056 .70771 .26605 .70157 .25769 Mtetra
.70157 .25769 .70771 .26605 .72088 .26153 .71478 .25312 Mtetra
.71478 .25312 .72088 .26153 .73411 .25699 .72806 .24854 Mtetra
.72806 .24854 .73411 .25699 .7474 .25242 .7414 .24393 Mtetra
.7414 .24393 .7474 .25242 .76076 .24783 .7548 .23931 Mtetra
.7548 .23931 .76076 .24783 .77418 .24322 .76826 .23466 Mtetra
.76826 .23466 .77418 .24322 .78766 .23859 .78179 .22999 Mtetra
.78179 .22999 .78766 .23859 .8012 .23394 .79538 .2253 Mtetra
.79538 .2253 .8012 .23394 .81481 .22927 .80903 .22058 Mtetra
.80903 .22058 .81481 .22927 .82848 .22457 .82275 .21585 Mtetra
.664 .741 .908 r
.2012 .41384 .20877 .42089 .21976 .41708 .21222 .41 Mtetra
.21222 .41 .21976 .41708 .2308 .41325 .22329 .40615 Mtetra
.22329 .40615 .2308 .41325 .24188 .40941 .2344 .40227 Mtetra
.2344 .40227 .24188 .40941 .25302 .40555 .24556 .39839 Mtetra
.24556 .39839 .25302 .40555 .26419 .40168 .25677 .39448 Mtetra
.25677 .39448 .26419 .40168 .27542 .39779 .26802 .39056 Mtetra
.26802 .39056 .27542 .39779 .2867 .39388 .27933 .38662 Mtetra
.27933 .38662 .2867 .39388 .29802 .38995 .29068 .38266 Mtetra
.29068 .38266 .29802 .38995 .30939 .38601 .30208 .37869 Mtetra
.30208 .37869 .30939 .38601 .32082 .38205 .31353 .3747 Mtetra
.31353 .3747 .32082 .38205 .33229 .37807 .32503 .37069 Mtetra
.32503 .37069 .33229 .37807 .34381 .37408 .33659 .36666 Mtetra
.33659 .36666 .34381 .37408 .35538 .37007 .34819 .36262 Mtetra
.34819 .36262 .35538 .37007 .367 .36604 .35984 .35856 Mtetra
.35984 .35856 .367 .36604 .37867 .362 .37155 .35448 Mtetra
.37155 .35448 .37867 .362 .3904 .35793 .3833 .35038 Mtetra
.3833 .35038 .3904 .35793 .40217 .35385 .39511 .34627 Mtetra
.39511 .34627 .40217 .35385 .414 .34975 .40697 .34213 Mtetra
.40697 .34213 .414 .34975 .42588 .34563 .41888 .33798 Mtetra
.41888 .33798 .42588 .34563 .43781 .3415 .43084 .33381 Mtetra
.43084 .33381 .43781 .3415 .44979 .33734 .44286 .32963 Mtetra
.44286 .32963 .44979 .33734 .46183 .33317 .45493 .32542 Mtetra
.45493 .32542 .46183 .33317 .47392 .32898 .46706 .32119 Mtetra
.46706 .32119 .47392 .32898 .48607 .32477 .47924 .31695 Mtetra
.47924 .31695 .48607 .32477 .49827 .32054 .49147 .31268 Mtetra
.49147 .31268 .49827 .32054 .51052 .31629 .50376 .3084 Mtetra
.50376 .3084 .51052 .31629 .52283 .31203 .51611 .3041 Mtetra
.51611 .3041 .52283 .31203 .53519 .30774 .52851 .29978 Mtetra
.52851 .29978 .53519 .30774 .54761 .30344 .54097 .29544 Mtetra
.54097 .29544 .54761 .30344 .56009 .29911 .55348 .29108 Mtetra
.55348 .29108 .56009 .29911 .57262 .29477 .56605 .28669 Mtetra
.56605 .28669 .57262 .29477 .58521 .2904 .57868 .28229 Mtetra
.57868 .28229 .58521 .2904 .59786 .28602 .59136 .27787 Mtetra
.59136 .27787 .59786 .28602 .61056 .28162 .60411 .27343 Mtetra
.60411 .27343 .61056 .28162 .62333 .27719 .61691 .26897 Mtetra
.61691 .26897 .62333 .27719 .63615 .27275 .62977 .26449 Mtetra
.62977 .26449 .63615 .27275 .64903 .26828 .64269 .25999 Mtetra
.329 .576 .931 r
.64269 .25999 .64903 .26828 .6623 .27125 .65598 .26292 Mtetra
.663 .742 .909 r
.65598 .26292 .6623 .27125 .67533 .26675 .66906 .25839 Mtetra
.66906 .25839 .67533 .26675 .68842 .26223 .68219 .25383 Mtetra
.68219 .25383 .68842 .26223 .70157 .25769 .69538 .24925 Mtetra
.69538 .24925 .70157 .25769 .71478 .25312 .70864 .24464 Mtetra
.70864 .24464 .71478 .25312 .72806 .24854 .72196 .24002 Mtetra
.72196 .24002 .72806 .24854 .7414 .24393 .73534 .23538 Mtetra
.73534 .23538 .7414 .24393 .7548 .23931 .74878 .23071 Mtetra
.74878 .23071 .7548 .23931 .76826 .23466 .76229 .22602 Mtetra
.76229 .22602 .76826 .23466 .78179 .22999 .77586 .22131 Mtetra
.77586 .22131 .78179 .22999 .79538 .2253 .7895 .21658 Mtetra
.7895 .21658 .79538 .2253 .80903 .22058 .8032 .21182 Mtetra
.8032 .21182 .80903 .22058 .82275 .21585 .81696 .20704 Mtetra
.664 .741 .908 r
.19358 .40674 .2012 .41384 .21222 .41 .20462 .40287 Mtetra
.20462 .40287 .21222 .41 .22329 .40615 .21571 .39899 Mtetra
.21571 .39899 .22329 .40615 .2344 .40227 .22685 .39508 Mtetra
.22685 .39508 .2344 .40227 .24556 .39839 .23804 .39116 Mtetra
.23804 .39116 .24556 .39839 .25677 .39448 .24928 .38723 Mtetra
.24928 .38723 .25677 .39448 .26802 .39056 .26056 .38327 Mtetra
.26056 .38327 .26802 .39056 .27933 .38662 .2719 .3793 Mtetra
.2719 .3793 .27933 .38662 .29068 .38266 .28328 .37531 Mtetra
.28328 .37531 .29068 .38266 .30208 .37869 .29471 .37131 Mtetra
.29471 .37131 .30208 .37869 .31353 .3747 .30619 .36728 Mtetra
.30619 .36728 .31353 .3747 .32503 .37069 .31772 .36324 Mtetra
.31772 .36324 .32503 .37069 .33659 .36666 .32931 .35918 Mtetra
.32931 .35918 .33659 .36666 .34819 .36262 .34094 .35511 Mtetra
.34094 .35511 .34819 .36262 .35984 .35856 .35262 .35101 Mtetra
.35262 .35101 .35984 .35856 .37155 .35448 .36436 .3469 Mtetra
.36436 .3469 .37155 .35448 .3833 .35038 .37615 .34277 Mtetra
.37615 .34277 .3833 .35038 .39511 .34627 .38799 .33862 Mtetra
.38799 .33862 .39511 .34627 .40697 .34213 .39988 .33446 Mtetra
.39988 .33446 .40697 .34213 .41888 .33798 .41182 .33027 Mtetra
.41182 .33027 .41888 .33798 .43084 .33381 .42382 .32607 Mtetra
.42382 .32607 .43084 .33381 .44286 .32963 .43587 .32184 Mtetra
.43587 .32184 .44286 .32963 .45493 .32542 .44798 .3176 Mtetra
.44798 .3176 .45493 .32542 .46706 .32119 .46014 .31334 Mtetra
.46014 .31334 .46706 .32119 .47924 .31695 .47236 .30906 Mtetra
.47236 .30906 .47924 .31695 .49147 .31268 .48463 .30476 Mtetra
.48463 .30476 .49147 .31268 .50376 .3084 .49695 .30044 Mtetra
.49695 .30044 .50376 .3084 .51611 .3041 .50933 .29611 Mtetra
.50933 .29611 .51611 .3041 .52851 .29978 .52177 .29175 Mtetra
.52177 .29175 .52851 .29978 .54097 .29544 .53426 .28737 Mtetra
.53426 .28737 .54097 .29544 .55348 .29108 .54681 .28297 Mtetra
.54681 .28297 .55348 .29108 .56605 .28669 .55942 .27855 Mtetra
.55942 .27855 .56605 .28669 .57868 .28229 .57209 .27412 Mtetra
.57209 .27412 .57868 .28229 .59136 .27787 .58481 .26966 Mtetra
.58481 .26966 .59136 .27787 .60411 .27343 .59759 .26518 Mtetra
.59759 .26518 .60411 .27343 .61691 .26897 .61043 .26068 Mtetra
.61043 .26068 .61691 .26897 .62977 .26449 .62333 .25616 Mtetra
.62333 .25616 .62977 .26449 .64269 .25999 .63629 .25162 Mtetra
.329 .576 .931 r
.63629 .25162 .64269 .25999 .65598 .26292 .64962 .25453 Mtetra
.663 .742 .909 r
.64962 .25453 .65598 .26292 .66906 .25839 .66273 .24995 Mtetra
.66273 .24995 .66906 .25839 .68219 .25383 .67591 .24535 Mtetra
.67591 .24535 .68219 .25383 .69538 .24925 .68914 .24073 Mtetra
.68914 .24073 .69538 .24925 .70864 .24464 .70244 .23609 Mtetra
.70244 .23609 .70864 .24464 .72196 .24002 .7158 .23143 Mtetra
.7158 .23143 .72196 .24002 .73534 .23538 .72923 .22674 Mtetra
.72923 .22674 .73534 .23538 .74878 .23071 .74272 .22204 Mtetra
.74272 .22204 .74878 .23071 .76229 .22602 .75627 .21731 Mtetra
.75627 .21731 .76229 .22602 .77586 .22131 .76988 .21255 Mtetra
.76988 .21255 .77586 .22131 .7895 .21658 .78356 .20778 Mtetra
.78356 .20778 .7895 .21658 .8032 .21182 .79731 .20298 Mtetra
.79731 .20298 .8032 .21182 .81696 .20704 .81112 .19816 Mtetra
.664 .741 .908 r
.18589 .39958 .19358 .40674 .20462 .40287 .19696 .39568 Mtetra
.19696 .39568 .20462 .40287 .21571 .39899 .20808 .39177 Mtetra
.20808 .39177 .21571 .39899 .22685 .39508 .21925 .38783 Mtetra
.21925 .38783 .22685 .39508 .23804 .39116 .23047 .38388 Mtetra
.23047 .38388 .23804 .39116 .24928 .38723 .24173 .37991 Mtetra
.24173 .37991 .24928 .38723 .26056 .38327 .25304 .37593 Mtetra
.25304 .37593 .26056 .38327 .2719 .3793 .26441 .37192 Mtetra
.26441 .37192 .2719 .3793 .28328 .37531 .27582 .3679 Mtetra
.27582 .3679 .28328 .37531 .29471 .37131 .28728 .36387 Mtetra
.28728 .36387 .29471 .37131 .30619 .36728 .29879 .35981 Mtetra
.29879 .35981 .30619 .36728 .31772 .36324 .31035 .35574 Mtetra
.31035 .35574 .31772 .36324 .32931 .35918 .32197 .35165 Mtetra
.32197 .35165 .32931 .35918 .34094 .35511 .33363 .34754 Mtetra
.33363 .34754 .34094 .35511 .35262 .35101 .34535 .34341 Mtetra
.34535 .34341 .35262 .35101 .36436 .3469 .35711 .33926 Mtetra
.35711 .33926 .36436 .3469 .37615 .34277 .36893 .3351 Mtetra
.36893 .3351 .37615 .34277 .38799 .33862 .38081 .33092 Mtetra
.38081 .33092 .38799 .33862 .39988 .33446 .39273 .32671 Mtetra
.39273 .32671 .39988 .33446 .41182 .33027 .40471 .32249 Mtetra
.40471 .32249 .41182 .33027 .42382 .32607 .41674 .31826 Mtetra
.41674 .31826 .42382 .32607 .43587 .32184 .42883 .314 Mtetra
.42883 .314 .43587 .32184 .44798 .3176 .44097 .30972 Mtetra
.44097 .30972 .44798 .3176 .46014 .31334 .45316 .30543 Mtetra
.45316 .30543 .46014 .31334 .47236 .30906 .46541 .30111 Mtetra
.46541 .30111 .47236 .30906 .48463 .30476 .47772 .29677 Mtetra
.47772 .29677 .48463 .30476 .49695 .30044 .49008 .29242 Mtetra
.49008 .29242 .49695 .30044 .50933 .29611 .5025 .28804 Mtetra
.5025 .28804 .50933 .29611 .52177 .29175 .51497 .28365 Mtetra
.51497 .28365 .52177 .29175 .53426 .28737 .5275 .27924 Mtetra
.5275 .27924 .53426 .28737 .54681 .28297 .54009 .2748 Mtetra
.54009 .2748 .54681 .28297 .55942 .27855 .55274 .27035 Mtetra
.55274 .27035 .55942 .27855 .57209 .27412 .56544 .26587 Mtetra
.56544 .26587 .57209 .27412 .58481 .26966 .5782 .26137 Mtetra
.5782 .26137 .58481 .26966 .59759 .26518 .59102 .25686 Mtetra
.59102 .25686 .59759 .26518 .61043 .26068 .60391 .25232 Mtetra
.60391 .25232 .61043 .26068 .62333 .25616 .61685 .24776 Mtetra
.61685 .24776 .62333 .25616 .63629 .25162 .62985 .24318 Mtetra
.329 .576 .931 r
.62985 .24318 .63629 .25162 .64962 .25453 .6432 .24606 Mtetra
.663 .742 .909 r
.6432 .24606 .64962 .25453 .66273 .24995 .65635 .24145 Mtetra
.65635 .24145 .66273 .24995 .67591 .24535 .66957 .23681 Mtetra
.66957 .23681 .67591 .24535 .68914 .24073 .68285 .23215 Mtetra
.68285 .23215 .68914 .24073 .70244 .23609 .69619 .22747 Mtetra
.69619 .22747 .70244 .23609 .7158 .23143 .70959 .22276 Mtetra
.70959 .22276 .7158 .23143 .72923 .22674 .72306 .21803 Mtetra
.72306 .21803 .72923 .22674 .74272 .22204 .7366 .21329 Mtetra
.7366 .21329 .74272 .22204 .75627 .21731 .75019 .20851 Mtetra
.75019 .20851 .75627 .21731 .76988 .21255 .76385 .20372 Mtetra
.76385 .20372 .76988 .21255 .78356 .20778 .77758 .1989 Mtetra
.77758 .1989 .78356 .20778 .79731 .20298 .79137 .19406 Mtetra
.79137 .19406 .79731 .20298 .81112 .19816 .80523 .1892 Mtetra
.664 .741 .908 r
.17814 .39237 .18589 .39958 .19696 .39568 .18924 .38844 Mtetra
.18924 .38844 .19696 .39568 .20808 .39177 .20039 .38449 Mtetra
.20039 .38449 .20808 .39177 .21925 .38783 .21158 .38052 Mtetra
.21158 .38052 .21925 .38783 .23047 .38388 .22283 .37654 Mtetra
.22283 .37654 .23047 .38388 .24173 .37991 .23412 .37254 Mtetra
.23412 .37254 .24173 .37991 .25304 .37593 .24546 .36852 Mtetra
.24546 .36852 .25304 .37593 .26441 .37192 .25686 .36449 Mtetra
.25686 .36449 .26441 .37192 .27582 .3679 .2683 .36043 Mtetra
.2683 .36043 .27582 .3679 .28728 .36387 .27979 .35636 Mtetra
.27979 .35636 .28728 .36387 .29879 .35981 .29133 .35228 Mtetra
.29133 .35228 .29879 .35981 .31035 .35574 .30292 .34817 Mtetra
.30292 .34817 .31035 .35574 .32197 .35165 .31457 .34404 Mtetra
.31457 .34404 .32197 .35165 .33363 .34754 .32626 .3399 Mtetra
.32626 .3399 .33363 .34754 .34535 .34341 .33801 .33574 Mtetra
.33801 .33574 .34535 .34341 .35711 .33926 .34981 .33156 Mtetra
.34981 .33156 .35711 .33926 .36893 .3351 .36166 .32736 Mtetra
.36166 .32736 .36893 .3351 .38081 .33092 .37357 .32315 Mtetra
.37357 .32315 .38081 .33092 .39273 .32671 .38553 .31891 Mtetra
.38553 .31891 .39273 .32671 .40471 .32249 .39754 .31465 Mtetra
.39754 .31465 .40471 .32249 .41674 .31826 .4096 .31038 Mtetra
.4096 .31038 .41674 .31826 .42883 .314 .42172 .30609 Mtetra
.42172 .30609 .42883 .314 .44097 .30972 .4339 .30177 Mtetra
.4339 .30177 .44097 .30972 .45316 .30543 .44613 .29744 Mtetra
.44613 .29744 .45316 .30543 .46541 .30111 .45841 .29309 Mtetra
.45841 .29309 .46541 .30111 .47772 .29677 .47075 .28872 Mtetra
.47075 .28872 .47772 .29677 .49008 .29242 .48315 .28433 Mtetra
.48315 .28433 .49008 .29242 .5025 .28804 .49561 .27992 Mtetra
.49561 .27992 .5025 .28804 .51497 .28365 .50812 .27548 Mtetra
.50812 .27548 .51497 .28365 .5275 .27924 .52068 .27103 Mtetra
.52068 .27103 .5275 .27924 .54009 .2748 .53331 .26656 Mtetra
.53331 .26656 .54009 .2748 .55274 .27035 .54599 .26207 Mtetra
.54599 .26207 .55274 .27035 .56544 .26587 .55874 .25755 Mtetra
.55874 .25755 .56544 .26587 .5782 .26137 .57154 .25302 Mtetra
.57154 .25302 .5782 .26137 .59102 .25686 .5844 .24846 Mtetra
.5844 .24846 .59102 .25686 .60391 .25232 .59732 .24389 Mtetra
.59732 .24389 .60391 .25232 .61685 .24776 .6103 .23929 Mtetra
.6103 .23929 .61685 .24776 .62985 .24318 .62334 .23467 Mtetra
.329 .576 .931 r
.62334 .23467 .62985 .24318 .6432 .24606 .63672 .23752 Mtetra
.663 .742 .909 r
.63672 .23752 .6432 .24606 .65635 .24145 .64992 .23287 Mtetra
.64992 .23287 .65635 .24145 .66957 .23681 .66318 .22819 Mtetra
.66318 .22819 .66957 .23681 .68285 .23215 .6765 .22349 Mtetra
.6765 .22349 .68285 .23215 .69619 .22747 .68988 .21876 Mtetra
.68988 .21876 .69619 .22747 .70959 .22276 .70333 .21402 Mtetra
.70333 .21402 .70959 .22276 .72306 .21803 .71684 .20925 Mtetra
.71684 .20925 .72306 .21803 .7366 .21329 .73042 .20446 Mtetra
.73042 .20446 .7366 .21329 .75019 .20851 .74406 .19964 Mtetra
.74406 .19964 .75019 .20851 .76385 .20372 .75777 .19481 Mtetra
.75777 .19481 .76385 .20372 .77758 .1989 .77154 .18995 Mtetra
.77154 .18995 .77758 .1989 .79137 .19406 .78538 .18506 Mtetra
.78538 .18506 .79137 .19406 .80523 .1892 .79929 .18016 Mtetra
.664 .741 .908 r
.17033 .3851 .17814 .39237 .18924 .38844 .18146 .38114 Mtetra
.18146 .38114 .18924 .38844 .20039 .38449 .19263 .37715 Mtetra
.19263 .37715 .20039 .38449 .21158 .38052 .20386 .37316 Mtetra
.20386 .37316 .21158 .38052 .22283 .37654 .21513 .36914 Mtetra
.21513 .36914 .22283 .37654 .23412 .37254 .22645 .36511 Mtetra
.22645 .36511 .23412 .37254 .24546 .36852 .23782 .36106 Mtetra
.23782 .36106 .24546 .36852 .25686 .36449 .24924 .35699 Mtetra
.24924 .35699 .25686 .36449 .2683 .36043 .26072 .35291 Mtetra
.26072 .35291 .2683 .36043 .27979 .35636 .27224 .3488 Mtetra
.27224 .3488 .27979 .35636 .29133 .35228 .28381 .34468 Mtetra
.28381 .34468 .29133 .35228 .30292 .34817 .29543 .34054 Mtetra
.29543 .34054 .30292 .34817 .31457 .34404 .30711 .33638 Mtetra
.30711 .33638 .31457 .34404 .32626 .3399 .31884 .3322 Mtetra
.31884 .3322 .32626 .3399 .33801 .33574 .33061 .32801 Mtetra
.33061 .32801 .33801 .33574 .34981 .33156 .34245 .3238 Mtetra
.34245 .3238 .34981 .33156 .36166 .32736 .35433 .31956 Mtetra
.35433 .31956 .36166 .32736 .37357 .32315 .36627 .31531 Mtetra
.36627 .31531 .37357 .32315 .38553 .31891 .37826 .31104 Mtetra
.37826 .31104 .38553 .31891 .39754 .31465 .39031 .30675 Mtetra
.39031 .30675 .39754 .31465 .4096 .31038 .40241 .30244 Mtetra
.40241 .30244 .4096 .31038 .42172 .30609 .41456 .29811 Mtetra
.41456 .29811 .42172 .30609 .4339 .30177 .42677 .29376 Mtetra
.42677 .29376 .4339 .30177 .44613 .29744 .43903 .28939 Mtetra
.43903 .28939 .44613 .29744 .45841 .29309 .45135 .285 Mtetra
.45135 .285 .45841 .29309 .47075 .28872 .46373 .2806 Mtetra
.46373 .2806 .47075 .28872 .48315 .28433 .47617 .27617 Mtetra
.47617 .27617 .48315 .28433 .49561 .27992 .48866 .27172 Mtetra
.48866 .27172 .49561 .27992 .50812 .27548 .5012 .26725 Mtetra
.5012 .26725 .50812 .27548 .52068 .27103 .51381 .26276 Mtetra
.51381 .26276 .52068 .27103 .53331 .26656 .52647 .25825 Mtetra
.52647 .25825 .53331 .26656 .54599 .26207 .5392 .25372 Mtetra
.5392 .25372 .54599 .26207 .55874 .25755 .55198 .24917 Mtetra
.55198 .24917 .55874 .25755 .57154 .25302 .56482 .24459 Mtetra
.56482 .24459 .57154 .25302 .5844 .24846 .57772 .24 Mtetra
.57772 .24 .5844 .24846 .59732 .24389 .59068 .23538 Mtetra
.59068 .23538 .59732 .24389 .6103 .23929 .6037 .23074 Mtetra
.6037 .23074 .6103 .23929 .62334 .23467 .61678 .22608 Mtetra
.329 .576 .931 r
.61678 .22608 .62334 .23467 .63672 .23752 .63019 .22891 Mtetra
.663 .742 .909 r
.63019 .22891 .63672 .23752 .64992 .23287 .64343 .22421 Mtetra
.64343 .22421 .64992 .23287 .66318 .22819 .65673 .21949 Mtetra
.65673 .21949 .66318 .22819 .6765 .22349 .67009 .21475 Mtetra
.67009 .21475 .6765 .22349 .68988 .21876 .68352 .20998 Mtetra
.68352 .20998 .68988 .21876 .70333 .21402 .69701 .2052 Mtetra
.69701 .2052 .70333 .21402 .71684 .20925 .71057 .20039 Mtetra
.71057 .20039 .71684 .20925 .73042 .20446 .72419 .19555 Mtetra
.72419 .19555 .73042 .20446 .74406 .19964 .73788 .1907 Mtetra
.73788 .1907 .74406 .19964 .75777 .19481 .75163 .18582 Mtetra
.75163 .18582 .75777 .19481 .77154 .18995 .76545 .18091 Mtetra
.76545 .18091 .77154 .18995 .78538 .18506 .77934 .17599 Mtetra
.77934 .17599 .78538 .18506 .79929 .18016 .79329 .17103 Mtetra
.664 .741 .908 r
.16246 .37777 .17033 .3851 .18146 .38114 .17361 .37377 Mtetra
.17361 .37377 .18146 .38114 .19263 .37715 .18482 .36976 Mtetra
.18482 .36976 .19263 .37715 .20386 .37316 .19607 .36573 Mtetra
.19607 .36573 .20386 .37316 .21513 .36914 .20737 .36168 Mtetra
.20737 .36168 .21513 .36914 .22645 .36511 .21872 .35762 Mtetra
.21872 .35762 .22645 .36511 .23782 .36106 .23012 .35354 Mtetra
.23012 .35354 .23782 .36106 .24924 .35699 .24157 .34943 Mtetra
.24157 .34943 .24924 .35699 .26072 .35291 .25307 .34532 Mtetra
.25307 .34532 .26072 .35291 .27224 .3488 .26462 .34118 Mtetra
.26462 .34118 .27224 .3488 .28381 .34468 .27623 .33702 Mtetra
.27623 .33702 .28381 .34468 .29543 .34054 .28788 .33285 Mtetra
.28788 .33285 .29543 .34054 .30711 .33638 .29959 .32866 Mtetra
.29959 .32866 .30711 .33638 .31884 .3322 .31135 .32444 Mtetra
.31135 .32444 .31884 .3322 .33061 .32801 .32316 .32021 Mtetra
.32316 .32021 .33061 .32801 .34245 .3238 .33502 .31597 Mtetra
.33502 .31597 .34245 .3238 .35433 .31956 .34694 .3117 Mtetra
.34694 .3117 .35433 .31956 .36627 .31531 .35891 .30741 Mtetra
.35891 .30741 .36627 .31531 .37826 .31104 .37093 .3031 Mtetra
.37093 .3031 .37826 .31104 .39031 .30675 .38301 .29878 Mtetra
.38301 .29878 .39031 .30675 .40241 .30244 .39515 .29443 Mtetra
.39515 .29443 .40241 .30244 .41456 .29811 .40734 .29007 Mtetra
.40734 .29007 .41456 .29811 .42677 .29376 .41958 .28568 Mtetra
.41958 .28568 .42677 .29376 .43903 .28939 .43188 .28128 Mtetra
.43188 .28128 .43903 .28939 .45135 .285 .44424 .27685 Mtetra
.44424 .27685 .45135 .285 .46373 .2806 .45665 .2724 Mtetra
.45665 .2724 .46373 .2806 .47617 .27617 .46912 .26794 Mtetra
.46912 .26794 .47617 .27617 .48866 .27172 .48165 .26345 Mtetra
.48165 .26345 .48866 .27172 .5012 .26725 .49423 .25894 Mtetra
.49423 .25894 .5012 .26725 .51381 .26276 .50688 .25442 Mtetra
.50688 .25442 .51381 .26276 .52647 .25825 .51958 .24987 Mtetra
.51958 .24987 .52647 .25825 .5392 .25372 .53234 .2453 Mtetra
.53234 .2453 .5392 .25372 .55198 .24917 .54516 .24071 Mtetra
.54516 .24071 .55198 .24917 .56482 .24459 .55804 .23609 Mtetra
.55804 .23609 .56482 .24459 .57772 .24 .57098 .23146 Mtetra
.57098 .23146 .57772 .24 .59068 .23538 .58398 .2268 Mtetra
.58398 .2268 .59068 .23538 .6037 .23074 .59704 .22212 Mtetra
.59704 .22212 .6037 .23074 .61678 .22608 .61017 .21742 Mtetra
.329 .576 .931 r
.61017 .21742 .61678 .22608 .63019 .22891 .6236 .22022 Mtetra
.663 .742 .909 r
.6236 .22022 .63019 .22891 .64343 .22421 .63688 .21548 Mtetra
.63688 .21548 .64343 .22421 .65673 .21949 .65022 .21072 Mtetra
.65022 .21072 .65673 .21949 .67009 .21475 .66363 .20593 Mtetra
.66363 .20593 .67009 .21475 .68352 .20998 .6771 .20113 Mtetra
.6771 .20113 .68352 .20998 .69701 .2052 .69064 .1963 Mtetra
.69064 .1963 .69701 .2052 .71057 .20039 .70424 .19144 Mtetra
.70424 .19144 .71057 .20039 .72419 .19555 .71791 .18657 Mtetra
.71791 .18657 .72419 .19555 .73788 .1907 .73164 .18167 Mtetra
.73164 .18167 .73788 .1907 .75163 .18582 .74544 .17674 Mtetra
.74544 .17674 .75163 .18582 .76545 .18091 .75931 .1718 Mtetra
.75931 .1718 .76545 .18091 .77934 .17599 .77324 .16683 Mtetra
.77324 .16683 .77934 .17599 .79329 .17103 .78724 .16183 Mtetra
.664 .741 .908 r
.15452 .37038 .16246 .37777 .17361 .37377 .16571 .36635 Mtetra
.16571 .36635 .17361 .37377 .18482 .36976 .17694 .36231 Mtetra
.17694 .36231 .18482 .36976 .19607 .36573 .18822 .35825 Mtetra
.18822 .35825 .19607 .36573 .20737 .36168 .19955 .35416 Mtetra
.19955 .35416 .20737 .36168 .21872 .35762 .21093 .35007 Mtetra
.21093 .35007 .21872 .35762 .23012 .35354 .22236 .34595 Mtetra
.22236 .34595 .23012 .35354 .24157 .34943 .23384 .34182 Mtetra
.23384 .34182 .24157 .34943 .25307 .34532 .24537 .33766 Mtetra
.24537 .33766 .25307 .34532 .26462 .34118 .25695 .33349 Mtetra
.25695 .33349 .26462 .34118 .27623 .33702 .26858 .3293 Mtetra
.26858 .3293 .27623 .33702 .28788 .33285 .28027 .32509 Mtetra
.28027 .32509 .28788 .33285 .29959 .32866 .292 .32087 Mtetra
.292 .32087 .29959 .32866 .31135 .32444 .30379 .31662 Mtetra
.30379 .31662 .31135 .32444 .32316 .32021 .31564 .31236 Mtetra
.31564 .31236 .32316 .32021 .33502 .31597 .32753 .30807 Mtetra
.32753 .30807 .33502 .31597 .34694 .3117 .33948 .30377 Mtetra
.33948 .30377 .34694 .3117 .35891 .30741 .35149 .29944 Mtetra
.35149 .29944 .35891 .30741 .37093 .3031 .36355 .2951 Mtetra
.36355 .2951 .37093 .3031 .38301 .29878 .37566 .29074 Mtetra
.37566 .29074 .38301 .29878 .39515 .29443 .38783 .28636 Mtetra
.38783 .28636 .39515 .29443 .40734 .29007 .40005 .28195 Mtetra
.40005 .28195 .40734 .29007 .41958 .28568 .41233 .27753 Mtetra
.41233 .27753 .41958 .28568 .43188 .28128 .42467 .27309 Mtetra
.42467 .27309 .43188 .28128 .44424 .27685 .43706 .26863 Mtetra
.43706 .26863 .44424 .27685 .45665 .2724 .44951 .26414 Mtetra
.44951 .26414 .45665 .2724 .46912 .26794 .46201 .25964 Mtetra
.46201 .25964 .46912 .26794 .48165 .26345 .47458 .25511 Mtetra
.47458 .25511 .48165 .26345 .49423 .25894 .4872 .25057 Mtetra
.4872 .25057 .49423 .25894 .50688 .25442 .49988 .246 Mtetra
.49988 .246 .50688 .25442 .51958 .24987 .51262 .24141 Mtetra
.51262 .24141 .51958 .24987 .53234 .2453 .52542 .2368 Mtetra
.52542 .2368 .53234 .2453 .54516 .24071 .53828 .23217 Mtetra
.53828 .23217 .54516 .24071 .55804 .23609 .5512 .22752 Mtetra
.5512 .22752 .55804 .23609 .57098 .23146 .56418 .22284 Mtetra
.56418 .22284 .57098 .23146 .58398 .2268 .57722 .21815 Mtetra
.57722 .21815 .58398 .2268 .59704 .22212 .59033 .21343 Mtetra
.59033 .21343 .59704 .22212 .61017 .21742 .60349 .20869 Mtetra
.329 .576 .931 r
.60349 .20869 .61017 .21742 .6236 .22022 .61695 .21145 Mtetra
.663 .742 .909 r
.61695 .21145 .6236 .22022 .63688 .21548 .63027 .20667 Mtetra
.63027 .20667 .63688 .21548 .65022 .21072 .64366 .20187 Mtetra
.64366 .20187 .65022 .21072 .66363 .20593 .65711 .19704 Mtetra
.65711 .19704 .66363 .20593 .6771 .20113 .67063 .19219 Mtetra
.67063 .19219 .6771 .20113 .69064 .1963 .68421 .18732 Mtetra
.68421 .18732 .69064 .1963 .70424 .19144 .69786 .18242 Mtetra
.69786 .18242 .70424 .19144 .71791 .18657 .71157 .1775 Mtetra
.71157 .1775 .71791 .18657 .73164 .18167 .72535 .17256 Mtetra
.72535 .17256 .73164 .18167 .74544 .17674 .73919 .16759 Mtetra
.73919 .16759 .74544 .17674 .75931 .1718 .75311 .1626 Mtetra
.75311 .1626 .75931 .1718 .77324 .16683 .76709 .15758 Mtetra
.76709 .15758 .77324 .16683 .78724 .16183 .78114 .15254 Mtetra
.664 .741 .908 r
.14652 .36293 .15452 .37038 .16571 .36635 .15773 .35887 Mtetra
.15773 .35887 .16571 .36635 .17694 .36231 .16899 .35479 Mtetra
.16899 .35479 .17694 .36231 .18822 .35825 .1803 .3507 Mtetra
.1803 .3507 .18822 .35825 .19955 .35416 .19166 .34658 Mtetra
.19166 .34658 .19955 .35416 .21093 .35007 .20307 .34245 Mtetra
.20307 .34245 .21093 .35007 .22236 .34595 .21453 .3383 Mtetra
.21453 .3383 .22236 .34595 .23384 .34182 .22604 .33414 Mtetra
.22604 .33414 .23384 .34182 .24537 .33766 .2376 .32995 Mtetra
.2376 .32995 .24537 .33766 .25695 .33349 .24921 .32574 Mtetra
.24921 .32574 .25695 .33349 .26858 .3293 .26087 .32152 Mtetra
.26087 .32152 .26858 .3293 .28027 .32509 .27259 .31728 Mtetra
.27259 .31728 .28027 .32509 .292 .32087 .28436 .31301 Mtetra
.28436 .31301 .292 .32087 .30379 .31662 .29618 .30873 Mtetra
.29618 .30873 .30379 .31662 .31564 .31236 .30806 .30443 Mtetra
.30806 .30443 .31564 .31236 .32753 .30807 .31998 .30011 Mtetra
.31998 .30011 .32753 .30807 .33948 .30377 .33197 .29577 Mtetra
.33197 .29577 .33948 .30377 .35149 .29944 .344 .29141 Mtetra
.344 .29141 .35149 .29944 .36355 .2951 .3561 .28703 Mtetra
.3561 .28703 .36355 .2951 .37566 .29074 .36824 .28263 Mtetra
.36824 .28263 .37566 .29074 .38783 .28636 .38045 .27821 Mtetra
.38045 .27821 .38783 .28636 .40005 .28195 .3927 .27377 Mtetra
.3927 .27377 .40005 .28195 .41233 .27753 .40502 .26932 Mtetra
.40502 .26932 .41233 .27753 .42467 .27309 .41739 .26483 Mtetra
.41739 .26483 .42467 .27309 .43706 .26863 .42982 .26033 Mtetra
.42982 .26033 .43706 .26863 .44951 .26414 .4423 .25581 Mtetra
.4423 .25581 .44951 .26414 .46201 .25964 .45485 .25127 Mtetra
.45485 .25127 .46201 .25964 .47458 .25511 .46745 .24671 Mtetra
.46745 .24671 .47458 .25511 .4872 .25057 .48011 .24212 Mtetra
.48011 .24212 .4872 .25057 .49988 .246 .49283 .23751 Mtetra
.49283 .23751 .49988 .246 .51262 .24141 .50561 .23289 Mtetra
.50561 .23289 .51262 .24141 .52542 .2368 .51844 .22824 Mtetra
.51844 .22824 .52542 .2368 .53828 .23217 .53134 .22356 Mtetra
.53134 .22356 .53828 .23217 .5512 .22752 .5443 .21887 Mtetra
.5443 .21887 .5512 .22752 .56418 .22284 .55732 .21416 Mtetra
.55732 .21416 .56418 .22284 .57722 .21815 .57041 .20942 Mtetra
.57041 .20942 .57722 .21815 .59033 .21343 .58355 .20466 Mtetra
.58355 .20466 .59033 .21343 .60349 .20869 .59676 .19987 Mtetra
.329 .576 .931 r
.59676 .19987 .60349 .20869 .61695 .21145 .61024 .20261 Mtetra
.663 .742 .909 r
.61024 .20261 .61695 .21145 .63027 .20667 .62361 .19779 Mtetra
.62361 .19779 .63027 .20667 .64366 .20187 .63704 .19294 Mtetra
.63704 .19294 .64366 .20187 .65711 .19704 .65053 .18807 Mtetra
.65053 .18807 .65711 .19704 .67063 .19219 .66409 .18318 Mtetra
.66409 .18318 .67063 .19219 .68421 .18732 .67772 .17826 Mtetra
.67772 .17826 .68421 .18732 .69786 .18242 .69141 .17332 Mtetra
.69141 .17332 .69786 .18242 .71157 .1775 .70517 .16836 Mtetra
.70517 .16836 .71157 .1775 .72535 .17256 .719 .16337 Mtetra
.719 .16337 .72535 .17256 .73919 .16759 .73289 .15836 Mtetra
.73289 .15836 .73919 .16759 .75311 .1626 .74685 .15332 Mtetra
.74685 .15332 .75311 .1626 .76709 .15758 .76088 .14826 Mtetra
.76088 .14826 .76709 .15758 .78114 .15254 .77498 .14317 Mtetra
.664 .741 .908 r
.13846 .35542 .14652 .36293 .15773 .35887 .1497 .35133 Mtetra
.1497 .35133 .15773 .35887 .16899 .35479 .16098 .34722 Mtetra
.16098 .34722 .16899 .35479 .1803 .3507 .17232 .34309 Mtetra
.17232 .34309 .1803 .3507 .19166 .34658 .18371 .33894 Mtetra
.18371 .33894 .19166 .34658 .20307 .34245 .19515 .33478 Mtetra
.19515 .33478 .20307 .34245 .21453 .3383 .20663 .33059 Mtetra
.20663 .33059 .21453 .3383 .22604 .33414 .21817 .32639 Mtetra
.21817 .32639 .22604 .33414 .2376 .32995 .22976 .32217 Mtetra
.22976 .32217 .2376 .32995 .24921 .32574 .24141 .31793 Mtetra
.24141 .31793 .24921 .32574 .26087 .32152 .2531 .31367 Mtetra
.2531 .31367 .26087 .32152 .27259 .31728 .26485 .30939 Mtetra
.26485 .30939 .27259 .31728 .28436 .31301 .27665 .30509 Mtetra
.27665 .30509 .28436 .31301 .29618 .30873 .2885 .30078 Mtetra
.2885 .30078 .29618 .30873 .30806 .30443 .30041 .29644 Mtetra
.30041 .29644 .30806 .30443 .31998 .30011 .31237 .29208 Mtetra
.31237 .29208 .31998 .30011 .33197 .29577 .32439 .28771 Mtetra
.32439 .28771 .33197 .29577 .344 .29141 .33646 .28331 Mtetra
.33646 .28331 .344 .29141 .3561 .28703 .34858 .2789 Mtetra
.34858 .2789 .3561 .28703 .36824 .28263 .36077 .27446 Mtetra
.36077 .27446 .36824 .28263 .38045 .27821 .373 .27 Mtetra
.373 .27 .38045 .27821 .3927 .27377 .3853 .26553 Mtetra
.3853 .26553 .3927 .27377 .40502 .26932 .39764 .26103 Mtetra
.39764 .26103 .40502 .26932 .41739 .26483 .41005 .25651 Mtetra
.41005 .25651 .41739 .26483 .42982 .26033 .42252 .25197 Mtetra
.42252 .25197 .42982 .26033 .4423 .25581 .43504 .24741 Mtetra
.43504 .24741 .4423 .25581 .45485 .25127 .44762 .24283 Mtetra
.44762 .24283 .45485 .25127 .46745 .24671 .46026 .23822 Mtetra
.46026 .23822 .46745 .24671 .48011 .24212 .47296 .2336 Mtetra
.47296 .2336 .48011 .24212 .49283 .23751 .48571 .22895 Mtetra
.48571 .22895 .49283 .23751 .50561 .23289 .49853 .22429 Mtetra
.49853 .22429 .50561 .23289 .51844 .22824 .51141 .2196 Mtetra
.51141 .2196 .51844 .22824 .53134 .22356 .52435 .21488 Mtetra
.52435 .21488 .53134 .22356 .5443 .21887 .53735 .21015 Mtetra
.53735 .21015 .5443 .21887 .55732 .21416 .55041 .20539 Mtetra
.55041 .20539 .55732 .21416 .57041 .20942 .56353 .20061 Mtetra
.56353 .20061 .57041 .20942 .58355 .20466 .57672 .19581 Mtetra
.57672 .19581 .58355 .20466 .59676 .19987 .58996 .19098 Mtetra
.58996 .19098 .59676 .19987 .61024 .20261 .60328 .18614 Mtetra
.637 .591 .786 r
.60328 .18614 .61024 .20261 .62361 .19779 .61665 .18126 Mtetra
.61665 .18126 .62361 .19779 .63704 .19294 .63009 .17637 Mtetra
.63009 .17637 .63704 .19294 .65053 .18807 .6436 .17145 Mtetra
.6436 .17145 .65053 .18807 .66409 .18318 .65717 .16651 Mtetra
.65717 .16651 .66409 .18318 .67772 .17826 .6708 .16154 Mtetra
.6708 .16154 .67772 .17826 .69141 .17332 .68451 .15655 Mtetra
.68451 .15655 .69141 .17332 .70517 .16836 .69828 .15154 Mtetra
.69828 .15154 .70517 .16836 .719 .16337 .71211 .1465 Mtetra
.71211 .1465 .719 .16337 .73289 .15836 .72601 .14144 Mtetra
.72601 .14144 .73289 .15836 .74685 .15332 .73999 .13635 Mtetra
.73999 .13635 .74685 .15332 .76088 .14826 .75403 .13123 Mtetra
.75403 .13123 .76088 .14826 .77498 .14317 .76814 .12609 Mtetra
.664 .741 .908 r
.13033 .34785 .13846 .35542 .1497 .35133 .1416 .34373 Mtetra
.1416 .34373 .1497 .35133 .16098 .34722 .15291 .33958 Mtetra
.15291 .33958 .16098 .34722 .17232 .34309 .16428 .33542 Mtetra
.16428 .33542 .17232 .34309 .18371 .33894 .17569 .33124 Mtetra
.17569 .33124 .18371 .33894 .19515 .33478 .18716 .32704 Mtetra
.18716 .32704 .19515 .33478 .20663 .33059 .19868 .32282 Mtetra
.19868 .32282 .20663 .33059 .21817 .32639 .21025 .31858 Mtetra
.21025 .31858 .21817 .32639 .22976 .32217 .22187 .31433 Mtetra
.22187 .31433 .22976 .32217 .24141 .31793 .23354 .31005 Mtetra
.23354 .31005 .24141 .31793 .2531 .31367 .24527 .30576 Mtetra
.24527 .30576 .2531 .31367 .26485 .30939 .25704 .30144 Mtetra
.25704 .30144 .26485 .30939 .27665 .30509 .26888 .29711 Mtetra
.26888 .29711 .27665 .30509 .2885 .30078 .28076 .29276 Mtetra
.28076 .29276 .2885 .30078 .30041 .29644 .2927 .28838 Mtetra
.2927 .28838 .30041 .29644 .31237 .29208 .3047 .28399 Mtetra
.3047 .28399 .31237 .29208 .32439 .28771 .31674 .27958 Mtetra
.31674 .27958 .32439 .28771 .33646 .28331 .32885 .27514 Mtetra
.32885 .27514 .33646 .28331 .34858 .2789 .34101 .27069 Mtetra
.34101 .27069 .34858 .2789 .36077 .27446 .35322 .26622 Mtetra
.35322 .26622 .36077 .27446 .373 .27 .36549 .26172 Mtetra
.36549 .26172 .373 .27 .3853 .26553 .37782 .25721 Mtetra
.37782 .25721 .3853 .26553 .39764 .26103 .39021 .25267 Mtetra
.39021 .25267 .39764 .26103 .41005 .25651 .40265 .24811 Mtetra
.40265 .24811 .41005 .25651 .42252 .25197 .41515 .24353 Mtetra
.41515 .24353 .42252 .25197 .43504 .24741 .42771 .23893 Mtetra
.42771 .23893 .43504 .24741 .44762 .24283 .44033 .23431 Mtetra
.44033 .23431 .44762 .24283 .46026 .23822 .453 .22967 Mtetra
.453 .22967 .46026 .23822 .47296 .2336 .46574 .225 Mtetra
.46574 .225 .47296 .2336 .48571 .22895 .47854 .22032 Mtetra
.47854 .22032 .48571 .22895 .49853 .22429 .49139 .21561 Mtetra
.49139 .21561 .49853 .22429 .51141 .2196 .50431 .21088 Mtetra
.50431 .21088 .51141 .2196 .52435 .21488 .51729 .20612 Mtetra
.51729 .20612 .52435 .21488 .53735 .21015 .53033 .20135 Mtetra
.53033 .20135 .53735 .21015 .55041 .20539 .54343 .19655 Mtetra
.54343 .19655 .55041 .20539 .56353 .20061 .55659 .19173 Mtetra
.55659 .19173 .56353 .20061 .57672 .19581 .56982 .18688 Mtetra
.56982 .18688 .57672 .19581 .58996 .19098 .58311 .18202 Mtetra
.58311 .18202 .58996 .19098 .60328 .18614 .59647 .17712 Mtetra
.59647 .17712 .60328 .18614 .61665 .18126 .60989 .17221 Mtetra
.60989 .17221 .61665 .18126 .63009 .17637 .62337 .16727 Mtetra
.62337 .16727 .63009 .17637 .6436 .17145 .63692 .16231 Mtetra
.63692 .16231 .6436 .17145 .65717 .16651 .65053 .15732 Mtetra
.65053 .15732 .65717 .16651 .6708 .16154 .66421 .15231 Mtetra
.66421 .15231 .6708 .16154 .68451 .15655 .67796 .14728 Mtetra
.67796 .14728 .68451 .15655 .69828 .15154 .69178 .14222 Mtetra
.69178 .14222 .69828 .15154 .71211 .1465 .70566 .13713 Mtetra
.70566 .13713 .71211 .1465 .72601 .14144 .71961 .13202 Mtetra
.71961 .13202 .72601 .14144 .73999 .13635 .73363 .12689 Mtetra
.73363 .12689 .73999 .13635 .75403 .13123 .74772 .12173 Mtetra
.74772 .12173 .75403 .13123 .76814 .12609 .76188 .11654 Mtetra
.12213 .34022 .13033 .34785 .1416 .34373 .13343 .33606 Mtetra
.13343 .33606 .1416 .34373 .15291 .33958 .14477 .33188 Mtetra
.14477 .33188 .15291 .33958 .16428 .33542 .15616 .32769 Mtetra
.15616 .32769 .16428 .33542 .17569 .33124 .16761 .32347 Mtetra
.16761 .32347 .17569 .33124 .18716 .32704 .17911 .31924 Mtetra
.17911 .31924 .18716 .32704 .19868 .32282 .19065 .31498 Mtetra
.19065 .31498 .19868 .32282 .21025 .31858 .20225 .31071 Mtetra
.20225 .31071 .21025 .31858 .22187 .31433 .2139 .30642 Mtetra
.2139 .30642 .22187 .31433 .23354 .31005 .22561 .30211 Mtetra
.22561 .30211 .23354 .31005 .24527 .30576 .23736 .29778 Mtetra
.23736 .29778 .24527 .30576 .25704 .30144 .24917 .29343 Mtetra
.24917 .29343 .25704 .30144 .26888 .29711 .26104 .28906 Mtetra
.26104 .28906 .26888 .29711 .28076 .29276 .27296 .28467 Mtetra
.27296 .28467 .28076 .29276 .2927 .28838 .28493 .28026 Mtetra
.28493 .28026 .2927 .28838 .3047 .28399 .29695 .27583 Mtetra
.29695 .27583 .3047 .28399 .31674 .27958 .30904 .27138 Mtetra
.30904 .27138 .31674 .27958 .32885 .27514 .32117 .26691 Mtetra
.32117 .26691 .32885 .27514 .34101 .27069 .33337 .26241 Mtetra
.33337 .26241 .34101 .27069 .35322 .26622 .34562 .2579 Mtetra
.34562 .2579 .35322 .26622 .36549 .26172 .35792 .25337 Mtetra
.35792 .25337 .36549 .26172 .37782 .25721 .37029 .24881 Mtetra
.37029 .24881 .37782 .25721 .39021 .25267 .38271 .24424 Mtetra
.38271 .24424 .39021 .25267 .40265 .24811 .39519 .23964 Mtetra
.39519 .23964 .40265 .24811 .41515 .24353 .40772 .23502 Mtetra
.40772 .23502 .41515 .24353 .42771 .23893 .42032 .23039 Mtetra
.42032 .23039 .42771 .23893 .44033 .23431 .43297 .22572 Mtetra
.43297 .22572 .44033 .23431 .453 .22967 .44569 .22104 Mtetra
.44569 .22104 .453 .22967 .46574 .225 .45846 .21634 Mtetra
.45846 .21634 .46574 .225 .47854 .22032 .4713 .21161 Mtetra
.4713 .21161 .47854 .22032 .49139 .21561 .48419 .20686 Mtetra
.48419 .20686 .49139 .21561 .50431 .21088 .49715 .20209 Mtetra
.49715 .20209 .50431 .21088 .51729 .20612 .51017 .19729 Mtetra
.51017 .19729 .51729 .20612 .53033 .20135 .52325 .19247 Mtetra
.52325 .19247 .53033 .20135 .54343 .19655 .53639 .18763 Mtetra
.53639 .18763 .54343 .19655 .55659 .19173 .5496 .18277 Mtetra
.5496 .18277 .55659 .19173 .56982 .18688 .56287 .17788 Mtetra
.56287 .17788 .56982 .18688 .58311 .18202 .5762 .17297 Mtetra
.5762 .17297 .58311 .18202 .59647 .17712 .5896 .16803 Mtetra
.5896 .16803 .59647 .17712 .60989 .17221 .60306 .16307 Mtetra
.60306 .16307 .60989 .17221 .62337 .16727 .61659 .15809 Mtetra
.61659 .15809 .62337 .16727 .63692 .16231 .63018 .15308 Mtetra
.63018 .15308 .63692 .16231 .65053 .15732 .64384 .14805 Mtetra
.64384 .14805 .65053 .15732 .66421 .15231 .65757 .143 Mtetra
.65757 .143 .66421 .15231 .67796 .14728 .67136 .13792 Mtetra
.67136 .13792 .67796 .14728 .69178 .14222 .68522 .13281 Mtetra
.68522 .13281 .69178 .14222 .70566 .13713 .69915 .12768 Mtetra
.69915 .12768 .70566 .13713 .71961 .13202 .71315 .12252 Mtetra
.71315 .12252 .71961 .13202 .73363 .12689 .72722 .11734 Mtetra
.72722 .11734 .73363 .12689 .74772 .12173 .74135 .11213 Mtetra
.74135 .11213 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.11387 .33253 .12213 .34022 .13343 .33606 .12519 .32833 Mtetra
.12519 .32833 .13343 .33606 .14477 .33188 .13656 .32412 Mtetra
.13656 .32412 .14477 .33188 .15616 .32769 .14799 .31989 Mtetra
.14799 .31989 .15616 .32769 .16761 .32347 .15946 .31564 Mtetra
.15946 .31564 .16761 .32347 .17911 .31924 .17099 .31137 Mtetra
.17099 .31137 .17911 .31924 .19065 .31498 .18256 .30708 Mtetra
.18256 .30708 .19065 .31498 .20225 .31071 .19419 .30277 Mtetra
.19419 .30277 .20225 .31071 .2139 .30642 .20587 .29844 Mtetra
.20587 .29844 .2139 .30642 .22561 .30211 .21761 .2941 Mtetra
.21761 .2941 .22561 .30211 .23736 .29778 .2294 .28973 Mtetra
.2294 .28973 .23736 .29778 .24917 .29343 .24124 .28534 Mtetra
.24124 .28534 .24917 .29343 .26104 .28906 .25313 .28094 Mtetra
.25313 .28094 .26104 .28906 .27296 .28467 .26508 .27651 Mtetra
.26508 .27651 .27296 .28467 .28493 .28026 .27709 .27206 Mtetra
.27709 .27206 .28493 .28026 .29695 .27583 .28915 .26759 Mtetra
.28915 .26759 .29695 .27583 .30904 .27138 .30126 .26311 Mtetra
.30126 .26311 .30904 .27138 .32117 .26691 .31343 .2586 Mtetra
.31343 .2586 .32117 .26691 .33337 .26241 .32566 .25407 Mtetra
.32566 .25407 .33337 .26241 .34562 .2579 .33795 .24952 Mtetra
.33795 .24952 .34562 .2579 .35792 .25337 .35029 .24494 Mtetra
.35029 .24494 .35792 .25337 .37029 .24881 .36269 .24035 Mtetra
.36269 .24035 .37029 .24881 .38271 .24424 .37514 .23574 Mtetra
.37514 .23574 .38271 .24424 .39519 .23964 .38766 .2311 Mtetra
.38766 .2311 .39519 .23964 .40772 .23502 .40023 .22644 Mtetra
.40023 .22644 .40772 .23502 .42032 .23039 .41286 .22176 Mtetra
.41286 .22176 .42032 .23039 .43297 .22572 .42556 .21706 Mtetra
.42556 .21706 .43297 .22572 .44569 .22104 .43831 .21234 Mtetra
.43831 .21234 .44569 .22104 .45846 .21634 .45112 .20759 Mtetra
.45112 .20759 .45846 .21634 .4713 .21161 .46399 .20282 Mtetra
.46399 .20282 .4713 .21161 .48419 .20686 .47693 .19803 Mtetra
.47693 .19803 .48419 .20686 .49715 .20209 .48993 .19321 Mtetra
.48993 .19321 .49715 .20209 .51017 .19729 .50298 .18838 Mtetra
.50298 .18838 .51017 .19729 .52325 .19247 .5161 .18352 Mtetra
.5161 .18352 .52325 .19247 .53639 .18763 .52929 .17863 Mtetra
.52929 .17863 .53639 .18763 .5496 .18277 .54254 .17372 Mtetra
.54254 .17372 .5496 .18277 .56287 .17788 .55585 .16879 Mtetra
.55585 .16879 .56287 .17788 .5762 .17297 .56922 .16384 Mtetra
.56922 .16384 .5762 .17297 .5896 .16803 .58266 .15886 Mtetra
.58266 .15886 .5896 .16803 .60306 .16307 .59617 .15386 Mtetra
.59617 .15386 .60306 .16307 .61659 .15809 .60974 .14883 Mtetra
.60974 .14883 .61659 .15809 .63018 .15308 .62338 .14378 Mtetra
.62338 .14378 .63018 .15308 .64384 .14805 .63708 .1387 Mtetra
.63708 .1387 .64384 .14805 .65757 .143 .65086 .1336 Mtetra
.65086 .1336 .65757 .143 .67136 .13792 .6647 .12847 Mtetra
.6647 .12847 .67136 .13792 .68522 .13281 .6786 .12332 Mtetra
.6786 .12332 .68522 .13281 .69915 .12768 .69258 .11814 Mtetra
.69258 .11814 .69915 .12768 .71315 .12252 .70663 .11294 Mtetra
.70663 .11294 .71315 .12252 .72722 .11734 .72074 .10771 Mtetra
.72074 .10771 .72722 .11734 .74135 .11213 .73493 .10245 Mtetra
.73493 .10245 .74135 .11213 .75556 .1069 .74918 .09717 Mtetra
.10554 .32477 .11387 .33253 .12519 .32833 .11689 .32054 Mtetra
.11689 .32054 .12519 .32833 .13656 .32412 .12829 .31629 Mtetra
.12829 .31629 .13656 .32412 .14799 .31989 .13974 .31203 Mtetra
.13974 .31203 .14799 .31989 .15946 .31564 .15124 .30774 Mtetra
.15124 .30774 .15946 .31564 .17099 .31137 .1628 .30344 Mtetra
.1628 .30344 .17099 .31137 .18256 .30708 .1744 .29911 Mtetra
.1744 .29911 .18256 .30708 .19419 .30277 .18606 .29477 Mtetra
.18606 .29477 .19419 .30277 .20587 .29844 .19778 .2904 Mtetra
.19778 .2904 .20587 .29844 .21761 .2941 .20954 .28602 Mtetra
.20954 .28602 .21761 .2941 .2294 .28973 .22136 .28162 Mtetra
.22136 .28162 .2294 .28973 .24124 .28534 .23323 .27719 Mtetra
.23323 .27719 .24124 .28534 .25313 .28094 .24516 .27275 Mtetra
.24516 .27275 .25313 .28094 .26508 .27651 .25714 .26828 Mtetra
.25714 .26828 .26508 .27651 .27709 .27206 .26918 .2638 Mtetra
.26918 .2638 .27709 .27206 .28915 .26759 .28127 .25929 Mtetra
.28127 .25929 .28915 .26759 .30126 .26311 .29342 .25477 Mtetra
.29342 .25477 .30126 .26311 .31343 .2586 .30563 .25022 Mtetra
.30563 .25022 .31343 .2586 .32566 .25407 .31789 .24565 Mtetra
.31789 .24565 .32566 .25407 .33795 .24952 .33021 .24106 Mtetra
.33021 .24106 .33795 .24952 .35029 .24494 .34259 .23645 Mtetra
.34259 .23645 .35029 .24494 .36269 .24035 .35502 .23182 Mtetra
.35502 .23182 .36269 .24035 .37514 .23574 .36751 .22716 Mtetra
.36751 .22716 .37514 .23574 .38766 .2311 .38006 .22248 Mtetra
.38006 .22248 .38766 .2311 .40023 .22644 .39267 .21779 Mtetra
.39267 .21779 .40023 .22644 .41286 .22176 .40534 .21306 Mtetra
.40534 .21306 .41286 .22176 .42556 .21706 .41807 .20832 Mtetra
.41807 .20832 .42556 .21706 .43831 .21234 .43086 .20356 Mtetra
.43086 .20356 .43831 .21234 .45112 .20759 .44372 .19877 Mtetra
.44372 .19877 .45112 .20759 .46399 .20282 .45663 .19396 Mtetra
.45663 .19396 .46399 .20282 .47693 .19803 .4696 .18912 Mtetra
.4696 .18912 .47693 .19803 .48993 .19321 .48264 .18427 Mtetra
.48264 .18427 .48993 .19321 .50298 .18838 .49574 .17939 Mtetra
.49574 .17939 .50298 .18838 .5161 .18352 .5089 .17448 Mtetra
.5089 .17448 .5161 .18352 .52929 .17863 .52212 .16955 Mtetra
.52212 .16955 .52929 .17863 .54254 .17372 .53541 .1646 Mtetra
.53541 .1646 .54254 .17372 .55585 .16879 .54877 .15963 Mtetra
.54877 .15963 .55585 .16879 .56922 .16384 .56218 .15463 Mtetra
.56218 .15463 .56922 .16384 .58266 .15886 .57567 .1496 Mtetra
.57567 .1496 .58266 .15886 .59617 .15386 .58922 .14455 Mtetra
.58922 .14455 .59617 .15386 .60974 .14883 .60283 .13948 Mtetra
.60283 .13948 .60974 .14883 .62338 .14378 .61652 .13438 Mtetra
.61652 .13438 .62338 .14378 .63708 .1387 .63027 .12926 Mtetra
.63027 .12926 .63708 .1387 .65086 .1336 .64408 .12411 Mtetra
.64408 .12411 .65086 .1336 .6647 .12847 .65797 .11894 Mtetra
.65797 .11894 .6647 .12847 .6786 .12332 .67193 .11374 Mtetra
.67193 .11374 .6786 .12332 .69258 .11814 .68595 .10851 Mtetra
.68595 .10851 .69258 .11814 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.09714 .31695 .10554 .32477 .11689 .32054 .10852 .31268 Mtetra
.10852 .31268 .11689 .32054 .12829 .31629 .11995 .3084 Mtetra
.11995 .3084 .12829 .31629 .13974 .31203 .13143 .3041 Mtetra
.13143 .3041 .13974 .31203 .15124 .30774 .14296 .29978 Mtetra
.14296 .29978 .15124 .30774 .1628 .30344 .15454 .29544 Mtetra
.15454 .29544 .1628 .30344 .1744 .29911 .16618 .29108 Mtetra
.16618 .29108 .1744 .29911 .18606 .29477 .17787 .28669 Mtetra
.17787 .28669 .18606 .29477 .19778 .2904 .18961 .28229 Mtetra
.18961 .28229 .19778 .2904 .20954 .28602 .20141 .27787 Mtetra
.20141 .27787 .20954 .28602 .22136 .28162 .21326 .27343 Mtetra
.21326 .27343 .22136 .28162 .23323 .27719 .22516 .26897 Mtetra
.22516 .26897 .23323 .27719 .24516 .27275 .23712 .26449 Mtetra
.23712 .26449 .24516 .27275 .25714 .26828 .24914 .25999 Mtetra
.24914 .25999 .25714 .26828 .26918 .2638 .26121 .25546 Mtetra
.26121 .25546 .26918 .2638 .28127 .25929 .27333 .25092 Mtetra
.27333 .25092 .28127 .25929 .29342 .25477 .28552 .24635 Mtetra
.28552 .24635 .29342 .25477 .30563 .25022 .29776 .24177 Mtetra
.29776 .24177 .30563 .25022 .31789 .24565 .31005 .23716 Mtetra
.31005 .23716 .31789 .24565 .33021 .24106 .32241 .23253 Mtetra
.32241 .23253 .33021 .24106 .34259 .23645 .33482 .22788 Mtetra
.33482 .22788 .34259 .23645 .35502 .23182 .34729 .2232 Mtetra
.34729 .2232 .35502 .23182 .36751 .22716 .35982 .21851 Mtetra
.35982 .21851 .36751 .22716 .38006 .22248 .3724 .21379 Mtetra
.3724 .21379 .38006 .22248 .39267 .21779 .38505 .20905 Mtetra
.38505 .20905 .39267 .21779 .40534 .21306 .39776 .20429 Mtetra
.39776 .20429 .40534 .21306 .41807 .20832 .41053 .19951 Mtetra
.41053 .19951 .41807 .20832 .43086 .20356 .42335 .1947 Mtetra
.42335 .1947 .43086 .20356 .44372 .19877 .43624 .18987 Mtetra
.43624 .18987 .44372 .19877 .45663 .19396 .4492 .18501 Mtetra
.4492 .18501 .45663 .19396 .4696 .18912 .46221 .18014 Mtetra
.46221 .18014 .4696 .18912 .48264 .18427 .47529 .17524 Mtetra
.47529 .17524 .48264 .18427 .49574 .17939 .48843 .17031 Mtetra
.48843 .17031 .49574 .17939 .5089 .17448 .50163 .16537 Mtetra
.50163 .16537 .5089 .17448 .52212 .16955 .51489 .16039 Mtetra
.51489 .16039 .52212 .16955 .53541 .1646 .52823 .1554 Mtetra
.52823 .1554 .53541 .1646 .54877 .15963 .54162 .15038 Mtetra
.54162 .15038 .54877 .15963 .56218 .15463 .55508 .14533 Mtetra
.55508 .14533 .56218 .15463 .57567 .1496 .56861 .14026 Mtetra
.56861 .14026 .57567 .1496 .58922 .14455 .5822 .13517 Mtetra
.5822 .13517 .58922 .14455 .60283 .13948 .59586 .13005 Mtetra
.59586 .13005 .60283 .13948 .61652 .13438 .60959 .12491 Mtetra
.60959 .12491 .61652 .13438 .63027 .12926 .62339 .11974 Mtetra
.62339 .11974 .63027 .12926 .64408 .12411 .63725 .11454 Mtetra
.63725 .11454 .64408 .12411 .65797 .11894 .65119 .10932 Mtetra
.65119 .10932 .65797 .11894 .67193 .11374 .66519 .10407 Mtetra
.66519 .10407 .67193 .11374 .68595 .10851 .67926 .0988 Mtetra
.67926 .0988 .68595 .10851 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.08867 .30906 .09714 .31695 .10852 .31268 .10008 .30476 Mtetra
.10008 .30476 .10852 .31268 .11995 .3084 .11153 .30044 Mtetra
.11153 .30044 .11995 .3084 .13143 .3041 .12304 .29611 Mtetra
.12304 .29611 .13143 .3041 .14296 .29978 .1346 .29175 Mtetra
.1346 .29175 .14296 .29978 .15454 .29544 .14622 .28737 Mtetra
.14622 .28737 .15454 .29544 .16618 .29108 .15788 .28297 Mtetra
.15788 .28297 .16618 .29108 .17787 .28669 .1696 .27855 Mtetra
.1696 .27855 .17787 .28669 .18961 .28229 .18138 .27412 Mtetra
.18138 .27412 .18961 .28229 .20141 .27787 .1932 .26966 Mtetra
.1932 .26966 .20141 .27787 .21326 .27343 .20509 .26518 Mtetra
.20509 .26518 .21326 .27343 .22516 .26897 .21702 .26068 Mtetra
.21702 .26068 .22516 .26897 .23712 .26449 .22901 .25616 Mtetra
.22901 .25616 .23712 .26449 .24914 .25999 .24106 .25162 Mtetra
.24106 .25162 .24914 .25999 .26121 .25546 .25317 .24706 Mtetra
.25317 .24706 .26121 .25546 .27333 .25092 .26532 .24247 Mtetra
.26532 .24247 .27333 .25092 .28552 .24635 .27754 .23787 Mtetra
.27754 .23787 .28552 .24635 .29776 .24177 .28981 .23324 Mtetra
.28981 .23324 .29776 .24177 .31005 .23716 .30215 .22859 Mtetra
.30215 .22859 .31005 .23716 .32241 .23253 .31453 .22393 Mtetra
.31453 .22393 .32241 .23253 .33482 .22788 .32698 .21923 Mtetra
.32698 .21923 .33482 .22788 .34729 .2232 .33949 .21452 Mtetra
.33949 .21452 .34729 .2232 .35982 .21851 .35205 .20978 Mtetra
.35205 .20978 .35982 .21851 .3724 .21379 .36468 .20502 Mtetra
.36468 .20502 .3724 .21379 .38505 .20905 .37736 .20024 Mtetra
.37736 .20024 .38505 .20905 .39776 .20429 .39011 .19544 Mtetra
.39011 .19544 .39776 .20429 .41053 .19951 .40291 .19061 Mtetra
.40291 .19061 .41053 .19951 .42335 .1947 .41578 .18576 Mtetra
.41578 .18576 .42335 .1947 .43624 .18987 .42871 .18089 Mtetra
.42871 .18089 .43624 .18987 .4492 .18501 .4417 .17599 Mtetra
.4417 .17599 .4492 .18501 .46221 .18014 .45475 .17107 Mtetra
.45475 .17107 .46221 .18014 .47529 .17524 .46787 .16613 Mtetra
.46787 .16613 .47529 .17524 .48843 .17031 .48105 .16116 Mtetra
.48105 .16116 .48843 .17031 .50163 .16537 .49429 .15617 Mtetra
.49429 .15617 .50163 .16537 .51489 .16039 .5076 .15115 Mtetra
.5076 .15115 .51489 .16039 .52823 .1554 .52097 .14611 Mtetra
.52097 .14611 .52823 .1554 .54162 .15038 .53441 .14104 Mtetra
.53441 .14104 .54162 .15038 .55508 .14533 .54792 .13595 Mtetra
.54792 .13595 .55508 .14533 .56861 .14026 .56149 .13084 Mtetra
.56149 .13084 .56861 .14026 .5822 .13517 .57513 .1257 Mtetra
.57513 .1257 .5822 .13517 .59586 .13005 .58883 .12053 Mtetra
.58883 .12053 .59586 .13005 .60959 .12491 .60261 .11534 Mtetra
.60261 .11534 .60959 .12491 .62339 .11974 .61645 .11012 Mtetra
.61645 .11012 .62339 .11974 .63725 .11454 .63036 .10488 Mtetra
.63036 .10488 .63725 .11454 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09431 Mtetra
.65839 .09431 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.08013 .30111 .08867 .30906 .10008 .30476 .09156 .29677 Mtetra
.09156 .29677 .10008 .30476 .11153 .30044 .10305 .29242 Mtetra
.10305 .29242 .11153 .30044 .12304 .29611 .11459 .28804 Mtetra
.11459 .28804 .12304 .29611 .1346 .29175 .12618 .28365 Mtetra
.12618 .28365 .1346 .29175 .14622 .28737 .13782 .27924 Mtetra
.13782 .27924 .14622 .28737 .15788 .28297 .14952 .2748 Mtetra
.14952 .2748 .15788 .28297 .1696 .27855 .16127 .27035 Mtetra
.16127 .27035 .1696 .27855 .18138 .27412 .17307 .26587 Mtetra
.17307 .26587 .18138 .27412 .1932 .26966 .18493 .26137 Mtetra
.18493 .26137 .1932 .26966 .20509 .26518 .19684 .25686 Mtetra
.19684 .25686 .20509 .26518 .21702 .26068 .20881 .25232 Mtetra
.20881 .25232 .21702 .26068 .22901 .25616 .22084 .24776 Mtetra
.22084 .24776 .22901 .25616 .24106 .25162 .23292 .24318 Mtetra
.23292 .24318 .24106 .25162 .25317 .24706 .24505 .23858 Mtetra
.24505 .23858 .25317 .24706 .26532 .24247 .25725 .23396 Mtetra
.25725 .23396 .26532 .24247 .27754 .23787 .2695 .22931 Mtetra
.2695 .22931 .27754 .23787 .28981 .23324 .2818 .22464 Mtetra
.2818 .22464 .28981 .23324 .30215 .22859 .29417 .21996 Mtetra
.29417 .21996 .30215 .22859 .31453 .22393 .30659 .21525 Mtetra
.30659 .21525 .31453 .22393 .32698 .21923 .31908 .21051 Mtetra
.31908 .21051 .32698 .21923 .33949 .21452 .33162 .20576 Mtetra
.33162 .20576 .33949 .21452 .35205 .20978 .34422 .20098 Mtetra
.34422 .20098 .35205 .20978 .36468 .20502 .35688 .19618 Mtetra
.35688 .19618 .36468 .20502 .37736 .20024 .3696 .19136 Mtetra
.3696 .19136 .37736 .20024 .39011 .19544 .38239 .18651 Mtetra
.38239 .18651 .39011 .19544 .40291 .19061 .39523 .18164 Mtetra
.39523 .18164 .40291 .19061 .41578 .18576 .40813 .17675 Mtetra
.40813 .17675 .41578 .18576 .42871 .18089 .4211 .17183 Mtetra
.4211 .17183 .42871 .18089 .4417 .17599 .43413 .16689 Mtetra
.43413 .16689 .4417 .17599 .45475 .17107 .44723 .16193 Mtetra
.44723 .16193 .45475 .17107 .46787 .16613 .46038 .15694 Mtetra
.46038 .15694 .46787 .16613 .48105 .16116 .4736 .15192 Mtetra
.4736 .15192 .48105 .16116 .49429 .15617 .48689 .14689 Mtetra
.48689 .14689 .49429 .15617 .5076 .15115 .50024 .14183 Mtetra
.50024 .14183 .5076 .15115 .52097 .14611 .51366 .13674 Mtetra
.51366 .13674 .52097 .14611 .53441 .14104 .52714 .13163 Mtetra
.52714 .13163 .53441 .14104 .54792 .13595 .54069 .12649 Mtetra
.54069 .12649 .54792 .13595 .56149 .13084 .5543 .12133 Mtetra
.5543 .12133 .56149 .13084 .57513 .1257 .56798 .11614 Mtetra
.56798 .11614 .57513 .1257 .58883 .12053 .58173 .11093 Mtetra
.58173 .11093 .58883 .12053 .60261 .11534 .59555 .10569 Mtetra
.59555 .10569 .60261 .11534 .61645 .11012 .60944 .10042 Mtetra
.60944 .10042 .61645 .11012 .63036 .10488 .6234 .09513 Mtetra
.6234 .09513 .63036 .10488 .64434 .09961 .63742 .08981 Mtetra
.63742 .08981 .64434 .09961 .65839 .09431 .65152 .08447 Mtetra
.65152 .08447 .65839 .09431 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.07152 .29309 .08013 .30111 .09156 .29677 .08298 .28872 Mtetra
.08298 .28872 .09156 .29677 .10305 .29242 .09449 .28433 Mtetra
.09449 .28433 .10305 .29242 .11459 .28804 .10606 .27992 Mtetra
.10606 .27992 .11459 .28804 .12618 .28365 .11768 .27548 Mtetra
.11768 .27548 .12618 .28365 .13782 .27924 .12935 .27103 Mtetra
.12935 .27103 .13782 .27924 .14952 .2748 .14108 .26656 Mtetra
.14108 .26656 .14952 .2748 .16127 .27035 .15286 .26207 Mtetra
.15286 .26207 .16127 .27035 .17307 .26587 .1647 .25755 Mtetra
.1647 .25755 .17307 .26587 .18493 .26137 .17659 .25302 Mtetra
.17659 .25302 .18493 .26137 .19684 .25686 .18853 .24846 Mtetra
.18853 .24846 .19684 .25686 .20881 .25232 .20053 .24389 Mtetra
.20053 .24389 .20881 .25232 .22084 .24776 .21259 .23929 Mtetra
.21259 .23929 .22084 .24776 .23292 .24318 .2247 .23467 Mtetra
.2247 .23467 .23292 .24318 .24505 .23858 .23687 .23003 Mtetra
.23687 .23003 .24505 .23858 .25725 .23396 .2491 .22536 Mtetra
.2491 .22536 .25725 .23396 .2695 .22931 .26138 .22068 Mtetra
.26138 .22068 .2695 .22931 .2818 .22464 .27373 .21597 Mtetra
.27373 .21597 .2818 .22464 .29417 .21996 .28613 .21124 Mtetra
.28613 .21124 .29417 .21996 .30659 .21525 .29858 .20649 Mtetra
.29858 .20649 .30659 .21525 .31908 .21051 .3111 .20172 Mtetra
.3111 .20172 .31908 .21051 .33162 .20576 .32368 .19692 Mtetra
.32368 .19692 .33162 .20576 .34422 .20098 .33632 .1921 Mtetra
.33632 .1921 .34422 .20098 .35688 .19618 .34902 .18726 Mtetra
.34902 .18726 .35688 .19618 .3696 .19136 .36178 .18239 Mtetra
.36178 .18239 .3696 .19136 .38239 .18651 .3746 .1775 Mtetra
.3746 .1775 .38239 .18651 .39523 .18164 .38748 .17259 Mtetra
.38748 .17259 .39523 .18164 .40813 .17675 .40042 .16765 Mtetra
.40042 .16765 .40813 .17675 .4211 .17183 .41343 .16269 Mtetra
.41343 .16269 .4211 .17183 .43413 .16689 .4265 .15771 Mtetra
.4265 .15771 .43413 .16689 .44723 .16193 .43963 .1527 Mtetra
.43963 .1527 .44723 .16193 .46038 .15694 .45283 .14766 Mtetra
.45283 .14766 .46038 .15694 .4736 .15192 .46609 .14261 Mtetra
.46609 .14261 .4736 .15192 .48689 .14689 .47942 .13752 Mtetra
.47942 .13752 .48689 .14689 .50024 .14183 .49281 .13242 Mtetra
.49281 .13242 .50024 .14183 .51366 .13674 .50627 .12728 Mtetra
.50627 .12728 .51366 .13674 .52714 .13163 .5198 .12212 Mtetra
.5198 .12212 .52714 .13163 .54069 .12649 .53339 .11694 Mtetra
.53339 .11694 .54069 .12649 .5543 .12133 .54705 .11173 Mtetra
.54705 .11173 .5543 .12133 .56798 .11614 .56078 .1065 Mtetra
.56078 .1065 .56798 .11614 .58173 .11093 .57457 .10123 Mtetra
.57457 .10123 .58173 .11093 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10042 .60237 .09063 Mtetra
.60237 .09063 .60944 .10042 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63742 .08981 .63045 .07992 Mtetra
.63045 .07992 .63742 .08981 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.06283 .285 .07152 .29309 .08298 .28872 .07432 .2806 Mtetra
.07432 .2806 .08298 .28872 .09449 .28433 .08587 .27617 Mtetra
.08587 .27617 .09449 .28433 .10606 .27992 .09746 .27172 Mtetra
.09746 .27172 .10606 .27992 .11768 .27548 .10911 .26725 Mtetra
.10911 .26725 .11768 .27548 .12935 .27103 .12082 .26276 Mtetra
.12082 .26276 .12935 .27103 .14108 .26656 .13257 .25825 Mtetra
.13257 .25825 .14108 .26656 .15286 .26207 .14438 .25372 Mtetra
.14438 .25372 .15286 .26207 .1647 .25755 .15625 .24917 Mtetra
.15625 .24917 .1647 .25755 .17659 .25302 .16817 .24459 Mtetra
.16817 .24459 .17659 .25302 .18853 .24846 .18015 .24 Mtetra
.18015 .24 .18853 .24846 .20053 .24389 .19218 .23538 Mtetra
.19218 .23538 .20053 .24389 .21259 .23929 .20427 .23074 Mtetra
.20427 .23074 .21259 .23929 .2247 .23467 .21642 .22608 Mtetra
.21642 .22608 .2247 .23467 .23687 .23003 .22862 .2214 Mtetra
.22862 .2214 .23687 .23003 .2491 .22536 .24088 .2167 Mtetra
.24088 .2167 .2491 .22536 .26138 .22068 .2532 .21197 Mtetra
.2532 .21197 .26138 .22068 .27373 .21597 .26558 .20722 Mtetra
.26558 .20722 .27373 .21597 .28613 .21124 .27801 .20245 Mtetra
.27801 .20245 .28613 .21124 .29858 .20649 .29051 .19766 Mtetra
.29051 .19766 .29858 .20649 .3111 .20172 .30306 .19284 Mtetra
.30306 .19284 .3111 .20172 .32368 .19692 .31567 .188 Mtetra
.31567 .188 .32368 .19692 .33632 .1921 .32835 .18314 Mtetra
.32835 .18314 .33632 .1921 .34902 .18726 .34108 .17826 Mtetra
.34108 .17826 .34902 .18726 .36178 .18239 .35388 .17335 Mtetra
.35388 .17335 .36178 .18239 .3746 .1775 .36674 .16841 Mtetra
.36674 .16841 .3746 .1775 .38748 .17259 .37966 .16346 Mtetra
.37966 .16346 .38748 .17259 .40042 .16765 .39264 .15847 Mtetra
.39264 .15847 .40042 .16765 .41343 .16269 .40569 .15347 Mtetra
.40569 .15347 .41343 .16269 .4265 .15771 .4188 .14844 Mtetra
.4188 .14844 .4265 .15771 .43963 .1527 .43197 .14339 Mtetra
.43197 .14339 .43963 .1527 .45283 .14766 .44521 .13831 Mtetra
.44521 .13831 .45283 .14766 .46609 .14261 .45852 .1332 Mtetra
.45852 .1332 .46609 .14261 .47942 .13752 .47188 .12807 Mtetra
.47188 .12807 .47942 .13752 .49281 .13242 .48532 .12292 Mtetra
.48532 .12292 .49281 .13242 .50627 .12728 .49882 .11774 Mtetra
.49882 .11774 .50627 .12728 .5198 .12212 .51239 .11253 Mtetra
.51239 .11253 .5198 .12212 .53339 .11694 .52603 .1073 Mtetra
.52603 .1073 .53339 .11694 .54705 .11173 .53973 .10205 Mtetra
.53973 .10205 .54705 .11173 .56078 .1065 .5535 .09676 Mtetra
.5535 .09676 .56078 .1065 .57457 .10123 .56734 .09145 Mtetra
.56734 .09145 .57457 .10123 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09063 .59523 .08075 Mtetra
.59523 .08075 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.05408 .27685 .06283 .285 .07432 .2806 .06559 .2724 Mtetra
.06559 .2724 .07432 .2806 .08587 .27617 .07717 .26794 Mtetra
.07717 .26794 .08587 .27617 .09746 .27172 .08879 .26345 Mtetra
.08879 .26345 .09746 .27172 .10911 .26725 .10047 .25894 Mtetra
.10047 .25894 .10911 .26725 .12082 .26276 .1122 .25442 Mtetra
.1122 .25442 .12082 .26276 .13257 .25825 .12399 .24987 Mtetra
.12399 .24987 .13257 .25825 .14438 .25372 .13583 .2453 Mtetra
.13583 .2453 .14438 .25372 .15625 .24917 .14773 .24071 Mtetra
.14773 .24071 .15625 .24917 .16817 .24459 .15968 .23609 Mtetra
.15968 .23609 .16817 .24459 .18015 .24 .17169 .23146 Mtetra
.17169 .23146 .18015 .24 .19218 .23538 .18376 .2268 Mtetra
.18376 .2268 .19218 .23538 .20427 .23074 .19588 .22212 Mtetra
.19588 .22212 .20427 .23074 .21642 .22608 .20806 .21742 Mtetra
.20806 .21742 .21642 .22608 .22862 .2214 .2203 .2127 Mtetra
.2203 .2127 .22862 .2214 .24088 .2167 .23259 .20796 Mtetra
.23259 .20796 .24088 .2167 .2532 .21197 .24494 .20319 Mtetra
.24494 .20319 .2532 .21197 .26558 .20722 .25735 .1984 Mtetra
.25735 .1984 .26558 .20722 .27801 .20245 .26982 .19359 Mtetra
.26982 .19359 .27801 .20245 .29051 .19766 .28235 .18875 Mtetra
.28235 .18875 .29051 .19766 .30306 .19284 .29494 .18389 Mtetra
.29494 .18389 .30306 .19284 .31567 .188 .30759 .17901 Mtetra
.30759 .17901 .31567 .188 .32835 .18314 .32031 .1741 Mtetra
.32031 .1741 .32835 .18314 .34108 .17826 .33308 .16917 Mtetra
.33308 .16917 .34108 .17826 .35388 .17335 .34591 .16422 Mtetra
.34591 .16422 .35388 .17335 .36674 .16841 .35881 .15924 Mtetra
.35881 .15924 .36674 .16841 .37966 .16346 .37177 .15424 Mtetra
.37177 .15424 .37966 .16346 .39264 .15847 .38479 .14922 Mtetra
.38479 .14922 .39264 .15847 .40569 .15347 .39788 .14417 Mtetra
.39788 .14417 .40569 .15347 .4188 .14844 .41103 .13909 Mtetra
.41103 .13909 .4188 .14844 .43197 .14339 .42424 .13399 Mtetra
.42424 .13399 .43197 .14339 .44521 .13831 .43752 .12886 Mtetra
.43752 .12886 .44521 .13831 .45852 .1332 .45087 .12371 Mtetra
.45087 .12371 .45852 .1332 .47188 .12807 .46428 .11854 Mtetra
.46428 .11854 .47188 .12807 .48532 .12292 .47776 .11334 Mtetra
.47776 .11334 .48532 .12292 .49882 .11774 .4913 .10811 Mtetra
.4913 .10811 .49882 .11774 .51239 .11253 .50491 .10286 Mtetra
.50491 .10286 .51239 .11253 .52603 .1073 .51859 .09758 Mtetra
.51859 .09758 .52603 .1073 .53973 .10205 .53234 .09227 Mtetra
.53234 .09227 .53973 .10205 .5535 .09676 .54616 .08694 Mtetra
.54616 .08694 .5535 .09676 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.04524 .26863 .05408 .27685 .06559 .2724 .05679 .26414 Mtetra
.05679 .26414 .06559 .2724 .07717 .26794 .06839 .25964 Mtetra
.06839 .25964 .07717 .26794 .08879 .26345 .08005 .25511 Mtetra
.08005 .25511 .08879 .26345 .10047 .25894 .09176 .25057 Mtetra
.09176 .25057 .10047 .25894 .1122 .25442 .10352 .246 Mtetra
.10352 .246 .1122 .25442 .12399 .24987 .11534 .24141 Mtetra
.11534 .24141 .12399 .24987 .13583 .2453 .12721 .2368 Mtetra
.12721 .2368 .13583 .2453 .14773 .24071 .13914 .23217 Mtetra
.13914 .23217 .14773 .24071 .15968 .23609 .15112 .22752 Mtetra
.15112 .22752 .15968 .23609 .17169 .23146 .16316 .22284 Mtetra
.16316 .22284 .17169 .23146 .18376 .2268 .17526 .21815 Mtetra
.17526 .21815 .18376 .2268 .19588 .22212 .18742 .21343 Mtetra
.18742 .21343 .19588 .22212 .20806 .21742 .19963 .20869 Mtetra
.19963 .20869 .20806 .21742 .2203 .2127 .2119 .20392 Mtetra
.2119 .20392 .2203 .2127 .23259 .20796 .22423 .19914 Mtetra
.22423 .19914 .23259 .20796 .24494 .20319 .23661 .19433 Mtetra
.23661 .19433 .24494 .20319 .25735 .1984 .24906 .1895 Mtetra
.24906 .1895 .25735 .1984 .26982 .19359 .26157 .18464 Mtetra
.26157 .18464 .26982 .19359 .28235 .18875 .27413 .17976 Mtetra
.27413 .17976 .28235 .18875 .29494 .18389 .28676 .17486 Mtetra
.28676 .17486 .29494 .18389 .30759 .17901 .29944 .16993 Mtetra
.29944 .16993 .30759 .17901 .32031 .1741 .31219 .16498 Mtetra
.31219 .16498 .32031 .1741 .33308 .16917 .325 .16001 Mtetra
.325 .16001 .33308 .16917 .34591 .16422 .33788 .15501 Mtetra
.33788 .15501 .34591 .16422 .35881 .15924 .35081 .14999 Mtetra
.35081 .14999 .35881 .15924 .37177 .15424 .36381 .14494 Mtetra
.36381 .14494 .37177 .15424 .38479 .14922 .37687 .13987 Mtetra
.37687 .13987 .38479 .14922 .39788 .14417 .39 .13478 Mtetra
.39 .13478 .39788 .14417 .41103 .13909 .40319 .12965 Mtetra
.40319 .12965 .41103 .13909 .42424 .13399 .41644 .12451 Mtetra
.41644 .12451 .42424 .13399 .43752 .12886 .42976 .11934 Mtetra
.42976 .11934 .43752 .12886 .45087 .12371 .44315 .11414 Mtetra
.44315 .11414 .45087 .12371 .46428 .11854 .4566 .10892 Mtetra
.4566 .10892 .46428 .11854 .47776 .11334 .47013 .10367 Mtetra
.47013 .10367 .47776 .11334 .4913 .10811 .48371 .09839 Mtetra
.48371 .09839 .4913 .10811 .50491 .10286 .49737 .09309 Mtetra
.49737 .09309 .50491 .10286 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09227 .52489 .0824 Mtetra
.52489 .0824 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.03634 .26033 .04524 .26863 .05679 .26414 .04791 .25581 Mtetra
.04791 .25581 .05679 .26414 .06839 .25964 .05954 .25127 Mtetra
.05954 .25127 .06839 .25964 .08005 .25511 .07123 .24671 Mtetra
.07123 .24671 .08005 .25511 .09176 .25057 .08297 .24212 Mtetra
.08297 .24212 .09176 .25057 .10352 .246 .09476 .23751 Mtetra
.09476 .23751 .10352 .246 .11534 .24141 .10661 .23289 Mtetra
.10661 .23289 .11534 .24141 .12721 .2368 .11851 .22824 Mtetra
.11851 .22824 .12721 .2368 .13914 .23217 .13047 .22356 Mtetra
.13047 .22356 .13914 .23217 .15112 .22752 .14249 .21887 Mtetra
.14249 .21887 .15112 .22752 .16316 .22284 .15456 .21416 Mtetra
.15456 .21416 .16316 .22284 .17526 .21815 .16669 .20942 Mtetra
.16669 .20942 .17526 .21815 .18742 .21343 .17888 .20466 Mtetra
.17888 .20466 .18742 .21343 .19963 .20869 .19112 .19987 Mtetra
.19112 .19987 .19963 .20869 .2119 .20392 .20343 .19507 Mtetra
.20343 .19507 .2119 .20392 .22423 .19914 .21579 .19024 Mtetra
.21579 .19024 .22423 .19914 .23661 .19433 .22821 .18539 Mtetra
.22821 .18539 .23661 .19433 .24906 .1895 .24069 .18051 Mtetra
.24069 .18051 .24906 .1895 .26157 .18464 .25323 .17561 Mtetra
.25323 .17561 .26157 .18464 .27413 .17976 .26583 .17069 Mtetra
.26583 .17069 .27413 .17976 .28676 .17486 .2785 .16575 Mtetra
.2785 .16575 .28676 .17486 .29944 .16993 .29122 .16078 Mtetra
.29122 .16078 .29944 .16993 .31219 .16498 .30401 .15578 Mtetra
.30401 .15578 .31219 .16498 .325 .16001 .31685 .15076 Mtetra
.31685 .15076 .325 .16001 .33788 .15501 .32977 .14572 Mtetra
.32977 .14572 .33788 .15501 .35081 .14999 .34274 .14065 Mtetra
.34274 .14065 .35081 .14999 .36381 .14494 .35578 .13556 Mtetra
.35578 .13556 .36381 .14494 .37687 .13987 .36888 .13044 Mtetra
.36888 .13044 .37687 .13987 .39 .13478 .38204 .1253 Mtetra
.38204 .1253 .39 .13478 .40319 .12965 .39527 .12013 Mtetra
.39527 .12013 .40319 .12965 .41644 .12451 .40857 .11494 Mtetra
.40857 .11494 .41644 .12451 .42976 .11934 .42193 .10972 Mtetra
.42193 .10972 .42976 .11934 .44315 .11414 .43536 .10448 Mtetra
.43536 .10448 .44315 .11414 .4566 .10892 .44886 .0992 Mtetra
.44886 .0992 .4566 .10892 .47013 .10367 .46242 .09391 Mtetra
.46242 .09391 .47013 .10367 .48371 .09839 .47605 .08858 Mtetra
.47605 .08858 .48371 .09839 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .0824 .51736 .07245 Mtetra
.51736 .07245 .52489 .0824 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .57879 .48228 .57294 Mtetra
.48228 .57294 .48818 .57879 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57244 .5035 .56654 Mtetra
.5035 .56654 .50935 .57244 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .56009 Mtetra
.52489 .56009 .53068 .56605 .54141 .56283 .53564 .55685 Mtetra
.53564 .55685 .54141 .56283 .55218 .5596 .54644 .5536 Mtetra
.54644 .5536 .55218 .5596 .56299 .55635 .55728 .55033 Mtetra
.55728 .55033 .56299 .55635 .57385 .5531 .56816 .54705 Mtetra
.56816 .54705 .57385 .5531 .58474 .54983 .57909 .54376 Mtetra
.57909 .54376 .58474 .54983 .59568 .54654 .59006 .54045 Mtetra
.59006 .54045 .59568 .54654 .60667 .54325 .60107 .53713 Mtetra
.60107 .53713 .60667 .54325 .61769 .53994 .61213 .5338 Mtetra
.61213 .5338 .61769 .53994 .62876 .53662 .62323 .53045 Mtetra
.62323 .53045 .62876 .53662 .63988 .53329 .63437 .5271 Mtetra
.63437 .5271 .63988 .53329 .65104 .52994 .64556 .52372 Mtetra
.64556 .52372 .65104 .52994 .66224 .52658 .65679 .52034 Mtetra
.65679 .52034 .66224 .52658 .67349 .5232 .66807 .51694 Mtetra
.66807 .51694 .67349 .5232 .68478 .51982 .67939 .51353 Mtetra
.67939 .51353 .68478 .51982 .69612 .51641 .69076 .5101 Mtetra
.69076 .5101 .69612 .51641 .7075 .513 .70218 .50666 Mtetra
.70218 .50666 .7075 .513 .71893 .50957 .71364 .5032 Mtetra
.71364 .5032 .71893 .50957 .73041 .50613 .72515 .49974 Mtetra
.72515 .49974 .73041 .50613 .74193 .50267 .7367 .49625 Mtetra
.7367 .49625 .74193 .50267 .7535 .4992 .7483 .49276 Mtetra
.7483 .49276 .7535 .4992 .76511 .49572 .75995 .48925 Mtetra
.75995 .48925 .76511 .49572 .77677 .49222 .77165 .48572 Mtetra
.77165 .48572 .77677 .49222 .78848 .48871 .78339 .48218 Mtetra
.78339 .48218 .78848 .48871 .80024 .48518 .79518 .47863 Mtetra
.79518 .47863 .80024 .48518 .81205 .48164 .80702 .47506 Mtetra
.80702 .47506 .81205 .48164 .8239 .47808 .81891 .47148 Mtetra
.81891 .47148 .8239 .47808 .8358 .47451 .83085 .46788 Mtetra
.83085 .46788 .8358 .47451 .84775 .47092 .84283 .46427 Mtetra
.84283 .46427 .84775 .47092 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .45699 Mtetra
.86696 .45699 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57342 Mtetra
.45523 .57342 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55735 Mtetra
.50831 .55735 .51417 .56332 .52489 .56009 .51905 .5541 Mtetra
.51905 .5541 .52489 .56009 .53564 .55685 .52983 .55083 Mtetra
.52983 .55083 .53564 .55685 .54644 .5536 .54066 .54756 Mtetra
.54066 .54756 .54644 .5536 .55728 .55033 .55153 .54426 Mtetra
.55153 .54426 .55728 .55033 .56816 .54705 .56244 .54096 Mtetra
.56244 .54096 .56816 .54705 .57909 .54376 .57339 .53764 Mtetra
.57339 .53764 .57909 .54376 .59006 .54045 .58439 .53431 Mtetra
.58439 .53431 .59006 .54045 .60107 .53713 .59543 .53097 Mtetra
.59543 .53097 .60107 .53713 .61213 .5338 .60652 .52761 Mtetra
.60652 .52761 .61213 .5338 .62323 .53045 .61765 .52424 Mtetra
.61765 .52424 .62323 .53045 .63437 .5271 .62882 .52086 Mtetra
.62882 .52086 .63437 .5271 .64556 .52372 .64004 .51746 Mtetra
.64004 .51746 .64556 .52372 .65679 .52034 .6513 .51405 Mtetra
.6513 .51405 .65679 .52034 .66807 .51694 .66261 .51063 Mtetra
.66261 .51063 .66807 .51694 .67939 .51353 .67397 .50719 Mtetra
.67397 .50719 .67939 .51353 .69076 .5101 .68537 .50374 Mtetra
.68537 .50374 .69076 .5101 .70218 .50666 .69682 .50027 Mtetra
.69682 .50027 .70218 .50666 .71364 .5032 .70831 .49679 Mtetra
.70831 .49679 .71364 .5032 .72515 .49974 .71985 .4933 Mtetra
.71985 .4933 .72515 .49974 .7367 .49625 .73144 .48979 Mtetra
.73144 .48979 .7367 .49625 .7483 .49276 .74307 .48626 Mtetra
.74307 .48626 .7483 .49276 .75995 .48925 .75475 .48273 Mtetra
.75475 .48273 .75995 .48925 .77165 .48572 .76648 .47918 Mtetra
.76648 .47918 .77165 .48572 .78339 .48218 .77826 .47561 Mtetra
.77826 .47561 .78339 .48218 .79518 .47863 .79008 .47203 Mtetra
.79008 .47203 .79518 .47863 .80702 .47506 .80196 .46843 Mtetra
.80196 .46843 .80702 .47506 .81891 .47148 .81388 .46482 Mtetra
.81388 .46482 .81891 .47148 .83085 .46788 .82585 .4612 Mtetra
.82585 .4612 .83085 .46788 .84283 .46427 .83788 .45756 Mtetra
.83788 .45756 .84283 .46427 .85487 .46064 .84995 .4539 Mtetra
.84995 .4539 .85487 .46064 .86696 .45699 .86207 .45023 Mtetra
.86207 .45023 .86696 .45699 .87909 .45334 .87424 .44654 Mtetra
.87424 .44654 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57342 .44919 .56753 Mtetra
.44919 .56753 .45523 .57342 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .5546 Mtetra
.49168 .5546 .49761 .56059 .50831 .55735 .5024 .55134 Mtetra
.5024 .55134 .50831 .55735 .51905 .5541 .51317 .54806 Mtetra
.51317 .54806 .51905 .5541 .52983 .55083 .52398 .54477 Mtetra
.52398 .54477 .52983 .55083 .54066 .54756 .53484 .54147 Mtetra
.53484 .54147 .54066 .54756 .55153 .54426 .54573 .53815 Mtetra
.54573 .53815 .55153 .54426 .56244 .54096 .55667 .53483 Mtetra
.55667 .53483 .56244 .54096 .57339 .53764 .56766 .53149 Mtetra
.56766 .53149 .57339 .53764 .58439 .53431 .57868 .52813 Mtetra
.57868 .52813 .58439 .53431 .59543 .53097 .58975 .52476 Mtetra
.58975 .52476 .59543 .53097 .60652 .52761 .60087 .52138 Mtetra
.60087 .52138 .60652 .52761 .61765 .52424 .61203 .51799 Mtetra
.61203 .51799 .61765 .52424 .62882 .52086 .62323 .51458 Mtetra
.62323 .51458 .62882 .52086 .64004 .51746 .63448 .51115 Mtetra
.63448 .51115 .64004 .51746 .6513 .51405 .64578 .50772 Mtetra
.64578 .50772 .6513 .51405 .66261 .51063 .65712 .50427 Mtetra
.65712 .50427 .66261 .51063 .67397 .50719 .6685 .5008 Mtetra
.6685 .5008 .67397 .50719 .68537 .50374 .67993 .49733 Mtetra
.67993 .49733 .68537 .50374 .69682 .50027 .69141 .49383 Mtetra
.69141 .49383 .69682 .50027 .70831 .49679 .70294 .49033 Mtetra
.70294 .49033 .70831 .49679 .71985 .4933 .71451 .48681 Mtetra
.71451 .48681 .71985 .4933 .73144 .48979 .72613 .48327 Mtetra
.72613 .48327 .73144 .48979 .74307 .48626 .7378 .47972 Mtetra
.7378 .47972 .74307 .48626 .75475 .48273 .74951 .47616 Mtetra
.74951 .47616 .75475 .48273 .76648 .47918 .76127 .47258 Mtetra
.76127 .47258 .76648 .47918 .77826 .47561 .77309 .46899 Mtetra
.77309 .46899 .77826 .47561 .79008 .47203 .78495 .46538 Mtetra
.78495 .46538 .79008 .47203 .80196 .46843 .79686 .46176 Mtetra
.79686 .46176 .80196 .46843 .81388 .46482 .80881 .45812 Mtetra
.80881 .45812 .81388 .46482 .82585 .4612 .82082 .45446 Mtetra
.82082 .45446 .82585 .4612 .83788 .45756 .83288 .4508 Mtetra
.83288 .4508 .83788 .45756 .84995 .4539 .84499 .44711 Mtetra
.84499 .44711 .84995 .4539 .86207 .45023 .85715 .44341 Mtetra
.85715 .44341 .86207 .45023 .87424 .44654 .86936 .4397 Mtetra
.86936 .4397 .87424 .44654 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .5551 Mtetra
.46432 .5551 .47035 .56109 .48099 .55785 .47499 .55184 Mtetra
.47499 .55184 .48099 .55785 .49168 .5546 .4857 .54857 Mtetra
.4857 .54857 .49168 .5546 .5024 .55134 .49646 .54528 Mtetra
.49646 .54528 .5024 .55134 .51317 .54806 .50725 .54198 Mtetra
.50725 .54198 .51317 .54806 .52398 .54477 .51809 .53867 Mtetra
.51809 .53867 .52398 .54477 .53484 .54147 .52897 .53534 Mtetra
.52897 .53534 .53484 .54147 .54573 .53815 .5399 .532 Mtetra
.5399 .532 .54573 .53815 .55667 .53483 .55087 .52865 Mtetra
.55087 .52865 .55667 .53483 .56766 .53149 .56188 .52528 Mtetra
.56188 .52528 .56766 .53149 .57868 .52813 .57293 .5219 Mtetra
.57293 .5219 .57868 .52813 .58975 .52476 .58403 .51851 Mtetra
.58403 .51851 .58975 .52476 .60087 .52138 .59518 .5151 Mtetra
.59518 .5151 .60087 .52138 .61203 .51799 .60637 .51168 Mtetra
.60637 .51168 .61203 .51799 .62323 .51458 .6176 .50825 Mtetra
.6176 .50825 .62323 .51458 .63448 .51115 .62888 .5048 Mtetra
.62888 .5048 .63448 .51115 .64578 .50772 .64021 .50134 Mtetra
.64021 .50134 .64578 .50772 .65712 .50427 .65158 .49786 Mtetra
.65158 .49786 .65712 .50427 .6685 .5008 .663 .49437 Mtetra
.663 .49437 .6685 .5008 .67993 .49733 .67446 .49087 Mtetra
.67446 .49087 .67993 .49733 .69141 .49383 .68597 .48735 Mtetra
.68597 .48735 .69141 .49383 .70294 .49033 .69753 .48382 Mtetra
.69753 .48382 .70294 .49033 .71451 .48681 .70913 .48027 Mtetra
.70913 .48027 .71451 .48681 .72613 .48327 .72078 .47671 Mtetra
.72078 .47671 .72613 .48327 .7378 .47972 .73248 .47313 Mtetra
.73248 .47313 .7378 .47972 .74951 .47616 .74423 .46954 Mtetra
.74423 .46954 .74951 .47616 .76127 .47258 .75603 .46593 Mtetra
.75603 .46593 .76127 .47258 .77309 .46899 .76788 .46231 Mtetra
.76788 .46231 .77309 .46899 .78495 .46538 .77977 .45868 Mtetra
.77977 .45868 .78495 .46538 .79686 .46176 .79171 .45503 Mtetra
.79171 .45503 .79686 .46176 .80881 .45812 .80371 .45136 Mtetra
.80371 .45136 .80881 .45812 .82082 .45446 .81575 .44768 Mtetra
.81575 .44768 .82082 .45446 .83288 .4508 .82785 .44398 Mtetra
.82785 .44398 .83288 .4508 .84499 .44711 .83999 .44027 Mtetra
.83999 .44027 .84499 .44711 .85715 .44341 .85219 .43654 Mtetra
.85219 .43654 .85715 .44341 .86936 .4397 .86443 .4328 Mtetra
.86443 .4328 .86936 .4397 .88162 .43597 .87673 .42904 Mtetra
.87673 .42904 .88162 .43597 .89393 .43222 .88908 .42526 Mtetra
.88908 .42526 .89393 .43222 .9063 .42846 .90148 .42147 Mtetra
.90148 .42147 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .5556 Mtetra
.43698 .5556 .44311 .56159 .45369 .55835 .4476 .55234 Mtetra
.4476 .55234 .45369 .55835 .46432 .5551 .45825 .54907 Mtetra
.45825 .54907 .46432 .5551 .47499 .55184 .46895 .54579 Mtetra
.46895 .54579 .47499 .55184 .4857 .54857 .47968 .54249 Mtetra
.47968 .54249 .4857 .54857 .49646 .54528 .49046 .53918 Mtetra
.49046 .53918 .49646 .54528 .50725 .54198 .50129 .53585 Mtetra
.50129 .53585 .50725 .54198 .51809 .53867 .51215 .53251 Mtetra
.51215 .53251 .51809 .53867 .52897 .53534 .52306 .52916 Mtetra
.52306 .52916 .52897 .53534 .5399 .532 .53402 .5258 Mtetra
.53402 .5258 .5399 .532 .55087 .52865 .54501 .52242 Mtetra
.54501 .52242 .55087 .52865 .56188 .52528 .55606 .51903 Mtetra
.55606 .51903 .56188 .52528 .57293 .5219 .56714 .51563 Mtetra
.56714 .51563 .57293 .5219 .58403 .51851 .57827 .51221 Mtetra
.57827 .51221 .58403 .51851 .59518 .5151 .58944 .50878 Mtetra
.58944 .50878 .59518 .5151 .60637 .51168 .60066 .50533 Mtetra
.60066 .50533 .60637 .51168 .6176 .50825 .61193 .50187 Mtetra
.61193 .50187 .6176 .50825 .62888 .5048 .62324 .4984 Mtetra
.62324 .4984 .62888 .5048 .64021 .50134 .6346 .49491 Mtetra
.6346 .49491 .64021 .50134 .65158 .49786 .646 .49141 Mtetra
.646 .49141 .65158 .49786 .663 .49437 .65745 .48789 Mtetra
.65745 .48789 .663 .49437 .67446 .49087 .66894 .48436 Mtetra
.66894 .48436 .67446 .49087 .68597 .48735 .68049 .48082 Mtetra
.68049 .48082 .68597 .48735 .69753 .48382 .69208 .47726 Mtetra
.69208 .47726 .69753 .48382 .70913 .48027 .70371 .47368 Mtetra
.70371 .47368 .70913 .48027 .72078 .47671 .7154 .47009 Mtetra
.7154 .47009 .72078 .47671 .73248 .47313 .72713 .46649 Mtetra
.72713 .46649 .73248 .47313 .74423 .46954 .73891 .46287 Mtetra
.73891 .46287 .74423 .46954 .75603 .46593 .75075 .45924 Mtetra
.75075 .45924 .75603 .46593 .76788 .46231 .76263 .45559 Mtetra
.76263 .45559 .76788 .46231 .77977 .45868 .77455 .45193 Mtetra
.77455 .45193 .77977 .45868 .79171 .45503 .78653 .44825 Mtetra
.78653 .44825 .79171 .45503 .80371 .45136 .79856 .44455 Mtetra
.79856 .44455 .80371 .45136 .81575 .44768 .81064 .44084 Mtetra
.81064 .44084 .81575 .44768 .82785 .44398 .82277 .43712 Mtetra
.82277 .43712 .82785 .44398 .83999 .44027 .83495 .43338 Mtetra
.83495 .43338 .83999 .44027 .85219 .43654 .84719 .42962 Mtetra
.84719 .42962 .85219 .43654 .86443 .4328 .85947 .42585 Mtetra
.85947 .42585 .86443 .4328 .87673 .42904 .87181 .42206 Mtetra
.87181 .42206 .87673 .42904 .88908 .42526 .88419 .41825 Mtetra
.88419 .41825 .88908 .42526 .90148 .42147 .89664 .41443 Mtetra
.89664 .41443 .90148 .42147 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55284 Mtetra
.42022 .55284 .42641 .55885 .43698 .5556 .43081 .54957 Mtetra
.43081 .54957 .43698 .5556 .4476 .55234 .44145 .54629 Mtetra
.44145 .54629 .4476 .55234 .45825 .54907 .45213 .543 Mtetra
.45213 .543 .45825 .54907 .46895 .54579 .46286 .53969 Mtetra
.46286 .53969 .46895 .54579 .47968 .54249 .47362 .53636 Mtetra
.47362 .53636 .47968 .54249 .49046 .53918 .48443 .53303 Mtetra
.48443 .53303 .49046 .53918 .50129 .53585 .49528 .52968 Mtetra
.49528 .52968 .50129 .53585 .51215 .53251 .50617 .52632 Mtetra
.50617 .52632 .51215 .53251 .52306 .52916 .51711 .52294 Mtetra
.51711 .52294 .52306 .52916 .53402 .5258 .52809 .51955 Mtetra
.52809 .51955 .53402 .5258 .54501 .52242 .53912 .51615 Mtetra
.53912 .51615 .54501 .52242 .55606 .51903 .55019 .51274 Mtetra
.55019 .51274 .55606 .51903 .56714 .51563 .5613 .50931 Mtetra
.5613 .50931 .56714 .51563 .57827 .51221 .57246 .50586 Mtetra
.57246 .50586 .57827 .51221 .58944 .50878 .58367 .50241 Mtetra
.58367 .50241 .58944 .50878 .60066 .50533 .59492 .49893 Mtetra
.59492 .49893 .60066 .50533 .61193 .50187 .60621 .49545 Mtetra
.60621 .49545 .61193 .50187 .62324 .4984 .61755 .49195 Mtetra
.61755 .49195 .62324 .4984 .6346 .49491 .62894 .48843 Mtetra
.62894 .48843 .6346 .49491 .646 .49141 .64038 .48491 Mtetra
.64038 .48491 .646 .49141 .65745 .48789 .65186 .48136 Mtetra
.65186 .48136 .65745 .48789 .66894 .48436 .66338 .47781 Mtetra
.66338 .47781 .66894 .48436 .68049 .48082 .67496 .47423 Mtetra
.67496 .47423 .68049 .48082 .69208 .47726 .68658 .47065 Mtetra
.68658 .47065 .69208 .47726 .70371 .47368 .69825 .46705 Mtetra
.69825 .46705 .70371 .47368 .7154 .47009 .70997 .46343 Mtetra
.70997 .46343 .7154 .47009 .72713 .46649 .72174 .4598 Mtetra
.72174 .4598 .72713 .46649 .73891 .46287 .73355 .45615 Mtetra
.73355 .45615 .73891 .46287 .75075 .45924 .74542 .45249 Mtetra
.74542 .45249 .75075 .45924 .76263 .45559 .75733 .44881 Mtetra
.75733 .44881 .76263 .45559 .77455 .45193 .7693 .44512 Mtetra
.7693 .44512 .77455 .45193 .78653 .44825 .78131 .44141 Mtetra
.78131 .44141 .78653 .44825 .79856 .44455 .79338 .43769 Mtetra
.79338 .43769 .79856 .44455 .81064 .44084 .80549 .43395 Mtetra
.80549 .43395 .81064 .44084 .82277 .43712 .81766 .4302 Mtetra
.81766 .4302 .82277 .43712 .83495 .43338 .82988 .42643 Mtetra
.82988 .42643 .83495 .43338 .84719 .42962 .84215 .42264 Mtetra
.84215 .42264 .84719 .42962 .85947 .42585 .85447 .41884 Mtetra
.85447 .41884 .85947 .42585 .87181 .42206 .86684 .41502 Mtetra
.86684 .41502 .87181 .42206 .88419 .41825 .87927 .41119 Mtetra
.87927 .41119 .88419 .41825 .89664 .41443 .89175 .40734 Mtetra
.89175 .40734 .89664 .41443 .90913 .4106 .90428 .40347 Mtetra
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39958 Mtetra
.91687 .39958 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55984 Mtetra
.37189 .55984 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55284 .41397 .5468 Mtetra
.41397 .5468 .42022 .55284 .43081 .54957 .4246 .5435 Mtetra
.4246 .5435 .43081 .54957 .44145 .54629 .43526 .5402 Mtetra
.43526 .5402 .44145 .54629 .45213 .543 .44597 .53688 Mtetra
.44597 .53688 .45213 .543 .46286 .53969 .45672 .53354 Mtetra
.45672 .53354 .46286 .53969 .47362 .53636 .46751 .5302 Mtetra
.46751 .5302 .47362 .53636 .48443 .53303 .47835 .52684 Mtetra
.47835 .52684 .48443 .53303 .49528 .52968 .48923 .52346 Mtetra
.48923 .52346 .49528 .52968 .50617 .52632 .50015 .52008 Mtetra
.50015 .52008 .50617 .52632 .51711 .52294 .51112 .51668 Mtetra
.51112 .51668 .51711 .52294 .52809 .51955 .52213 .51326 Mtetra
.52213 .51326 .52809 .51955 .53912 .51615 .53318 .50983 Mtetra
.53318 .50983 .53912 .51615 .55019 .51274 .54428 .50639 Mtetra
.54428 .50639 .55019 .51274 .5613 .50931 .55543 .50294 Mtetra
.55543 .50294 .5613 .50931 .57246 .50586 .56661 .49947 Mtetra
.56661 .49947 .57246 .50586 .58367 .50241 .57785 .49599 Mtetra
.57785 .49599 .58367 .50241 .59492 .49893 .58913 .49249 Mtetra
.58913 .49249 .59492 .49893 .60621 .49545 .60045 .48898 Mtetra
.60045 .48898 .60621 .49545 .61755 .49195 .61183 .48545 Mtetra
.61183 .48545 .61755 .49195 .62894 .48843 .62325 .48191 Mtetra
.62325 .48191 .62894 .48843 .64038 .48491 .63471 .47835 Mtetra
.63471 .47835 .64038 .48491 .65186 .48136 .64622 .47478 Mtetra
.64622 .47478 .65186 .48136 .66338 .47781 .65778 .4712 Mtetra
.65778 .4712 .66338 .47781 .67496 .47423 .66939 .4676 Mtetra
.66939 .4676 .67496 .47423 .68658 .47065 .68105 .46399 Mtetra
.68105 .46399 .68658 .47065 .69825 .46705 .69275 .46036 Mtetra
.69275 .46036 .69825 .46705 .70997 .46343 .7045 .45671 Mtetra
.7045 .45671 .70997 .46343 .72174 .4598 .7163 .45306 Mtetra
.7163 .45306 .72174 .4598 .73355 .45615 .72815 .44938 Mtetra
.72815 .44938 .73355 .45615 .74542 .45249 .74005 .44569 Mtetra
.74005 .44569 .74542 .45249 .75733 .44881 .752 .44199 Mtetra
.752 .44199 .75733 .44881 .7693 .44512 .764 .43827 Mtetra
.764 .43827 .7693 .44512 .78131 .44141 .77605 .43453 Mtetra
.77605 .43453 .78131 .44141 .79338 .43769 .78815 .43078 Mtetra
.78815 .43078 .79338 .43769 .80549 .43395 .8003 .42701 Mtetra
.8003 .42701 .80549 .43395 .81766 .4302 .81251 .42323 Mtetra
.81251 .42323 .81766 .4302 .82988 .42643 .82476 .41943 Mtetra
.82476 .41943 .82988 .42643 .84215 .42264 .83707 .41561 Mtetra
.83707 .41561 .84215 .42264 .85447 .41884 .84943 .41178 Mtetra
.84943 .41178 .85447 .41884 .86684 .41502 .86184 .40793 Mtetra
.86184 .40793 .86684 .41502 .87927 .41119 .8743 .40406 Mtetra
.8743 .40406 .87927 .41119 .89175 .40734 .88682 .40018 Mtetra
.88682 .40018 .89175 .40734 .90428 .40347 .89939 .39628 Mtetra
.89939 .39628 .90428 .40347 .91687 .39958 .91202 .39237 Mtetra
.91202 .39237 .91687 .39958 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.35506 .5571 .36148 .56307 .37189 .55984 .3655 .55385 Mtetra
.3655 .55385 .37189 .55984 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .5435 .41834 .53739 Mtetra
.41834 .53739 .4246 .5435 .43526 .5402 .42903 .53406 Mtetra
.42903 .53406 .43526 .5402 .44597 .53688 .43976 .53071 Mtetra
.43976 .53071 .44597 .53688 .45672 .53354 .45054 .52735 Mtetra
.45054 .52735 .45672 .53354 .46751 .5302 .46136 .52398 Mtetra
.46136 .52398 .46751 .5302 .47835 .52684 .47222 .5206 Mtetra
.47222 .5206 .47835 .52684 .48923 .52346 .48313 .5172 Mtetra
.48313 .5172 .48923 .52346 .50015 .52008 .49408 .51379 Mtetra
.49408 .51379 .50015 .52008 .51112 .51668 .50508 .51036 Mtetra
.50508 .51036 .51112 .51668 .52213 .51326 .51612 .50692 Mtetra
.51612 .50692 .52213 .51326 .53318 .50983 .5272 .50347 Mtetra
.5272 .50347 .53318 .50983 .54428 .50639 .53833 .5 Mtetra
.53833 .5 .54428 .50639 .55543 .50294 .5495 .49652 Mtetra
.5495 .49652 .55543 .50294 .56661 .49947 .56072 .49303 Mtetra
.56072 .49303 .56661 .49947 .57785 .49599 .57199 .48952 Mtetra
.57199 .48952 .57785 .49599 .58913 .49249 .5833 .48599 Mtetra
.5833 .48599 .58913 .49249 .60045 .48898 .59465 .48245 Mtetra
.59465 .48245 .60045 .48898 .61183 .48545 .60606 .4789 Mtetra
.60606 .4789 .61183 .48545 .62325 .48191 .61751 .47533 Mtetra
.61751 .47533 .62325 .48191 .63471 .47835 .629 .47175 Mtetra
.629 .47175 .63471 .47835 .64622 .47478 .64055 .46816 Mtetra
.64055 .46816 .64622 .47478 .65778 .4712 .65214 .46454 Mtetra
.65214 .46454 .65778 .4712 .66939 .4676 .66378 .46092 Mtetra
.66378 .46092 .66939 .4676 .68105 .46399 .67547 .45728 Mtetra
.67547 .45728 .68105 .46399 .69275 .46036 .68721 .45362 Mtetra
.68721 .45362 .69275 .46036 .7045 .45671 .69899 .44995 Mtetra
.69899 .44995 .7045 .45671 .7163 .45306 .71083 .44626 Mtetra
.71083 .44626 .7163 .45306 .72815 .44938 .72271 .44256 Mtetra
.72271 .44256 .72815 .44938 .74005 .44569 .73465 .43884 Mtetra
.73465 .43884 .74005 .44569 .752 .44199 .74663 .4351 Mtetra
.74663 .4351 .752 .44199 .764 .43827 .75866 .43136 Mtetra
.75866 .43136 .764 .43827 .77605 .43453 .77075 .42759 Mtetra
.77075 .42759 .77605 .43453 .78815 .43078 .78289 .42381 Mtetra
.78289 .42381 .78815 .43078 .8003 .42701 .79507 .42001 Mtetra
.79507 .42001 .8003 .42701 .81251 .42323 .80731 .4162 Mtetra
.80731 .4162 .81251 .42323 .82476 .41943 .81961 .41237 Mtetra
.81961 .41237 .82476 .41943 .83707 .41561 .83195 .40852 Mtetra
.83195 .40852 .83707 .41561 .84943 .41178 .84435 .40466 Mtetra
.84435 .40466 .84943 .41178 .86184 .40793 .8568 .40078 Mtetra
.8568 .40078 .86184 .40793 .8743 .40406 .8693 .39689 Mtetra
.8693 .39689 .8743 .40406 .88682 .40018 .88186 .39297 Mtetra
.88186 .39297 .88682 .40018 .89939 .39628 .89447 .38904 Mtetra
.89447 .38904 .89939 .39628 .91202 .39237 .90713 .3851 Mtetra
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37715 Mtetra
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53457 Mtetra
.40135 .53457 .40769 .54071 .41834 .53739 .41203 .53123 Mtetra
.41203 .53123 .41834 .53739 .42903 .53406 .42275 .52787 Mtetra
.42275 .52787 .42903 .53406 .43976 .53071 .43351 .5245 Mtetra
.43351 .5245 .43976 .53071 .45054 .52735 .44432 .52112 Mtetra
.44432 .52112 .45054 .52735 .46136 .52398 .45516 .51772 Mtetra
.45516 .51772 .46136 .52398 .47222 .5206 .46605 .51431 Mtetra
.46605 .51431 .47222 .5206 .48313 .5172 .47699 .51089 Mtetra
.47699 .51089 .48313 .5172 .49408 .51379 .48797 .50745 Mtetra
.48797 .50745 .49408 .51379 .50508 .51036 .49899 .504 Mtetra
.49899 .504 .50508 .51036 .51612 .50692 .51006 .50054 Mtetra
.51006 .50054 .51612 .50692 .5272 .50347 .52117 .49706 Mtetra
.52117 .49706 .5272 .50347 .53833 .5 .53233 .49357 Mtetra
.53233 .49357 .53833 .5 .5495 .49652 .54353 .49006 Mtetra
.54353 .49006 .5495 .49652 .56072 .49303 .55478 .48654 Mtetra
.55478 .48654 .56072 .49303 .57199 .48952 .56608 .483 Mtetra
.56608 .483 .57199 .48952 .5833 .48599 .57742 .47945 Mtetra
.57742 .47945 .5833 .48599 .59465 .48245 .58881 .47588 Mtetra
.58881 .47588 .59465 .48245 .60606 .4789 .60024 .4723 Mtetra
.60024 .4723 .60606 .4789 .61751 .47533 .61172 .46871 Mtetra
.61172 .46871 .61751 .47533 .629 .47175 .62325 .4651 Mtetra
.62325 .4651 .629 .47175 .64055 .46816 .63483 .46148 Mtetra
.63483 .46148 .64055 .46816 .65214 .46454 .64645 .45784 Mtetra
.64645 .45784 .65214 .46454 .66378 .46092 .65813 .45418 Mtetra
.65813 .45418 .66378 .46092 .67547 .45728 .66985 .45051 Mtetra
.66985 .45051 .67547 .45728 .68721 .45362 .68162 .44683 Mtetra
.68162 .44683 .68721 .45362 .69899 .44995 .69344 .44313 Mtetra
.69344 .44313 .69899 .44995 .71083 .44626 .70531 .43941 Mtetra
.70531 .43941 .71083 .44626 .72271 .44256 .71723 .43568 Mtetra
.71723 .43568 .72271 .44256 .73465 .43884 .7292 .43193 Mtetra
.7292 .43193 .73465 .43884 .74663 .4351 .74122 .42817 Mtetra
.74122 .42817 .74663 .4351 .75866 .43136 .75329 .42439 Mtetra
.75329 .42439 .75866 .43136 .77075 .42759 .76541 .4206 Mtetra
.76541 .4206 .77075 .42759 .78289 .42381 .77758 .41679 Mtetra
.77758 .41679 .78289 .42381 .79507 .42001 .7898 .41296 Mtetra
.7898 .41296 .79507 .42001 .80731 .4162 .80208 .40912 Mtetra
.80208 .40912 .80731 .4162 .81961 .41237 .81441 .40526 Mtetra
.81441 .40526 .81961 .41237 .83195 .40852 .82679 .40138 Mtetra
.82679 .40138 .83195 .40852 .84435 .40466 .83923 .39749 Mtetra
.83923 .39749 .84435 .40466 .8568 .40078 .85171 .39358 Mtetra
.85171 .39358 .8568 .40078 .8693 .39689 .86426 .38965 Mtetra
.86426 .38965 .8693 .39689 .88186 .39297 .87685 .38571 Mtetra
.87685 .38571 .88186 .39297 .89447 .38904 .8895 .38175 Mtetra
.8895 .38175 .89447 .38904 .90713 .3851 .90221 .37777 Mtetra
.90221 .37777 .90713 .3851 .91985 .38114 .91497 .37377 Mtetra
.91497 .37377 .91985 .38114 .93263 .37715 .92778 .36976 Mtetra
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53508 Mtetra
.3737 .53508 .38013 .54122 .39072 .5379 .38431 .53174 Mtetra
.38431 .53174 .39072 .5379 .40135 .53457 .39497 .52839 Mtetra
.39497 .52839 .40135 .53457 .41203 .53123 .40568 .52502 Mtetra
.40568 .52502 .41203 .53123 .42275 .52787 .41642 .52164 Mtetra
.41642 .52164 .42275 .52787 .43351 .5245 .42721 .51825 Mtetra
.42721 .51825 .43351 .5245 .44432 .52112 .43804 .51484 Mtetra
.43804 .51484 .44432 .52112 .45516 .51772 .44892 .51142 Mtetra
.44892 .51142 .45516 .51772 .46605 .51431 .45984 .50798 Mtetra
.45984 .50798 .46605 .51431 .47699 .51089 .4708 .50453 Mtetra
.4708 .50453 .47699 .51089 .48797 .50745 .48181 .50107 Mtetra
.48181 .50107 .48797 .50745 .49899 .504 .49286 .49759 Mtetra
.49286 .49759 .49899 .504 .51006 .50054 .50396 .4941 Mtetra
.50396 .4941 .51006 .50054 .52117 .49706 .5151 .4906 Mtetra
.5151 .4906 .52117 .49706 .53233 .49357 .52629 .48708 Mtetra
.52629 .48708 .53233 .49357 .54353 .49006 .53752 .48355 Mtetra
.53752 .48355 .54353 .49006 .55478 .48654 .5488 .48 Mtetra
.5488 .48 .55478 .48654 .56608 .483 .56013 .47643 Mtetra
.56013 .47643 .56608 .483 .57742 .47945 .5715 .47286 Mtetra
.5715 .47286 .57742 .47945 .58881 .47588 .58292 .46926 Mtetra
.58292 .46926 .58881 .47588 .60024 .4723 .59438 .46566 Mtetra
.59438 .46566 .60024 .4723 .61172 .46871 .6059 .46203 Mtetra
.6059 .46203 .61172 .46871 .62325 .4651 .61746 .4584 Mtetra
.61746 .4584 .62325 .4651 .63483 .46148 .62907 .45475 Mtetra
.62907 .45475 .63483 .46148 .64645 .45784 .64072 .45108 Mtetra
.64072 .45108 .64645 .45784 .65813 .45418 .65243 .4474 Mtetra
.65243 .4474 .65813 .45418 .66985 .45051 .66418 .4437 Mtetra
.66418 .4437 .66985 .45051 .68162 .44683 .67599 .43998 Mtetra
.67599 .43998 .68162 .44683 .69344 .44313 .68784 .43626 Mtetra
.68784 .43626 .69344 .44313 .70531 .43941 .69975 .43251 Mtetra
.69975 .43251 .70531 .43941 .71723 .43568 .7117 .42875 Mtetra
.7117 .42875 .71723 .43568 .7292 .43193 .7237 .42497 Mtetra
.7237 .42497 .7292 .43193 .74122 .42817 .73576 .42118 Mtetra
.73576 .42118 .74122 .42817 .75329 .42439 .74786 .41737 Mtetra
.74786 .41737 .75329 .42439 .76541 .4206 .76002 .41355 Mtetra
.76002 .41355 .76541 .4206 .77758 .41679 .77223 .40971 Mtetra
.77223 .40971 .77758 .41679 .7898 .41296 .78449 .40585 Mtetra
.78449 .40585 .7898 .41296 .80208 .40912 .79681 .40198 Mtetra
.79681 .40198 .80208 .40912 .81441 .40526 .80917 .39809 Mtetra
.80917 .39809 .81441 .40526 .82679 .40138 .82159 .39418 Mtetra
.82159 .39418 .82679 .40138 .83923 .39749 .83406 .39025 Mtetra
.83406 .39025 .83923 .39749 .85171 .39358 .84659 .38631 Mtetra
.84659 .38631 .85171 .39358 .86426 .38965 .85917 .38236 Mtetra
.85917 .38236 .86426 .38965 .87685 .38571 .87181 .37838 Mtetra
.87181 .37838 .87685 .38571 .8895 .38175 .8845 .37439 Mtetra
.8845 .37439 .8895 .38175 .90221 .37777 .89724 .37038 Mtetra
.89724 .37038 .90221 .37777 .91497 .37377 .91004 .36635 Mtetra
.91004 .36635 .91497 .37377 .92778 .36976 .9229 .36231 Mtetra
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53508 .36722 .52891 Mtetra
.36722 .52891 .3737 .53508 .38431 .53174 .37786 .52554 Mtetra
.37786 .52554 .38431 .53174 .39497 .52839 .38855 .52216 Mtetra
.38855 .52216 .39497 .52839 .40568 .52502 .39928 .51877 Mtetra
.39928 .51877 .40568 .52502 .41642 .52164 .41005 .51537 Mtetra
.41005 .51537 .41642 .52164 .42721 .51825 .42087 .51195 Mtetra
.42087 .51195 .42721 .51825 .43804 .51484 .43173 .50851 Mtetra
.43173 .50851 .43804 .51484 .44892 .51142 .44263 .50507 Mtetra
.44263 .50507 .44892 .51142 .45984 .50798 .45358 .50161 Mtetra
.45358 .50161 .45984 .50798 .4708 .50453 .46457 .49813 Mtetra
.46457 .49813 .4708 .50453 .48181 .50107 .4756 .49464 Mtetra
.4756 .49464 .48181 .50107 .49286 .49759 .48668 .49114 Mtetra
.48668 .49114 .49286 .49759 .50396 .4941 .49781 .48762 Mtetra
.49781 .48762 .50396 .4941 .5151 .4906 .50898 .48409 Mtetra
.50898 .48409 .5151 .4906 .52629 .48708 .5202 .48054 Mtetra
.5202 .48054 .52629 .48708 .53752 .48355 .53146 .47698 Mtetra
.53146 .47698 .53752 .48355 .5488 .48 .54277 .47341 Mtetra
.54277 .47341 .5488 .48 .56013 .47643 .55413 .46982 Mtetra
.55413 .46982 .56013 .47643 .5715 .47286 .56553 .46621 Mtetra
.56553 .46621 .5715 .47286 .58292 .46926 .57698 .46259 Mtetra
.57698 .46259 .58292 .46926 .59438 .46566 .58848 .45896 Mtetra
.58848 .45896 .59438 .46566 .6059 .46203 .60002 .45531 Mtetra
.60002 .45531 .6059 .46203 .61746 .4584 .61162 .45164 Mtetra
.61162 .45164 .61746 .4584 .62907 .45475 .62326 .44796 Mtetra
.62326 .44796 .62907 .45475 .64072 .45108 .63495 .44427 Mtetra
.63495 .44427 .64072 .45108 .65243 .4474 .64669 .44056 Mtetra
.64669 .44056 .65243 .4474 .66418 .4437 .65848 .43683 Mtetra
.65848 .43683 .66418 .4437 .67599 .43998 .67031 .43309 Mtetra
.67031 .43309 .67599 .43998 .68784 .43626 .6822 .42933 Mtetra
.6822 .42933 .68784 .43626 .69975 .43251 .69414 .42556 Mtetra
.69414 .42556 .69975 .43251 .7117 .42875 .70613 .42177 Mtetra
.70613 .42177 .7117 .42875 .7237 .42497 .71817 .41796 Mtetra
.71817 .41796 .7237 .42497 .73576 .42118 .73026 .41414 Mtetra
.73026 .41414 .73576 .42118 .74786 .41737 .7424 .4103 Mtetra
.7424 .4103 .74786 .41737 .76002 .41355 .75459 .40644 Mtetra
.75459 .40644 .76002 .41355 .77223 .40971 .76684 .40257 Mtetra
.76684 .40257 .77223 .40971 .78449 .40585 .77914 .39869 Mtetra
.77914 .39869 .78449 .40585 .79681 .40198 .79149 .39478 Mtetra
.79149 .39478 .79681 .40198 .80917 .39809 .80389 .39086 Mtetra
.80389 .39086 .80917 .39809 .82159 .39418 .81635 .38692 Mtetra
.81635 .38692 .82159 .39418 .83406 .39025 .82886 .38297 Mtetra
.82886 .38297 .83406 .39025 .84659 .38631 .84143 .37899 Mtetra
.84143 .37899 .84659 .38631 .85917 .38236 .85405 .375 Mtetra
.85405 .375 .85917 .38236 .87181 .37838 .86672 .371 Mtetra
.86672 .371 .87181 .37838 .8845 .37439 .87945 .36697 Mtetra
.87945 .36697 .8845 .37439 .89724 .37038 .89224 .36293 Mtetra
.89224 .36293 .89724 .37038 .91004 .36635 .90508 .35887 Mtetra
.90508 .35887 .91004 .36635 .9229 .36231 .91798 .35479 Mtetra
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52268 Mtetra
.36069 .52268 .36722 .52891 .37786 .52554 .37136 .51929 Mtetra
.37136 .51929 .37786 .52554 .38855 .52216 .38207 .51589 Mtetra
.38207 .51589 .38855 .52216 .39928 .51877 .39283 .51247 Mtetra
.39283 .51247 .39928 .51877 .41005 .51537 .40363 .50904 Mtetra
.40363 .50904 .41005 .51537 .42087 .51195 .41447 .5056 Mtetra
.41447 .5056 .42087 .51195 .43173 .50851 .42536 .50214 Mtetra
.42536 .50214 .43173 .50851 .44263 .50507 .43629 .49867 Mtetra
.43629 .49867 .44263 .50507 .45358 .50161 .44727 .49518 Mtetra
.44727 .49518 .45358 .50161 .46457 .49813 .45829 .49168 Mtetra
.45829 .49168 .46457 .49813 .4756 .49464 .46935 .48816 Mtetra
.46935 .48816 .4756 .49464 .48668 .49114 .48046 .48463 Mtetra
.48046 .48463 .48668 .49114 .49781 .48762 .49162 .48109 Mtetra
.49162 .48109 .49781 .48762 .50898 .48409 .50282 .47753 Mtetra
.50282 .47753 .50898 .48409 .5202 .48054 .51406 .47396 Mtetra
.51406 .47396 .5202 .48054 .53146 .47698 .52536 .47037 Mtetra
.52536 .47037 .53146 .47698 .54277 .47341 .5367 .46677 Mtetra
.5367 .46677 .54277 .47341 .55413 .46982 .54809 .46315 Mtetra
.54809 .46315 .55413 .46982 .56553 .46621 .55952 .45952 Mtetra
.55952 .45952 .56553 .46621 .57698 .46259 .571 .45587 Mtetra
.571 .45587 .57698 .46259 .58848 .45896 .58253 .45221 Mtetra
.58253 .45221 .58848 .45896 .60002 .45531 .59411 .44853 Mtetra
.59411 .44853 .60002 .45531 .61162 .45164 .60573 .44484 Mtetra
.60573 .44484 .61162 .45164 .62326 .44796 .61741 .44113 Mtetra
.61741 .44113 .62326 .44796 .63495 .44427 .62913 .4374 Mtetra
.62913 .4374 .63495 .44427 .64669 .44056 .6409 .43366 Mtetra
.6409 .43366 .64669 .44056 .65848 .43683 .65272 .42991 Mtetra
.65272 .42991 .65848 .43683 .67031 .43309 .6646 .42614 Mtetra
.6646 .42614 .67031 .43309 .6822 .42933 .67652 .42235 Mtetra
.67652 .42235 .6822 .42933 .69414 .42556 .68849 .41855 Mtetra
.68849 .41855 .69414 .42556 .70613 .42177 .70051 .41473 Mtetra
.70051 .41473 .70613 .42177 .71817 .41796 .71259 .41089 Mtetra
.71259 .41089 .71817 .41796 .73026 .41414 .72471 .40704 Mtetra
.72471 .40704 .73026 .41414 .7424 .4103 .73689 .40317 Mtetra
.73689 .40317 .7424 .4103 .75459 .40644 .74912 .39928 Mtetra
.74912 .39928 .75459 .40644 .76684 .40257 .76141 .39538 Mtetra
.76141 .39538 .76684 .40257 .77914 .39869 .77374 .39146 Mtetra
.77374 .39146 .77914 .39869 .79149 .39478 .78613 .38753 Mtetra
.78613 .38753 .79149 .39478 .80389 .39086 .79857 .38358 Mtetra
.79857 .38358 .80389 .39086 .81635 .38692 .81107 .37961 Mtetra
.81107 .37961 .81635 .38692 .82886 .38297 .82362 .37562 Mtetra
.82362 .37562 .82886 .38297 .84143 .37899 .83622 .37161 Mtetra
.83622 .37161 .84143 .37899 .85405 .375 .84888 .36759 Mtetra
.84888 .36759 .85405 .375 .86672 .371 .8616 .36355 Mtetra
.8616 .36355 .86672 .371 .87945 .36697 .87437 .3595 Mtetra
.87437 .3595 .87945 .36697 .89224 .36293 .88719 .35542 Mtetra
.88719 .35542 .89224 .36293 .90508 .35887 .90008 .35133 Mtetra
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .5232 Mtetra
.33285 .5232 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52268 .35411 .51641 Mtetra
.35411 .51641 .36069 .52268 .37136 .51929 .36481 .513 Mtetra
.36481 .513 .37136 .51929 .38207 .51589 .37555 .50957 Mtetra
.37555 .50957 .38207 .51589 .39283 .51247 .38633 .50613 Mtetra
.38633 .50613 .39283 .51247 .40363 .50904 .39716 .50267 Mtetra
.39716 .50267 .40363 .50904 .41447 .5056 .40803 .4992 Mtetra
.40803 .4992 .41447 .5056 .42536 .50214 .41895 .49572 Mtetra
.41895 .49572 .42536 .50214 .43629 .49867 .42991 .49222 Mtetra
.42991 .49222 .43629 .49867 .44727 .49518 .44091 .48871 Mtetra
.44091 .48871 .44727 .49518 .45829 .49168 .45196 .48518 Mtetra
.45196 .48518 .45829 .49168 .46935 .48816 .46305 .48164 Mtetra
.46305 .48164 .46935 .48816 .48046 .48463 .47419 .47808 Mtetra
.47419 .47808 .48046 .48463 .49162 .48109 .48538 .47451 Mtetra
.48538 .47451 .49162 .48109 .50282 .47753 .49661 .47092 Mtetra
.49661 .47092 .50282 .47753 .51406 .47396 .50788 .46732 Mtetra
.50788 .46732 .51406 .47396 .52536 .47037 .51921 .46371 Mtetra
.51921 .46371 .52536 .47037 .5367 .46677 .53058 .46008 Mtetra
.53058 .46008 .5367 .46677 .54809 .46315 .542 .45643 Mtetra
.542 .45643 .54809 .46315 .55952 .45952 .55346 .45277 Mtetra
.55346 .45277 .55952 .45952 .571 .45587 .56497 .4491 Mtetra
.56497 .4491 .571 .45587 .58253 .45221 .57654 .44541 Mtetra
.57654 .44541 .58253 .45221 .59411 .44853 .58814 .4417 Mtetra
.58814 .4417 .59411 .44853 .60573 .44484 .5998 .43798 Mtetra
.5998 .43798 .60573 .44484 .61741 .44113 .61151 .43424 Mtetra
.61151 .43424 .61741 .44113 .62913 .4374 .62327 .43049 Mtetra
.62327 .43049 .62913 .4374 .6409 .43366 .63507 .42672 Mtetra
.63507 .42672 .6409 .43366 .65272 .42991 .64693 .42293 Mtetra
.64693 .42293 .65272 .42991 .6646 .42614 .65883 .41913 Mtetra
.65883 .41913 .6646 .42614 .67652 .42235 .67079 .41532 Mtetra
.67079 .41532 .67652 .42235 .68849 .41855 .6828 .41148 Mtetra
.6828 .41148 .68849 .41855 .70051 .41473 .69486 .40763 Mtetra
.69486 .40763 .70051 .41473 .71259 .41089 .70697 .40377 Mtetra
.70697 .40377 .71259 .41089 .72471 .40704 .71913 .39988 Mtetra
.71913 .39988 .72471 .40704 .73689 .40317 .73134 .39598 Mtetra
.73134 .39598 .73689 .40317 .74912 .39928 .74361 .39207 Mtetra
.74361 .39207 .74912 .39928 .76141 .39538 .75593 .38814 Mtetra
.75593 .38814 .76141 .39538 .77374 .39146 .7683 .38419 Mtetra
.7683 .38419 .77374 .39146 .78613 .38753 .78073 .38022 Mtetra
.78073 .38022 .78613 .38753 .79857 .38358 .79321 .37623 Mtetra
.79321 .37623 .79857 .38358 .81107 .37961 .80574 .37223 Mtetra
.80574 .37223 .81107 .37961 .82362 .37562 .81833 .36821 Mtetra
.81833 .36821 .82362 .37562 .83622 .37161 .83097 .36418 Mtetra
.83097 .36418 .83622 .37161 .84888 .36759 .84367 .36012 Mtetra
.84367 .36012 .84888 .36759 .8616 .36355 .85643 .35605 Mtetra
.85643 .35605 .8616 .36355 .87437 .3595 .86924 .35196 Mtetra
.86924 .35196 .87437 .3595 .88719 .35542 .88211 .34785 Mtetra
.88211 .34785 .88719 .35542 .90008 .35133 .89503 .34373 Mtetra
.89503 .34373 .90008 .35133 .91302 .34722 .90801 .33958 Mtetra
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .34346 .51982 .33681 .51353 Mtetra
.33681 .51353 .34346 .51982 .35411 .51641 .34749 .5101 Mtetra
.34749 .5101 .35411 .51641 .36481 .513 .35821 .50666 Mtetra
.35821 .50666 .36481 .513 .37555 .50957 .36898 .5032 Mtetra
.36898 .5032 .37555 .50957 .38633 .50613 .37979 .49974 Mtetra
.37979 .49974 .38633 .50613 .39716 .50267 .39065 .49625 Mtetra
.39065 .49625 .39716 .50267 .40803 .4992 .40154 .49276 Mtetra
.40154 .49276 .40803 .4992 .41895 .49572 .41249 .48925 Mtetra
.41249 .48925 .41895 .49572 .42991 .49222 .42347 .48572 Mtetra
.42347 .48572 .42991 .49222 .44091 .48871 .4345 .48218 Mtetra
.4345 .48218 .44091 .48871 .45196 .48518 .44558 .47863 Mtetra
.44558 .47863 .45196 .48518 .46305 .48164 .4567 .47506 Mtetra
.4567 .47506 .46305 .48164 .47419 .47808 .46787 .47148 Mtetra
.46787 .47148 .47419 .47808 .48538 .47451 .47909 .46788 Mtetra
.47909 .46788 .48538 .47451 .49661 .47092 .49035 .46427 Mtetra
.49035 .46427 .49661 .47092 .50788 .46732 .50166 .46064 Mtetra
.50166 .46064 .50788 .46732 .51921 .46371 .51301 .45699 Mtetra
.51301 .45699 .51921 .46371 .53058 .46008 .52441 .45334 Mtetra
.52441 .45334 .53058 .46008 .542 .45643 .53586 .44966 Mtetra
.53586 .44966 .542 .45643 .55346 .45277 .54736 .44598 Mtetra
.54736 .44598 .55346 .45277 .56497 .4491 .5589 .44227 Mtetra
.5589 .44227 .56497 .4491 .57654 .44541 .57049 .43855 Mtetra
.57049 .43855 .57654 .44541 .58814 .4417 .58214 .43482 Mtetra
.58214 .43482 .58814 .4417 .5998 .43798 .59383 .43107 Mtetra
.59383 .43107 .5998 .43798 .61151 .43424 .60557 .4273 Mtetra
.60557 .4273 .61151 .43424 .62327 .43049 .61736 .42352 Mtetra
.61736 .42352 .62327 .43049 .63507 .42672 .6292 .41972 Mtetra
.6292 .41972 .63507 .42672 .64693 .42293 .64109 .4159 Mtetra
.64109 .4159 .64693 .42293 .65883 .41913 .65303 .41207 Mtetra
.65303 .41207 .65883 .41913 .67079 .41532 .66502 .40823 Mtetra
.66502 .40823 .67079 .41532 .6828 .41148 .67706 .40436 Mtetra
.67706 .40436 .6828 .41148 .69486 .40763 .68915 .40048 Mtetra
.68915 .40048 .69486 .40763 .70697 .40377 .7013 .39659 Mtetra
.7013 .39659 .70697 .40377 .71913 .39988 .7135 .39267 Mtetra
.7135 .39267 .71913 .39988 .73134 .39598 .72575 .38874 Mtetra
.72575 .38874 .73134 .39598 .74361 .39207 .73805 .38479 Mtetra
.73805 .38479 .74361 .39207 .75593 .38814 .75041 .38083 Mtetra
.75041 .38083 .75593 .38814 .7683 .38419 .76282 .37685 Mtetra
.76282 .37685 .7683 .38419 .78073 .38022 .77528 .37285 Mtetra
.77528 .37285 .78073 .38022 .79321 .37623 .7878 .36883 Mtetra
.7878 .36883 .79321 .37623 .80574 .37223 .80037 .3648 Mtetra
.80037 .3648 .80574 .37223 .81833 .36821 .813 .36075 Mtetra
.813 .36075 .81833 .36821 .83097 .36418 .82568 .35668 Mtetra
.82568 .35668 .83097 .36418 .84367 .36012 .83842 .35259 Mtetra
.83842 .35259 .84367 .36012 .85643 .35605 .85122 .34849 Mtetra
.85122 .34849 .85643 .35605 .86924 .35196 .86407 .34436 Mtetra
.86407 .34436 .86924 .35196 .88211 .34785 .87698 .34022 Mtetra
.87698 .34022 .88211 .34785 .89503 .34373 .88994 .33606 Mtetra
.88994 .33606 .89503 .34373 .90801 .33958 .90297 .33188 Mtetra
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.34082 .50374 .34749 .5101 .35821 .50666 .35157 .50027 Mtetra
.35157 .50027 .35821 .50666 .36898 .5032 .36236 .49679 Mtetra
.36236 .49679 .36898 .5032 .37979 .49974 .3732 .4933 Mtetra
.3732 .4933 .37979 .49974 .39065 .49625 .38408 .48979 Mtetra
.38408 .48979 .39065 .49625 .40154 .49276 .39501 .48626 Mtetra
.39501 .48626 .40154 .49276 .41249 .48925 .40598 .48273 Mtetra
.40598 .48273 .41249 .48925 .42347 .48572 .41699 .47918 Mtetra
.41699 .47918 .42347 .48572 .4345 .48218 .42805 .47561 Mtetra
.42805 .47561 .4345 .48218 .44558 .47863 .43916 .47203 Mtetra
.43916 .47203 .44558 .47863 .4567 .47506 .45031 .46843 Mtetra
.45031 .46843 .4567 .47506 .46787 .47148 .46151 .46482 Mtetra
.46151 .46482 .46787 .47148 .47909 .46788 .47275 .4612 Mtetra
.47275 .4612 .47909 .46788 .49035 .46427 .48404 .45756 Mtetra
.48404 .45756 .49035 .46427 .50166 .46064 .49538 .4539 Mtetra
.49538 .4539 .50166 .46064 .51301 .45699 .50676 .45023 Mtetra
.50676 .45023 .51301 .45699 .52441 .45334 .5182 .44654 Mtetra
.5182 .44654 .52441 .45334 .53586 .44966 .52968 .44284 Mtetra
.52968 .44284 .53586 .44966 .54736 .44598 .5412 .43913 Mtetra
.5412 .43913 .54736 .44598 .5589 .44227 .55278 .43539 Mtetra
.55278 .43539 .5589 .44227 .57049 .43855 .56441 .43164 Mtetra
.56441 .43164 .57049 .43855 .58214 .43482 .57608 .42788 Mtetra
.57608 .42788 .58214 .43482 .59383 .43107 .5878 .4241 Mtetra
.5878 .4241 .59383 .43107 .60557 .4273 .59958 .4203 Mtetra
.59958 .4203 .60557 .4273 .61736 .42352 .6114 .41649 Mtetra
.6114 .41649 .61736 .42352 .6292 .41972 .62327 .41266 Mtetra
.62327 .41266 .6292 .41972 .64109 .4159 .6352 .40882 Mtetra
.6352 .40882 .64109 .4159 .65303 .41207 .64717 .40496 Mtetra
.64717 .40496 .65303 .41207 .66502 .40823 .6592 .40108 Mtetra
.6592 .40108 .66502 .40823 .67706 .40436 .67128 .39719 Mtetra
.67128 .39719 .67706 .40436 .68915 .40048 .6834 .39327 Mtetra
.6834 .39327 .68915 .40048 .7013 .39659 .69559 .38935 Mtetra
.69559 .38935 .7013 .39659 .7135 .39267 .70782 .3854 Mtetra
.70782 .3854 .7135 .39267 .72575 .38874 .72011 .38144 Mtetra
.72011 .38144 .72575 .38874 .73805 .38479 .73245 .37746 Mtetra
.73245 .37746 .73805 .38479 .75041 .38083 .74484 .37347 Mtetra
.74484 .37347 .75041 .38083 .76282 .37685 .75729 .36945 Mtetra
.75729 .36945 .76282 .37685 .77528 .37285 .76979 .36542 Mtetra
.76979 .36542 .77528 .37285 .7878 .36883 .78235 .36137 Mtetra
.78235 .36137 .7878 .36883 .80037 .3648 .79496 .35731 Mtetra
.79496 .35731 .80037 .3648 .813 .36075 .80763 .35322 Mtetra
.80763 .35322 .813 .36075 .82568 .35668 .82035 .34912 Mtetra
.82035 .34912 .82568 .35668 .83842 .35259 .83313 .345 Mtetra
.83313 .345 .83842 .35259 .85122 .34849 .84597 .34086 Mtetra
.84597 .34086 .85122 .34849 .86407 .34436 .85886 .3367 Mtetra
.85886 .3367 .86407 .34436 .87698 .34022 .87181 .33253 Mtetra
.87181 .33253 .87698 .34022 .88994 .33606 .88482 .32833 Mtetra
.88482 .32833 .88994 .33606 .90297 .33188 .89788 .32412 Mtetra
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .5008 Mtetra
.32336 .5008 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49383 Mtetra
.34487 .49383 .35157 .50027 .36236 .49679 .35569 .49033 Mtetra
.35569 .49033 .36236 .49679 .3732 .4933 .36656 .48681 Mtetra
.36656 .48681 .3732 .4933 .38408 .48979 .37746 .48327 Mtetra
.37746 .48327 .38408 .48979 .39501 .48626 .38842 .47972 Mtetra
.38842 .47972 .39501 .48626 .40598 .48273 .39942 .47616 Mtetra
.39942 .47616 .40598 .48273 .41699 .47918 .41046 .47258 Mtetra
.41046 .47258 .41699 .47918 .42805 .47561 .42155 .46899 Mtetra
.42155 .46899 .42805 .47561 .43916 .47203 .43268 .46538 Mtetra
.43268 .46538 .43916 .47203 .45031 .46843 .44386 .46176 Mtetra
.44386 .46176 .45031 .46843 .46151 .46482 .45509 .45812 Mtetra
.45509 .45812 .46151 .46482 .47275 .4612 .46637 .45446 Mtetra
.46637 .45446 .47275 .4612 .48404 .45756 .47769 .4508 Mtetra
.47769 .4508 .48404 .45756 .49538 .4539 .48905 .44711 Mtetra
.48905 .44711 .49538 .4539 .50676 .45023 .50047 .44341 Mtetra
.50047 .44341 .50676 .45023 .5182 .44654 .51193 .4397 Mtetra
.51193 .4397 .5182 .44654 .52968 .44284 .52344 .43597 Mtetra
.52344 .43597 .52968 .44284 .5412 .43913 .535 .43222 Mtetra
.535 .43222 .5412 .43913 .55278 .43539 .54661 .42846 Mtetra
.54661 .42846 .55278 .43539 .56441 .43164 .55827 .42468 Mtetra
.55827 .42468 .56441 .43164 .57608 .42788 .56998 .42089 Mtetra
.56998 .42089 .57608 .42788 .5878 .4241 .58173 .41708 Mtetra
.58173 .41708 .5878 .4241 .59958 .4203 .59354 .41325 Mtetra
.59354 .41325 .59958 .4203 .6114 .41649 .6054 .40941 Mtetra
.6054 .40941 .6114 .41649 .62327 .41266 .6173 .40555 Mtetra
.6173 .40555 .62327 .41266 .6352 .40882 .62926 .40168 Mtetra
.62926 .40168 .6352 .40882 .64717 .40496 .64127 .39779 Mtetra
.64127 .39779 .64717 .40496 .6592 .40108 .65333 .39388 Mtetra
.65333 .39388 .6592 .40108 .67128 .39719 .66545 .38995 Mtetra
.66545 .38995 .67128 .39719 .6834 .39327 .67761 .38601 Mtetra
.67761 .38601 .6834 .39327 .69559 .38935 .68983 .38205 Mtetra
.68983 .38205 .69559 .38935 .70782 .3854 .7021 .37807 Mtetra
.7021 .37807 .70782 .3854 .72011 .38144 .71442 .37408 Mtetra
.71442 .37408 .72011 .38144 .73245 .37746 .7268 .37007 Mtetra
.7268 .37007 .73245 .37746 .74484 .37347 .73923 .36604 Mtetra
.73923 .36604 .74484 .37347 .75729 .36945 .75172 .362 Mtetra
.75172 .362 .75729 .36945 .76979 .36542 .76426 .35793 Mtetra
.76426 .35793 .76979 .36542 .78235 .36137 .77685 .35385 Mtetra
.77685 .35385 .78235 .36137 .79496 .35731 .78951 .34975 Mtetra
.78951 .34975 .79496 .35731 .80763 .35322 .80221 .34563 Mtetra
.80221 .34563 .80763 .35322 .82035 .34912 .81498 .3415 Mtetra
.81498 .3415 .82035 .34912 .83313 .345 .82779 .33734 Mtetra
.82779 .33734 .83313 .345 .84597 .34086 .84067 .33317 Mtetra
.84067 .33317 .84597 .34086 .85886 .3367 .8536 .32898 Mtetra
.8536 .32898 .85886 .3367 .87181 .33253 .8666 .32477 Mtetra
.8666 .32477 .87181 .33253 .88482 .32833 .87965 .32054 Mtetra
.87965 .32054 .88482 .32833 .89788 .32412 .89275 .31629 Mtetra
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49786 Mtetra
.30585 .49786 .31267 .50427 .32336 .5008 .31656 .49437 Mtetra
.31656 .49437 .32336 .5008 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49383 .33812 .48735 Mtetra
.33812 .48735 .34487 .49383 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36656 .48681 .35986 .48027 Mtetra
.35986 .48027 .36656 .48681 .37746 .48327 .3708 .47671 Mtetra
.3708 .47671 .37746 .48327 .38842 .47972 .38178 .47313 Mtetra
.38178 .47313 .38842 .47972 .39942 .47616 .39281 .46954 Mtetra
.39281 .46954 .39942 .47616 .41046 .47258 .40388 .46593 Mtetra
.40388 .46593 .41046 .47258 .42155 .46899 .415 .46231 Mtetra
.415 .46231 .42155 .46899 .43268 .46538 .42616 .45868 Mtetra
.42616 .45868 .43268 .46538 .44386 .46176 .43737 .45503 Mtetra
.43737 .45503 .44386 .46176 .45509 .45812 .44863 .45136 Mtetra
.44863 .45136 .45509 .45812 .46637 .45446 .45993 .44768 Mtetra
.45993 .44768 .46637 .45446 .47769 .4508 .47128 .44398 Mtetra
.47128 .44398 .47769 .4508 .48905 .44711 .48268 .44027 Mtetra
.48268 .44027 .48905 .44711 .50047 .44341 .49413 .43654 Mtetra
.49413 .43654 .50047 .44341 .51193 .4397 .50562 .4328 Mtetra
.50562 .4328 .51193 .4397 .52344 .43597 .51716 .42904 Mtetra
.51716 .42904 .52344 .43597 .535 .43222 .52876 .42526 Mtetra
.52876 .42526 .535 .43222 .54661 .42846 .5404 .42147 Mtetra
.5404 .42147 .54661 .42846 .55827 .42468 .55209 .41767 Mtetra
.55209 .41767 .55827 .42468 .56998 .42089 .56383 .41384 Mtetra
.56383 .41384 .56998 .42089 .58173 .41708 .57562 .41 Mtetra
.57562 .41 .58173 .41708 .59354 .41325 .58746 .40615 Mtetra
.58746 .40615 .59354 .41325 .6054 .40941 .59935 .40227 Mtetra
.59935 .40227 .6054 .40941 .6173 .40555 .61129 .39839 Mtetra
.61129 .39839 .6173 .40555 .62926 .40168 .62328 .39448 Mtetra
.62328 .39448 .62926 .40168 .64127 .39779 .63532 .39056 Mtetra
.63532 .39056 .64127 .39779 .65333 .39388 .64742 .38662 Mtetra
.64742 .38662 .65333 .39388 .66545 .38995 .65957 .38266 Mtetra
.65957 .38266 .66545 .38995 .67761 .38601 .67177 .37869 Mtetra
.67177 .37869 .67761 .38601 .68983 .38205 .68402 .3747 Mtetra
.68402 .3747 .68983 .38205 .7021 .37807 .69633 .37069 Mtetra
.69633 .37069 .7021 .37807 .71442 .37408 .70869 .36666 Mtetra
.70869 .36666 .71442 .37408 .7268 .37007 .72111 .36262 Mtetra
.72111 .36262 .7268 .37007 .73923 .36604 .73358 .35856 Mtetra
.73358 .35856 .73923 .36604 .75172 .362 .7461 .35448 Mtetra
.7461 .35448 .75172 .362 .76426 .35793 .75868 .35038 Mtetra
.75868 .35038 .76426 .35793 .77685 .35385 .77131 .34627 Mtetra
.77131 .34627 .77685 .35385 .78951 .34975 .78401 .34213 Mtetra
.78401 .34213 .78951 .34975 .80221 .34563 .79675 .33798 Mtetra
.79675 .33798 .80221 .34563 .81498 .3415 .80955 .33381 Mtetra
.80955 .33381 .81498 .3415 .82779 .33734 .82241 .32963 Mtetra
.82241 .32963 .82779 .33734 .84067 .33317 .83533 .32542 Mtetra
.83533 .32542 .84067 .33317 .8536 .32898 .84831 .32119 Mtetra
.84831 .32119 .8536 .32898 .8666 .32477 .86134 .31695 Mtetra
.86134 .31695 .8666 .32477 .87965 .32054 .87443 .31268 Mtetra
.87443 .31268 .87965 .32054 .89275 .31629 .88758 .3084 Mtetra
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .3708 .47671 .36408 .47009 Mtetra
.36408 .47009 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.37509 .46649 .38178 .47313 .39281 .46954 .38615 .46287 Mtetra
.38615 .46287 .39281 .46954 .40388 .46593 .39725 .45924 Mtetra
.39725 .45924 .40388 .46593 .415 .46231 .4084 .45559 Mtetra
.4084 .45559 .415 .46231 .42616 .45868 .41959 .45193 Mtetra
.41959 .45193 .42616 .45868 .43737 .45503 .43083 .44825 Mtetra
.43083 .44825 .43737 .45503 .44863 .45136 .44211 .44455 Mtetra
.44211 .44455 .44863 .45136 .45993 .44768 .45345 .44084 Mtetra
.45345 .44084 .45993 .44768 .47128 .44398 .46483 .43712 Mtetra
.46483 .43712 .47128 .44398 .48268 .44027 .47626 .43338 Mtetra
.47626 .43338 .48268 .44027 .49413 .43654 .48774 .42962 Mtetra
.48774 .42962 .49413 .43654 .50562 .4328 .49926 .42585 Mtetra
.49926 .42585 .50562 .4328 .51716 .42904 .51084 .42206 Mtetra
.51084 .42206 .51716 .42904 .52876 .42526 .52246 .41825 Mtetra
.52246 .41825 .52876 .42526 .5404 .42147 .53413 .41443 Mtetra
.53413 .41443 .5404 .42147 .55209 .41767 .54585 .4106 Mtetra
.54585 .4106 .55209 .41767 .56383 .41384 .55763 .40674 Mtetra
.55763 .40674 .56383 .41384 .57562 .41 .56945 .40287 Mtetra
.56945 .40287 .57562 .41 .58746 .40615 .58132 .39899 Mtetra
.58132 .39899 .58746 .40615 .59935 .40227 .59325 .39508 Mtetra
.59325 .39508 .59935 .40227 .61129 .39839 .60522 .39116 Mtetra
.60522 .39116 .61129 .39839 .62328 .39448 .61725 .38723 Mtetra
.61725 .38723 .62328 .39448 .63532 .39056 .62933 .38327 Mtetra
.62933 .38327 .63532 .39056 .64742 .38662 .64146 .3793 Mtetra
.64146 .3793 .64742 .38662 .65957 .38266 .65365 .37531 Mtetra
.65365 .37531 .65957 .38266 .67177 .37869 .66588 .37131 Mtetra
.66588 .37131 .67177 .37869 .68402 .3747 .67817 .36728 Mtetra
.67817 .36728 .68402 .3747 .69633 .37069 .69052 .36324 Mtetra
.69052 .36324 .69633 .37069 .70869 .36666 .70292 .35918 Mtetra
.70292 .35918 .70869 .36666 .72111 .36262 .71537 .35511 Mtetra
.71537 .35511 .72111 .36262 .73358 .35856 .72788 .35101 Mtetra
.72788 .35101 .73358 .35856 .7461 .35448 .74044 .3469 Mtetra
.74044 .3469 .7461 .35448 .75868 .35038 .75306 .34277 Mtetra
.75306 .34277 .75868 .35038 .77131 .34627 .76573 .33862 Mtetra
.76573 .33862 .77131 .34627 .78401 .34213 .77846 .33446 Mtetra
.77846 .33446 .78401 .34213 .79675 .33798 .79125 .33027 Mtetra
.79125 .33027 .79675 .33798 .80955 .33381 .80409 .32607 Mtetra
.80409 .32607 .80955 .33381 .82241 .32963 .81699 .32184 Mtetra
.81699 .32184 .82241 .32963 .83533 .32542 .82995 .3176 Mtetra
.82995 .3176 .83533 .32542 .84831 .32119 .84297 .31334 Mtetra
.84297 .31334 .84831 .32119 .86134 .31695 .85604 .30906 Mtetra
.85604 .30906 .86134 .31695 .87443 .31268 .86918 .30476 Mtetra
.86918 .30476 .87443 .31268 .88758 .3084 .88237 .30044 Mtetra
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.34633 .46705 .35312 .47368 .36408 .47009 .35732 .46343 Mtetra
.35732 .46343 .36408 .47009 .37509 .46649 .36835 .4598 Mtetra
.36835 .4598 .37509 .46649 .38615 .46287 .37944 .45615 Mtetra
.37944 .45615 .38615 .46287 .39725 .45924 .39057 .45249 Mtetra
.39057 .45249 .39725 .45924 .4084 .45559 .40174 .44881 Mtetra
.40174 .44881 .4084 .45559 .41959 .45193 .41296 .44512 Mtetra
.41296 .44512 .41959 .45193 .43083 .44825 .42423 .44141 Mtetra
.42423 .44141 .43083 .44825 .44211 .44455 .43555 .43769 Mtetra
.43555 .43769 .44211 .44455 .45345 .44084 .44691 .43395 Mtetra
.44691 .43395 .45345 .44084 .46483 .43712 .45833 .4302 Mtetra
.45833 .4302 .46483 .43712 .47626 .43338 .46979 .42643 Mtetra
.46979 .42643 .47626 .43338 .48774 .42962 .48129 .42264 Mtetra
.48129 .42264 .48774 .42962 .49926 .42585 .49285 .41884 Mtetra
.49285 .41884 .49926 .42585 .51084 .42206 .50446 .41502 Mtetra
.50446 .41502 .51084 .42206 .52246 .41825 .51611 .41119 Mtetra
.51611 .41119 .52246 .41825 .53413 .41443 .52782 .40734 Mtetra
.52782 .40734 .53413 .41443 .54585 .4106 .53957 .40347 Mtetra
.53957 .40347 .54585 .4106 .55763 .40674 .55138 .39958 Mtetra
.55138 .39958 .55763 .40674 .56945 .40287 .56323 .39568 Mtetra
.56323 .39568 .56945 .40287 .58132 .39899 .57514 .39177 Mtetra
.57514 .39177 .58132 .39899 .59325 .39508 .5871 .38783 Mtetra
.5871 .38783 .59325 .39508 .60522 .39116 .59911 .38388 Mtetra
.59911 .38388 .60522 .39116 .61725 .38723 .61117 .37991 Mtetra
.61117 .37991 .61725 .38723 .62933 .38327 .62329 .37593 Mtetra
.62329 .37593 .62933 .38327 .64146 .3793 .63545 .37192 Mtetra
.63545 .37192 .64146 .3793 .65365 .37531 .64767 .3679 Mtetra
.64767 .3679 .65365 .37531 .66588 .37131 .65995 .36387 Mtetra
.65995 .36387 .66588 .37131 .67817 .36728 .67228 .35981 Mtetra
.67228 .35981 .67817 .36728 .69052 .36324 .68466 .35574 Mtetra
.68466 .35574 .69052 .36324 .70292 .35918 .69709 .35165 Mtetra
.69709 .35165 .70292 .35918 .71537 .35511 .70958 .34754 Mtetra
.70958 .34754 .71537 .35511 .72788 .35101 .72213 .34341 Mtetra
.72213 .34341 .72788 .35101 .74044 .3469 .73473 .33926 Mtetra
.73473 .33926 .74044 .3469 .75306 .34277 .74739 .3351 Mtetra
.74739 .3351 .75306 .34277 .76573 .33862 .7601 .33092 Mtetra
.7601 .33092 .76573 .33862 .77846 .33446 .77287 .32671 Mtetra
.77287 .32671 .77846 .33446 .79125 .33027 .7857 .32249 Mtetra
.7857 .32249 .79125 .33027 .80409 .32607 .79858 .31826 Mtetra
.79858 .31826 .80409 .32607 .81699 .32184 .81152 .314 Mtetra
.81152 .314 .81699 .32184 .82995 .3176 .82452 .30972 Mtetra
.82452 .30972 .82995 .3176 .84297 .31334 .83758 .30543 Mtetra
.83758 .30543 .84297 .31334 .85604 .30906 .8507 .30111 Mtetra
.8507 .30111 .85604 .30906 .86918 .30476 .86387 .29677 Mtetra
.86387 .29677 .86918 .30476 .88237 .30044 .87711 .29242 Mtetra
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.3285 .46399 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45671 Mtetra
.3505 .45671 .35732 .46343 .36835 .4598 .36156 .45306 Mtetra
.36156 .45306 .36835 .4598 .37944 .45615 .37268 .44938 Mtetra
.37268 .44938 .37944 .45615 .39057 .45249 .38383 .44569 Mtetra
.38383 .44569 .39057 .45249 .40174 .44881 .39504 .44199 Mtetra
.39504 .44199 .40174 .44881 .41296 .44512 .40629 .43827 Mtetra
.40629 .43827 .41296 .44512 .42423 .44141 .41759 .43453 Mtetra
.41759 .43453 .42423 .44141 .43555 .43769 .42893 .43078 Mtetra
.42893 .43078 .43555 .43769 .44691 .43395 .44033 .42701 Mtetra
.44033 .42701 .44691 .43395 .45833 .4302 .45177 .42323 Mtetra
.45177 .42323 .45833 .4302 .46979 .42643 .46326 .41943 Mtetra
.46326 .41943 .46979 .42643 .48129 .42264 .4748 .41561 Mtetra
.4748 .41561 .48129 .42264 .49285 .41884 .48639 .41178 Mtetra
.48639 .41178 .49285 .41884 .50446 .41502 .49803 .40793 Mtetra
.49803 .40793 .50446 .41502 .51611 .41119 .50972 .40406 Mtetra
.50972 .40406 .51611 .41119 .52782 .40734 .52145 .40018 Mtetra
.52145 .40018 .52782 .40734 .53957 .40347 .53324 .39628 Mtetra
.53324 .39628 .53957 .40347 .55138 .39958 .54508 .39237 Mtetra
.54508 .39237 .55138 .39958 .56323 .39568 .55697 .38844 Mtetra
.55697 .38844 .56323 .39568 .57514 .39177 .56891 .38449 Mtetra
.56891 .38449 .57514 .39177 .5871 .38783 .5809 .38052 Mtetra
.5809 .38052 .5871 .38783 .59911 .38388 .59295 .37654 Mtetra
.59295 .37654 .59911 .38388 .61117 .37991 .60505 .37254 Mtetra
.60505 .37254 .61117 .37991 .62329 .37593 .6172 .36852 Mtetra
.6172 .36852 .62329 .37593 .63545 .37192 .6294 .36449 Mtetra
.6294 .36449 .63545 .37192 .64767 .3679 .64166 .36043 Mtetra
.64166 .36043 .64767 .3679 .65995 .36387 .65397 .35636 Mtetra
.65397 .35636 .65995 .36387 .67228 .35981 .66633 .35228 Mtetra
.66633 .35228 .67228 .35981 .68466 .35574 .67875 .34817 Mtetra
.67875 .34817 .68466 .35574 .69709 .35165 .69122 .34404 Mtetra
.69122 .34404 .69709 .35165 .70958 .34754 .70375 .3399 Mtetra
.70375 .3399 .70958 .34754 .72213 .34341 .71633 .33574 Mtetra
.71633 .33574 .72213 .34341 .73473 .33926 .72897 .33156 Mtetra
.72897 .33156 .73473 .33926 .74739 .3351 .74167 .32736 Mtetra
.74167 .32736 .74739 .3351 .7601 .33092 .75442 .32315 Mtetra
.75442 .32315 .7601 .33092 .77287 .32671 .76723 .31891 Mtetra
.76723 .31891 .77287 .32671 .7857 .32249 .7801 .31465 Mtetra
.7801 .31465 .7857 .32249 .79858 .31826 .79302 .31038 Mtetra
.79302 .31038 .79858 .31826 .81152 .314 .80601 .30609 Mtetra
.80601 .30609 .81152 .314 .82452 .30972 .81905 .30177 Mtetra
.81905 .30177 .82452 .30972 .83758 .30543 .83215 .29744 Mtetra
.83215 .29744 .83758 .30543 .8507 .30111 .84531 .29309 Mtetra
.84531 .29309 .8507 .30111 .86387 .29677 .85853 .28872 Mtetra
.85853 .28872 .86387 .29677 .87711 .29242 .87181 .28433 Mtetra
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.33258 .45362 .33948 .46036 .3505 .45671 .34363 .44995 Mtetra
.34363 .44995 .3505 .45671 .36156 .45306 .35472 .44626 Mtetra
.35472 .44626 .36156 .45306 .37268 .44938 .36586 .44256 Mtetra
.36586 .44256 .37268 .44938 .38383 .44569 .37705 .43884 Mtetra
.37705 .43884 .38383 .44569 .39504 .44199 .38828 .4351 Mtetra
.38828 .4351 .39504 .44199 .40629 .43827 .39956 .43136 Mtetra
.39956 .43136 .40629 .43827 .41759 .43453 .41089 .42759 Mtetra
.41089 .42759 .41759 .43453 .42893 .43078 .42227 .42381 Mtetra
.42227 .42381 .42893 .43078 .44033 .42701 .43369 .42001 Mtetra
.43369 .42001 .44033 .42701 .45177 .42323 .44517 .4162 Mtetra
.44517 .4162 .45177 .42323 .46326 .41943 .45669 .41237 Mtetra
.45669 .41237 .46326 .41943 .4748 .41561 .46826 .40852 Mtetra
.46826 .40852 .4748 .41561 .48639 .41178 .47988 .40466 Mtetra
.47988 .40466 .48639 .41178 .49803 .40793 .49155 .40078 Mtetra
.49155 .40078 .49803 .40793 .50972 .40406 .50327 .39689 Mtetra
.50327 .39689 .50972 .40406 .52145 .40018 .51504 .39297 Mtetra
.51504 .39297 .52145 .40018 .53324 .39628 .52686 .38904 Mtetra
.52686 .38904 .53324 .39628 .54508 .39237 .53873 .3851 Mtetra
.53873 .3851 .54508 .39237 .55697 .38844 .55066 .38114 Mtetra
.55066 .38114 .55697 .38844 .56891 .38449 .56263 .37715 Mtetra
.56263 .37715 .56891 .38449 .5809 .38052 .57466 .37316 Mtetra
.57466 .37316 .5809 .38052 .59295 .37654 .58674 .36914 Mtetra
.58674 .36914 .59295 .37654 .60505 .37254 .59887 .36511 Mtetra
.59887 .36511 .60505 .37254 .6172 .36852 .61106 .36106 Mtetra
.61106 .36106 .6172 .36852 .6294 .36449 .62329 .35699 Mtetra
.62329 .35699 .6294 .36449 .64166 .36043 .63559 .35291 Mtetra
.63559 .35291 .64166 .36043 .65397 .35636 .64793 .3488 Mtetra
.64793 .3488 .65397 .35636 .66633 .35228 .66033 .34468 Mtetra
.66033 .34468 .66633 .35228 .67875 .34817 .67279 .34054 Mtetra
.67279 .34054 .67875 .34817 .69122 .34404 .6853 .33638 Mtetra
.6853 .33638 .69122 .34404 .70375 .3399 .69787 .3322 Mtetra
.69787 .3322 .70375 .3399 .71633 .33574 .71049 .32801 Mtetra
.71049 .32801 .71633 .33574 .72897 .33156 .72317 .3238 Mtetra
.72317 .3238 .72897 .33156 .74167 .32736 .73591 .31956 Mtetra
.73591 .31956 .74167 .32736 .75442 .32315 .7487 .31531 Mtetra
.7487 .31531 .75442 .32315 .76723 .31891 .76155 .31104 Mtetra
.76155 .31104 .76723 .31891 .7801 .31465 .77446 .30675 Mtetra
.77446 .30675 .7801 .31465 .79302 .31038 .78742 .30244 Mtetra
.78742 .30244 .79302 .31038 .80601 .30609 .80045 .29811 Mtetra
.80045 .29811 .80601 .30609 .81905 .30177 .81353 .29376 Mtetra
.81353 .29376 .81905 .30177 .83215 .29744 .82667 .28939 Mtetra
.82667 .28939 .83215 .29744 .84531 .29309 .83988 .285 Mtetra
.83988 .285 .84531 .29309 .85853 .28872 .85314 .2806 Mtetra
.85314 .2806 .85853 .28872 .87181 .28433 .86646 .27617 Mtetra
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
.3146 .45051 .32158 .45728 .33258 .45362 .32563 .44683 Mtetra
.32563 .44683 .33258 .45362 .34363 .44995 .3367 .44313 Mtetra
.3367 .44313 .34363 .44995 .35472 .44626 .34783 .43941 Mtetra
.34783 .43941 .35472 .44626 .36586 .44256 .35899 .43568 Mtetra
.35899 .43568 .36586 .44256 .37705 .43884 .37021 .43193 Mtetra
.37021 .43193 .37705 .43884 .38828 .4351 .38147 .42817 Mtetra
.38147 .42817 .38828 .4351 .39956 .43136 .39278 .42439 Mtetra
.39278 .42439 .39956 .43136 .41089 .42759 .40414 .4206 Mtetra
.40414 .4206 .41089 .42759 .42227 .42381 .41555 .41679 Mtetra
.41555 .41679 .42227 .42381 .43369 .42001 .427 .41296 Mtetra
.427 .41296 .43369 .42001 .44517 .4162 .43851 .40912 Mtetra
.43851 .40912 .44517 .4162 .45669 .41237 .45006 .40526 Mtetra
.45006 .40526 .45669 .41237 .46826 .40852 .46166 .40138 Mtetra
.46166 .40138 .46826 .40852 .47988 .40466 .47332 .39749 Mtetra
.47332 .39749 .47988 .40466 .49155 .40078 .48502 .39358 Mtetra
.48502 .39358 .49155 .40078 .50327 .39689 .49677 .38965 Mtetra
.49677 .38965 .50327 .39689 .51504 .39297 .50857 .38571 Mtetra
.50857 .38571 .51504 .39297 .52686 .38904 .52043 .38175 Mtetra
.52043 .38175 .52686 .38904 .53873 .3851 .53233 .37777 Mtetra
.53233 .37777 .53873 .3851 .55066 .38114 .54429 .37377 Mtetra
.54429 .37377 .55066 .38114 .56263 .37715 .5563 .36976 Mtetra
.5563 .36976 .56263 .37715 .57466 .37316 .56836 .36573 Mtetra
.56836 .36573 .57466 .37316 .58674 .36914 .58048 .36168 Mtetra
.58048 .36168 .58674 .36914 .59887 .36511 .59265 .35762 Mtetra
.59265 .35762 .59887 .36511 .61106 .36106 .60487 .35354 Mtetra
.60487 .35354 .61106 .36106 .62329 .35699 .61714 .34943 Mtetra
.61714 .34943 .62329 .35699 .63559 .35291 .62947 .34532 Mtetra
.62947 .34532 .63559 .35291 .64793 .3488 .64185 .34118 Mtetra
.64185 .34118 .64793 .3488 .66033 .34468 .65429 .33702 Mtetra
.65429 .33702 .66033 .34468 .67279 .34054 .66679 .33285 Mtetra
.66679 .33285 .67279 .34054 .6853 .33638 .67933 .32866 Mtetra
.67933 .32866 .6853 .33638 .69787 .3322 .69194 .32444 Mtetra
.69194 .32444 .69787 .3322 .71049 .32801 .7046 .32021 Mtetra
.7046 .32021 .71049 .32801 .72317 .3238 .71732 .31597 Mtetra
.71732 .31597 .72317 .3238 .73591 .31956 .73009 .3117 Mtetra
.73009 .3117 .73591 .31956 .7487 .31531 .74293 .30741 Mtetra
.74293 .30741 .7487 .31531 .76155 .31104 .75582 .3031 Mtetra
.75582 .3031 .76155 .31104 .77446 .30675 .76877 .29878 Mtetra
.76877 .29878 .77446 .30675 .78742 .30244 .78177 .29443 Mtetra
.78177 .29443 .78742 .30244 .80045 .29811 .79484 .29007 Mtetra
.79484 .29007 .80045 .29811 .81353 .29376 .80797 .28568 Mtetra
.80797 .28568 .81353 .29376 .82667 .28939 .82115 .28128 Mtetra
.82115 .28128 .82667 .28939 .83988 .285 .8344 .27685 Mtetra
.8344 .27685 .83988 .285 .85314 .2806 .8477 .2724 Mtetra
.8477 .2724 .85314 .2806 .86646 .27617 .86107 .26794 Mtetra
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.28559 .45108 .29268 .45784 .30361 .45418 .29655 .4474 Mtetra
.29655 .4474 .30361 .45418 .3146 .45051 .30756 .4437 Mtetra
.30756 .4437 .3146 .45051 .32563 .44683 .31862 .43998 Mtetra
.31862 .43998 .32563 .44683 .3367 .44313 .32973 .43626 Mtetra
.32973 .43626 .3367 .44313 .34783 .43941 .34088 .43251 Mtetra
.34088 .43251 .34783 .43941 .35899 .43568 .35207 .42875 Mtetra
.35207 .42875 .35899 .43568 .37021 .43193 .36332 .42497 Mtetra
.36332 .42497 .37021 .43193 .38147 .42817 .37461 .42118 Mtetra
.37461 .42118 .38147 .42817 .39278 .42439 .38595 .41737 Mtetra
.38595 .41737 .39278 .42439 .40414 .4206 .39734 .41355 Mtetra
.39734 .41355 .40414 .4206 .41555 .41679 .40878 .40971 Mtetra
.40878 .40971 .41555 .41679 .427 .41296 .42026 .40585 Mtetra
.42026 .40585 .427 .41296 .43851 .40912 .4318 .40198 Mtetra
.4318 .40198 .43851 .40912 .45006 .40526 .44338 .39809 Mtetra
.44338 .39809 .45006 .40526 .46166 .40138 .45502 .39418 Mtetra
.45502 .39418 .46166 .40138 .47332 .39749 .4667 .39025 Mtetra
.4667 .39025 .47332 .39749 .48502 .39358 .47843 .38631 Mtetra
.47843 .38631 .48502 .39358 .49677 .38965 .49022 .38236 Mtetra
.49022 .38236 .49677 .38965 .50857 .38571 .50206 .37838 Mtetra
.50206 .37838 .50857 .38571 .52043 .38175 .51394 .37439 Mtetra
.51394 .37439 .52043 .38175 .53233 .37777 .52588 .37038 Mtetra
.52588 .37038 .53233 .37777 .54429 .37377 .53788 .36635 Mtetra
.53788 .36635 .54429 .37377 .5563 .36976 .54992 .36231 Mtetra
.54992 .36231 .5563 .36976 .56836 .36573 .56202 .35825 Mtetra
.56202 .35825 .56836 .36573 .58048 .36168 .57417 .35416 Mtetra
.57417 .35416 .58048 .36168 .59265 .35762 .58637 .35007 Mtetra
.58637 .35007 .59265 .35762 .60487 .35354 .59863 .34595 Mtetra
.59863 .34595 .60487 .35354 .61714 .34943 .61094 .34182 Mtetra
.61094 .34182 .61714 .34943 .62947 .34532 .6233 .33766 Mtetra
.6233 .33766 .62947 .34532 .64185 .34118 .63572 .33349 Mtetra
.63572 .33349 .64185 .34118 .65429 .33702 .6482 .3293 Mtetra
.6482 .3293 .65429 .33702 .66679 .33285 .66073 .32509 Mtetra
.66073 .32509 .66679 .33285 .67933 .32866 .67332 .32087 Mtetra
.67332 .32087 .67933 .32866 .69194 .32444 .68596 .31662 Mtetra
.68596 .31662 .69194 .32444 .7046 .32021 .69866 .31236 Mtetra
.69866 .31236 .7046 .32021 .71732 .31597 .71142 .30807 Mtetra
.71142 .30807 .71732 .31597 .73009 .3117 .72423 .30377 Mtetra
.72423 .30377 .73009 .3117 .74293 .30741 .73711 .29944 Mtetra
.73711 .29944 .74293 .30741 .75582 .3031 .75004 .2951 Mtetra
.75004 .2951 .75582 .3031 .76877 .29878 .76303 .29074 Mtetra
.76303 .29074 .76877 .29878 .78177 .29443 .77608 .28636 Mtetra
.77608 .28636 .78177 .29443 .79484 .29007 .78919 .28195 Mtetra
.78919 .28195 .79484 .29007 .80797 .28568 .80235 .27753 Mtetra
.80235 .27753 .80797 .28568 .82115 .28128 .81558 .27309 Mtetra
.81558 .27309 .82115 .28128 .8344 .27685 .82887 .26863 Mtetra
.82887 .26863 .8344 .27685 .8477 .2724 .84222 .26414 Mtetra
.84222 .26414 .8477 .2724 .86107 .26794 .85563 .25964 Mtetra
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .4437 .30048 .43683 Mtetra
.30048 .43683 .30756 .4437 .31862 .43998 .31156 .43309 Mtetra
.31156 .43309 .31862 .43998 .32973 .43626 .32269 .42933 Mtetra
.32269 .42933 .32973 .43626 .34088 .43251 .33387 .42556 Mtetra
.33387 .42556 .34088 .43251 .35207 .42875 .3451 .42177 Mtetra
.3451 .42177 .35207 .42875 .36332 .42497 .35637 .41796 Mtetra
.35637 .41796 .36332 .42497 .37461 .42118 .3677 .41414 Mtetra
.3677 .41414 .37461 .42118 .38595 .41737 .37907 .4103 Mtetra
.37907 .4103 .38595 .41737 .39734 .41355 .39048 .40644 Mtetra
.39048 .40644 .39734 .41355 .40878 .40971 .40195 .40257 Mtetra
.40195 .40257 .40878 .40971 .42026 .40585 .41347 .39869 Mtetra
.41347 .39869 .42026 .40585 .4318 .40198 .42503 .39478 Mtetra
.42503 .39478 .4318 .40198 .44338 .39809 .43665 .39086 Mtetra
.43665 .39086 .44338 .39809 .45502 .39418 .44832 .38692 Mtetra
.44832 .38692 .45502 .39418 .4667 .39025 .46003 .38297 Mtetra
.46003 .38297 .4667 .39025 .47843 .38631 .4718 .37899 Mtetra
.4718 .37899 .47843 .38631 .49022 .38236 .48362 .375 Mtetra
.48362 .375 .49022 .38236 .50206 .37838 .49549 .371 Mtetra
.49549 .371 .50206 .37838 .51394 .37439 .50741 .36697 Mtetra
.50741 .36697 .51394 .37439 .52588 .37038 .51938 .36293 Mtetra
.51938 .36293 .52588 .37038 .53788 .36635 .53141 .35887 Mtetra
.53141 .35887 .53788 .36635 .54992 .36231 .54349 .35479 Mtetra
.54349 .35479 .54992 .36231 .56202 .35825 .55562 .3507 Mtetra
.55562 .3507 .56202 .35825 .57417 .35416 .5678 .34658 Mtetra
.5678 .34658 .57417 .35416 .58637 .35007 .58004 .34245 Mtetra
.58004 .34245 .58637 .35007 .59863 .34595 .59233 .3383 Mtetra
.59233 .3383 .59863 .34595 .61094 .34182 .60468 .33414 Mtetra
.60468 .33414 .61094 .34182 .6233 .33766 .61708 .32995 Mtetra
.61708 .32995 .6233 .33766 .63572 .33349 .62954 .32574 Mtetra
.62954 .32574 .63572 .33349 .6482 .3293 .64206 .32152 Mtetra
.64206 .32152 .6482 .3293 .66073 .32509 .65462 .31728 Mtetra
.65462 .31728 .66073 .32509 .67332 .32087 .66725 .31301 Mtetra
.66725 .31301 .67332 .32087 .68596 .31662 .67993 .30873 Mtetra
.67993 .30873 .68596 .31662 .69866 .31236 .69267 .30443 Mtetra
.69267 .30443 .69866 .31236 .71142 .30807 .70547 .30011 Mtetra
.70547 .30011 .71142 .30807 .72423 .30377 .71832 .29577 Mtetra
.71832 .29577 .72423 .30377 .73711 .29944 .73124 .29141 Mtetra
.73124 .29141 .73711 .29944 .75004 .2951 .74421 .28703 Mtetra
.74421 .28703 .75004 .2951 .76303 .29074 .75724 .28263 Mtetra
.75724 .28263 .76303 .29074 .77608 .28636 .77033 .27821 Mtetra
.77033 .27821 .77608 .28636 .78919 .28195 .78348 .27377 Mtetra
.78348 .27377 .78919 .28195 .80235 .27753 .79669 .26932 Mtetra
.79669 .26932 .80235 .27753 .81558 .27309 .80997 .26483 Mtetra
.80997 .26483 .81558 .27309 .82887 .26863 .8233 .26033 Mtetra
.8233 .26033 .82887 .26863 .84222 .26414 .83669 .25581 Mtetra
.83669 .25581 .84222 .26414 .85563 .25964 .85015 .25127 Mtetra
.504 .239 .446 r
.23297 .51115 .24574 .45531 .25659 .45164 .24406 .50752 Mtetra
.24406 .50752 .25659 .45164 .2675 .44796 .25518 .50387 Mtetra
.25518 .50387 .2675 .44796 .27844 .44427 .26636 .50021 Mtetra
.26636 .50021 .27844 .44427 .28944 .44056 .27758 .49653 Mtetra
.27758 .49653 .28944 .44056 .30048 .43683 .28885 .49284 Mtetra
.28885 .49284 .30048 .43683 .31156 .43309 .30017 .48913 Mtetra
.30017 .48913 .31156 .43309 .32269 .42933 .31154 .4854 Mtetra
.31154 .4854 .32269 .42933 .33387 .42556 .32296 .48166 Mtetra
.32296 .48166 .33387 .42556 .3451 .42177 .33442 .4779 Mtetra
.33442 .4779 .3451 .42177 .35637 .41796 .34594 .47413 Mtetra
.34594 .47413 .35637 .41796 .3677 .41414 .35751 .47034 Mtetra
.35751 .47034 .3677 .41414 .37907 .4103 .36912 .46653 Mtetra
.846 .565 .511 r
.36912 .46653 .37907 .4103 .39048 .40644 .37411 .61497 Mtetra
.534 .302 .509 r
.37411 .61497 .39048 .40644 .40195 .40257 .38636 .6113 Mtetra
.38636 .6113 .40195 .40257 .41347 .39869 .39867 .60762 Mtetra
.39867 .60762 .41347 .39869 .42503 .39478 .41103 .60391 Mtetra
.41103 .60391 .42503 .39478 .43665 .39086 .42344 .60019 Mtetra
.42344 .60019 .43665 .39086 .44832 .38692 .43592 .59645 Mtetra
.43592 .59645 .44832 .38692 .46003 .38297 .44845 .5927 Mtetra
.44845 .5927 .46003 .38297 .4718 .37899 .46104 .58892 Mtetra
.46104 .58892 .4718 .37899 .48362 .375 .47369 .58513 Mtetra
.47369 .58513 .48362 .375 .49549 .371 .4864 .58133 Mtetra
.4864 .58133 .49549 .371 .50741 .36697 .49917 .5775 Mtetra
.49917 .5775 .50741 .36697 .51938 .36293 .512 .57366 Mtetra
.512 .57366 .51938 .36293 .53141 .35887 .52489 .5698 Mtetra
0 0 .339 r
.52489 .5698 .53141 .35887 .54349 .35479 .53708 .36834 Mtetra
.349 0 .155 r
.53708 .36834 .54349 .35479 .55562 .3507 .54933 .36423 Mtetra
.54933 .36423 .55562 .3507 .5678 .34658 .56163 .3601 Mtetra
.56163 .3601 .5678 .34658 .58004 .34245 .57399 .35596 Mtetra
.57399 .35596 .58004 .34245 .59233 .3383 .5864 .35179 Mtetra
.5864 .35179 .59233 .3383 .60468 .33414 .59887 .34761 Mtetra
.59887 .34761 .60468 .33414 .61708 .32995 .6114 .34341 Mtetra
.6114 .34341 .61708 .32995 .62954 .32574 .62398 .33919 Mtetra
.62398 .33919 .62954 .32574 .64206 .32152 .63661 .33495 Mtetra
.63661 .33495 .64206 .32152 .65462 .31728 .64931 .33069 Mtetra
.64931 .33069 .65462 .31728 .66725 .31301 .66206 .32641 Mtetra
.66206 .32641 .66725 .31301 .67993 .30873 .67487 .32211 Mtetra
0 0 0 r
.67487 .32211 .67993 .30873 .69267 .30443 .68663 .29644 Mtetra
.664 .741 .908 r
.68663 .29644 .69267 .30443 .70547 .30011 .69947 .29208 Mtetra
.69947 .29208 .70547 .30011 .71832 .29577 .71237 .28771 Mtetra
.71237 .28771 .71832 .29577 .73124 .29141 .72532 .28331 Mtetra
.72532 .28331 .73124 .29141 .74421 .28703 .73833 .2789 Mtetra
.73833 .2789 .74421 .28703 .75724 .28263 .75141 .27446 Mtetra
.75141 .27446 .75724 .28263 .77033 .27821 .76454 .27 Mtetra
.76454 .27 .77033 .27821 .78348 .27377 .77773 .26553 Mtetra
.77773 .26553 .78348 .27377 .79669 .26932 .79099 .26103 Mtetra
.79099 .26103 .79669 .26932 .80997 .26483 .8043 .25651 Mtetra
.8043 .25651 .80997 .26483 .8233 .26033 .81768 .25197 Mtetra
.81768 .25197 .8233 .26033 .83669 .25581 .83112 .24741 Mtetra
.83112 .24741 .83669 .25581 .85015 .25127 .84462 .24283 Mtetra
.659 .747 .915 r
.22548 .50443 .23297 .51115 .24406 .50752 .23658 .50077 Mtetra
.23658 .50077 .24406 .50752 .25518 .50387 .24774 .4971 Mtetra
.24774 .4971 .25518 .50387 .26636 .50021 .25894 .49341 Mtetra
.25894 .49341 .26636 .50021 .27758 .49653 .27019 .4897 Mtetra
.27019 .4897 .27758 .49653 .28885 .49284 .28149 .48598 Mtetra
.28149 .48598 .28885 .49284 .30017 .48913 .29284 .48224 Mtetra
.29284 .48224 .30017 .48913 .31154 .4854 .30424 .47848 Mtetra
.30424 .47848 .31154 .4854 .32296 .48166 .31569 .47471 Mtetra
.31569 .47471 .32296 .48166 .33442 .4779 .32719 .47092 Mtetra
.32719 .47092 .33442 .4779 .34594 .47413 .33873 .46712 Mtetra
.33873 .46712 .34594 .47413 .35751 .47034 .35033 .4633 Mtetra
.35033 .4633 .35751 .47034 .36912 .46653 .36198 .45946 Mtetra
.954 .662 .443 r
.36198 .45946 .36912 .46653 .37411 .61497 .36664 .60818 Mtetra
.646 .762 .934 r
.36664 .60818 .37411 .61497 .38636 .6113 .37892 .60448 Mtetra
.37892 .60448 .38636 .6113 .39867 .60762 .39126 .60076 Mtetra
.39126 .60076 .39867 .60762 .41103 .60391 .40366 .59703 Mtetra
.40366 .59703 .41103 .60391 .42344 .60019 .41611 .59328 Mtetra
.41611 .59328 .42344 .60019 .43592 .59645 .42862 .58951 Mtetra
.42862 .58951 .43592 .59645 .44845 .5927 .44119 .58572 Mtetra
.44119 .58572 .44845 .5927 .46104 .58892 .45382 .58191 Mtetra
.45382 .58191 .46104 .58892 .47369 .58513 .46651 .57809 Mtetra
.46651 .57809 .47369 .58513 .4864 .58133 .47926 .57425 Mtetra
.47926 .57425 .4864 .58133 .49917 .5775 .49206 .57039 Mtetra
.49206 .57039 .49917 .5775 .512 .57366 .50493 .56651 Mtetra
.50493 .56651 .512 .57366 .52489 .5698 .51786 .56262 Mtetra
.965 .707 .495 r
.51786 .56262 .52489 .5698 .53708 .36834 .5305 .36074 Mtetra
.662 .743 .91 r
.5305 .36074 .53708 .36834 .54933 .36423 .54278 .3566 Mtetra
.54278 .3566 .54933 .36423 .56163 .3601 .55512 .35244 Mtetra
.55512 .35244 .56163 .3601 .57399 .35596 .56752 .34825 Mtetra
.56752 .34825 .57399 .35596 .5864 .35179 .57997 .34406 Mtetra
.57997 .34406 .5864 .35179 .59887 .34761 .59247 .33984 Mtetra
.59247 .33984 .59887 .34761 .6114 .34341 .60503 .3356 Mtetra
.60503 .3356 .6114 .34341 .62398 .33919 .61765 .33134 Mtetra
.61765 .33134 .62398 .33919 .63661 .33495 .63033 .32707 Mtetra
.63033 .32707 .63661 .33495 .64931 .33069 .64306 .32277 Mtetra
.64306 .32277 .64931 .33069 .66206 .32641 .65586 .31846 Mtetra
.65586 .31846 .66206 .32641 .67487 .32211 .66871 .31412 Mtetra
.92 .784 .694 r
.66871 .31412 .67487 .32211 .68663 .29644 .68054 .28838 Mtetra
.664 .741 .908 r
.68054 .28838 .68663 .29644 .69947 .29208 .69342 .28399 Mtetra
.69342 .28399 .69947 .29208 .71237 .28771 .70636 .27958 Mtetra
.70636 .27958 .71237 .28771 .72532 .28331 .71935 .27514 Mtetra
.71935 .27514 .72532 .28331 .73833 .2789 .73241 .27069 Mtetra
.73241 .27069 .73833 .2789 .75141 .27446 .74552 .26622 Mtetra
.74552 .26622 .75141 .27446 .76454 .27 .7587 .26172 Mtetra
.7587 .26172 .76454 .27 .77773 .26553 .77193 .25721 Mtetra
.77193 .25721 .77773 .26553 .79099 .26103 .78523 .25267 Mtetra
.78523 .25267 .79099 .26103 .8043 .25651 .79859 .24811 Mtetra
.79859 .24811 .8043 .25651 .81768 .25197 .81201 .24353 Mtetra
.81201 .24353 .81768 .25197 .83112 .24741 .82549 .23893 Mtetra
.82549 .23893 .83112 .24741 .84462 .24283 .83904 .23431 Mtetra
.659 .747 .915 r
.21792 .49766 .22548 .50443 .23658 .50077 .22905 .49398 Mtetra
.22905 .49398 .23658 .50077 .24774 .4971 .24024 .49027 Mtetra
.24024 .49027 .24774 .4971 .25894 .49341 .25147 .48655 Mtetra
.25147 .48655 .25894 .49341 .27019 .4897 .26275 .48282 Mtetra
.26275 .48282 .27019 .4897 .28149 .48598 .27408 .47906 Mtetra
.27408 .47906 .28149 .48598 .29284 .48224 .28546 .47529 Mtetra
.28546 .47529 .29284 .48224 .30424 .47848 .29689 .47151 Mtetra
.29689 .47151 .30424 .47848 .31569 .47471 .30836 .46771 Mtetra
.30836 .46771 .31569 .47471 .32719 .47092 .31989 .46389 Mtetra
.31989 .46389 .32719 .47092 .33873 .46712 .33147 .46005 Mtetra
.33147 .46005 .33873 .46712 .35033 .4633 .3431 .4562 Mtetra
.3431 .4562 .35033 .4633 .36198 .45946 .35478 .45233 Mtetra
.954 .662 .443 r
.35478 .45233 .36198 .45946 .36664 .60818 .3591 .60134 Mtetra
.646 .762 .934 r
.3591 .60134 .36664 .60818 .37892 .60448 .37142 .5976 Mtetra
.37142 .5976 .37892 .60448 .39126 .60076 .3838 .59385 Mtetra
.3838 .59385 .39126 .60076 .40366 .59703 .39623 .59009 Mtetra
.39623 .59009 .40366 .59703 .41611 .59328 .40872 .5863 Mtetra
.40872 .5863 .41611 .59328 .42862 .58951 .42127 .5825 Mtetra
.42127 .5825 .42862 .58951 .44119 .58572 .43387 .57868 Mtetra
.43387 .57868 .44119 .58572 .45382 .58191 .44654 .57484 Mtetra
.44654 .57484 .45382 .58191 .46651 .57809 .45926 .57099 Mtetra
.45926 .57099 .46651 .57809 .47926 .57425 .47205 .56711 Mtetra
.47205 .56711 .47926 .57425 .49206 .57039 .4849 .56322 Mtetra
.4849 .56322 .49206 .57039 .50493 .56651 .4978 .55931 Mtetra
.4978 .55931 .50493 .56651 .51786 .56262 .51077 .55538 Mtetra
.965 .707 .495 r
.51077 .55538 .51786 .56262 .5305 .36074 .52386 .35308 Mtetra
.662 .743 .91 r
.52386 .35308 .5305 .36074 .54278 .3566 .53618 .3489 Mtetra
.53618 .3489 .54278 .3566 .55512 .35244 .54856 .3447 Mtetra
.54856 .3447 .55512 .35244 .56752 .34825 .56099 .34049 Mtetra
.56099 .34049 .56752 .34825 .57997 .34406 .57348 .33625 Mtetra
.57348 .33625 .57997 .34406 .59247 .33984 .58602 .332 Mtetra
.58602 .332 .59247 .33984 .60503 .3356 .59862 .32773 Mtetra
.59862 .32773 .60503 .3356 .61765 .33134 .61128 .32343 Mtetra
.61128 .32343 .61765 .33134 .63033 .32707 .62399 .31912 Mtetra
.62399 .31912 .63033 .32707 .64306 .32277 .63676 .31479 Mtetra
.63676 .31479 .64306 .32277 .65586 .31846 .6496 .31044 Mtetra
.6496 .31044 .65586 .31846 .66871 .31412 .66249 .30607 Mtetra
.92 .784 .694 r
.66249 .30607 .66871 .31412 .68054 .28838 .6744 .28026 Mtetra
.664 .741 .908 r
.6744 .28026 .68054 .28838 .69342 .28399 .68732 .27583 Mtetra
.68732 .27583 .69342 .28399 .70636 .27958 .7003 .27138 Mtetra
.7003 .27138 .70636 .27958 .71935 .27514 .71333 .26691 Mtetra
.71333 .26691 .71935 .27514 .73241 .27069 .72643 .26241 Mtetra
.72643 .26241 .73241 .27069 .74552 .26622 .73959 .2579 Mtetra
.73959 .2579 .74552 .26622 .7587 .26172 .7528 .25337 Mtetra
.7528 .25337 .7587 .26172 .77193 .25721 .76608 .24881 Mtetra
.76608 .24881 .77193 .25721 .78523 .25267 .77942 .24424 Mtetra
.77942 .24424 .78523 .25267 .79859 .24811 .79283 .23964 Mtetra
.79283 .23964 .79859 .24811 .81201 .24353 .80629 .23502 Mtetra
.80629 .23502 .81201 .24353 .82549 .23893 .81982 .23039 Mtetra
.81982 .23039 .82549 .23893 .83904 .23431 .83341 .22572 Mtetra
.659 .747 .915 r
.2103 .49084 .21792 .49766 .22905 .49398 .22147 .48713 Mtetra
.22147 .48713 .22905 .49398 .24024 .49027 .23268 .48339 Mtetra
.23268 .48339 .24024 .49027 .25147 .48655 .24394 .47964 Mtetra
.24394 .47964 .25147 .48655 .26275 .48282 .25525 .47587 Mtetra
.25525 .47587 .26275 .48282 .27408 .47906 .2666 .47209 Mtetra
.2666 .47209 .27408 .47906 .28546 .47529 .27801 .46829 Mtetra
.27801 .46829 .28546 .47529 .29689 .47151 .28947 .46448 Mtetra
.28947 .46448 .29689 .47151 .30836 .46771 .30098 .46064 Mtetra
.30098 .46064 .30836 .46771 .31989 .46389 .31253 .4568 Mtetra
.31253 .4568 .31989 .46389 .33147 .46005 .32414 .45293 Mtetra
.32414 .45293 .33147 .46005 .3431 .4562 .3358 .44905 Mtetra
.3358 .44905 .3431 .4562 .35478 .45233 .34751 .44515 Mtetra
.954 .662 .443 r
.34751 .44515 .35478 .45233 .3591 .60134 .3515 .59443 Mtetra
.646 .762 .934 r
.3515 .59443 .3591 .60134 .37142 .5976 .36386 .59067 Mtetra
.36386 .59067 .37142 .5976 .3838 .59385 .37627 .58689 Mtetra
.37627 .58689 .3838 .59385 .39623 .59009 .38873 .58309 Mtetra
.38873 .58309 .39623 .59009 .40872 .5863 .40126 .57927 Mtetra
.40126 .57927 .40872 .5863 .42127 .5825 .41385 .57543 Mtetra
.41385 .57543 .42127 .5825 .43387 .57868 .42649 .57158 Mtetra
.42649 .57158 .43387 .57868 .44654 .57484 .43919 .56771 Mtetra
.43919 .56771 .44654 .57484 .45926 .57099 .45196 .56382 Mtetra
.45196 .56382 .45926 .57099 .47205 .56711 .46478 .55991 Mtetra
.46478 .55991 .47205 .56711 .4849 .56322 .47766 .55598 Mtetra
.47766 .55598 .4849 .56322 .4978 .55931 .49061 .55204 Mtetra
.49061 .55204 .4978 .55931 .51077 .55538 .50362 .54807 Mtetra
.965 .707 .495 r
.50362 .54807 .51077 .55538 .52386 .35308 .51717 .34535 Mtetra
.662 .743 .91 r
.51717 .34535 .52386 .35308 .53618 .3489 .52953 .34114 Mtetra
.52953 .34114 .53618 .3489 .54856 .3447 .54194 .33691 Mtetra
.54194 .33691 .54856 .3447 .56099 .34049 .55441 .33266 Mtetra
.55441 .33266 .56099 .34049 .57348 .33625 .56693 .32839 Mtetra
.56693 .32839 .57348 .33625 .58602 .332 .57951 .3241 Mtetra
.57951 .3241 .58602 .332 .59862 .32773 .59215 .31979 Mtetra
.59215 .31979 .59862 .32773 .61128 .32343 .60485 .31546 Mtetra
.60485 .31546 .61128 .32343 .62399 .31912 .6176 .31111 Mtetra
.6176 .31111 .62399 .31912 .63676 .31479 .63041 .30674 Mtetra
.63041 .30674 .63676 .31479 .6496 .31044 .64328 .30235 Mtetra
.64328 .30235 .6496 .31044 .66249 .30607 .65621 .29795 Mtetra
.92 .784 .694 r
.65621 .29795 .66249 .30607 .6744 .28026 .66821 .27206 Mtetra
.664 .741 .908 r
.66821 .27206 .6744 .28026 .68732 .27583 .68117 .26759 Mtetra
.68117 .26759 .68732 .27583 .7003 .27138 .69419 .26311 Mtetra
.69419 .26311 .7003 .27138 .71333 .26691 .70726 .2586 Mtetra
.70726 .2586 .71333 .26691 .72643 .26241 .7204 .25407 Mtetra
.7204 .25407 .72643 .26241 .73959 .2579 .7336 .24952 Mtetra
.7336 .24952 .73959 .2579 .7528 .25337 .74686 .24494 Mtetra
.74686 .24494 .7528 .25337 .76608 .24881 .76018 .24035 Mtetra
.76018 .24035 .76608 .24881 .77942 .24424 .77357 .23574 Mtetra
.77357 .23574 .77942 .24424 .79283 .23964 .78702 .2311 Mtetra
.78702 .2311 .79283 .23964 .80629 .23502 .80053 .22644 Mtetra
.80053 .22644 .80629 .23502 .81982 .23039 .8141 .22176 Mtetra
.8141 .22176 .81982 .23039 .83341 .22572 .82774 .21706 Mtetra
.659 .747 .915 r
.20262 .48397 .2103 .49084 .22147 .48713 .21382 .48022 Mtetra
.21382 .48022 .22147 .48713 .23268 .48339 .22506 .47646 Mtetra
.22506 .47646 .23268 .48339 .24394 .47964 .23634 .47268 Mtetra
.23634 .47268 .24394 .47964 .25525 .47587 .24768 .46888 Mtetra
.24768 .46888 .25525 .47587 .2666 .47209 .25907 .46507 Mtetra
.25907 .46507 .2666 .47209 .27801 .46829 .27051 .46124 Mtetra
.27051 .46124 .27801 .46829 .28947 .46448 .28199 .45739 Mtetra
.28199 .45739 .28947 .46448 .30098 .46064 .29353 .45353 Mtetra
.29353 .45353 .30098 .46064 .31253 .4568 .30512 .44964 Mtetra
.30512 .44964 .31253 .4568 .32414 .45293 .31676 .44575 Mtetra
.31676 .44575 .32414 .45293 .3358 .44905 .32845 .44183 Mtetra
.32845 .44183 .3358 .44905 .34751 .44515 .34019 .4379 Mtetra
.954 .662 .443 r
.34019 .4379 .34751 .44515 .3515 .59443 .34384 .58747 Mtetra
.646 .762 .934 r
.34384 .58747 .3515 .59443 .36386 .59067 .35622 .58367 Mtetra
.35622 .58367 .36386 .59067 .37627 .58689 .36867 .57986 Mtetra
.36867 .57986 .37627 .58689 .38873 .58309 .38117 .57602 Mtetra
.38117 .57602 .38873 .58309 .40126 .57927 .39374 .57217 Mtetra
.39374 .57217 .40126 .57927 .41385 .57543 .40636 .56831 Mtetra
.40636 .56831 .41385 .57543 .42649 .57158 .41904 .56442 Mtetra
.41904 .56442 .42649 .57158 .43919 .56771 .43178 .56051 Mtetra
.43178 .56051 .43919 .56771 .45196 .56382 .44458 .55659 Mtetra
.44458 .55659 .45196 .56382 .46478 .55991 .45745 .55265 Mtetra
.45745 .55265 .46478 .55991 .47766 .55598 .47037 .54869 Mtetra
.47037 .54869 .47766 .55598 .49061 .55204 .48336 .54471 Mtetra
.48336 .54471 .49061 .55204 .50362 .54807 .4964 .54071 Mtetra
.965 .707 .495 r
.4964 .54071 .50362 .54807 .51717 .34535 .51042 .33756 Mtetra
.662 .743 .91 r
.51042 .33756 .51717 .34535 .52953 .34114 .52282 .33331 Mtetra
.52282 .33331 .52953 .34114 .54194 .33691 .53526 .32904 Mtetra
.53526 .32904 .54194 .33691 .55441 .33266 .54777 .32476 Mtetra
.54777 .32476 .55441 .33266 .56693 .32839 .56033 .32045 Mtetra
.56033 .32045 .56693 .32839 .57951 .3241 .57295 .31613 Mtetra
.57295 .31613 .57951 .3241 .59215 .31979 .58563 .31178 Mtetra
.58563 .31178 .59215 .31979 .60485 .31546 .59836 .30742 Mtetra
.59836 .30742 .60485 .31546 .6176 .31111 .61115 .30303 Mtetra
.61115 .30303 .6176 .31111 .63041 .30674 .62401 .29863 Mtetra
.62401 .29863 .63041 .30674 .64328 .30235 .63692 .2942 Mtetra
.63692 .2942 .64328 .30235 .65621 .29795 .64989 .28975 Mtetra
.92 .784 .694 r
.64989 .28975 .65621 .29795 .66821 .27206 .66197 .2638 Mtetra
.664 .741 .908 r
.66197 .2638 .66821 .27206 .68117 .26759 .67496 .25929 Mtetra
.67496 .25929 .68117 .26759 .69419 .26311 .68802 .25477 Mtetra
.68802 .25477 .69419 .26311 .70726 .2586 .70114 .25022 Mtetra
.70114 .25022 .70726 .2586 .7204 .25407 .71432 .24565 Mtetra
.71432 .24565 .7204 .25407 .7336 .24952 .72756 .24106 Mtetra
.72756 .24106 .7336 .24952 .74686 .24494 .74087 .23645 Mtetra
.74087 .23645 .74686 .24494 .76018 .24035 .75423 .23182 Mtetra
.75423 .23182 .76018 .24035 .77357 .23574 .76766 .22716 Mtetra
.76766 .22716 .77357 .23574 .78702 .2311 .78115 .22248 Mtetra
.78115 .22248 .78702 .2311 .80053 .22644 .79471 .21779 Mtetra
.79471 .21779 .80053 .22644 .8141 .22176 .80833 .21306 Mtetra
.80833 .21306 .8141 .22176 .82774 .21706 .82201 .20832 Mtetra
.659 .747 .915 r
.19488 .47704 .20262 .48397 .21382 .48022 .2061 .47326 Mtetra
.2061 .47326 .21382 .48022 .22506 .47646 .21737 .46946 Mtetra
.21737 .46946 .22506 .47646 .23634 .47268 .22869 .46565 Mtetra
.22869 .46565 .23634 .47268 .24768 .46888 .24006 .46183 Mtetra
.24006 .46183 .24768 .46888 .25907 .46507 .25147 .45798 Mtetra
.25147 .45798 .25907 .46507 .27051 .46124 .26294 .45412 Mtetra
.26294 .45412 .27051 .46124 .28199 .45739 .27446 .45024 Mtetra
.27446 .45024 .28199 .45739 .29353 .45353 .28602 .44635 Mtetra
.28602 .44635 .29353 .45353 .30512 .44964 .29764 .44244 Mtetra
.29764 .44244 .30512 .44964 .31676 .44575 .30931 .43851 Mtetra
.30931 .43851 .31676 .44575 .32845 .44183 .32104 .43456 Mtetra
.32104 .43456 .32845 .44183 .34019 .4379 .33281 .4306 Mtetra
.954 .662 .443 r
.33281 .4306 .34019 .4379 .34384 .58747 .3361 .58045 Mtetra
.646 .762 .934 r
.3361 .58045 .34384 .58747 .35622 .58367 .34853 .57662 Mtetra
.34853 .57662 .35622 .58367 .36867 .57986 .36101 .57277 Mtetra
.36101 .57277 .36867 .57986 .38117 .57602 .37355 .5689 Mtetra
.37355 .5689 .38117 .57602 .39374 .57217 .38615 .56502 Mtetra
.38615 .56502 .39374 .57217 .40636 .56831 .39881 .56111 Mtetra
.39881 .56111 .40636 .56831 .41904 .56442 .41153 .55719 Mtetra
.41153 .55719 .41904 .56442 .43178 .56051 .42431 .55325 Mtetra
.42431 .55325 .43178 .56051 .44458 .55659 .43715 .5493 Mtetra
.43715 .5493 .44458 .55659 .45745 .55265 .45005 .54532 Mtetra
.45005 .54532 .45745 .55265 .47037 .54869 .46301 .54132 Mtetra
.46301 .54132 .47037 .54869 .48336 .54471 .47604 .53731 Mtetra
.47604 .53731 .48336 .54471 .4964 .54071 .48912 .53327 Mtetra
.965 .707 .495 r
.48912 .53327 .4964 .54071 .51042 .33756 .50362 .3297 Mtetra
.662 .743 .91 r
.50362 .3297 .51042 .33756 .52282 .33331 .51605 .32542 Mtetra
.51605 .32542 .52282 .33331 .53526 .32904 .52853 .32112 Mtetra
.52853 .32112 .53526 .32904 .54777 .32476 .54108 .31679 Mtetra
.54108 .31679 .54777 .32476 .56033 .32045 .55368 .31245 Mtetra
.55368 .31245 .56033 .32045 .57295 .31613 .56633 .30809 Mtetra
.56633 .30809 .57295 .31613 .58563 .31178 .57905 .30371 Mtetra
.57905 .30371 .58563 .31178 .59836 .30742 .59182 .29931 Mtetra
.59182 .29931 .59836 .30742 .61115 .30303 .60465 .29488 Mtetra
.60465 .29488 .61115 .30303 .62401 .29863 .61755 .29044 Mtetra
.61755 .29044 .62401 .29863 .63692 .2942 .6305 .28598 Mtetra
.6305 .28598 .63692 .2942 .64989 .28975 .64351 .28149 Mtetra
.92 .784 .694 r
.64351 .28149 .64989 .28975 .66197 .2638 .65567 .25546 Mtetra
.664 .741 .908 r
.65567 .25546 .66197 .2638 .67496 .25929 .66871 .25092 Mtetra
.66871 .25092 .67496 .25929 .68802 .25477 .68181 .24635 Mtetra
.68181 .24635 .68802 .25477 .70114 .25022 .69497 .24177 Mtetra
.69497 .24177 .70114 .25022 .71432 .24565 .70819 .23716 Mtetra
.70819 .23716 .71432 .24565 .72756 .24106 .72148 .23253 Mtetra
.72148 .23253 .72756 .24106 .74087 .23645 .73482 .22788 Mtetra
.73482 .22788 .74087 .23645 .75423 .23182 .74823 .2232 Mtetra
.74823 .2232 .75423 .23182 .76766 .22716 .7617 .21851 Mtetra
.7617 .21851 .76766 .22716 .78115 .22248 .77524 .21379 Mtetra
.77524 .21379 .78115 .22248 .79471 .21779 .78884 .20905 Mtetra
.78884 .20905 .79471 .21779 .80833 .21306 .80251 .20429 Mtetra
.80251 .20429 .80833 .21306 .82201 .20832 .81623 .19951 Mtetra
.659 .747 .915 r
.18708 .47005 .19488 .47704 .2061 .47326 .19833 .46624 Mtetra
.19833 .46624 .2061 .47326 .21737 .46946 .20963 .46242 Mtetra
.20963 .46242 .21737 .46946 .22869 .46565 .22097 .45857 Mtetra
.22097 .45857 .22869 .46565 .24006 .46183 .23237 .45472 Mtetra
.23237 .45472 .24006 .46183 .25147 .45798 .24382 .45084 Mtetra
.24382 .45084 .25147 .45798 .26294 .45412 .25531 .44695 Mtetra
.25531 .44695 .26294 .45412 .27446 .45024 .26686 .44304 Mtetra
.26686 .44304 .27446 .45024 .28602 .44635 .27846 .43911 Mtetra
.27846 .43911 .28602 .44635 .29764 .44244 .29011 .43517 Mtetra
.29011 .43517 .29764 .44244 .30931 .43851 .30181 .43121 Mtetra
.30181 .43121 .30931 .43851 .32104 .43456 .31356 .42723 Mtetra
.31356 .42723 .32104 .43456 .33281 .4306 .32537 .42323 Mtetra
.954 .662 .443 r
.32537 .42323 .33281 .4306 .3361 .58045 .3283 .57336 Mtetra
.646 .762 .934 r
.3283 .57336 .3361 .58045 .34853 .57662 .34076 .5695 Mtetra
.34076 .5695 .34853 .57662 .36101 .57277 .35328 .56562 Mtetra
.35328 .56562 .36101 .57277 .37355 .5689 .36586 .56172 Mtetra
.36586 .56172 .37355 .5689 .38615 .56502 .37849 .5578 Mtetra
.37849 .5578 .38615 .56502 .39881 .56111 .39119 .55386 Mtetra
.39119 .55386 .39881 .56111 .41153 .55719 .40395 .54991 Mtetra
.40395 .54991 .41153 .55719 .42431 .55325 .41677 .54593 Mtetra
.41677 .54593 .42431 .55325 .43715 .5493 .42964 .54194 Mtetra
.42964 .54194 .43715 .5493 .45005 .54532 .44258 .53793 Mtetra
.44258 .53793 .45005 .54532 .46301 .54132 .45559 .53389 Mtetra
.45559 .53389 .46301 .54132 .47604 .53731 .46865 .52984 Mtetra
.46865 .52984 .47604 .53731 .48912 .53327 .48178 .52577 Mtetra
.965 .707 .495 r
.48178 .52577 .48912 .53327 .50362 .3297 .49676 .32178 Mtetra
.662 .743 .91 r
.49676 .32178 .50362 .3297 .51605 .32542 .50923 .31746 Mtetra
.50923 .31746 .51605 .32542 .52853 .32112 .52175 .31312 Mtetra
.52175 .31312 .52853 .32112 .54108 .31679 .53433 .30876 Mtetra
.53433 .30876 .54108 .31679 .55368 .31245 .54696 .30438 Mtetra
.54696 .30438 .55368 .31245 .56633 .30809 .55966 .29998 Mtetra
.55966 .29998 .56633 .30809 .57905 .30371 .57241 .29556 Mtetra
.57241 .29556 .57905 .30371 .59182 .29931 .58523 .29112 Mtetra
.58523 .29112 .59182 .29931 .60465 .29488 .5981 .28666 Mtetra
.5981 .28666 .60465 .29488 .61755 .29044 .61103 .28218 Mtetra
.61103 .28218 .61755 .29044 .6305 .28598 .62402 .27768 Mtetra
.62402 .27768 .6305 .28598 .64351 .28149 .63708 .27316 Mtetra
.92 .784 .694 r
.63708 .27316 .64351 .28149 .65567 .25546 .64932 .24706 Mtetra
.664 .741 .908 r
.64932 .24706 .65567 .25546 .66871 .25092 .6624 .24247 Mtetra
.6624 .24247 .66871 .25092 .68181 .24635 .67554 .23787 Mtetra
.67554 .23787 .68181 .24635 .69497 .24177 .68874 .23324 Mtetra
.68874 .23324 .69497 .24177 .70819 .23716 .70201 .22859 Mtetra
.70201 .22859 .70819 .23716 .72148 .23253 .71533 .22393 Mtetra
.71533 .22393 .72148 .23253 .73482 .22788 .72872 .21923 Mtetra
.72872 .21923 .73482 .22788 .74823 .2232 .74218 .21452 Mtetra
.74218 .21452 .74823 .2232 .7617 .21851 .75569 .20978 Mtetra
.75569 .20978 .7617 .21851 .77524 .21379 .76928 .20502 Mtetra
.76928 .20502 .77524 .21379 .78884 .20905 .78292 .20024 Mtetra
.78292 .20024 .78884 .20905 .80251 .20429 .79663 .19544 Mtetra
.79663 .19544 .80251 .20429 .81623 .19951 .81041 .19061 Mtetra
.659 .747 .915 r
.17922 .46301 .18708 .47005 .19833 .46624 .19049 .45917 Mtetra
.19049 .45917 .19833 .46624 .20963 .46242 .20182 .45531 Mtetra
.20182 .45531 .20963 .46242 .22097 .45857 .21319 .45144 Mtetra
.21319 .45144 .22097 .45857 .23237 .45472 .22462 .44755 Mtetra
.22462 .44755 .23237 .45472 .24382 .45084 .2361 .44364 Mtetra
.2361 .44364 .24382 .45084 .25531 .44695 .24762 .43972 Mtetra
.24762 .43972 .25531 .44695 .26686 .44304 .2592 .43578 Mtetra
.2592 .43578 .26686 .44304 .27846 .43911 .27083 .43182 Mtetra
.27083 .43182 .27846 .43911 .29011 .43517 .28251 .42784 Mtetra
.28251 .42784 .29011 .43517 .30181 .43121 .29424 .42385 Mtetra
.29424 .42385 .30181 .43121 .31356 .42723 .30603 .41983 Mtetra
.30603 .41983 .31356 .42723 .32537 .42323 .31787 .4158 Mtetra
.954 .662 .443 r
.31787 .4158 .32537 .42323 .3283 .57336 .32044 .56621 Mtetra
.646 .762 .934 r
.32044 .56621 .3283 .57336 .34076 .5695 .33293 .56232 Mtetra
.33293 .56232 .34076 .5695 .35328 .56562 .34549 .5584 Mtetra
.34549 .5584 .35328 .56562 .36586 .56172 .3581 .55447 Mtetra
.3581 .55447 .36586 .56172 .37849 .5578 .37077 .55052 Mtetra
.37077 .55052 .37849 .5578 .39119 .55386 .38351 .54654 Mtetra
.38351 .54654 .39119 .55386 .40395 .54991 .3963 .54255 Mtetra
.3963 .54255 .40395 .54991 .41677 .54593 .40916 .53854 Mtetra
.40916 .53854 .41677 .54593 .42964 .54194 .42207 .53452 Mtetra
.42207 .53452 .42964 .54194 .44258 .53793 .43505 .53047 Mtetra
.43505 .53047 .44258 .53793 .45559 .53389 .4481 .5264 Mtetra
.4481 .5264 .45559 .53389 .46865 .52984 .4612 .52231 Mtetra
.4612 .52231 .46865 .52984 .48178 .52577 .47437 .51821 Mtetra
.965 .707 .495 r
.47437 .51821 .48178 .52577 .49676 .32178 .48984 .31379 Mtetra
.662 .743 .91 r
.48984 .31379 .49676 .32178 .50923 .31746 .50234 .30943 Mtetra
.50234 .30943 .50923 .31746 .52175 .31312 .5149 .30506 Mtetra
.5149 .30506 .52175 .31312 .53433 .30876 .52752 .30066 Mtetra
.52752 .30066 .53433 .30876 .54696 .30438 .5402 .29625 Mtetra
.5402 .29625 .54696 .30438 .55966 .29998 .55293 .29181 Mtetra
.55293 .29181 .55966 .29998 .57241 .29556 .56572 .28735 Mtetra
.56572 .28735 .57241 .29556 .58523 .29112 .57857 .28287 Mtetra
.57857 .28287 .58523 .29112 .5981 .28666 .59149 .27838 Mtetra
.59149 .27838 .5981 .28666 .61103 .28218 .60446 .27386 Mtetra
.60446 .27386 .61103 .28218 .62402 .27768 .61749 .26932 Mtetra
.61749 .26932 .62402 .27768 .63708 .27316 .63059 .26475 Mtetra
.92 .784 .694 r
.63059 .26475 .63708 .27316 .64932 .24706 .64291 .23858 Mtetra
.664 .741 .908 r
.64291 .23858 .64932 .24706 .6624 .24247 .65603 .23396 Mtetra
.65603 .23396 .6624 .24247 .67554 .23787 .66921 .22931 Mtetra
.66921 .22931 .67554 .23787 .68874 .23324 .68246 .22464 Mtetra
.68246 .22464 .68874 .23324 .70201 .22859 .69577 .21996 Mtetra
.69577 .21996 .70201 .22859 .71533 .22393 .70914 .21525 Mtetra
.70914 .21525 .71533 .22393 .72872 .21923 .72257 .21051 Mtetra
.72257 .21051 .72872 .21923 .74218 .21452 .73607 .20576 Mtetra
.73607 .20576 .74218 .21452 .75569 .20978 .74963 .20098 Mtetra
.74963 .20098 .75569 .20978 .76928 .20502 .76326 .19618 Mtetra
.76326 .19618 .76928 .20502 .78292 .20024 .77695 .19136 Mtetra
.77695 .19136 .78292 .20024 .79663 .19544 .79071 .18651 Mtetra
.79071 .18651 .79663 .19544 .81041 .19061 .80453 .18164 Mtetra
.659 .747 .915 r
.17129 .4559 .17922 .46301 .19049 .45917 .18259 .45203 Mtetra
.18259 .45203 .19049 .45917 .20182 .45531 .19395 .44815 Mtetra
.19395 .44815 .20182 .45531 .21319 .45144 .20535 .44424 Mtetra
.20535 .44424 .21319 .45144 .22462 .44755 .21681 .44032 Mtetra
.21681 .44032 .22462 .44755 .2361 .44364 .22831 .43638 Mtetra
.22831 .43638 .2361 .44364 .24762 .43972 .23987 .43243 Mtetra
.23987 .43243 .24762 .43972 .2592 .43578 .25148 .42845 Mtetra
.25148 .42845 .2592 .43578 .27083 .43182 .26314 .42446 Mtetra
.26314 .42446 .27083 .43182 .28251 .42784 .27485 .42045 Mtetra
.27485 .42045 .28251 .42784 .29424 .42385 .28661 .41642 Mtetra
.28661 .41642 .29424 .42385 .30603 .41983 .29843 .41238 Mtetra
.29843 .41238 .30603 .41983 .31787 .4158 .3103 .40831 Mtetra
.954 .662 .443 r
.3103 .40831 .31787 .4158 .32044 .56621 .3125 .55901 Mtetra
.646 .762 .934 r
.3125 .55901 .32044 .56621 .33293 .56232 .32503 .55507 Mtetra
.32503 .55507 .33293 .56232 .34549 .5584 .33762 .55113 Mtetra
.33762 .55113 .34549 .5584 .3581 .55447 .35027 .54716 Mtetra
.35027 .54716 .3581 .55447 .37077 .55052 .36298 .54317 Mtetra
.36298 .54317 .37077 .55052 .38351 .54654 .37575 .53916 Mtetra
.37575 .53916 .38351 .54654 .3963 .54255 .38859 .53514 Mtetra
.38859 .53514 .3963 .54255 .40916 .53854 .40148 .53109 Mtetra
.40148 .53109 .40916 .53854 .42207 .53452 .41444 .52703 Mtetra
.41444 .52703 .42207 .53452 .43505 .53047 .42746 .52294 Mtetra
.42746 .52294 .43505 .53047 .4481 .5264 .44054 .51884 Mtetra
.44054 .51884 .4481 .5264 .4612 .52231 .45369 .51472 Mtetra
.45369 .51472 .4612 .52231 .47437 .51821 .46689 .51057 Mtetra
.965 .707 .495 r
.46689 .51057 .47437 .51821 .48984 .31379 .48286 .30573 Mtetra
.662 .743 .91 r
.48286 .30573 .48984 .31379 .50234 .30943 .4954 .30134 Mtetra
.4954 .30134 .50234 .30943 .5149 .30506 .508 .29693 Mtetra
.508 .29693 .5149 .30506 .52752 .30066 .52066 .29249 Mtetra
.52066 .29249 .52752 .30066 .5402 .29625 .53337 .28804 Mtetra
.53337 .28804 .5402 .29625 .55293 .29181 .54614 .28356 Mtetra
.54614 .28356 .55293 .29181 .56572 .28735 .55897 .27907 Mtetra
.55897 .27907 .56572 .28735 .57857 .28287 .57187 .27455 Mtetra
.57187 .27455 .57857 .28287 .59149 .27838 .58482 .27002 Mtetra
.58482 .27002 .59149 .27838 .60446 .27386 .59783 .26546 Mtetra
.59783 .26546 .60446 .27386 .61749 .26932 .6109 .26088 Mtetra
.6109 .26088 .61749 .26932 .63059 .26475 .62404 .25628 Mtetra
.92 .784 .694 r
.62404 .25628 .63059 .26475 .64291 .23858 .63645 .23003 Mtetra
.664 .741 .908 r
.63645 .23003 .64291 .23858 .65603 .23396 .64961 .22536 Mtetra
.64961 .22536 .65603 .23396 .66921 .22931 .66284 .22068 Mtetra
.66284 .22068 .66921 .22931 .68246 .22464 .67612 .21597 Mtetra
.67612 .21597 .68246 .22464 .69577 .21996 .68948 .21124 Mtetra
.68948 .21124 .69577 .21996 .70914 .21525 .70289 .20649 Mtetra
.70289 .20649 .70914 .21525 .72257 .21051 .71637 .20172 Mtetra
.71637 .20172 .72257 .21051 .73607 .20576 .72991 .19692 Mtetra
.72991 .19692 .73607 .20576 .74963 .20098 .74352 .1921 Mtetra
.74352 .1921 .74963 .20098 .76326 .19618 .75719 .18726 Mtetra
.75719 .18726 .76326 .19618 .77695 .19136 .77093 .18239 Mtetra
.77093 .18239 .77695 .19136 .79071 .18651 .78473 .1775 Mtetra
.78473 .1775 .79071 .18651 .80453 .18164 .7986 .17259 Mtetra
.659 .747 .915 r
.1633 .44875 .17129 .4559 .18259 .45203 .17463 .44485 Mtetra
.17463 .44485 .18259 .45203 .19395 .44815 .18601 .44093 Mtetra
.18601 .44093 .19395 .44815 .20535 .44424 .19745 .43699 Mtetra
.19745 .43699 .20535 .44424 .21681 .44032 .20893 .43304 Mtetra
.20893 .43304 .21681 .44032 .22831 .43638 .22046 .42907 Mtetra
.22046 .42907 .22831 .43638 .23987 .43243 .23205 .42508 Mtetra
.23205 .42508 .23987 .43243 .25148 .42845 .24369 .42107 Mtetra
.24369 .42107 .25148 .42845 .26314 .42446 .25538 .41705 Mtetra
.25538 .41705 .26314 .42446 .27485 .42045 .26712 .413 Mtetra
.26712 .413 .27485 .42045 .28661 .41642 .27892 .40894 Mtetra
.27892 .40894 .28661 .41642 .29843 .41238 .29077 .40486 Mtetra
.29077 .40486 .29843 .41238 .3103 .40831 .30267 .40076 Mtetra
.954 .662 .443 r
.30267 .40076 .3103 .40831 .3125 .55901 .3045 .55173 Mtetra
.646 .762 .934 r
.3045 .55173 .3125 .55901 .32503 .55507 .31706 .54777 Mtetra
.31706 .54777 .32503 .55507 .33762 .55113 .32969 .54378 Mtetra
.32969 .54378 .33762 .55113 .35027 .54716 .34238 .53978 Mtetra
.34238 .53978 .35027 .54716 .36298 .54317 .35512 .53576 Mtetra
.35512 .53576 .36298 .54317 .37575 .53916 .36793 .53172 Mtetra
.36793 .53172 .37575 .53916 .38859 .53514 .3808 .52765 Mtetra
.3808 .52765 .38859 .53514 .40148 .53109 .39374 .52357 Mtetra
.39374 .52357 .40148 .53109 .41444 .52703 .40673 .51947 Mtetra
.40673 .51947 .41444 .52703 .42746 .52294 .41979 .51535 Mtetra
.41979 .51535 .42746 .52294 .44054 .51884 .43291 .51121 Mtetra
.43291 .51121 .44054 .51884 .45369 .51472 .4461 .50705 Mtetra
.4461 .50705 .45369 .51472 .46689 .51057 .45935 .50287 Mtetra
.965 .707 .495 r
.45935 .50287 .46689 .51057 .48286 .30573 .47583 .29761 Mtetra
.662 .743 .91 r
.47583 .29761 .48286 .30573 .4954 .30134 .4884 .29318 Mtetra
.4884 .29318 .4954 .30134 .508 .29693 .50104 .28873 Mtetra
.50104 .28873 .508 .29693 .52066 .29249 .51373 .28425 Mtetra
.51373 .28425 .52066 .29249 .53337 .28804 .52648 .27976 Mtetra
.52648 .27976 .53337 .28804 .54614 .28356 .5393 .27525 Mtetra
.5393 .27525 .54614 .28356 .55897 .27907 .55217 .27072 Mtetra
.55217 .27072 .55897 .27907 .57187 .27455 .5651 .26616 Mtetra
.5651 .26616 .57187 .27455 .58482 .27002 .57809 .26158 Mtetra
.57809 .26158 .58482 .27002 .59783 .26546 .59114 .25698 Mtetra
.59114 .25698 .59783 .26546 .6109 .26088 .60426 .25237 Mtetra
.60426 .25237 .6109 .26088 .62404 .25628 .61744 .24772 Mtetra
.92 .784 .694 r
.61744 .24772 .62404 .25628 .63645 .23003 .62993 .2214 Mtetra
.664 .741 .908 r
.62993 .2214 .63645 .23003 .64961 .22536 .64313 .2167 Mtetra
.64313 .2167 .64961 .22536 .66284 .22068 .6564 .21197 Mtetra
.6564 .21197 .66284 .22068 .67612 .21597 .66973 .20722 Mtetra
.66973 .20722 .67612 .21597 .68948 .21124 .68313 .20245 Mtetra
.68313 .20245 .68948 .21124 .70289 .20649 .69659 .19766 Mtetra
.69659 .19766 .70289 .20649 .71637 .20172 .71011 .19284 Mtetra
.71011 .19284 .71637 .20172 .72991 .19692 .72369 .188 Mtetra
.72369 .188 .72991 .19692 .74352 .1921 .73735 .18314 Mtetra
.73735 .18314 .74352 .1921 .75719 .18726 .75106 .17826 Mtetra
.75106 .17826 .75719 .18726 .77093 .18239 .76485 .17335 Mtetra
.76485 .17335 .77093 .18239 .78473 .1775 .7787 .16841 Mtetra
.7787 .16841 .78473 .1775 .7986 .17259 .79262 .16346 Mtetra
.659 .747 .915 r
.15524 .44153 .1633 .44875 .17463 .44485 .1666 .4376 Mtetra
.1666 .4376 .17463 .44485 .18601 .44093 .17801 .43365 Mtetra
.17801 .43365 .18601 .44093 .19745 .43699 .18947 .42968 Mtetra
.18947 .42968 .19745 .43699 .20893 .43304 .20099 .42569 Mtetra
.20099 .42569 .20893 .43304 .22046 .42907 .21255 .42169 Mtetra
.21255 .42169 .22046 .42907 .23205 .42508 .22417 .41767 Mtetra
.22417 .41767 .23205 .42508 .24369 .42107 .23584 .41363 Mtetra
.23584 .41363 .24369 .42107 .25538 .41705 .24756 .40957 Mtetra
.24756 .40957 .25538 .41705 .26712 .413 .25933 .40549 Mtetra
.25933 .40549 .26712 .413 .27892 .40894 .27116 .4014 Mtetra
.27116 .4014 .27892 .40894 .29077 .40486 .28304 .39728 Mtetra
.28304 .39728 .29077 .40486 .30267 .40076 .29498 .39315 Mtetra
.954 .662 .443 r
.29498 .39315 .30267 .40076 .3045 .55173 .29642 .5444 Mtetra
.646 .762 .934 r
.29642 .5444 .3045 .55173 .31706 .54777 .30902 .5404 Mtetra
.30902 .5404 .31706 .54777 .32969 .54378 .32169 .53638 Mtetra
.32169 .53638 .32969 .54378 .34238 .53978 .33441 .53234 Mtetra
.33441 .53234 .34238 .53978 .35512 .53576 .3472 .52828 Mtetra
.3472 .52828 .35512 .53576 .36793 .53172 .36004 .5242 Mtetra
.36004 .5242 .36793 .53172 .3808 .52765 .37295 .5201 Mtetra
.37295 .5201 .3808 .52765 .39374 .52357 .38592 .51599 Mtetra
.38592 .51599 .39374 .52357 .40673 .51947 .39896 .51185 Mtetra
.39896 .51185 .40673 .51947 .41979 .51535 .41206 .50769 Mtetra
.41206 .50769 .41979 .51535 .43291 .51121 .42522 .50351 Mtetra
.42522 .50351 .43291 .51121 .4461 .50705 .43845 .49931 Mtetra
.43845 .49931 .4461 .50705 .45935 .50287 .45174 .49509 Mtetra
.965 .707 .495 r
.45174 .49509 .45935 .50287 .47583 .29761 .46873 .28941 Mtetra
.662 .743 .91 r
.46873 .28941 .47583 .29761 .4884 .29318 .48135 .28494 Mtetra
.48135 .28494 .4884 .29318 .50104 .28873 .49402 .28045 Mtetra
.49402 .28045 .50104 .28873 .51373 .28425 .50675 .27594 Mtetra
.50675 .27594 .51373 .28425 .52648 .27976 .51954 .27141 Mtetra
.51954 .27141 .52648 .27976 .5393 .27525 .53239 .26686 Mtetra
.53239 .26686 .5393 .27525 .55217 .27072 .5453 .26229 Mtetra
.5453 .26229 .55217 .27072 .5651 .26616 .55827 .25769 Mtetra
.55827 .25769 .5651 .26616 .57809 .26158 .57131 .25308 Mtetra
.57131 .25308 .57809 .26158 .59114 .25698 .5844 .24844 Mtetra
.5844 .24844 .59114 .25698 .60426 .25237 .59756 .24378 Mtetra
.59756 .24378 .60426 .25237 .61744 .24772 .61077 .2391 Mtetra
.92 .784 .694 r
.61077 .2391 .61744 .24772 .62993 .2214 .62335 .2127 Mtetra
.664 .741 .908 r
.62335 .2127 .62993 .2214 .64313 .2167 .6366 .20796 Mtetra
.6366 .20796 .64313 .2167 .6564 .21197 .64991 .20319 Mtetra
.64991 .20319 .6564 .21197 .66973 .20722 .66328 .1984 Mtetra
.66328 .1984 .66973 .20722 .68313 .20245 .67672 .19359 Mtetra
.67672 .19359 .68313 .20245 .69659 .19766 .69023 .18875 Mtetra
.69023 .18875 .69659 .19766 .71011 .19284 .70379 .18389 Mtetra
.70379 .18389 .71011 .19284 .72369 .188 .71742 .17901 Mtetra
.71742 .17901 .72369 .188 .73735 .18314 .73112 .1741 Mtetra
.73112 .1741 .73735 .18314 .75106 .17826 .74489 .16917 Mtetra
.74489 .16917 .75106 .17826 .76485 .17335 .75872 .16422 Mtetra
.75872 .16422 .76485 .17335 .7787 .16841 .77261 .15924 Mtetra
.77261 .15924 .7787 .16841 .79262 .16346 .78658 .15424 Mtetra
.659 .747 .915 r
.14712 .43426 .15524 .44153 .1666 .4376 .1585 .43029 Mtetra
.1585 .43029 .1666 .4376 .17801 .43365 .16995 .42631 Mtetra
.16995 .42631 .17801 .43365 .18947 .42968 .18144 .4223 Mtetra
.18144 .4223 .18947 .42968 .20099 .42569 .19298 .41829 Mtetra
.19298 .41829 .20099 .42569 .21255 .42169 .20457 .41425 Mtetra
.20457 .41425 .21255 .42169 .22417 .41767 .21622 .41019 Mtetra
.21622 .41019 .22417 .41767 .23584 .41363 .22792 .40612 Mtetra
.22792 .40612 .23584 .41363 .24756 .40957 .23967 .40203 Mtetra
.23967 .40203 .24756 .40957 .25933 .40549 .25148 .39792 Mtetra
.25148 .39792 .25933 .40549 .27116 .4014 .26334 .39379 Mtetra
.26334 .39379 .27116 .4014 .28304 .39728 .27525 .38964 Mtetra
.27525 .38964 .28304 .39728 .29498 .39315 .28722 .38547 Mtetra
.954 .662 .443 r
.28722 .38547 .29498 .39315 .29642 .5444 .28827 .537 Mtetra
.646 .762 .934 r
.28827 .537 .29642 .5444 .30902 .5404 .30091 .53296 Mtetra
.30091 .53296 .30902 .5404 .32169 .53638 .31361 .52891 Mtetra
.31361 .52891 .32169 .53638 .33441 .53234 .32637 .52483 Mtetra
.32637 .52483 .33441 .53234 .3472 .52828 .3392 .52074 Mtetra
.3392 .52074 .3472 .52828 .36004 .5242 .35208 .51662 Mtetra
.35208 .51662 .36004 .5242 .37295 .5201 .36503 .51249 Mtetra
.36503 .51249 .37295 .5201 .38592 .51599 .37804 .50833 Mtetra
.37804 .50833 .38592 .51599 .39896 .51185 .39112 .50416 Mtetra
.39112 .50416 .39896 .51185 .41206 .50769 .40425 .49996 Mtetra
.40425 .49996 .41206 .50769 .42522 .50351 .41746 .49575 Mtetra
.41746 .49575 .42522 .50351 .43845 .49931 .43072 .49151 Mtetra
.43072 .49151 .43845 .49931 .45174 .49509 .44406 .48725 Mtetra
.965 .707 .495 r
.44406 .48725 .45174 .49509 .46873 .28941 .46157 .28115 Mtetra
.662 .743 .91 r
.46157 .28115 .46873 .28941 .48135 .28494 .47423 .27664 Mtetra
.47423 .27664 .48135 .28494 .49402 .28045 .48694 .27211 Mtetra
.48694 .27211 .49402 .28045 .50675 .27594 .49971 .26756 Mtetra
.49971 .26756 .50675 .27594 .51954 .27141 .51254 .26299 Mtetra
.51254 .26299 .51954 .27141 .53239 .26686 .52543 .2584 Mtetra
.52543 .2584 .53239 .26686 .5453 .26229 .53838 .25379 Mtetra
.53838 .25379 .5453 .26229 .55827 .25769 .55139 .24915 Mtetra
.55139 .24915 .55827 .25769 .57131 .25308 .56446 .2445 Mtetra
.56446 .2445 .57131 .25308 .5844 .24844 .5776 .23982 Mtetra
.5776 .23982 .5844 .24844 .59756 .24378 .59079 .23512 Mtetra
.59079 .23512 .59756 .24378 .61077 .2391 .60405 .23039 Mtetra
.92 .784 .694 r
.60405 .23039 .61077 .2391 .62335 .2127 .61672 .20392 Mtetra
.664 .741 .908 r
.61672 .20392 .62335 .2127 .6366 .20796 .63001 .19914 Mtetra
.63001 .19914 .6366 .20796 .64991 .20319 .64336 .19433 Mtetra
.64336 .19433 .64991 .20319 .66328 .1984 .65678 .1895 Mtetra
.65678 .1895 .66328 .1984 .67672 .19359 .67026 .18464 Mtetra
.67026 .18464 .67672 .19359 .69023 .18875 .68381 .17976 Mtetra
.68381 .17976 .69023 .18875 .70379 .18389 .69742 .17486 Mtetra
.69742 .17486 .70379 .18389 .71742 .17901 .7111 .16993 Mtetra
.7111 .16993 .71742 .17901 .73112 .1741 .72484 .16498 Mtetra
.72484 .16498 .73112 .1741 .74489 .16917 .73865 .16001 Mtetra
.73865 .16001 .74489 .16917 .75872 .16422 .75253 .15501 Mtetra
.75253 .15501 .75872 .16422 .77261 .15924 .76647 .14999 Mtetra
.76647 .14999 .77261 .15924 .78658 .15424 .78049 .14494 Mtetra
.659 .747 .915 r
.13892 .42692 .14712 .43426 .1585 .43029 .15034 .42292 Mtetra
.15034 .42292 .1585 .43029 .16995 .42631 .16181 .4189 Mtetra
.16181 .4189 .16995 .42631 .18144 .4223 .17333 .41487 Mtetra
.17333 .41487 .18144 .4223 .19298 .41829 .18491 .41082 Mtetra
.18491 .41082 .19298 .41829 .20457 .41425 .19653 .40675 Mtetra
.19653 .40675 .20457 .41425 .21622 .41019 .20821 .40266 Mtetra
.20821 .40266 .21622 .41019 .22792 .40612 .21994 .39855 Mtetra
.21994 .39855 .22792 .40612 .23967 .40203 .23172 .39442 Mtetra
.23172 .39442 .23967 .40203 .25148 .39792 .24356 .39028 Mtetra
.24356 .39028 .25148 .39792 .26334 .39379 .25545 .38611 Mtetra
.25545 .38611 .26334 .39379 .27525 .38964 .26739 .38193 Mtetra
.26739 .38193 .27525 .38964 .28722 .38547 .27939 .37773 Mtetra
.954 .662 .443 r
.27939 .37773 .28722 .38547 .28827 .537 .28005 .52953 Mtetra
.646 .762 .934 r
.28005 .52953 .28827 .537 .30091 .53296 .29273 .52546 Mtetra
.29273 .52546 .30091 .53296 .31361 .52891 .30547 .52137 Mtetra
.30547 .52137 .31361 .52891 .32637 .52483 .31827 .51726 Mtetra
.31827 .51726 .32637 .52483 .3392 .52074 .33113 .51312 Mtetra
.33113 .51312 .3392 .52074 .35208 .51662 .34405 .50897 Mtetra
.34405 .50897 .35208 .51662 .36503 .51249 .35704 .5048 Mtetra
.35704 .5048 .36503 .51249 .37804 .50833 .37009 .50061 Mtetra
.37009 .50061 .37804 .50833 .39112 .50416 .3832 .4964 Mtetra
.3832 .4964 .39112 .50416 .40425 .49996 .39638 .49216 Mtetra
.39638 .49216 .40425 .49996 .41746 .49575 .40962 .48791 Mtetra
.40962 .48791 .41746 .49575 .43072 .49151 .42293 .48363 Mtetra
.42293 .48363 .43072 .49151 .44406 .48725 .43631 .47933 Mtetra
.965 .707 .495 r
.43631 .47933 .44406 .48725 .46157 .28115 .45436 .27281 Mtetra
.662 .743 .91 r
.45436 .27281 .46157 .28115 .47423 .27664 .46704 .26826 Mtetra
.46704 .26826 .47423 .27664 .48694 .27211 .47979 .2637 Mtetra
.47979 .2637 .48694 .27211 .49971 .26756 .4926 .25911 Mtetra
.4926 .25911 .49971 .26756 .51254 .26299 .50547 .2545 Mtetra
.50547 .2545 .51254 .26299 .52543 .2584 .5184 .24987 Mtetra
.5184 .24987 .52543 .2584 .53838 .25379 .53139 .24521 Mtetra
.53139 .24521 .53838 .25379 .55139 .24915 .54444 .24054 Mtetra
.54444 .24054 .55139 .24915 .56446 .2445 .55756 .23584 Mtetra
.55756 .23584 .56446 .2445 .5776 .23982 .57073 .23112 Mtetra
.57073 .23112 .5776 .23982 .59079 .23512 .58397 .22638 Mtetra
.58397 .22638 .59079 .23512 .60405 .23039 .59727 .22161 Mtetra
.92 .784 .694 r
.59727 .22161 .60405 .23039 .61672 .20392 .61003 .19507 Mtetra
.664 .741 .908 r
.61003 .19507 .61672 .20392 .63001 .19914 .62336 .19024 Mtetra
.62336 .19024 .63001 .19914 .64336 .19433 .63676 .18539 Mtetra
.63676 .18539 .64336 .19433 .65678 .1895 .65022 .18051 Mtetra
.65022 .18051 .65678 .1895 .67026 .18464 .66374 .17561 Mtetra
.66374 .17561 .67026 .18464 .68381 .17976 .67734 .17069 Mtetra
.67734 .17069 .68381 .17976 .69742 .17486 .69099 .16575 Mtetra
.69099 .16575 .69742 .17486 .7111 .16993 .70472 .16078 Mtetra
.70472 .16078 .7111 .16993 .72484 .16498 .7185 .15578 Mtetra
.7185 .15578 .72484 .16498 .73865 .16001 .73236 .15076 Mtetra
.73236 .15076 .73865 .16001 .75253 .15501 .74629 .14572 Mtetra
.74629 .14572 .75253 .15501 .76647 .14999 .76028 .14065 Mtetra
.76028 .14065 .76647 .14999 .78049 .14494 .77434 .13556 Mtetra
.501 .248 .462 r
.11481 .5499 .13892 .42692 .15034 .42292 .12668 .54601 Mtetra
.12668 .54601 .15034 .42292 .16181 .4189 .13861 .54211 Mtetra
.13861 .54211 .16181 .4189 .17333 .41487 .15059 .53818 Mtetra
.15059 .53818 .17333 .41487 .18491 .41082 .16263 .53423 Mtetra
.16263 .53423 .18491 .41082 .19653 .40675 .17473 .53027 Mtetra
.17473 .53027 .19653 .40675 .20821 .40266 .18688 .52629 Mtetra
.18688 .52629 .20821 .40266 .21994 .39855 .19909 .52229 Mtetra
.19909 .52229 .21994 .39855 .23172 .39442 .21136 .51827 Mtetra
.21136 .51827 .23172 .39442 .24356 .39028 .22369 .51423 Mtetra
.22369 .51423 .24356 .39028 .25545 .38611 .23607 .51017 Mtetra
.23607 .51017 .25545 .38611 .26739 .38193 .24852 .50609 Mtetra
.24852 .50609 .26739 .38193 .27939 .37773 .26102 .50199 Mtetra
0 0 0 r
.26102 .50199 .27939 .37773 .28005 .52953 .28443 .35466 Mtetra
.538 .327 .542 r
.28443 .35466 .28005 .52953 .29273 .52546 .29653 .35037 Mtetra
.29653 .35037 .29273 .52546 .30547 .52137 .30869 .34607 Mtetra
.30869 .34607 .30547 .52137 .31827 .51726 .3209 .34174 Mtetra
.3209 .34174 .31827 .51726 .33113 .51312 .33318 .33739 Mtetra
.33318 .33739 .33113 .51312 .34405 .50897 .34551 .33302 Mtetra
.34551 .33302 .34405 .50897 .35704 .5048 .35789 .32864 Mtetra
.35789 .32864 .35704 .5048 .37009 .50061 .37034 .32423 Mtetra
.37034 .32423 .37009 .50061 .3832 .4964 .38284 .3198 Mtetra
.38284 .3198 .3832 .4964 .39638 .49216 .3954 .31535 Mtetra
.3954 .31535 .39638 .49216 .40962 .48791 .40802 .31088 Mtetra
.40802 .31088 .40962 .48791 .42293 .48363 .4207 .30639 Mtetra
.4207 .30639 .42293 .48363 .43631 .47933 .43344 .30187 Mtetra
.648 .413 .55 r
.43344 .30187 .43631 .47933 .45436 .27281 .44762 .24283 Mtetra
.597 .469 .676 r
.44762 .24283 .45436 .27281 .46704 .26826 .46026 .23822 Mtetra
.46026 .23822 .46704 .26826 .47979 .2637 .47296 .2336 Mtetra
.47296 .2336 .47979 .2637 .4926 .25911 .48571 .22895 Mtetra
.48571 .22895 .4926 .25911 .50547 .2545 .49853 .22429 Mtetra
.49853 .22429 .50547 .2545 .5184 .24987 .51141 .2196 Mtetra
.51141 .2196 .5184 .24987 .53139 .24521 .52435 .21488 Mtetra
.52435 .21488 .53139 .24521 .54444 .24054 .53735 .21015 Mtetra
.53735 .21015 .54444 .24054 .55756 .23584 .55041 .20539 Mtetra
.55041 .20539 .55756 .23584 .57073 .23112 .56353 .20061 Mtetra
.56353 .20061 .57073 .23112 .58397 .22638 .57672 .19581 Mtetra
.57672 .19581 .58397 .22638 .59727 .22161 .58996 .19098 Mtetra
.58996 .19098 .59727 .22161 .61003 .19507 .60328 .18614 Mtetra
.664 .741 .908 r
.60328 .18614 .61003 .19507 .62336 .19024 .61665 .18126 Mtetra
.61665 .18126 .62336 .19024 .63676 .18539 .63009 .17637 Mtetra
.63009 .17637 .63676 .18539 .65022 .18051 .6436 .17145 Mtetra
.6436 .17145 .65022 .18051 .66374 .17561 .65717 .16651 Mtetra
.65717 .16651 .66374 .17561 .67734 .17069 .6708 .16154 Mtetra
.6708 .16154 .67734 .17069 .69099 .16575 .68451 .15655 Mtetra
.68451 .15655 .69099 .16575 .70472 .16078 .69828 .15154 Mtetra
.69828 .15154 .70472 .16078 .7185 .15578 .71211 .1465 Mtetra
.71211 .1465 .7185 .15578 .73236 .15076 .72601 .14144 Mtetra
.72601 .14144 .73236 .15076 .74629 .14572 .73999 .13635 Mtetra
.73999 .13635 .74629 .14572 .76028 .14065 .75403 .13123 Mtetra
.75403 .13123 .76028 .14065 .77434 .13556 .76814 .12609 Mtetra
.648 .76 .931 r
.10608 .54271 .11481 .5499 .12668 .54601 .11798 .53878 Mtetra
.11798 .53878 .12668 .54601 .13861 .54211 .12994 .53484 Mtetra
.12994 .53484 .13861 .54211 .15059 .53818 .14196 .53088 Mtetra
.14196 .53088 .15059 .53818 .16263 .53423 .15403 .5269 Mtetra
.15403 .5269 .16263 .53423 .17473 .53027 .16616 .5229 Mtetra
.16616 .5229 .17473 .53027 .18688 .52629 .17834 .51889 Mtetra
.17834 .51889 .18688 .52629 .19909 .52229 .19059 .51485 Mtetra
.19059 .51485 .19909 .52229 .21136 .51827 .20289 .51079 Mtetra
.20289 .51079 .21136 .51827 .22369 .51423 .21525 .50672 Mtetra
.21525 .50672 .22369 .51423 .23607 .51017 .22767 .50263 Mtetra
.22767 .50263 .23607 .51017 .24852 .50609 .24015 .49851 Mtetra
.24015 .49851 .24852 .50609 .26102 .50199 .25269 .49438 Mtetra
.946 .708 .546 r
.25269 .49438 .26102 .50199 .28443 .35466 .27653 .34673 Mtetra
.66 .746 .914 r
.27653 .34673 .28443 .35466 .29653 .35037 .28867 .34241 Mtetra
.28867 .34241 .29653 .35037 .30869 .34607 .30086 .33806 Mtetra
.30086 .33806 .30869 .34607 .3209 .34174 .31311 .3337 Mtetra
.31311 .3337 .3209 .34174 .33318 .33739 .32542 .32931 Mtetra
.32542 .32931 .33318 .33739 .34551 .33302 .33778 .32491 Mtetra
.33778 .32491 .34551 .33302 .35789 .32864 .35021 .32048 Mtetra
.35021 .32048 .35789 .32864 .37034 .32423 .36269 .31604 Mtetra
.36269 .31604 .37034 .32423 .38284 .3198 .37523 .31157 Mtetra
.37523 .31157 .38284 .3198 .3954 .31535 .38783 .30708 Mtetra
.38783 .30708 .3954 .31535 .40802 .31088 .40048 .30257 Mtetra
.40048 .30257 .40802 .31088 .4207 .30639 .4132 .29804 Mtetra
.4132 .29804 .4207 .30639 .43344 .30187 .42598 .29349 Mtetra
.949 .74 .587 r
.42598 .29349 .43344 .30187 .44762 .24283 .44033 .23431 Mtetra
.664 .741 .908 r
.44033 .23431 .44762 .24283 .46026 .23822 .453 .22967 Mtetra
.453 .22967 .46026 .23822 .47296 .2336 .46574 .225 Mtetra
.46574 .225 .47296 .2336 .48571 .22895 .47854 .22032 Mtetra
.47854 .22032 .48571 .22895 .49853 .22429 .49139 .21561 Mtetra
.49139 .21561 .49853 .22429 .51141 .2196 .50431 .21088 Mtetra
.50431 .21088 .51141 .2196 .52435 .21488 .51729 .20612 Mtetra
.51729 .20612 .52435 .21488 .53735 .21015 .53033 .20135 Mtetra
.53033 .20135 .53735 .21015 .55041 .20539 .54343 .19655 Mtetra
.54343 .19655 .55041 .20539 .56353 .20061 .55659 .19173 Mtetra
.55659 .19173 .56353 .20061 .57672 .19581 .56982 .18688 Mtetra
.56982 .18688 .57672 .19581 .58996 .19098 .58311 .18202 Mtetra
.58311 .18202 .58996 .19098 .60328 .18614 .59647 .17712 Mtetra
.59647 .17712 .60328 .18614 .61665 .18126 .60989 .17221 Mtetra
.60989 .17221 .61665 .18126 .63009 .17637 .62337 .16727 Mtetra
.62337 .16727 .63009 .17637 .6436 .17145 .63692 .16231 Mtetra
.63692 .16231 .6436 .17145 .65717 .16651 .65053 .15732 Mtetra
.65053 .15732 .65717 .16651 .6708 .16154 .66421 .15231 Mtetra
.66421 .15231 .6708 .16154 .68451 .15655 .67796 .14728 Mtetra
.67796 .14728 .68451 .15655 .69828 .15154 .69178 .14222 Mtetra
.69178 .14222 .69828 .15154 .71211 .1465 .70566 .13713 Mtetra
.70566 .13713 .71211 .1465 .72601 .14144 .71961 .13202 Mtetra
.71961 .13202 .72601 .14144 .73999 .13635 .73363 .12689 Mtetra
.73363 .12689 .73999 .13635 .75403 .13123 .74772 .12173 Mtetra
.74772 .12173 .75403 .13123 .76814 .12609 .76188 .11654 Mtetra
.648 .76 .931 r
.09727 .53545 .10608 .54271 .11798 .53878 .10921 .53149 Mtetra
.10921 .53149 .11798 .53878 .12994 .53484 .1212 .52752 Mtetra
.1212 .52752 .12994 .53484 .14196 .53088 .13324 .52352 Mtetra
.13324 .52352 .14196 .53088 .15403 .5269 .14535 .51951 Mtetra
.14535 .51951 .15403 .5269 .16616 .5229 .15751 .51547 Mtetra
.15751 .51547 .16616 .5229 .17834 .51889 .16973 .51142 Mtetra
.16973 .51142 .17834 .51889 .19059 .51485 .182 .50735 Mtetra
.182 .50735 .19059 .51485 .20289 .51079 .19434 .50326 Mtetra
.19434 .50326 .20289 .51079 .21525 .50672 .20673 .49915 Mtetra
.20673 .49915 .21525 .50672 .22767 .50263 .21919 .49502 Mtetra
.21919 .49502 .22767 .50263 .24015 .49851 .2317 .49086 Mtetra
.2317 .49086 .24015 .49851 .25269 .49438 .24428 .48669 Mtetra
.946 .708 .546 r
.24428 .48669 .25269 .49438 .27653 .34673 .26857 .33873 Mtetra
.66 .746 .914 r
.26857 .33873 .27653 .34673 .28867 .34241 .28074 .33437 Mtetra
.28074 .33437 .28867 .34241 .30086 .33806 .29297 .32999 Mtetra
.29297 .32999 .30086 .33806 .31311 .3337 .30525 .32559 Mtetra
.30525 .32559 .31311 .3337 .32542 .32931 .3176 .32116 Mtetra
.3176 .32116 .32542 .32931 .33778 .32491 .33 .31672 Mtetra
.33 .31672 .33778 .32491 .35021 .32048 .34245 .31226 Mtetra
.34245 .31226 .35021 .32048 .36269 .31604 .35497 .30777 Mtetra
.35497 .30777 .36269 .31604 .37523 .31157 .36755 .30327 Mtetra
.36755 .30327 .37523 .31157 .38783 .30708 .38018 .29874 Mtetra
.38018 .29874 .38783 .30708 .40048 .30257 .39288 .29419 Mtetra
.39288 .29419 .40048 .30257 .4132 .29804 .40563 .28962 Mtetra
.40563 .28962 .4132 .29804 .42598 .29349 .41845 .28502 Mtetra
.949 .74 .587 r
.41845 .28502 .42598 .29349 .44033 .23431 .43297 .22572 Mtetra
.664 .741 .908 r
.43297 .22572 .44033 .23431 .453 .22967 .44569 .22104 Mtetra
.44569 .22104 .453 .22967 .46574 .225 .45846 .21634 Mtetra
.45846 .21634 .46574 .225 .47854 .22032 .4713 .21161 Mtetra
.4713 .21161 .47854 .22032 .49139 .21561 .48419 .20686 Mtetra
.48419 .20686 .49139 .21561 .50431 .21088 .49715 .20209 Mtetra
.49715 .20209 .50431 .21088 .51729 .20612 .51017 .19729 Mtetra
.51017 .19729 .51729 .20612 .53033 .20135 .52325 .19247 Mtetra
.52325 .19247 .53033 .20135 .54343 .19655 .53639 .18763 Mtetra
.53639 .18763 .54343 .19655 .55659 .19173 .5496 .18277 Mtetra
.5496 .18277 .55659 .19173 .56982 .18688 .56287 .17788 Mtetra
.56287 .17788 .56982 .18688 .58311 .18202 .5762 .17297 Mtetra
.5762 .17297 .58311 .18202 .59647 .17712 .5896 .16803 Mtetra
.5896 .16803 .59647 .17712 .60989 .17221 .60306 .16307 Mtetra
.60306 .16307 .60989 .17221 .62337 .16727 .61659 .15809 Mtetra
.61659 .15809 .62337 .16727 .63692 .16231 .63018 .15308 Mtetra
.63018 .15308 .63692 .16231 .65053 .15732 .64384 .14805 Mtetra
.64384 .14805 .65053 .15732 .66421 .15231 .65757 .143 Mtetra
.65757 .143 .66421 .15231 .67796 .14728 .67136 .13792 Mtetra
.67136 .13792 .67796 .14728 .69178 .14222 .68522 .13281 Mtetra
.68522 .13281 .69178 .14222 .70566 .13713 .69915 .12768 Mtetra
.69915 .12768 .70566 .13713 .71961 .13202 .71315 .12252 Mtetra
.71315 .12252 .71961 .13202 .73363 .12689 .72722 .11734 Mtetra
.72722 .11734 .73363 .12689 .74772 .12173 .74135 .11213 Mtetra
.74135 .11213 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.648 .76 .931 r
.08839 .52813 .09727 .53545 .10921 .53149 .10035 .52414 Mtetra
.10035 .52414 .10921 .53149 .1212 .52752 .11238 .52012 Mtetra
.11238 .52012 .1212 .52752 .13324 .52352 .12445 .51609 Mtetra
.12445 .51609 .13324 .52352 .14535 .51951 .13659 .51204 Mtetra
.13659 .51204 .14535 .51951 .15751 .51547 .14878 .50798 Mtetra
.14878 .50798 .15751 .51547 .16973 .51142 .16104 .50389 Mtetra
.16104 .50389 .16973 .51142 .182 .50735 .17335 .49978 Mtetra
.17335 .49978 .182 .50735 .19434 .50326 .18572 .49565 Mtetra
.18572 .49565 .19434 .50326 .20673 .49915 .19815 .4915 Mtetra
.19815 .4915 .20673 .49915 .21919 .49502 .21063 .48734 Mtetra
.21063 .48734 .21919 .49502 .2317 .49086 .22318 .48315 Mtetra
.22318 .48315 .2317 .49086 .24428 .48669 .2358 .47894 Mtetra
.946 .708 .546 r
.2358 .47894 .24428 .48669 .26857 .33873 .26054 .33066 Mtetra
.66 .746 .914 r
.26054 .33066 .26857 .33873 .28074 .33437 .27275 .32627 Mtetra
.27275 .32627 .28074 .33437 .29297 .32999 .28501 .32185 Mtetra
.28501 .32185 .29297 .32999 .30525 .32559 .29733 .31741 Mtetra
.29733 .31741 .30525 .32559 .3176 .32116 .3097 .31295 Mtetra
.3097 .31295 .3176 .32116 .33 .31672 .32214 .30846 Mtetra
.32214 .30846 .33 .31672 .34245 .31226 .33463 .30396 Mtetra
.33463 .30396 .34245 .31226 .35497 .30777 .34719 .29944 Mtetra
.34719 .29944 .35497 .30777 .36755 .30327 .3598 .29489 Mtetra
.3598 .29489 .36755 .30327 .38018 .29874 .37247 .29032 Mtetra
.37247 .29032 .38018 .29874 .39288 .29419 .3852 .28573 Mtetra
.3852 .28573 .39288 .29419 .40563 .28962 .398 .28112 Mtetra
.398 .28112 .40563 .28962 .41845 .28502 .41085 .27649 Mtetra
.949 .74 .587 r
.41085 .27649 .41845 .28502 .43297 .22572 .42556 .21706 Mtetra
.664 .741 .908 r
.42556 .21706 .43297 .22572 .44569 .22104 .43831 .21234 Mtetra
.43831 .21234 .44569 .22104 .45846 .21634 .45112 .20759 Mtetra
.45112 .20759 .45846 .21634 .4713 .21161 .46399 .20282 Mtetra
.46399 .20282 .4713 .21161 .48419 .20686 .47693 .19803 Mtetra
.47693 .19803 .48419 .20686 .49715 .20209 .48993 .19321 Mtetra
.48993 .19321 .49715 .20209 .51017 .19729 .50298 .18838 Mtetra
.50298 .18838 .51017 .19729 .52325 .19247 .5161 .18352 Mtetra
.5161 .18352 .52325 .19247 .53639 .18763 .52929 .17863 Mtetra
.52929 .17863 .53639 .18763 .5496 .18277 .54254 .17372 Mtetra
.54254 .17372 .5496 .18277 .56287 .17788 .55585 .16879 Mtetra
.55585 .16879 .56287 .17788 .5762 .17297 .56922 .16384 Mtetra
.56922 .16384 .5762 .17297 .5896 .16803 .58266 .15886 Mtetra
.58266 .15886 .5896 .16803 .60306 .16307 .59617 .15386 Mtetra
.59617 .15386 .60306 .16307 .61659 .15809 .60974 .14883 Mtetra
.60974 .14883 .61659 .15809 .63018 .15308 .62338 .14378 Mtetra
.62338 .14378 .63018 .15308 .64384 .14805 .63708 .1387 Mtetra
.63708 .1387 .64384 .14805 .65757 .143 .65086 .1336 Mtetra
.65086 .1336 .65757 .143 .67136 .13792 .6647 .12847 Mtetra
.6647 .12847 .67136 .13792 .68522 .13281 .6786 .12332 Mtetra
.6786 .12332 .68522 .13281 .69915 .12768 .69258 .11814 Mtetra
.69258 .11814 .69915 .12768 .71315 .12252 .70663 .11294 Mtetra
.70663 .11294 .71315 .12252 .72722 .11734 .72074 .10771 Mtetra
.72074 .10771 .72722 .11734 .74135 .11213 .73493 .10245 Mtetra
.73493 .10245 .74135 .11213 .75556 .1069 .74918 .09717 Mtetra
.648 .76 .931 r
.07943 .52074 .08839 .52813 .10035 .52414 .09142 .51672 Mtetra
.09142 .51672 .10035 .52414 .11238 .52012 .10348 .51267 Mtetra
.10348 .51267 .11238 .52012 .12445 .51609 .11559 .5086 Mtetra
.11559 .5086 .12445 .51609 .13659 .51204 .12776 .50452 Mtetra
.12776 .50452 .13659 .51204 .14878 .50798 .13998 .50041 Mtetra
.13998 .50041 .14878 .50798 .16104 .50389 .15227 .49629 Mtetra
.15227 .49629 .16104 .50389 .17335 .49978 .16461 .49214 Mtetra
.16461 .49214 .17335 .49978 .18572 .49565 .17701 .48798 Mtetra
.17701 .48798 .18572 .49565 .19815 .4915 .18948 .48379 Mtetra
.18948 .48379 .19815 .4915 .21063 .48734 .202 .47959 Mtetra
.202 .47959 .21063 .48734 .22318 .48315 .21459 .47536 Mtetra
.21459 .47536 .22318 .48315 .2358 .47894 .22723 .47112 Mtetra
.946 .708 .546 r
.22723 .47112 .2358 .47894 .26054 .33066 .25245 .32253 Mtetra
.66 .746 .914 r
.25245 .32253 .26054 .33066 .27275 .32627 .26468 .31809 Mtetra
.26468 .31809 .27275 .32627 .28501 .32185 .27698 .31363 Mtetra
.27698 .31363 .28501 .32185 .29733 .31741 .28933 .30915 Mtetra
.28933 .30915 .29733 .31741 .3097 .31295 .30174 .30465 Mtetra
.30174 .30465 .3097 .31295 .32214 .30846 .31421 .30013 Mtetra
.31421 .30013 .32214 .30846 .33463 .30396 .32674 .29559 Mtetra
.32674 .29559 .33463 .30396 .34719 .29944 .33933 .29103 Mtetra
.33933 .29103 .34719 .29944 .3598 .29489 .35198 .28644 Mtetra
.35198 .28644 .3598 .29489 .37247 .29032 .36469 .28183 Mtetra
.36469 .28183 .37247 .29032 .3852 .28573 .37746 .2772 Mtetra
.37746 .2772 .3852 .28573 .398 .28112 .39029 .27255 Mtetra
.39029 .27255 .398 .28112 .41085 .27649 .40319 .26788 Mtetra
.949 .74 .587 r
.40319 .26788 .41085 .27649 .42556 .21706 .41807 .20832 Mtetra
.664 .741 .908 r
.41807 .20832 .42556 .21706 .43831 .21234 .43086 .20356 Mtetra
.43086 .20356 .43831 .21234 .45112 .20759 .44372 .19877 Mtetra
.44372 .19877 .45112 .20759 .46399 .20282 .45663 .19396 Mtetra
.45663 .19396 .46399 .20282 .47693 .19803 .4696 .18912 Mtetra
.4696 .18912 .47693 .19803 .48993 .19321 .48264 .18427 Mtetra
.48264 .18427 .48993 .19321 .50298 .18838 .49574 .17939 Mtetra
.49574 .17939 .50298 .18838 .5161 .18352 .5089 .17448 Mtetra
.5089 .17448 .5161 .18352 .52929 .17863 .52212 .16955 Mtetra
.52212 .16955 .52929 .17863 .54254 .17372 .53541 .1646 Mtetra
.53541 .1646 .54254 .17372 .55585 .16879 .54877 .15963 Mtetra
.54877 .15963 .55585 .16879 .56922 .16384 .56218 .15463 Mtetra
.56218 .15463 .56922 .16384 .58266 .15886 .57567 .1496 Mtetra
.57567 .1496 .58266 .15886 .59617 .15386 .58922 .14455 Mtetra
.58922 .14455 .59617 .15386 .60974 .14883 .60283 .13948 Mtetra
.60283 .13948 .60974 .14883 .62338 .14378 .61652 .13438 Mtetra
.61652 .13438 .62338 .14378 .63708 .1387 .63027 .12926 Mtetra
.63027 .12926 .63708 .1387 .65086 .1336 .64408 .12411 Mtetra
.64408 .12411 .65086 .1336 .6647 .12847 .65797 .11894 Mtetra
.65797 .11894 .6647 .12847 .6786 .12332 .67193 .11374 Mtetra
.67193 .11374 .6786 .12332 .69258 .11814 .68595 .10851 Mtetra
.68595 .10851 .69258 .11814 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.648 .76 .931 r
.07039 .51329 .07943 .52074 .09142 .51672 .08242 .50923 Mtetra
.08242 .50923 .09142 .51672 .10348 .51267 .0945 .50515 Mtetra
.0945 .50515 .10348 .51267 .11559 .5086 .10664 .50105 Mtetra
.10664 .50105 .11559 .5086 .12776 .50452 .11884 .49692 Mtetra
.11884 .49692 .12776 .50452 .13998 .50041 .1311 .49278 Mtetra
.1311 .49278 .13998 .50041 .15227 .49629 .14342 .48862 Mtetra
.14342 .48862 .15227 .49629 .16461 .49214 .1558 .48444 Mtetra
.1558 .48444 .16461 .49214 .17701 .48798 .16824 .48024 Mtetra
.16824 .48024 .17701 .48798 .18948 .48379 .18073 .47602 Mtetra
.18073 .47602 .18948 .48379 .202 .47959 .19329 .47177 Mtetra
.19329 .47177 .202 .47959 .21459 .47536 .20591 .46751 Mtetra
.20591 .46751 .21459 .47536 .22723 .47112 .2186 .46322 Mtetra
.946 .708 .546 r
.2186 .46322 .22723 .47112 .25245 .32253 .24428 .31432 Mtetra
.66 .746 .914 r
.24428 .31432 .25245 .32253 .26468 .31809 .25655 .30984 Mtetra
.25655 .30984 .26468 .31809 .27698 .31363 .26888 .30535 Mtetra
.26888 .30535 .27698 .31363 .28933 .30915 .28127 .30083 Mtetra
.28127 .30083 .28933 .30915 .30174 .30465 .29371 .29629 Mtetra
.29371 .29629 .30174 .30465 .31421 .30013 .30622 .29173 Mtetra
.30622 .29173 .31421 .30013 .32674 .29559 .31879 .28715 Mtetra
.31879 .28715 .32674 .29559 .33933 .29103 .33141 .28254 Mtetra
.33141 .28254 .33933 .29103 .35198 .28644 .3441 .27792 Mtetra
.3441 .27792 .35198 .28644 .36469 .28183 .35684 .27327 Mtetra
.35684 .27327 .36469 .28183 .37746 .2772 .36965 .2686 Mtetra
.36965 .2686 .37746 .2772 .39029 .27255 .38252 .2639 Mtetra
.38252 .2639 .39029 .27255 .40319 .26788 .39545 .25919 Mtetra
.949 .74 .587 r
.39545 .25919 .40319 .26788 .41807 .20832 .41053 .19951 Mtetra
.664 .741 .908 r
.41053 .19951 .41807 .20832 .43086 .20356 .42335 .1947 Mtetra
.42335 .1947 .43086 .20356 .44372 .19877 .43624 .18987 Mtetra
.43624 .18987 .44372 .19877 .45663 .19396 .4492 .18501 Mtetra
.4492 .18501 .45663 .19396 .4696 .18912 .46221 .18014 Mtetra
.46221 .18014 .4696 .18912 .48264 .18427 .47529 .17524 Mtetra
.47529 .17524 .48264 .18427 .49574 .17939 .48843 .17031 Mtetra
.48843 .17031 .49574 .17939 .5089 .17448 .50163 .16537 Mtetra
.50163 .16537 .5089 .17448 .52212 .16955 .51489 .16039 Mtetra
.51489 .16039 .52212 .16955 .53541 .1646 .52823 .1554 Mtetra
.52823 .1554 .53541 .1646 .54877 .15963 .54162 .15038 Mtetra
.54162 .15038 .54877 .15963 .56218 .15463 .55508 .14533 Mtetra
.55508 .14533 .56218 .15463 .57567 .1496 .56861 .14026 Mtetra
.56861 .14026 .57567 .1496 .58922 .14455 .5822 .13517 Mtetra
.5822 .13517 .58922 .14455 .60283 .13948 .59586 .13005 Mtetra
.59586 .13005 .60283 .13948 .61652 .13438 .60959 .12491 Mtetra
.60959 .12491 .61652 .13438 .63027 .12926 .62339 .11974 Mtetra
.62339 .11974 .63027 .12926 .64408 .12411 .63725 .11454 Mtetra
.63725 .11454 .64408 .12411 .65797 .11894 .65119 .10932 Mtetra
.65119 .10932 .65797 .11894 .67193 .11374 .66519 .10407 Mtetra
.66519 .10407 .67193 .11374 .68595 .10851 .67926 .0988 Mtetra
.67926 .0988 .68595 .10851 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.648 .76 .931 r
.06127 .50578 .07039 .51329 .08242 .50923 .07333 .50168 Mtetra
.07333 .50168 .08242 .50923 .0945 .50515 .08544 .49756 Mtetra
.08544 .49756 .0945 .50515 .10664 .50105 .09762 .49342 Mtetra
.09762 .49342 .10664 .50105 .11884 .49692 .10985 .48926 Mtetra
.10985 .48926 .11884 .49692 .1311 .49278 .12214 .48508 Mtetra
.12214 .48508 .1311 .49278 .14342 .48862 .13449 .48089 Mtetra
.13449 .48089 .14342 .48862 .1558 .48444 .14691 .47667 Mtetra
.14691 .47667 .1558 .48444 .16824 .48024 .15938 .47243 Mtetra
.15938 .47243 .16824 .48024 .18073 .47602 .17191 .46817 Mtetra
.17191 .46817 .18073 .47602 .19329 .47177 .18451 .46389 Mtetra
.18451 .46389 .19329 .47177 .20591 .46751 .19716 .45958 Mtetra
.19716 .45958 .20591 .46751 .2186 .46322 .20988 .45526 Mtetra
.946 .708 .546 r
.20988 .45526 .2186 .46322 .24428 .31432 .23604 .30604 Mtetra
.66 .746 .914 r
.23604 .30604 .24428 .31432 .25655 .30984 .24834 .30153 Mtetra
.24834 .30153 .25655 .30984 .26888 .30535 .26071 .29699 Mtetra
.26071 .29699 .26888 .30535 .28127 .30083 .27313 .29243 Mtetra
.27313 .29243 .28127 .30083 .29371 .29629 .28561 .28785 Mtetra
.28561 .28785 .29371 .29629 .30622 .29173 .29816 .28325 Mtetra
.29816 .28325 .30622 .29173 .31879 .28715 .31076 .27863 Mtetra
.31076 .27863 .31879 .28715 .33141 .28254 .32342 .27398 Mtetra
.32342 .27398 .33141 .28254 .3441 .27792 .33614 .26932 Mtetra
.33614 .26932 .3441 .27792 .35684 .27327 .34893 .26463 Mtetra
.34893 .26463 .35684 .27327 .36965 .2686 .36177 .25991 Mtetra
.36177 .25991 .36965 .2686 .38252 .2639 .37468 .25518 Mtetra
.37468 .25518 .38252 .2639 .39545 .25919 .38765 .25042 Mtetra
.949 .74 .587 r
.38765 .25042 .39545 .25919 .41053 .19951 .40291 .19061 Mtetra
.664 .741 .908 r
.40291 .19061 .41053 .19951 .42335 .1947 .41578 .18576 Mtetra
.41578 .18576 .42335 .1947 .43624 .18987 .42871 .18089 Mtetra
.42871 .18089 .43624 .18987 .4492 .18501 .4417 .17599 Mtetra
.4417 .17599 .4492 .18501 .46221 .18014 .45475 .17107 Mtetra
.45475 .17107 .46221 .18014 .47529 .17524 .46787 .16613 Mtetra
.46787 .16613 .47529 .17524 .48843 .17031 .48105 .16116 Mtetra
.48105 .16116 .48843 .17031 .50163 .16537 .49429 .15617 Mtetra
.49429 .15617 .50163 .16537 .51489 .16039 .5076 .15115 Mtetra
.5076 .15115 .51489 .16039 .52823 .1554 .52097 .14611 Mtetra
.52097 .14611 .52823 .1554 .54162 .15038 .53441 .14104 Mtetra
.53441 .14104 .54162 .15038 .55508 .14533 .54792 .13595 Mtetra
.54792 .13595 .55508 .14533 .56861 .14026 .56149 .13084 Mtetra
.56149 .13084 .56861 .14026 .5822 .13517 .57513 .1257 Mtetra
.57513 .1257 .5822 .13517 .59586 .13005 .58883 .12053 Mtetra
.58883 .12053 .59586 .13005 .60959 .12491 .60261 .11534 Mtetra
.60261 .11534 .60959 .12491 .62339 .11974 .61645 .11012 Mtetra
.61645 .11012 .62339 .11974 .63725 .11454 .63036 .10488 Mtetra
.63036 .10488 .63725 .11454 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09431 Mtetra
.65839 .09431 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.648 .76 .931 r
.05207 .49819 .06127 .50578 .07333 .50168 .06416 .49406 Mtetra
.06416 .49406 .07333 .50168 .08544 .49756 .07631 .4899 Mtetra
.07631 .4899 .08544 .49756 .09762 .49342 .08851 .48573 Mtetra
.08851 .48573 .09762 .49342 .10985 .48926 .10078 .48153 Mtetra
.10078 .48153 .10985 .48926 .12214 .48508 .1131 .47732 Mtetra
.1131 .47732 .12214 .48508 .13449 .48089 .12549 .47308 Mtetra
.12549 .47308 .13449 .48089 .14691 .47667 .13793 .46882 Mtetra
.13793 .46882 .14691 .47667 .15938 .47243 .15044 .46455 Mtetra
.15044 .46455 .15938 .47243 .17191 .46817 .16301 .46025 Mtetra
.16301 .46025 .17191 .46817 .18451 .46389 .17564 .45593 Mtetra
.17564 .45593 .18451 .46389 .19716 .45958 .18833 .45158 Mtetra
.18833 .45158 .19716 .45958 .20988 .45526 .20109 .44722 Mtetra
.946 .708 .546 r
.20109 .44722 .20988 .45526 .23604 .30604 .22773 .29769 Mtetra
.66 .746 .914 r
.22773 .29769 .23604 .30604 .24834 .30153 .24007 .29314 Mtetra
.24007 .29314 .24834 .30153 .26071 .29699 .25247 .28856 Mtetra
.25247 .28856 .26071 .29699 .27313 .29243 .26492 .28396 Mtetra
.26492 .28396 .27313 .29243 .28561 .28785 .27744 .27934 Mtetra
.27744 .27934 .28561 .28785 .29816 .28325 .29002 .2747 Mtetra
.29002 .2747 .29816 .28325 .31076 .27863 .30266 .27004 Mtetra
.30266 .27004 .31076 .27863 .32342 .27398 .31536 .26535 Mtetra
.31536 .26535 .32342 .27398 .33614 .26932 .32812 .26064 Mtetra
.32812 .26064 .33614 .26932 .34893 .26463 .34094 .25591 Mtetra
.34094 .25591 .34893 .26463 .36177 .25991 .35382 .25115 Mtetra
.35382 .25115 .36177 .25991 .37468 .25518 .36677 .24638 Mtetra
.36677 .24638 .37468 .25518 .38765 .25042 .37978 .24158 Mtetra
.949 .74 .587 r
.37978 .24158 .38765 .25042 .40291 .19061 .39523 .18164 Mtetra
.664 .741 .908 r
.39523 .18164 .40291 .19061 .41578 .18576 .40813 .17675 Mtetra
.40813 .17675 .41578 .18576 .42871 .18089 .4211 .17183 Mtetra
.4211 .17183 .42871 .18089 .4417 .17599 .43413 .16689 Mtetra
.43413 .16689 .4417 .17599 .45475 .17107 .44723 .16193 Mtetra
.44723 .16193 .45475 .17107 .46787 .16613 .46038 .15694 Mtetra
.46038 .15694 .46787 .16613 .48105 .16116 .4736 .15192 Mtetra
.4736 .15192 .48105 .16116 .49429 .15617 .48689 .14689 Mtetra
.48689 .14689 .49429 .15617 .5076 .15115 .50024 .14183 Mtetra
.50024 .14183 .5076 .15115 .52097 .14611 .51366 .13674 Mtetra
.51366 .13674 .52097 .14611 .53441 .14104 .52714 .13163 Mtetra
.52714 .13163 .53441 .14104 .54792 .13595 .54069 .12649 Mtetra
.54069 .12649 .54792 .13595 .56149 .13084 .5543 .12133 Mtetra
.5543 .12133 .56149 .13084 .57513 .1257 .56798 .11614 Mtetra
.56798 .11614 .57513 .1257 .58883 .12053 .58173 .11093 Mtetra
.58173 .11093 .58883 .12053 .60261 .11534 .59555 .10569 Mtetra
.59555 .10569 .60261 .11534 .61645 .11012 .60944 .10042 Mtetra
.60944 .10042 .61645 .11012 .63036 .10488 .6234 .09513 Mtetra
.6234 .09513 .63036 .10488 .64434 .09961 .63742 .08981 Mtetra
.63742 .08981 .64434 .09961 .65839 .09431 .65152 .08447 Mtetra
.65152 .08447 .65839 .09431 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.648 .76 .931 r
.04279 .49054 .05207 .49819 .06416 .49406 .05491 .48637 Mtetra
.05491 .48637 .06416 .49406 .07631 .4899 .06709 .48218 Mtetra
.06709 .48218 .07631 .4899 .08851 .48573 .07933 .47797 Mtetra
.07933 .47797 .08851 .48573 .10078 .48153 .09162 .47373 Mtetra
.09162 .47373 .10078 .48153 .1131 .47732 .10398 .46948 Mtetra
.10398 .46948 .1131 .47732 .12549 .47308 .1164 .4652 Mtetra
.1164 .4652 .12549 .47308 .13793 .46882 .12888 .46091 Mtetra
.12888 .46091 .13793 .46882 .15044 .46455 .14142 .45659 Mtetra
.14142 .45659 .15044 .46455 .16301 .46025 .15402 .45225 Mtetra
.15402 .45225 .16301 .46025 .17564 .45593 .16669 .44789 Mtetra
.16669 .44789 .17564 .45593 .18833 .45158 .17942 .44351 Mtetra
.17942 .44351 .18833 .45158 .20109 .44722 .19221 .43911 Mtetra
.946 .708 .546 r
.19221 .43911 .20109 .44722 .22773 .29769 .21934 .28926 Mtetra
.66 .746 .914 r
.21934 .28926 .22773 .29769 .24007 .29314 .23172 .28467 Mtetra
.23172 .28467 .24007 .29314 .25247 .28856 .24415 .28005 Mtetra
.24415 .28005 .25247 .28856 .26492 .28396 .25664 .27542 Mtetra
.25664 .27542 .26492 .28396 .27744 .27934 .2692 .27076 Mtetra
.2692 .27076 .27744 .27934 .29002 .2747 .28181 .26607 Mtetra
.28181 .26607 .29002 .2747 .30266 .27004 .29449 .26137 Mtetra
.29449 .26137 .30266 .27004 .31536 .26535 .30722 .25664 Mtetra
.30722 .25664 .31536 .26535 .32812 .26064 .32002 .25189 Mtetra
.32002 .25189 .32812 .26064 .34094 .25591 .33288 .24711 Mtetra
.33288 .24711 .34094 .25591 .35382 .25115 .3458 .24232 Mtetra
.3458 .24232 .35382 .25115 .36677 .24638 .35879 .23749 Mtetra
.35879 .23749 .36677 .24638 .37978 .24158 .37183 .23265 Mtetra
.949 .74 .587 r
.37183 .23265 .37978 .24158 .39523 .18164 .38748 .17259 Mtetra
.664 .741 .908 r
.38748 .17259 .39523 .18164 .40813 .17675 .40042 .16765 Mtetra
.40042 .16765 .40813 .17675 .4211 .17183 .41343 .16269 Mtetra
.41343 .16269 .4211 .17183 .43413 .16689 .4265 .15771 Mtetra
.4265 .15771 .43413 .16689 .44723 .16193 .43963 .1527 Mtetra
.43963 .1527 .44723 .16193 .46038 .15694 .45283 .14766 Mtetra
.45283 .14766 .46038 .15694 .4736 .15192 .46609 .14261 Mtetra
.46609 .14261 .4736 .15192 .48689 .14689 .47942 .13752 Mtetra
.47942 .13752 .48689 .14689 .50024 .14183 .49281 .13242 Mtetra
.49281 .13242 .50024 .14183 .51366 .13674 .50627 .12728 Mtetra
.50627 .12728 .51366 .13674 .52714 .13163 .5198 .12212 Mtetra
.5198 .12212 .52714 .13163 .54069 .12649 .53339 .11694 Mtetra
.53339 .11694 .54069 .12649 .5543 .12133 .54705 .11173 Mtetra
.54705 .11173 .5543 .12133 .56798 .11614 .56078 .1065 Mtetra
.56078 .1065 .56798 .11614 .58173 .11093 .57457 .10123 Mtetra
.57457 .10123 .58173 .11093 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10042 .60237 .09063 Mtetra
.60237 .09063 .60944 .10042 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63742 .08981 .63045 .07992 Mtetra
.63045 .07992 .63742 .08981 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.648 .76 .931 r
.03342 .48283 .04279 .49054 .05491 .48637 .04557 .47862 Mtetra
.04557 .47862 .05491 .48637 .06709 .48218 .05778 .47439 Mtetra
.05778 .47439 .06709 .48218 .07933 .47797 .07006 .47014 Mtetra
.07006 .47014 .07933 .47797 .09162 .47373 .08239 .46586 Mtetra
.08239 .46586 .09162 .47373 .10398 .46948 .09478 .46157 Mtetra
.09478 .46157 .10398 .46948 .1164 .4652 .10723 .45726 Mtetra
.10723 .45726 .1164 .4652 .12888 .46091 .11975 .45292 Mtetra
.11975 .45292 .12888 .46091 .14142 .45659 .13232 .44857 Mtetra
.13232 .44857 .14142 .45659 .15402 .45225 .14496 .44419 Mtetra
.14496 .44419 .15402 .45225 .16669 .44789 .15766 .43979 Mtetra
.15766 .43979 .16669 .44789 .17942 .44351 .17042 .43537 Mtetra
.17042 .43537 .17942 .44351 .19221 .43911 .18325 .43092 Mtetra
.946 .708 .546 r
.18325 .43092 .19221 .43911 .21934 .28926 .21088 .28077 Mtetra
.66 .746 .914 r
.21088 .28077 .21934 .28926 .23172 .28467 .22329 .27613 Mtetra
.22329 .27613 .23172 .28467 .24415 .28005 .23576 .27147 Mtetra
.23576 .27147 .24415 .28005 .25664 .27542 .24829 .26679 Mtetra
.24829 .26679 .25664 .27542 .2692 .27076 .26088 .26209 Mtetra
.26088 .26209 .2692 .27076 .28181 .26607 .27353 .25737 Mtetra
.27353 .25737 .28181 .26607 .29449 .26137 .28624 .25262 Mtetra
.28624 .25262 .29449 .26137 .30722 .25664 .29901 .24785 Mtetra
.29901 .24785 .30722 .25664 .32002 .25189 .31185 .24306 Mtetra
.31185 .24306 .32002 .25189 .33288 .24711 .32475 .23824 Mtetra
.32475 .23824 .33288 .24711 .3458 .24232 .33771 .2334 Mtetra
.33771 .2334 .3458 .24232 .35879 .23749 .35073 .22853 Mtetra
.35073 .22853 .35879 .23749 .37183 .23265 .36382 .22364 Mtetra
.949 .74 .587 r
.36382 .22364 .37183 .23265 .38748 .17259 .37966 .16346 Mtetra
.664 .741 .908 r
.37966 .16346 .38748 .17259 .40042 .16765 .39264 .15847 Mtetra
.39264 .15847 .40042 .16765 .41343 .16269 .40569 .15347 Mtetra
.40569 .15347 .41343 .16269 .4265 .15771 .4188 .14844 Mtetra
.4188 .14844 .4265 .15771 .43963 .1527 .43197 .14339 Mtetra
.43197 .14339 .43963 .1527 .45283 .14766 .44521 .13831 Mtetra
.44521 .13831 .45283 .14766 .46609 .14261 .45852 .1332 Mtetra
.45852 .1332 .46609 .14261 .47942 .13752 .47188 .12807 Mtetra
.47188 .12807 .47942 .13752 .49281 .13242 .48532 .12292 Mtetra
.48532 .12292 .49281 .13242 .50627 .12728 .49882 .11774 Mtetra
.49882 .11774 .50627 .12728 .5198 .12212 .51239 .11253 Mtetra
.51239 .11253 .5198 .12212 .53339 .11694 .52603 .1073 Mtetra
.52603 .1073 .53339 .11694 .54705 .11173 .53973 .10205 Mtetra
.53973 .10205 .54705 .11173 .56078 .1065 .5535 .09676 Mtetra
.5535 .09676 .56078 .1065 .57457 .10123 .56734 .09145 Mtetra
.56734 .09145 .57457 .10123 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09063 .59523 .08075 Mtetra
.59523 .08075 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.648 .76 .931 r
.02397 .47504 .03342 .48283 .04557 .47862 .03615 .47079 Mtetra
.03615 .47079 .04557 .47862 .05778 .47439 .0484 .46652 Mtetra
.0484 .46652 .05778 .47439 .07006 .47014 .0607 .46223 Mtetra
.0607 .46223 .07006 .47014 .08239 .46586 .07307 .45792 Mtetra
.07307 .45792 .08239 .46586 .09478 .46157 .08549 .45359 Mtetra
.08549 .45359 .09478 .46157 .10723 .45726 .09798 .44924 Mtetra
.09798 .44924 .10723 .45726 .11975 .45292 .11053 .44486 Mtetra
.11053 .44486 .11975 .45292 .13232 .44857 .12314 .44047 Mtetra
.12314 .44047 .13232 .44857 .14496 .44419 .13581 .43605 Mtetra
.13581 .43605 .14496 .44419 .15766 .43979 .14855 .43161 Mtetra
.14855 .43161 .15766 .43979 .17042 .43537 .16135 .42715 Mtetra
.16135 .42715 .17042 .43537 .18325 .43092 .17421 .42266 Mtetra
.946 .708 .546 r
.17421 .42266 .18325 .43092 .21088 .28077 .20235 .27219 Mtetra
.66 .746 .914 r
.20235 .27219 .21088 .28077 .22329 .27613 .21479 .26752 Mtetra
.21479 .26752 .22329 .27613 .23576 .27147 .2273 .26282 Mtetra
.2273 .26282 .23576 .27147 .24829 .26679 .23986 .2581 Mtetra
.23986 .2581 .24829 .26679 .26088 .26209 .25249 .25335 Mtetra
.25249 .25335 .26088 .26209 .27353 .25737 .26517 .24858 Mtetra
.26517 .24858 .27353 .25737 .28624 .25262 .27792 .24379 Mtetra
.27792 .24379 .28624 .25262 .29901 .24785 .29073 .23898 Mtetra
.29073 .23898 .29901 .24785 .31185 .24306 .3036 .23414 Mtetra
.3036 .23414 .31185 .24306 .32475 .23824 .31654 .22928 Mtetra
.31654 .22928 .32475 .23824 .33771 .2334 .32954 .2244 Mtetra
.32954 .2244 .33771 .2334 .35073 .22853 .3426 .21949 Mtetra
.3426 .21949 .35073 .22853 .36382 .22364 .35573 .21456 Mtetra
.949 .74 .587 r
.35573 .21456 .36382 .22364 .37966 .16346 .37177 .15424 Mtetra
.664 .741 .908 r
.37177 .15424 .37966 .16346 .39264 .15847 .38479 .14922 Mtetra
.38479 .14922 .39264 .15847 .40569 .15347 .39788 .14417 Mtetra
.39788 .14417 .40569 .15347 .4188 .14844 .41103 .13909 Mtetra
.41103 .13909 .4188 .14844 .43197 .14339 .42424 .13399 Mtetra
.42424 .13399 .43197 .14339 .44521 .13831 .43752 .12886 Mtetra
.43752 .12886 .44521 .13831 .45852 .1332 .45087 .12371 Mtetra
.45087 .12371 .45852 .1332 .47188 .12807 .46428 .11854 Mtetra
.46428 .11854 .47188 .12807 .48532 .12292 .47776 .11334 Mtetra
.47776 .11334 .48532 .12292 .49882 .11774 .4913 .10811 Mtetra
.4913 .10811 .49882 .11774 .51239 .11253 .50491 .10286 Mtetra
.50491 .10286 .51239 .11253 .52603 .1073 .51859 .09758 Mtetra
.51859 .09758 .52603 .1073 .53973 .10205 .53234 .09227 Mtetra
.53234 .09227 .53973 .10205 .5535 .09676 .54616 .08694 Mtetra
.54616 .08694 .5535 .09676 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.648 .76 .931 r
.01444 .46718 .02397 .47504 .03615 .47079 .02665 .46289 Mtetra
.02665 .46289 .03615 .47079 .0484 .46652 .03893 .45859 Mtetra
.03893 .45859 .0484 .46652 .0607 .46223 .05126 .45426 Mtetra
.05126 .45426 .0607 .46223 .07307 .45792 .06366 .44991 Mtetra
.06366 .44991 .07307 .45792 .08549 .45359 .07612 .44554 Mtetra
.07612 .44554 .08549 .45359 .09798 .44924 .08864 .44115 Mtetra
.08864 .44115 .09798 .44924 .11053 .44486 .10122 .43673 Mtetra
.10122 .43673 .11053 .44486 .12314 .44047 .11387 .43229 Mtetra
.11387 .43229 .12314 .44047 .13581 .43605 .12658 .42784 Mtetra
.12658 .42784 .13581 .43605 .14855 .43161 .13935 .42335 Mtetra
.13935 .42335 .14855 .43161 .16135 .42715 .15218 .41885 Mtetra
.15218 .41885 .16135 .42715 .17421 .42266 .16509 .41432 Mtetra
.946 .708 .546 r
.16509 .41432 .17421 .42266 .20235 .27219 .19374 .26354 Mtetra
.66 .746 .914 r
.19374 .26354 .20235 .27219 .21479 .26752 .20622 .25882 Mtetra
.20622 .25882 .21479 .26752 .2273 .26282 .21876 .25408 Mtetra
.21876 .25408 .2273 .26282 .23986 .2581 .23136 .24932 Mtetra
.23136 .24932 .23986 .2581 .25249 .25335 .24402 .24453 Mtetra
.24402 .24453 .25249 .25335 .26517 .24858 .25674 .23972 Mtetra
.25674 .23972 .26517 .24858 .27792 .24379 .26953 .23489 Mtetra
.26953 .23489 .27792 .24379 .29073 .23898 .28237 .23003 Mtetra
.28237 .23003 .29073 .23898 .3036 .23414 .29528 .22515 Mtetra
.29528 .22515 .3036 .23414 .31654 .22928 .30826 .22025 Mtetra
.30826 .22025 .31654 .22928 .32954 .2244 .3213 .21532 Mtetra
.3213 .21532 .32954 .2244 .3426 .21949 .3344 .21036 Mtetra
.3344 .21036 .3426 .21949 .35573 .21456 .34757 .20538 Mtetra
.949 .74 .587 r
.34757 .20538 .35573 .21456 .37177 .15424 .36381 .14494 Mtetra
.664 .741 .908 r
.36381 .14494 .37177 .15424 .38479 .14922 .37687 .13987 Mtetra
.37687 .13987 .38479 .14922 .39788 .14417 .39 .13478 Mtetra
.39 .13478 .39788 .14417 .41103 .13909 .40319 .12965 Mtetra
.40319 .12965 .41103 .13909 .42424 .13399 .41644 .12451 Mtetra
.41644 .12451 .42424 .13399 .43752 .12886 .42976 .11934 Mtetra
.42976 .11934 .43752 .12886 .45087 .12371 .44315 .11414 Mtetra
.44315 .11414 .45087 .12371 .46428 .11854 .4566 .10892 Mtetra
.4566 .10892 .46428 .11854 .47776 .11334 .47013 .10367 Mtetra
.47013 .10367 .47776 .11334 .4913 .10811 .48371 .09839 Mtetra
.48371 .09839 .4913 .10811 .50491 .10286 .49737 .09309 Mtetra
.49737 .09309 .50491 .10286 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09227 .52489 .0824 Mtetra
.52489 .0824 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.648 .76 .931 r
.00481 .45925 .01444 .46718 .02665 .46289 .01706 .45493 Mtetra
.01706 .45493 .02665 .46289 .03893 .45859 .02937 .45058 Mtetra
.02937 .45058 .03893 .45859 .05126 .45426 .04174 .44621 Mtetra
.04174 .44621 .05126 .45426 .06366 .44991 .05417 .44182 Mtetra
.05417 .44182 .06366 .44991 .07612 .44554 .06666 .43741 Mtetra
.06666 .43741 .07612 .44554 .08864 .44115 .07922 .43298 Mtetra
.07922 .43298 .08864 .44115 .10122 .43673 .09183 .42852 Mtetra
.09183 .42852 .10122 .43673 .11387 .43229 .10451 .42404 Mtetra
.10451 .42404 .11387 .43229 .12658 .42784 .11726 .41954 Mtetra
.11726 .41954 .12658 .42784 .13935 .42335 .13006 .41502 Mtetra
.13006 .41502 .13935 .42335 .15218 .41885 .14294 .41048 Mtetra
.14294 .41048 .15218 .41885 .16509 .41432 .15588 .40591 Mtetra
.946 .708 .546 r
.15588 .40591 .16509 .41432 .19374 .26354 .18506 .25481 Mtetra
.66 .746 .914 r
.18506 .25481 .19374 .26354 .20622 .25882 .19757 .25005 Mtetra
.19757 .25005 .20622 .25882 .21876 .25408 .21014 .24527 Mtetra
.21014 .24527 .21876 .25408 .23136 .24932 .22278 .24046 Mtetra
.22278 .24046 .23136 .24932 .24402 .24453 .23548 .23563 Mtetra
.23548 .23563 .24402 .24453 .25674 .23972 .24823 .23078 Mtetra
.24823 .23078 .25674 .23972 .26953 .23489 .26106 .2259 Mtetra
.26106 .2259 .26953 .23489 .28237 .23003 .27394 .221 Mtetra
.27394 .221 .28237 .23003 .29528 .22515 .28689 .21608 Mtetra
.28689 .21608 .29528 .22515 .30826 .22025 .2999 .21113 Mtetra
.2999 .21113 .30826 .22025 .3213 .21532 .31298 .20615 Mtetra
.31298 .20615 .3213 .21532 .3344 .21036 .32612 .20115 Mtetra
.32612 .20115 .3344 .21036 .34757 .20538 .33933 .19613 Mtetra
.949 .74 .587 r
.33933 .19613 .34757 .20538 .36381 .14494 .35578 .13556 Mtetra
.664 .741 .908 r
.35578 .13556 .36381 .14494 .37687 .13987 .36888 .13044 Mtetra
.36888 .13044 .37687 .13987 .39 .13478 .38204 .1253 Mtetra
.38204 .1253 .39 .13478 .40319 .12965 .39527 .12013 Mtetra
.39527 .12013 .40319 .12965 .41644 .12451 .40857 .11494 Mtetra
.40857 .11494 .41644 .12451 .42976 .11934 .42193 .10972 Mtetra
.42193 .10972 .42976 .11934 .44315 .11414 .43536 .10448 Mtetra
.43536 .10448 .44315 .11414 .4566 .10892 .44886 .0992 Mtetra
.44886 .0992 .4566 .10892 .47013 .10367 .46242 .09391 Mtetra
.46242 .09391 .47013 .10367 .48371 .09839 .47605 .08858 Mtetra
.47605 .08858 .48371 .09839 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .0824 .51736 .07245 Mtetra
.51736 .07245 .52489 .0824 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 154.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000VR000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00QOooool2o`000<Cooooo0_l0
0013ooooo`00P_ooool3o`000003ooooool0003ooooo0<3ooooo0ol000000ooooooo0000ooooo`12
ooooo`00P?ooool2o`0000?ooooo00<0ZKgXo`000?l00000__ooool2o`0000?ooooo00<0ZKgXo`00
0?l00000@_ooool007gooooo0ol00002ooooo`@0ZKgX00?o0000ooooool00000^_ooool3o`0000?o
oooo0`2Y_NP00ol0003oooooo`000011ooooo`00N_ooool3o`0000?ooooo1P2Y_NP00ol00000ZKgX
o`00002hooooo`;o00000oooool60:Vmj003o`00002Y_NSo0000047ooooo001hooooo`;o00000ooo
ool90:Vmj004o`00002Y_NP0ZKgXo`000;Cooooo0ol00002ooooo`T0ZKgX00Co00000:Vmj02Y_NSo
0000@?ooool007Gooooo0ol00002ooooo``0ZKgX00Go00000:Vmj02Y_NP0ZKgXo`00002`ooooo`?o
00000oooool;0:Vmj005o`00002Y_NP0ZKgX0:Vmj?l00000?oooool007?ooooo0_l00003ooooo`h0
ZKgX00Go00000:Vmj02Y_NP0ZKgXo`00002^ooooo`;o00000oooool>0:Vmj005o`00002Y_NP0ZKgX
0:Vmj?l00000?oooool0073ooooo0ol00002oooooa40ZKgX00?o00000:Vmj02Y_NP00P2Y_NP00ol0
003oooooooooo`2Xooooo`?o00000_oooolB0:Vmj005o`00002Y_NP0ZKgX0:Vmj?l00000?_ooool0
06kooooo0_l00003oooooa<0ZKgX00?o00000:Vmj02Y_NP00P2Y_NP00ooooooo0000ooooo`2Voooo
o`;o00000ooooolD0:Vmj006o`00002Y_NP0ZKgX0:Vmj?oooooo0000?Oooool006_ooooo0ol00002
oooooaH0ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00ol0003oooooooooo`2Rooooo`?o00000_oooolG
0:Vmj003o`00002Y_NP0ZKgX0080ZKgX00?o0000ooooooooool0>oooool006Sooooo0ol00003oooo
oaP0ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00ooooooo0000ooooo`2Pooooo`;o00000ooooolI0:Vm
j003o`00002Y_NP0ZKgX0080ZKgX00?oooooo`000?ooool0>oooool006Kooooo0_l00003oooooa`0
ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00ol0003oooooooooo`2Looooo`?o00000_oooolL0:Vmj003
o`00002Y_NP0ZKgX00<0ZKgX00?oooooo`000?ooool0>_ooool006?ooooo0ol00002oooooal0ZKgX
00?o00000:Vmj02Y_NP00`2Y_NP00ooooooo0000ooooo`2Jooooo`;o00000ooooolN0:Vmj003o`00
002Y_NP0ZKgX00@0ZKgX00?o0000ooooooooool0>Oooool0067ooooo0_l00003ooooob40ZKgX00?o
00000:Vmj02Y_NP0102Y_NP00ooooooo0000ooooo`2Fooooo`?o00000_oooolQ0:Vmj003o`00002Y
_NP0ZKgX00D0ZKgX00?o0000ooooooooool0>?ooool005kooooo0ol00002ooooob@0ZKgX00?o0000
0:Vmj02Y_NP01@2Y_NP00ol0003oooooooooo`2Cooooo`;o00000ooooolS0:Vmj003o`00002Y_NP0
ZKgX00H0ZKgX00?o0000ooooooooool0=oooool005cooooo0_l00003ooooobH0ZKgX00?o00000:Vm
j02Y_NP01P2Y_NP00ol0003oooooooooo`2?ooooo`?o00000_oooolV0:Vmj003o`00002Y_NP0ZKgX
00H0ZKgX00?o0000ooooooooool0=oooool005Wooooo0ol00003ooooobP0ZKgX00?o00000:Vmj02Y
_NP01`2Y_NP00ol0003oooooooooo`2;ooooo`?o00000ooooolX0:Vmj003o`00002Y_NP0ZKgX00L0
ZKgX00?o0000ooooooooool0=_ooool005Oooooo0_l00003ooooob/0ZKgX00?o00000:Vmj02Y_NP0
1`2Y_NP00ol0003oooooooooo`29ooooo`;o00000oooool[0:Vmj003o`00002Y_NP0ZKgX00L0ZKgX
00?oooooo`000?ooool0=_ooool005Cooooo0ol00003ooooobd0ZKgX00?o00000:Vmj02Y_NP0202Y
_NP00ol0003oooooooooo`25ooooo`?o00000oooool]0:Vmj003o`00002Y_NP0ZKgX00P0ZKgX00?o
0000ooooooooool0=Oooool0057ooooo0ol000000oooool0ZKgX0:Vmj00`0:Vmj003o`00002Y_NP0
ZKgX00P0ZKgX00?oooooo`000?ooool0Poooool2o`000003ooooo`2Y_NP0ZKgX0300ZKgX00?o0000
0:Vmj02Y_NP0202Y_NP00ooooooo0000ooooo`0eooooo`00Coooool2o`000003ooooo`2Y_NP0ZKgX
03<0ZKgX00?o00000:Vmj02Y_NP02@2Y_NP00ol0003oooooooooo`1oooooo`?o000000?ooooo0:Vm
j02Y_NP0<P2Y_NP00ol00000ZKgX0:Vmj0090:Vmj003ooooool0003ooooo03Cooooo001<ooooo`?o
000000?ooooo0:Vmj02Y_NP0=@2Y_NP00ol00000ZKgX0:Vmj00:0:Vmj003o`000?oooooooooo07co
oooo0_l000000oooool0ZKgX0:Vmj00e0:Vmj003o`00002Y_NP0ZKgX00X0ZKgX00?o0000oooooooo
ool0<oooool004[ooooo0_l00002ooooocT0ZKgX00?o00000:Vmj02Y_NP02@2Y_NP00`2SUlWooooo
o`00001jooooo`?o000000?ooooo0:Vmj02Y_NP0>02Y_NP00ol00000ZKgX0:Vmj00:0:Vmj003o`00
0?oooooooooo03;ooooo0017ooooo`?o000000?ooooo0:Vmj02Y_NP0>P2Y_NP00ol00000ZKgX0:Vm
j0070:Vmj0@0XiO900?o0000ooooooooool0M_ooool2o`000003ooooo`2Y_NP0ZKgX03/0ZKgX00?o
00000:Vmj02Y_NP02`2Y_NP00ol0003oooooooooo`0aooooo`00AOooool2o`0000;ooooo?P2Y_NP0
0ol00000ZKgX0:Vmj0040:Vmj0L0XiO900?oooooo`000?ooool0Loooool3o`0000;ooooo00<0l[fF
0:Vmj02Y_NP0>`2Y_NP00ol00000ZKgX0:Vmj00;0:Vmj003o`000?oooooooooo037ooooo0012oooo
o`?o00000_oooom00:Vmj003o`00002Y_NP0ZKgX0080ZKgX202SUlT20:Vmj003ooooool0003ooooo
073ooooo0_l00005ooooo`80l[fF?02Y_NP00ol00000ZKgX0:Vmj00<0:Vmj003o`000?oooooooooo
033ooooo000oooooo`?o00000_oooom30:Vmj003o`00002Y_NP0XiO900P0XiO91@2Y_NP00ol0003o
ooooooooo`1/ooooo`?o00001oooool30?:mUS/0ZKgX00?o00000:Vmj02Y_NP03@2Y_NP00ol0003o
ooooooooo`0_ooooo`00?Oooool2o`0000?oooooA@2Y_NP00ol00000XiO90:>Gb@050:>Gb@P0ZKgX
00?oooooo`000?ooool0J_ooool2o`0000Wooooo103b_IHk0:Vmj003o`00002Y_NP0ZKgX00d0ZKgX
00?o0000ooooooooool0;oooool003[ooooo0ol00003oooood@0ZKgX0`2SUlT00ol00000XiO90:>G
b@030:>Gb@/0ZKgX00?oooooo`000?ooool0I_ooool3o`0000_ooooo1@3b_IHj0:Vmj003o`00002Y
_NP0ZKgX00h0ZKgX00?o0000ooooooooool0;_ooool003Sooooo0_l00003ooooodD0ZKgX1@2SUlT0
0ol00000XiO90:>Gb@0>0:Vmj003ooooool0003ooooo06?ooooo0ol0000>ooooo`H0l[fF>@2Y_NP0
0ol00000ZKgX0:Vmj00>0:Vmj003ooooool0003ooooo02kooooo000eooooo`?o000000?ooooo0:Vm
j02Y_NP0A02Y_NP80:>Gb@03o`00002Y_NP0ZKgX00l0ZKgX00?oooooo`000?ooool0H?ooool2o`00
013ooooo203b_IHh0:Vmj003o`00002Y_NP0ZKgX00l0ZKgX00?o0000ooooooooool0;Oooool003?o
oooo0_l000000oooool0ZKgX0:Vmj0120:Vmj0/0XiO90P2Y_NP00ol00000ZKgX0:Vmj00@0:Vmj003
o`000?oooooooooo05cooooo0ol0000Booooo`T0l[fF=`2Y_NP00ol00000ZKgX0:Vmj00@0:Vmj003
o`000?oooooooooo02cooooo000`ooooo`?o000000?ooooo0:Vmj02Y_NP0@P2Y_NP;0:>Gb@@0ZKgX
00?o00000:Vmj02Y_NP0402Y_NP00ooooooo0000ooooo`1Jooooo`;o00005Oooool:0?:mUSH0ZKgX
00?o00000:Vmj02Y_NP0402Y_NP00ooooooo0000ooooo`0/ooooo`00;Oooool3o`0000;oooooA02Y
_NP:0:>Gb@P0ZKgX00?o00000:Vmj02Y_NP0402Y_NP00ooooooo0000ooooo`1Fooooo`?o00005ooo
ool;0?:mUR<0ZKgX00<0V7R]0:Vmj02Y_NP03`2Y_NP00ol00000ZKgX0:Vmj00A0:Vmj003o`000?oo
oooooooo02_ooooo000[ooooo`;o00000ooooom70:Vmj0D0XiO9302Y_NP00ol00000ZKgX0:Vmj00A
0:Vmj003o`000?oooooooooo05?ooooo0_l0000Iooooo``0l[fF802Y_NP509Qh[A00ZKgX00?o0000
0:Vmj02Y_NP04@2Y_NP00ooooooo0000ooooo`0[ooooo`00:?ooool3o`0000;oooooB`2Y_NP00`2S
UlT0ZKgX0:Vmj00=0:Vmj003o`00002Y_NP0ZKgX0140ZKgX00?oooooo`000?ooool0D?ooool3o`00
01[ooooo0P2X_^T<0?:mUQd0ZKgX1`2HN:d00`3[b;40ZKgX0:Vmj00=0:Vmj003o`00002Y_NP0ZKgX
0180ZKgX00?oooooo`000?ooool0:_ooool002Kooooo0_l00003oooood/0ZKgX0P1DTnh@0:Vmj003
o`00002Y_NP0ZKgX0180ZKgX00?oooooo`000?ooool0COooool2o`0001_ooooo1@2X_^T<0?:mUQX0
ZKgX2@2HN:d00`3[b;40ZKgX0:Vmj00=0:Vmj003o`00002Y_NP0ZKgX01<0ZKgX00?o0000oooooooo
ool0:Oooool002?ooooo0ol000000oooool0ZKgX0:Vmj01>0:Vmj080E9?^3`2Y_NP00ol00000ZKgX
0:Vmj00B0:Vmj003ooooool0003ooooo04[ooooo0ol0000Jooooo`T0Z;kY303b_IHF0:Vmj0/0V7R]
0`3[b;4?0:Vmj003o`00002Y_NP0ZKgX0180ZKgX00?oooooo`000?ooool0:Oooool0027ooooo0_l0
0002oooooe<0ZKgX0P1DTnh>0:Vmj003o`00002Y_NP0ZKgX01<0ZKgX00?oooooo`000?ooool0Aooo
ool2o`0001_ooooo302X_^T<0?:mUQ00ZKgX402HN:d40>_8/@h0ZKgX00?o00000:Vmj02Y_NP04`2Y
_NP00ooooooo0000ooooo`0Xooooo`007_ooool3o`000003ooooo`2Y_NP0ZKgX05D0ZKgX00<0E9?^
0:Vmj02Y_NP0302Y_NP00ol00000ZKgX0:Vmj00D0:Vmj003ooooool0003ooooo04?ooooo0ol0000K
ooooo`l0Z;kY303b_IH=0:Vmj180V7R]1@3[b;4=0:Vmj003o`00002Y_NP0ZKgX01@0ZKgX00?o0000
ooooooooool09oooool001cooooo0_l00002oooooeT0ZKgX0P1DTnh=0:Vmj003o`00002Y_NP0ZKgX
01@0ZKgX00?oooooo`000?ooool0@?ooool3o`0001Wooooo502X_^T<0?:mUP/0ZKgX3`2HN:d50:Vn
j0H0jlRa302Y_NP00ol00000ZKgX0:Vmj00D0:Vmj003ooooool0003ooooo02Oooooo000Iooooo`?o
00000_oooomL0:Vmj080E9?^302Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003ooooool0003ooooo03go
oooo0_l0000JoooooaL0Z;kY303b_IH80:Vmj0l0V7R]1`2Y_^P60>_8/@`0ZKgX00?o00000:Vmj02Y
_NP05@2Y_NP00ol0003oooooooooo`0Vooooo`005_ooool3o`000003ooooo`2Y_NP0ZKgX05h0ZKgX
0`1DTnh;0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?oooooo`000?ooool0>Oooool3o`0001Wooooo
6`2X_^T=0?:mUP<0ZKgX3`2HN:d;0:Vnj0H0jlRa2`2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`00
0?oooooooooo02Gooooo000Dooooo`;o00000_oooomS0:Vmj0<0E9?^2@2Y_NP2o`0001P0ZKgX00?o
ooooo`000?ooool0=oooool2o`0001[ooooo7P2X_^T<0?:mUQ00V7R]3P2Y_^P60>_8/@T0ZKgX0_l0
000H0:Vmj003ooooool0003ooooo02Gooooo000Aooooo`?o00000_oooomV0:Vmj080E9?^1P2Y_NP3
o`0000030:Vmj?l00000ZKgX01P0ZKgX00?oooooo`000?ooool0<oooool3o`0001[ooooo8@2X_^T;
0?:mUPh0V7R]402Y_^P60>_8/@H0ZKgX0ol000000`2Y_NSo00000:Vmj00H0:Vmj003o`000?oooooo
oooo02Cooooo000@ooooo`;o000000?ooooo0:Vmj02Y_NP0J02Y_NP205BCkP80ZKgX0ol000050:Vm
j003o`00002Y_NP0ZKgX01D0ZKgX00@0TF6Foooooooooooo0000<_ooool2o`0001[ooooo902X_^T:
0?:mUP/0V7R]502Y_^P60>_8/@80ZKgX0ol000050:Vmj003o`00002Y_NP0ZKgX01L0ZKgX00?o0000
ooooooooool08oooool0013ooooo00?o00000:Vmj02Y_NP0J`2Y_NP3o`0000T0ZKgX00?o00000:Vm
j02Y_NP03`2Y_NP6095QUP;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooo`00000Goooo
o`80l[F;9@2X_^T80?:mUP80YFV<1P2HN:dJ0:Vnj0<0jlRa0ol000090:Vmj003o`00002Y_NP0ZKgX
01H0ZKgX00?oooooo`000?ooool08oooool0013ooooo00?o0000ooooo`2Y_NP0J02Y_NP3o`000003
0:Vmj01DTnh0ZKgX00X0ZKgX00?o00000:Vmj02Y_NP0302Y_NP9095QUP;ooooo00?o0000oooooooo
ool0;oooool01?l0003oooooooooool0000Fooooo`80l[F;9P2X_^T70?:mUP80YFV<0`2HN:dM0:Vn
j0?o00000P3[b;4;0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o0000ooooooooool08_ooool0013o
oooo00?o0000ooooo`2Y_NP0I@2Y_NP3o`0000@0ZKgX0P1DTnh:0:Vmj003o`00002Y_NP0ZKgX00T0
ZKgX302AHIH2ooooo`03o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`00000Eoooo
o`<0l[F;9@2X_^T70?:mUP80YFV<00<0V7R]0:Vnj02Y_^P06P2Y_^P3o`0000030:Vnj03[b;40jlRa
00<0jlRa2P2Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003o`000?oooooooooo027ooooo000?ooooo`04
o`000?ooooooooooooooof80ZKgX0ol000080:Vmj080E9?^2P2Y_NP00ol00000ZKgX0:Vmj0060:Vm
j0h0TF6F0oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04_ooool50?:eRb@0Z;kY1@3b_IH30:EYS0030?NdOP2Y_^P0ZKkX01L0ZKkX0ol000050:Vn
j0H0jlRa2@2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003ooooool0003ooooo027ooooo000?ooooo`03
o`000?oooooooooo00?oooooGP2Y_NP2o`0000`0ZKgX00<0E9?^0:Vmj02Y_NP02@2Y_NP00ol00000
ZKgX0:Vmj00C095QUPCooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo013ooooo1`3b]H/T0:Rnj@@0l[fF0`2UJH`00`3g]7h0ZKkX0:Vnj00D0:Vnj0?o
0000202Y_^P60>_8/@X0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Pooooo`00
3oooool00ol0003oooooooooo`04oooooeX0ZKgX0ol0000?0:Vmj00305BCkP2Y_NP0ZKgX00T0ZKgX
00?o0000095QUP2AHIH04P2AHIH4ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0?ooooo`P0l[F;902X_^T30?:mUP<0YFV<0P3g]7hB0:Vnj0?o0000
302Y_^P60>_8/@T0ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ol0003oooooooooo`0Oooooo`003ooo
ool00ol0003oooooooooo`05oooooeH0ZKgX0ol0000B0:Vmj080E9?^202Y_NP2095QUP03o`00002A
HIH0TF6F01<0TF6F1?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03_ooool90?:eRb@0Z;kY0P3b_IH30:EYS0@0mkAn3P2Y_^P2o`000100ZKkX1P3[
b;490:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?oooooo`000?ooool07oooool000oooooo00?o0000
ooooooooool01_oooomB0:Vmj0?o00005P2Y_NP305BCkP<0ZKgX1P2AHIH00ol00000TF6F095QUP0B
095QUPGooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00gooooo2P3b]H/T0:Rnj@@0YFV<103g]7h;0:Vnj0?o00004P2Y_^P60>_8/@X0ZKgX00?o0000
0:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Nooooo`003oooool00ol0003oooooooooo`08oooo
odd0ZKgX0ol0000H0:Vmj00408eHS@2:EXd0RUJ=08YFS@X0TF6F00?o0000095QUP2AHIH04@2AHIH5
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<
ooooo`/0l[F;8P2X_^T00`29DhX0YFV<0:EYS0020:EYS0D0mkAn1`2Y_^P3o`0001H0ZKkX1@3[b;40
0`000000ZKgX0:Vmj0080:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o0000ooooooooool07Oooool0
00oooooo00?o0000ooooooooool02?oooom:0:Vmj0?o00005`2Y_NP508eHS@<0RUJ=2`2AHIH00ol0
0000TF6F095QUP0@095QUPKooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00[ooooo3@3b]H/O0:Rnj@<0RE>:102UJH`60?NdOP<0ZKkX0ol0000J0:Vn
j0<0jlRa302Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003ooooool0003ooooo01gooooo000>ooooo`03
o`000?oooooooooo00[oooooAP2Y_NP3o`0001L0ZKgX202=F8d308YFS@/0TF6F00?o0000095QUP2A
HIH0402AHIH7ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`09ooooo`d0l[F;7@2X_^T508UCRP<0YFV<1`3g]7h3o`0001h0ZKkX0P3[b;4=0:Vmj003
o`00002Y_NP0ZKgX01H0ZKgX00?o0000ooooooooool07?ooool000kooooo00?o0000ooooooooool0
3?oooom10:Vmj0?o0000602Y_NP:08eHS@<0RUJ=302AHIH00ol00000TF6F095QUP0@095QUPKooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo
3P3b]H/G0:Rnj@X0RE>:0`2UJH`40?NdOP?o00000P3g]7hP0:Vnj0030>_8/@2Y_NP0ZKgX00`0ZKgX
00?o00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Kooooo`003_ooool00ol0003ooooooooo
o`0<ooooocl0ZKgX0_l0000I0:Vmj0`0SER=0`2:EXd=095QUP03o`00002AHIH0TF6F00l0TF6F1ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01ooo
ool@0?:eRa<0Z;kY3029DhX30:EYS0040?NdO_l0003o0000o`0000H0mkAn7P2Y_^PA0:Vmj003o`00
002Y_NP0ZKgX01D0ZKgX00?oooooo`000?ooool06oooool000kooooo00?o0000ooooooooool03Ooo
oolk0:Vmj0?o00005P2Y_NPA08eHS@<0RUJ=3@2AHIH00ol00000TF6F095QUP0?095QUPSooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo403b
]H/@0:Rnj@l0RE>:00@0YFV<o`000?l0003o00002@3g]7hI0:Vnj1H0ZKgX00?o00000:Vmj02Y_NP0
5P2Y_NP00ol0003oooooooooo`0Jooooo`003_ooool00ol0003oooooooooo`0?ooooocH0ZKgX0ol0
000G0:Vmj1<0SER=0`2:EXd>095QUP03o`00002AHIH0TF6F00d0TF6F00<0Z;o[ooooooooool01_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00oooooo0_l00005oooooa80l[F;2`2X
_^TA08UCRP?o00000P2UJH`;0?NdOQH0ZKkX6@2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`000?oo
oooooooo01Wooooo000>ooooo`03o`000?oooooooooo013ooooo<P2Y_NP3o`0001P0ZKgX5P2=F8d2
08YFS@l0TF6F00?o0000095QUP2AHIH02@2AHIH50:Roj`Sooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo503b]H/70:RnjA40RE>:0_l00002
08UCRP<0YFV<303g]7hB0:Vnj1d0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0H
ooooo`003_ooool00ol0003oooooooooo`0Aooooobh0ZKgX0ol0000G0:Vmj00309j4]`2=F8d0SER=
01L0SER=0`2:EXd?095QUP03o`00002AHIH0TF6F00H0TF6F202X_n/6ooooo`0308U:O_oooooo0000
02Cooooo00?o0000ooooooooool04oooool01?l0003ooooooooooooooolD0?:eR`D0Z;kY4029DhX3
o`0000@0RE>:0`2UJH`=0?NdOPd0ZKkX8@2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`000?oooooo
oooo01Sooooo000=ooooo`03o`000?oooooooooo01?ooooo:P2Y_NP3o`0001L0ZKgX102NQ;LI08eH
S@<0RUJ=3`2AHIH01?l00000TF6F095QUP2AHIH=0:Roj`Cooooo0`29BWh00onY_NSo0000ooooo`0S
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05@3b]H/00`2X_^T0RE>:08UCRP0>
08UCRP?o00001`29DhX30:EYS0h0mkAn2P2Y_^PT0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?ooooo
o`000?ooool06?ooool000gooooo00?o0000ooooooooool05?oooolV0:Vmj0?o00005P2Y_NP809j4
]aT0SER=0`2:EXd@095QUP03o`00002X_n/0Z;o[00h0Z;o[1P29BWh2ojVmj003o`000?oooooooooo
027ooooo00?o0000ooooooooool05Oooool00ol0003ooooo0?:eR`0D0?:eR`h0RE>:0ol0000:08UC
RP<0YFV<3`3g]7h60:Vnj2P0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ooooooo0000ooooo`0Goooo
o`003Oooool00ol0003oooooooooo`0Fooooob80ZKgX0_l0000G0:Vmj0X0WXBg6@2=F8d308YFS@h0
TF6F0`2X_n/00ol00000Z;o[0:Roj`0>0:Roj`D0RDYn0onY_NP00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo01Kooooo00?o00000?:eR`3b]H/04`3b]H/;08UCRP?o00003@29DhX30:EYS100
mkAn00<0ZKkX0:Vmj02Y_NP0:`2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003o`000?oooooooooo01Ko
oooo000=ooooo`03o`000?oooooooooo01Kooooo7`2Y_NP3o`0001L0ZKgX302NQ;LI08eHS@<0RUJ=
2@2AHIH90:Roj`03o`00002X_n/0Z;o[00d0Z;o[1@29BWh3ojVmj003o`000?oooooooooo023ooooo
00?o0000ooooooooool05_oooolF0?:eR`P0RE>:0ol0000@08UCRP<0YFV<403g]7h^0:Vmj003o`00
002Y_NP0ZKgX01D0ZKgX00?oooooo`000?ooool05_ooool000gooooo00?o0000ooooooooool05ooo
oolK0:Vmj0?o00005@2Y_NP?09j4]`030:Vnj02NQ;L0SER=01P0SER=0`2:EXd7095QUP/0Z;o[00?o
00000:Roj`2X_n/03@2X_n/508U:OPCoZKgX00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0GoooooaH0l[F;1@29DhX3o`0001<0RE>:0`2UJH`@0?NdORl0ZKgX00?o00000:Vmj02Y_NP05@2Y
_NP00ooooooo0000ooooo`0Eooooo`003Oooool00ol0003oooooooooo`0HoooooaL0ZKgX0ol0000F
0:Vmj0`0WXBg1P2Y_^P00`2NQ;L0SER=08eHS@0G08eHS@<0RUJ=102AHIH?0:Roj`03o`00002X_n/0
Z;o[00d0Z;o[1029BWh4ojVmj003o`000?oooooooooo01kooooo00?o0000ooooooooool05ooooolE
0?:eR`0300000029DhX0RE>:00?o00005P29DhX20:EYS140mkAn<02Y_NP00ol00000ZKgX0:Vmj00E
0:Vmj003o`000?oooooooooo01Cooooo000=ooooo`03o`000?oooooooooo01[ooooo4P2Y_NP3o`00
01L0ZKgX302NQ;L80:Vnj00309j4]`2=F8d0SER=01L0SER=0`2:EXd2095QUQ80Z;o[00?o00000:Ro
j`2X_n/03@2X_n/408U:OPCoZKgX00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Goooo
oaD0l[F;00<00000o`000?l000006@29DhX20:EYS140mkAn<@2Y_NP00ol00000ZKgX0:Vmj00E0:Vm
j003o`000?oooooooooo01?ooooo000<ooooo`03o`000?oooooooooo01_ooooo3`2Y_NP3o`0001H0
ZKgX3P2NQ;L:0:Vnj00309j4]`2=F8d0SER=01L0SER=0`2:EXd00`3j]gP0Z;o[0:Roj`0B0:Roj`03
o`00002X_n/0Z;o[00`0Z;o[1029BWh5ojVmj003o`000?oooooooooo01cooooo00?o0000oooooooo
ool05ooooolC0?:eR`?o00007029DhX00`2UJH`0mkAn0?NdOP0?0?NdOS40ZKgX00?o00000:Vmj02Y
_NP05@2Y_NP00ooooooo0000ooooo`0Cooooo`003?ooool00ol0003oooooooooo`0Looooo`/0ZKgX
0ol0000G0:Vmj0`0WXBg3P2Y_^P00`2NQ;L0SER=08eHS@0G08eHS@<0RUJ=0`3j]gPB0:Roj`03o`00
002X_n/0Z;o[00d0Z;o[0`29BWh5ojVmj003o`000?oooooooooo01cooooo00?o0000ooooooooool0
5_oooolA0?:eR`?o00000P3b]H/00`000000RE>:08UCRP0J08UCRP030:EYS03g]7h0mkAn00l0mkAn
<P2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003o`000?oooooooooo01;ooooo000<ooooo`03o`000?oo
oooooooo01kooooo1`2Y_NP2o`0001T0ZKgX2P2NQ;LA0:Vnj00309j4]`2=F8d0SER=01L0SER=0`2:
EXd30?ZgN1<0Z;o[00?o00000:Roj`2X_n/03@2X_n/208U:OPKoZKgX00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Fooooo`h0l[F;0ol000050?:eR`0300000029DhX0RE>:01X0RE>:00<0
YFV<0?NdOP3g]7h03`3g]7hc0:Vmj003o`00002Y_NP0ZKgX01@0ZKgX00?oooooo`000?ooool04_oo
ool000cooooo00?o0000ooooooooool07oooool30:Vmj0?o00006`2Y_NP609j4]aD0ZKkX00<0WXBg
08eHS@2=F8d05`2=F8d308YFS@@0n[Mh4`2X_n/00ol00000Z;o[0:Roj`0=0:Roj`0308U:O_nY_NSo
ZKgX00GoZKgX00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`<0YL;^2@3b]H/3
o`0000P0l[F;00<0000008UCRP29DhX06P29DhX00`2UJH`0mkAn0?NdOP0?0?NdOS<0ZKgX00?o0000
0:Vmj02Y_NP05@2Y_NP00ooooooo0000ooooo`0Aooooo`003?ooool00ol0003oooooooooo`0Ooooo
o`?o00007`2Y_NP309j4]aL0ZKkX00<0WXBg08eHS@2=F8d0602=F8d208YFS@D0n[Mh4`2X_n/00ol0
0000Z;o[0:Roj`0<0:Roj`0308U:O_nY_NSoZKgX00GoZKgX00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Aooooo`P0YL;^1P3b]H/3o`0000/0l[F;00<0000008UCRP29DhX06P29DhX00`2U
JH`0mkAn0?NdOP0?0?NdOS@0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ol0003oooooooooo`0@oooo
o`003?ooool00ol0003oooooooooo`0Looooo`?o000000?ooooo0:Vmj02Y_NP07`2Y_NP00`2NQ;L0
ZKkX0:Vnj00G0:Vnj00309j4]`2=F8d0SER=01P0SER=0P2:EXd60?ZgN180Z;o[00?o00000:Roj`2X
_n/03@2X_n/8ojVmj003o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool;0:G2kP80
l[F;0ol0000=0?:eR`030:RojP000000RE>:01/0RE>:00<0YFV<0?NdOP3g]7h03`3g]7he0:Vmj003
o`00002Y_NP0ZKgX01@0ZKgX00?oooooo`000?ooool04?ooool000cooooo00?o0000ooooooooool0
6Oooool3o`0000Kooooo802Y_NPJ0:Vnj1X0SER=0P2:EXd60?ZgN1<0Z;o[00?o00000:Roj`2X_n/0
2`2X_n/:ojVmj003o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool<0:G2kP?o0000
403b]H/00`2X_nX0000008UCRP0K08UCRP030:EYS03g]7h0mkAn00h0mkAn=`2Y_NP00ol00000ZKgX
0:Vmj00D0:Vmj0;o00004?ooool000_ooooo00?o0000ooooooooool05oooool3o`0000[ooooo802Y
_NPI0:Vnj1X0SER=0P2:EXd70?ZgN1<0Z;o[00?o00000:Roj`2X_n/01@2X_n/?ojVmj003o`000?oo
oooooooo01Oooooo00?o0000ooooooooool02oooool;0:G2kP?o0000102U`^h?0?:eR`030:RojP00
0000RE>:01/0RE>:00<0YFV<0?NdOP3g]7h03P3g]7hg0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?o
0000ooooooooool03_ooool000_ooooo00?o0000ooooooooool05?ooool3o`0000kooooo802Y_NP0
0`001HH0ZKkX0:Vnj00E0:Vnj1X0SER=0P2:EXd80?ZgN1<0Z;o[00?o00000:Roj`2X_n/00P2X_n/A
ojVmj003o`000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool<0:G2kP;o0000202U`^h>
0?:eR`030:RojP000000RE>:01/0RE>:00<0YFV<0?NdOP3g]7h03P3g]7hh0:Vmj003o`00002Y_NP0
ZKgX01<0ZKgX00?oooooo`000?ooool03oooool000_ooooo00?o0000ooooooooool04Oooool3o`00
01;ooooo802Y_NPG0:Vnj1X0SER=0P2:EXd90?ZgN180Z;o[00?o0000ojVmj?nY_NP03_nY_NP5oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool=0:G2kP?o00002`2U`^h=0?:e
R`030:RojP000000RE>:01/0RE>:00<0YFV<0?NdOP3g]7h03P3g]7hi0:Vmj003o`00002Y_NP0ZKgX
00d0ZKgX1_ooool00ol0003oooooooooo`0>ooooo`002oooool00ol0003oooooooooo`0?ooooo`;o
00005_oooolP0:Vmj1H0ZKkX6P2=F8d208YFS@T0n[Mh402X_n/3ojVmj003o`000?nY_NSoZKgX00_o
ZKgX2?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo302U`^h3o`0000l0
YL;^303b]H/00`2X_nX0RE>:08UCRP0K08UCRP030:EYS03g]7h0mkAn00h0mkAn>P2Y_NP00ol00000
ZKgX0:Vmj00:0:Vmj0Sooooo00?o0000ooooooooool03_ooool000_ooooo00?o0000ooooooooool0
3?ooool3o`0001Wooooo802Y_NPE0:Vnj1X0SER=0P2:EXd:0?ZgN0d0Z;o[1_nY_NP00ol0003oZKgX
ojVmj005ojVmj0gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0<0:G2kP?o0000
4`2U`^h:0?:eR`80Z;oZ7@29DhXA0?NdOSX0ZKgX00?o00000:Vmj02Y_NP01P2Y_NP=ooooo`03o`00
0?oooooooooo00gooooo000;ooooo`03o`000?oooooooooo00Wooooo0ol0000Mooooob00ZKgX502Y
_^P00`2NQ;L0SER=08eHS@0G08eHS@80RUJ=2`3j]gP70:Roj`?omL:H2?nY_NP00ol0003oZKgXojVm
j003ojVmj0oooooo00?o0000ooooooooool05Oooool00ol00000YL;^0:G2kP090:G2kP?o00005`2U
`^h90?:eR`80Z;oZ7@29DhXA0?NdOS/0ZKgX00?o00000:Vmj02Y_NP00P2Y_NP@ooooo`03o`000?oo
oooooooo00gooooo000;ooooo`03o`000?oooooooooo00Kooooo0ol0000Roooooal0ZKgX4`2Y_^P0
0`2NQ;L0SER=08eHS@0G08eHS@0308YFS@3j]gP0n[Mh00/0n[Mh102X_n/5ooG2V0WoZKgX00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?ooool0YL;^00H0YL;^0ol0000K
0:G2kPP0l[F;0P2X_nXM08UCRQ40mkAn?02Y_NP00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00gooooo000:ooooo`03o`000?oooooooooo00Cooooo0ol0000Voooooal0ZKgX00<000F60:Vn
j02Y_^P03`2Y_^P00`2NQ;L0SER=08eHS@0G08eHS@0308YFS@3j]gP0n[Mh00/0n[Mh0onY_^T7ooG2
V0OoZKgX0_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00`2U`^h3o`0001l0YL;^1`3b]H/20:RojQd0RE>:4@3g]7hj0:Vmj0;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0=ooooo`002_ooool01?l0003oooooooooooooool3o`00
02Wooooo802Y_NP>0:Vnj0?oYjKE00<0WXBg08eHS@2=F8d05`2=F8d00`2:EXd0n[Mh0?ZgN00;0?Zg
N0CoZKkY1ooe`YP00onY_NSoooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05?ooool01?l0003oooooooooooooool3o`0002<0YL;^1P3b]H/20:RojQd0RE>:4@3g]7hf
0:Vmj0Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`002_ooool4o`00
02gooooo802Y_NP90:Vnj0OoYjKE00<0WXBg08eHS@2=F8d05`2=F8d00`2:EXd0n[Mh0?ZgN00;0?Zg
N0CoZKkY1ooe`YP9ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool4o`00
00;ooooo9P2U`^h40?:eR`80Z;oZ7029DhX20:G3ka00mkAn<@2Y_NP=ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03Oooool000[ooooo0_l0000`oooooah0ZKgX0_nY_NP60:Vnj0Oo
YjKE0_nY_^P00`2NQ;L0SER=08eHS@0G08eHS@0308YFS@3j]gP0n[Mh00/0n[Mh1OnY_^T6ooG2V0[o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`;o00001_oooolU0:G2kP<0
l[F;0P2X_nXI08UCRPD0YL?_403g]7h_0:Vmj13ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`003?ooool00ol0003oooooooooo`0_oooooaP0ZKgX1_nY_NP00ol01HH0ZKkX
ojNVe@06ojNVe@KoZKkX00<0WXBg08eHS@2=F8d0602=F8d=0?ZgN0KoZKkY1Ooe`YP;ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooobD0YL;^
00@0l[F;0:RojP2X_nX0Z;oZ5029DhX;0:G3k`l0mkAn:`2Y_NPDooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool000gooooo00?o0000ooooooooool0;ooooolE0:Vmj0WoZKgX
1_nWY]D8ojVnj00309j4]`2=F8d0SER=01P0SER=3@3j]gP7ojVnj@ComL:H3?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?oooolU0:G2kP80Z;oZ
00?ooooo08UCRP29DhX04029DhX?0:G3k`d0mkAn:@2Y_NPGooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0;oooool@0:Vmj0koZKgX00?o
YjKEojVnj?nY_^P02_nY_^P00`2NQ;L0SER=08eHS@0H08eHS@d0n[Mh2?nY_^T3ooG2V0cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo8`2U
`^h4oooooa00RE>:4@2U`nl=0?NdORD0ZKgX7?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00cooooo000?ooooo`;o0000<?ooool=0:Vmj17oZKgX3?nY_^P00`2NQ;L0SER=08eHS@0H
08eHS@d0n[Mh2OnY_^T00ooe`YSoooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool06?ooool2o`0000Kooooo7`2U`^h6ooooo`/0RE>:5`2U`nl<0?NdOR<0ZKgX7_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo000Aooooo`03o`000?oooooooooo
02oooooo202Y_NPFojVmj0[oZKkX00<0WXBg08eHS@2=F8d0602=F8d=0?ZgN0WoZKkY00?omL:Hoooo
ooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool00ooooolJ0:G2kP_ooooo2@29DhXJ0:G3k`/0mkAn7P2Y_NPTooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool001;ooooo00?o0000ooooooooool0;_ooool40:Vmj1_o
ZKgX2OnY_^P00`2NQ;L0SER=08eHS@0H08eHS@d0n[Mh2_nY_^T@ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03oooooaL0YL;^3Oooool608UCRQl0
YL?_2@3g]7hJ0:Vmj2Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`00
4oooool00ol0003oooooooooo`0^ooooo`030:Vmj?nY_NSoZKgX01_oZKgX00?o[c40ojVnj?nY_^P0
1onY_^PJ08eHS@d0n[Mh1onY_^TCooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`04oooooa<0YL;^3oooool208UCRR<0YL?_203g]7hI0:Vmj2cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`005?ooool00ol0003ooooooooo
o`0^oooooakoZKgX2OnY_^PI08eHS@80YL?_303j]gP2ojVnjAWooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Looooo`;o00001_ooool<0:G2kQKooooo902U`nl70?NdOQD0ZKgX<?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo000Eooooo`;o0000;ooooolN
ojVmj0SoZKkX5`2=F8d50:G3k`/0n[Mh7?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01?ooool90:G2kQSooooo9@2U`nl60?NdOQ40ZKgX=Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo000Gooooo`03o`000?oooooooooo
02gooooo7_nY_NP7ojVnj180SER=2`2U`nl90?ZgN1kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo102U`^hMooooobH0YL?_103g]7h?0:Vm
j3Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`006?ooool00ol0003o
ooooooooo`0^oooooagoZKgX1_nY_^P@08eHS@h0YL?_203j]gPNooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`030:G2k_oooooooooo01oo
oooo902U`nl40?NdOP/0ZKgX?Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_o
oooo000Iooooo`03o`000?oooooooooo02kooooo7OnY_NP5ojVnj0/0SER=502U`nl70?ZgN1oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`;o00009ooooolT0:G3k`<0mkAn
1`2Y_NQ1ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool001[ooooo0_l0
000_oooooagoZKgX1?nY_^P808eHSAL0YL?_1`3j]gPPooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0Uooooob@0YL?_0P3g]7h50:Vmj4Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`0]
oooooagoZKgX0onY_^P608eHSAX0YL?_1P3j]gPQooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0UooooobD0YL?_0P2Y_NQ8ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02oooool001gooooo00?o0000ooooooooool0;OoooolJojVm
j0?ooooo0_nY_^P00`2=F8d0YL?_0:G3k`0N0:G3k`D0n[Mh8Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09OoooolS0:G3kd_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0;ooooo`007_ooool00ol0003oooooooooo`0]oooooaGo
ZKgX2?ooool2ojVnj240YL?_103j]gPRooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Voooooah0YL?_Coooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00_ooooo000Oooooo`03o`000?oooooooooo02gooooo4_nY_NP<ooooob40YL?_
103j]gPSooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09_ooool2o`0002Kooooo
6P2U`nmDooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool0023ooooo0_l0
000_ooooo`coZKgX4OoooolQ0:G3k`<0n[Mh8oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool09?oooolF0:G3keSooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`0]ooooo`OoZKgX5ooooolP
0:G3k`80n[Mh9?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool09?oooolA0:G3kecooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`008oooool00ol0003oooooooooo`0]ooooo`?oZKgX6ooooolP0:G3k`030?ZgN?oooooooooo
02?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
02Gooooo3@2U`nmOooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool002Co
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Looooob00YL?_9_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02[ooooo0_l0000Vooooo`T0YL?_Hoooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo000Uooooo`;o0000;?ooool00ol0003ooooo
ooooo`0Moooooah0YL?_9oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool08oooool50:G3k`;ooooo00?o0000ooooooooool0Hoooool01Ol0003ooooo
oooooooooooo000000cooooo000Wooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
7OoooolL0:G3kb[ooooo00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooooooo02?o
oooo0P2U`nl4ooooo`03o`000?oooooooooo06?ooooo00Go0000ooooooooooooooooo`00000<oooo
o`00:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01kooooo5P2U`nl`ooooo`04
o`000?ooooooooooo`00033ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Toooo
o`04o`000?ooooooooooo`0000cooooo000Yooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool08?oooolB0:G3kc?ooooo00?o0000ooooool00000<Oooool2o`0002Sooooo00?o0000oooo
ooooool0IOooool00ol0003oooooo`00000<ooooo`00:_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo027ooooo302U`nlhooooo`03o`000?oooooo000003?ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0000_ooooo000[ooooo`;o
00009_ooool00ol0003oooooooooo`0Rooooo`T0YL?_>oooool00ol0003oooooo`00000cooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00000;ooooo`00
;Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo0`2U`nm1ooooo`;o0000
=?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Oooooo0_l0000;ooooo`00;_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06Kooooo0ol0000eooooo`;o00008ooo
ool00ol0003oooooooooo`1Vooooo`?o00002oooool002oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`1Sooooo`Co0000>_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo06;ooooo1?l0000>ooooo`00<?ooool2o`00023ooooo00?o0000ooooooooool0H?ooool3o`00
03oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Oooooo`?o00004_ooool003;o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Looooo`Co0000@oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo05_ooooo1?l0000Eooooo`00<oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo05Sooooo1?l00018ooooo`;o00007_ooool00ol0003ooooo
ooooo`1Gooooo`Co00006Oooool003Cooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`1Dooooo`Co0000C_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Cooooo0ol0
000Mooooo`00=Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo0ol0001C
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0D?ooool4o`00023ooooo000foooo
o`;o00006_ooool00ol0003oooooooooo`1=ooooo`Co0000Eoooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo04cooooo1?l0000Tooooo`00>?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo04Wooooo1?l0001Looooo`;o00006Oooool00ol0003oooooooooo`18ooooo`Co
0000:?ooool003Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`Co0000
H_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Gooooo0ol0000/ooooo`00>_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04;ooooo0ol0001Wooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0@Oooool4o`0002oooooo000kooooo`;o00005Oooool0
0ol0003oooooooooo`0nooooo`Co0000Joooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo03kooooo1?l0000cooooo`00?Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
03[ooooo1?l0001`ooooo`;o00004oooool00ol0003oooooooooo`0jooooo`Co0000=oooool003ko
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0fooooo`Co0000M_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03Oooooo0ol0000kooooo`00?oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03;ooooo1?l0001kooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<oooool4o`0003kooooo0010ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0;oooool3o`00083ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0_ooooo`Co0000@_ooool0047ooooo0_l0000?ooooo`03o`000?oooooooooo02_ooooo1?l00024
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool3o`0004Kooooo0013oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool09oooool4o`0008Wooooo0_l0000=oooo
o`03o`000?oooooooooo02Sooooo1?l00019ooooo`00A?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02?ooooo1?l0002?ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool09?ooool4o`0004gooooo0015ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
8?ooool3o`0009Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`Co0000
DOooool004Kooooo0_l00009ooooo`03o`000?oooooooooo01gooooo1?l0002Hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07Oooool3o`0005Gooooo0018ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool06Oooool4o`0009gooooo0_l00008ooooo`03o`000?oooooo
oooo01Wooooo1?l0001Hooooo`00BOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Gooooo1?l0002Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool4o`00
05cooooo001:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool3o`000:So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`Co0000H?ooool004_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000[?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00kooooo0ol0001Tooooo`00C?ooool2o`0000?ooooo00?o
0000ooooooooool02_ooool4o`000;7ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0
001Wooooo`00C_ooool01?l0003oooooooooool00008ooooo`Co0000]oooool01?l0003ooooooooo
ool00008ooooo`Co0000Joooool004oooooo00?o0000ooooool000001Oooool3o`000;cooooo00?o
0000ooooool000001Oooool3o`0006oooooo001@ooooo`;o000000?oooooo`000?l000000_l00030
ooooo`;o000000?oooooo`000?l000000_l0001booooo`00DOooool2o`000<Gooooo0_l0001foooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {153.5, 0}} -> {-0.0542361, -0.0193168, \
0.0052844, 0.0052844}, {{10.25, 190.438}, {149.812, 3.625}} -> {-0.0541935, \
0.0451583, 0.00528671, 0.00528671}, {{208.5, 388.688}, {149.812, 3.625}} -> \
{-1.10228, 0.0451583, 0.00528671, 0.00528671}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gdnoFrame\  = \ 
        Show[gd, \ Frame \[Rule] False, \ nS];\)\), "\[IndentingNewLine]", 
    \(\(gclass\  = \ 
        DrawHistogramClass[{h1, h2}, \ {class1Color, class2Color}, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gdnoFrame, gclass}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.76921 .64295 Mdot
.56704 .69013 Mdot
.75295 .59186 Mdot
.68704 .57554 Mdot
.7077 .64248 Mdot
.72536 .69368 Mdot
.56743 .81534 Mdot
.6185 .66989 Mdot
.7966 .59181 Mdot
.91874 .53216 Mdot
.63443 .74925 Mdot
.67714 .58782 Mdot
.68619 .65385 Mdot
.63347 .67867 Mdot
.78301 .68453 Mdot
.431 .75982 Mdot
.83512 .58625 Mdot
.62213 .69227 Mdot
.65099 .52892 Mdot
.68982 .60815 Mdot
.62373 .60539 Mdot
.70365 .5862 Mdot
.46149 .7704 Mdot
.96423 .55213 Mdot
.58757 .75816 Mdot
.66269 .50089 Mdot
.77416 .67256 Mdot
.64296 .68883 Mdot
.68658 .64317 Mdot
.6796 .62759 Mdot
.59038 .7189 Mdot
.93142 .57169 Mdot
.43749 .63803 Mdot
.69974 .72659 Mdot
.69326 .67323 Mdot
.77793 .6757 Mdot
.78924 .5041 Mdot
.4401 .83425 Mdot
.58603 .51263 Mdot
.78866 .65554 Mdot
.44366 .65311 Mdot
.727 .70103 Mdot
.62042 .75592 Mdot
.80902 .64126 Mdot
.51964 .63381 Mdot
.6647 .635 Mdot
.51329 .73266 Mdot
.65075 .59886 Mdot
.47075 .68029 Mdot
.56864 .73715 Mdot
.80079 .49161 Mdot
.67625 .72883 Mdot
.65021 .77721 Mdot
.97719 .52753 Mdot
.73793 .59678 Mdot
.73021 .58639 Mdot
.56985 .75537 Mdot
.73744 .60898 Mdot
.6851 .61125 Mdot
.61857 .83447 Mdot
.62482 .71998 Mdot
.79441 .52571 Mdot
.50075 .76869 Mdot
.51028 .57576 Mdot
.75974 .68296 Mdot
.40991 .62938 Mdot
.70963 .69078 Mdot
.59779 .56609 Mdot
.65813 .63733 Mdot
.5929 .59807 Mdot
.94806 .4805 Mdot
.49059 .76358 Mdot
.5947 .59351 Mdot
.26742 .80621 Mdot
.55099 .89452 Mdot
.67095 .62172 Mdot
.72009 .64925 Mdot
.65949 .66589 Mdot
.85005 .50774 Mdot
.53748 .70428 Mdot
.83179 .61265 Mdot
.72058 .50966 Mdot
.83562 .62877 Mdot
.59405 .70406 Mdot
.56972 .71403 Mdot
.69442 .59167 Mdot
.71954 .64562 Mdot
.71914 .61218 Mdot
.65898 .61832 Mdot
.73796 .61888 Mdot
.6014 .78205 Mdot
.79683 .55767 Mdot
.62126 .66387 Mdot
.77326 .50924 Mdot
.8496 .62908 Mdot
.51148 .73852 Mdot
.63201 .75524 Mdot
.60299 .71066 Mdot
.63009 .7393 Mdot
.59565 .71558 Mdot
0 0 1 r
.1162 .19077 Mdot
.24801 .25894 Mdot
.30902 .37049 Mdot
.18551 .28447 Mdot
.21993 .14635 Mdot
.02549 .16303 Mdot
.08225 .09379 Mdot
.37208 .31797 Mdot
.21305 .25985 Mdot
.22133 .20287 Mdot
.39469 .36398 Mdot
.10113 .29615 Mdot
.20089 .20862 Mdot
.51363 .42542 Mdot
.1511 .2407 Mdot
.23301 .18202 Mdot
.16033 .11693 Mdot
.2447 .32645 Mdot
.5096 .43276 Mdot
.25586 .29169 Mdot
.20055 .12342 Mdot
.24726 .24881 Mdot
.19842 .19721 Mdot
.26062 .2788 Mdot
.29485 .27788 Mdot
.28462 .29833 Mdot
.13895 .13094 Mdot
.064 .19115 Mdot
.49848 .34485 Mdot
.2812 .30219 Mdot
.50266 .28702 Mdot
.26402 .2562 Mdot
.28044 .30149 Mdot
.24434 .25201 Mdot
.39987 .44812 Mdot
.46729 .35465 Mdot
.33173 .26109 Mdot
.21507 .22824 Mdot
.36508 .28363 Mdot
.09954 .2719 Mdot
.38085 .3301 Mdot
.04621 .21355 Mdot
.30535 .23911 Mdot
.49027 .39152 Mdot
.23274 .29061 Mdot
.43262 .23807 Mdot
.25424 .1969 Mdot
.29699 .25132 Mdot
.2794 .24928 Mdot
.22965 .26337 Mdot
.41048 .29125 Mdot
.33432 .28509 Mdot
.31801 .25888 Mdot
.14785 .18068 Mdot
.53255 .43691 Mdot
.11549 .17091 Mdot
.27123 .17228 Mdot
.17499 .14652 Mdot
.35782 .30983 Mdot
.28877 .2093 Mdot
.30443 .31716 Mdot
.14287 .20794 Mdot
.27211 .34369 Mdot
.18753 .21951 Mdot
.18918 .27159 Mdot
.4538 .31739 Mdot
.22019 .29944 Mdot
.16333 .23401 Mdot
.04671 .13445 Mdot
.25109 .1515 Mdot
.11931 .18207 Mdot
.35414 .28788 Mdot
.20382 .26025 Mdot
.3703 .36834 Mdot
.48294 .35325 Mdot
.27007 .2202 Mdot
.29123 .27611 Mdot
.04322 .15197 Mdot
.1047 .11027 Mdot
.26397 .25715 Mdot
.2582 .25228 Mdot
.10358 .19648 Mdot
.41186 .28622 Mdot
.34047 .33201 Mdot
.07782 .20346 Mdot
.45474 .34458 Mdot
.01792 .17003 Mdot
.29718 .34707 Mdot
.05681 .20874 Mdot
.19923 .12606 Mdot
.26693 .23785 Mdot
.23707 .14248 Mdot
.2935 .26349 Mdot
.23856 .28659 Mdot
.37127 .31719 Mdot
.36967 .41544 Mdot
.09343 .12923 Mdot
.27573 .28996 Mdot
.40644 .40736 Mdot
.40734 .32038 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.0238095 0.0186741 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
153 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00e?oooomH
o`00oeGoo`003oooool00=CoooooF?l00?mEool000oooooo003DoooooeSo003oEOoo000?ooooo`00
e?oooomHo`00oeGoo`003oooool00=CoooooF?l00?mEool000oooooo003DoooooeSo003oEOoo000?
ooooo`00e?oooomHo`00oeGoo`003oooool00=CoooooF?l00?mEool000oooooo003DoooooeSo003o
EOoo000?ooooo`00e?oooomHo`00oeGoo`003oooool00=CoooooF?l00?mEool000oooooo000Goooo
o`?o003o^_oooomHo`00oeGoo`003oooool001Oooooo0ol00?njoooooeSo003oEOoo000?ooooo`00
5oooool3o`00ok[oooooF?l00?mEool000oooooo000Kooooo`?o003o]_oooomHo`00oeGoo`003ooo
ool001_ooooo0ol00?l7ooooo`?o003o[?oooomHo`00oeGoo`003oooool001_ooooo0ol00?l7oooo
o`?o003o1?ooool3o`00ojGoooooF?l00?mEool000oooooo000Iooooo`?o003o1Oooool3o`00o`04
ooooool00?oo003oo`00o`Cooooo0ol00?nUoooooeSo003oEOoo000?ooooo`004Oooool3o`00o`Go
oooo0ol00?l5ooooo`?o003o2?ooool3o`00ojGoooooF?l00?mEool000oooooo000Aooooo`?o003o
1Oooool3o`00o`Gooooo0ol00?l8ooooo`?o003oYOoooomHo`00oeGoo`003oooool0017ooooo0ol0
0?lDooooo`?o003o1Oooool6o`00oikoooooF?l00?mEool000oooooo000@ooooo`?o003o5Oooool3
o`00o`Gooooo2Ol00?nKoooooeSo003oEOoo000?ooooo`004?ooool3o`00oaGooooo0ol00?l5oooo
o`Wo003oVooooomHo`00oeGoo`003oooool000gooooo1_l00?lSooooo`?o003oVooooomHo`00oeGo
o`003oooool000gooooo0ol00?o4oooooeSo003oEOoo000?ooooo`003?ooool4o`00o`gooooo0ol0
0?lIooooo`?o003oV?oooomHo`00oeGoo`003oooool000cooooo0ol00?l>ooooo`?o003o0oooool3
o`00oa?ooooo0ol00?nHoooooeSo003oEOoo000?ooooo`003?ooool3o`00o`kooooo1?l00?l2oooo
o`?o003o3?ooool3o`00o`Cooooo0ol00?nHoooooeSo003oEOoo000?ooooo`005?ooool3o`00o`Ko
oooo1?l00?l2ooooo`?o003o3?ooool3o`00oiooooooF?l00?mEool000oooooo000Dooooo`?o003o
1?ooool6o`00o`_ooooo0ol00?l3ooooo`?o003o00Coooooo`00ool00?oo003oVooooomHo`00oeGo
o`003oooool001Cooooo0ol00?l4ooooo`Go003o3?ooool3o`00o`04ooooool00?oo003oo`00o`?o
oooo0ol00?nKoooooeSo003oEOoo000?ooooo`005_ooool3o`00o`;ooooo0ol00?l4ooooo`?o003o
1oooool3o`00o`04ooooool00?oo003oo`00o`?ooooo0ol00?nKoooooeSo003oEOoo000?ooooo`00
4Oooool8o`00o`Wooooo0ol00?l8ooooo`Ko003o2Oooool3o`00oiGoooooF?l00?mEool000oooooo
000Aooooo`So003o2Oooool3o`00o`Gooooo1_l00?l<ooooo`?o003oUOoooomHo`00oeGoo`003ooo
ool0017ooooo1Ol00?lDooooo`Ko003o2Oooool6o`00oiGoooooF?l00?mEool000oooooo000Zoooo
o`?o003o0_ooool3o`00o`Oooooo0ol00?nHoooooeSo003oEOoo000?ooooo`009_ooool3o`00o`Ko
oooo0ol00?l7ooooo`?o003oV?oooomHo`00oeGoo`003oooool002Cooooo1Ol00?l6ooooo`?o003o
1_ooool3o`00o`Cooooo0ol00?lDooooo`?o003oNooooomHo`00oeGoo`003oooool002Cooooo1Ol0
0?l?ooooo`?o003o1?ooool3o`00oaCooooo0ol00?mkoooooeSo003oEOoo000?ooooo`009?ooool3
o`00o`gooooo3_l00?lDooooo`?o003oNooooomHo`00oeGoo`003oooool003Cooooo3Ol00?nCoooo
oeSo003oEOoo000?ooooo`00;OoooolDo`00o`03ooooool00?oo003o00?o003oSOoooomHo`00oeGo
o`003oooool002gooooo3_l00?l2ooooo`?o003o0_ooool5o`00ohgoooooF?l00?mEool000oooooo
000Jooooo`?o003o3Oooool>o`00o`Gooooo0ol00?l2ooooo`Go003oSOoooon1o`00obcoo`003ooo
ool001[ooooo0ol00?l=ooooo`?o003o2_ooool3o`00o`?ooooo0ol00?nDoooooh7o003o;?oo000?
ooooo`006_ooool3o`00o`gooooo0ol00?l:ooooo`?o003o0oooool3o`00o`Gooooo0ol00?l2oooo
o`?o003oQooooon1o`00obcoo`003oooool002[ooooo0ol00?l5ooooo`ko003o1Oooool8o`00o`Go
oooo1?l00?l=ooooo`?o003oK_oooon1o`00obcoo`003oooool001_ooooo0ol00?l<ooooo`?o003o
1Oooool7o`00o`04ooooool00?oo003oo`00o`Sooooo2?l00?l5ooooo`Co003o3Oooool3o`00ofko
ooooPOl00?l/ool000oooooo000Kooooo`?o003o4_ooool9o`00o`03ooooool00?oo003o00?o003o
2Oooool3o`00o`Oooooo1?l00?l=ooooo`?o003oK_oooon1o`00obcoo`003oooool001_ooooo0ol0
0?lBooooo`?o003o2?ooool4o`00oiGoooooPOl00?l/ool000oooooo000`ooooo`?o003o2?ooool4
o`00o`[ooooo0ol00?n8oooooh7o003o;?oo000?ooooo`00?oooool3o`00o`Oooooo1Ol00?l<oooo
o`?o003oMooooon1o`00obcoo`003oooool003oooooo0ol00?l7ooooo`Go003o1?ooool3o`00o`Go
oooo0ol00?mgoooooh7o003o;?oo000?ooooo`00=?ooool3o`00o`Sooooo0ol00?l9ooooo`Go003o
0_ooool3o`00o`Gooooo0ol00?mgoooooh7o003o;?oo000?ooooo`00=?ooool3o`00o`oooooo0ol0
0?l4ooooo`?o003o0_ooool3o`00ogooooooPOl00?l/ool000oooooo000dooooo`?o003o3oooool3
o`00o`Cooooo0ol00?n4oooooh7o003o;?oo000?ooooo`00>Oooool3o`00o`;ooooo0ol00?l5oooo
o`?o003o4Oooool3o`00o`Gooooo0ol00?m_oooooh7o003o;?oo000?ooooo`00>Oooool3o`00o`;o
oooo0ol00?lIooooo`?o003o1Oooool3o`00ofooooooPOl00?l/ool000oooooo000iooooo`?o003o
0_ooool3o`00oaWooooo2ol00?m_oooooh7o003o;?oo000?ooooo`00GOooool5o`00og;oooooPOl0
0?l/ool000oooooo001;ooooo`?o003o0_ooool3o`00o`[ooooo1Ol00?mboooooh7o003o;?oo000?
ooooo`00@?ooool3o`00o`Sooooo0ol00?l2ooooo`?o003oPOoooon1o`00obcoo`003oooool0043o
oooo0ol00?l8ooooo`?o003o0_ooool3o`00oh7oooooPOl00?l/ool000oooooo0010ooooo`?o003o
TOoooon1o`00obcoo`003oooool0067ooooo0ol00?m`oooooh7o003o;?oo000?ooooo`00HOooool3
o`00og3oooooPOl00?l/ool000oooooo001Qooooo`?o003oL?oooon1o`00obcoo`003oooool005;o
oooo0ol00?mooooooh7o003o;?oo000?ooooo`00D_ooool3o`00ogooooooPOl00?l/ool000oooooo
001;ooooo`?o003o1?ooool3o`00ogooooooPOl00?l/ool000oooooo001;ooooo`?o003oQ_oooon1
o`00obcoo`003oooool004_ooooo0ol00?lGooooo`?o003oK?oooon1o`00obcoo`003oooool006Co
oooo1?l00?m/oooooh7o003o;?oo000?ooooo`00I?ooool7o`00ofWoooooPOl00?l/ool000oooooo
001Tooooo`?o003o00Coooooo`00ool00?oo003oJOoooon1o`00obcoo`003oooool0053ooooo0ol0
0?lEooooo`?o003oJOoooon1o`00obcoo`003oooool0053ooooo0ol00?n1oooooh7o003o;?oo000?
ooooo`00D?ooool3o`00oh7oooooPOl00?l/ool000oooooo003Doooooh7o003o;?oo000?ooooo`00
e?oooon1o`00obcoo`003oooool00=CoooooPOl00?l/ool000oooooo002cooooo`?oo`007_oooon1
o`00obcoo`003oooool00;?ooooo0ooo000Noooooh7o003o;?oo000?ooooo`00VOooool3ool001Oo
oooo0ooo000Noooooh7o003o;?oo000?ooooo`00P?ooool3ool001Kooooo0ooo000hoooooh7o003o
;?oo000?ooooo`00P?ooool3ool001Cooooo1Ooo0006ooooo`?oo`00;ooooon1o`00obcoo`003ooo
ool007;ooooo0ooo000;ooooo`?oo`001oooool3ool000Oooooo1_oo0008ooooo`?oo`00;ooooon1
o`00obcoo`003oooool007;ooooo0ooo000Eooooo`?oo`001oooool6ool000Sooooo0ooo000_oooo
ojgoo`003oooool007;ooooo0ooo000Eooooo`?oo`001oooool3ool003gooooo[Ooo000?ooooo`00
O_ooool3ool001Oooooo0ooo000Nooooo`?oo`006?oooon]ool000oooooo001nooooo`?oo`005ooo
ool3ool001?ooooo0ooo0008ooooo`?oo`006?oooon]ool000oooooo001nooooo`?oo`005oooool3
ool001?ooooo0ooo0008ooooo`?oo`006?oooon]ool000oooooo002^ooooo`?oo`008ooooon]ool0
00oooooo002fooooo`?oo`006ooooon]ool000oooooo002Hooooo`?oo`006oooool3ool001_ooooo
[Ooo000?ooooo`00V?ooool3ool001_ooooo0ooo000Kooooojgoo`003oooool007Cooooo0ooo000Q
ooooo`?oo`00>Ooooon]ool000oooooo001dooooo`?oo`00>Oooool3ool0027ooooo[Ooo000?oooo
o`00I?ooool3ool000gooooo0ooo000=ooooo`?oo`00:Oooool3ool0027ooooo[Ooo000?ooooo`00
I?ooool3ool001gooooo0ooo000Yooooo`?oo`008Ooooon]ool000oooooo001Tooooo`?oo`006ooo
ool8ool000;ooooo0ooo000@ooooo`?oo`00<_oooon]ool000oooooo001dooooo`?oo`002oooool3
ool00003oooooooo003oo`0000;oo`000_ooool3ool00004oooooooo003oo`00ool000Gooooo0ooo
0004ooooo`?oo`00<_oooon]ool000oooooo001cooooo`Coo`001oooool3ool00005oooooooo003o
o`00ool00?ooool01?oo0002ooooo`Ooo`001Oooool3ool000Cooooo0ooo000booooojgoo`003ooo
ool007?ooooo1?oo0002ooooo`?oo`000_ooool3ool000Gooooo0ooo0004ooooo`Koo`001Oooool3
ool003Wooooo[Ooo000?ooooo`00Loooool3ool000?ooooo0ooo0002ooooo`?oo`000oooool4ool0
00;ooooo1_oo000>ooooo`?oo`00<ooooon]ool000oooooo001iooooo`?oo`000oooool3ool000;o
oooo1?oo0002ooooo`Koo`003_ooool3ool003?ooooo[Ooo000?ooooo`00Ooooool9ool000;ooooo
1_oo000>ooooo`?oo`00<ooooon]ool000oooooo001Booooo`?oo`00:_ooool7ool000Oooooo0ooo
000?ooooo`Koo`00;ooooon]ool000oooooo001Booooo`?oo`004Oooool3ool001Oooooo1_oo0007
ooooo`?oo`003oooool6ool002oooooo[Ooo000?ooooo`00D_ooool3ool000;ooooo0ooo000<oooo
o`?oo`005_ooool7ool001Wooooo1_oo000_ooooojgoo`003oooool005Oooooo0ooo000<ooooo`?o
o`005_ooool4ool00005oooooooo003oo`00ool00?ooool01Ooo0006ooooo`?oo`001?ooool3ool0
03Oooooo[Ooo000?ooooo`00Eoooool3ool002Gooooo0ooo0002ooooo`?oo`0000?oooooool00?oo
00000ooo0006ooooo`?oo`001?ooool3ool003Oooooo[Ooo000?ooooo`00F?ooool3ool002Wooooo
0ooo00000oooooooo`00ool00003ool000Kooooo0ooo00000oooooooo`00ool00004ool003Oooooo
[Ooo000?ooooo`00F?ooool3ool002Wooooo0ooo0003ooooo`?oo`002_ooool3ool003[ooooo[Ooo
000?ooooo`00F?ooool3ool001gooooo0ooo0004ooooo`?oo`000_ooool3ool0013ooooo0ooo000j
ooooojgoo`003oooool007Sooooo0ooo0004ooooo`?oo`000oooool3ool000cooooo0ooo000moooo
ojgoo`003oooool007Sooooo1_oo00001?ooooooo`00ool00?oo0003ooooo`?oo`003?ooool4ool0
03cooooo[Ooo000?ooooo`00GOooool3ool001Sooooo1_oo0007ooooo`?oo`002Oooool8ool003_o
oooo[Ooo000?ooooo`00GOooool3ool000oooooo0ooo0009ooooo`Coo`002Oooool3ool000Kooooo
0ooo00000oooooooo`00ool00002ool003_ooooo[Ooo000?ooooo`00GOooool3ool000oooooo0ooo
0007ooooo`Koo`002Oooool6ool000?ooooo0ooo0002ooooo`?oo`00>ooooon]ool000oooooo001_
ooooo`?oo`001oooool6ool000Wooooo1_oo0016ooooojgoo`003oooool006Wooooo0ooo0007oooo
o`?oo`000oooool3ool000oooooo0ooo0016ooooojgoo`003oooool006Wooooo0ooo0007ooooo`Go
o`004oooool3ool004Kooooo[Ooo000?ooooo`00JOooool3ool000?ooooo0ooo00000oooooooo`00
ool00003ool005cooooo[Ooo000?ooooo`00Koooool3ool00003oooooooo003oo`0000?oo`0000Co
ooooool00?oo003oo`00F?oooon]ool000oooooo001_ooooo`?oo`0000?oooooool00?oo00000_oo
0002ooooo`?oo`001_ooool3ool000;ooooo0ooo001:ooooojgoo`003oooool006Gooooo0ooo000;
ooooo`?oo`000oooool3ool000Kooooo0ooo0002ooooo`?oo`00B_oooon]ool000oooooo001Uoooo
o`?oo`001oooool3ool000Sooooo0ooo0005ooooo`?oo`000_ooool3ool004[ooooo[Ooo000?oooo
o`00IOooool3ool000Oooooo0ooo0008ooooo`?oo`00Eooooon]ool000oooooo001Uooooo`?oo`00
1oooool3ool000Sooooo1?oo001Fooooojgoo`003oooool006oooooo0ooo0006ooooo`Koo`00E_oo
oon]ool000oooooo001Fooooo`?oo`005_ooool6ool000?ooooo1_oo001Fooooojgoo`003oooool0
05Kooooo0ooo0008ooooo`?oo`002oooool6ool000?ooooo1Ooo001Gooooojgoo`003oooool005Ko
oooo0ooo0003ooooo`?oo`000_ooool5ool000cooooo0ooo001Oooooojgoo`003oooool005cooooo
0ooo0002ooooo`Goo`006?ooool3ool005?ooooo[Ooo000?ooooo`00G?ooool3ool000Cooooo0ooo
000?ooooo`?oo`001_ooool3ool005?ooooo[Ooo000?ooooo`00MOooool3ool000Kooooo0ooo001C
ooooojgoo`003oooool007Gooooo0ooo001Looooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00
>Oooool3ool009Sooooo[Ooo000?ooooo`00>Oooool3ool009Sooooo[Ooo000?ooooo`00>Oooool3
ool003?ooooo0ooo001Rooooojgoo`003oooool006oooooo0ooo001Rooooojgoo`003oooool006oo
oooo0ooo001Rooooojgoo`003oooool005Sooooo0ooo000Mooooo`?oo`00FOoooon]ool000oooooo
001Hooooo`?oo`007Oooool3ool005Wooooo[Ooo000?ooooo`00F?ooool3ool001gooooo0ooo001I
ooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00e?oooon]ool000oooooo003Dooooojgoo`00
3oooool00=Cooooo[Ooo000?ooooo`00e?oooon]ool000oooooo003Dooooojgoo`003oooool00=Co
oooo[Ooo000?ooooo`00e?oooon]ool000oooooo001/ooooo`?oo`00IOoooon]ool000oooooo001/
ooooo`?oo`00IOoooon]ool000oooooo001/ooooo`?oo`00IOoooon]ool000oooooo003Dooooojgo
o`003oooool00=Cooooo[Ooo000?ooooo`00e?oooon]ool000oooooo003Dooooojgoo`003oooool0
0=Cooooo[Ooo000?ooooo`00e?oooon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo
000?ooooo`00e?oooon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00
e?oooon]ool000oooooo003Dooooojgoo`003oooool00?ooooooTOooool00?ooooooTOooool00?oo
ooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oo
ooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-1.1227, \
-1.0611, 0.011199, 0.011199}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-63.1851, -2.62981, 0.296885, 0.296885}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data-dependent quantization (vector quantization)", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Number of centroids for each class (",
  Cell[BoxData[
      \(TraditionalForm\`2\^m\)]],
  ")"
}], "Subsubsection"],

Cell[BoxData[
    \(\(m\  = \ 3;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute data-dependent centroids", "Subsubsection"],

Cell[BoxData[{
    \(\(vqCentroids1 = \ VQ[data1, m];\)\), "\n", 
    \(\(vqCentroids2\  = VQ[data2, m];\)\), "\n", 
    \(\(vqCentroids\  = \ vqCentroids1~Join~vqCentroids2;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gCentroids = \ 
        PlotData2D[vqCentroids, pr, \ centroidStyle, \ 
          FrameTicks \[Rule] None];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 1 r
.02 w
.89909 .56897 Mdot
.79022 .52469 Mdot
.73383 .65234 Mdot
.65416 .58973 Mdot
.6116 .7788 Mdot
.59922 .70059 Mdot
.45202 .77177 Mdot
.46529 .63506 Mdot
.4779 .39943 Mdot
.43907 .29784 Mdot
.34623 .33266 Mdot
.28597 .2627 Mdot
.22841 .27164 Mdot
.21499 .16662 Mdot
.12721 .20932 Mdot
.05987 .16088 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool03?ooool3ool0oooooooo3Oooool1o`00007ooooo00000ol0003oooooooooo`0;oooo
o`Goo`3oooooool<ooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo1Ooo0?lYooooo`?o
o`3ogoooool1o`00007ooooo00000ol0003oooooooooo`0;ooooo`Goo`3o:?ooool5ool0omkooooo
0Ol00001ooooo`0000?o0000ooooooooool03?ooool3ool0obWooooo1Ooo0?oNooooo`7o00000Ooo
ool00003o`000?oooooooooo03Sooooo1Ooo0?oNooooo`7o00000Oooool00003o`000?oooooooooo
03Wooooo0ooo0?oOooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Pooooo`?oo`3on?ooool1o`00007ooooo00000ol0003oooooooooo`0Oooooo`Goo`3omoooool1
o`00007ooooo00000ol0003oooooooooo`0Oooooo`Goo`3omoooool1o`00007ooooo00000ol0003o
ooooooooo`0Oooooo`Goo`3omoooool1o`00007ooooo00000ol0003oooooooooo`0Pooooo`?oo`3o
n?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0COooool3ool0ol_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0C?ooool5ool0ol[ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0C?ooool5ool0ol[ooooo0Ol00001ooooo`0000?o0000ooooooooool0?Oooool3ool0o`co
oooo1Ooo0?o:ooooo`7o00000Oooool00003o`000?oooooooooo03cooooo1Ooo0?l<ooooo`?oo`3o
boooool1o`00007ooooo00000ol0003oooooooooo`0looooo`Goo`3of_ooool1o`00007ooooo0000
0ol0003oooooooooo`0looooo`Goo`3of_ooool1o`00007ooooo00000ol0003oooooooooo`0moooo
o`?oo`3ofoooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo07Wooooo0ooo
0?nOooooo`7o00000Oooool00003o`000?oooooooooo07Sooooo1Ooo0?nNooooo`7o00000Oooool0
0003o`000?oooooooooo07Sooooo1Ooo0?nNooooo`7o00000Oooool00003o`000?oooooooooo07So
oooo1Ooo0?nNooooo`7o00000Oooool00003o`000?oooooooooo07Wooooo0ooo0?nOooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0Goooool3ool0okWooooo0Ol00001ooooo`0000?o0000
ooooooooool0G_ooool5ool0okSooooo0Ol00001ooooo`0000?o0000ooooooooool0G_ooool5ool0
okSooooo0Ol00001ooooo`0000?o0000ooooooooool0G_ooool5ool0okSooooo0Ol00001ooooo`00
00?o0000ooooooooool0Goooool3ool0okWooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`24ooooo`?oo`3oU?ooool1o`00007ooooo
00000ol0003oooooooooo`23ooooo`Goo`3oToooool1o`00007ooooo00000ol0003oooooooooo`23
ooooo`Goo`3oToooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Goo`3oToooool1o`00
007ooooo00000ol0003oooooooooo`24ooooo`?oo`3oU?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0g_ooool3ool0oc[ooooo0Ol00001ooooo`0000?o0000ooooooooool0gOooool5
ool0ocWooooo0Ol00001ooooo`0000?o0000ooooooooool0gOooool5ool0ocWooooo0Ol00001oooo
o`0000?o0000ooooooooool0gOooool5ool0ocWooooo0Ol00001ooooo`0000?o0000ooooooooool0
g_ooool3ool0oc[ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3mooooo`?oo`3o6oooool1o`00007o
oooo00000ol0003oooooooooo`3looooo`Goo`3o6_ooool1o`00007ooooo00000ol0003ooooooooo
o`3looooo`Goo`3o6_ooool1o`00007ooooo00000ol0003oooooooooo`3looooo`Goo`3o6_ooool1
o`00007ooooo00000ol0003oooooooooo`3mooooo`?oo`3o6oooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0]oooool3ool0of7ooooo
0Ol00001ooooo`0000?o0000ooooooooool0]_ooool5ool0of3ooooo0Ol00001ooooo`0000?o0000
ooooooooool0]_ooool5ool0of3ooooo0Ol00001ooooo`0000?o0000ooooooooool0]_ooool5ool0
of3ooooo0Ol00001ooooo`0000?o0000ooooooooool0]oooool3ool0of7ooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`21ooooo`?oo`3oUoooool1o`00007ooooo00000ol0003oooooooooo`20ooooo`Go
o`3oU_ooool1o`00007ooooo00000ol0003oooooooooo`20ooooo`Goo`3oU_ooool1o`00007ooooo
00000ol0003oooooooooo`20ooooo`Goo`3oU_ooool1o`00007ooooo00000ol0003oooooooooo`21
ooooo`?oo`3oUoooool1o`00007ooooo00000ol0003oooooooooo`3>ooooo`?oo`3oB_ooool1o`00
007ooooo00000ol0003oooooooooo`3=ooooo`Goo`3oBOooool1o`00007ooooo00000ol0003ooooo
ooooo`3=ooooo`Goo`3oBOooool1o`00007ooooo00000ol0003oooooooooo`3=ooooo`Goo`3oBOoo
ool1o`00007ooooo00000ol0003oooooooooo`3>ooooo`?oo`3oB_ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`2Wooooo`?oo`3oLOooool1
o`00007ooooo00000ol0003oooooooooo`2Vooooo`Goo`3oL?ooool1o`00007ooooo00000ol0003o
ooooooooo`2Vooooo`Goo`3oL?ooool1o`00007ooooo00000ol0003oooooooooo`2Vooooo`Goo`3o
L?ooool1o`00007ooooo00000ol0003oooooooooo`2Wooooo`?oo`3oLOooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`1mooooo`?oo`3oVoooool1o`00007ooooo00000ol0
003oooooooooo`1looooo`Goo`3oV_ooool1o`00007ooooo00000ol0003oooooooooo`1looooo`Go
o`3o:_ooool3ool0ofgooooo0Ol00001ooooo`0000?o0000ooooooooool0O?ooool5ool0obWooooo
1Ooo0?m/ooooo`7o00000Oooool00003o`000?oooooooooo07gooooo0ooo0?lZooooo`Goo`3oK?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Zooooo`Goo`3oK?ooool1o`00007ooooo00000ol0
003oooooooooo`2[ooooo`?oo`3oKOooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo003oo`00023o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.01089, -1.01089, 0.00704453, \
0.00704453}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize resultant partitioning of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gpart1\  = \ 
        DrawPartitioning[vqCentroids, \ pr, nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[gpart1, gCentroids, yS, FrameTicks \[Rule] None];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.012 w
.90308 .56966 Mdot
.79312 .52494 Mdot
.73617 .65386 Mdot
.65571 .59063 Mdot
.61272 .78159 Mdot
.60021 .7026 Mdot
.45154 .77448 Mdot
.46494 .63641 Mdot
.47768 .39842 Mdot
.43846 .29582 Mdot
.34469 .33098 Mdot
.28383 .26033 Mdot
.22569 .26936 Mdot
.21214 .16328 Mdot
.12349 .20641 Mdot
.05547 .15749 Mdot
.02271 .66316 Mdot
.13516 .58987 Mdot
.13537 .11816 Mdot
.18522 .22063 Mdot
.24667 .21277 Mdot
.266 .33722 Mdot
.33738 .51025 Mdot
.36767 .24965 Mdot
.40257 .09761 Mdot
.41097 .36512 Mdot
.51242 .71071 Mdot
.5332 .75369 Mdot
.53812 .52099 Mdot
.56021 .61304 Mdot
.65505 .41269 Mdot
.6631 .66403 Mdot
.68654 .72942 Mdot
.72177 .24633 Mdot
.7328 .57533 Mdot
.82087 .61424 Mdot
.003 w
.5332 .75369 m
.52502 .93922 L
s
.40257 .09761 m
0 0 rlineto s
.40257 .09761 m
.45973 0 L
s
.13537 .11816 m
0 0 rlineto s
.13537 .11816 m
.13974 0 L
s
1 .96932 m
.82087 .61424 L
s
.82087 .61424 m
1 .17383 L
s
1 .17383 m
.82087 .61424 L
.7328 .57533 L
.65505 .41269 L
.72177 .24633 L
s
.72177 .24633 m
.88091 0 L
s
.68654 .72942 m
.6631 .66403 L
.7328 .57533 L
.82087 .61424 L
s
.82087 .61424 m
1 .96932 L
s
.96649 1 m
.68654 .72942 L
s
.56021 .61304 m
.53812 .52099 L
.65505 .41269 L
.7328 .57533 L
.6631 .66403 L
.56021 .61304 L
s
.5332 .75369 m
.68654 .72942 L
s
.68654 .72942 m
.96649 1 L
s
.5332 .75369 m
.51242 .71071 L
.56021 .61304 L
.6631 .66403 L
.68654 .72942 L
.5332 .75369 L
s
0 .67332 m
.02271 .66316 L
.51242 .71071 L
.5332 .75369 L
s
.02271 .66316 m
.13516 .58987 L
.33738 .51025 L
.53812 .52099 L
.56021 .61304 L
.51242 .71071 L
.02271 .66316 L
s
.41097 .36512 m
.72177 .24633 L
.65505 .41269 L
.53812 .52099 L
.33738 .51025 L
.41097 .36512 L
s
.88091 0 m
.72177 .24633 L
.41097 .36512 L
.36767 .24965 L
.40257 .09761 L
s
.266 .33722 m
.36767 .24965 L
.41097 .36512 L
.33738 .51025 L
.13516 .58987 L
.266 .33722 L
s
.24667 .21277 m
.40257 .09761 L
.36767 .24965 L
.266 .33722 L
.24667 .21277 L
s
.18522 .22063 m
.24667 .21277 L
.266 .33722 L
.13516 .58987 L
.02271 .66316 L
s
.02271 .66316 m
0 .67332 L
s
0 .52138 m
.18522 .22063 L
s
.40257 .09761 m
.24667 .21277 L
.18522 .22063 L
.13537 .11816 L
s
.13537 .11816 m
.18522 .22063 L
s
.18522 .22063 m
0 .52138 L
s
0 .30634 m
.13537 .11816 L
s
.13537 .11816 m
0 0 rlineto s
.13537 .11816 m
0 .30634 L
s
1 0 1 r
.02 w
.90308 .56966 Mdot
.79312 .52494 Mdot
.73617 .65386 Mdot
.65571 .59063 Mdot
.61272 .78159 Mdot
.60021 .7026 Mdot
.45154 .77448 Mdot
.46494 .63641 Mdot
.47768 .39842 Mdot
.43846 .29582 Mdot
.34469 .33098 Mdot
.28383 .26033 Mdot
.22569 .26936 Mdot
.21214 .16328 Mdot
.12349 .20641 Mdot
.05547 .15749 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Uooooo`0300000?oooooooooo05So
oooo00<00000ooooooooool0M_ooool00`00003oooooooooo`0Oooooo`7o00000Oooool00003o`00
0?oooooooooo02Gooooo00<00000ooooooooool0Eoooool00`00003oooooooooo`1fooooo`030000
0?oooooooooo023ooooo0Ol00001ooooo`0000?o0000ooooooooool09Oooool00`00003ooooooooo
o`1Gooooo`0300000?oooooooooo07Gooooo00<00000ooooooooool08Oooool1o`00007ooooo0000
0ol0003oooooooooo`0Uooooo`0300000?oooooooooo05Kooooo00<00000ooooooooool0M_ooool0
0`00003oooooooooo`0Qooooo`7o00000Oooool00003o`000?oooooooooo02Gooooo00<00000oooo
ooooool0EOooool00`00003oooooooooo`1fooooo`0300000?oooooooooo02;ooooo0Ol00001oooo
o`0000?o0000ooooooooool09Oooool00`00003oooooooooo`1Eooooo`0300000?oooooooooo07Go
oooo00<00000ooooooooool08oooool1o`00007ooooo00000ol0003oooooooooo`0Uooooo`030000
0?oooooooooo05Cooooo00<00000ooooooooool0M_ooool00`00003oooooooooo`0Sooooo`7o0000
0Oooool00003o`000?oooooooooo02Gooooo00<00000ooooooooool0E?ooool00`00003ooooooooo
o`1eooooo`0300000?oooooooooo02Cooooo0Ol00001ooooo`0000?o0000ooooooooool09?ooool0
0`00003oooooooooo`1Dooooo`0300000?oooooooooo07Kooooo00<00000ooooooooool09?ooool1
o`00007ooooo00000ol0003oooooooooo`0Tooooo`0300000?oooooooooo05Cooooo00<00000oooo
ooooool0MOooool00`00003oooooooooo`0Uooooo`7o00000Oooool00003o`000?oooooooooo02Co
oooo00<00000ooooooooool0Doooool00`00003oooooooooo`1eooooo`0300000?oooooooooo02Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool09?ooool00`00003oooooooooo`1Booooo`030000
0?oooooooooo07Kooooo00<00000ooooooooool09_ooool1o`00007ooooo00000ol0003ooooooooo
o`0Tooooo`0300000?oooooooooo05;ooooo00<00000ooooooooool0MOooool00`00003ooooooooo
o`0Wooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00<00000ooooooooool0DOooool0
0`00003oooooooooo`1eooooo`0300000?oooooooooo02Sooooo0Ol00001ooooo`0000?o0000oooo
ooooool09?ooool00`00003oooooooooo`1Aooooo`0300000?oooooooooo07Gooooo00<00000oooo
ooooool0:?ooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`0300000?oooooooooo053o
oooo00<00000ooooooooool0MOooool00`00003oooooooooo`0Yooooo`7o00000Oooool00003o`00
0?oooooooooo02Cooooo00<00000ooooooooool0D?ooool00`00003oooooooooo`1dooooo`030000
0?oooooooooo02[ooooo0Ol00001ooooo`0000?o0000ooooooooool09?ooool00`00003ooooooooo
o`1?ooooo`0300000?oooooooooo07Gooooo00<00000ooooooooool0:_ooool1o`00007ooooo0000
0ol0003oooooooooo`0Tooooo`0300000?oooooooooo04kooooo00<00000ooooooooool0MOooool0
0`00003oooooooooo`0[ooooo`7o00000Oooool00003o`000?oooooooooo02Cooooo00<00000oooo
ooooool0C_ooool00`00003oooooooooo`1dooooo`0300000?oooooooooo02cooooo0Ol00001oooo
o`0000?o0000ooooooooool09?ooool00`00003oooooooooo`1=ooooo`0300000?oooooooooo07Go
oooo00<00000ooooooooool0;?ooool1o`00007ooooo00000ol0003oooooooooo`0Tooooo`030000
0?oooooooooo04gooooo00<00000ooooooooool0M?ooool00`00003oooooooooo`0]ooooo`7o0000
0Oooool00003o`000?oooooooooo02Cooooo00<00000ooooooooool0C?ooool00`00003ooooooooo
o`1eooooo`0300000?oooooooooo02gooooo0Ol00001ooooo`0000?o0000ooooooooool09?ooool0
0`00003oooooooooo`1<ooooo`0300000?oooooooooo07Cooooo00<00000ooooooooool0;_ooool1
o`00007ooooo00000ol0003oooooooooo`0Tooooo`0300000?oooooooooo04_ooooo00<00000oooo
ooooool0M?ooool00`00003oooooooooo`0_ooooo`7o00000Oooool00003o`000?oooooooooo02?o
oooo00<00000ooooooooool0Boooool00`00003oooooooooo`1eooooo`0300000?oooooooooo02oo
oooo0Ol00001ooooo`0000?o0000ooooooooool08oooool00`00003oooooooooo`19ooooo`;o0000
00<00000ooooooooool0M?ooool00`00003oooooooooo`0`ooooo`7o00000Oooool00003o`000?oo
oooooooo02?ooooo00<00000ooooooooool0BOooool200000003o`000?oooooooooo07?ooooo00<0
0000ooooooooool0<Oooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`0300000?oooooo
oooo04Sooooo00@00000o`000000003o0000MOooool00`00003oooooooooo`0aooooo`7o00000Ooo
ool00003o`000?oooooooooo02?ooooo00<00000ooooooooool0Aoooool01000003oooooooooo`00
001eooooo`0300000?oooooooooo03;ooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool0
0`00003oooooooooo`15ooooo`8000000_ooool00`00003oooooooooo`1cooooo`0300000?oooooo
oooo03?ooooo0Ol00001ooooo`0000?o0000ooooooooool08oooool00`00003oooooooooo`14oooo
o`0300000?oooooooooo00;ooooo00<00000ooooooooool0Loooool00`00003oooooooooo`0coooo
o`7o00000Oooool00003o`000?oooooooooo02;ooooo00?o000000000?l00000@oooool2000000Go
oooo00<00000ooooooooool0L_ooool00`00003oooooooooo`0dooooo`7o00000Oooool00003o`00
0?oooooooooo02;ooooo00?o000000000?l00000@_ooool00`00003oooooooooo`05ooooo`030000
0?oooooooooo077ooooo00<00000ooooooooool0=Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Rooooo`03o`000000003o0000047ooooo00<00000ooooooooool01Oooool00`00003ooooooooo
o`1booooo`0300000?oooooooooo03Gooooo0Ol00001ooooo`0000?o0000ooooooooool08_ooool0
0`00003ooooo0000000oooooo`8000002?ooool00`00003oooooooooo`1aooooo`0300000?oooooo
oooo03Kooooo0Ol00001ooooo`0000?o0000ooooooooool08Oooool01000003oooooooooo`00000n
ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0LOooool00`00003oooooooooo`0f
ooooo`7o00000Oooool00003o`000?oooooooooo023ooooo00<00000ooooooooool00_ooool00`00
003oooooooooo`0jooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0L?ooool00`00
003oooooooooo`0gooooo`7o00000Oooool00003o`000?oooooooooo023ooooo00<00000oooooooo
ool00_ooool00`00003oooooooooo`0hooooo`8000003?ooool00`00003oooooooooo`1_ooooo`03
00000?oooooooooo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool07oooool00`00003ooooo
ooooo`04ooooo`0300000?oooooooooo03Kooooo00<00000ooooooooool02oooool00`00003ooooo
ooooo`1`ooooo`0300000?oooooooooo03Sooooo0Ol00001ooooo`0000?o0000ooooooooool07_oo
ool00`00003oooooooooo`05ooooo`0300000?oooooooooo03Gooooo00<00000ooooooooool03?oo
ool00`00003oooooooooo`1_ooooo`0300000?oooooooooo03Wooooo0Ol00001ooooo`0000?o0000
ooooooooool07_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo03;ooooo0P00000?
ooooo`0300000?oooooooooo06kooooo00<00000ooooooooool0>_ooool1o`00007ooooo00000ol0
003oooooooooo`0;ooooo`?oo`3o3oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo
037ooooo00<00000ooooooooool03oooool00`00003oooooooooo`1^ooooo`0300000?oooooooooo
03[ooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool5ool0o`gooooo00<00000oooooooo
ool02Oooool00`00003oooooooooo`0^ooooo`8000004Oooool00`00003oooooooooo`1^ooooo`03
00000?oooooooooo03_ooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool5ool0o`cooooo
00<00000ooooooooool02_ooool00`00003oooooooooo`0=ooooo`?oo`3o7Oooool00`00003ooooo
ooooo`0Aooooo`0300000?oooooooooo06gooooo00<00000ooooooooool0??ooool1o`00007ooooo
00000ol0003oooooooooo`0:ooooo`Goo`3o3?ooool00`00003oooooooooo`0;ooooo`0300000?oo
oooooooo00_ooooo1Ooo0?lKooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool0KOoo
ool00`00003oooooooooo`0looooo`7o00000Oooool00003o`000?oooooooooo00_ooooo0ooo0?l<
ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool02oooool5ool0oaWooooo0P00000E
ooooo`0300000?oooooooooo06cooooo00<00000ooooooooool0?Oooool1o`00007ooooo00000ol0
003oooooooooo`0Iooooo`0300000?oooooooooo00kooooo00<00000ooooooooool02_ooool5ool0
oaSooooo00<00000ooooooooool05?ooool00`00003oooooooooo`1/ooooo`0300000?oooooooooo
03kooooo0Ol00001ooooo`0000?o0000ooooooooool06Oooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo00[ooooo0ooo0?lHooooo`0300000?oooooooooo01Gooooo00<00000oooooooo
ool0K?ooool00`00003oooooooooo`0nooooo`7o00000Oooool00003o`000?oooooooooo01Sooooo
00<00000ooooooooool04?ooool00`00003oooooooooo`0Sooooo`8000006?ooool00`00003ooooo
ooooo`1[ooooo`0300000?oooooooooo03oooooo0Ol00001ooooo`0000?o0000ooooooooool05ooo
ool00`00003oooooooooo`0Booooo`0300000?oooooooooo027ooooo00<00000ooooooooool06?oo
ool00`00003oooooooooo`1[ooooo`0300000?oooooooooo03kooooo0@000001o`00007ooooo0000
0ol0003oooooooooo`0Fooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool08?ooool0
0`00003oooooooooo`0Iooooo`0300000?oooooooooo06[ooooo00<00000ooooooooool0?oooool1
0000007o00000Oooool00003o`000?oooooooooo01Kooooo00<00000ooooooooool05?ooool00`00
003oooooooooo`0Mooooo`8000006oooool00`00003oooooooooo`1Zooooo`0300000?oooooooooo
043ooooo0@000001o`00007ooooo00000ol0003oooooooooo`0Eooooo`0300000?oooooooooo01Go
oooo00<00000ooooooooool07?ooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo06[o
oooo00<00000ooooooooool0?oooool00`00003oooooo`000001ooooo`0000?o0000ooooooooool0
5?ooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo01Wooooo0P00000Nooooo`030000
0?oooooooooo06Wooooo00<00000ooooooooool0@?ooool00`00003oooooo`000001ooooo`0000?o
0000ooooooooool05?ooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo01Sooooo00<0
0000ooooooooool07_ooool00`00003oooooooooo`1Xooooo`0300000?oooooooooo043ooooo00@0
0000oooooooooooo00000Oooool00003o`000?oooooooooo01?ooooo00<00000ooooooooool02Ooo
ool3ool0o`gooooo00<00000ooooooooool05_ooool00`00003oooooooooo`0Nooooo`0300000?oo
oooooooo06Wooooo00<00000ooooooooool0@?ooool01000003oooooooooool00001ooooo`0000?o
0000ooooooooool04_ooool00`00003oooooooooo`09ooooo`Goo`3o3?ooool00`00003ooooooooo
o`0Dooooo`8000008Oooool00`00003oooooooooo`1Xooooo`0300000?oooooooooo047ooooo00@0
0000oooooooooooo00000Oooool00003o`000?oooooooooo017ooooo00<00000ooooooooool02_oo
ool5ool0o`gooooo00<00000ooooooooool04_ooool00`00003oooooooooo`0Qooooo`0300000?oo
oooooooo06Oooooo00<00000ooooooooool0@Oooool01@00003ooooooooooooooooo0000007ooooo
00000ol0003oooooooooo`0Aooooo`0300000?oooooooooo00[ooooo1Ooo0?l=ooooo`0300000?oo
oooooooo00oooooo0_l000000`00003oooooooooo`0Rooooo`0300000?oooooooooo06Oooooo00<0
0000ooooooooool0@Oooool01@00003ooooooooooooooooo0000007ooooo00000ol0003ooooooooo
o`0@ooooo`0300000?oooooooooo00cooooo0ooo0?l?ooooo`0300000?oooooooooo00_ooooo1@00
00000ol0003oooooooooo`0Qooooo`0300000?oooooooooo06Oooooo00<00000ooooooooool0@Ooo
ool00`00003oooooooooo`02ooooo`7o00000Oooool00003o`000?oooooooooo00oooooo00<00000
ooooooooool07oooool00`00003o0000o`000002ooooo`T000000oooool00ol000000000o`00000S
ooooo`0300000?oooooooooo06Kooooo00<00000ooooooooool0@_ooool00`00003oooooooooo`02
ooooo`7o00000Oooool00003o`000?oooooooooo00oooooo00<00000ooooooooool07oooool00ol0
0000000000000002000000gooooo00<00000ooooooooool08_ooool00`00003oooooooooo`1Voooo
o`0300000?oooooooooo04;ooooo00<00000ooooooooool00_ooool1o`00007ooooo00000ol0003o
ooooooooo`0>ooooo`0300000?oooooooooo023ooooo00?o000000000?l000003oooool00`00003o
ooooooooo`0Rooooo`0300000?oooooooooo06Gooooo00<00000ooooooooool0@_ooool00`00003o
ooooooooo`03ooooo`7o00000Oooool00003o`000?oooooooooo00gooooo00<00000ooooooooool0
8Oooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo027ooooo00<00000ooooooooool0
IOooool00`00003oooooooooo`12ooooo`0300000?oooooooooo00?ooooo0Ol00001ooooo`0000?o
0000ooooooooool03?ooool00`00003oooooooooo`0Qooooo`0300000?oooooooooo017ooooo00<0
0000ooooooooool08?ooool00`00003oooooooooo`1Uooooo`0300000?oooooooooo04;ooooo00<0
0000ooooooooool01?ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`0300000?oooooo
oooo027ooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Pooooo`0300000?oooooo
oooo06Cooooo00<00000ooooooooool0@oooool00`00003oooooooooo`04ooooo`7o00000Oooool0
0003o`000?oooooooooo00_ooooo00<00000ooooooooool08Oooool00`00003oooooooooo`0Boooo
o`0300000?oooooooooo023ooooo00<00000ooooooooool0I?ooool00`00003oooooooooo`13oooo
o`0300000?oooooooooo00Cooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool00`00003o
ooooooooo`0Rooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool08?ooool00`00003o
ooooooooo`1Pooooo`?o000000<00000ooooooooool0@oooool00`00003oooooooooo`05ooooo`7o
00000Oooool00003o`000?oooooooooo00[ooooo00<00000ooooooooool08Oooool00`00003ooooo
ooooo`0Cooooo`0300000?oooooooooo01kooooo00?o000000000?l00000H_ooool00ol000000000
00000016ooooo`0300000?oooooooooo00Gooooo0Ol00001ooooo`0000?o0000ooooooooool02Ooo
ool00`00003oooooooooo`0Qooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool07Ooo
ool200000003o`000?oooooooooo05kooooo0`0000000ol000000000ooooo`14ooooo`0300000?oo
oooooooo00Kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00`00003oooooooooo`0R
ooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool07?ooool01000003o000000000?l0
001Mooooo`<000000oooool00`00003oooooooooo`14ooooo`0300000?oooooooooo00Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool01oooool00`00003oooooooooo`0Rooooo`0300000?oooooo
oooo01Kooooo00<00000ooooooooool01Oooool3ool0oa?ooooo00D00000oooooooooooooooo0000
001Kooooo`8000001_ooool00`00003oooooooooo`14ooooo`0300000?oooooooooo00Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool01oooool00`00003oooooooooo`0Rooooo`0300000?oooooo
oooo01Kooooo00<00000ooooooooool01?ooool5ool0oa7ooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`1Fooooo`<000002?ooool00`00003oooooooooo`13ooooo`0300000?oooooo
oooo00Oooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool00`00003oooooooooo`0Roooo
o`0300000?oooooooooo00kooooo0ooo0?l6ooooo`0300000?oooooooooo00Cooooo1Ooo0?l@oooo
o`0300000?oooooooooo00?ooooo00<00000ooooooooool0Doooool3000000[ooooo00<00000oooo
ooooool0A?ooool00`00003oooooooooo`07ooooo`7o00000Oooool00003o`000?oooooooooo00Go
oooo00<00000ooooooooool08_ooool00`00003oooooooooo`0>ooooo`Goo`3o1Oooool00`00003o
ooooooooo`04ooooo`Goo`3o3oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo053o
oooo0P00000=ooooo`0300000?oooooooooo04?ooooo00<00000ooooooooool02?ooool1o`00007o
oooo00000ol0003oooooooooo`05ooooo`0300000?oooooooooo02;ooooo00<00000ooooooooool0
3_ooool5ool0o`Kooooo00<00000ooooooooool01?ooool3ool0o`kooooo0P000008ooooo`030000
0?oooooooooo04gooooo0`00000>ooooo`0300000?oooooooooo04Cooooo00<00000ooooooooool0
2?ooool1o`00007ooooo00000ol0003oooooooooo`04ooooo`0300000?oooooooooo02;ooooo00<0
0000ooooooooool03oooool5ool0o`Kooooo00<00000ooooooooool05?ooool00`00003ooooooooo
o`08ooooo`0300000?oooooooooo04[ooooo0`00000Aooooo`0300000?oooooooooo04Cooooo00<0
0000ooooooooool02?ooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`0300000?oooooo
oooo02;ooooo00<00000ooooooooool04Oooool3ool0o`Oooooo00<00000ooooooooool04oooool0
0`00003oooooooooo`0:ooooo`0300000?oooooooooo04Oooooo0P00000Cooooo`0300000?oooooo
oooo04Cooooo00<00000ooooooooool02Oooool1o`00007ooooo00000ol0003oooooooooo`02oooo
o`0300000?oooooooooo02?ooooo00<00000ooooooooool06oooool00`00003oooooooooo`0Boooo
o`0300000?oooooooooo00_ooooo00<00000ooooooooool0A?ooool3000001Gooooo00<00000oooo
ooooool0A?ooool00`00003oooooooooo`09ooooo`7o00000Oooool00003o`000?oooooooooo00;o
oooo00<00000ooooooooool08_ooool00`00003oooooooooo`0Looooo`0300000?oooooooooo017o
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`12ooooo`8000006?ooool00`00003o
ooooooooo`13ooooo`0300000?oooooooooo00[ooooo0Ol00001ooooo`0000Go0000oooooooooooo
oooo0000000Uooooo`0300000?oooooooooo01gooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`0>ooooo`0300000?oooooooooo03kooooo0`00000Iooooo`0300000?oooooooooo04Co
oooo00<00000ooooooooool02_ooool1o`00007ooooo00001?l0003oooooooooo`00000Uooooo`03
00000?oooooooooo01kooooo00<00000ooooooooool03Oooool20000017ooooo00<00000oooooooo
ool03?ooool3ool0obcooooo0`00000Looooo`0300000?oooooooooo04Cooooo00<00000oooooooo
ool02_ooool1o`00007ooooo00001?l0003oooooooooo`00000Tooooo`0300000?oooooooooo01oo
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`0Booooo`0300000?oooooooooo00[o
oooo1Ooo0?lYooooo`8000007_ooool00`00003oooooooooo`14ooooo`0300000?oooooooooo00_o
oooo0Ol00001ooooo`0000?o0000ooooo`0000009Oooool00`00003oooooooooo`0Oooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool04oooool00`00003oooooooooo`0:ooooo`Goo`3o
9_ooool30000023ooooo00<00000ooooooooool0A?ooool00`00003oooooooooo`0;ooooo`7o0000
0Oooool00003o`000000003ooooo02Cooooo00<00000ooooooooool08?ooool00`00003ooooooooo
o`0:ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool02_ooool5ool0ob?ooooo0`00
000Sooooo`0300000?oooooooooo04?ooooo00<00000ooooooooool03?ooool1o`00007ooooo0000
0`00003oooooooooo`0Tooooo`0300000?oooooooooo023ooooo00<00000ooooooooool02Oooool0
0`00003oooooooooo`0Fooooo`0300000?oooooooooo00[ooooo0ooo0?lRooooo`8000009Oooool0
0`00003oooooooooo`14ooooo`0300000?oooooooooo00cooooo0Ol00001ooooo`0000?o0000oooo
ooooool08oooool00`00003oooooooooo`0Rooooo`0300000?oooooooooo00Oooooo00<00000oooo
ooooool05oooool00`00003oooooooooo`0/ooooo`<000009oooool00`00003oooooooooo`14oooo
o`0300000?oooooooooo00cooooo0Ol00001ooooo`0000?o0000ooooooooool08_ooool00`00003o
ooooooooo`0Sooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool06?ooool00`00003o
ooooooooo`0Yooooo`<00000:Oooool00`00003oooooooooo`14ooooo`0300000?oooooooooo00go
oooo0Ol00001ooooo`0000?o0000ooooooooool08_ooool00`00003oooooooooo`0Sooooo`030000
0?oooooooooo00Cooooo0P00000Looooo`0300000?oooooooooo02Kooooo0P00000/ooooo`030000
0?oooooooooo04Cooooo00<00000ooooooooool03Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Qooooo`0300000?oooooooooo02Cooooo00<00000ooooooooool00oooool00`00003ooooooooo
o`0Looooo`0300000?oooooooooo02?ooooo0`00000]ooooo`0300000?oooooooooo04Cooooo00<0
0000ooooooooool03_ooool1o`00007ooooo00000ol0003oooooooooo`0Pooooo`0300000?oooooo
oooo02Gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`0Mooooo`0300000?oooooo
oooo023ooooo0`00000`ooooo`0300000?oooooooooo04Cooooo00<00000ooooooooool03_ooool1
o`00007ooooo00000ol0003oooooooooo`0Pooooo`0300000?oooooooooo02Gooooo00D00000oooo
oooooooooooo0000000Aooooo`?oo`3o3Oooool00`00003oooooooooo`0Mooooo`800000<oooool0
0`00003oooooooooo`14ooooo`0300000?oooooooooo00kooooo0Ol00001ooooo`0000?o0000oooo
ooooool07oooool00`00003oooooooooo`0Wooooo`0300000?ooool00000017ooooo1Ooo0?l<oooo
o`0300000?oooooooooo01[ooooo0`00000dooooo`0300000?oooooooooo04Cooooo00<00000oooo
ooooool03oooool1o`00007ooooo00000ol0003oooooooooo`0Oooooo`0300000?oooooooooo02Oo
oooo0P00000Booooo`Goo`3o3Oooool00`00003oooooooooo`0Fooooo`<00000=oooool00`00003o
ooooooooo`14ooooo`0300000?oooooooooo00oooooo0Ol00001ooooo`0000?o0000ooooooooool0
7_ooool00`00003oooooooooo`0Wooooo`03o`000000003o000001;ooooo1Ooo0?l=ooooo`030000
0?oooooooooo01Cooooo0P00000iooooo`0300000?oooooooooo04Cooooo00<00000ooooooooool0
4?ooool1o`00007ooooo00000ol0003oooooooooo`0Mooooo`0300000?oooooooooo02Sooooo00?o
000000000?l000004oooool3ool0o`kooooo00<00000ooooooooool04Oooool3000003_ooooo00<0
0000ooooooooool0A?ooool00`00003oooooooooo`0@ooooo`7o00000Oooool00003o`000?oooooo
oooo01gooooo00<00000ooooooooool0:?ooool00`00003o0000o`00000Uooooo`0300000?oooooo
oooo00kooooo0P00000nooooo`0300000?oooooooooo04Cooooo00<00000ooooooooool04?ooool1
o`00007ooooo00000ol0003oooooooooo`0Looooo`0300000?oooooooooo02Wooooo00<00000oooo
ooooool09Oooool00`00003oooooooooo`0;ooooo`<00000?oooool00`00003oooooooooo`14oooo
o`0300000?oooooooooo017ooooo0Ol00001ooooo`0000?o0000ooooooooool07?ooool00`00003o
ooooooooo`0Xooooo`0300000?oooooooooo02Kooooo00<00000ooooooooool02?ooool3000004;o
oooo00<00000ooooooooool0A?ooool00`00003oooooooooo`0Aooooo`7o00000Oooool00003o`00
0?oooooooooo01_ooooo00<00000ooooooooool0:Oooool00`00003oooooooooo`0Wooooo`030000
0?oooooooooo00Gooooo0P000014ooooo`0300000?oooooooooo04Cooooo00<00000ooooooooool0
4_ooool1o`00007ooooo00000ol0003oooooooooo`0Jooooo`0300000?oooooooooo02Wooooo00<0
0000ooooooooool0:?ooool00`00003oooooooooo`02ooooo`<00000A_ooool00`00003ooooooooo
o`14ooooo`0300000?oooooooooo01;ooooo0Ol00001ooooo`0000?o0000ooooooooool06_ooool0
0`00003oooooooooo`0Yooooo`0300000?oooooooooo02Sooooo00<00000ooooo`0000000P000018
ooooo`0300000?oooooooooo04Gooooo00<00000ooooooooool04_ooool1o`00007ooooo00000ol0
003oooooooooo`0Iooooo`0300000?oooooooooo02Wooooo00<00000ooooooooool0:Oooool00ol0
00000000o`00001:ooooo`0300000?oooooooooo04Cooooo00<00000ooooooooool04oooool1o`00
007ooooo00000ol0003oooooooooo`0Hooooo`0300000?oooooooooo02[ooooo00<00000oooooooo
ool0:Oooool00ol000000000o`00001:ooooo`0300000?oooooooooo04Cooooo00<00000oooooooo
ool04oooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`0300000?oooooooooo02Wooooo
00<00000ooooooooool0:_ooool00`00003o0000o`000019ooooo`0300000?oooooooooo04Cooooo
00<00000ooooooooool05?ooool1o`00007ooooo00000ol0003oooooooooo`0Gooooo`0300000?oo
oooooooo02[ooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`19ooooo`0300000?oo
oooooooo04Cooooo00<00000ooooooooool05?ooool1o`00007ooooo00000ol0003oooooooooo`0G
ooooo`0300000?oooooooooo02Wooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`19
ooooo`0300000?oooooooooo04Gooooo00<00000ooooooooool05?ooool1o`00007ooooo00000ol0
003oooooooooo`0Fooooo`0300000?oooooooooo02Wooooo00<00000ooooooooool0:oooool00`00
003oooooooooo`19ooooo`0300000?oooooooooo04Cooooo00<00000ooooooooool05Oooool1o`00
007ooooo00000ol0003oooooooooo`0Eooooo`0300000?oooooooooo02[ooooo00<00000oooooooo
ool0:_ooool00`00003oooooooooo`1:ooooo`0300000?oooooooooo04Cooooo00<00000oooooooo
ool05Oooool1o`00007ooooo00000ol0003oooooooooo`0Eooooo`0300000?oooooooooo02Wooooo
00<00000ooooooooool0:oooool00`00003oooooooooo`19ooooo`0300000?oooooooooo04Cooooo
00<00000ooooooooool05_ooool1o`00007ooooo00000ol0003oooooooooo`0Dooooo`0300000?oo
oooooooo02[ooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0Cooooo`?oo`3o=?oo
ool00`00003oooooooooo`14ooooo`0300000?oooooooooo01Kooooo0Ol00001ooooo`0000?o0000
ooooooooool04oooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo02_ooooo00<00000
ooooooooool04_ooool5ool0oc;ooooo00<00000ooooooooool0A?ooool00`00003oooooooooo`0G
ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo00<00000ooooooooool0:_ooool00`00
003oooooooooo`0Zooooo`0300000?oooooooooo01?ooooo1Ooo0?lbooooo`0300000?oooooooooo
04Cooooo00<00000ooooooooool05oooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`03
00000?oooooooooo02[ooooo00<00000ooooooooool0:oooool00`00003oooooooooo`0Cooooo`Go
o`3o<Oooool00`00003oooooooooo`15ooooo`0300000?oooooooooo01Oooooo0Ol00001ooooo`00
00?o0000ooooooooool04_ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo02[ooooo
00<00000ooooooooool05Oooool3ool0oc;ooooo00<00000ooooooooool0A?ooool00`00003ooooo
ooooo`0Hooooo`7o00000Oooool00003o`000?oooooooooo017ooooo00<00000ooooooooool0:_oo
ool00`00003oooooooooo`0[ooooo`0300000?oooooooooo04Sooooo0_l000000`00003ooooooooo
o`14ooooo`0300000?oooooooooo01Sooooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool0
0`00003oooooooooo`0[ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool0BOooool2
00000003o`000?oooooooooo04?ooooo00<00000ooooooooool06Oooool1o`00007ooooo00000ol0
003oooooooooo`0@ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool0:oooool00`00
003oooooooooo`18ooooo`0400000?l000000000o`0004Gooooo00<00000ooooooooool06Oooool1
o`00007ooooo00000ol0003oooooooooo`0?ooooo`0300000?oooooooooo02_ooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`18ooooo`0500000?ooooooooooooooo`000000AOooool0
0`00003oooooooooo`0Iooooo`7o00000Oooool00003o`000?oooooooooo00oooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`0[ooooo`0300000?oooooooooo04Oooooo00<00000oooo
ooooool00_ooool00`00003oooooooooo`12ooooo`0300000?oooooooooo01[ooooo0Ol00001oooo
o`0000?o0000ooooooooool03_ooool00`00003oooooooooo`0[ooooo`0300000?oooooooooo02[o
oooo00<00000ooooooooool0Aoooool00`00003oooooooooo`04ooooo`0300000?oooooooooo047o
oooo00<00000ooooooooool06_ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`030000
0?oooooooooo02_ooooo00<00000ooooooooool0:oooool00`00003oooooooooo`16ooooo`030000
0?oooooooooo00Gooooo00<00000ooooooooool0@?ooool00`00003oooooooooo`0Kooooo`7o0000
0Oooool00003o`000?oooooooooo00gooooo00<00000ooooooooool0:oooool00`00003ooooooooo
o`0Zooooo`0300000?oooooooooo04Kooooo00<00000ooooooooool01oooool00`00003ooooooooo
o`0oooooo`0300000?oooooooooo01_ooooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool0
0`00003oooooooooo`0[ooooo`0300000?oooooooooo02_ooooo00<00000ooooooooool0AOooool0
0`00003oooooooooo`08ooooo`0300000?oooooooooo03oooooo00<00000ooooooooool06oooool1
o`00007ooooo00000ol0003oooooooooo`0;ooooo`0300000?oooooooooo02cooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`15ooooo`0300000?oooooooooo00[ooooo00<00000oooo
ooooool0?Oooool00`00003oooooooooo`0Looooo`7o00000Oooool00003o`000?oooooooooo00_o
oooo00<00000ooooooooool0:oooool00`00003oooooooooo`0[ooooo`0300000?oooooooooo04Co
oooo00<00000ooooooooool02oooool00`00003oooooooooo`0mooooo`0300000?oooooooooo01co
oooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool00`00003oooooooooo`0/ooooo`030000
0?oooooooooo02[ooooo00<00000ooooooooool0A?ooool00`00003oooooooooo`0=ooooo`030000
0?oooooooooo03_ooooo00<00000ooooooooool07Oooool1o`00007ooooo00000ol0003ooooooooo
o`0:ooooo`0300000?oooooooooo02_ooooo00<00000ooooooooool0:oooool00`00003ooooooooo
o`13ooooo`0300000?oooooooooo00kooooo00<00000ooooooooool0>oooool00`00003ooooooooo
o`0Mooooo`7o00000Oooool00003o`000?oooooooooo00Wooooo00<00000ooooooooool0;?ooool0
0`00003oooooooooo`0Zooooo`0300000?oooooooooo04?ooooo00<00000ooooooooool04?ooool0
0`00003oooooooooo`0jooooo`0300000?oooooooooo01gooooo0Ol00001ooooo`0000?o0000oooo
ooooool02?ooool00`00003oooooooooo`0/ooooo`0300000?oooooooooo02_ooooo00<00000oooo
ooooool0@_ooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo03Wooooo00<00000oooo
ooooool07_ooool1o`00007ooooo00000ol0003oooooooooo`08ooooo`0300000?oooooooooo02co
oooo00<00000ooooooooool0:_ooool00`00003oooooooooo`12ooooo`0300000?oooooooooo01?o
oooo00<00000ooooooooool0>?ooool00`00003oooooooooo`0Nooooo`7o00000Oooool00003o`00
0?oooooooooo00Oooooo00<00000ooooooooool0;?ooool00`00003oooooooooo`0[ooooo`030000
0?oooooooooo043ooooo0P00000Fooooo`0300000?oooooooooo03Oooooo00<00000ooooooooool0
7oooool1o`00007ooooo00000ol0003oooooooooo`07ooooo`0300000?oooooooooo02_ooooo00<0
0000ooooooooool0:oooool00`00003oooooooooo`10ooooo`0300000?oooooooooo01Oooooo00<0
0000ooooooooool0=_ooool00`00003oooooooooo`0Oooooo`7o00000Oooool00003o`000?oooooo
oooo00Kooooo00<00000ooooooooool0;?ooool00`00003oooooooooo`0[ooooo`0300000?oooooo
oooo03oooooo00<00000ooooooooool06?ooool00`00003oooooooooo`0fooooo`0300000?oooooo
oooo01oooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool00`00003oooooooooo`0/oooo
o`0300000?oooooooooo02_ooooo00<00000ooooooooool0?oooool00`00003oooooooooo`0Joooo
o`0300000?oooooooooo03Cooooo00<00000ooooooooool08?ooool1o`00007ooooo00000ol0003o
ooooooooo`05ooooo`0300000?oooooooooo02cooooo00<00000ooooooooool0:oooool00`00003o
ooooooooo`0nooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool0=?ooool00`00003o
ooooooooo`0Pooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo00<00000ooooooooool0
;?ooool00`00003oooooooooo`0[ooooo`0300000?oooooooooo03kooooo00<00000ooooooooool0
7Oooool00`00003oooooooooo`0booooo`0300000?oooooooooo027ooooo0Ol00001ooooo`0000?o
0000ooooooooool00oooool00`00003oooooooooo`0]ooooo`0300000?oooooooooo02_ooooo00<0
0000ooooooooool0?Oooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo03;ooooo00<0
0000ooooooooool08Oooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`0300000?oooooo
oooo02cooooo00<00000ooooooooool0:oooool00`00003oooooooooo`0mooooo`0300000?oooooo
oooo023ooooo00<00000ooooooooool0<Oooool00`00003oooooooooo`0Qooooo`7o00000Oooool0
0003o`000?oooooooooo00;ooooo00<00000ooooooooool0;Oooool00`00003oooooooooo`0[oooo
o`0300000?oooooooooo03cooooo00<00000ooooooooool08Oooool00`00003oooooooooo`0`oooo
o`0300000?oooooooooo02;ooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool00`00003o
ooooooooo`0/ooooo`0300000?oooooooooo02_ooooo00<00000ooooooooool0??ooool00`00003o
ooooooooo`0Sooooo`0300000?oooooooooo02oooooo00<00000ooooooooool08_ooool1o`00007o
oooo00001Ol0003oooooooooooooool0000002oooooo00<00000ooooooooool0:oooool00`00003o
ooooooooo`0kooooo`0300000?oooooooooo02Cooooo00<00000ooooooooool0;_ooool00`00003o
ooooooooo`0Sooooo`7o00000Oooool00004o`000?oooooooooo000002oooooo00<00000oooooooo
ool0:oooool00`00003oooooooooo`0kooooo`0300000?oooooooooo02Gooooo00<00000oooooooo
ool0;_ooool00`00003oooooooooo`0Sooooo`7o00000Oooool00004o`000?oooooooooo000002oo
oooo00<00000ooooooooool0:Oooool2o`00000300000?oooooooooo03[ooooo00<00000oooooooo
ool09oooool00`00003oooooooooo`0]ooooo`0300000?oooooooooo02?ooooo0Ol00001ooooo`00
00?o0000ooooo`000000;oooool00`00003oooooooooo`0Zooooo``00000<_ooool00`00003ooooo
ooooo`0Xooooo`0300000?oooooooooo02cooooo00<00000ooooooooool09?ooool1o`00007ooooo
00000ol0003ooooo0000000_ooooo`0300000?oooooooooo02Oooooo0`000003o`0000Wooooo4`00
000Nooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool0:oooool00`00003ooooooooo
o`0Tooooo`7o00000Oooool00003o`000000003ooooo02kooooo00<00000ooooooooool09_ooool2
000002;ooooo4`000008ooooo`;o000000<00000ooooooooool0:oooool00`00003oooooooooo`0F
ooooo`?oo`3o4Oooool00`00003oooooooooo`0Uooooo`7o00000Oooool0000300000?oooooooooo
02kooooo00<00000ooooooooool08oooool3000003Oooooo2P0000000ol0003oooooooooo`0/oooo
o`0300000?oooooooooo01Cooooo1Ooo0?l@ooooo`0300000?oooooooooo02Gooooo0Ol00001oooo
o`0000?o0000ooooooooool0;Oooool00`00003oooooooooo`0Rooooo`800000@_ooool00ol00000
0000o`00000^ooooo`0300000?oooooooooo01Cooooo1Ooo0?l@ooooo`0300000?oooooooooo02Go
oooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool00`00003oooooooooo`0Oooooo`<00000
AOooool00`00003oooooooooo`0^ooooo`0300000?oooooooooo01?ooooo1Ooo0?l?ooooo`030000
0?oooooooooo02Kooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool00`00003ooooooooo
o`0Nooooo`800000BOooool00`00003oooooooooo`0]ooooo`0300000?oooooooooo01Cooooo0ooo
0?l@ooooo`0300000?oooooooooo02Kooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool0
0`00003oooooooooo`0Kooooo`<00000Boooool00`00003oooooooooo`0^ooooo`0300000?oooooo
oooo02Gooooo00<00000ooooooooool09oooool1o`00007ooooo00000ol0003oooooooooo`0[oooo
o`0300000?oooooooooo01[ooooo0P00001>ooooo`0300000?oooooooooo02kooooo00<00000oooo
ooooool09Oooool00`00003oooooooooo`0Wooooo`7o00000Oooool00003o`000?oooooooooo02_o
oooo00<00000ooooooooool05oooool30000053ooooo00<00000ooooooooool0;oooool00`00003o
ooooooooo`0Tooooo`0300000?oooooooooo02Oooooo0Ol00001ooooo`0000?o0000ooooooooool0
:_ooool00`00003oooooooooo`0Fooooo`800000E?ooool00`00003oooooooooo`0^ooooo`030000
0?oooooooooo02?ooooo00<00000ooooooooool0:?ooool1o`00007ooooo00000ol0003ooooooooo
o`0Zooooo`0300000?oooooooooo01?ooooo0`00001Fooooo`0300000?oooooooooo02oooooo00<0
0000ooooooooool08_ooool00`00003oooooooooo`0Xooooo`7o00000Oooool00003o`000?oooooo
oooo02Wooooo00<00000ooooooooool04Oooool3000005Wooooo00<00000ooooooooool0;oooool0
0`00003oooooooooo`0Qooooo`0300000?oooooooooo02Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0:?ooool00`00003oooooooooo`0@ooooo`800000G?ooool00`00003oooooooooo`0`oooo
o`0300000?oooooooooo023ooooo00<00000ooooooooool0:Oooool1o`00007ooooo00000ol0003o
ooooooooo`0Xooooo`0300000?oooooooooo00gooooo0`00001Nooooo`0300000?oooooooooo033o
oooo00<00000ooooooooool08?ooool00`00003oooooooooo`0Yooooo`7o00000Oooool00003o`00
0?oooooooooo02Oooooo00<00000ooooooooool03?ooool2000006;ooooo00<00000ooooooooool0
<?ooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo00gooooo0ooo0?lJooooo`7o0000
0Oooool00003o`000?oooooooooo02Oooooo00<00000ooooooooool02Oooool3000006Cooooo00<0
0000ooooooooool0<?ooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo00cooooo1Ooo
0?lIooooo`7o00000Oooool00003o`000?oooooooooo02Kooooo00<00000ooooooooool02?ooool2
000006Oooooo00<00000ooooooooool0<Oooool00`00003oooooooooo`0Looooo`0300000?oooooo
oooo00gooooo1Ooo0?lIooooo`7o00000Oooool00003o`000?oooooooooo02Kooooo00<00000oooo
ooooool01Oooool3000006Wooooo00<00000ooooooooool0<Oooool00`00003o0000o`00000Loooo
o`0300000?oooooooooo00gooooo1Ooo0?lIooooo`7o00000Oooool00003o`000?oooooooooo02Go
oooo00<00000ooooooooool01?ooool2000006gooooo00<00000ooooooooool0<?ooool00ol00000
00000000000Looooo`0300000?oooooooooo00kooooo0ooo0?lJooooo`7o00000Oooool00003o`00
0?oooooooooo02Gooooo00@00000oooooooooooooooo0`00001_ooooo`0300000?oooooooooo033o
oooo00?o000000000?l000000P00000Iooooo`0300000?oooooooooo02cooooo0Ol00001ooooo`00
00?o0000ooooooooool09?ooool00`00003oooooooooo`02000007;ooooo00<00000ooooooooool0
6Oooool3ool0oaCooooo00<00000ooooooooool00_ooool3000001Kooooo00<00000ooooooooool0
;?ooool1o`00007ooooo00000ol0003oooooooooo`0Rooooo`;o00000`00001dooooo`0300000?oo
oooooooo01Sooooo1Ooo0?lBooooo`0300000?oooooooooo00Kooooo0P00000Cooooo`0300000?oo
oooooooo02gooooo0Ol00001ooooo`0000?o0000ooooooooool08_ooool200000003o`000?oooooo
oooo07Gooooo00<00000ooooooooool05oooool5ool0oa7ooooo00<00000ooooooooool02Oooool2
0000017ooooo00<00000ooooooooool0;Oooool1o`00007ooooo00000ol0003oooooooooo`0Qoooo
o`0400000?l0003o0000o`0007Oooooo00<00000ooooooooool05oooool5ool0oa3ooooo00<00000
ooooooooool03?ooool3000000kooooo00<00000ooooooooool0;Oooool1o`00007ooooo00000ol0
003oooooooooo`0Oooooo`800000Noooool00`00003oooooooooo`0Hooooo`?oo`3o4Oooool00`00
003oooooooooo`0?ooooo`8000002oooool00`00003oooooooooo`0^ooooo`7o00000Oooool00003
o`000?oooooooooo01kooooo00<00000ooooooooool0Noooool00`00003oooooooooo`0[ooooo`03
00000?oooooooooo01;ooooo0P000009ooooo`0300000?oooooooooo02kooooo0Ol00001ooooo`00
00?o0000ooooooooool07?ooool2000007kooooo00<00000ooooooooool0:_ooool00`00003ooooo
ooooo`0Eooooo`8000001_ooool00`00003oooooooooo`0_ooooo`7o00000Oooool00003o`000?oo
oooooooo01_ooooo00<00000ooooooooool0Ooooool00`00003oooooooooo`0Xooooo`0300000?oo
oooooooo01Sooooo0`000003ooooo`0300000?oooooooooo02oooooo0Ol00001ooooo`0000?o0000
ooooooooool06Oooool20000087ooooo00?o0000000000000000:?ooool00`00003oooooooooo`0L
ooooo`80000000?o000000000?ooool0<?ooool1o`00007ooooo00000ol0003oooooooooo`0Hoooo
o`0300000?oooooooooo087ooooo00?o000000000?l000000P00000Vooooo`0300000?oooooooooo
01gooooo00?o000000000?l00000<Oooool1o`00007ooooo00000ol0003oooooooooo`0Fooooo`80
0000Q?ooool00`00003o0000o`000002ooooo`8000008oooool00`00003oooooooooo`0Nooooo`03
o`000000003o0000037ooooo0Ol00001ooooo`0000?o0000ooooooooool05Oooool00`00003ooooo
ooooo`24ooooo`0300000?oooooooooo00Cooooo0P00000Pooooo`0300000?oooooooooo027ooooo
00<00000ooooooooool0;oooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`800000Q_oo
ool00`00003oooooooooo`07ooooo`8000007Oooool00`00003oooooooooo`0Rooooo`0300000?oo
oooooooo02oooooo0Ol00001ooooo`0000?o0000ooooooooool04Oooool2000006kooooo0ooo0?lG
ooooo`0300000?oooooooooo00Wooooo0P00000Jooooo`0300000?oooooooooo02Cooooo00<00000
ooooooooool0;_ooool1o`00007ooooo00000ol0003oooooooooo`0@ooooo`0300000?oooooooooo
06gooooo1Ooo0?lEooooo`0300000?oooooooooo00cooooo0P00000Hooooo`0300000?oooooooooo
02Cooooo00<00000ooooooooool0;_ooool1o`00007ooooo00000ol0003oooooooooo`0>ooooo`80
0000L?ooool5ool0oaGooooo00<00000ooooooooool03_ooool2000001Gooooo00<00000oooooooo
ool09_ooool00`00003oooooooooo`0]ooooo`7o00000Oooool00003o`000?oooooooooo00gooooo
00<00000ooooooooool0L?ooool5ool0oaGooooo00<00000ooooooooool04?ooool2000001;ooooo
00<00000ooooooooool09oooool00`00003oooooooooo`0]ooooo`7o00000Oooool00003o`000?oo
oooooooo00_ooooo0P00001dooooo`?oo`3o5Oooool00`00003oooooooooo`0Cooooo`8000003ooo
ool00`00003oooooooooo`0Yooooo`0300000?oooooooooo02cooooo0Ol00001ooooo`0000?o0000
ooooooooool02_ooool00`00003oooooooooo`2<ooooo`0300000?oooooooooo01Gooooo0P00000<
ooooo`0300000?oooooooooo00cooooo0ooo0?lKooooo`0300000?oooooooooo02cooooo0Ol00001
ooooo`0000?o0000ooooooooool02?ooool2000008kooooo00<00000ooooooooool06?ooool20000
00[ooooo00<00000ooooooooool02oooool5ool0oa_ooooo00<00000ooooooooool0:oooool1o`00
007ooooo00000ol0003oooooooooo`07ooooo`0300000?oooooooooo08kooooo00<00000oooooooo
ool06_ooool2000000Oooooo00<00000ooooooooool03?ooool5ool0oa_ooooo00<00000oooooooo
ool0:oooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`800000T?ooool00`00003ooooo
ooooo`0Mooooo`8000001?ooool00`00003oooooooooo`0=ooooo`Goo`3o7?ooool00`00003ooooo
ooooo`0Zooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo0_l000000`00003ooooooooo
o`2@ooooo`0300000?oooooooooo01oooooo0P0000000ol000000000ooooo`0@ooooo`?oo`3o7Ooo
ool00`00003oooooooooo`0Zooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo1`00002=
ooooo`0300000?oooooooooo027ooooo00?o000000000?l00000<_ooool00`00003oooooooooo`0Y
ooooo`7o00000Oooool00003o`000?oooooooooo008000000ol00004ooooo`/00000P_ooool00`00
003oooooooooo`0Qooooo`03o`000000003o000003;ooooo00<00000ooooooooool0:Oooool1o`00
007ooooo00000ol0000000000000000Dooooo`/00000M_ooool00`00003oooooooooo`0Sooooo`03
00000?oooooooooo03;ooooo00<00000ooooooooool0:?ooool1o`00007ooooo00000`00003ooooo
ooooo`0Oooooo`/00000Joooool00`00003oooooooooo`0Tooooo`0300000?oooooooooo037ooooo
00<00000ooooooooool0:?ooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`/00000Gooo
ool00`00003oooooooooo`0Uooooo`0300000?oooooooooo03;ooooo00<00000ooooooooool09ooo
ool1o`00007ooooo00000ol0003oooooooooo`0eooooo`/00000E?ooool00`00003oooooooooo`0U
ooooo`0300000?oooooooooo03;ooooo00<00000ooooooooool09oooool1o`00007ooooo00000ol0
003oooooooooo`10ooooo`/00000B?ooool00`00003oooooooooo`0Wooooo`0300000?oooooooooo
03;ooooo00<00000ooooooooool09_ooool1o`00007ooooo00000ol0003oooooooooo`1;ooooo`X0
0000?_ooool00`00003oooooooooo`0Wooooo`0300000?oooooooooo03;ooooo00<00000oooooooo
ool09_ooool1o`00007ooooo00000ol0003oooooooooo`1Eooooo`/00000<oooool00`00003ooooo
ooooo`0Wooooo`0300000?oooooooooo03?ooooo00<00000ooooooooool09Oooool1o`00007ooooo
00000ol0003oooooooooo`1Pooooo`/000009oooool00`00003oooooooooo`0Booooo`?oo`3o5?oo
ool00`00003oooooooooo`0booooo`0300000?oooooooooo02Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0Joooool;000001cooooo00<00000ooooooooool04Oooool5ool0oa?ooooo00<00000
ooooooooool0<oooool00`00003oooooooooo`0Tooooo`7o00000Oooool00003o`000?oooooooooo
07Kooooo2`00000@ooooo`0300000?oooooooooo01;ooooo1Ooo0?lCooooo`0300000?oooooooooo
03?ooooo00<00000ooooooooool09?ooool1o`00007ooooo00000ol0003oooooooooo`21ooooo`/0
00001Oooool00`00003oooooooooo`0Booooo`Goo`3o5?ooool00`00003oooooooooo`0cooooo`03
00000?oooooooooo02?ooooo0Ol00001ooooo`0000?o0000ooooooooool0S?ooool5000001Kooooo
0ooo0?lEooooo`0300000?oooooooooo03?ooooo00<00000ooooooooool08oooool1o`00007ooooo
00000ol0003oooooooooo`2>ooooo`;o000000<00000ooooooooool0;?ooool00`00003ooooooooo
o`0dooooo`0300000?oooooooooo02;ooooo0Ol00001ooooo`0000?o0000ooooooooool0S_ooool3
o`00000300000?oooooooooo02cooooo00<00000ooooooooool0<oooool00`00003oooooooooo`0R
ooooo`7o00000Oooool00003o`000?oooooooooo097ooooo00<00000ooooooooool0;?ooool00`00
003oooooooooo`0dooooo`0300000?oooooooooo027ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0T_ooool00`00003oooooooooo`0[ooooo`0300000?oooooooooo03Cooooo00<00000oooooooo
ool08Oooool1o`00007ooooo00000ol0003oooooooooo`2Booooo`0300000?oooooooooo02_ooooo
00?o000000000?l00000=Oooool00`00003oooooooooo`0Pooooo`7o00000Oooool00003o`000?oo
oooooooo09?ooooo00<00000ooooooooool0:?ooool5000003Gooooo00<00000ooooooooool08?oo
ool1o`00007ooooo00000ol0003oooooooooo`2Cooooo`0300000?oooooooooo02;ooooo1P000002
ooooo`?o000000<00000ooooooooool0<oooool00`00003oooooooooo`0Oooooo`7o00000Oooool0
0003o`000?oooooooooo09?ooooo00<00000ooooooooool07?ooool6000000cooooo00<00000oooo
ooooool0<_ooool00`00003oooooooooo`0Oooooo`7o00000Oooool00003o`000?oooooooooo09Co
oooo00<00000ooooooooool05?ooool7000001?ooooo00<00000ooooooooool0<_ooool00`00003o
ooooooooo`0Nooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00<00000ooooooooool0
3_ooool6000001_ooooo00<00000ooooooooool0<Oooool00`00003oooooooooo`0Nooooo`7o0000
0Oooool00003o`000?oooooooooo09Gooooo00<00000ooooooooool01oooool6000002;ooooo00<0
0000ooooooooool0<Oooool00`00003oooooooooo`0Mooooo`7o00000Oooool00003o`000?oooooo
oooo09Cooooo00?o000000000?l000000_ooool6000002Wooooo00<00000ooooooooool0<?ooool0
0`00003oooooooooo`0Mooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo0_l000030000
033ooooo00<00000ooooooooool0<?ooool00`00003oooooooooo`0Looooo`7o00000Oooool00003
o`000?oooooooooo09Cooooo0ol0000cooooo`0300000?oooooooooo02oooooo00<00000oooooooo
ool07?ooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`03o`000?oooooooooo03;ooooo
00<00000ooooooooool0;oooool00`00003oooooooooo`0Kooooo`7o00000Oooool00003o`000?oo
oooooooo09Kooooo00?o0000ooooooooool0<oooool00`00003oooooooooo`0^ooooo`0300000?oo
oooooooo01_ooooo0Ol00001ooooo`0000?o0000ooooooooool0OOooool3ool0oaKooooo00?o0000
ooooooooool0=?ooool00`00003oooooooooo`0^ooooo`0300000?oooooooooo01[ooooo0Ol00001
ooooo`0000?o0000ooooooooool0O?ooool5ool0oaGooooo00?o0000ooooooooool0=Oooool00`00
003oooooooooo`0]ooooo`0300000?oooooooooo01[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0O?ooool5ool0oaGooooo00?o0000ooooooooool04_ooool3ool0ob7ooooo00<00000oooooooo
ool0;Oooool00`00003oooooooooo`0Iooooo`7o00000Oooool00003o`000?oooooooooo07cooooo
1Ooo0?lEooooo`03o`000?oooooooooo017ooooo1Ooo0?lQooooo`0300000?oooooooooo02cooooo
00<00000ooooooooool06Oooool1o`00007ooooo00000ol0003oooooooooo`1mooooo`?oo`3o5_oo
ool00ol0003oooooooooo`0Aooooo`Goo`3o8_ooool00`00003oooooooooo`0/ooooo`0300000?oo
oooooooo01Sooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool00ol0003oooooooooo`0A
ooooo`Goo`3o8oooool00`00003oooooooooo`0[ooooo`0300000?oooooooooo01Sooooo0Ol00001
ooooo`0000?o0000ooooooooool0UOooool00ol0003oooooooooo`0Cooooo`?oo`3o9Oooool00`00
003oooooooooo`0[ooooo`0300000?oooooooooo01Oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0UOooool00ol0003oooooooooo`0looooo`0300000?oooooooooo02[ooooo00<00000oooooooo
ool05oooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`000?oooooooooo03gooooo
0P00000[ooooo`0300000?oooooooooo01Kooooo0Ol00001ooooo`0000?o0000ooooooooool0UOoo
ool00ol0003oooooooooo`0oooooo`0300000?oooooooooo02Sooooo00<00000ooooooooool05_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`000?oooooooooo043ooooo00<00000
ooooooooool0:?ooool00`00003oooooooooo`0Eooooo`7o00000Oooool00003o`000?oooooooooo
09Gooooo00?o0000ooooooooool0@Oooool00`00003oooooooooo`0Wooooo`0300000?oooooooooo
01Gooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol0003oooooooooo`12ooooo`03
00000?oooooooooo02Oooooo00<00000ooooooooool05?ooool1o`00007ooooo00000ol0003ooooo
ooooo`2Eooooo`03o`000?oooooooooo04?ooooo00<00000ooooooooool09_ooool00`00003ooooo
ooooo`0Dooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o0000ooooooooool0A?oo
ool00`00003oooooooooo`0Vooooo`0300000?oooooooooo01?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0UOooool00ol0003oooooooooo`15ooooo`0300000?oooooooooo02Gooooo00<00000
ooooooooool04oooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03o`000?oooooooooo
04Kooooo00<00000ooooooooool09Oooool00`00003oooooooooo`0Booooo`7o00000Oooool00003
o`000?oooooooooo09Gooooo00?o0000ooooooooool0Aoooool00`00003oooooooooo`0Tooooo`03
00000?oooooooooo01;ooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool00ol0003ooooo
ooooo`18ooooo`0300000?oooooooooo02Cooooo00<00000ooooooooool04Oooool1o`00007ooooo
00000ol0003oooooooooo`2Eooooo`03o`000?oooooooooo04Wooooo00<00000ooooooooool08ooo
ool00`00003oooooooooo`0Aooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo00?o0000
ooooooooool0B_ooool00`00003oooooooooo`0Sooooo`0300000?oooooooooo013ooooo0Ol00001
ooooo`0000?o0000ooooooooool0UOooool00ol0003oooooooooo`1;ooooo`0300000?oooooooooo
02;ooooo00<00000ooooooooool04?ooool1o`00007ooooo00000ol0003oooooooooo`2Eooooo`03
o`000?oooooooooo04cooooo00<00000ooooooooool08_ooool00`00003oooooooooo`0?ooooo`7o
00000Oooool00003o`000?oooooooooo09Cooooo00?o0000ooooooooool0C_ooool00`00003ooooo
ooooo`0Qooooo`0300000?oooooooooo00oooooo0Ol00001ooooo`0000?o0000ooooooooool0U?oo
ool00ol0003oooooooooo`1?ooooo`0300000?oooooooooo027ooooo00<00000ooooooooool03_oo
ool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`000?oooooooooo053ooooo00<00000
ooooooooool08?ooool00`00003oooooooooo`0>ooooo`7o00000Oooool00003o`000?oooooooooo
09Cooooo00?o0000ooooooooool0DOooool00`00003oooooooooo`0Pooooo`0300000?oooooooooo
00gooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol0003oooooooooo`1Booooo`80
00008?ooool00`00003oooooooooo`0=ooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo
00?o0000ooooooooool0E?ooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo00cooooo
0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol0003oooooooooo`1Eooooo`0300000?oo
oooooooo01gooooo00<00000ooooooooool03?ooool1o`00007ooooo00000ol0003oooooooooo`2D
ooooo`03o`000?oooooooooo05Kooooo00<00000ooooooooool07Oooool00`00003oooooooooo`0;
ooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o0000ooooooooool0Eoooool00`00
003oooooooooo`0Looooo`0300000?oooooooooo00_ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0U?ooool00ol0003oooooooooo`1Hooooo`0300000?oooooooooo01cooooo00<00000oooooooo
ool02_ooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`000?oooooooooo05Wooooo
00<00000ooooooooool06oooool00`00003oooooooooo`0:ooooo`7o00000Oooool00003o`000?oo
oooooooo09Cooooo00?o0000ooooooooool0F_ooool00`00003oooooooooo`0Kooooo`0300000?oo
oooooooo00Wooooo0Ol00001ooooo`0000?o0000ooooooooool0U?ooool00ol0003oooooooooo`1K
ooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool02Oooool1o`00007ooooo00000ol0
003oooooooooo`2Dooooo`03o`000?oooooooooo05cooooo00<00000ooooooooool06_ooool00`00
003oooooooooo`08ooooo`7o00000Oooool00003o`000?oooooooooo09Cooooo00?o0000oooooooo
ool0GOooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo00Sooooo0Ol00001ooooo`00
00?o0000ooooooooool0U?ooool00ol0003oooooooooo`1Nooooo`0300000?oooooooooo01Wooooo
00<00000ooooooooool01oooool1o`00007ooooo00000ol0003oooooooooo`2Dooooo`03o`000?oo
oooooooo05oooooo00<00000ooooooooool06?ooool00`00003oooooooooo`07ooooo`7o00000Ooo
ool00003o`000?oooooooooo09Cooooo00?o0000ooooooooool0H?ooool00`00003oooooooooo`0H
ooooo`0300000?oooooooooo00Kooooo0Ol00001ooooo`0000?o0000ooooooooool0Toooool00ol0
003oooooooooo`1Rooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool01_ooool1o`00
007ooooo00000ol0003oooooooooo`2Cooooo`03o`000?oooooooooo06?ooooo00<00000oooooooo
ool05oooool00`00003oooooooooo`05ooooo`7o00000Oooool00003o`000?oooooooooo09?ooooo
00?o0000ooooooooool0I?ooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo00Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0Toooool00ol0003oooooooooo`1Uooooo`0300000?oo
oooooooo01Kooooo00<00000ooooooooool01?ooool1o`00007ooooo00000ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo06Kooooo00<00000ooooooooool05Oooool00`00003oooooooooo`04
ooooo`7o00000Oooool00003o`000?oooooooooo09?ooooo00?o0000ooooooooool0Ioooool00`00
003oooooooooo`0Eooooo`0300000?oooooooooo00?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Toooool00ol0003oooooooooo`1Xooooo`8000005Oooool00`00003oooooooooo`03ooooo`7o
00000Oooool00003o`000?oooooooooo09?ooooo00?o0000ooooooooool0J_ooool00`00003ooooo
ooooo`0Cooooo`0300000?oooooooooo00;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Tooo
ool00ol0003oooooooooo`1[ooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool00_oo
ool1o`00007ooooo00000ol0003oooooooooo`3oooooo`?ooooo00<00000ooooooooool04_ooool0
1@00003ooooooooooooooooo0000007ooooo00000ol0003oooooooooo`3oooooo`Cooooo00<00000
ooooooooool04Oooool01@00003ooooooooooooooooo0000007ooooo00000ol0003oooooooooo`3o
ooooo`Gooooo00<00000ooooooooool04Oooool01000003oooooooooool00001ooooo`0000?o0000
ooooooooool0ooooool6ooooo`0300000?oooooooooo013ooooo00@00000oooooooooooo00000Ooo
ool00003o`000?oooooooooo0?oooooo1oooool00`00003oooooooooo`0@ooooo`0300000?oooooo
0000007ooooo00000ol0003oooooooooo`3oooooo`Sooooo00<00000ooooooooool03oooool00`00
003oooooo`000001ooooo`0000?o0000ooooooooool0ooooool9ooooo`0300000?oooooooooo00oo
oooo0@000001o`00007ooooo00000ol0003oooooooooo`3oooooo`[ooooo00<00000ooooooooool0
3_ooool10000007o00000Oooool00003o`000?oooooooooo0?oooooo2oooool00`00003ooooooooo
o`0>ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo3?ooool00`00003oooooooooo`0=
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo3Oooool00`00003oooooooooo`0<oooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo3_ooool00`00003oooooooooo`0;ooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo3oooool00`00003oooooooooo`0:ooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo4?ooool00`00003oooooooooo`09ooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo4Oooool00`00003oooooooooo`08ooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo4_ooool00`00003oooooooooo`07ooooo`7o00000Oooool00?oo
00005_l000000`00003o0000o`000007o`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.00088, -1.00088, 0.00697479, \
0.00697479}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New histograms for two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Compute histograms based on data-dependent centroids", "Subsubsection"],

Cell[BoxData[{
    \(\(h1\  = Histogram[data1, vqCentroids, pr, 50];\)\), "\n", 
    \(\(h2\  = Histogram[data2, vqCentroids, pr, 50];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize two histograms", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gh1\  = 
        DrawHistogram[h1, pr, \ nS, 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(gh2\  = 
        DrawHistogram[h2, pr, \ nS, 
          Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gh1, gh2}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
%%ImageSize: 400 154.502 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.658 .748 .916 r
.39652 .66584 .40276 .67139 .4132 .66839 .40699 .66282 Mtetra
.40699 .66282 .4132 .66839 .42368 .66538 .4175 .65978 Mtetra
.4175 .65978 .42368 .66538 .43421 .66235 .42805 .65673 Mtetra
.42805 .65673 .43421 .66235 .44477 .65931 .43864 .65367 Mtetra
.43864 .65367 .44477 .65931 .45538 .65626 .44927 .6506 Mtetra
.44927 .6506 .45538 .65626 .46602 .6532 .45995 .64752 Mtetra
.45995 .64752 .46602 .6532 .47671 .65013 .47066 .64442 Mtetra
.47066 .64442 .47671 .65013 .48745 .64704 .48142 .64131 Mtetra
.48142 .64131 .48745 .64704 .49822 .64394 .49222 .63819 Mtetra
.49222 .63819 .49822 .64394 .50904 .64083 .50307 .63506 Mtetra
.50307 .63506 .50904 .64083 .5199 .63771 .51396 .63191 Mtetra
.51396 .63191 .5199 .63771 .5308 .63458 .52489 .62876 Mtetra
.52489 .62876 .5308 .63458 .54174 .63143 .53586 .62558 Mtetra
.53586 .62558 .54174 .63143 .55273 .62827 .54688 .6224 Mtetra
.54688 .6224 .55273 .62827 .56377 .6251 .55794 .61921 Mtetra
.55794 .61921 .56377 .6251 .57484 .62191 .56905 .616 Mtetra
.56905 .616 .57484 .62191 .58597 .61871 .5802 .61277 Mtetra
.5802 .61277 .58597 .61871 .59713 .6155 .5914 .60954 Mtetra
.5914 .60954 .59713 .6155 .60834 .61228 .60264 .60629 Mtetra
.60264 .60629 .60834 .61228 .6196 .60904 .61393 .60303 Mtetra
.61393 .60303 .6196 .60904 .6309 .60579 .62526 .59976 Mtetra
.62526 .59976 .6309 .60579 .64225 .60253 .63664 .59647 Mtetra
.63664 .59647 .64225 .60253 .65365 .59925 .64806 .59317 Mtetra
.64806 .59317 .65365 .59925 .66509 .59596 .65954 .58985 Mtetra
.65954 .58985 .66509 .59596 .67657 .59266 .67105 .58653 Mtetra
.67105 .58653 .67657 .59266 .68811 .58934 .68262 .58318 Mtetra
.893 .48 .078 r
.68262 .58318 .68811 .58934 .70153 .62191 .69602 .6158 Mtetra
.655 .752 .921 r
.69602 .6158 .70153 .62191 .71328 .61861 .70781 .61247 Mtetra
.70781 .61247 .71328 .61861 .72509 .61529 .71965 .60913 Mtetra
.71965 .60913 .72509 .61529 .73694 .61196 .73154 .60577 Mtetra
.73154 .60577 .73694 .61196 .74884 .60861 .74348 .6024 Mtetra
.74348 .6024 .74884 .60861 .76079 .60525 .75546 .59901 Mtetra
.75546 .59901 .76079 .60525 .7728 .60188 .7675 .59561 Mtetra
.7675 .59561 .7728 .60188 .78485 .59849 .77959 .59219 Mtetra
.77959 .59219 .78485 .59849 .79695 .59508 .79173 .58877 Mtetra
.79173 .58877 .79695 .59508 .8091 .59167 .80392 .58532 Mtetra
.80392 .58532 .8091 .59167 .82131 .58824 .81616 .58186 Mtetra
.81616 .58186 .82131 .58824 .83357 .58479 .82845 .57839 Mtetra
.82845 .57839 .83357 .58479 .84588 .58133 .8408 .5749 Mtetra
.8408 .5749 .84588 .58133 .85824 .57786 .8532 .5714 Mtetra
.8532 .5714 .85824 .57786 .87065 .57437 .86565 .56788 Mtetra
.86565 .56788 .87065 .57437 .88312 .57086 .87815 .56435 Mtetra
.87815 .56435 .88312 .57086 .89564 .56734 .89071 .5608 Mtetra
.89071 .5608 .89564 .56734 .90821 .56381 .90333 .55724 Mtetra
.90333 .55724 .90821 .56381 .92084 .56026 .91599 .55366 Mtetra
.91599 .55366 .92084 .56026 .93352 .55669 .92872 .55007 Mtetra
.92872 .55007 .93352 .55669 .94626 .55311 .94149 .54646 Mtetra
.935 .578 .167 r
.94149 .54646 .94626 .55311 .95905 .54951 .96779 .64834 Mtetra
.559 .33 .525 r
.96779 .64834 .95905 .54951 .98588 .65131 .98111 .64482 Mtetra
.646 .762 .934 r
.98111 .64482 .98588 .65131 .99922 .6478 .99449 .64129 Mtetra
.658 .748 .916 r
.39025 .66025 .39652 .66584 .40699 .66282 .40074 .6572 Mtetra
.40074 .6572 .40699 .66282 .4175 .65978 .41127 .65414 Mtetra
.41127 .65414 .4175 .65978 .42805 .65673 .42185 .65107 Mtetra
.42185 .65107 .42805 .65673 .43864 .65367 .43247 .64799 Mtetra
.43247 .64799 .43864 .65367 .44927 .6506 .44313 .6449 Mtetra
.44313 .6449 .44927 .6506 .45995 .64752 .45383 .64179 Mtetra
.45383 .64179 .45995 .64752 .47066 .64442 .46457 .63867 Mtetra
.46457 .63867 .47066 .64442 .48142 .64131 .47536 .63554 Mtetra
.47536 .63554 .48142 .64131 .49222 .63819 .48619 .6324 Mtetra
.48619 .6324 .49222 .63819 .50307 .63506 .49706 .62924 Mtetra
.49706 .62924 .50307 .63506 .51396 .63191 .50797 .62607 Mtetra
.50797 .62607 .51396 .63191 .52489 .62876 .51893 .62289 Mtetra
.51893 .62289 .52489 .62876 .53586 .62558 .52994 .6197 Mtetra
.52994 .6197 .53586 .62558 .54688 .6224 .54098 .61649 Mtetra
.54098 .61649 .54688 .6224 .55794 .61921 .55207 .61327 Mtetra
.55207 .61327 .55794 .61921 .56905 .616 .56321 .61004 Mtetra
.56321 .61004 .56905 .616 .5802 .61277 .57439 .60679 Mtetra
.57439 .60679 .5802 .61277 .5914 .60954 .58562 .60353 Mtetra
.58562 .60353 .5914 .60954 .60264 .60629 .59689 .60026 Mtetra
.59689 .60026 .60264 .60629 .61393 .60303 .60821 .59698 Mtetra
.60821 .59698 .61393 .60303 .62526 .59976 .61957 .59368 Mtetra
.61957 .59368 .62526 .59976 .63664 .59647 .63098 .59036 Mtetra
.63098 .59036 .63664 .59647 .64806 .59317 .64244 .58704 Mtetra
.64244 .58704 .64806 .59317 .65954 .58985 .65394 .5837 Mtetra
.65394 .5837 .65954 .58985 .67105 .58653 .66549 .58035 Mtetra
.66549 .58035 .67105 .58653 .68262 .58318 .67709 .57698 Mtetra
.893 .48 .078 r
.67709 .57698 .68262 .58318 .69602 .6158 .69048 .60964 Mtetra
.655 .752 .921 r
.69048 .60964 .69602 .6158 .70781 .61247 .7023 .60628 Mtetra
.7023 .60628 .70781 .61247 .71965 .60913 .71417 .60292 Mtetra
.71417 .60292 .71965 .60913 .73154 .60577 .72609 .59953 Mtetra
.72609 .59953 .73154 .60577 .74348 .6024 .73807 .59613 Mtetra
.73807 .59613 .74348 .6024 .75546 .59901 .75009 .59272 Mtetra
.75009 .59272 .75546 .59901 .7675 .59561 .76216 .58929 Mtetra
.76216 .58929 .7675 .59561 .77959 .59219 .77429 .58585 Mtetra
.77429 .58585 .77959 .59219 .79173 .58877 .78646 .5824 Mtetra
.78646 .5824 .79173 .58877 .80392 .58532 .79869 .57893 Mtetra
.79869 .57893 .80392 .58532 .81616 .58186 .81097 .57544 Mtetra
.81097 .57544 .81616 .58186 .82845 .57839 .8233 .57194 Mtetra
.8233 .57194 .82845 .57839 .8408 .5749 .83568 .56843 Mtetra
.83568 .56843 .8408 .5749 .8532 .5714 .84812 .5649 Mtetra
.84812 .5649 .8532 .5714 .86565 .56788 .86061 .56135 Mtetra
.86061 .56135 .86565 .56788 .87815 .56435 .87315 .55779 Mtetra
.87315 .55779 .87815 .56435 .89071 .5608 .88575 .55421 Mtetra
.88575 .55421 .89071 .5608 .90333 .55724 .8984 .55062 Mtetra
.8984 .55062 .90333 .55724 .91599 .55366 .91111 .54702 Mtetra
.91111 .54702 .91599 .55366 .92872 .55007 .92387 .54339 Mtetra
.938 .582 .177 r
.92387 .54339 .92872 .55007 .94149 .54646 .94963 .64537 Mtetra
.558 .329 .524 r
.94963 .64537 .94149 .54646 .96779 .64834 .96293 .64183 Mtetra
.646 .762 .934 r
.96293 .64183 .96779 .64834 .98111 .64482 .9763 .63829 Mtetra
.986 .713 .406 r
.9763 .63829 .98111 .64482 .99449 .64129 .97174 .50096 Mtetra
.658 .748 .916 r
.38392 .65462 .39025 .66025 .40074 .6572 .39444 .65155 Mtetra
.39444 .65155 .40074 .6572 .41127 .65414 .405 .64847 Mtetra
.405 .64847 .41127 .65414 .42185 .65107 .4156 .64537 Mtetra
.4156 .64537 .42185 .65107 .43247 .64799 .42625 .64227 Mtetra
.42625 .64227 .43247 .64799 .44313 .6449 .43693 .63915 Mtetra
.43693 .63915 .44313 .6449 .45383 .64179 .44766 .63602 Mtetra
.44766 .63602 .45383 .64179 .46457 .63867 .45843 .63288 Mtetra
.45843 .63288 .46457 .63867 .47536 .63554 .46925 .62973 Mtetra
.46925 .62973 .47536 .63554 .48619 .6324 .4801 .62656 Mtetra
.4801 .62656 .48619 .6324 .49706 .62924 .491 .62338 Mtetra
.491 .62338 .49706 .62924 .50797 .62607 .50195 .62019 Mtetra
.50195 .62019 .50797 .62607 .51893 .62289 .51293 .61698 Mtetra
.51293 .61698 .51893 .62289 .52994 .6197 .52397 .61377 Mtetra
.52397 .61377 .52994 .6197 .54098 .61649 .53504 .61054 Mtetra
.53504 .61054 .54098 .61649 .55207 .61327 .54616 .60729 Mtetra
.54616 .60729 .55207 .61327 .56321 .61004 .55733 .60404 Mtetra
.55733 .60404 .56321 .61004 .57439 .60679 .56854 .60077 Mtetra
.56854 .60077 .57439 .60679 .58562 .60353 .5798 .59748 Mtetra
.5798 .59748 .58562 .60353 .59689 .60026 .5911 .59419 Mtetra
.5911 .59419 .59689 .60026 .60821 .59698 .60245 .59087 Mtetra
.60245 .59087 .60821 .59698 .61957 .59368 .61384 .58755 Mtetra
.61384 .58755 .61957 .59368 .63098 .59036 .62528 .58421 Mtetra
.62528 .58421 .63098 .59036 .64244 .58704 .63677 .58086 Mtetra
.63677 .58086 .64244 .58704 .65394 .5837 .64831 .5775 Mtetra
.64831 .5775 .65394 .5837 .66549 .58035 .65989 .57412 Mtetra
.65989 .57412 .66549 .58035 .67709 .57698 .67152 .57073 Mtetra
.893 .48 .078 r
.67152 .57073 .67709 .57698 .69048 .60964 .68489 .60343 Mtetra
.655 .752 .921 r
.68489 .60343 .69048 .60964 .7023 .60628 .69675 .60005 Mtetra
.69675 .60005 .7023 .60628 .71417 .60292 .70865 .59666 Mtetra
.70865 .59666 .71417 .60292 .72609 .59953 .72061 .59325 Mtetra
.72061 .59325 .72609 .59953 .73807 .59613 .73262 .58982 Mtetra
.73262 .58982 .73807 .59613 .75009 .59272 .74467 .58638 Mtetra
.74467 .58638 .75009 .59272 .76216 .58929 .75678 .58293 Mtetra
.75678 .58293 .76216 .58929 .77429 .58585 .76894 .57946 Mtetra
.76894 .57946 .77429 .58585 .78646 .5824 .78115 .57598 Mtetra
.78115 .57598 .78646 .5824 .79869 .57893 .79342 .57248 Mtetra
.79342 .57248 .79869 .57893 .81097 .57544 .80573 .56897 Mtetra
.80573 .56897 .81097 .57544 .8233 .57194 .8181 .56544 Mtetra
.8181 .56544 .8233 .57194 .83568 .56843 .83052 .5619 Mtetra
.83052 .5619 .83568 .56843 .84812 .5649 .843 .55834 Mtetra
.843 .55834 .84812 .5649 .86061 .56135 .85553 .55477 Mtetra
.85553 .55477 .86061 .56135 .87315 .55779 .86811 .55118 Mtetra
.86811 .55118 .87315 .55779 .88575 .55421 .88075 .54757 Mtetra
.88075 .54757 .88575 .55421 .8984 .55062 .89344 .54395 Mtetra
.89344 .54395 .8984 .55062 .91111 .54702 .90619 .54032 Mtetra
.941 .586 .188 r
.90619 .54032 .91111 .54702 .92387 .54339 .93139 .64238 Mtetra
.556 .327 .522 r
.93139 .64238 .92387 .54339 .94963 .64537 .94469 .63883 Mtetra
.646 .762 .934 r
.94469 .63883 .94963 .64537 .96293 .64183 .95804 .63527 Mtetra
.95804 .63527 .96293 .64183 .9763 .63829 .97145 .63169 Mtetra
.986 .713 .406 r
.97145 .63169 .9763 .63829 .97174 .50096 .96705 .49406 Mtetra
.658 .748 .916 r
.37755 .64894 .38392 .65462 .39444 .65155 .3881 .64585 Mtetra
.3881 .64585 .39444 .65155 .405 .64847 .39868 .64275 Mtetra
.39868 .64275 .405 .64847 .4156 .64537 .40931 .63963 Mtetra
.40931 .63963 .4156 .64537 .42625 .64227 .41998 .63651 Mtetra
.41998 .63651 .42625 .64227 .43693 .63915 .4307 .63337 Mtetra
.4307 .63337 .43693 .63915 .44766 .63602 .44145 .63021 Mtetra
.44145 .63021 .44766 .63602 .45843 .63288 .45225 .62705 Mtetra
.45225 .62705 .45843 .63288 .46925 .62973 .46309 .62387 Mtetra
.46309 .62387 .46925 .62973 .4801 .62656 .47397 .62068 Mtetra
.47397 .62068 .4801 .62656 .491 .62338 .4849 .61748 Mtetra
.4849 .61748 .491 .62338 .50195 .62019 .49587 .61426 Mtetra
.49587 .61426 .50195 .62019 .51293 .61698 .50689 .61103 Mtetra
.50689 .61103 .51293 .61698 .52397 .61377 .51795 .60779 Mtetra
.51795 .60779 .52397 .61377 .53504 .61054 .52906 .60454 Mtetra
.52906 .60454 .53504 .61054 .54616 .60729 .54021 .60127 Mtetra
.54021 .60127 .54616 .60729 .55733 .60404 .5514 .59799 Mtetra
.5514 .59799 .55733 .60404 .56854 .60077 .56264 .59469 Mtetra
.56264 .59469 .56854 .60077 .5798 .59748 .57393 .59138 Mtetra
.57393 .59138 .5798 .59748 .5911 .59419 .58526 .58806 Mtetra
.58526 .58806 .5911 .59419 .60245 .59087 .59664 .58473 Mtetra
.59664 .58473 .60245 .59087 .61384 .58755 .60807 .58138 Mtetra
.60807 .58138 .61384 .58755 .62528 .58421 .61954 .57802 Mtetra
.61954 .57802 .62528 .58421 .63677 .58086 .63106 .57464 Mtetra
.63106 .57464 .63677 .58086 .64831 .5775 .64263 .57125 Mtetra
.64263 .57125 .64831 .5775 .65989 .57412 .65425 .56784 Mtetra
.65425 .56784 .65989 .57412 .67152 .57073 .66591 .56443 Mtetra
.893 .48 .078 r
.66591 .56443 .67152 .57073 .68489 .60343 .67926 .59718 Mtetra
.655 .752 .921 r
.67926 .59718 .68489 .60343 .69675 .60005 .69115 .59377 Mtetra
.69115 .59377 .69675 .60005 .70865 .59666 .70309 .59035 Mtetra
.70309 .59035 .70865 .59666 .72061 .59325 .71508 .58691 Mtetra
.71508 .58691 .72061 .59325 .73262 .58982 .72712 .58346 Mtetra
.72712 .58346 .73262 .58982 .74467 .58638 .73922 .58 Mtetra
.73922 .58 .74467 .58638 .75678 .58293 .75136 .57652 Mtetra
.75136 .57652 .75678 .58293 .76894 .57946 .76356 .57302 Mtetra
.76356 .57302 .76894 .57946 .78115 .57598 .77581 .56951 Mtetra
.77581 .56951 .78115 .57598 .79342 .57248 .78811 .56598 Mtetra
.78811 .56598 .79342 .57248 .80573 .56897 .80046 .56244 Mtetra
.80046 .56244 .80573 .56897 .8181 .56544 .81287 .55889 Mtetra
.81287 .55889 .8181 .56544 .83052 .5619 .82533 .55532 Mtetra
.82533 .55532 .83052 .5619 .843 .55834 .83784 .55173 Mtetra
.83784 .55173 .843 .55834 .85553 .55477 .85041 .54813 Mtetra
.85041 .54813 .85553 .55477 .86811 .55118 .86303 .54451 Mtetra
.86303 .54451 .86811 .55118 .88075 .54757 .87571 .54088 Mtetra
.87571 .54088 .88075 .54757 .89344 .54395 .88844 .53723 Mtetra
.944 .59 .198 r
.88844 .53723 .89344 .54395 .90619 .54032 .91309 .63938 Mtetra
.555 .325 .521 r
.91309 .63938 .90619 .54032 .93139 .64238 .92637 .63582 Mtetra
.646 .762 .934 r
.92637 .63582 .93139 .64238 .94469 .63883 .9397 .63225 Mtetra
.9397 .63225 .94469 .63883 .95804 .63527 .9531 .62865 Mtetra
.986 .714 .412 r
.9531 .62865 .95804 .63527 .97145 .63169 .94937 .49088 Mtetra
.581 .39 .587 r
.94937 .49088 .97145 .63169 .96705 .49406 .96232 .4871 Mtetra
.658 .748 .916 r
.37114 .64323 .37755 .64894 .3881 .64585 .38171 .64011 Mtetra
.38171 .64011 .3881 .64585 .39868 .64275 .39232 .63699 Mtetra
.39232 .63699 .39868 .64275 .40931 .63963 .40298 .63385 Mtetra
.40298 .63385 .40931 .63963 .41998 .63651 .41367 .6307 Mtetra
.41367 .6307 .41998 .63651 .4307 .63337 .42441 .62754 Mtetra
.42441 .62754 .4307 .63337 .44145 .63021 .43519 .62436 Mtetra
.43519 .62436 .44145 .63021 .45225 .62705 .44602 .62117 Mtetra
.44602 .62117 .45225 .62705 .46309 .62387 .45689 .61797 Mtetra
.45689 .61797 .46309 .62387 .47397 .62068 .4678 .61476 Mtetra
.4678 .61476 .47397 .62068 .4849 .61748 .47876 .61153 Mtetra
.47876 .61153 .4849 .61748 .49587 .61426 .48976 .60829 Mtetra
.48976 .60829 .49587 .61426 .50689 .61103 .5008 .60504 Mtetra
.5008 .60504 .50689 .61103 .51795 .60779 .51189 .60177 Mtetra
.51189 .60177 .51795 .60779 .52906 .60454 .52303 .59849 Mtetra
.52303 .59849 .52906 .60454 .54021 .60127 .53421 .5952 Mtetra
.53421 .5952 .54021 .60127 .5514 .59799 .54543 .59189 Mtetra
.54543 .59189 .5514 .59799 .56264 .59469 .5567 .58858 Mtetra
.5567 .58858 .56264 .59469 .57393 .59138 .56802 .58524 Mtetra
.56802 .58524 .57393 .59138 .58526 .58806 .57939 .5819 Mtetra
.57939 .5819 .58526 .58806 .59664 .58473 .5908 .57853 Mtetra
.5908 .57853 .59664 .58473 .60807 .58138 .60225 .57516 Mtetra
.60225 .57516 .60807 .58138 .61954 .57802 .61376 .57177 Mtetra
.61376 .57177 .61954 .57802 .63106 .57464 .62531 .56837 Mtetra
.62531 .56837 .63106 .57464 .64263 .57125 .63691 .56495 Mtetra
.63691 .56495 .64263 .57125 .65425 .56784 .64856 .56152 Mtetra
.64856 .56152 .65425 .56784 .66591 .56443 .66026 .55808 Mtetra
.893 .48 .078 r
.66026 .55808 .66591 .56443 .67926 .59718 .67358 .59088 Mtetra
.655 .752 .921 r
.67358 .59088 .67926 .59718 .69115 .59377 .68551 .58744 Mtetra
.68551 .58744 .69115 .59377 .70309 .59035 .69748 .58399 Mtetra
.69748 .58399 .70309 .59035 .71508 .58691 .70951 .58053 Mtetra
.70951 .58053 .71508 .58691 .72712 .58346 .72159 .57705 Mtetra
.72159 .57705 .72712 .58346 .73922 .58 .73372 .57356 Mtetra
.73372 .57356 .73922 .58 .75136 .57652 .7459 .57005 Mtetra
.7459 .57005 .75136 .57652 .76356 .57302 .75813 .56653 Mtetra
.75813 .56653 .76356 .57302 .77581 .56951 .77041 .56299 Mtetra
.77041 .56299 .77581 .56951 .78811 .56598 .78275 .55944 Mtetra
.78275 .55944 .78811 .56598 .80046 .56244 .79514 .55587 Mtetra
.79514 .55587 .80046 .56244 .81287 .55889 .80759 .55228 Mtetra
.80759 .55228 .81287 .55889 .82533 .55532 .82009 .54868 Mtetra
.82009 .54868 .82533 .55532 .83784 .55173 .83264 .54507 Mtetra
.83264 .54507 .83784 .55173 .85041 .54813 .84524 .54144 Mtetra
.84524 .54144 .85041 .54813 .86303 .54451 .85791 .53779 Mtetra
.85791 .53779 .86303 .54451 .87571 .54088 .87062 .53413 Mtetra
.946 .594 .208 r
.87062 .53413 .87571 .54088 .88844 .53723 .89472 .63637 Mtetra
.554 .323 .519 r
.89472 .63637 .88844 .53723 .91309 .63938 .90798 .6328 Mtetra
.646 .762 .934 r
.90798 .6328 .91309 .63938 .92637 .63582 .9213 .62921 Mtetra
.9213 .62921 .92637 .63582 .9397 .63225 .93468 .6256 Mtetra
.93468 .6256 .9397 .63225 .9531 .62865 .94812 .62198 Mtetra
.986 .714 .412 r
.94812 .62198 .9531 .62865 .94937 .49088 .94456 .48389 Mtetra
.658 .749 .917 r
.94456 .48389 .94937 .49088 .96232 .4871 .95756 .48009 Mtetra
.658 .748 .916 r
.36468 .63747 .37114 .64323 .38171 .64011 .37527 .63433 Mtetra
.37527 .63433 .38171 .64011 .39232 .63699 .38591 .63119 Mtetra
.38591 .63119 .39232 .63699 .40298 .63385 .39659 .62802 Mtetra
.39659 .62802 .40298 .63385 .41367 .6307 .40731 .62485 Mtetra
.40731 .62485 .41367 .6307 .42441 .62754 .41808 .62166 Mtetra
.41808 .62166 .42441 .62754 .43519 .62436 .42889 .61847 Mtetra
.42889 .61847 .43519 .62436 .44602 .62117 .43974 .61525 Mtetra
.43974 .61525 .44602 .62117 .45689 .61797 .45064 .61203 Mtetra
.45064 .61203 .45689 .61797 .4678 .61476 .46158 .60879 Mtetra
.46158 .60879 .4678 .61476 .47876 .61153 .47257 .60554 Mtetra
.47257 .60554 .47876 .61153 .48976 .60829 .48359 .60228 Mtetra
.48359 .60228 .48976 .60829 .5008 .60504 .49467 .599 Mtetra
.49467 .599 .5008 .60504 .51189 .60177 .50579 .59571 Mtetra
.50579 .59571 .51189 .60177 .52303 .59849 .51695 .5924 Mtetra
.51695 .5924 .52303 .59849 .53421 .5952 .52816 .58909 Mtetra
.52816 .58909 .53421 .5952 .54543 .59189 .53942 .58576 Mtetra
.53942 .58576 .54543 .59189 .5567 .58858 .55072 .58241 Mtetra
.55072 .58241 .5567 .58858 .56802 .58524 .56207 .57905 Mtetra
.56207 .57905 .56802 .58524 .57939 .5819 .57346 .57568 Mtetra
.57346 .57568 .57939 .5819 .5908 .57853 .5849 .57229 Mtetra
.5849 .57229 .5908 .57853 .60225 .57516 .59639 .56889 Mtetra
.59639 .56889 .60225 .57516 .61376 .57177 .60793 .56548 Mtetra
.60793 .56548 .61376 .57177 .62531 .56837 .61951 .56205 Mtetra
.61951 .56205 .62531 .56837 .63691 .56495 .63115 .55861 Mtetra
.63115 .55861 .63691 .56495 .64856 .56152 .64283 .55515 Mtetra
.64283 .55515 .64856 .56152 .66026 .55808 .65456 .55168 Mtetra
.893 .48 .078 r
.65456 .55168 .66026 .55808 .67358 .59088 .66786 .58453 Mtetra
.655 .752 .921 r
.66786 .58453 .67358 .59088 .68551 .58744 .67982 .58106 Mtetra
.67982 .58106 .68551 .58744 .69748 .58399 .69183 .57759 Mtetra
.69183 .57759 .69748 .58399 .70951 .58053 .70389 .5741 Mtetra
.70389 .5741 .70951 .58053 .72159 .57705 .71601 .57059 Mtetra
.71601 .57059 .72159 .57705 .73372 .57356 .72817 .56707 Mtetra
.72817 .56707 .73372 .57356 .7459 .57005 .74039 .56353 Mtetra
.74039 .56353 .7459 .57005 .75813 .56653 .75266 .55998 Mtetra
.75266 .55998 .75813 .56653 .77041 .56299 .76498 .55642 Mtetra
.76498 .55642 .77041 .56299 .78275 .55944 .77736 .55283 Mtetra
.77736 .55283 .78275 .55944 .79514 .55587 .78978 .54924 Mtetra
.78978 .54924 .79514 .55587 .80759 .55228 .80227 .54562 Mtetra
.80227 .54562 .80759 .55228 .82009 .54868 .8148 .542 Mtetra
.8148 .542 .82009 .54868 .83264 .54507 .82739 .53835 Mtetra
.82739 .53835 .83264 .54507 .84524 .54144 .84004 .53469 Mtetra
.84004 .53469 .84524 .54144 .85791 .53779 .85274 .53102 Mtetra
.949 .598 .217 r
.85274 .53102 .85791 .53779 .87062 .53413 .87628 .63335 Mtetra
.552 .321 .518 r
.87628 .63335 .87062 .53413 .89472 .63637 .88952 .62976 Mtetra
.646 .762 .934 r
.88952 .62976 .89472 .63637 .90798 .6328 .90283 .62616 Mtetra
.90283 .62616 .90798 .6328 .9213 .62921 .91619 .62254 Mtetra
.91619 .62254 .9213 .62921 .93468 .6256 .92962 .61891 Mtetra
.985 .714 .418 r
.92962 .61891 .93468 .6256 .94812 .62198 .92673 .48067 Mtetra
.579 .387 .585 r
.92673 .48067 .94812 .62198 .94456 .48389 .93971 .47685 Mtetra
.658 .749 .917 r
.93971 .47685 .94456 .48389 .95756 .48009 .95275 .47301 Mtetra
.658 .748 .916 r
.35817 .63167 .36468 .63747 .37527 .63433 .36879 .62851 Mtetra
.36879 .62851 .37527 .63433 .38591 .63119 .37945 .62534 Mtetra
.37945 .62534 .38591 .63119 .39659 .62802 .39016 .62216 Mtetra
.39016 .62216 .39659 .62802 .40731 .62485 .40091 .61896 Mtetra
.40091 .61896 .40731 .62485 .41808 .62166 .4117 .61575 Mtetra
.4117 .61575 .41808 .62166 .42889 .61847 .42254 .61253 Mtetra
.42254 .61253 .42889 .61847 .43974 .61525 .43342 .60929 Mtetra
.43342 .60929 .43974 .61525 .45064 .61203 .44435 .60604 Mtetra
.44435 .60604 .45064 .61203 .46158 .60879 .45531 .60278 Mtetra
.45531 .60278 .46158 .60879 .47257 .60554 .46633 .5995 Mtetra
.46633 .5995 .47257 .60554 .48359 .60228 .47739 .59622 Mtetra
.47739 .59622 .48359 .60228 .49467 .599 .48849 .59291 Mtetra
.48849 .59291 .49467 .599 .50579 .59571 .49964 .5896 Mtetra
.49964 .5896 .50579 .59571 .51695 .5924 .51083 .58627 Mtetra
.51083 .58627 .51695 .5924 .52816 .58909 .52207 .58293 Mtetra
.52207 .58293 .52816 .58909 .53942 .58576 .53336 .57957 Mtetra
.53336 .57957 .53942 .58576 .55072 .58241 .54469 .5762 Mtetra
.54469 .5762 .55072 .58241 .56207 .57905 .55607 .57282 Mtetra
.55607 .57282 .56207 .57905 .57346 .57568 .56749 .56942 Mtetra
.56749 .56942 .57346 .57568 .5849 .57229 .57897 .56601 Mtetra
.57897 .56601 .5849 .57229 .59639 .56889 .59049 .56258 Mtetra
.59049 .56258 .59639 .56889 .60793 .56548 .60206 .55914 Mtetra
.60206 .55914 .60793 .56548 .61951 .56205 .61367 .55568 Mtetra
.61367 .55568 .61951 .56205 .63115 .55861 .62534 .55221 Mtetra
.62534 .55221 .63115 .55861 .64283 .55515 .63705 .54873 Mtetra
.63705 .54873 .64283 .55515 .65456 .55168 .64882 .54523 Mtetra
.893 .48 .078 r
.64882 .54523 .65456 .55168 .66786 .58453 .6621 .57812 Mtetra
.655 .752 .921 r
.6621 .57812 .66786 .58453 .67982 .58106 .67409 .57463 Mtetra
.67409 .57463 .67982 .58106 .69183 .57759 .68614 .57113 Mtetra
.68614 .57113 .69183 .57759 .70389 .5741 .69823 .56761 Mtetra
.69823 .56761 .70389 .5741 .71601 .57059 .71038 .56408 Mtetra
.71038 .56408 .71601 .57059 .72817 .56707 .72258 .56053 Mtetra
.72258 .56053 .72817 .56707 .74039 .56353 .73484 .55697 Mtetra
.73484 .55697 .74039 .56353 .75266 .55998 .74714 .55339 Mtetra
.74714 .55339 .75266 .55998 .76498 .55642 .7595 .54979 Mtetra
.7595 .54979 .76498 .55642 .77736 .55283 .77192 .54618 Mtetra
.77192 .54618 .77736 .55283 .78978 .54924 .78438 .54256 Mtetra
.78438 .54256 .78978 .54924 .80227 .54562 .7969 .53891 Mtetra
.7969 .53891 .80227 .54562 .8148 .542 .80948 .53526 Mtetra
.80948 .53526 .8148 .542 .82739 .53835 .82211 .53158 Mtetra
.82211 .53158 .82739 .53835 .84004 .53469 .83479 .52789 Mtetra
.95 .601 .227 r
.83479 .52789 .84004 .53469 .85274 .53102 .85777 .63031 Mtetra
.551 .319 .516 r
.85777 .63031 .85274 .53102 .87628 .63335 .87099 .62671 Mtetra
.646 .762 .934 r
.87099 .62671 .87628 .63335 .88952 .62976 .88428 .6231 Mtetra
.88428 .6231 .88952 .62976 .90283 .62616 .89763 .61947 Mtetra
.89763 .61947 .90283 .62616 .91619 .62254 .91104 .61582 Mtetra
.91104 .61582 .91619 .62254 .92962 .61891 .92451 .61215 Mtetra
.985 .714 .418 r
.92451 .61215 .92962 .61891 .92673 .48067 .9218 .47361 Mtetra
.658 .749 .917 r
.9218 .47361 .92673 .48067 .93971 .47685 .93482 .46975 Mtetra
.93482 .46975 .93971 .47685 .95275 .47301 .94791 .46589 Mtetra
.658 .748 .916 r
.35161 .62583 .35817 .63167 .36879 .62851 .36226 .62265 Mtetra
.36226 .62265 .36879 .62851 .37945 .62534 .37295 .61945 Mtetra
.37295 .61945 .37945 .62534 .39016 .62216 .38368 .61624 Mtetra
.38368 .61624 .39016 .62216 .40091 .61896 .39446 .61302 Mtetra
.39446 .61302 .40091 .61896 .4117 .61575 .40528 .60979 Mtetra
.40528 .60979 .4117 .61575 .42254 .61253 .41614 .60654 Mtetra
.41614 .60654 .42254 .61253 .43342 .60929 .42705 .60328 Mtetra
.42705 .60328 .43342 .60929 .44435 .60604 .438 .60001 Mtetra
.438 .60001 .44435 .60604 .45531 .60278 .449 .59672 Mtetra
.449 .59672 .45531 .60278 .46633 .5995 .46004 .59342 Mtetra
.46004 .59342 .46633 .5995 .47739 .59622 .47113 .59011 Mtetra
.47113 .59011 .47739 .59622 .48849 .59291 .48226 .58678 Mtetra
.48226 .58678 .48849 .59291 .49964 .5896 .49344 .58344 Mtetra
.49344 .58344 .49964 .5896 .51083 .58627 .50466 .58009 Mtetra
.50466 .58009 .51083 .58627 .52207 .58293 .51593 .57672 Mtetra
.51593 .57672 .52207 .58293 .53336 .57957 .52725 .57334 Mtetra
.52725 .57334 .53336 .57957 .54469 .5762 .53861 .56994 Mtetra
.53861 .56994 .54469 .5762 .55607 .57282 .55002 .56653 Mtetra
.55002 .56653 .55607 .57282 .56749 .56942 .56148 .56311 Mtetra
.56148 .56311 .56749 .56942 .57897 .56601 .57298 .55967 Mtetra
.57298 .55967 .57897 .56601 .59049 .56258 .58454 .55622 Mtetra
.58454 .55622 .59049 .56258 .60206 .55914 .59614 .55275 Mtetra
.59614 .55275 .60206 .55914 .61367 .55568 .60779 .54927 Mtetra
.60779 .54927 .61367 .55568 .62534 .55221 .61948 .54577 Mtetra
.61948 .54577 .62534 .55221 .63705 .54873 .63123 .54226 Mtetra
.63123 .54226 .63705 .54873 .64882 .54523 .64303 .53874 Mtetra
.893 .48 .078 r
.64303 .53874 .64882 .54523 .6621 .57812 .65629 .57167 Mtetra
.655 .752 .921 r
.65629 .57167 .6621 .57812 .67409 .57463 .66832 .56815 Mtetra
.66832 .56815 .67409 .57463 .68614 .57113 .6804 .56462 Mtetra
.6804 .56462 .68614 .57113 .69823 .56761 .69253 .56108 Mtetra
.69253 .56108 .69823 .56761 .71038 .56408 .70471 .55752 Mtetra
.70471 .55752 .71038 .56408 .72258 .56053 .71695 .55394 Mtetra
.71695 .55394 .72258 .56053 .73484 .55697 .72924 .55035 Mtetra
.72924 .55035 .73484 .55697 .74714 .55339 .74159 .54674 Mtetra
.74159 .54674 .74714 .55339 .7595 .54979 .75398 .54311 Mtetra
.75398 .54311 .7595 .54979 .77192 .54618 .76643 .53947 Mtetra
.76643 .53947 .77192 .54618 .78438 .54256 .77894 .53582 Mtetra
.77894 .53582 .78438 .54256 .7969 .53891 .7915 .53215 Mtetra
.7915 .53215 .7969 .53891 .80948 .53526 .80411 .52846 Mtetra
.80411 .52846 .80948 .53526 .82211 .53158 .81678 .52476 Mtetra
.952 .604 .236 r
.81678 .52476 .82211 .53158 .83479 .52789 .83918 .62727 Mtetra
.55 .317 .515 r
.83918 .62727 .83479 .52789 .85777 .63031 .8524 .62366 Mtetra
.646 .762 .934 r
.8524 .62366 .85777 .63031 .87099 .62671 .86567 .62003 Mtetra
.86567 .62003 .87099 .62671 .88428 .6231 .879 .61638 Mtetra
.879 .61638 .88428 .6231 .89763 .61947 .89239 .61272 Mtetra
.89239 .61272 .89763 .61947 .91104 .61582 .90584 .60904 Mtetra
.985 .715 .424 r
.90584 .60904 .91104 .61582 .92451 .61215 .90382 .47035 Mtetra
.577 .384 .583 r
.90382 .47035 .92451 .61215 .9218 .47361 .91683 .46648 Mtetra
.658 .749 .917 r
.91683 .46648 .9218 .47361 .93482 .46975 .9299 .4626 Mtetra
.9299 .4626 .93482 .46975 .94791 .46589 .94302 .4587 Mtetra
.658 .748 .916 r
.345 .61994 .35161 .62583 .36226 .62265 .35568 .61674 Mtetra
.35568 .61674 .36226 .62265 .37295 .61945 .36639 .61352 Mtetra
.36639 .61352 .37295 .61945 .38368 .61624 .37716 .61029 Mtetra
.37716 .61029 .38368 .61624 .39446 .61302 .38796 .60704 Mtetra
.38796 .60704 .39446 .61302 .40528 .60979 .39881 .60378 Mtetra
.39881 .60378 .40528 .60979 .41614 .60654 .4097 .60051 Mtetra
.4097 .60051 .41614 .60654 .42705 .60328 .42063 .59723 Mtetra
.42063 .59723 .42705 .60328 .438 .60001 .43162 .59393 Mtetra
.43162 .59393 .438 .60001 .449 .59672 .44264 .59062 Mtetra
.44264 .59062 .449 .59672 .46004 .59342 .45371 .58729 Mtetra
.45371 .58729 .46004 .59342 .47113 .59011 .46483 .58396 Mtetra
.46483 .58396 .47113 .59011 .48226 .58678 .47599 .5806 Mtetra
.47599 .5806 .48226 .58678 .49344 .58344 .48719 .57724 Mtetra
.48719 .57724 .49344 .58344 .50466 .58009 .49845 .57386 Mtetra
.49845 .57386 .50466 .58009 .51593 .57672 .50975 .57046 Mtetra
.50975 .57046 .51593 .57672 .52725 .57334 .52109 .56706 Mtetra
.52109 .56706 .52725 .57334 .53861 .56994 .53249 .56364 Mtetra
.53249 .56364 .53861 .56994 .55002 .56653 .54393 .5602 Mtetra
.54393 .5602 .55002 .56653 .56148 .56311 .55542 .55675 Mtetra
.55542 .55675 .56148 .56311 .57298 .55967 .56695 .55328 Mtetra
.56695 .55328 .57298 .55967 .58454 .55622 .57854 .5498 Mtetra
.57854 .5498 .58454 .55622 .59614 .55275 .59017 .54631 Mtetra
.59017 .54631 .59614 .55275 .60779 .54927 .60185 .5428 Mtetra
.60185 .5428 .60779 .54927 .61948 .54577 .61359 .53928 Mtetra
.61359 .53928 .61948 .54577 .63123 .54226 .62537 .53574 Mtetra
.62537 .53574 .63123 .54226 .64303 .53874 .6372 .53219 Mtetra
.893 .48 .078 r
.6372 .53219 .64303 .53874 .65629 .57167 .65043 .56517 Mtetra
.655 .752 .921 r
.65043 .56517 .65629 .57167 .66832 .56815 .6625 .56162 Mtetra
.6625 .56162 .66832 .56815 .6804 .56462 .67461 .55806 Mtetra
.67461 .55806 .6804 .56462 .69253 .56108 .68678 .55449 Mtetra
.68678 .55449 .69253 .56108 .70471 .55752 .699 .5509 Mtetra
.699 .5509 .70471 .55752 .71695 .55394 .71127 .54729 Mtetra
.71127 .54729 .71695 .55394 .72924 .55035 .7236 .54367 Mtetra
.7236 .54367 .72924 .55035 .74159 .54674 .73598 .54004 Mtetra
.73598 .54004 .74159 .54674 .75398 .54311 .74842 .53638 Mtetra
.74842 .53638 .75398 .54311 .76643 .53947 .7609 .53271 Mtetra
.7609 .53271 .76643 .53947 .77894 .53582 .77345 .52903 Mtetra
.77345 .52903 .77894 .53582 .7915 .53215 .78605 .52533 Mtetra
.78605 .52533 .7915 .53215 .80411 .52846 .7987 .52161 Mtetra
.954 .607 .245 r
.7987 .52161 .80411 .52846 .81678 .52476 .82053 .62421 Mtetra
.548 .315 .513 r
.82053 .62421 .81678 .52476 .83918 .62727 .83372 .62059 Mtetra
.646 .762 .934 r
.83372 .62059 .83918 .62727 .8524 .62366 .84698 .61694 Mtetra
.84698 .61694 .8524 .62366 .86567 .62003 .86029 .61328 Mtetra
.86029 .61328 .86567 .62003 .879 .61638 .87367 .6096 Mtetra
.87367 .6096 .879 .61638 .89239 .61272 .8871 .60591 Mtetra
.8871 .60591 .89239 .61272 .90584 .60904 .9006 .6022 Mtetra
.985 .715 .424 r
.9006 .6022 .90584 .60904 .90382 .47035 .89877 .4632 Mtetra
.658 .749 .917 r
.89877 .4632 .90382 .47035 .91683 .46648 .91182 .4593 Mtetra
.91182 .4593 .91683 .46648 .9299 .4626 .92493 .45538 Mtetra
.92493 .45538 .9299 .4626 .94302 .4587 .93809 .45145 Mtetra
.658 .748 .916 r
.33835 .61402 .345 .61994 .35568 .61674 .34905 .61079 Mtetra
.34905 .61079 .35568 .61674 .36639 .61352 .35979 .60754 Mtetra
.35979 .60754 .36639 .61352 .37716 .61029 .37058 .60429 Mtetra
.37058 .60429 .37716 .61029 .38796 .60704 .38141 .60102 Mtetra
.38141 .60102 .38796 .60704 .39881 .60378 .39229 .59773 Mtetra
.39229 .59773 .39881 .60378 .4097 .60051 .40321 .59444 Mtetra
.40321 .59444 .4097 .60051 .42063 .59723 .41417 .59113 Mtetra
.41417 .59113 .42063 .59723 .43162 .59393 .42518 .58781 Mtetra
.42518 .58781 .43162 .59393 .44264 .59062 .43623 .58447 Mtetra
.43623 .58447 .44264 .59062 .45371 .58729 .44733 .58112 Mtetra
.44733 .58112 .45371 .58729 .46483 .58396 .45848 .57776 Mtetra
.45848 .57776 .46483 .58396 .47599 .5806 .46967 .57438 Mtetra
.46967 .57438 .47599 .5806 .48719 .57724 .4809 .57099 Mtetra
.4809 .57099 .48719 .57724 .49845 .57386 .49219 .56758 Mtetra
.49219 .56758 .49845 .57386 .50975 .57046 .50352 .56416 Mtetra
.50352 .56416 .50975 .57046 .52109 .56706 .51489 .56073 Mtetra
.51489 .56073 .52109 .56706 .53249 .56364 .52632 .55728 Mtetra
.52632 .55728 .53249 .56364 .54393 .5602 .53779 .55382 Mtetra
.53779 .55382 .54393 .5602 .55542 .55675 .54931 .55034 Mtetra
.54931 .55034 .55542 .55675 .56695 .55328 .56088 .54685 Mtetra
.56088 .54685 .56695 .55328 .57854 .5498 .57249 .54334 Mtetra
.57249 .54334 .57854 .5498 .59017 .54631 .58416 .53982 Mtetra
.58416 .53982 .59017 .54631 .60185 .5428 .59588 .53629 Mtetra
.59588 .53629 .60185 .5428 .61359 .53928 .60764 .53273 Mtetra
.60764 .53273 .61359 .53928 .62537 .53574 .61945 .52917 Mtetra
.61945 .52917 .62537 .53574 .6372 .53219 .63132 .52559 Mtetra
.893 .48 .078 r
.63132 .52559 .6372 .53219 .65043 .56517 .64453 .55861 Mtetra
.655 .752 .921 r
.64453 .55861 .65043 .56517 .6625 .56162 .65663 .55504 Mtetra
.65663 .55504 .6625 .56162 .67461 .55806 .66878 .55145 Mtetra
.66878 .55145 .67461 .55806 .68678 .55449 .68098 .54785 Mtetra
.68098 .54785 .68678 .55449 .699 .5509 .69324 .54423 Mtetra
.69324 .54423 .699 .5509 .71127 .54729 .70555 .5406 Mtetra
.70555 .5406 .71127 .54729 .7236 .54367 .71792 .53695 Mtetra
.71792 .53695 .7236 .54367 .73598 .54004 .73033 .53328 Mtetra
.73033 .53328 .73598 .54004 .74842 .53638 .74281 .5296 Mtetra
.74281 .5296 .74842 .53638 .7609 .53271 .75533 .5259 Mtetra
.75533 .5259 .7609 .53271 .77345 .52903 .76791 .52218 Mtetra
.957 .613 .262 r
.76791 .52218 .77345 .52903 .78605 .52533 .78869 .62477 Mtetra
.547 .312 .511 r
.78869 .62477 .78605 .52533 .7987 .52161 .8018 .62114 Mtetra
.8018 .62114 .7987 .52161 .82053 .62421 .81498 .6175 Mtetra
.646 .762 .934 r
.81498 .6175 .82053 .62421 .83372 .62059 .82822 .61384 Mtetra
.82822 .61384 .83372 .62059 .84698 .61694 .84151 .61017 Mtetra
.84151 .61017 .84698 .61694 .86029 .61328 .85487 .60648 Mtetra
.85487 .60648 .86029 .61328 .87367 .6096 .86829 .60277 Mtetra
.86829 .60277 .87367 .6096 .8871 .60591 .88177 .59904 Mtetra
.984 .716 .429 r
.88177 .59904 .8871 .60591 .9006 .6022 .88064 .4599 Mtetra
.575 .382 .582 r
.88064 .4599 .9006 .6022 .89877 .4632 .89368 .45599 Mtetra
.658 .749 .917 r
.89368 .45599 .89877 .4632 .91182 .4593 .90677 .45206 Mtetra
.90677 .45206 .91182 .4593 .92493 .45538 .91992 .44811 Mtetra
.91992 .44811 .92493 .45538 .93809 .45145 .93313 .44414 Mtetra
.658 .748 .916 r
.33164 .60804 .33835 .61402 .34905 .61079 .34237 .60479 Mtetra
.34237 .60479 .34905 .61079 .35979 .60754 .35314 .60152 Mtetra
.35314 .60152 .35979 .60754 .37058 .60429 .36395 .59824 Mtetra
.36395 .59824 .37058 .60429 .38141 .60102 .37481 .59495 Mtetra
.37481 .59495 .38141 .60102 .39229 .59773 .38572 .59164 Mtetra
.38572 .59164 .39229 .59773 .40321 .59444 .39666 .58832 Mtetra
.39666 .58832 .40321 .59444 .41417 .59113 .40765 .58499 Mtetra
.40765 .58499 .41417 .59113 .42518 .58781 .41869 .58164 Mtetra
.41869 .58164 .42518 .58781 .43623 .58447 .42977 .57828 Mtetra
.42977 .57828 .43623 .58447 .44733 .58112 .4409 .5749 Mtetra
.4409 .5749 .44733 .58112 .45848 .57776 .45208 .57151 Mtetra
.45208 .57151 .45848 .57776 .46967 .57438 .4633 .56811 Mtetra
.4633 .56811 .46967 .57438 .4809 .57099 .47456 .56469 Mtetra
.47456 .56469 .4809 .57099 .49219 .56758 .48588 .56126 Mtetra
.48588 .56126 .49219 .56758 .50352 .56416 .49724 .55781 Mtetra
.49724 .55781 .50352 .56416 .51489 .56073 .50864 .55435 Mtetra
.50864 .55435 .51489 .56073 .52632 .55728 .5201 .55088 Mtetra
.5201 .55088 .52632 .55728 .53779 .55382 .5316 .54739 Mtetra
.5316 .54739 .53779 .55382 .54931 .55034 .54315 .54388 Mtetra
.54315 .54388 .54931 .55034 .56088 .54685 .55475 .54036 Mtetra
.55475 .54036 .56088 .54685 .57249 .54334 .5664 .53683 Mtetra
.5664 .53683 .57249 .54334 .58416 .53982 .5781 .53328 Mtetra
.5781 .53328 .58416 .53982 .59588 .53629 .58985 .52972 Mtetra
.58985 .52972 .59588 .53629 .60764 .53273 .60165 .52614 Mtetra
.60165 .52614 .60764 .53273 .61945 .52917 .6135 .52255 Mtetra
.6135 .52255 .61945 .52917 .63132 .52559 .62539 .51894 Mtetra
.893 .48 .078 r
.62539 .51894 .63132 .52559 .64453 .55861 .63858 .55201 Mtetra
.655 .752 .921 r
.63858 .55201 .64453 .55861 .65663 .55504 .65071 .54841 Mtetra
.65071 .54841 .65663 .55504 .66878 .55145 .6629 .54479 Mtetra
.6629 .54479 .66878 .55145 .68098 .54785 .67514 .54116 Mtetra
.67514 .54116 .68098 .54785 .69324 .54423 .68744 .53751 Mtetra
.68744 .53751 .69324 .54423 .70555 .5406 .69978 .53384 Mtetra
.69978 .53384 .70555 .5406 .71792 .53695 .71218 .53016 Mtetra
.71218 .53016 .71792 .53695 .73033 .53328 .72464 .52647 Mtetra
.72464 .52647 .73033 .53328 .74281 .5296 .73715 .52276 Mtetra
.73715 .52276 .74281 .5296 .75533 .5259 .74972 .51903 Mtetra
.958 .616 .27 r
.74972 .51903 .75533 .5259 .76791 .52218 .76991 .6217 Mtetra
.546 .31 .51 r
.76991 .6217 .76791 .52218 .78869 .62477 .78301 .61806 Mtetra
.646 .762 .934 r
.78301 .61806 .78869 .62477 .8018 .62114 .79616 .61441 Mtetra
.79616 .61441 .8018 .62114 .81498 .6175 .80938 .61074 Mtetra
.80938 .61074 .81498 .6175 .82822 .61384 .82266 .60705 Mtetra
.82266 .60705 .82822 .61384 .84151 .61017 .836 .60334 Mtetra
.836 .60334 .84151 .61017 .85487 .60648 .84941 .59962 Mtetra
.84941 .59962 .85487 .60648 .86829 .60277 .86287 .59588 Mtetra
.86287 .59588 .86829 .60277 .88177 .59904 .8764 .59212 Mtetra
.984 .716 .429 r
.8764 .59212 .88177 .59904 .88064 .4599 .87546 .45266 Mtetra
.658 .749 .917 r
.87546 .45266 .88064 .4599 .89368 .45599 .88854 .44872 Mtetra
.88854 .44872 .89368 .45599 .90677 .45206 .90167 .44475 Mtetra
.90167 .44475 .90677 .45206 .91992 .44811 .91487 .44077 Mtetra
.91487 .44077 .91992 .44811 .93313 .44414 .92812 .43678 Mtetra
.658 .748 .916 r
.32489 .60202 .33164 .60804 .34237 .60479 .33564 .59875 Mtetra
.33564 .59875 .34237 .60479 .35314 .60152 .34644 .59545 Mtetra
.34644 .59545 .35314 .60152 .36395 .59824 .35728 .59215 Mtetra
.35728 .59215 .36395 .59824 .37481 .59495 .36817 .58883 Mtetra
.36817 .58883 .37481 .59495 .38572 .59164 .3791 .5855 Mtetra
.3791 .5855 .38572 .59164 .39666 .58832 .39007 .58215 Mtetra
.39007 .58215 .39666 .58832 .40765 .58499 .40109 .57879 Mtetra
.40109 .57879 .40765 .58499 .41869 .58164 .41216 .57542 Mtetra
.41216 .57542 .41869 .58164 .42977 .57828 .42327 .57203 Mtetra
.42327 .57203 .42977 .57828 .4409 .5749 .43442 .56863 Mtetra
.43442 .56863 .4409 .5749 .45208 .57151 .44563 .56522 Mtetra
.44563 .56522 .45208 .57151 .4633 .56811 .45688 .56179 Mtetra
.45688 .56179 .4633 .56811 .47456 .56469 .46817 .55834 Mtetra
.46817 .55834 .47456 .56469 .48588 .56126 .47952 .55488 Mtetra
.47952 .55488 .48588 .56126 .49724 .55781 .49091 .55141 Mtetra
.49091 .55141 .49724 .55781 .50864 .55435 .50235 .54792 Mtetra
.50235 .54792 .50864 .55435 .5201 .55088 .51383 .54442 Mtetra
.51383 .54442 .5201 .55088 .5316 .54739 .52537 .54091 Mtetra
.52537 .54091 .5316 .54739 .54315 .54388 .53695 .53738 Mtetra
.53695 .53738 .54315 .54388 .55475 .54036 .54858 .53383 Mtetra
.54858 .53383 .55475 .54036 .5664 .53683 .56027 .53027 Mtetra
.56027 .53027 .5664 .53683 .5781 .53328 .572 .52669 Mtetra
.572 .52669 .5781 .53328 .58985 .52972 .58378 .5231 Mtetra
.58378 .5231 .58985 .52972 .60165 .52614 .59561 .51949 Mtetra
.59561 .51949 .60165 .52614 .6135 .52255 .60749 .51587 Mtetra
.60749 .51587 .6135 .52255 .62539 .51894 .61942 .51223 Mtetra
.893 .48 .078 r
.61942 .51223 .62539 .51894 .63858 .55201 .63258 .54535 Mtetra
.655 .752 .921 r
.63258 .54535 .63858 .55201 .65071 .54841 .64475 .54172 Mtetra
.64475 .54172 .65071 .54841 .6629 .54479 .65698 .53807 Mtetra
.65698 .53807 .6629 .54479 .67514 .54116 .66925 .53441 Mtetra
.66925 .53441 .67514 .54116 .68744 .53751 .68158 .53073 Mtetra
.68158 .53073 .68744 .53751 .69978 .53384 .69397 .52704 Mtetra
.69397 .52704 .69978 .53384 .71218 .53016 .70641 .52333 Mtetra
.70641 .52333 .71218 .53016 .72464 .52647 .7189 .5196 Mtetra
.7189 .5196 .72464 .52647 .73715 .52276 .73145 .51586 Mtetra
.959 .618 .278 r
.73145 .51586 .73715 .52276 .74972 .51903 .75105 .61862 Mtetra
.544 .308 .508 r
.75105 .61862 .74972 .51903 .76991 .6217 .76413 .61497 Mtetra
.646 .762 .934 r
.76413 .61497 .76991 .6217 .78301 .61806 .77728 .6113 Mtetra
.77728 .6113 .78301 .61806 .79616 .61441 .79048 .60762 Mtetra
.79048 .60762 .79616 .61441 .80938 .61074 .80374 .60391 Mtetra
.80374 .60391 .80938 .61074 .82266 .60705 .81706 .60019 Mtetra
.81706 .60019 .82266 .60705 .836 .60334 .83045 .59645 Mtetra
.83045 .59645 .836 .60334 .84941 .59962 .84389 .5927 Mtetra
.84389 .5927 .84941 .59962 .86287 .59588 .8574 .58892 Mtetra
.984 .716 .435 r
.8574 .58892 .86287 .59588 .8764 .59212 .85718 .44933 Mtetra
.573 .379 .58 r
.85718 .44933 .8764 .59212 .87546 .45266 .87024 .44537 Mtetra
.658 .749 .917 r
.87024 .44537 .87546 .45266 .88854 .44872 .88336 .44139 Mtetra
.88336 .44139 .88854 .44872 .90167 .44475 .89654 .43739 Mtetra
.89654 .43739 .90167 .44475 .91487 .44077 .90977 .43338 Mtetra
.90977 .43338 .91487 .44077 .92812 .43678 .92307 .42935 Mtetra
.658 .748 .916 r
.31808 .59596 .32489 .60202 .33564 .59875 .32886 .59266 Mtetra
.32886 .59266 .33564 .59875 .34644 .59545 .33969 .58934 Mtetra
.33969 .58934 .34644 .59545 .35728 .59215 .35056 .58601 Mtetra
.35056 .58601 .35728 .59215 .36817 .58883 .36147 .58267 Mtetra
.36147 .58267 .36817 .58883 .3791 .5855 .37243 .57931 Mtetra
.37243 .57931 .3791 .5855 .39007 .58215 .38343 .57594 Mtetra
.38343 .57594 .39007 .58215 .40109 .57879 .39448 .57255 Mtetra
.39448 .57255 .40109 .57879 .41216 .57542 .40557 .56916 Mtetra
.40557 .56916 .41216 .57542 .42327 .57203 .41671 .56574 Mtetra
.41671 .56574 .42327 .57203 .43442 .56863 .4279 .56232 Mtetra
.4279 .56232 .43442 .56863 .44563 .56522 .43913 .55887 Mtetra
.43913 .55887 .44563 .56522 .45688 .56179 .45041 .55542 Mtetra
.45041 .55542 .45688 .56179 .46817 .55834 .46174 .55195 Mtetra
.46174 .55195 .46817 .55834 .47952 .55488 .47311 .54846 Mtetra
.47311 .54846 .47952 .55488 .49091 .55141 .48453 .54496 Mtetra
.48453 .54496 .49091 .55141 .50235 .54792 .496 .54145 Mtetra
.496 .54145 .50235 .54792 .51383 .54442 .50752 .53792 Mtetra
.50752 .53792 .51383 .54442 .52537 .54091 .51909 .53438 Mtetra
.51909 .53438 .52537 .54091 .53695 .53738 .5307 .53082 Mtetra
.5307 .53082 .53695 .53738 .54858 .53383 .54237 .52724 Mtetra
.54237 .52724 .54858 .53383 .56027 .53027 .55408 .52365 Mtetra
.55408 .52365 .56027 .53027 .572 .52669 .56584 .52005 Mtetra
.56584 .52005 .572 .52669 .58378 .5231 .57766 .51643 Mtetra
.57766 .51643 .58378 .5231 .59561 .51949 .58952 .51279 Mtetra
.58952 .51279 .59561 .51949 .60749 .51587 .60144 .50914 Mtetra
.60144 .50914 .60749 .51587 .61942 .51223 .6134 .50548 Mtetra
.949 .594 .265 r
.6134 .50548 .61942 .51223 .63258 .54535 .62739 .5668 Mtetra
.466 .148 .342 r
.62739 .5668 .63258 .54535 .64475 .54172 .6397 .56317 Mtetra
.6397 .56317 .64475 .54172 .65698 .53807 .65206 .55953 Mtetra
.65206 .55953 .65698 .53807 .66925 .53441 .66448 .55587 Mtetra
0 0 .042 r
.66448 .55587 .66925 .53441 .68158 .53073 .67568 .5239 Mtetra
.655 .752 .921 r
.67568 .5239 .68158 .53073 .69397 .52704 .6881 .52018 Mtetra
.6881 .52018 .69397 .52704 .70641 .52333 .70058 .51644 Mtetra
.70058 .51644 .70641 .52333 .7189 .5196 .71311 .51268 Mtetra
.959 .621 .286 r
.71311 .51268 .7189 .5196 .73145 .51586 .73213 .61553 Mtetra
.543 .306 .506 r
.73213 .61553 .73145 .51586 .75105 .61862 .74519 .61187 Mtetra
.646 .762 .934 r
.74519 .61187 .75105 .61862 .76413 .61497 .75831 .60818 Mtetra
.75831 .60818 .76413 .61497 .77728 .6113 .7715 .60448 Mtetra
.7715 .60448 .77728 .6113 .79048 .60762 .78474 .60076 Mtetra
.78474 .60076 .79048 .60762 .80374 .60391 .79805 .59703 Mtetra
.79805 .59703 .80374 .60391 .81706 .60019 .81141 .59328 Mtetra
.81141 .59328 .81706 .60019 .83045 .59645 .82484 .58951 Mtetra
.82484 .58951 .83045 .59645 .84389 .5927 .83833 .58572 Mtetra
.83833 .58572 .84389 .5927 .8574 .58892 .85189 .58191 Mtetra
.984 .716 .435 r
.85189 .58191 .8574 .58892 .85718 .44933 .85187 .442 Mtetra
.658 .749 .917 r
.85187 .442 .85718 .44933 .87024 .44537 .86498 .43801 Mtetra
.86498 .43801 .87024 .44537 .88336 .44139 .87814 .434 Mtetra
.87814 .434 .88336 .44139 .89654 .43739 .89136 .42997 Mtetra
.89136 .42997 .89654 .43739 .90977 .43338 .90464 .42592 Mtetra
.90464 .42592 .90977 .43338 .92307 .42935 .91798 .42186 Mtetra
.658 .748 .916 r
.31123 .58985 .31808 .59596 .32886 .59266 .32203 .58653 Mtetra
.32203 .58653 .32886 .59266 .33969 .58934 .33288 .58318 Mtetra
.33288 .58318 .33969 .58934 .35056 .58601 .34378 .57983 Mtetra
.34378 .57983 .35056 .58601 .36147 .58267 .35472 .57646 Mtetra
.35472 .57646 .36147 .58267 .37243 .57931 .36571 .57308 Mtetra
.36571 .57308 .37243 .57931 .38343 .57594 .37674 .56968 Mtetra
.37674 .56968 .38343 .57594 .39448 .57255 .38781 .56627 Mtetra
.38781 .56627 .39448 .57255 .40557 .56916 .39894 .56284 Mtetra
.39894 .56284 .40557 .56916 .41671 .56574 .4101 .5594 Mtetra
.4101 .5594 .41671 .56574 .4279 .56232 .42132 .55595 Mtetra
.42132 .55595 .4279 .56232 .43913 .55887 .43258 .55248 Mtetra
.43258 .55248 .43913 .55887 .45041 .55542 .44389 .549 Mtetra
.44389 .549 .45041 .55542 .46174 .55195 .45525 .5455 Mtetra
.45525 .5455 .46174 .55195 .47311 .54846 .46665 .54199 Mtetra
.46665 .54199 .47311 .54846 .48453 .54496 .4781 .53846 Mtetra
.4781 .53846 .48453 .54496 .496 .54145 .48961 .53492 Mtetra
.48961 .53492 .496 .54145 .50752 .53792 .50115 .53137 Mtetra
.50115 .53137 .50752 .53792 .51909 .53438 .51275 .52779 Mtetra
.51275 .52779 .51909 .53438 .5307 .53082 .5244 .52421 Mtetra
.5244 .52421 .5307 .53082 .54237 .52724 .5361 .5206 Mtetra
.5361 .5206 .54237 .52724 .55408 .52365 .54784 .51699 Mtetra
.54784 .51699 .55408 .52365 .56584 .52005 .55964 .51335 Mtetra
.55964 .51335 .56584 .52005 .57766 .51643 .57149 .50971 Mtetra
.57149 .50971 .57766 .51643 .58952 .51279 .58339 .50604 Mtetra
.58339 .50604 .58952 .51279 .60144 .50914 .59534 .50236 Mtetra
.95 .597 .273 r
.59534 .50236 .60144 .50914 .6134 .50548 .60895 .56373 Mtetra
.527 .274 .474 r
.60895 .56373 .6134 .50548 .62739 .5668 .62125 .56009 Mtetra
.653 .755 .924 r
.62125 .56009 .62739 .5668 .6397 .56317 .63359 .55643 Mtetra
.63359 .55643 .6397 .56317 .65206 .55953 .646 .55276 Mtetra
.646 .55276 .65206 .55953 .66448 .55587 .65845 .54907 Mtetra
.65845 .54907 .66448 .55587 .67568 .5239 .67096 .54537 Mtetra
.463 .144 .338 r
.67096 .54537 .67568 .5239 .6881 .52018 .68353 .54164 Mtetra
.68353 .54164 .6881 .52018 .70058 .51644 .69616 .5379 Mtetra
.69616 .5379 .70058 .51644 .71311 .51268 .70884 .53415 Mtetra
.874 .544 .422 r
.70884 .53415 .71311 .51268 .73213 .61553 .72617 .60875 Mtetra
.646 .762 .934 r
.72617 .60875 .73213 .61553 .74519 .61187 .73928 .60505 Mtetra
.73928 .60505 .74519 .61187 .75831 .60818 .75244 .60134 Mtetra
.75244 .60134 .75831 .60818 .7715 .60448 .76567 .5976 Mtetra
.76567 .5976 .7715 .60448 .78474 .60076 .77896 .59385 Mtetra
.77896 .59385 .78474 .60076 .79805 .59703 .7923 .59009 Mtetra
.7923 .59009 .79805 .59703 .81141 .59328 .80572 .5863 Mtetra
.80572 .5863 .81141 .59328 .82484 .58951 .81919 .5825 Mtetra
.81919 .5825 .82484 .58951 .83833 .58572 .83273 .57868 Mtetra
.983 .716 .44 r
.83273 .57868 .83833 .58572 .85189 .58191 .83344 .43862 Mtetra
.571 .376 .578 r
.83344 .43862 .85189 .58191 .85187 .442 .84652 .43462 Mtetra
.658 .749 .917 r
.84652 .43462 .85187 .442 .86498 .43801 .85967 .43059 Mtetra
.85967 .43059 .86498 .43801 .87814 .434 .87287 .42654 Mtetra
.87287 .42654 .87814 .434 .89136 .42997 .88614 .42248 Mtetra
.88614 .42248 .89136 .42997 .90464 .42592 .89946 .4184 Mtetra
.89946 .4184 .90464 .42592 .91798 .42186 .91285 .4143 Mtetra
.658 .748 .916 r
.30432 .5837 .31123 .58985 .32203 .58653 .31515 .58035 Mtetra
.31515 .58035 .32203 .58653 .33288 .58318 .32603 .57698 Mtetra
.32603 .57698 .33288 .58318 .34378 .57983 .33695 .5736 Mtetra
.33695 .5736 .34378 .57983 .35472 .57646 .34792 .5702 Mtetra
.34792 .5702 .35472 .57646 .36571 .57308 .35893 .56679 Mtetra
.35893 .56679 .36571 .57308 .37674 .56968 .36999 .56337 Mtetra
.36999 .56337 .37674 .56968 .38781 .56627 .3811 .55993 Mtetra
.3811 .55993 .38781 .56627 .39894 .56284 .39225 .55648 Mtetra
.39225 .55648 .39894 .56284 .4101 .5594 .40345 .55302 Mtetra
.40345 .55302 .4101 .5594 .42132 .55595 .41469 .54954 Mtetra
.41469 .54954 .42132 .55595 .43258 .55248 .42598 .54604 Mtetra
.42598 .54604 .43258 .55248 .44389 .549 .43732 .54253 Mtetra
.43732 .54253 .44389 .549 .45525 .5455 .44871 .53901 Mtetra
.44871 .53901 .45525 .5455 .46665 .54199 .46014 .53547 Mtetra
.46014 .53547 .46665 .54199 .4781 .53846 .47163 .53191 Mtetra
.47163 .53191 .4781 .53846 .48961 .53492 .48316 .52834 Mtetra
.48316 .52834 .48961 .53492 .50115 .53137 .49474 .52476 Mtetra
.49474 .52476 .50115 .53137 .51275 .52779 .50637 .52116 Mtetra
.50637 .52116 .51275 .52779 .5244 .52421 .51805 .51754 Mtetra
.51805 .51754 .5244 .52421 .5361 .5206 .52978 .51391 Mtetra
.892 .771 .721 r
.52978 .51391 .5361 .5206 .54784 .51699 .54147 .49219 Mtetra
.615 .497 .696 r
.54147 .49219 .54784 .51699 .55964 .51335 .55324 .48851 Mtetra
.55324 .48851 .55964 .51335 .57149 .50971 .56505 .48482 Mtetra
.56505 .48482 .57149 .50971 .58339 .50604 .57692 .4811 Mtetra
.57692 .4811 .58339 .50604 .59534 .50236 .58884 .47738 Mtetra
.906 .597 .106 r
.58884 .47738 .59534 .50236 .60895 .56373 .60272 .557 Mtetra
.653 .755 .924 r
.60272 .557 .60895 .56373 .62125 .56009 .61505 .55333 Mtetra
.61505 .55333 .62125 .56009 .63359 .55643 .62744 .54964 Mtetra
.62744 .54964 .63359 .55643 .646 .55276 .63988 .54594 Mtetra
.63988 .54594 .646 .55276 .65845 .54907 .65237 .54222 Mtetra
.65237 .54222 .65845 .54907 .67096 .54537 .66492 .53848 Mtetra
.66492 .53848 .67096 .54537 .68353 .54164 .67753 .53473 Mtetra
.67753 .53473 .68353 .54164 .69616 .5379 .69019 .53096 Mtetra
.949 .594 .244 r
.69019 .53096 .69616 .5379 .70884 .53415 .70708 .60562 Mtetra
.532 .284 .484 r
.70708 .60562 .70884 .53415 .72617 .60875 .72017 .60191 Mtetra
.646 .762 .934 r
.72017 .60191 .72617 .60875 .73928 .60505 .73331 .59818 Mtetra
.73331 .59818 .73928 .60505 .75244 .60134 .74652 .59443 Mtetra
.74652 .59443 .75244 .60134 .76567 .5976 .75979 .59067 Mtetra
.75979 .59067 .76567 .5976 .77896 .59385 .77312 .58689 Mtetra
.77312 .58689 .77896 .59385 .7923 .59009 .78651 .58309 Mtetra
.78651 .58309 .7923 .59009 .80572 .5863 .79997 .57927 Mtetra
.79997 .57927 .80572 .5863 .81919 .5825 .81349 .57543 Mtetra
.81349 .57543 .81919 .5825 .83273 .57868 .82707 .57158 Mtetra
.983 .716 .44 r
.82707 .57158 .83273 .57868 .83344 .43862 .828 .43121 Mtetra
.658 .749 .917 r
.828 .43121 .83344 .43862 .84652 .43462 .84113 .42717 Mtetra
.84113 .42717 .84652 .43462 .85967 .43059 .85431 .42311 Mtetra
.85431 .42311 .85967 .43059 .87287 .42654 .86756 .41903 Mtetra
.86756 .41903 .87287 .42654 .88614 .42248 .88087 .41493 Mtetra
.88087 .41493 .88614 .42248 .89946 .4184 .89424 .41082 Mtetra
.89424 .41082 .89946 .4184 .91285 .4143 .90767 .40668 Mtetra
.658 .748 .916 r
.29736 .5775 .30432 .5837 .31515 .58035 .30822 .57412 Mtetra
.30822 .57412 .31515 .58035 .32603 .57698 .31912 .57073 Mtetra
.31912 .57073 .32603 .57698 .33695 .5736 .33007 .56732 Mtetra
.33007 .56732 .33695 .5736 .34792 .5702 .34107 .5639 Mtetra
.34107 .5639 .34792 .5702 .35893 .56679 .35211 .56046 Mtetra
.35211 .56046 .35893 .56679 .36999 .56337 .3632 .55701 Mtetra
.3632 .55701 .36999 .56337 .3811 .55993 .37433 .55355 Mtetra
.37433 .55355 .3811 .55993 .39225 .55648 .38551 .55007 Mtetra
.38551 .55007 .39225 .55648 .40345 .55302 .39674 .54658 Mtetra
.881 .759 .723 r
.39674 .54658 .40345 .55302 .41469 .54954 .40863 .52517 Mtetra
.615 .497 .696 r
.40863 .52517 .41469 .54954 .42598 .54604 .4199 .52163 Mtetra
.4199 .52163 .42598 .54604 .43732 .54253 .43121 .51807 Mtetra
.43121 .51807 .43732 .54253 .44871 .53901 .44256 .5145 Mtetra
.44256 .5145 .44871 .53901 .46014 .53547 .45397 .51092 Mtetra
.45397 .51092 .46014 .53547 .47163 .53191 .46542 .50731 Mtetra
.46542 .50731 .47163 .53191 .48316 .52834 .47692 .5037 Mtetra
.47692 .5037 .48316 .52834 .49474 .52476 .48847 .50007 Mtetra
.48847 .50007 .49474 .52476 .50637 .52116 .50007 .49642 Mtetra
.50007 .49642 .50637 .52116 .51805 .51754 .51172 .49276 Mtetra
.51172 .49276 .51805 .51754 .52978 .51391 .52342 .48908 Mtetra
.52342 .48908 .52978 .51391 .54147 .49219 .53517 .48539 Mtetra
.66 .746 .914 r
.53517 .48539 .54147 .49219 .55324 .48851 .54697 .48168 Mtetra
.54697 .48168 .55324 .48851 .56505 .48482 .55882 .47795 Mtetra
.55882 .47795 .56505 .48482 .57692 .4811 .57072 .47421 Mtetra
.57072 .47421 .57692 .4811 .58884 .47738 .58267 .47045 Mtetra
.58267 .47045 .58884 .47738 .60272 .557 .59467 .46668 Mtetra
.076 .026 .492 r
.59467 .46668 .60272 .557 .61505 .55333 .60881 .54651 Mtetra
.653 .755 .924 r
.60881 .54651 .61505 .55333 .62744 .54964 .62123 .54279 Mtetra
.62123 .54279 .62744 .54964 .63988 .54594 .63371 .53906 Mtetra
.63371 .53906 .63988 .54594 .65237 .54222 .64624 .5353 Mtetra
.64624 .5353 .65237 .54222 .66492 .53848 .65883 .53154 Mtetra
.65883 .53154 .66492 .53848 .67753 .53473 .67147 .52775 Mtetra
.67147 .52775 .67753 .53473 .69019 .53096 .68418 .52395 Mtetra
.949 .594 .244 r
.68418 .52395 .69019 .53096 .70708 .60562 .70098 .59875 Mtetra
.646 .762 .934 r
.70098 .59875 .70708 .60562 .72017 .60191 .71411 .59501 Mtetra
.71411 .59501 .72017 .60191 .73331 .59818 .7273 .59125 Mtetra
.7273 .59125 .73331 .59818 .74652 .59443 .74055 .58747 Mtetra
.74055 .58747 .74652 .59443 .75979 .59067 .75386 .58367 Mtetra
.75386 .58367 .75979 .59067 .77312 .58689 .76724 .57986 Mtetra
.76724 .57986 .77312 .58689 .78651 .58309 .78067 .57602 Mtetra
.78067 .57602 .78651 .58309 .79997 .57927 .79417 .57217 Mtetra
.79417 .57217 .79997 .57927 .81349 .57543 .80774 .56831 Mtetra
.982 .717 .445 r
.80774 .56831 .81349 .57543 .82707 .57158 .8094 .42779 Mtetra
.569 .373 .576 r
.8094 .42779 .82707 .57158 .828 .43121 .82251 .42373 Mtetra
.658 .749 .917 r
.82251 .42373 .828 .43121 .84113 .42717 .83569 .41966 Mtetra
.83569 .41966 .84113 .42717 .85431 .42311 .84892 .41556 Mtetra
.84892 .41556 .85431 .42311 .86756 .41903 .86221 .41145 Mtetra
.86221 .41145 .86756 .41903 .88087 .41493 .87556 .40732 Mtetra
.87556 .40732 .88087 .41493 .89424 .41082 .88897 .40317 Mtetra
.88897 .40317 .89424 .41082 .90767 .40668 .90245 .399 Mtetra
.577 .394 .596 r
.29517 .50134 .29736 .5775 .30822 .57412 .30585 .49786 Mtetra
.153 .07 .5 r
.30585 .49786 .30822 .57412 .31912 .57073 .31328 .54664 Mtetra
.614 .497 .696 r
.31328 .54664 .31912 .57073 .33007 .56732 .3242 .54319 Mtetra
.3242 .54319 .33007 .56732 .34107 .5639 .33517 .53972 Mtetra
.33517 .53972 .34107 .5639 .35211 .56046 .34618 .53624 Mtetra
.34618 .53624 .35211 .56046 .3632 .55701 .35724 .53274 Mtetra
.35724 .53274 .3632 .55701 .37433 .55355 .36835 .52924 Mtetra
.36835 .52924 .37433 .55355 .38551 .55007 .3795 .52571 Mtetra
.3795 .52571 .38551 .55007 .39674 .54658 .3907 .52217 Mtetra
.3907 .52217 .39674 .54658 .40863 .52517 .40194 .51862 Mtetra
.66 .746 .914 r
.40194 .51862 .40863 .52517 .4199 .52163 .41323 .51505 Mtetra
.41323 .51505 .4199 .52163 .43121 .51807 .42457 .51147 Mtetra
.42457 .51147 .43121 .51807 .44256 .5145 .43596 .50787 Mtetra
.43596 .50787 .44256 .5145 .45397 .51092 .4474 .50426 Mtetra
.4474 .50426 .45397 .51092 .46542 .50731 .45888 .50063 Mtetra
.45888 .50063 .46542 .50731 .47692 .5037 .47041 .49698 Mtetra
.47041 .49698 .47692 .5037 .48847 .50007 .48199 .49332 Mtetra
.48199 .49332 .48847 .50007 .50007 .49642 .49363 .48965 Mtetra
.49363 .48965 .50007 .49642 .51172 .49276 .50531 .48596 Mtetra
.50531 .48596 .51172 .49276 .52342 .48908 .51704 .48225 Mtetra
.51704 .48225 .52342 .48908 .53517 .48539 .52882 .47853 Mtetra
.52882 .47853 .53517 .48539 .54697 .48168 .54065 .47479 Mtetra
.54065 .47479 .54697 .48168 .55882 .47795 .55253 .47103 Mtetra
.55253 .47103 .55882 .47795 .57072 .47421 .56447 .46726 Mtetra
.56447 .46726 .57072 .47421 .58267 .47045 .57645 .46347 Mtetra
.57645 .46347 .58267 .47045 .59467 .46668 .58849 .45967 Mtetra
.958 .62 .311 r
.58849 .45967 .59467 .46668 .60881 .54651 .60252 .53963 Mtetra
.653 .755 .924 r
.60252 .53963 .60881 .54651 .62123 .54279 .61498 .53588 Mtetra
.61498 .53588 .62123 .54279 .63371 .53906 .62749 .53212 Mtetra
.62749 .53212 .63371 .53906 .64624 .5353 .64006 .52834 Mtetra
.64006 .52834 .64624 .5353 .65883 .53154 .65269 .52454 Mtetra
.65269 .52454 .65883 .53154 .67147 .52775 .66537 .52072 Mtetra
.875 .456 .029 r
.66537 .52072 .67147 .52775 .68418 .52395 .6799 .55578 Mtetra
.752 .432 .444 r
.6799 .55578 .68418 .52395 .70098 .59875 .69483 .59183 Mtetra
.646 .762 .934 r
.69483 .59183 .70098 .59875 .71411 .59501 .708 .58805 Mtetra
.708 .58805 .71411 .59501 .7273 .59125 .72123 .58426 Mtetra
.72123 .58426 .7273 .59125 .74055 .58747 .73453 .58045 Mtetra
.73453 .58045 .74055 .58747 .75386 .58367 .74788 .57662 Mtetra
.74788 .57662 .75386 .58367 .76724 .57986 .7613 .57277 Mtetra
.7613 .57277 .76724 .57986 .78067 .57602 .77478 .5689 Mtetra
.77478 .5689 .78067 .57602 .79417 .57217 .78833 .56502 Mtetra
.78833 .56502 .79417 .57217 .80774 .56831 .80193 .56111 Mtetra
.982 .717 .445 r
.80193 .56111 .80774 .56831 .8094 .42779 .80383 .42029 Mtetra
.658 .749 .917 r
.80383 .42029 .8094 .42779 .82251 .42373 .81698 .4162 Mtetra
.81698 .4162 .82251 .42373 .83569 .41966 .8302 .41209 Mtetra
.8302 .41209 .83569 .41966 .84892 .41556 .84347 .40796 Mtetra
.84347 .40796 .84892 .41556 .86221 .41145 .85681 .40381 Mtetra
.85681 .40381 .86221 .41145 .87556 .40732 .8702 .39964 Mtetra
.8702 .39964 .87556 .40732 .88897 .40317 .88366 .39546 Mtetra
.88366 .39546 .88897 .40317 .90245 .399 .89718 .39125 Mtetra
.664 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31328 .54664 .30971 .48789 Mtetra
0 0 .443 r
.30971 .48789 .31328 .54664 .3242 .54319 .31726 .53678 Mtetra
.66 .746 .914 r
.31726 .53678 .3242 .54319 .33517 .53972 .32825 .53328 Mtetra
.32825 .53328 .33517 .53972 .34618 .53624 .33929 .52978 Mtetra
.33929 .52978 .34618 .53624 .35724 .53274 .35038 .52625 Mtetra
.35038 .52625 .35724 .53274 .36835 .52924 .36151 .52272 Mtetra
.36151 .52272 .36835 .52924 .3795 .52571 .37269 .51917 Mtetra
.37269 .51917 .3795 .52571 .3907 .52217 .38392 .5156 Mtetra
.38392 .5156 .3907 .52217 .40194 .51862 .3952 .51202 Mtetra
.3952 .51202 .40194 .51862 .41323 .51505 .40652 .50842 Mtetra
.40652 .50842 .41323 .51505 .42457 .51147 .41789 .50481 Mtetra
.41789 .50481 .42457 .51147 .43596 .50787 .42931 .50119 Mtetra
.42931 .50119 .43596 .50787 .4474 .50426 .44077 .49754 Mtetra
.44077 .49754 .4474 .50426 .45888 .50063 .45229 .49389 Mtetra
.45229 .49389 .45888 .50063 .47041 .49698 .46385 .49021 Mtetra
.46385 .49021 .47041 .49698 .48199 .49332 .47546 .48652 Mtetra
.47546 .48652 .48199 .49332 .49363 .48965 .48713 .48282 Mtetra
.48713 .48282 .49363 .48965 .50531 .48596 .49884 .4791 Mtetra
.49884 .4791 .50531 .48596 .51704 .48225 .5106 .47536 Mtetra
.5106 .47536 .51704 .48225 .52882 .47853 .52242 .47161 Mtetra
.52242 .47161 .52882 .47853 .54065 .47479 .53428 .46784 Mtetra
.53428 .46784 .54065 .47479 .55253 .47103 .5462 .46406 Mtetra
.5462 .46406 .55253 .47103 .56447 .46726 .55817 .46026 Mtetra
.55817 .46026 .56447 .46726 .57645 .46347 .57019 .45644 Mtetra
.57019 .45644 .57645 .46347 .58849 .45967 .58226 .4526 Mtetra
.58226 .4526 .58849 .45967 .60252 .53963 .59439 .44875 Mtetra
.07 .021 .488 r
.59439 .44875 .60252 .53963 .61498 .53588 .60867 .52892 Mtetra
.653 .755 .924 r
.60867 .52892 .61498 .53588 .62749 .53212 .62122 .52512 Mtetra
.62122 .52512 .62749 .53212 .64006 .52834 .63383 .52131 Mtetra
.884 .468 .053 r
.63383 .52131 .64006 .52834 .65269 .52454 .64791 .55636 Mtetra
.488 .195 .395 r
.64791 .55636 .65269 .52454 .66537 .52072 .66078 .55256 Mtetra
.66078 .55256 .66537 .52072 .6799 .55578 .67372 .54874 Mtetra
.65 .758 .929 r
.67372 .54874 .6799 .55578 .69483 .59183 .68671 .5449 Mtetra
.185 .153 .586 r
.68671 .5449 .69483 .59183 .708 .58805 .70184 .58103 Mtetra
.646 .762 .934 r
.70184 .58103 .708 .58805 .72123 .58426 .71511 .57721 Mtetra
.71511 .57721 .72123 .58426 .73453 .58045 .72845 .57336 Mtetra
.72845 .57336 .73453 .58045 .74788 .57662 .74185 .5695 Mtetra
.74185 .5695 .74788 .57662 .7613 .57277 .75531 .56562 Mtetra
.75531 .56562 .7613 .57277 .77478 .5689 .76884 .56172 Mtetra
.76884 .56172 .77478 .5689 .78833 .56502 .78243 .5578 Mtetra
.981 .717 .45 r
.78243 .5578 .78833 .56502 .80193 .56111 .78508 .41683 Mtetra
.567 .37 .573 r
.78508 .41683 .80193 .56111 .80383 .42029 .79821 .41272 Mtetra
.658 .749 .917 r
.79821 .41272 .80383 .42029 .81698 .4162 .81141 .40859 Mtetra
.81141 .40859 .81698 .4162 .8302 .41209 .82466 .40445 Mtetra
.82466 .40445 .8302 .41209 .84347 .40796 .83798 .40028 Mtetra
.83798 .40028 .84347 .40796 .85681 .40381 .85136 .3961 Mtetra
.85136 .3961 .85681 .40381 .8702 .39964 .8648 .3919 Mtetra
.8648 .3919 .8702 .39964 .88366 .39546 .8783 .38768 Mtetra
.8783 .38768 .88366 .39546 .89718 .39125 .89187 .38344 Mtetra
.664 .741 .908 r
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .31726 .53678 .31362 .47781 Mtetra
.582 .407 .61 r
.31362 .47781 .31726 .53678 .32825 .53328 .32448 .47423 Mtetra
0 0 .448 r
.32448 .47423 .32825 .53328 .33929 .52978 .33235 .52326 Mtetra
.66 .746 .914 r
.33235 .52326 .33929 .52978 .35038 .52625 .34347 .51971 Mtetra
.34347 .51971 .35038 .52625 .36151 .52272 .35463 .51615 Mtetra
.35463 .51615 .36151 .52272 .37269 .51917 .36584 .51257 Mtetra
.36584 .51257 .37269 .51917 .38392 .5156 .37709 .50898 Mtetra
.37709 .50898 .38392 .5156 .3952 .51202 .3884 .50537 Mtetra
.3884 .50537 .3952 .51202 .40652 .50842 .39975 .50174 Mtetra
.39975 .50174 .40652 .50842 .41789 .50481 .41115 .49811 Mtetra
.41115 .49811 .41789 .50481 .42931 .50119 .4226 .49445 Mtetra
.4226 .49445 .42931 .50119 .44077 .49754 .4341 .49078 Mtetra
.4341 .49078 .44077 .49754 .45229 .49389 .44564 .48709 Mtetra
.44564 .48709 .45229 .49389 .46385 .49021 .45724 .48339 Mtetra
.45724 .48339 .46385 .49021 .47546 .48652 .46888 .47967 Mtetra
.46888 .47967 .47546 .48652 .48713 .48282 .48058 .47594 Mtetra
.48058 .47594 .48713 .48282 .49884 .4791 .49232 .47219 Mtetra
.49232 .47219 .49884 .4791 .5106 .47536 .50412 .46842 Mtetra
.50412 .46842 .5106 .47536 .52242 .47161 .51597 .46464 Mtetra
.51597 .46464 .52242 .47161 .53428 .46784 .52787 .46084 Mtetra
.52787 .46084 .53428 .46784 .5462 .46406 .53982 .45703 Mtetra
.53982 .45703 .5462 .46406 .55817 .46026 .55182 .45319 Mtetra
.55182 .45319 .55817 .46026 .57019 .45644 .56387 .44934 Mtetra
.56387 .44934 .57019 .45644 .58226 .4526 .57598 .44548 Mtetra
.57598 .44548 .58226 .4526 .59439 .44875 .58814 .4416 Mtetra
.957 .618 .304 r
.58814 .4416 .59439 .44875 .60867 .52892 .60231 .5219 Mtetra
.892 .479 .075 r
.60231 .5219 .60867 .52892 .62122 .52512 .61594 .55695 Mtetra
.486 .192 .391 r
.61594 .55695 .62122 .52512 .63383 .52131 .62874 .55315 Mtetra
.62874 .55315 .63383 .52131 .64791 .55636 .64159 .54933 Mtetra
.65 .758 .929 r
.64159 .54933 .64791 .55636 .66078 .55256 .65451 .54549 Mtetra
.65451 .54549 .66078 .55256 .67372 .54874 .66748 .54164 Mtetra
.66748 .54164 .67372 .54874 .68671 .5449 .68052 .53777 Mtetra
.87 .45 .017 r
.68052 .53777 .68671 .5449 .70184 .58103 .69563 .57395 Mtetra
.646 .762 .934 r
.69563 .57395 .70184 .58103 .71511 .57721 .70894 .57009 Mtetra
.70894 .57009 .71511 .57721 .72845 .57336 .72232 .56621 Mtetra
.72232 .56621 .72845 .57336 .74185 .5695 .73577 .56232 Mtetra
.73577 .56232 .74185 .5695 .75531 .56562 .74927 .5584 Mtetra
.74927 .5584 .75531 .56562 .76884 .56172 .76284 .55447 Mtetra
.76284 .55447 .76884 .56172 .78243 .5578 .77648 .55052 Mtetra
.981 .717 .45 r
.77648 .55052 .78243 .5578 .78508 .41683 .77937 .40923 Mtetra
.658 .749 .917 r
.77937 .40923 .78508 .41683 .79821 .41272 .79254 .40509 Mtetra
.79254 .40509 .79821 .41272 .81141 .40859 .80578 .40093 Mtetra
.80578 .40093 .81141 .40859 .82466 .40445 .81908 .39675 Mtetra
.81908 .39675 .82466 .40445 .83798 .40028 .83244 .39255 Mtetra
.83244 .39255 .83798 .40028 .85136 .3961 .84587 .38833 Mtetra
.84587 .38833 .85136 .3961 .8648 .3919 .85935 .38409 Mtetra
.85935 .38409 .8648 .3919 .8783 .38768 .8729 .37983 Mtetra
.8729 .37983 .8783 .38768 .89187 .38344 .88651 .37556 Mtetra
.664 .741 .908 r
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33235 .52326 .3285 .46399 Mtetra
0 0 .448 r
.3285 .46399 .33235 .52326 .34347 .51971 .3365 .51312 Mtetra
.66 .746 .914 r
.3365 .51312 .34347 .51971 .35463 .51615 .34769 .50953 Mtetra
.34769 .50953 .35463 .51615 .36584 .51257 .35893 .50593 Mtetra
.35893 .50593 .36584 .51257 .37709 .50898 .37021 .5023 Mtetra
.37021 .5023 .37709 .50898 .3884 .50537 .38155 .49867 Mtetra
.38155 .49867 .3884 .50537 .39975 .50174 .39293 .49501 Mtetra
.39293 .49501 .39975 .50174 .41115 .49811 .40436 .49135 Mtetra
.40436 .49135 .41115 .49811 .4226 .49445 .41584 .48766 Mtetra
.41584 .48766 .4226 .49445 .4341 .49078 .42737 .48396 Mtetra
.42737 .48396 .4341 .49078 .44564 .48709 .43894 .48025 Mtetra
.43894 .48025 .44564 .48709 .45724 .48339 .45057 .47651 Mtetra
.45057 .47651 .45724 .48339 .46888 .47967 .46225 .47277 Mtetra
.46225 .47277 .46888 .47967 .48058 .47594 .47398 .469 Mtetra
.47398 .469 .48058 .47594 .49232 .47219 .48575 .46522 Mtetra
.48575 .46522 .49232 .47219 .50412 .46842 .49758 .46143 Mtetra
.49758 .46143 .50412 .46842 .51597 .46464 .50946 .45761 Mtetra
.50946 .45761 .51597 .46464 .52787 .46084 .5214 .45378 Mtetra
.5214 .45378 .52787 .46084 .53982 .45703 .53338 .44994 Mtetra
.53338 .44994 .53982 .45703 .55182 .45319 .54542 .44607 Mtetra
.54542 .44607 .55182 .45319 .56387 .44934 .55751 .4422 Mtetra
.55751 .4422 .56387 .44934 .57598 .44548 .56965 .4383 Mtetra
.56965 .4383 .57598 .44548 .58814 .4416 .58185 .43438 Mtetra
.964 .643 .352 r
.58185 .43438 .58814 .4416 .60231 .5219 .59672 .55373 Mtetra
.483 .188 .388 r
.59672 .55373 .60231 .5219 .61594 .55695 .6095 .54992 Mtetra
.65 .758 .929 r
.6095 .54992 .61594 .55695 .62874 .55315 .62233 .54608 Mtetra
.62233 .54608 .62874 .55315 .64159 .54933 .63523 .54223 Mtetra
.63523 .54223 .64159 .54933 .65451 .54549 .64818 .53836 Mtetra
.64818 .53836 .65451 .54549 .66748 .54164 .6612 .53447 Mtetra
.6612 .53447 .66748 .54164 .68052 .53777 .67427 .53057 Mtetra
.67427 .53057 .68052 .53777 .69563 .57395 .68741 .52665 Mtetra
.181 .149 .584 r
.68741 .52665 .69563 .57395 .70894 .57009 .70272 .56292 Mtetra
.646 .762 .934 r
.70272 .56292 .70894 .57009 .72232 .56621 .71614 .55901 Mtetra
.71614 .55901 .72232 .56621 .73577 .56232 .72963 .55507 Mtetra
.72963 .55507 .73577 .56232 .74927 .5584 .74318 .55113 Mtetra
.98 .715 .455 r
.74318 .55113 .74927 .5584 .76284 .55447 .7467 .40049 Mtetra
.564 .365 .569 r
.7467 .40049 .76284 .55447 .77648 .55052 .75976 .39634 Mtetra
.543 .35 .569 r
.75976 .39634 .77648 .55052 .77937 .40923 .77361 .40157 Mtetra
.658 .749 .917 r
.77361 .40157 .77937 .40923 .79254 .40509 .78683 .39739 Mtetra
.78683 .39739 .79254 .40509 .80578 .40093 .80011 .39319 Mtetra
.80011 .39319 .80578 .40093 .81908 .39675 .81346 .38898 Mtetra
.81346 .38898 .81908 .39675 .83244 .39255 .82686 .38474 Mtetra
.82686 .38474 .83244 .39255 .84587 .38833 .84033 .38049 Mtetra
.84033 .38049 .84587 .38833 .85935 .38409 .85386 .37621 Mtetra
.85386 .37621 .85935 .38409 .8729 .37983 .86745 .37192 Mtetra
.86745 .37192 .8729 .37983 .88651 .37556 .88111 .36761 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .3365 .51312 .33258 .45362 Mtetra
.58 .404 .608 r
.33258 .45362 .3365 .51312 .34769 .50953 .34363 .44995 Mtetra
.34363 .44995 .34769 .50953 .35893 .50593 .35472 .44626 Mtetra
0 0 .456 r
.35472 .44626 .35893 .50593 .37021 .5023 .36328 .49558 Mtetra
.66 .746 .914 r
.36328 .49558 .37021 .5023 .38155 .49867 .37464 .49191 Mtetra
.37464 .49191 .38155 .49867 .39293 .49501 .38605 .48823 Mtetra
.38605 .48823 .39293 .49501 .40436 .49135 .39751 .48453 Mtetra
.39751 .48453 .40436 .49135 .41584 .48766 .40902 .48082 Mtetra
.40902 .48082 .41584 .48766 .42737 .48396 .42058 .47709 Mtetra
.42058 .47709 .42737 .48396 .43894 .48025 .43219 .47334 Mtetra
.43219 .47334 .43894 .48025 .45057 .47651 .44385 .46958 Mtetra
.44385 .46958 .45057 .47651 .46225 .47277 .45556 .46581 Mtetra
.45556 .46581 .46225 .47277 .47398 .469 .46732 .46201 Mtetra
.46732 .46201 .47398 .469 .48575 .46522 .47913 .4582 Mtetra
.47913 .4582 .48575 .46522 .49758 .46143 .49099 .45437 Mtetra
.49099 .45437 .49758 .46143 .50946 .45761 .50291 .45053 Mtetra
.50291 .45053 .50946 .45761 .5214 .45378 .51487 .44667 Mtetra
.51487 .44667 .5214 .45378 .53338 .44994 .52689 .44279 Mtetra
.52689 .44279 .53338 .44994 .54542 .44607 .53897 .4389 Mtetra
.53897 .4389 .54542 .44607 .55751 .4422 .55109 .43499 Mtetra
.55109 .43499 .55751 .4422 .56965 .4383 .56327 .43106 Mtetra
.56327 .43106 .56965 .4383 .58185 .43438 .5755 .42711 Mtetra
.964 .643 .352 r
.5755 .42711 .58185 .43438 .59672 .55373 .59018 .54667 Mtetra
.65 .758 .929 r
.59018 .54667 .59672 .55373 .6095 .54992 .603 .54282 Mtetra
.603 .54282 .6095 .54992 .62233 .54608 .61587 .53896 Mtetra
.61587 .53896 .62233 .54608 .63523 .54223 .62881 .53507 Mtetra
.62881 .53507 .63523 .54223 .64818 .53836 .6418 .53117 Mtetra
.6418 .53117 .64818 .53836 .6612 .53447 .65486 .52725 Mtetra
.65486 .52725 .6612 .53447 .67427 .53057 .66797 .52331 Mtetra
.66797 .52331 .67427 .53057 .68741 .52665 .68115 .51936 Mtetra
.68115 .51936 .68741 .52665 .70272 .56292 .69439 .51538 Mtetra
.181 .149 .584 r
.69439 .51538 .70272 .56292 .71614 .55901 .70991 .55173 Mtetra
.978 .715 .464 r
.70991 .55173 .71614 .55901 .72963 .55507 .7148 .40112 Mtetra
.563 .363 .568 r
.7148 .40112 .72963 .55507 .74318 .55113 .72778 .39698 Mtetra
.72778 .39698 .74318 .55113 .7467 .40049 .74082 .39281 Mtetra
.658 .748 .916 r
.74082 .39281 .7467 .40049 .75976 .39634 .75393 .38863 Mtetra
.206 .506 .909 r
.75393 .38863 .75976 .39634 .77361 .40157 .7678 .39384 Mtetra
.658 .749 .917 r
.7678 .39384 .77361 .40157 .78683 .39739 .78107 .38963 Mtetra
.78107 .38963 .78683 .39739 .80011 .39319 .79439 .3854 Mtetra
.79439 .3854 .80011 .39319 .81346 .38898 .80778 .38114 Mtetra
.80778 .38114 .81346 .38898 .82686 .38474 .82123 .37687 Mtetra
.82123 .37687 .82686 .38474 .84033 .38049 .83474 .37258 Mtetra
.83474 .37258 .84033 .38049 .85386 .37621 .84832 .36827 Mtetra
.84832 .36827 .85386 .37621 .86745 .37192 .86196 .36394 Mtetra
.86196 .36394 .86745 .37192 .88111 .36761 .87566 .35959 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
.3146 .45051 .32158 .45728 .33258 .45362 .32563 .44683 Mtetra
.32563 .44683 .33258 .45362 .34363 .44995 .3367 .44313 Mtetra
.3367 .44313 .34363 .44995 .35472 .44626 .34783 .43941 Mtetra
.34783 .43941 .35472 .44626 .36328 .49558 .35899 .43568 Mtetra
.579 .403 .607 r
.35899 .43568 .36328 .49558 .37464 .49191 .37021 .43193 Mtetra
0 0 .461 r
.37021 .43193 .37464 .49191 .38605 .48823 .37912 .48139 Mtetra
.66 .746 .914 r
.37912 .48139 .38605 .48823 .39751 .48453 .39062 .47766 Mtetra
.39062 .47766 .39751 .48453 .40902 .48082 .40216 .47392 Mtetra
.40216 .47392 .40902 .48082 .42058 .47709 .41375 .47016 Mtetra
.41375 .47016 .42058 .47709 .43219 .47334 .42539 .46639 Mtetra
.42539 .46639 .43219 .47334 .44385 .46958 .43708 .4626 Mtetra
.43708 .4626 .44385 .46958 .45556 .46581 .44882 .45879 Mtetra
.44882 .45879 .45556 .46581 .46732 .46201 .46061 .45496 Mtetra
.46061 .45496 .46732 .46201 .47913 .4582 .47246 .45112 Mtetra
.47246 .45112 .47913 .4582 .49099 .45437 .48435 .44727 Mtetra
.48435 .44727 .49099 .45437 .50291 .45053 .4963 .44339 Mtetra
.4963 .44339 .50291 .45053 .51487 .44667 .5083 .4395 Mtetra
.5083 .4395 .51487 .44667 .52689 .44279 .52035 .43559 Mtetra
.52035 .43559 .52689 .44279 .53897 .4389 .53246 .43166 Mtetra
.53246 .43166 .53897 .4389 .55109 .43499 .54462 .42772 Mtetra
.54462 .42772 .55109 .43499 .56327 .43106 .55683 .42376 Mtetra
.55683 .42376 .56327 .43106 .5755 .42711 .5691 .41978 Mtetra
.964 .643 .352 r
.5691 .41978 .5755 .42711 .59018 .54667 .58358 .53955 Mtetra
.65 .758 .929 r
.58358 .53955 .59018 .54667 .603 .54282 .59644 .53567 Mtetra
.59644 .53567 .603 .54282 .61587 .53896 .60935 .53177 Mtetra
.60935 .53177 .61587 .53896 .62881 .53507 .62233 .52786 Mtetra
.62233 .52786 .62881 .53507 .6418 .53117 .63537 .52392 Mtetra
.63537 .52392 .6418 .53117 .65486 .52725 .64846 .51997 Mtetra
.64846 .51997 .65486 .52725 .66797 .52331 .66162 .51599 Mtetra
.66162 .51599 .66797 .52331 .68115 .51936 .67484 .512 Mtetra
.67484 .512 .68115 .51936 .69439 .51538 .68812 .50799 Mtetra
.975 .725 .492 r
.68812 .50799 .69439 .51538 .70991 .55173 .69582 .39762 Mtetra
.561 .361 .567 r
.69582 .39762 .70991 .55173 .7148 .40112 .70879 .39345 Mtetra
.658 .748 .916 r
.70879 .39345 .7148 .40112 .72778 .39698 .72181 .38927 Mtetra
.72181 .38927 .72778 .39698 .74082 .39281 .7349 .38507 Mtetra
.7349 .38507 .74082 .39281 .75393 .38863 .74804 .38085 Mtetra
.74804 .38085 .75393 .38863 .7678 .39384 .76125 .37662 Mtetra
.435 .455 .781 r
.76125 .37662 .7678 .39384 .78107 .38963 .77525 .3818 Mtetra
.658 .749 .917 r
.77525 .3818 .78107 .38963 .79439 .3854 .78862 .37753 Mtetra
.78862 .37753 .79439 .3854 .80778 .38114 .80205 .37324 Mtetra
.80205 .37324 .80778 .38114 .82123 .37687 .81555 .36893 Mtetra
.81555 .36893 .82123 .37687 .83474 .37258 .8291 .36461 Mtetra
.8291 .36461 .83474 .37258 .84832 .36827 .84273 .36026 Mtetra
.84273 .36026 .84832 .36827 .86196 .36394 .85641 .35589 Mtetra
.85641 .35589 .86196 .36394 .87566 .35959 .87016 .3515 Mtetra
.664 .741 .908 r
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.28559 .45108 .29268 .45784 .30361 .45418 .29655 .4474 Mtetra
.29655 .4474 .30361 .45418 .3146 .45051 .30756 .4437 Mtetra
.30756 .4437 .3146 .45051 .32563 .44683 .31862 .43998 Mtetra
.31862 .43998 .32563 .44683 .3367 .44313 .32973 .43626 Mtetra
.32973 .43626 .3367 .44313 .34783 .43941 .34088 .43251 Mtetra
.34088 .43251 .34783 .43941 .35899 .43568 .35207 .42875 Mtetra
.35207 .42875 .35899 .43568 .37021 .43193 .36332 .42497 Mtetra
.36332 .42497 .37021 .43193 .37912 .48139 .37461 .42118 Mtetra
.578 .402 .607 r
.37461 .42118 .37912 .48139 .39062 .47766 .38595 .41737 Mtetra
.38595 .41737 .39062 .47766 .40216 .47392 .39734 .41355 Mtetra
0 0 .469 r
.39734 .41355 .40216 .47392 .41375 .47016 .40686 .46318 Mtetra
.66 .746 .914 r
.40686 .46318 .41375 .47016 .42539 .46639 .41853 .45938 Mtetra
.41853 .45938 .42539 .46639 .43708 .4626 .43025 .45555 Mtetra
.43025 .45555 .43708 .4626 .44882 .45879 .44202 .45172 Mtetra
.44202 .45172 .44882 .45879 .46061 .45496 .45385 .44786 Mtetra
.45385 .44786 .46061 .45496 .47246 .45112 .46573 .44399 Mtetra
.46573 .44399 .47246 .45112 .48435 .44727 .47766 .4401 Mtetra
.47766 .4401 .48435 .44727 .4963 .44339 .48964 .43619 Mtetra
.48964 .43619 .4963 .44339 .5083 .4395 .50167 .43227 Mtetra
.50167 .43227 .5083 .4395 .52035 .43559 .51376 .42833 Mtetra
.51376 .42833 .52035 .43559 .53246 .43166 .5259 .42437 Mtetra
.5259 .42437 .53246 .43166 .54462 .42772 .5381 .42039 Mtetra
.5381 .42039 .54462 .42772 .55683 .42376 .55034 .4164 Mtetra
.55034 .4164 .55683 .42376 .5691 .41978 .56265 .41239 Mtetra
.964 .643 .352 r
.56265 .41239 .5691 .41978 .58358 .53955 .57693 .53237 Mtetra
.65 .758 .929 r
.57693 .53237 .58358 .53955 .59644 .53567 .58983 .52846 Mtetra
.58983 .52846 .59644 .53567 .60935 .53177 .60278 .52453 Mtetra
.60278 .52453 .60935 .53177 .62233 .52786 .6158 .52058 Mtetra
.6158 .52058 .62233 .52786 .63537 .52392 .62888 .51661 Mtetra
.62888 .51661 .63537 .52392 .64846 .51997 .64201 .51262 Mtetra
.64201 .51262 .64846 .51997 .66162 .51599 .65521 .50861 Mtetra
.65521 .50861 .66162 .51599 .67484 .512 .66848 .50458 Mtetra
.974 .725 .496 r
.66848 .50458 .67484 .512 .68812 .50799 .67678 .3941 Mtetra
.565 .37 .576 r
.67678 .3941 .68812 .50799 .69582 .39762 .68972 .38992 Mtetra
.658 .748 .916 r
.68972 .38992 .69582 .39762 .70879 .39345 .70273 .38572 Mtetra
.70273 .38572 .70879 .39345 .72181 .38927 .71579 .38151 Mtetra
.71579 .38151 .72181 .38927 .7349 .38507 .72892 .37727 Mtetra
.72892 .37727 .7349 .38507 .74804 .38085 .74211 .37301 Mtetra
.74211 .37301 .74804 .38085 .76125 .37662 .75536 .36874 Mtetra
.211 .508 .909 r
.75536 .36874 .76125 .37662 .77525 .3818 .76939 .3739 Mtetra
.658 .749 .917 r
.76939 .3739 .77525 .3818 .78862 .37753 .7828 .3696 Mtetra
.7828 .3696 .78862 .37753 .80205 .37324 .79628 .36527 Mtetra
.79628 .36527 .80205 .37324 .81555 .36893 .80982 .36093 Mtetra
.80982 .36093 .81555 .36893 .8291 .36461 .82342 .35656 Mtetra
.82342 .35656 .8291 .36461 .84273 .36026 .83709 .35217 Mtetra
.83709 .35217 .84273 .36026 .85641 .35589 .85082 .34777 Mtetra
.85082 .34777 .85641 .35589 .87016 .3515 .86462 .34334 Mtetra
.664 .741 .908 r
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .4437 .30048 .43683 Mtetra
.30048 .43683 .30756 .4437 .31862 .43998 .31156 .43309 Mtetra
.31156 .43309 .31862 .43998 .32973 .43626 .32269 .42933 Mtetra
.32269 .42933 .32973 .43626 .34088 .43251 .33387 .42556 Mtetra
.33387 .42556 .34088 .43251 .35207 .42875 .3451 .42177 Mtetra
.3451 .42177 .35207 .42875 .36332 .42497 .35637 .41796 Mtetra
.35637 .41796 .36332 .42497 .37461 .42118 .3677 .41414 Mtetra
.3677 .41414 .37461 .42118 .38595 .41737 .37907 .4103 Mtetra
.37907 .4103 .38595 .41737 .39734 .41355 .39048 .40644 Mtetra
.39048 .40644 .39734 .41355 .40686 .46318 .40195 .40257 Mtetra
.577 .401 .606 r
.40195 .40257 .40686 .46318 .41853 .45938 .41347 .39869 Mtetra
.002 0 .473 r
.41347 .39869 .41853 .45938 .43025 .45555 .42337 .44845 Mtetra
.66 .746 .914 r
.42337 .44845 .43025 .45555 .44202 .45172 .43517 .44458 Mtetra
.43517 .44458 .44202 .45172 .45385 .44786 .44703 .4407 Mtetra
.44703 .4407 .45385 .44786 .46573 .44399 .45894 .43679 Mtetra
.45894 .43679 .46573 .44399 .47766 .4401 .47091 .43287 Mtetra
.47091 .43287 .47766 .4401 .48964 .43619 .48292 .42894 Mtetra
.48292 .42894 .48964 .43619 .50167 .43227 .49499 .42498 Mtetra
.49499 .42498 .50167 .43227 .51376 .42833 .50711 .42101 Mtetra
.50711 .42101 .51376 .42833 .5259 .42437 .51929 .41702 Mtetra
.51929 .41702 .5259 .42437 .5381 .42039 .53152 .41301 Mtetra
.95 .74 .585 r
.53152 .41301 .5381 .42039 .55034 .4164 .54349 .35479 Mtetra
.896 .644 .133 r
.54349 .35479 .55034 .4164 .56265 .41239 .55734 .52906 Mtetra
.528 .286 .492 r
.55734 .52906 .56265 .41239 .57693 .53237 .57022 .52513 Mtetra
.65 .758 .929 r
.57022 .52513 .57693 .53237 .58983 .52846 .58316 .52118 Mtetra
.58316 .52118 .58983 .52846 .60278 .52453 .59615 .51722 Mtetra
.59615 .51722 .60278 .52453 .6158 .52058 .60921 .51323 Mtetra
.60921 .51323 .6158 .52058 .62888 .51661 .62233 .50923 Mtetra
.62233 .50923 .62888 .51661 .64201 .51262 .63551 .50521 Mtetra
.63551 .50521 .64201 .51262 .65521 .50861 .64875 .50116 Mtetra
.64875 .50116 .65521 .50861 .66848 .50458 .66206 .4971 Mtetra
.974 .725 .496 r
.66206 .4971 .66848 .50458 .67678 .3941 .67058 .38637 Mtetra
.658 .748 .916 r
.67058 .38637 .67678 .3941 .68972 .38992 .68357 .38215 Mtetra
.68357 .38215 .68972 .38992 .70273 .38572 .69662 .37792 Mtetra
.69662 .37792 .70273 .38572 .71579 .38151 .70972 .37367 Mtetra
.70972 .37367 .71579 .38151 .72892 .37727 .72289 .3694 Mtetra
.72289 .3694 .72892 .37727 .74211 .37301 .73612 .36511 Mtetra
.73612 .36511 .74211 .37301 .75536 .36874 .74941 .3608 Mtetra
.211 .508 .909 r
.74941 .3608 .75536 .36874 .76939 .3739 .76348 .36594 Mtetra
.658 .749 .917 r
.76348 .36594 .76939 .3739 .7828 .3696 .77693 .3616 Mtetra
.77693 .3616 .7828 .3696 .79628 .36527 .79045 .35723 Mtetra
.79045 .35723 .79628 .36527 .80982 .36093 .80404 .35285 Mtetra
.80404 .35285 .80982 .36093 .82342 .35656 .81769 .34845 Mtetra
.81769 .34845 .82342 .35656 .83709 .35217 .8314 .34402 Mtetra
.8314 .34402 .83709 .35217 .85082 .34777 .84518 .33958 Mtetra
.84518 .33958 .85082 .34777 .86462 .34334 .85902 .33511 Mtetra
.664 .741 .908 r
.23846 .44853 .24574 .45531 .25659 .45164 .24934 .44484 Mtetra
.24934 .44484 .25659 .45164 .2675 .44796 .26027 .44113 Mtetra
.26027 .44113 .2675 .44796 .27844 .44427 .27124 .4374 Mtetra
.27124 .4374 .27844 .44427 .28944 .44056 .28226 .43366 Mtetra
.28226 .43366 .28944 .44056 .30048 .43683 .29333 .42991 Mtetra
.29333 .42991 .30048 .43683 .31156 .43309 .30445 .42614 Mtetra
.30445 .42614 .31156 .43309 .32269 .42933 .31561 .42235 Mtetra
.31561 .42235 .32269 .42933 .33387 .42556 .32681 .41855 Mtetra
.32681 .41855 .33387 .42556 .3451 .42177 .33807 .41473 Mtetra
.33807 .41473 .3451 .42177 .35637 .41796 .34937 .41089 Mtetra
.34937 .41089 .35637 .41796 .3677 .41414 .36072 .40704 Mtetra
.36072 .40704 .3677 .41414 .37907 .4103 .37213 .40317 Mtetra
.37213 .40317 .37907 .4103 .39048 .40644 .38357 .39928 Mtetra
.38357 .39928 .39048 .40644 .40195 .40257 .39507 .39538 Mtetra
.39507 .39538 .40195 .40257 .41347 .39869 .40662 .39146 Mtetra
.40662 .39146 .41347 .39869 .42337 .44845 .41822 .38753 Mtetra
.576 .399 .605 r
.41822 .38753 .42337 .44845 .43517 .44458 .42986 .38358 Mtetra
.42986 .38358 .43517 .44458 .44703 .4407 .44156 .37961 Mtetra
.44156 .37961 .44703 .4407 .45894 .43679 .45331 .37562 Mtetra
.45331 .37562 .45894 .43679 .47091 .43287 .46511 .37161 Mtetra
.46511 .37161 .47091 .43287 .48292 .42894 .47696 .36759 Mtetra
.47696 .36759 .48292 .42894 .49499 .42498 .48886 .36355 Mtetra
.48886 .36355 .49499 .42498 .50711 .42101 .50082 .3595 Mtetra
.50082 .3595 .50711 .42101 .51929 .41702 .51283 .35542 Mtetra
.51283 .35542 .51929 .41702 .53152 .41301 .52489 .35133 Mtetra
.52489 .35133 .53152 .41301 .54349 .35479 .537 .34722 Mtetra
.664 .741 .908 r
.537 .34722 .54349 .35479 .55734 .52906 .54917 .34309 Mtetra
.556 .351 .558 r
.54917 .34309 .55734 .52906 .57022 .52513 .56139 .33894 Mtetra
0 0 .417 r
.56139 .33894 .57022 .52513 .58316 .52118 .57643 .51385 Mtetra
.65 .758 .929 r
.57643 .51385 .58316 .52118 .59615 .51722 .58947 .50985 Mtetra
.58947 .50985 .59615 .51722 .60921 .51323 .60256 .50583 Mtetra
.60256 .50583 .60921 .51323 .62233 .50923 .61572 .50179 Mtetra
.61572 .50179 .62233 .50923 .63551 .50521 .62895 .49773 Mtetra
.62895 .49773 .63551 .50521 .64875 .50116 .64223 .49365 Mtetra
.973 .725 .5 r
.64223 .49365 .64875 .50116 .66206 .4971 .65137 .3828 Mtetra
.562 .367 .574 r
.65137 .3828 .66206 .4971 .67058 .38637 .66433 .37857 Mtetra
.658 .748 .916 r
.66433 .37857 .67058 .38637 .68357 .38215 .67736 .37433 Mtetra
.67736 .37433 .68357 .38215 .69662 .37792 .69045 .37006 Mtetra
.69045 .37006 .69662 .37792 .70972 .37367 .7036 .36577 Mtetra
.7036 .36577 .70972 .37367 .72289 .3694 .71681 .36146 Mtetra
.71681 .36146 .72289 .3694 .73612 .36511 .73008 .35713 Mtetra
.73008 .35713 .73612 .36511 .74941 .3608 .74342 .35278 Mtetra
.74342 .35278 .74941 .3608 .76348 .36594 .75682 .34841 Mtetra
.432 .453 .781 r
.75682 .34841 .76348 .36594 .77693 .3616 .77101 .35353 Mtetra
.658 .749 .917 r
.77101 .35353 .77693 .3616 .79045 .35723 .78458 .34913 Mtetra
.78458 .34913 .79045 .35723 .80404 .35285 .79821 .3447 Mtetra
.79821 .3447 .80404 .35285 .81769 .34845 .8119 .34026 Mtetra
.8119 .34026 .81769 .34845 .8314 .34402 .82566 .3358 Mtetra
.82566 .3358 .8314 .34402 .84518 .33958 .83949 .33131 Mtetra
.83949 .33131 .84518 .33958 .85902 .33511 .85338 .3268 Mtetra
.664 .741 .908 r
.23112 .4417 .23846 .44853 .24934 .44484 .24203 .43798 Mtetra
.24203 .43798 .24934 .44484 .26027 .44113 .25299 .43424 Mtetra
.25299 .43424 .26027 .44113 .27124 .4374 .26399 .43049 Mtetra
.26399 .43049 .27124 .4374 .28226 .43366 .27504 .42672 Mtetra
.27504 .42672 .28226 .43366 .29333 .42991 .28613 .42293 Mtetra
.28613 .42293 .29333 .42991 .30445 .42614 .29727 .41913 Mtetra
.29727 .41913 .30445 .42614 .31561 .42235 .30846 .41532 Mtetra
.30846 .41532 .31561 .42235 .32681 .41855 .3197 .41148 Mtetra
.3197 .41148 .32681 .41855 .33807 .41473 .33099 .40763 Mtetra
.33099 .40763 .33807 .41473 .34937 .41089 .34232 .40377 Mtetra
.34232 .40377 .34937 .41089 .36072 .40704 .3537 .39988 Mtetra
.3537 .39988 .36072 .40704 .37213 .40317 .36513 .39598 Mtetra
.36513 .39598 .37213 .40317 .38357 .39928 .37661 .39207 Mtetra
.37661 .39207 .38357 .39928 .39507 .39538 .38814 .38814 Mtetra
.38814 .38814 .39507 .39538 .40662 .39146 .39972 .38419 Mtetra
.39972 .38419 .40662 .39146 .41822 .38753 .41135 .38022 Mtetra
.41135 .38022 .41822 .38753 .42986 .38358 .42302 .37623 Mtetra
.42302 .37623 .42986 .38358 .44156 .37961 .43475 .37223 Mtetra
.43475 .37223 .44156 .37961 .45331 .37562 .44654 .36821 Mtetra
.44654 .36821 .45331 .37562 .46511 .37161 .45837 .36418 Mtetra
.45837 .36418 .46511 .37161 .47696 .36759 .47025 .36012 Mtetra
.47025 .36012 .47696 .36759 .48886 .36355 .48219 .35605 Mtetra
.48219 .35605 .48886 .36355 .50082 .3595 .49418 .35196 Mtetra
.49418 .35196 .50082 .3595 .51283 .35542 .50622 .34785 Mtetra
.50622 .34785 .51283 .35542 .52489 .35133 .51831 .34373 Mtetra
.51831 .34373 .52489 .35133 .537 .34722 .53046 .33958 Mtetra
.53046 .33958 .537 .34722 .54917 .34309 .54266 .33542 Mtetra
.54266 .33542 .54917 .34309 .56139 .33894 .55492 .33124 Mtetra
.55492 .33124 .56139 .33894 .57643 .51385 .56723 .32704 Mtetra
0 0 .417 r
.56723 .32704 .57643 .51385 .58947 .50985 .58272 .50241 Mtetra
.65 .758 .929 r
.58272 .50241 .58947 .50985 .60256 .50583 .59586 .49835 Mtetra
.59586 .49835 .60256 .50583 .61572 .50179 .60906 .49428 Mtetra
.60906 .49428 .61572 .50179 .62895 .49773 .62232 .49019 Mtetra
.62232 .49019 .62895 .49773 .64223 .49365 .63565 .48607 Mtetra
.973 .725 .5 r
.63565 .48607 .64223 .49365 .65137 .3828 .64502 .37498 Mtetra
.658 .748 .916 r
.64502 .37498 .65137 .3828 .66433 .37857 .65803 .37072 Mtetra
.65803 .37072 .66433 .37857 .67736 .37433 .6711 .36643 Mtetra
.6711 .36643 .67736 .37433 .69045 .37006 .68423 .36212 Mtetra
.68423 .36212 .69045 .37006 .7036 .36577 .69743 .3578 Mtetra
.69743 .3578 .7036 .36577 .71681 .36146 .71068 .35345 Mtetra
.71068 .35345 .71681 .36146 .73008 .35713 .72399 .34909 Mtetra
.72399 .34909 .73008 .35713 .74342 .35278 .73737 .3447 Mtetra
.73737 .3447 .74342 .35278 .75682 .34841 .75081 .34029 Mtetra
.216 .51 .91 r
.75081 .34029 .75682 .34841 .77101 .35353 .76504 .34539 Mtetra
.658 .749 .917 r
.76504 .34539 .77101 .35353 .78458 .34913 .77865 .34095 Mtetra
.77865 .34095 .78458 .34913 .79821 .3447 .79233 .33648 Mtetra
.79233 .33648 .79821 .3447 .8119 .34026 .80607 .332 Mtetra
.80607 .332 .8119 .34026 .82566 .3358 .81987 .3275 Mtetra
.81987 .3275 .82566 .3358 .83949 .33131 .83375 .32297 Mtetra
.83375 .32297 .83949 .33131 .85338 .3268 .84768 .31843 Mtetra
.664 .741 .908 r
.22373 .43482 .23112 .4417 .24203 .43798 .23467 .43107 Mtetra
.23467 .43107 .24203 .43798 .25299 .43424 .24565 .4273 Mtetra
.24565 .4273 .25299 .43424 .26399 .43049 .25668 .42352 Mtetra
.25668 .42352 .26399 .43049 .27504 .42672 .26775 .41972 Mtetra
.26775 .41972 .27504 .42672 .28613 .42293 .27888 .4159 Mtetra
.27888 .4159 .28613 .42293 .29727 .41913 .29005 .41207 Mtetra
.29005 .41207 .29727 .41913 .30846 .41532 .30127 .40823 Mtetra
.30127 .40823 .30846 .41532 .3197 .41148 .31253 .40436 Mtetra
.31253 .40436 .3197 .41148 .33099 .40763 .32384 .40048 Mtetra
.32384 .40048 .33099 .40763 .34232 .40377 .33521 .39659 Mtetra
.33521 .39659 .34232 .40377 .3537 .39988 .34662 .39267 Mtetra
.34662 .39267 .3537 .39988 .36513 .39598 .35808 .38874 Mtetra
.35808 .38874 .36513 .39598 .37661 .39207 .36959 .38479 Mtetra
.36959 .38479 .37661 .39207 .38814 .38814 .38115 .38083 Mtetra
.38115 .38083 .38814 .38814 .39972 .38419 .39276 .37685 Mtetra
.39276 .37685 .39972 .38419 .41135 .38022 .40442 .37285 Mtetra
.40442 .37285 .41135 .38022 .42302 .37623 .41613 .36883 Mtetra
.41613 .36883 .42302 .37623 .43475 .37223 .42789 .3648 Mtetra
.42789 .3648 .43475 .37223 .44654 .36821 .43971 .36075 Mtetra
.43971 .36075 .44654 .36821 .45837 .36418 .45157 .35668 Mtetra
.45157 .35668 .45837 .36418 .47025 .36012 .46349 .35259 Mtetra
.46349 .35259 .47025 .36012 .48219 .35605 .47546 .34849 Mtetra
.47546 .34849 .48219 .35605 .49418 .35196 .48748 .34436 Mtetra
.48748 .34436 .49418 .35196 .50622 .34785 .49956 .34022 Mtetra
.49956 .34022 .50622 .34785 .51831 .34373 .51169 .33606 Mtetra
.51169 .33606 .51831 .34373 .53046 .33958 .52387 .33188 Mtetra
.52387 .33188 .53046 .33958 .54266 .33542 .53611 .32769 Mtetra
.53611 .32769 .54266 .33542 .55492 .33124 .5484 .32347 Mtetra
.5484 .32347 .55492 .33124 .56723 .32704 .56075 .31924 Mtetra
.56075 .31924 .56723 .32704 .58272 .50241 .57315 .31498 Mtetra
0 0 .417 r
.57315 .31498 .58272 .50241 .59586 .49835 .5891 .49082 Mtetra
.65 .758 .929 r
.5891 .49082 .59586 .49835 .60906 .49428 .60234 .48671 Mtetra
.60234 .48671 .60906 .49428 .62232 .49019 .61565 .48258 Mtetra
.972 .725 .503 r
.61565 .48258 .62232 .49019 .63565 .48607 .62564 .37137 Mtetra
.56 .364 .572 r
.62564 .37137 .63565 .48607 .64502 .37498 .63863 .36709 Mtetra
.658 .748 .916 r
.63863 .36709 .64502 .37498 .65803 .37072 .65168 .36279 Mtetra
.65168 .36279 .65803 .37072 .6711 .36643 .66479 .35847 Mtetra
.66479 .35847 .6711 .36643 .68423 .36212 .67796 .35412 Mtetra
.67796 .35412 .68423 .36212 .69743 .3578 .6912 .34976 Mtetra
.6912 .34976 .69743 .3578 .71068 .35345 .70449 .34538 Mtetra
.70449 .34538 .71068 .35345 .72399 .34909 .71785 .34097 Mtetra
.71785 .34097 .72399 .34909 .73737 .3447 .73127 .33655 Mtetra
.73127 .33655 .73737 .3447 .75081 .34029 .74476 .3321 Mtetra
.74476 .3321 .75081 .34029 .76504 .34539 .75831 .32764 Mtetra
.431 .453 .781 r
.75831 .32764 .76504 .34539 .77865 .34095 .77267 .33269 Mtetra
.658 .749 .917 r
.77267 .33269 .77865 .34095 .79233 .33648 .78639 .32819 Mtetra
.78639 .32819 .79233 .33648 .80607 .332 .80018 .32367 Mtetra
.80018 .32367 .80607 .332 .81987 .3275 .81403 .31913 Mtetra
.81403 .31913 .81987 .3275 .83375 .32297 .82795 .31456 Mtetra
.82795 .31456 .83375 .32297 .84768 .31843 .84194 .30998 Mtetra
.664 .741 .908 r
.21628 .42788 .22373 .43482 .23467 .43107 .22724 .4241 Mtetra
.22724 .4241 .23467 .43107 .24565 .4273 .23825 .4203 Mtetra
.23825 .4203 .24565 .4273 .25668 .42352 .24931 .41649 Mtetra
.24931 .41649 .25668 .42352 .26775 .41972 .26041 .41266 Mtetra
.26041 .41266 .26775 .41972 .27888 .4159 .27156 .40882 Mtetra
.27156 .40882 .27888 .4159 .29005 .41207 .28276 .40496 Mtetra
.28276 .40496 .29005 .41207 .30127 .40823 .29401 .40108 Mtetra
.29401 .40108 .30127 .40823 .31253 .40436 .3053 .39719 Mtetra
.3053 .39719 .31253 .40436 .32384 .40048 .31665 .39327 Mtetra
.31665 .39327 .32384 .40048 .33521 .39659 .32804 .38935 Mtetra
.32804 .38935 .33521 .39659 .34662 .39267 .33948 .3854 Mtetra
.33948 .3854 .34662 .39267 .35808 .38874 .35097 .38144 Mtetra
.35097 .38144 .35808 .38874 .36959 .38479 .36251 .37746 Mtetra
.36251 .37746 .36959 .38479 .38115 .38083 .3741 .37347 Mtetra
.3741 .37347 .38115 .38083 .39276 .37685 .38574 .36945 Mtetra
.38574 .36945 .39276 .37685 .40442 .37285 .39744 .36542 Mtetra
.39744 .36542 .40442 .37285 .41613 .36883 .40918 .36137 Mtetra
.40918 .36137 .41613 .36883 .42789 .3648 .42097 .35731 Mtetra
.42097 .35731 .42789 .3648 .43971 .36075 .43282 .35322 Mtetra
.43282 .35322 .43971 .36075 .45157 .35668 .44472 .34912 Mtetra
.44472 .34912 .45157 .35668 .46349 .35259 .45667 .345 Mtetra
.45667 .345 .46349 .35259 .47546 .34849 .46867 .34086 Mtetra
.46867 .34086 .47546 .34849 .48748 .34436 .48073 .3367 Mtetra
.48073 .3367 .48748 .34436 .49956 .34022 .49284 .33253 Mtetra
.49284 .33253 .49956 .34022 .51169 .33606 .505 .32833 Mtetra
.505 .32833 .51169 .33606 .52387 .33188 .51722 .32412 Mtetra
.51722 .32412 .52387 .33188 .53611 .32769 .5295 .31989 Mtetra
.5295 .31989 .53611 .32769 .5484 .32347 .54182 .31564 Mtetra
.54182 .31564 .5484 .32347 .56075 .31924 .55421 .31137 Mtetra
.55421 .31137 .56075 .31924 .57315 .31498 .56665 .30708 Mtetra
.56665 .30708 .57315 .31498 .5891 .49082 .57914 .30277 Mtetra
0 0 .417 r
.57914 .30277 .5891 .49082 .60234 .48671 .59556 .47907 Mtetra
.65 .758 .929 r
.59556 .47907 .60234 .48671 .61565 .48258 .60891 .4749 Mtetra
.972 .725 .503 r
.60891 .4749 .61565 .48258 .62564 .37137 .61915 .36345 Mtetra
.658 .748 .916 r
.61915 .36345 .62564 .37137 .63863 .36709 .63218 .35913 Mtetra
.63218 .35913 .63863 .36709 .65168 .36279 .64527 .35479 Mtetra
.64527 .35479 .65168 .36279 .66479 .35847 .65842 .35043 Mtetra
.65842 .35043 .66479 .35847 .67796 .35412 .67164 .34605 Mtetra
.67164 .34605 .67796 .35412 .6912 .34976 .68491 .34165 Mtetra
.68491 .34165 .6912 .34976 .70449 .34538 .69825 .33723 Mtetra
.69825 .33723 .70449 .34538 .71785 .34097 .71166 .33279 Mtetra
.71166 .33279 .71785 .34097 .73127 .33655 .72512 .32832 Mtetra
.72512 .32832 .73127 .33655 .74476 .3321 .73865 .32384 Mtetra
.73865 .32384 .74476 .3321 .75831 .32764 .75225 .31933 Mtetra
.221 .512 .91 r
.75225 .31933 .75831 .32764 .77267 .33269 .76664 .32437 Mtetra
.658 .749 .917 r
.76664 .32437 .77267 .33269 .78639 .32819 .78041 .31983 Mtetra
.78041 .31983 .78639 .32819 .80018 .32367 .79424 .31527 Mtetra
.79424 .31527 .80018 .32367 .81403 .31913 .80814 .31068 Mtetra
.80814 .31068 .81403 .31913 .82795 .31456 .82211 .30608 Mtetra
.82211 .30608 .82795 .31456 .84194 .30998 .83614 .30145 Mtetra
.664 .741 .908 r
.20877 .42089 .21628 .42788 .22724 .4241 .21976 .41708 Mtetra
.21976 .41708 .22724 .4241 .23825 .4203 .2308 .41325 Mtetra
.2308 .41325 .23825 .4203 .24931 .41649 .24188 .40941 Mtetra
.24188 .40941 .24931 .41649 .26041 .41266 .25302 .40555 Mtetra
.25302 .40555 .26041 .41266 .27156 .40882 .26419 .40168 Mtetra
.26419 .40168 .27156 .40882 .28276 .40496 .27542 .39779 Mtetra
.27542 .39779 .28276 .40496 .29401 .40108 .2867 .39388 Mtetra
.2867 .39388 .29401 .40108 .3053 .39719 .29802 .38995 Mtetra
.29802 .38995 .3053 .39719 .31665 .39327 .30939 .38601 Mtetra
.30939 .38601 .31665 .39327 .32804 .38935 .32082 .38205 Mtetra
.32082 .38205 .32804 .38935 .33948 .3854 .33229 .37807 Mtetra
.33229 .37807 .33948 .3854 .35097 .38144 .34381 .37408 Mtetra
.34381 .37408 .35097 .38144 .36251 .37746 .35538 .37007 Mtetra
.35538 .37007 .36251 .37746 .3741 .37347 .367 .36604 Mtetra
.367 .36604 .3741 .37347 .38574 .36945 .37867 .362 Mtetra
.37867 .362 .38574 .36945 .39744 .36542 .3904 .35793 Mtetra
.3904 .35793 .39744 .36542 .40918 .36137 .40217 .35385 Mtetra
.40217 .35385 .40918 .36137 .42097 .35731 .414 .34975 Mtetra
.414 .34975 .42097 .35731 .43282 .35322 .42588 .34563 Mtetra
.42588 .34563 .43282 .35322 .44472 .34912 .43781 .3415 Mtetra
.43781 .3415 .44472 .34912 .45667 .345 .44979 .33734 Mtetra
.44979 .33734 .45667 .345 .46867 .34086 .46183 .33317 Mtetra
.46183 .33317 .46867 .34086 .48073 .3367 .47392 .32898 Mtetra
.47392 .32898 .48073 .3367 .49284 .33253 .48607 .32477 Mtetra
.48607 .32477 .49284 .33253 .505 .32833 .49827 .32054 Mtetra
.49827 .32054 .505 .32833 .51722 .32412 .51052 .31629 Mtetra
.51052 .31629 .51722 .32412 .5295 .31989 .52283 .31203 Mtetra
.52283 .31203 .5295 .31989 .54182 .31564 .53519 .30774 Mtetra
.53519 .30774 .54182 .31564 .55421 .31137 .54761 .30344 Mtetra
.54761 .30344 .55421 .31137 .56665 .30708 .56009 .29911 Mtetra
.56009 .29911 .56665 .30708 .57914 .30277 .57262 .29477 Mtetra
.57262 .29477 .57914 .30277 .59556 .47907 .58521 .2904 Mtetra
.366 .206 .527 r
.58521 .2904 .59556 .47907 .60891 .4749 .59959 .3598 Mtetra
.557 .36 .57 r
.59959 .3598 .60891 .4749 .61915 .36345 .6126 .35546 Mtetra
.658 .748 .916 r
.6126 .35546 .61915 .36345 .63218 .35913 .62567 .3511 Mtetra
.62567 .3511 .63218 .35913 .64527 .35479 .63881 .34673 Mtetra
.63881 .34673 .64527 .35479 .65842 .35043 .652 .34233 Mtetra
.652 .34233 .65842 .35043 .67164 .34605 .66526 .33791 Mtetra
.66526 .33791 .67164 .34605 .68491 .34165 .67858 .33347 Mtetra
.67858 .33347 .68491 .34165 .69825 .33723 .69196 .32901 Mtetra
.69196 .32901 .69825 .33723 .71166 .33279 .70541 .32453 Mtetra
.70541 .32453 .71166 .33279 .72512 .32832 .71892 .32003 Mtetra
.71892 .32003 .72512 .32832 .73865 .32384 .73249 .3155 Mtetra
.73249 .3155 .73865 .32384 .75225 .31933 .74613 .31096 Mtetra
.221 .512 .91 r
.74613 .31096 .75225 .31933 .76664 .32437 .76055 .31597 Mtetra
.658 .749 .917 r
.76055 .31597 .76664 .32437 .78041 .31983 .77437 .31139 Mtetra
.77437 .31139 .78041 .31983 .79424 .31527 .78825 .30679 Mtetra
.78825 .30679 .79424 .31527 .80814 .31068 .8022 .30216 Mtetra
.8022 .30216 .80814 .31068 .82211 .30608 .81621 .29751 Mtetra
.81621 .29751 .82211 .30608 .83614 .30145 .8303 .29284 Mtetra
.664 .741 .908 r
.2012 .41384 .20877 .42089 .21976 .41708 .21222 .41 Mtetra
.21222 .41 .21976 .41708 .2308 .41325 .22329 .40615 Mtetra
.22329 .40615 .2308 .41325 .24188 .40941 .2344 .40227 Mtetra
.2344 .40227 .24188 .40941 .25302 .40555 .24556 .39839 Mtetra
.24556 .39839 .25302 .40555 .26419 .40168 .25677 .39448 Mtetra
.25677 .39448 .26419 .40168 .27542 .39779 .26802 .39056 Mtetra
.26802 .39056 .27542 .39779 .2867 .39388 .27933 .38662 Mtetra
.27933 .38662 .2867 .39388 .29802 .38995 .29068 .38266 Mtetra
.29068 .38266 .29802 .38995 .30939 .38601 .30208 .37869 Mtetra
.30208 .37869 .30939 .38601 .32082 .38205 .31353 .3747 Mtetra
.31353 .3747 .32082 .38205 .33229 .37807 .32503 .37069 Mtetra
.32503 .37069 .33229 .37807 .34381 .37408 .33659 .36666 Mtetra
.33659 .36666 .34381 .37408 .35538 .37007 .34819 .36262 Mtetra
.34819 .36262 .35538 .37007 .367 .36604 .35984 .35856 Mtetra
.35984 .35856 .367 .36604 .37867 .362 .37155 .35448 Mtetra
.37155 .35448 .37867 .362 .3904 .35793 .3833 .35038 Mtetra
.3833 .35038 .3904 .35793 .40217 .35385 .39511 .34627 Mtetra
.39511 .34627 .40217 .35385 .414 .34975 .40697 .34213 Mtetra
.40697 .34213 .414 .34975 .42588 .34563 .41888 .33798 Mtetra
.41888 .33798 .42588 .34563 .43781 .3415 .43084 .33381 Mtetra
.43084 .33381 .43781 .3415 .44979 .33734 .44286 .32963 Mtetra
.44286 .32963 .44979 .33734 .46183 .33317 .45493 .32542 Mtetra
.45493 .32542 .46183 .33317 .47392 .32898 .46706 .32119 Mtetra
.46706 .32119 .47392 .32898 .48607 .32477 .47924 .31695 Mtetra
.47924 .31695 .48607 .32477 .49827 .32054 .49147 .31268 Mtetra
.49147 .31268 .49827 .32054 .51052 .31629 .50376 .3084 Mtetra
.50376 .3084 .51052 .31629 .52283 .31203 .51611 .3041 Mtetra
.51611 .3041 .52283 .31203 .53519 .30774 .52851 .29978 Mtetra
.52851 .29978 .53519 .30774 .54761 .30344 .54097 .29544 Mtetra
.54097 .29544 .54761 .30344 .56009 .29911 .55348 .29108 Mtetra
.55348 .29108 .56009 .29911 .57262 .29477 .56605 .28669 Mtetra
.56605 .28669 .57262 .29477 .58521 .2904 .57868 .28229 Mtetra
.57868 .28229 .58521 .2904 .59959 .3598 .59136 .27787 Mtetra
.047 .005 .481 r
.59136 .27787 .59959 .3598 .6126 .35546 .606 .3474 Mtetra
.658 .748 .916 r
.606 .3474 .6126 .35546 .62567 .3511 .61911 .34301 Mtetra
.61911 .34301 .62567 .3511 .63881 .34673 .63229 .33859 Mtetra
.63229 .33859 .63881 .34673 .652 .34233 .64552 .33416 Mtetra
.64552 .33416 .652 .34233 .66526 .33791 .65882 .3297 Mtetra
.65882 .3297 .66526 .33791 .67858 .33347 .67218 .32522 Mtetra
.67218 .32522 .67858 .33347 .69196 .32901 .68561 .32072 Mtetra
.68561 .32072 .69196 .32901 .70541 .32453 .6991 .3162 Mtetra
.6991 .3162 .70541 .32453 .71892 .32003 .71265 .31166 Mtetra
.71265 .31166 .71892 .32003 .73249 .3155 .72627 .3071 Mtetra
.72627 .3071 .73249 .3155 .74613 .31096 .73996 .30251 Mtetra
.73996 .30251 .74613 .31096 .76055 .31597 .75371 .2979 Mtetra
.428 .451 .782 r
.75371 .2979 .76055 .31597 .77437 .31139 .76827 .30287 Mtetra
.658 .749 .917 r
.76827 .30287 .77437 .31139 .78825 .30679 .7822 .29823 Mtetra
.7822 .29823 .78825 .30679 .8022 .30216 .7962 .29356 Mtetra
.7962 .29356 .8022 .30216 .81621 .29751 .81026 .28888 Mtetra
.81026 .28888 .81621 .29751 .8303 .29284 .8244 .28416 Mtetra
.664 .741 .908 r
.19358 .40674 .2012 .41384 .21222 .41 .20462 .40287 Mtetra
.20462 .40287 .21222 .41 .22329 .40615 .21571 .39899 Mtetra
.21571 .39899 .22329 .40615 .2344 .40227 .22685 .39508 Mtetra
.22685 .39508 .2344 .40227 .24556 .39839 .23804 .39116 Mtetra
.23804 .39116 .24556 .39839 .25677 .39448 .24928 .38723 Mtetra
.24928 .38723 .25677 .39448 .26802 .39056 .26056 .38327 Mtetra
.26056 .38327 .26802 .39056 .27933 .38662 .2719 .3793 Mtetra
.2719 .3793 .27933 .38662 .29068 .38266 .28328 .37531 Mtetra
.28328 .37531 .29068 .38266 .30208 .37869 .29471 .37131 Mtetra
.29471 .37131 .30208 .37869 .31353 .3747 .30619 .36728 Mtetra
.30619 .36728 .31353 .3747 .32503 .37069 .31772 .36324 Mtetra
.31772 .36324 .32503 .37069 .33659 .36666 .32931 .35918 Mtetra
.32931 .35918 .33659 .36666 .34819 .36262 .34094 .35511 Mtetra
.34094 .35511 .34819 .36262 .35984 .35856 .35262 .35101 Mtetra
.35262 .35101 .35984 .35856 .37155 .35448 .36436 .3469 Mtetra
.36436 .3469 .37155 .35448 .3833 .35038 .37615 .34277 Mtetra
.37615 .34277 .3833 .35038 .39511 .34627 .38799 .33862 Mtetra
.38799 .33862 .39511 .34627 .40697 .34213 .39988 .33446 Mtetra
.39988 .33446 .40697 .34213 .41888 .33798 .41182 .33027 Mtetra
.41182 .33027 .41888 .33798 .43084 .33381 .42382 .32607 Mtetra
.42382 .32607 .43084 .33381 .44286 .32963 .43587 .32184 Mtetra
.43587 .32184 .44286 .32963 .45493 .32542 .44798 .3176 Mtetra
.44798 .3176 .45493 .32542 .46706 .32119 .46014 .31334 Mtetra
.46014 .31334 .46706 .32119 .47924 .31695 .47236 .30906 Mtetra
.47236 .30906 .47924 .31695 .49147 .31268 .48463 .30476 Mtetra
.48463 .30476 .49147 .31268 .50376 .3084 .49695 .30044 Mtetra
.49695 .30044 .50376 .3084 .51611 .3041 .50933 .29611 Mtetra
.50933 .29611 .51611 .3041 .52851 .29978 .52177 .29175 Mtetra
.52177 .29175 .52851 .29978 .54097 .29544 .53426 .28737 Mtetra
.53426 .28737 .54097 .29544 .55348 .29108 .54681 .28297 Mtetra
.54681 .28297 .55348 .29108 .56605 .28669 .55942 .27855 Mtetra
.55942 .27855 .56605 .28669 .57868 .28229 .57209 .27412 Mtetra
.57209 .27412 .57868 .28229 .59136 .27787 .58481 .26966 Mtetra
.947 .588 .228 r
.58481 .26966 .59136 .27787 .606 .3474 .59934 .33927 Mtetra
.658 .748 .916 r
.59934 .33927 .606 .3474 .61911 .34301 .61249 .33484 Mtetra
.61249 .33484 .61911 .34301 .63229 .33859 .62571 .33039 Mtetra
.62571 .33039 .63229 .33859 .64552 .33416 .63899 .32591 Mtetra
.63899 .32591 .64552 .33416 .65882 .3297 .65233 .32142 Mtetra
.65233 .32142 .65882 .3297 .67218 .32522 .66574 .3169 Mtetra
.66574 .3169 .67218 .32522 .68561 .32072 .6792 .31236 Mtetra
.6792 .31236 .68561 .32072 .6991 .3162 .69274 .3078 Mtetra
.69274 .3078 .6991 .3162 .71265 .31166 .70634 .30322 Mtetra
.70634 .30322 .71265 .31166 .72627 .3071 .72 .29861 Mtetra
.72 .29861 .72627 .3071 .73996 .30251 .73373 .29398 Mtetra
.73373 .29398 .73996 .30251 .75371 .2979 .74753 .28933 Mtetra
.226 .514 .911 r
.74753 .28933 .75371 .2979 .76827 .30287 .76213 .29428 Mtetra
.658 .749 .917 r
.76213 .29428 .76827 .30287 .7822 .29823 .7761 .2896 Mtetra
.7761 .2896 .7822 .29823 .7962 .29356 .79015 .28489 Mtetra
.79015 .28489 .7962 .29356 .81026 .28888 .80426 .28016 Mtetra
.80426 .28016 .81026 .28888 .8244 .28416 .81844 .2754 Mtetra
.664 .741 .908 r
.18589 .39958 .19358 .40674 .20462 .40287 .19696 .39568 Mtetra
.19696 .39568 .20462 .40287 .21571 .39899 .20808 .39177 Mtetra
.20808 .39177 .21571 .39899 .22685 .39508 .21925 .38783 Mtetra
.21925 .38783 .22685 .39508 .23804 .39116 .23047 .38388 Mtetra
.23047 .38388 .23804 .39116 .24928 .38723 .24173 .37991 Mtetra
.24173 .37991 .24928 .38723 .26056 .38327 .25304 .37593 Mtetra
.25304 .37593 .26056 .38327 .2719 .3793 .26441 .37192 Mtetra
.26441 .37192 .2719 .3793 .28328 .37531 .27582 .3679 Mtetra
.27582 .3679 .28328 .37531 .29471 .37131 .28728 .36387 Mtetra
.28728 .36387 .29471 .37131 .30619 .36728 .29879 .35981 Mtetra
.29879 .35981 .30619 .36728 .31772 .36324 .31035 .35574 Mtetra
.31035 .35574 .31772 .36324 .32931 .35918 .32197 .35165 Mtetra
.32197 .35165 .32931 .35918 .34094 .35511 .33363 .34754 Mtetra
.33363 .34754 .34094 .35511 .35262 .35101 .34535 .34341 Mtetra
.34535 .34341 .35262 .35101 .36436 .3469 .35711 .33926 Mtetra
.35711 .33926 .36436 .3469 .37615 .34277 .36893 .3351 Mtetra
.36893 .3351 .37615 .34277 .38799 .33862 .38081 .33092 Mtetra
.38081 .33092 .38799 .33862 .39988 .33446 .39273 .32671 Mtetra
.39273 .32671 .39988 .33446 .41182 .33027 .40471 .32249 Mtetra
.40471 .32249 .41182 .33027 .42382 .32607 .41674 .31826 Mtetra
.41674 .31826 .42382 .32607 .43587 .32184 .42883 .314 Mtetra
.42883 .314 .43587 .32184 .44798 .3176 .44097 .30972 Mtetra
.44097 .30972 .44798 .3176 .46014 .31334 .45316 .30543 Mtetra
.45316 .30543 .46014 .31334 .47236 .30906 .46541 .30111 Mtetra
.46541 .30111 .47236 .30906 .48463 .30476 .47772 .29677 Mtetra
.47772 .29677 .48463 .30476 .49695 .30044 .49008 .29242 Mtetra
.49008 .29242 .49695 .30044 .50933 .29611 .5025 .28804 Mtetra
.5025 .28804 .50933 .29611 .52177 .29175 .51497 .28365 Mtetra
.51497 .28365 .52177 .29175 .53426 .28737 .5275 .27924 Mtetra
.5275 .27924 .53426 .28737 .54681 .28297 .54009 .2748 Mtetra
.54009 .2748 .54681 .28297 .55942 .27855 .55274 .27035 Mtetra
.55274 .27035 .55942 .27855 .57209 .27412 .56544 .26587 Mtetra
.56544 .26587 .57209 .27412 .58481 .26966 .5782 .26137 Mtetra
.947 .588 .228 r
.5782 .26137 .58481 .26966 .59934 .33927 .59262 .33107 Mtetra
.658 .748 .916 r
.59262 .33107 .59934 .33927 .61249 .33484 .60581 .3266 Mtetra
.60581 .3266 .61249 .33484 .62571 .33039 .61907 .32211 Mtetra
.61907 .32211 .62571 .33039 .63899 .32591 .63239 .3176 Mtetra
.63239 .3176 .63899 .32591 .65233 .32142 .64578 .31306 Mtetra
.64578 .31306 .65233 .32142 .66574 .3169 .65923 .3085 Mtetra
.65923 .3085 .66574 .3169 .6792 .31236 .67274 .30392 Mtetra
.67274 .30392 .6792 .31236 .69274 .3078 .68632 .29932 Mtetra
.68632 .29932 .69274 .3078 .70634 .30322 .69997 .2947 Mtetra
.69997 .2947 .70634 .30322 .72 .29861 .71368 .29005 Mtetra
.71368 .29005 .72 .29861 .73373 .29398 .72745 .28538 Mtetra
.72745 .28538 .73373 .29398 .74753 .28933 .7413 .28069 Mtetra
.7413 .28069 .74753 .28933 .76213 .29428 .75521 .27598 Mtetra
.426 .45 .782 r
.75521 .27598 .76213 .29428 .7761 .2896 .76995 .28089 Mtetra
.658 .749 .917 r
.76995 .28089 .7761 .2896 .79015 .28489 .78404 .27614 Mtetra
.78404 .27614 .79015 .28489 .80426 .28016 .7982 .27136 Mtetra
.7982 .27136 .80426 .28016 .81844 .2754 .81243 .26656 Mtetra
.664 .741 .908 r
.17814 .39237 .18589 .39958 .19696 .39568 .18924 .38844 Mtetra
.18924 .38844 .19696 .39568 .20808 .39177 .20039 .38449 Mtetra
.20039 .38449 .20808 .39177 .21925 .38783 .21158 .38052 Mtetra
.21158 .38052 .21925 .38783 .23047 .38388 .22283 .37654 Mtetra
.22283 .37654 .23047 .38388 .24173 .37991 .23412 .37254 Mtetra
.23412 .37254 .24173 .37991 .25304 .37593 .24546 .36852 Mtetra
.24546 .36852 .25304 .37593 .26441 .37192 .25686 .36449 Mtetra
.25686 .36449 .26441 .37192 .27582 .3679 .2683 .36043 Mtetra
.2683 .36043 .27582 .3679 .28728 .36387 .27979 .35636 Mtetra
.27979 .35636 .28728 .36387 .29879 .35981 .29133 .35228 Mtetra
.29133 .35228 .29879 .35981 .31035 .35574 .30292 .34817 Mtetra
.30292 .34817 .31035 .35574 .32197 .35165 .31457 .34404 Mtetra
.31457 .34404 .32197 .35165 .33363 .34754 .32626 .3399 Mtetra
.32626 .3399 .33363 .34754 .34535 .34341 .33801 .33574 Mtetra
.33801 .33574 .34535 .34341 .35711 .33926 .34981 .33156 Mtetra
.34981 .33156 .35711 .33926 .36893 .3351 .36166 .32736 Mtetra
.36166 .32736 .36893 .3351 .38081 .33092 .37357 .32315 Mtetra
.37357 .32315 .38081 .33092 .39273 .32671 .38553 .31891 Mtetra
.38553 .31891 .39273 .32671 .40471 .32249 .39754 .31465 Mtetra
.39754 .31465 .40471 .32249 .41674 .31826 .4096 .31038 Mtetra
.4096 .31038 .41674 .31826 .42883 .314 .42172 .30609 Mtetra
.42172 .30609 .42883 .314 .44097 .30972 .4339 .30177 Mtetra
.4339 .30177 .44097 .30972 .45316 .30543 .44613 .29744 Mtetra
.44613 .29744 .45316 .30543 .46541 .30111 .45841 .29309 Mtetra
.45841 .29309 .46541 .30111 .47772 .29677 .47075 .28872 Mtetra
.47075 .28872 .47772 .29677 .49008 .29242 .48315 .28433 Mtetra
.48315 .28433 .49008 .29242 .5025 .28804 .49561 .27992 Mtetra
.49561 .27992 .5025 .28804 .51497 .28365 .50812 .27548 Mtetra
.50812 .27548 .51497 .28365 .5275 .27924 .52068 .27103 Mtetra
.52068 .27103 .5275 .27924 .54009 .2748 .53331 .26656 Mtetra
.53331 .26656 .54009 .2748 .55274 .27035 .54599 .26207 Mtetra
.54599 .26207 .55274 .27035 .56544 .26587 .55874 .25755 Mtetra
.55874 .25755 .56544 .26587 .5782 .26137 .57154 .25302 Mtetra
.57154 .25302 .5782 .26137 .59262 .33107 .5844 .24846 Mtetra
.034 0 .474 r
.5844 .24846 .59262 .33107 .60581 .3266 .59908 .31829 Mtetra
.658 .748 .916 r
.59908 .31829 .60581 .3266 .61907 .32211 .61238 .31376 Mtetra
.61238 .31376 .61907 .32211 .63239 .3176 .62574 .3092 Mtetra
.62574 .3092 .63239 .3176 .64578 .31306 .63917 .30463 Mtetra
.63917 .30463 .64578 .31306 .65923 .3085 .65267 .30003 Mtetra
.65267 .30003 .65923 .3085 .67274 .30392 .66622 .29541 Mtetra
.66622 .29541 .67274 .30392 .68632 .29932 .67985 .29077 Mtetra
.67985 .29077 .68632 .29932 .69997 .2947 .69354 .2861 Mtetra
.69354 .2861 .69997 .2947 .71368 .29005 .70729 .28142 Mtetra
.70729 .28142 .71368 .29005 .72745 .28538 .72112 .2767 Mtetra
.72112 .2767 .72745 .28538 .7413 .28069 .73501 .27197 Mtetra
.73501 .27197 .7413 .28069 .75521 .27598 .74896 .26722 Mtetra
.231 .515 .911 r
.74896 .26722 .75521 .27598 .76995 .28089 .76374 .2721 Mtetra
.658 .749 .917 r
.76374 .2721 .76995 .28089 .78404 .27614 .77788 .2673 Mtetra
.77788 .2673 .78404 .27614 .7982 .27136 .79209 .26248 Mtetra
.79209 .26248 .7982 .27136 .81243 .26656 .80637 .25764 Mtetra
.664 .741 .908 r
.17033 .3851 .17814 .39237 .18924 .38844 .18146 .38114 Mtetra
.18146 .38114 .18924 .38844 .20039 .38449 .19263 .37715 Mtetra
.19263 .37715 .20039 .38449 .21158 .38052 .20386 .37316 Mtetra
.20386 .37316 .21158 .38052 .22283 .37654 .21513 .36914 Mtetra
.21513 .36914 .22283 .37654 .23412 .37254 .22645 .36511 Mtetra
.22645 .36511 .23412 .37254 .24546 .36852 .23782 .36106 Mtetra
.23782 .36106 .24546 .36852 .25686 .36449 .24924 .35699 Mtetra
.24924 .35699 .25686 .36449 .2683 .36043 .26072 .35291 Mtetra
.26072 .35291 .2683 .36043 .27979 .35636 .27224 .3488 Mtetra
.27224 .3488 .27979 .35636 .29133 .35228 .28381 .34468 Mtetra
.28381 .34468 .29133 .35228 .30292 .34817 .29543 .34054 Mtetra
.29543 .34054 .30292 .34817 .31457 .34404 .30711 .33638 Mtetra
.30711 .33638 .31457 .34404 .32626 .3399 .31884 .3322 Mtetra
.31884 .3322 .32626 .3399 .33801 .33574 .33061 .32801 Mtetra
.33061 .32801 .33801 .33574 .34981 .33156 .34245 .3238 Mtetra
.34245 .3238 .34981 .33156 .36166 .32736 .35433 .31956 Mtetra
.35433 .31956 .36166 .32736 .37357 .32315 .36627 .31531 Mtetra
.36627 .31531 .37357 .32315 .38553 .31891 .37826 .31104 Mtetra
.37826 .31104 .38553 .31891 .39754 .31465 .39031 .30675 Mtetra
.39031 .30675 .39754 .31465 .4096 .31038 .40241 .30244 Mtetra
.40241 .30244 .4096 .31038 .42172 .30609 .41456 .29811 Mtetra
.41456 .29811 .42172 .30609 .4339 .30177 .42677 .29376 Mtetra
.42677 .29376 .4339 .30177 .44613 .29744 .43903 .28939 Mtetra
.43903 .28939 .44613 .29744 .45841 .29309 .45135 .285 Mtetra
.45135 .285 .45841 .29309 .47075 .28872 .46373 .2806 Mtetra
.46373 .2806 .47075 .28872 .48315 .28433 .47617 .27617 Mtetra
.47617 .27617 .48315 .28433 .49561 .27992 .48866 .27172 Mtetra
.48866 .27172 .49561 .27992 .50812 .27548 .5012 .26725 Mtetra
.5012 .26725 .50812 .27548 .52068 .27103 .51381 .26276 Mtetra
.51381 .26276 .52068 .27103 .53331 .26656 .52647 .25825 Mtetra
.52647 .25825 .53331 .26656 .54599 .26207 .5392 .25372 Mtetra
.5392 .25372 .54599 .26207 .55874 .25755 .55198 .24917 Mtetra
.55198 .24917 .55874 .25755 .57154 .25302 .56482 .24459 Mtetra
.56482 .24459 .57154 .25302 .5844 .24846 .57772 .24 Mtetra
.945 .585 .219 r
.57772 .24 .5844 .24846 .59908 .31829 .59228 .30991 Mtetra
.658 .748 .916 r
.59228 .30991 .59908 .31829 .61238 .31376 .60563 .30533 Mtetra
.60563 .30533 .61238 .31376 .62574 .3092 .61903 .30074 Mtetra
.61903 .30074 .62574 .3092 .63917 .30463 .63251 .29612 Mtetra
.63251 .29612 .63917 .30463 .65267 .30003 .64604 .29148 Mtetra
.64604 .29148 .65267 .30003 .66622 .29541 .65965 .28682 Mtetra
.65965 .28682 .66622 .29541 .67985 .29077 .67331 .28214 Mtetra
.67331 .28214 .67985 .29077 .69354 .2861 .68705 .27743 Mtetra
.68705 .27743 .69354 .2861 .70729 .28142 .70085 .2727 Mtetra
.70085 .2727 .70729 .28142 .72112 .2767 .71472 .26795 Mtetra
.71472 .26795 .72112 .2767 .73501 .27197 .72866 .26317 Mtetra
.72866 .26317 .73501 .27197 .74896 .26722 .74266 .25837 Mtetra
.74266 .25837 .74896 .26722 .76374 .2721 .75674 .25355 Mtetra
.425 .449 .782 r
.75674 .25355 .76374 .2721 .77788 .2673 .77166 .25839 Mtetra
.658 .749 .917 r
.77166 .25839 .77788 .2673 .79209 .26248 .78592 .25353 Mtetra
.78592 .25353 .79209 .26248 .80637 .25764 .80025 .24864 Mtetra
.664 .741 .908 r
.16246 .37777 .17033 .3851 .18146 .38114 .17361 .37377 Mtetra
.17361 .37377 .18146 .38114 .19263 .37715 .18482 .36976 Mtetra
.18482 .36976 .19263 .37715 .20386 .37316 .19607 .36573 Mtetra
.19607 .36573 .20386 .37316 .21513 .36914 .20737 .36168 Mtetra
.20737 .36168 .21513 .36914 .22645 .36511 .21872 .35762 Mtetra
.21872 .35762 .22645 .36511 .23782 .36106 .23012 .35354 Mtetra
.23012 .35354 .23782 .36106 .24924 .35699 .24157 .34943 Mtetra
.24157 .34943 .24924 .35699 .26072 .35291 .25307 .34532 Mtetra
.25307 .34532 .26072 .35291 .27224 .3488 .26462 .34118 Mtetra
.26462 .34118 .27224 .3488 .28381 .34468 .27623 .33702 Mtetra
.27623 .33702 .28381 .34468 .29543 .34054 .28788 .33285 Mtetra
.28788 .33285 .29543 .34054 .30711 .33638 .29959 .32866 Mtetra
.29959 .32866 .30711 .33638 .31884 .3322 .31135 .32444 Mtetra
.31135 .32444 .31884 .3322 .33061 .32801 .32316 .32021 Mtetra
.32316 .32021 .33061 .32801 .34245 .3238 .33502 .31597 Mtetra
.33502 .31597 .34245 .3238 .35433 .31956 .34694 .3117 Mtetra
.34694 .3117 .35433 .31956 .36627 .31531 .35891 .30741 Mtetra
.35891 .30741 .36627 .31531 .37826 .31104 .37093 .3031 Mtetra
.37093 .3031 .37826 .31104 .39031 .30675 .38301 .29878 Mtetra
.38301 .29878 .39031 .30675 .40241 .30244 .39515 .29443 Mtetra
.39515 .29443 .40241 .30244 .41456 .29811 .40734 .29007 Mtetra
.40734 .29007 .41456 .29811 .42677 .29376 .41958 .28568 Mtetra
.41958 .28568 .42677 .29376 .43903 .28939 .43188 .28128 Mtetra
.43188 .28128 .43903 .28939 .45135 .285 .44424 .27685 Mtetra
.44424 .27685 .45135 .285 .46373 .2806 .45665 .2724 Mtetra
.45665 .2724 .46373 .2806 .47617 .27617 .46912 .26794 Mtetra
.46912 .26794 .47617 .27617 .48866 .27172 .48165 .26345 Mtetra
.48165 .26345 .48866 .27172 .5012 .26725 .49423 .25894 Mtetra
.49423 .25894 .5012 .26725 .51381 .26276 .50688 .25442 Mtetra
.50688 .25442 .51381 .26276 .52647 .25825 .51958 .24987 Mtetra
.51958 .24987 .52647 .25825 .5392 .25372 .53234 .2453 Mtetra
.53234 .2453 .5392 .25372 .55198 .24917 .54516 .24071 Mtetra
.54516 .24071 .55198 .24917 .56482 .24459 .55804 .23609 Mtetra
.55804 .23609 .56482 .24459 .57772 .24 .57098 .23146 Mtetra
.57098 .23146 .57772 .24 .59228 .30991 .58398 .2268 Mtetra
.027 0 .471 r
.58398 .2268 .59228 .30991 .60563 .30533 .59881 .29683 Mtetra
.658 .748 .916 r
.59881 .29683 .60563 .30533 .61903 .30074 .61226 .2922 Mtetra
.61226 .2922 .61903 .30074 .63251 .29612 .62578 .28754 Mtetra
.62578 .28754 .63251 .29612 .64604 .29148 .63936 .28286 Mtetra
.63936 .28286 .64604 .29148 .65965 .28682 .65301 .27816 Mtetra
.65301 .27816 .65965 .28682 .67331 .28214 .66672 .27343 Mtetra
.66672 .27343 .67331 .28214 .68705 .27743 .6805 .26868 Mtetra
.6805 .26868 .68705 .27743 .70085 .2727 .69435 .26391 Mtetra
.69435 .26391 .70085 .2727 .71472 .26795 .70827 .25911 Mtetra
.70827 .25911 .71472 .26795 .72866 .26317 .72225 .25429 Mtetra
.72225 .25429 .72866 .26317 .74266 .25837 .73631 .24945 Mtetra
.73631 .24945 .74266 .25837 .75674 .25355 .75043 .24458 Mtetra
.236 .517 .912 r
.75043 .24458 .75674 .25355 .77166 .25839 .76538 .24939 Mtetra
.658 .749 .917 r
.76538 .24939 .77166 .25839 .78592 .25353 .77969 .24449 Mtetra
.77969 .24449 .78592 .25353 .80025 .24864 .79408 .23955 Mtetra
.664 .741 .908 r
.15452 .37038 .16246 .37777 .17361 .37377 .16571 .36635 Mtetra
.16571 .36635 .17361 .37377 .18482 .36976 .17694 .36231 Mtetra
.17694 .36231 .18482 .36976 .19607 .36573 .18822 .35825 Mtetra
.18822 .35825 .19607 .36573 .20737 .36168 .19955 .35416 Mtetra
.19955 .35416 .20737 .36168 .21872 .35762 .21093 .35007 Mtetra
.21093 .35007 .21872 .35762 .23012 .35354 .22236 .34595 Mtetra
.22236 .34595 .23012 .35354 .24157 .34943 .23384 .34182 Mtetra
.23384 .34182 .24157 .34943 .25307 .34532 .24537 .33766 Mtetra
.24537 .33766 .25307 .34532 .26462 .34118 .25695 .33349 Mtetra
.25695 .33349 .26462 .34118 .27623 .33702 .26858 .3293 Mtetra
.26858 .3293 .27623 .33702 .28788 .33285 .28027 .32509 Mtetra
.28027 .32509 .28788 .33285 .29959 .32866 .292 .32087 Mtetra
.292 .32087 .29959 .32866 .31135 .32444 .30379 .31662 Mtetra
.30379 .31662 .31135 .32444 .32316 .32021 .31564 .31236 Mtetra
.31564 .31236 .32316 .32021 .33502 .31597 .32753 .30807 Mtetra
.32753 .30807 .33502 .31597 .34694 .3117 .33948 .30377 Mtetra
.33948 .30377 .34694 .3117 .35891 .30741 .35149 .29944 Mtetra
.35149 .29944 .35891 .30741 .37093 .3031 .36355 .2951 Mtetra
.36355 .2951 .37093 .3031 .38301 .29878 .37566 .29074 Mtetra
.37566 .29074 .38301 .29878 .39515 .29443 .38783 .28636 Mtetra
.38783 .28636 .39515 .29443 .40734 .29007 .40005 .28195 Mtetra
.40005 .28195 .40734 .29007 .41958 .28568 .41233 .27753 Mtetra
.41233 .27753 .41958 .28568 .43188 .28128 .42467 .27309 Mtetra
.42467 .27309 .43188 .28128 .44424 .27685 .43706 .26863 Mtetra
.43706 .26863 .44424 .27685 .45665 .2724 .44951 .26414 Mtetra
.44951 .26414 .45665 .2724 .46912 .26794 .46201 .25964 Mtetra
.46201 .25964 .46912 .26794 .48165 .26345 .47458 .25511 Mtetra
.47458 .25511 .48165 .26345 .49423 .25894 .4872 .25057 Mtetra
.4872 .25057 .49423 .25894 .50688 .25442 .49988 .246 Mtetra
.49988 .246 .50688 .25442 .51958 .24987 .51262 .24141 Mtetra
.51262 .24141 .51958 .24987 .53234 .2453 .52542 .2368 Mtetra
.52542 .2368 .53234 .2453 .54516 .24071 .53828 .23217 Mtetra
.53828 .23217 .54516 .24071 .55804 .23609 .5512 .22752 Mtetra
.5512 .22752 .55804 .23609 .57098 .23146 .56418 .22284 Mtetra
.56418 .22284 .57098 .23146 .58398 .2268 .57722 .21815 Mtetra
.943 .582 .209 r
.57722 .21815 .58398 .2268 .59881 .29683 .59194 .28826 Mtetra
.658 .748 .916 r
.59194 .28826 .59881 .29683 .61226 .2922 .60543 .28358 Mtetra
.60543 .28358 .61226 .2922 .62578 .28754 .61899 .27888 Mtetra
.61899 .27888 .62578 .28754 .63936 .28286 .63262 .27416 Mtetra
.63262 .27416 .63936 .28286 .65301 .27816 .64631 .26941 Mtetra
.64631 .26941 .65301 .27816 .66672 .27343 .66007 .26464 Mtetra
.66007 .26464 .66672 .27343 .6805 .26868 .6739 .25985 Mtetra
.6739 .25985 .6805 .26868 .69435 .26391 .68779 .25504 Mtetra
.68779 .25504 .69435 .26391 .70827 .25911 .70176 .2502 Mtetra
.70176 .2502 .70827 .25911 .72225 .25429 .71579 .24533 Mtetra
.71579 .24533 .72225 .25429 .73631 .24945 .72989 .24044 Mtetra
.72989 .24044 .73631 .24945 .75043 .24458 .74406 .23553 Mtetra
.236 .517 .912 r
.74406 .23553 .75043 .24458 .76538 .24939 .75905 .24031 Mtetra
.658 .749 .917 r
.75905 .24031 .76538 .24939 .77969 .24449 .77341 .23536 Mtetra
.77341 .23536 .77969 .24449 .79408 .23955 .78785 .23038 Mtetra
.664 .741 .908 r
.14652 .36293 .15452 .37038 .16571 .36635 .15773 .35887 Mtetra
.15773 .35887 .16571 .36635 .17694 .36231 .16899 .35479 Mtetra
.16899 .35479 .17694 .36231 .18822 .35825 .1803 .3507 Mtetra
.1803 .3507 .18822 .35825 .19955 .35416 .19166 .34658 Mtetra
.19166 .34658 .19955 .35416 .21093 .35007 .20307 .34245 Mtetra
.20307 .34245 .21093 .35007 .22236 .34595 .21453 .3383 Mtetra
.21453 .3383 .22236 .34595 .23384 .34182 .22604 .33414 Mtetra
.22604 .33414 .23384 .34182 .24537 .33766 .2376 .32995 Mtetra
.2376 .32995 .24537 .33766 .25695 .33349 .24921 .32574 Mtetra
.24921 .32574 .25695 .33349 .26858 .3293 .26087 .32152 Mtetra
.26087 .32152 .26858 .3293 .28027 .32509 .27259 .31728 Mtetra
.27259 .31728 .28027 .32509 .292 .32087 .28436 .31301 Mtetra
.28436 .31301 .292 .32087 .30379 .31662 .29618 .30873 Mtetra
.29618 .30873 .30379 .31662 .31564 .31236 .30806 .30443 Mtetra
.30806 .30443 .31564 .31236 .32753 .30807 .31998 .30011 Mtetra
.31998 .30011 .32753 .30807 .33948 .30377 .33197 .29577 Mtetra
.33197 .29577 .33948 .30377 .35149 .29944 .344 .29141 Mtetra
.344 .29141 .35149 .29944 .36355 .2951 .3561 .28703 Mtetra
.3561 .28703 .36355 .2951 .37566 .29074 .36824 .28263 Mtetra
.36824 .28263 .37566 .29074 .38783 .28636 .38045 .27821 Mtetra
.38045 .27821 .38783 .28636 .40005 .28195 .3927 .27377 Mtetra
.3927 .27377 .40005 .28195 .41233 .27753 .40502 .26932 Mtetra
.40502 .26932 .41233 .27753 .42467 .27309 .41739 .26483 Mtetra
.41739 .26483 .42467 .27309 .43706 .26863 .42982 .26033 Mtetra
.42982 .26033 .43706 .26863 .44951 .26414 .4423 .25581 Mtetra
.4423 .25581 .44951 .26414 .46201 .25964 .45485 .25127 Mtetra
.45485 .25127 .46201 .25964 .47458 .25511 .46745 .24671 Mtetra
.46745 .24671 .47458 .25511 .4872 .25057 .48011 .24212 Mtetra
.48011 .24212 .4872 .25057 .49988 .246 .49283 .23751 Mtetra
.49283 .23751 .49988 .246 .51262 .24141 .50561 .23289 Mtetra
.50561 .23289 .51262 .24141 .52542 .2368 .51844 .22824 Mtetra
.51844 .22824 .52542 .2368 .53828 .23217 .53134 .22356 Mtetra
.53134 .22356 .53828 .23217 .5512 .22752 .5443 .21887 Mtetra
.5443 .21887 .5512 .22752 .56418 .22284 .55732 .21416 Mtetra
.55732 .21416 .56418 .22284 .57722 .21815 .57041 .20942 Mtetra
.943 .582 .209 r
.57041 .20942 .57722 .21815 .59194 .28826 .585 .27961 Mtetra
.658 .748 .916 r
.585 .27961 .59194 .28826 .60543 .28358 .59854 .27489 Mtetra
.59854 .27489 .60543 .28358 .61899 .27888 .61215 .27014 Mtetra
.61215 .27014 .61899 .27888 .63262 .27416 .62582 .26538 Mtetra
.62582 .26538 .63262 .27416 .64631 .26941 .63955 .26059 Mtetra
.63955 .26059 .64631 .26941 .66007 .26464 .65336 .25578 Mtetra
.65336 .25578 .66007 .26464 .6739 .25985 .66723 .25094 Mtetra
.66723 .25094 .6739 .25985 .68779 .25504 .68118 .24608 Mtetra
.68118 .24608 .68779 .25504 .70176 .2502 .69519 .2412 Mtetra
.69519 .2412 .70176 .2502 .71579 .24533 .70927 .23629 Mtetra
.70927 .23629 .71579 .24533 .72989 .24044 .72342 .23136 Mtetra
.72342 .23136 .72989 .24044 .74406 .23553 .73764 .2264 Mtetra
.73764 .2264 .74406 .23553 .75905 .24031 .75193 .22142 Mtetra
.422 .448 .782 r
.75193 .22142 .75905 .24031 .77341 .23536 .76707 .22615 Mtetra
.658 .749 .917 r
.76707 .22615 .77341 .23536 .78785 .23038 .78155 .22113 Mtetra
.664 .741 .908 r
.13846 .35542 .14652 .36293 .15773 .35887 .1497 .35133 Mtetra
.1497 .35133 .15773 .35887 .16899 .35479 .16098 .34722 Mtetra
.16098 .34722 .16899 .35479 .1803 .3507 .17232 .34309 Mtetra
.17232 .34309 .1803 .3507 .19166 .34658 .18371 .33894 Mtetra
.18371 .33894 .19166 .34658 .20307 .34245 .19515 .33478 Mtetra
.19515 .33478 .20307 .34245 .21453 .3383 .20663 .33059 Mtetra
.20663 .33059 .21453 .3383 .22604 .33414 .21817 .32639 Mtetra
.21817 .32639 .22604 .33414 .2376 .32995 .22976 .32217 Mtetra
.22976 .32217 .2376 .32995 .24921 .32574 .24141 .31793 Mtetra
.24141 .31793 .24921 .32574 .26087 .32152 .2531 .31367 Mtetra
.2531 .31367 .26087 .32152 .27259 .31728 .26485 .30939 Mtetra
.26485 .30939 .27259 .31728 .28436 .31301 .27665 .30509 Mtetra
.27665 .30509 .28436 .31301 .29618 .30873 .2885 .30078 Mtetra
.2885 .30078 .29618 .30873 .30806 .30443 .30041 .29644 Mtetra
.30041 .29644 .30806 .30443 .31998 .30011 .31237 .29208 Mtetra
.31237 .29208 .31998 .30011 .33197 .29577 .32439 .28771 Mtetra
.32439 .28771 .33197 .29577 .344 .29141 .33646 .28331 Mtetra
.33646 .28331 .344 .29141 .3561 .28703 .34858 .2789 Mtetra
.34858 .2789 .3561 .28703 .36824 .28263 .36077 .27446 Mtetra
.36077 .27446 .36824 .28263 .38045 .27821 .373 .27 Mtetra
.373 .27 .38045 .27821 .3927 .27377 .3853 .26553 Mtetra
.3853 .26553 .3927 .27377 .40502 .26932 .39764 .26103 Mtetra
.39764 .26103 .40502 .26932 .41739 .26483 .41005 .25651 Mtetra
.41005 .25651 .41739 .26483 .42982 .26033 .42252 .25197 Mtetra
.42252 .25197 .42982 .26033 .4423 .25581 .43504 .24741 Mtetra
.43504 .24741 .4423 .25581 .45485 .25127 .44762 .24283 Mtetra
.44762 .24283 .45485 .25127 .46745 .24671 .46026 .23822 Mtetra
.46026 .23822 .46745 .24671 .48011 .24212 .47296 .2336 Mtetra
.47296 .2336 .48011 .24212 .49283 .23751 .48571 .22895 Mtetra
.48571 .22895 .49283 .23751 .50561 .23289 .49853 .22429 Mtetra
.49853 .22429 .50561 .23289 .51844 .22824 .51141 .2196 Mtetra
.51141 .2196 .51844 .22824 .53134 .22356 .52435 .21488 Mtetra
.52435 .21488 .53134 .22356 .5443 .21887 .53735 .21015 Mtetra
.53735 .21015 .5443 .21887 .55732 .21416 .55041 .20539 Mtetra
.55041 .20539 .55732 .21416 .57041 .20942 .56353 .20061 Mtetra
.56353 .20061 .57041 .20942 .585 .27961 .57672 .19581 Mtetra
.013 0 .463 r
.57672 .19581 .585 .27961 .59854 .27489 .59159 .26611 Mtetra
.658 .748 .916 r
.59159 .26611 .59854 .27489 .61215 .27014 .60524 .26133 Mtetra
.60524 .26133 .61215 .27014 .62582 .26538 .61895 .25652 Mtetra
.61895 .25652 .62582 .26538 .63955 .26059 .63274 .25169 Mtetra
.63274 .25169 .63955 .26059 .65336 .25578 .64659 .24683 Mtetra
.64659 .24683 .65336 .25578 .66723 .25094 .66051 .24195 Mtetra
.66051 .24195 .66723 .25094 .68118 .24608 .6745 .23705 Mtetra
.6745 .23705 .68118 .24608 .69519 .2412 .68856 .23212 Mtetra
.68856 .23212 .69519 .2412 .70927 .23629 .70268 .22716 Mtetra
.70268 .22716 .70927 .23629 .72342 .23136 .71688 .22219 Mtetra
.71688 .22219 .72342 .23136 .73764 .2264 .73115 .21718 Mtetra
.73115 .21718 .73764 .2264 .75193 .22142 .7455 .21215 Mtetra
.241 .519 .912 r
.7455 .21215 .75193 .22142 .76707 .22615 .76067 .21686 Mtetra
.658 .749 .917 r
.76067 .21686 .76707 .22615 .78155 .22113 .77521 .21179 Mtetra
.664 .741 .908 r
.13033 .34785 .13846 .35542 .1497 .35133 .1416 .34373 Mtetra
.1416 .34373 .1497 .35133 .16098 .34722 .15291 .33958 Mtetra
.15291 .33958 .16098 .34722 .17232 .34309 .16428 .33542 Mtetra
.16428 .33542 .17232 .34309 .18371 .33894 .17569 .33124 Mtetra
.17569 .33124 .18371 .33894 .19515 .33478 .18716 .32704 Mtetra
.18716 .32704 .19515 .33478 .20663 .33059 .19868 .32282 Mtetra
.19868 .32282 .20663 .33059 .21817 .32639 .21025 .31858 Mtetra
.21025 .31858 .21817 .32639 .22976 .32217 .22187 .31433 Mtetra
.22187 .31433 .22976 .32217 .24141 .31793 .23354 .31005 Mtetra
.23354 .31005 .24141 .31793 .2531 .31367 .24527 .30576 Mtetra
.24527 .30576 .2531 .31367 .26485 .30939 .25704 .30144 Mtetra
.25704 .30144 .26485 .30939 .27665 .30509 .26888 .29711 Mtetra
.26888 .29711 .27665 .30509 .2885 .30078 .28076 .29276 Mtetra
.28076 .29276 .2885 .30078 .30041 .29644 .2927 .28838 Mtetra
.2927 .28838 .30041 .29644 .31237 .29208 .3047 .28399 Mtetra
.3047 .28399 .31237 .29208 .32439 .28771 .31674 .27958 Mtetra
.31674 .27958 .32439 .28771 .33646 .28331 .32885 .27514 Mtetra
.32885 .27514 .33646 .28331 .34858 .2789 .34101 .27069 Mtetra
.34101 .27069 .34858 .2789 .36077 .27446 .35322 .26622 Mtetra
.35322 .26622 .36077 .27446 .373 .27 .36549 .26172 Mtetra
.36549 .26172 .373 .27 .3853 .26553 .37782 .25721 Mtetra
.37782 .25721 .3853 .26553 .39764 .26103 .39021 .25267 Mtetra
.39021 .25267 .39764 .26103 .41005 .25651 .40265 .24811 Mtetra
.40265 .24811 .41005 .25651 .42252 .25197 .41515 .24353 Mtetra
.41515 .24353 .42252 .25197 .43504 .24741 .42771 .23893 Mtetra
.42771 .23893 .43504 .24741 .44762 .24283 .44033 .23431 Mtetra
.44033 .23431 .44762 .24283 .46026 .23822 .453 .22967 Mtetra
.453 .22967 .46026 .23822 .47296 .2336 .46574 .225 Mtetra
.46574 .225 .47296 .2336 .48571 .22895 .47854 .22032 Mtetra
.47854 .22032 .48571 .22895 .49853 .22429 .49139 .21561 Mtetra
.49139 .21561 .49853 .22429 .51141 .2196 .50431 .21088 Mtetra
.50431 .21088 .51141 .2196 .52435 .21488 .51729 .20612 Mtetra
.51729 .20612 .52435 .21488 .53735 .21015 .53033 .20135 Mtetra
.53033 .20135 .53735 .21015 .55041 .20539 .54343 .19655 Mtetra
.54343 .19655 .55041 .20539 .56353 .20061 .55659 .19173 Mtetra
.55659 .19173 .56353 .20061 .57672 .19581 .56982 .18688 Mtetra
.941 .578 .2 r
.56982 .18688 .57672 .19581 .59159 .26611 .58457 .25726 Mtetra
.658 .748 .916 r
.58457 .25726 .59159 .26611 .60524 .26133 .59826 .25243 Mtetra
.59826 .25243 .60524 .26133 .61895 .25652 .61202 .24758 Mtetra
.61202 .24758 .61895 .25652 .63274 .25169 .62585 .2427 Mtetra
.62585 .2427 .63274 .25169 .64659 .24683 .63975 .2378 Mtetra
.63975 .2378 .64659 .24683 .66051 .24195 .65372 .23288 Mtetra
.65372 .23288 .66051 .24195 .6745 .23705 .66776 .22793 Mtetra
.66776 .22793 .6745 .23705 .68856 .23212 .68186 .22295 Mtetra
.68186 .22295 .68856 .23212 .70268 .22716 .69604 .21795 Mtetra
.69604 .21795 .70268 .22716 .71688 .22219 .71029 .21293 Mtetra
.71029 .21293 .71688 .22219 .73115 .21718 .72461 .20788 Mtetra
.72461 .20788 .73115 .21718 .7455 .21215 .739 .2028 Mtetra
.739 .2028 .7455 .21215 .76067 .21686 .75347 .1977 Mtetra
.42 .447 .782 r
.75347 .1977 .76067 .21686 .77521 .21179 .7688 .20236 Mtetra
.664 .741 .908 r
.12213 .34022 .13033 .34785 .1416 .34373 .13343 .33606 Mtetra
.13343 .33606 .1416 .34373 .15291 .33958 .14477 .33188 Mtetra
.14477 .33188 .15291 .33958 .16428 .33542 .15616 .32769 Mtetra
.15616 .32769 .16428 .33542 .17569 .33124 .16761 .32347 Mtetra
.16761 .32347 .17569 .33124 .18716 .32704 .17911 .31924 Mtetra
.17911 .31924 .18716 .32704 .19868 .32282 .19065 .31498 Mtetra
.19065 .31498 .19868 .32282 .21025 .31858 .20225 .31071 Mtetra
.20225 .31071 .21025 .31858 .22187 .31433 .2139 .30642 Mtetra
.2139 .30642 .22187 .31433 .23354 .31005 .22561 .30211 Mtetra
.22561 .30211 .23354 .31005 .24527 .30576 .23736 .29778 Mtetra
.23736 .29778 .24527 .30576 .25704 .30144 .24917 .29343 Mtetra
.24917 .29343 .25704 .30144 .26888 .29711 .26104 .28906 Mtetra
.26104 .28906 .26888 .29711 .28076 .29276 .27296 .28467 Mtetra
.27296 .28467 .28076 .29276 .2927 .28838 .28493 .28026 Mtetra
.28493 .28026 .2927 .28838 .3047 .28399 .29695 .27583 Mtetra
.29695 .27583 .3047 .28399 .31674 .27958 .30904 .27138 Mtetra
.30904 .27138 .31674 .27958 .32885 .27514 .32117 .26691 Mtetra
.32117 .26691 .32885 .27514 .34101 .27069 .33337 .26241 Mtetra
.33337 .26241 .34101 .27069 .35322 .26622 .34562 .2579 Mtetra
.34562 .2579 .35322 .26622 .36549 .26172 .35792 .25337 Mtetra
.35792 .25337 .36549 .26172 .37782 .25721 .37029 .24881 Mtetra
.37029 .24881 .37782 .25721 .39021 .25267 .38271 .24424 Mtetra
.38271 .24424 .39021 .25267 .40265 .24811 .39519 .23964 Mtetra
.39519 .23964 .40265 .24811 .41515 .24353 .40772 .23502 Mtetra
.40772 .23502 .41515 .24353 .42771 .23893 .42032 .23039 Mtetra
.42032 .23039 .42771 .23893 .44033 .23431 .43297 .22572 Mtetra
.43297 .22572 .44033 .23431 .453 .22967 .44569 .22104 Mtetra
.44569 .22104 .453 .22967 .46574 .225 .45846 .21634 Mtetra
.45846 .21634 .46574 .225 .47854 .22032 .4713 .21161 Mtetra
.4713 .21161 .47854 .22032 .49139 .21561 .48419 .20686 Mtetra
.48419 .20686 .49139 .21561 .50431 .21088 .49715 .20209 Mtetra
.49715 .20209 .50431 .21088 .51729 .20612 .51017 .19729 Mtetra
.51017 .19729 .51729 .20612 .53033 .20135 .52325 .19247 Mtetra
.52325 .19247 .53033 .20135 .54343 .19655 .53639 .18763 Mtetra
.53639 .18763 .54343 .19655 .55659 .19173 .5496 .18277 Mtetra
.5496 .18277 .55659 .19173 .56982 .18688 .56287 .17788 Mtetra
.56287 .17788 .56982 .18688 .58457 .25726 .5762 .17297 Mtetra
.006 0 .459 r
.5762 .17297 .58457 .25726 .59826 .25243 .59123 .24346 Mtetra
.658 .748 .916 r
.59123 .24346 .59826 .25243 .61202 .24758 .60503 .23856 Mtetra
.60503 .23856 .61202 .24758 .62585 .2427 .61891 .23364 Mtetra
.61891 .23364 .62585 .2427 .63975 .2378 .63285 .22869 Mtetra
.63285 .22869 .63975 .2378 .65372 .23288 .64687 .22372 Mtetra
.64687 .22372 .65372 .23288 .66776 .22793 .66095 .21872 Mtetra
.66095 .21872 .66776 .22793 .68186 .22295 .67511 .2137 Mtetra
.67511 .2137 .68186 .22295 .69604 .21795 .68933 .20866 Mtetra
.68933 .20866 .69604 .21795 .71029 .21293 .70363 .20359 Mtetra
.70363 .20359 .71029 .21293 .72461 .20788 .718 .19849 Mtetra
.718 .19849 .72461 .20788 .739 .2028 .73245 .19337 Mtetra
.73245 .19337 .739 .2028 .75347 .1977 .74696 .18822 Mtetra
.245 .521 .913 r
.74696 .18822 .75347 .1977 .7688 .20236 .76233 .19284 Mtetra
.664 .741 .908 r
.11387 .33253 .12213 .34022 .13343 .33606 .12519 .32833 Mtetra
.12519 .32833 .13343 .33606 .14477 .33188 .13656 .32412 Mtetra
.13656 .32412 .14477 .33188 .15616 .32769 .14799 .31989 Mtetra
.14799 .31989 .15616 .32769 .16761 .32347 .15946 .31564 Mtetra
.15946 .31564 .16761 .32347 .17911 .31924 .17099 .31137 Mtetra
.17099 .31137 .17911 .31924 .19065 .31498 .18256 .30708 Mtetra
.18256 .30708 .19065 .31498 .20225 .31071 .19419 .30277 Mtetra
.19419 .30277 .20225 .31071 .2139 .30642 .20587 .29844 Mtetra
.20587 .29844 .2139 .30642 .22561 .30211 .21761 .2941 Mtetra
.21761 .2941 .22561 .30211 .23736 .29778 .2294 .28973 Mtetra
.2294 .28973 .23736 .29778 .24917 .29343 .24124 .28534 Mtetra
.24124 .28534 .24917 .29343 .26104 .28906 .25313 .28094 Mtetra
.25313 .28094 .26104 .28906 .27296 .28467 .26508 .27651 Mtetra
.26508 .27651 .27296 .28467 .28493 .28026 .27709 .27206 Mtetra
.27709 .27206 .28493 .28026 .29695 .27583 .28915 .26759 Mtetra
.28915 .26759 .29695 .27583 .30904 .27138 .30126 .26311 Mtetra
.30126 .26311 .30904 .27138 .32117 .26691 .31343 .2586 Mtetra
.31343 .2586 .32117 .26691 .33337 .26241 .32566 .25407 Mtetra
.32566 .25407 .33337 .26241 .34562 .2579 .33795 .24952 Mtetra
.33795 .24952 .34562 .2579 .35792 .25337 .35029 .24494 Mtetra
.35029 .24494 .35792 .25337 .37029 .24881 .36269 .24035 Mtetra
.36269 .24035 .37029 .24881 .38271 .24424 .37514 .23574 Mtetra
.37514 .23574 .38271 .24424 .39519 .23964 .38766 .2311 Mtetra
.38766 .2311 .39519 .23964 .40772 .23502 .40023 .22644 Mtetra
.40023 .22644 .40772 .23502 .42032 .23039 .41286 .22176 Mtetra
.41286 .22176 .42032 .23039 .43297 .22572 .42556 .21706 Mtetra
.42556 .21706 .43297 .22572 .44569 .22104 .43831 .21234 Mtetra
.43831 .21234 .44569 .22104 .45846 .21634 .45112 .20759 Mtetra
.45112 .20759 .45846 .21634 .4713 .21161 .46399 .20282 Mtetra
.46399 .20282 .4713 .21161 .48419 .20686 .47693 .19803 Mtetra
.47693 .19803 .48419 .20686 .49715 .20209 .48993 .19321 Mtetra
.48993 .19321 .49715 .20209 .51017 .19729 .50298 .18838 Mtetra
.50298 .18838 .51017 .19729 .52325 .19247 .5161 .18352 Mtetra
.5161 .18352 .52325 .19247 .53639 .18763 .52929 .17863 Mtetra
.52929 .17863 .53639 .18763 .5496 .18277 .54254 .17372 Mtetra
.54254 .17372 .5496 .18277 .56287 .17788 .55585 .16879 Mtetra
.55585 .16879 .56287 .17788 .5762 .17297 .56922 .16384 Mtetra
.56922 .16384 .5762 .17297 .59123 .24346 .58266 .15886 Mtetra
.006 0 .459 r
.58266 .15886 .59123 .24346 .60503 .23856 .59798 .22945 Mtetra
.658 .748 .916 r
.59798 .22945 .60503 .23856 .61891 .23364 .6119 .22449 Mtetra
.6119 .22449 .61891 .23364 .63285 .22869 .62589 .21949 Mtetra
.62589 .21949 .63285 .22869 .64687 .22372 .63995 .21448 Mtetra
.63995 .21448 .64687 .22372 .66095 .21872 .65409 .20944 Mtetra
.65409 .20944 .66095 .21872 .67511 .2137 .66829 .20437 Mtetra
.66829 .20437 .67511 .2137 .68933 .20866 .68257 .19927 Mtetra
.68257 .19927 .68933 .20866 .70363 .20359 .69691 .19416 Mtetra
.69691 .19416 .70363 .20359 .718 .19849 .71134 .18901 Mtetra
.71134 .18901 .718 .19849 .73245 .19337 .72583 .18384 Mtetra
.72583 .18384 .73245 .19337 .74696 .18822 .7404 .17864 Mtetra
.245 .521 .913 r
.7404 .17864 .74696 .18822 .76233 .19284 .7558 .18323 Mtetra
.664 .741 .908 r
.10554 .32477 .11387 .33253 .12519 .32833 .11689 .32054 Mtetra
.11689 .32054 .12519 .32833 .13656 .32412 .12829 .31629 Mtetra
.12829 .31629 .13656 .32412 .14799 .31989 .13974 .31203 Mtetra
.13974 .31203 .14799 .31989 .15946 .31564 .15124 .30774 Mtetra
.15124 .30774 .15946 .31564 .17099 .31137 .1628 .30344 Mtetra
.1628 .30344 .17099 .31137 .18256 .30708 .1744 .29911 Mtetra
.1744 .29911 .18256 .30708 .19419 .30277 .18606 .29477 Mtetra
.18606 .29477 .19419 .30277 .20587 .29844 .19778 .2904 Mtetra
.19778 .2904 .20587 .29844 .21761 .2941 .20954 .28602 Mtetra
.20954 .28602 .21761 .2941 .2294 .28973 .22136 .28162 Mtetra
.22136 .28162 .2294 .28973 .24124 .28534 .23323 .27719 Mtetra
.23323 .27719 .24124 .28534 .25313 .28094 .24516 .27275 Mtetra
.24516 .27275 .25313 .28094 .26508 .27651 .25714 .26828 Mtetra
.25714 .26828 .26508 .27651 .27709 .27206 .26918 .2638 Mtetra
.26918 .2638 .27709 .27206 .28915 .26759 .28127 .25929 Mtetra
.28127 .25929 .28915 .26759 .30126 .26311 .29342 .25477 Mtetra
.29342 .25477 .30126 .26311 .31343 .2586 .30563 .25022 Mtetra
.30563 .25022 .31343 .2586 .32566 .25407 .31789 .24565 Mtetra
.31789 .24565 .32566 .25407 .33795 .24952 .33021 .24106 Mtetra
.33021 .24106 .33795 .24952 .35029 .24494 .34259 .23645 Mtetra
.34259 .23645 .35029 .24494 .36269 .24035 .35502 .23182 Mtetra
.35502 .23182 .36269 .24035 .37514 .23574 .36751 .22716 Mtetra
.36751 .22716 .37514 .23574 .38766 .2311 .38006 .22248 Mtetra
.38006 .22248 .38766 .2311 .40023 .22644 .39267 .21779 Mtetra
.39267 .21779 .40023 .22644 .41286 .22176 .40534 .21306 Mtetra
.40534 .21306 .41286 .22176 .42556 .21706 .41807 .20832 Mtetra
.41807 .20832 .42556 .21706 .43831 .21234 .43086 .20356 Mtetra
.43086 .20356 .43831 .21234 .45112 .20759 .44372 .19877 Mtetra
.44372 .19877 .45112 .20759 .46399 .20282 .45663 .19396 Mtetra
.45663 .19396 .46399 .20282 .47693 .19803 .4696 .18912 Mtetra
.4696 .18912 .47693 .19803 .48993 .19321 .48264 .18427 Mtetra
.48264 .18427 .48993 .19321 .50298 .18838 .49574 .17939 Mtetra
.49574 .17939 .50298 .18838 .5161 .18352 .5089 .17448 Mtetra
.5089 .17448 .5161 .18352 .52929 .17863 .52212 .16955 Mtetra
.52212 .16955 .52929 .17863 .54254 .17372 .53541 .1646 Mtetra
.53541 .1646 .54254 .17372 .55585 .16879 .54877 .15963 Mtetra
.54877 .15963 .55585 .16879 .56922 .16384 .56218 .15463 Mtetra
.56218 .15463 .56922 .16384 .58266 .15886 .57567 .1496 Mtetra
.936 .571 .18 r
.57567 .1496 .58266 .15886 .59798 .22945 .59086 .22026 Mtetra
.658 .748 .916 r
.59086 .22026 .59798 .22945 .6119 .22449 .60483 .21525 Mtetra
.60483 .21525 .6119 .22449 .62589 .21949 .61887 .21021 Mtetra
.61887 .21021 .62589 .21949 .63995 .21448 .63298 .20515 Mtetra
.63298 .20515 .63995 .21448 .65409 .20944 .64716 .20006 Mtetra
.64716 .20006 .65409 .20944 .66829 .20437 .66141 .19495 Mtetra
.66141 .19495 .66829 .20437 .68257 .19927 .67573 .1898 Mtetra
.67573 .1898 .68257 .19927 .69691 .19416 .69013 .18464 Mtetra
.69013 .18464 .69691 .19416 .71134 .18901 .7046 .17944 Mtetra
.7046 .17944 .71134 .18901 .72583 .18384 .71915 .17422 Mtetra
.71915 .17422 .72583 .18384 .7404 .17864 .73377 .16898 Mtetra
.73377 .16898 .7404 .17864 .7558 .18323 .74847 .1637 Mtetra
.664 .741 .908 r
.09714 .31695 .10554 .32477 .11689 .32054 .10852 .31268 Mtetra
.10852 .31268 .11689 .32054 .12829 .31629 .11995 .3084 Mtetra
.11995 .3084 .12829 .31629 .13974 .31203 .13143 .3041 Mtetra
.13143 .3041 .13974 .31203 .15124 .30774 .14296 .29978 Mtetra
.14296 .29978 .15124 .30774 .1628 .30344 .15454 .29544 Mtetra
.15454 .29544 .1628 .30344 .1744 .29911 .16618 .29108 Mtetra
.16618 .29108 .1744 .29911 .18606 .29477 .17787 .28669 Mtetra
.17787 .28669 .18606 .29477 .19778 .2904 .18961 .28229 Mtetra
.18961 .28229 .19778 .2904 .20954 .28602 .20141 .27787 Mtetra
.20141 .27787 .20954 .28602 .22136 .28162 .21326 .27343 Mtetra
.21326 .27343 .22136 .28162 .23323 .27719 .22516 .26897 Mtetra
.22516 .26897 .23323 .27719 .24516 .27275 .23712 .26449 Mtetra
.23712 .26449 .24516 .27275 .25714 .26828 .24914 .25999 Mtetra
.24914 .25999 .25714 .26828 .26918 .2638 .26121 .25546 Mtetra
.26121 .25546 .26918 .2638 .28127 .25929 .27333 .25092 Mtetra
.27333 .25092 .28127 .25929 .29342 .25477 .28552 .24635 Mtetra
.28552 .24635 .29342 .25477 .30563 .25022 .29776 .24177 Mtetra
.29776 .24177 .30563 .25022 .31789 .24565 .31005 .23716 Mtetra
.31005 .23716 .31789 .24565 .33021 .24106 .32241 .23253 Mtetra
.32241 .23253 .33021 .24106 .34259 .23645 .33482 .22788 Mtetra
.33482 .22788 .34259 .23645 .35502 .23182 .34729 .2232 Mtetra
.34729 .2232 .35502 .23182 .36751 .22716 .35982 .21851 Mtetra
.35982 .21851 .36751 .22716 .38006 .22248 .3724 .21379 Mtetra
.3724 .21379 .38006 .22248 .39267 .21779 .38505 .20905 Mtetra
.38505 .20905 .39267 .21779 .40534 .21306 .39776 .20429 Mtetra
.39776 .20429 .40534 .21306 .41807 .20832 .41053 .19951 Mtetra
.41053 .19951 .41807 .20832 .43086 .20356 .42335 .1947 Mtetra
.42335 .1947 .43086 .20356 .44372 .19877 .43624 .18987 Mtetra
.43624 .18987 .44372 .19877 .45663 .19396 .4492 .18501 Mtetra
.4492 .18501 .45663 .19396 .4696 .18912 .46221 .18014 Mtetra
.46221 .18014 .4696 .18912 .48264 .18427 .47529 .17524 Mtetra
.47529 .17524 .48264 .18427 .49574 .17939 .48843 .17031 Mtetra
.48843 .17031 .49574 .17939 .5089 .17448 .50163 .16537 Mtetra
.50163 .16537 .5089 .17448 .52212 .16955 .51489 .16039 Mtetra
.51489 .16039 .52212 .16955 .53541 .1646 .52823 .1554 Mtetra
.52823 .1554 .53541 .1646 .54877 .15963 .54162 .15038 Mtetra
.54162 .15038 .54877 .15963 .56218 .15463 .55508 .14533 Mtetra
.55508 .14533 .56218 .15463 .57567 .1496 .56861 .14026 Mtetra
.56861 .14026 .57567 .1496 .59086 .22026 .5822 .13517 Mtetra
0 0 .455 r
.5822 .13517 .59086 .22026 .60483 .21525 .59769 .20593 Mtetra
.658 .748 .916 r
.59769 .20593 .60483 .21525 .61887 .21021 .61178 .20084 Mtetra
.61178 .20084 .61887 .21021 .63298 .20515 .62593 .19573 Mtetra
.62593 .19573 .63298 .20515 .64716 .20006 .64016 .1906 Mtetra
.64016 .1906 .64716 .20006 .66141 .19495 .65446 .18543 Mtetra
.65446 .18543 .66141 .19495 .67573 .1898 .66884 .18024 Mtetra
.66884 .18024 .67573 .1898 .69013 .18464 .68329 .17503 Mtetra
.68329 .17503 .69013 .18464 .7046 .17944 .69781 .16979 Mtetra
.69781 .16979 .7046 .17944 .71915 .17422 .71241 .16452 Mtetra
.71241 .16452 .71915 .17422 .73377 .16898 .72708 .15922 Mtetra
.72708 .15922 .73377 .16898 .74847 .1637 .74183 .15389 Mtetra
.664 .741 .908 r
.08867 .30906 .09714 .31695 .10852 .31268 .10008 .30476 Mtetra
.10008 .30476 .10852 .31268 .11995 .3084 .11153 .30044 Mtetra
.11153 .30044 .11995 .3084 .13143 .3041 .12304 .29611 Mtetra
.12304 .29611 .13143 .3041 .14296 .29978 .1346 .29175 Mtetra
.1346 .29175 .14296 .29978 .15454 .29544 .14622 .28737 Mtetra
.14622 .28737 .15454 .29544 .16618 .29108 .15788 .28297 Mtetra
.15788 .28297 .16618 .29108 .17787 .28669 .1696 .27855 Mtetra
.1696 .27855 .17787 .28669 .18961 .28229 .18138 .27412 Mtetra
.18138 .27412 .18961 .28229 .20141 .27787 .1932 .26966 Mtetra
.1932 .26966 .20141 .27787 .21326 .27343 .20509 .26518 Mtetra
.20509 .26518 .21326 .27343 .22516 .26897 .21702 .26068 Mtetra
.21702 .26068 .22516 .26897 .23712 .26449 .22901 .25616 Mtetra
.22901 .25616 .23712 .26449 .24914 .25999 .24106 .25162 Mtetra
.24106 .25162 .24914 .25999 .26121 .25546 .25317 .24706 Mtetra
.25317 .24706 .26121 .25546 .27333 .25092 .26532 .24247 Mtetra
.26532 .24247 .27333 .25092 .28552 .24635 .27754 .23787 Mtetra
.27754 .23787 .28552 .24635 .29776 .24177 .28981 .23324 Mtetra
.28981 .23324 .29776 .24177 .31005 .23716 .30215 .22859 Mtetra
.30215 .22859 .31005 .23716 .32241 .23253 .31453 .22393 Mtetra
.31453 .22393 .32241 .23253 .33482 .22788 .32698 .21923 Mtetra
.32698 .21923 .33482 .22788 .34729 .2232 .33949 .21452 Mtetra
.33949 .21452 .34729 .2232 .35982 .21851 .35205 .20978 Mtetra
.35205 .20978 .35982 .21851 .3724 .21379 .36468 .20502 Mtetra
.36468 .20502 .3724 .21379 .38505 .20905 .37736 .20024 Mtetra
.37736 .20024 .38505 .20905 .39776 .20429 .39011 .19544 Mtetra
.39011 .19544 .39776 .20429 .41053 .19951 .40291 .19061 Mtetra
.40291 .19061 .41053 .19951 .42335 .1947 .41578 .18576 Mtetra
.41578 .18576 .42335 .1947 .43624 .18987 .42871 .18089 Mtetra
.42871 .18089 .43624 .18987 .4492 .18501 .4417 .17599 Mtetra
.4417 .17599 .4492 .18501 .46221 .18014 .45475 .17107 Mtetra
.45475 .17107 .46221 .18014 .47529 .17524 .46787 .16613 Mtetra
.46787 .16613 .47529 .17524 .48843 .17031 .48105 .16116 Mtetra
.48105 .16116 .48843 .17031 .50163 .16537 .49429 .15617 Mtetra
.49429 .15617 .50163 .16537 .51489 .16039 .5076 .15115 Mtetra
.5076 .15115 .51489 .16039 .52823 .1554 .52097 .14611 Mtetra
.52097 .14611 .52823 .1554 .54162 .15038 .53441 .14104 Mtetra
.53441 .14104 .54162 .15038 .55508 .14533 .54792 .13595 Mtetra
.54792 .13595 .55508 .14533 .56861 .14026 .56149 .13084 Mtetra
.56149 .13084 .56861 .14026 .5822 .13517 .57513 .1257 Mtetra
.57513 .1257 .5822 .13517 .59769 .20593 .58883 .12053 Mtetra
0 0 .455 r
.58883 .12053 .59769 .20593 .61178 .20084 .60462 .19139 Mtetra
.658 .748 .916 r
.60462 .19139 .61178 .20084 .62593 .19573 .61882 .18623 Mtetra
.61882 .18623 .62593 .19573 .64016 .1906 .6331 .18104 Mtetra
.6331 .18104 .64016 .1906 .65446 .18543 .64745 .17583 Mtetra
.64745 .17583 .65446 .18543 .66884 .18024 .66188 .17059 Mtetra
.66188 .17059 .66884 .18024 .68329 .17503 .67638 .16533 Mtetra
.67638 .16533 .68329 .17503 .69781 .16979 .69095 .16003 Mtetra
.69095 .16003 .69781 .16979 .71241 .16452 .7056 .15471 Mtetra
.7056 .15471 .71241 .16452 .72708 .15922 .72033 .14937 Mtetra
.72033 .14937 .72708 .15922 .74183 .15389 .73513 .14399 Mtetra
.664 .741 .908 r
.08013 .30111 .08867 .30906 .10008 .30476 .09156 .29677 Mtetra
.09156 .29677 .10008 .30476 .11153 .30044 .10305 .29242 Mtetra
.10305 .29242 .11153 .30044 .12304 .29611 .11459 .28804 Mtetra
.11459 .28804 .12304 .29611 .1346 .29175 .12618 .28365 Mtetra
.12618 .28365 .1346 .29175 .14622 .28737 .13782 .27924 Mtetra
.13782 .27924 .14622 .28737 .15788 .28297 .14952 .2748 Mtetra
.14952 .2748 .15788 .28297 .1696 .27855 .16127 .27035 Mtetra
.16127 .27035 .1696 .27855 .18138 .27412 .17307 .26587 Mtetra
.17307 .26587 .18138 .27412 .1932 .26966 .18493 .26137 Mtetra
.18493 .26137 .1932 .26966 .20509 .26518 .19684 .25686 Mtetra
.19684 .25686 .20509 .26518 .21702 .26068 .20881 .25232 Mtetra
.20881 .25232 .21702 .26068 .22901 .25616 .22084 .24776 Mtetra
.22084 .24776 .22901 .25616 .24106 .25162 .23292 .24318 Mtetra
.23292 .24318 .24106 .25162 .25317 .24706 .24505 .23858 Mtetra
.24505 .23858 .25317 .24706 .26532 .24247 .25725 .23396 Mtetra
.25725 .23396 .26532 .24247 .27754 .23787 .2695 .22931 Mtetra
.2695 .22931 .27754 .23787 .28981 .23324 .2818 .22464 Mtetra
.2818 .22464 .28981 .23324 .30215 .22859 .29417 .21996 Mtetra
.29417 .21996 .30215 .22859 .31453 .22393 .30659 .21525 Mtetra
.30659 .21525 .31453 .22393 .32698 .21923 .31908 .21051 Mtetra
.31908 .21051 .32698 .21923 .33949 .21452 .33162 .20576 Mtetra
.33162 .20576 .33949 .21452 .35205 .20978 .34422 .20098 Mtetra
.34422 .20098 .35205 .20978 .36468 .20502 .35688 .19618 Mtetra
.35688 .19618 .36468 .20502 .37736 .20024 .3696 .19136 Mtetra
.3696 .19136 .37736 .20024 .39011 .19544 .38239 .18651 Mtetra
.38239 .18651 .39011 .19544 .40291 .19061 .39523 .18164 Mtetra
.39523 .18164 .40291 .19061 .41578 .18576 .40813 .17675 Mtetra
.40813 .17675 .41578 .18576 .42871 .18089 .4211 .17183 Mtetra
.4211 .17183 .42871 .18089 .4417 .17599 .43413 .16689 Mtetra
.43413 .16689 .4417 .17599 .45475 .17107 .44723 .16193 Mtetra
.44723 .16193 .45475 .17107 .46787 .16613 .46038 .15694 Mtetra
.46038 .15694 .46787 .16613 .48105 .16116 .4736 .15192 Mtetra
.4736 .15192 .48105 .16116 .49429 .15617 .48689 .14689 Mtetra
.48689 .14689 .49429 .15617 .5076 .15115 .50024 .14183 Mtetra
.50024 .14183 .5076 .15115 .52097 .14611 .51366 .13674 Mtetra
.51366 .13674 .52097 .14611 .53441 .14104 .52714 .13163 Mtetra
.52714 .13163 .53441 .14104 .54792 .13595 .54069 .12649 Mtetra
.54069 .12649 .54792 .13595 .56149 .13084 .5543 .12133 Mtetra
.5543 .12133 .56149 .13084 .57513 .1257 .56798 .11614 Mtetra
.56798 .11614 .57513 .1257 .58883 .12053 .58173 .11093 Mtetra
.931 .562 .16 r
.58173 .11093 .58883 .12053 .60462 .19139 .59739 .18184 Mtetra
.658 .748 .916 r
.59739 .18184 .60462 .19139 .61882 .18623 .61165 .17664 Mtetra
.61165 .17664 .61882 .18623 .6331 .18104 .62597 .1714 Mtetra
.62597 .1714 .6331 .18104 .64745 .17583 .64037 .16614 Mtetra
.64037 .16614 .64745 .17583 .66188 .17059 .65485 .16085 Mtetra
.65485 .16085 .66188 .17059 .67638 .16533 .6694 .15553 Mtetra
.6694 .15553 .67638 .16533 .69095 .16003 .68403 .15019 Mtetra
.68403 .15019 .69095 .16003 .7056 .15471 .69873 .14482 Mtetra
.69873 .14482 .7056 .15471 .72033 .14937 .71351 .13942 Mtetra
.71351 .13942 .72033 .14937 .73513 .14399 .72836 .13399 Mtetra
.664 .741 .908 r
.07152 .29309 .08013 .30111 .09156 .29677 .08298 .28872 Mtetra
.08298 .28872 .09156 .29677 .10305 .29242 .09449 .28433 Mtetra
.09449 .28433 .10305 .29242 .11459 .28804 .10606 .27992 Mtetra
.10606 .27992 .11459 .28804 .12618 .28365 .11768 .27548 Mtetra
.11768 .27548 .12618 .28365 .13782 .27924 .12935 .27103 Mtetra
.12935 .27103 .13782 .27924 .14952 .2748 .14108 .26656 Mtetra
.14108 .26656 .14952 .2748 .16127 .27035 .15286 .26207 Mtetra
.15286 .26207 .16127 .27035 .17307 .26587 .1647 .25755 Mtetra
.1647 .25755 .17307 .26587 .18493 .26137 .17659 .25302 Mtetra
.17659 .25302 .18493 .26137 .19684 .25686 .18853 .24846 Mtetra
.18853 .24846 .19684 .25686 .20881 .25232 .20053 .24389 Mtetra
.20053 .24389 .20881 .25232 .22084 .24776 .21259 .23929 Mtetra
.21259 .23929 .22084 .24776 .23292 .24318 .2247 .23467 Mtetra
.2247 .23467 .23292 .24318 .24505 .23858 .23687 .23003 Mtetra
.23687 .23003 .24505 .23858 .25725 .23396 .2491 .22536 Mtetra
.2491 .22536 .25725 .23396 .2695 .22931 .26138 .22068 Mtetra
.26138 .22068 .2695 .22931 .2818 .22464 .27373 .21597 Mtetra
.27373 .21597 .2818 .22464 .29417 .21996 .28613 .21124 Mtetra
.28613 .21124 .29417 .21996 .30659 .21525 .29858 .20649 Mtetra
.29858 .20649 .30659 .21525 .31908 .21051 .3111 .20172 Mtetra
.3111 .20172 .31908 .21051 .33162 .20576 .32368 .19692 Mtetra
.32368 .19692 .33162 .20576 .34422 .20098 .33632 .1921 Mtetra
.33632 .1921 .34422 .20098 .35688 .19618 .34902 .18726 Mtetra
.34902 .18726 .35688 .19618 .3696 .19136 .36178 .18239 Mtetra
.36178 .18239 .3696 .19136 .38239 .18651 .3746 .1775 Mtetra
.3746 .1775 .38239 .18651 .39523 .18164 .38748 .17259 Mtetra
.38748 .17259 .39523 .18164 .40813 .17675 .40042 .16765 Mtetra
.40042 .16765 .40813 .17675 .4211 .17183 .41343 .16269 Mtetra
.41343 .16269 .4211 .17183 .43413 .16689 .4265 .15771 Mtetra
.4265 .15771 .43413 .16689 .44723 .16193 .43963 .1527 Mtetra
.43963 .1527 .44723 .16193 .46038 .15694 .45283 .14766 Mtetra
.45283 .14766 .46038 .15694 .4736 .15192 .46609 .14261 Mtetra
.46609 .14261 .4736 .15192 .48689 .14689 .47942 .13752 Mtetra
.47942 .13752 .48689 .14689 .50024 .14183 .49281 .13242 Mtetra
.49281 .13242 .50024 .14183 .51366 .13674 .50627 .12728 Mtetra
.50627 .12728 .51366 .13674 .52714 .13163 .5198 .12212 Mtetra
.5198 .12212 .52714 .13163 .54069 .12649 .53339 .11694 Mtetra
.53339 .11694 .54069 .12649 .5543 .12133 .54705 .11173 Mtetra
.54705 .11173 .5543 .12133 .56798 .11614 .56078 .1065 Mtetra
.56078 .1065 .56798 .11614 .58173 .11093 .57457 .10123 Mtetra
.57457 .10123 .58173 .11093 .59739 .18184 .58844 .09595 Mtetra
0 0 .451 r
.58844 .09595 .59739 .18184 .61165 .17664 .6044 .16695 Mtetra
.658 .748 .916 r
.6044 .16695 .61165 .17664 .62597 .1714 .61878 .16167 Mtetra
.61878 .16167 .62597 .1714 .64037 .16614 .63323 .15635 Mtetra
.63323 .15635 .64037 .16614 .65485 .16085 .64775 .15102 Mtetra
.64775 .15102 .65485 .16085 .6694 .15553 .66236 .14565 Mtetra
.66236 .14565 .6694 .15553 .68403 .15019 .67703 .14025 Mtetra
.67703 .14025 .68403 .15019 .69873 .14482 .69179 .13483 Mtetra
.69179 .13483 .69873 .14482 .71351 .13942 .70662 .12938 Mtetra
.70662 .12938 .71351 .13942 .72836 .13399 .72153 .1239 Mtetra
.664 .741 .908 r
.06283 .285 .07152 .29309 .08298 .28872 .07432 .2806 Mtetra
.07432 .2806 .08298 .28872 .09449 .28433 .08587 .27617 Mtetra
.08587 .27617 .09449 .28433 .10606 .27992 .09746 .27172 Mtetra
.09746 .27172 .10606 .27992 .11768 .27548 .10911 .26725 Mtetra
.10911 .26725 .11768 .27548 .12935 .27103 .12082 .26276 Mtetra
.12082 .26276 .12935 .27103 .14108 .26656 .13257 .25825 Mtetra
.13257 .25825 .14108 .26656 .15286 .26207 .14438 .25372 Mtetra
.14438 .25372 .15286 .26207 .1647 .25755 .15625 .24917 Mtetra
.15625 .24917 .1647 .25755 .17659 .25302 .16817 .24459 Mtetra
.16817 .24459 .17659 .25302 .18853 .24846 .18015 .24 Mtetra
.18015 .24 .18853 .24846 .20053 .24389 .19218 .23538 Mtetra
.19218 .23538 .20053 .24389 .21259 .23929 .20427 .23074 Mtetra
.20427 .23074 .21259 .23929 .2247 .23467 .21642 .22608 Mtetra
.21642 .22608 .2247 .23467 .23687 .23003 .22862 .2214 Mtetra
.22862 .2214 .23687 .23003 .2491 .22536 .24088 .2167 Mtetra
.24088 .2167 .2491 .22536 .26138 .22068 .2532 .21197 Mtetra
.2532 .21197 .26138 .22068 .27373 .21597 .26558 .20722 Mtetra
.26558 .20722 .27373 .21597 .28613 .21124 .27801 .20245 Mtetra
.27801 .20245 .28613 .21124 .29858 .20649 .29051 .19766 Mtetra
.29051 .19766 .29858 .20649 .3111 .20172 .30306 .19284 Mtetra
.30306 .19284 .3111 .20172 .32368 .19692 .31567 .188 Mtetra
.31567 .188 .32368 .19692 .33632 .1921 .32835 .18314 Mtetra
.32835 .18314 .33632 .1921 .34902 .18726 .34108 .17826 Mtetra
.34108 .17826 .34902 .18726 .36178 .18239 .35388 .17335 Mtetra
.35388 .17335 .36178 .18239 .3746 .1775 .36674 .16841 Mtetra
.36674 .16841 .3746 .1775 .38748 .17259 .37966 .16346 Mtetra
.37966 .16346 .38748 .17259 .40042 .16765 .39264 .15847 Mtetra
.39264 .15847 .40042 .16765 .41343 .16269 .40569 .15347 Mtetra
.40569 .15347 .41343 .16269 .4265 .15771 .4188 .14844 Mtetra
.4188 .14844 .4265 .15771 .43963 .1527 .43197 .14339 Mtetra
.43197 .14339 .43963 .1527 .45283 .14766 .44521 .13831 Mtetra
.44521 .13831 .45283 .14766 .46609 .14261 .45852 .1332 Mtetra
.45852 .1332 .46609 .14261 .47942 .13752 .47188 .12807 Mtetra
.47188 .12807 .47942 .13752 .49281 .13242 .48532 .12292 Mtetra
.48532 .12292 .49281 .13242 .50627 .12728 .49882 .11774 Mtetra
.49882 .11774 .50627 .12728 .5198 .12212 .51239 .11253 Mtetra
.51239 .11253 .5198 .12212 .53339 .11694 .52603 .1073 Mtetra
.52603 .1073 .53339 .11694 .54705 .11173 .53973 .10205 Mtetra
.53973 .10205 .54705 .11173 .56078 .1065 .5535 .09676 Mtetra
.5535 .09676 .56078 .1065 .57457 .10123 .56734 .09145 Mtetra
.56734 .09145 .57457 .10123 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .6044 .16695 .59523 .08075 Mtetra
0 0 .451 r
.59523 .08075 .6044 .16695 .61878 .16167 .61151 .15184 Mtetra
.658 .748 .916 r
.61151 .15184 .61878 .16167 .63323 .15635 .62601 .14648 Mtetra
.62601 .14648 .63323 .15635 .64775 .15102 .64059 .14108 Mtetra
.64059 .14108 .64775 .15102 .66236 .14565 .65525 .13567 Mtetra
.65525 .13567 .66236 .14565 .67703 .14025 .66998 .13022 Mtetra
.66998 .13022 .67703 .14025 .69179 .13483 .68478 .12474 Mtetra
.68478 .12474 .69179 .13483 .70662 .12938 .69967 .11924 Mtetra
.69967 .11924 .70662 .12938 .72153 .1239 .71463 .11371 Mtetra
.664 .741 .908 r
.05408 .27685 .06283 .285 .07432 .2806 .06559 .2724 Mtetra
.06559 .2724 .07432 .2806 .08587 .27617 .07717 .26794 Mtetra
.07717 .26794 .08587 .27617 .09746 .27172 .08879 .26345 Mtetra
.08879 .26345 .09746 .27172 .10911 .26725 .10047 .25894 Mtetra
.10047 .25894 .10911 .26725 .12082 .26276 .1122 .25442 Mtetra
.1122 .25442 .12082 .26276 .13257 .25825 .12399 .24987 Mtetra
.12399 .24987 .13257 .25825 .14438 .25372 .13583 .2453 Mtetra
.13583 .2453 .14438 .25372 .15625 .24917 .14773 .24071 Mtetra
.14773 .24071 .15625 .24917 .16817 .24459 .15968 .23609 Mtetra
.15968 .23609 .16817 .24459 .18015 .24 .17169 .23146 Mtetra
.17169 .23146 .18015 .24 .19218 .23538 .18376 .2268 Mtetra
.18376 .2268 .19218 .23538 .20427 .23074 .19588 .22212 Mtetra
.19588 .22212 .20427 .23074 .21642 .22608 .20806 .21742 Mtetra
.20806 .21742 .21642 .22608 .22862 .2214 .2203 .2127 Mtetra
.2203 .2127 .22862 .2214 .24088 .2167 .23259 .20796 Mtetra
.23259 .20796 .24088 .2167 .2532 .21197 .24494 .20319 Mtetra
.24494 .20319 .2532 .21197 .26558 .20722 .25735 .1984 Mtetra
.25735 .1984 .26558 .20722 .27801 .20245 .26982 .19359 Mtetra
.26982 .19359 .27801 .20245 .29051 .19766 .28235 .18875 Mtetra
.28235 .18875 .29051 .19766 .30306 .19284 .29494 .18389 Mtetra
.29494 .18389 .30306 .19284 .31567 .188 .30759 .17901 Mtetra
.30759 .17901 .31567 .188 .32835 .18314 .32031 .1741 Mtetra
.32031 .1741 .32835 .18314 .34108 .17826 .33308 .16917 Mtetra
.33308 .16917 .34108 .17826 .35388 .17335 .34591 .16422 Mtetra
.34591 .16422 .35388 .17335 .36674 .16841 .35881 .15924 Mtetra
.35881 .15924 .36674 .16841 .37966 .16346 .37177 .15424 Mtetra
.37177 .15424 .37966 .16346 .39264 .15847 .38479 .14922 Mtetra
.38479 .14922 .39264 .15847 .40569 .15347 .39788 .14417 Mtetra
.39788 .14417 .40569 .15347 .4188 .14844 .41103 .13909 Mtetra
.41103 .13909 .4188 .14844 .43197 .14339 .42424 .13399 Mtetra
.42424 .13399 .43197 .14339 .44521 .13831 .43752 .12886 Mtetra
.43752 .12886 .44521 .13831 .45852 .1332 .45087 .12371 Mtetra
.45087 .12371 .45852 .1332 .47188 .12807 .46428 .11854 Mtetra
.46428 .11854 .47188 .12807 .48532 .12292 .47776 .11334 Mtetra
.47776 .11334 .48532 .12292 .49882 .11774 .4913 .10811 Mtetra
.4913 .10811 .49882 .11774 .51239 .11253 .50491 .10286 Mtetra
.50491 .10286 .51239 .11253 .52603 .1073 .51859 .09758 Mtetra
.51859 .09758 .52603 .1073 .53973 .10205 .53234 .09227 Mtetra
.53234 .09227 .53973 .10205 .5535 .09676 .54616 .08694 Mtetra
.54616 .08694 .5535 .09676 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.924 .553 .139 r
.58803 .07078 .59523 .08075 .61151 .15184 .60418 .14192 Mtetra
.658 .748 .916 r
.60418 .14192 .61151 .15184 .62601 .14648 .61873 .1365 Mtetra
.61873 .1365 .62601 .14648 .64059 .14108 .63336 .13106 Mtetra
.63336 .13106 .64059 .14108 .65525 .13567 .64806 .12559 Mtetra
.64806 .12559 .65525 .13567 .66998 .13022 .66285 .12009 Mtetra
.66285 .12009 .66998 .13022 .68478 .12474 .67771 .11456 Mtetra
.67771 .11456 .68478 .12474 .69967 .11924 .69265 .109 Mtetra
.69265 .109 .69967 .11924 .71463 .11371 .70767 .10341 Mtetra
.664 .741 .908 r
.04524 .26863 .05408 .27685 .06559 .2724 .05679 .26414 Mtetra
.05679 .26414 .06559 .2724 .07717 .26794 .06839 .25964 Mtetra
.06839 .25964 .07717 .26794 .08879 .26345 .08005 .25511 Mtetra
.08005 .25511 .08879 .26345 .10047 .25894 .09176 .25057 Mtetra
.09176 .25057 .10047 .25894 .1122 .25442 .10352 .246 Mtetra
.10352 .246 .1122 .25442 .12399 .24987 .11534 .24141 Mtetra
.11534 .24141 .12399 .24987 .13583 .2453 .12721 .2368 Mtetra
.12721 .2368 .13583 .2453 .14773 .24071 .13914 .23217 Mtetra
.13914 .23217 .14773 .24071 .15968 .23609 .15112 .22752 Mtetra
.15112 .22752 .15968 .23609 .17169 .23146 .16316 .22284 Mtetra
.16316 .22284 .17169 .23146 .18376 .2268 .17526 .21815 Mtetra
.17526 .21815 .18376 .2268 .19588 .22212 .18742 .21343 Mtetra
.18742 .21343 .19588 .22212 .20806 .21742 .19963 .20869 Mtetra
.19963 .20869 .20806 .21742 .2203 .2127 .2119 .20392 Mtetra
.2119 .20392 .2203 .2127 .23259 .20796 .22423 .19914 Mtetra
.22423 .19914 .23259 .20796 .24494 .20319 .23661 .19433 Mtetra
.23661 .19433 .24494 .20319 .25735 .1984 .24906 .1895 Mtetra
.24906 .1895 .25735 .1984 .26982 .19359 .26157 .18464 Mtetra
.26157 .18464 .26982 .19359 .28235 .18875 .27413 .17976 Mtetra
.27413 .17976 .28235 .18875 .29494 .18389 .28676 .17486 Mtetra
.28676 .17486 .29494 .18389 .30759 .17901 .29944 .16993 Mtetra
.29944 .16993 .30759 .17901 .32031 .1741 .31219 .16498 Mtetra
.31219 .16498 .32031 .1741 .33308 .16917 .325 .16001 Mtetra
.325 .16001 .33308 .16917 .34591 .16422 .33788 .15501 Mtetra
.33788 .15501 .34591 .16422 .35881 .15924 .35081 .14999 Mtetra
.35081 .14999 .35881 .15924 .37177 .15424 .36381 .14494 Mtetra
.36381 .14494 .37177 .15424 .38479 .14922 .37687 .13987 Mtetra
.37687 .13987 .38479 .14922 .39788 .14417 .39 .13478 Mtetra
.39 .13478 .39788 .14417 .41103 .13909 .40319 .12965 Mtetra
.40319 .12965 .41103 .13909 .42424 .13399 .41644 .12451 Mtetra
.41644 .12451 .42424 .13399 .43752 .12886 .42976 .11934 Mtetra
.42976 .11934 .43752 .12886 .45087 .12371 .44315 .11414 Mtetra
.44315 .11414 .45087 .12371 .46428 .11854 .4566 .10892 Mtetra
.4566 .10892 .46428 .11854 .47776 .11334 .47013 .10367 Mtetra
.47013 .10367 .47776 .11334 .4913 .10811 .48371 .09839 Mtetra
.48371 .09839 .4913 .10811 .50491 .10286 .49737 .09309 Mtetra
.49737 .09309 .50491 .10286 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09227 .52489 .0824 Mtetra
.52489 .0824 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60418 .14192 .59491 .05522 Mtetra
0 0 .447 r
.59491 .05522 .60418 .14192 .61873 .1365 .61138 .12643 Mtetra
.658 .748 .916 r
.61138 .12643 .61873 .1365 .63336 .13106 .62606 .12094 Mtetra
.62606 .12094 .63336 .13106 .64806 .12559 .64081 .11541 Mtetra
.64081 .11541 .64806 .12559 .66285 .12009 .65565 .10986 Mtetra
.65565 .10986 .66285 .12009 .67771 .11456 .67056 .10427 Mtetra
.67056 .10427 .67771 .11456 .69265 .109 .68556 .09866 Mtetra
.68556 .09866 .69265 .109 .70767 .10341 .70063 .09302 Mtetra
.664 .741 .908 r
.03634 .26033 .04524 .26863 .05679 .26414 .04791 .25581 Mtetra
.04791 .25581 .05679 .26414 .06839 .25964 .05954 .25127 Mtetra
.05954 .25127 .06839 .25964 .08005 .25511 .07123 .24671 Mtetra
.07123 .24671 .08005 .25511 .09176 .25057 .08297 .24212 Mtetra
.08297 .24212 .09176 .25057 .10352 .246 .09476 .23751 Mtetra
.09476 .23751 .10352 .246 .11534 .24141 .10661 .23289 Mtetra
.10661 .23289 .11534 .24141 .12721 .2368 .11851 .22824 Mtetra
.11851 .22824 .12721 .2368 .13914 .23217 .13047 .22356 Mtetra
.13047 .22356 .13914 .23217 .15112 .22752 .14249 .21887 Mtetra
.14249 .21887 .15112 .22752 .16316 .22284 .15456 .21416 Mtetra
.15456 .21416 .16316 .22284 .17526 .21815 .16669 .20942 Mtetra
.16669 .20942 .17526 .21815 .18742 .21343 .17888 .20466 Mtetra
.17888 .20466 .18742 .21343 .19963 .20869 .19112 .19987 Mtetra
.19112 .19987 .19963 .20869 .2119 .20392 .20343 .19507 Mtetra
.20343 .19507 .2119 .20392 .22423 .19914 .21579 .19024 Mtetra
.21579 .19024 .22423 .19914 .23661 .19433 .22821 .18539 Mtetra
.22821 .18539 .23661 .19433 .24906 .1895 .24069 .18051 Mtetra
.24069 .18051 .24906 .1895 .26157 .18464 .25323 .17561 Mtetra
.25323 .17561 .26157 .18464 .27413 .17976 .26583 .17069 Mtetra
.26583 .17069 .27413 .17976 .28676 .17486 .2785 .16575 Mtetra
.2785 .16575 .28676 .17486 .29944 .16993 .29122 .16078 Mtetra
.29122 .16078 .29944 .16993 .31219 .16498 .30401 .15578 Mtetra
.30401 .15578 .31219 .16498 .325 .16001 .31685 .15076 Mtetra
.31685 .15076 .325 .16001 .33788 .15501 .32977 .14572 Mtetra
.32977 .14572 .33788 .15501 .35081 .14999 .34274 .14065 Mtetra
.34274 .14065 .35081 .14999 .36381 .14494 .35578 .13556 Mtetra
.35578 .13556 .36381 .14494 .37687 .13987 .36888 .13044 Mtetra
.36888 .13044 .37687 .13987 .39 .13478 .38204 .1253 Mtetra
.38204 .1253 .39 .13478 .40319 .12965 .39527 .12013 Mtetra
.39527 .12013 .40319 .12965 .41644 .12451 .40857 .11494 Mtetra
.40857 .11494 .41644 .12451 .42976 .11934 .42193 .10972 Mtetra
.42193 .10972 .42976 .11934 .44315 .11414 .43536 .10448 Mtetra
.43536 .10448 .44315 .11414 .4566 .10892 .44886 .0992 Mtetra
.44886 .0992 .4566 .10892 .47013 .10367 .46242 .09391 Mtetra
.46242 .09391 .47013 .10367 .48371 .09839 .47605 .08858 Mtetra
.47605 .08858 .48371 .09839 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .0824 .51736 .07245 Mtetra
.51736 .07245 .52489 .0824 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .61138 .12643 .60188 .03943 Mtetra
0 0 .447 r
.60188 .03943 .61138 .12643 .62606 .12094 .61868 .11071 Mtetra
.658 .748 .916 r
.61868 .11071 .62606 .12094 .64081 .11541 .63349 .10513 Mtetra
.63349 .10513 .64081 .11541 .65565 .10986 .64838 .09953 Mtetra
.64838 .09953 .65565 .10986 .67056 .10427 .66335 .09389 Mtetra
.66335 .09389 .67056 .10427 .68556 .09866 .6784 .08822 Mtetra
.6784 .08822 .68556 .09866 .70063 .09302 .69353 .08252 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .57879 .48228 .57294 Mtetra
.48228 .57294 .48818 .57879 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57244 .5035 .56654 Mtetra
.5035 .56654 .50935 .57244 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .56009 Mtetra
.52489 .56009 .53068 .56605 .54141 .56283 .53564 .55685 Mtetra
.53564 .55685 .54141 .56283 .55218 .5596 .54644 .5536 Mtetra
.54644 .5536 .55218 .5596 .56299 .55635 .55728 .55033 Mtetra
.55728 .55033 .56299 .55635 .57385 .5531 .56816 .54705 Mtetra
.56816 .54705 .57385 .5531 .58474 .54983 .57909 .54376 Mtetra
.57909 .54376 .58474 .54983 .59568 .54654 .59006 .54045 Mtetra
.59006 .54045 .59568 .54654 .60667 .54325 .60107 .53713 Mtetra
.60107 .53713 .60667 .54325 .61769 .53994 .61213 .5338 Mtetra
.61213 .5338 .61769 .53994 .62876 .53662 .62323 .53045 Mtetra
.62323 .53045 .62876 .53662 .63988 .53329 .63437 .5271 Mtetra
.63437 .5271 .63988 .53329 .65104 .52994 .64556 .52372 Mtetra
.64556 .52372 .65104 .52994 .66224 .52658 .65679 .52034 Mtetra
.65679 .52034 .66224 .52658 .67349 .5232 .66807 .51694 Mtetra
.66807 .51694 .67349 .5232 .68478 .51982 .67939 .51353 Mtetra
.67939 .51353 .68478 .51982 .69612 .51641 .69076 .5101 Mtetra
.69076 .5101 .69612 .51641 .7075 .513 .70218 .50666 Mtetra
.70218 .50666 .7075 .513 .71893 .50957 .71364 .5032 Mtetra
.71364 .5032 .71893 .50957 .73041 .50613 .72515 .49974 Mtetra
.72515 .49974 .73041 .50613 .74193 .50267 .7367 .49625 Mtetra
.7367 .49625 .74193 .50267 .7535 .4992 .7483 .49276 Mtetra
.7483 .49276 .7535 .4992 .76511 .49572 .75995 .48925 Mtetra
.75995 .48925 .76511 .49572 .77677 .49222 .77165 .48572 Mtetra
.77165 .48572 .77677 .49222 .78848 .48871 .78339 .48218 Mtetra
.78339 .48218 .78848 .48871 .80024 .48518 .79518 .47863 Mtetra
.79518 .47863 .80024 .48518 .81205 .48164 .80702 .47506 Mtetra
.80702 .47506 .81205 .48164 .8239 .47808 .81891 .47148 Mtetra
.81891 .47148 .8239 .47808 .8358 .47451 .83085 .46788 Mtetra
.83085 .46788 .8358 .47451 .84775 .47092 .84283 .46427 Mtetra
.84283 .46427 .84775 .47092 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .45699 Mtetra
.86696 .45699 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57342 Mtetra
.45523 .57342 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55735 Mtetra
.50831 .55735 .51417 .56332 .52489 .56009 .51905 .5541 Mtetra
.51905 .5541 .52489 .56009 .53564 .55685 .52983 .55083 Mtetra
.52983 .55083 .53564 .55685 .54644 .5536 .54066 .54756 Mtetra
.54066 .54756 .54644 .5536 .55728 .55033 .55153 .54426 Mtetra
.55153 .54426 .55728 .55033 .56816 .54705 .56244 .54096 Mtetra
.56244 .54096 .56816 .54705 .57909 .54376 .57339 .53764 Mtetra
.57339 .53764 .57909 .54376 .59006 .54045 .58439 .53431 Mtetra
.58439 .53431 .59006 .54045 .60107 .53713 .59543 .53097 Mtetra
.59543 .53097 .60107 .53713 .61213 .5338 .60652 .52761 Mtetra
.60652 .52761 .61213 .5338 .62323 .53045 .61765 .52424 Mtetra
.61765 .52424 .62323 .53045 .63437 .5271 .62882 .52086 Mtetra
.62882 .52086 .63437 .5271 .64556 .52372 .64004 .51746 Mtetra
.64004 .51746 .64556 .52372 .65679 .52034 .6513 .51405 Mtetra
.6513 .51405 .65679 .52034 .66807 .51694 .66261 .51063 Mtetra
.66261 .51063 .66807 .51694 .67939 .51353 .67397 .50719 Mtetra
.67397 .50719 .67939 .51353 .69076 .5101 .68537 .50374 Mtetra
.68537 .50374 .69076 .5101 .70218 .50666 .69682 .50027 Mtetra
.69682 .50027 .70218 .50666 .71364 .5032 .70831 .49679 Mtetra
.70831 .49679 .71364 .5032 .72515 .49974 .71985 .4933 Mtetra
.71985 .4933 .72515 .49974 .7367 .49625 .73144 .48979 Mtetra
.73144 .48979 .7367 .49625 .7483 .49276 .74307 .48626 Mtetra
.74307 .48626 .7483 .49276 .75995 .48925 .75475 .48273 Mtetra
.75475 .48273 .75995 .48925 .77165 .48572 .76648 .47918 Mtetra
.76648 .47918 .77165 .48572 .78339 .48218 .77826 .47561 Mtetra
.77826 .47561 .78339 .48218 .79518 .47863 .79008 .47203 Mtetra
.79008 .47203 .79518 .47863 .80702 .47506 .80196 .46843 Mtetra
.80196 .46843 .80702 .47506 .81891 .47148 .81388 .46482 Mtetra
.81388 .46482 .81891 .47148 .83085 .46788 .82585 .4612 Mtetra
.82585 .4612 .83085 .46788 .84283 .46427 .83788 .45756 Mtetra
.83788 .45756 .84283 .46427 .85487 .46064 .84995 .4539 Mtetra
.84995 .4539 .85487 .46064 .86696 .45699 .86207 .45023 Mtetra
.86207 .45023 .86696 .45699 .87909 .45334 .87424 .44654 Mtetra
.87424 .44654 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57342 .44919 .56753 Mtetra
.44919 .56753 .45523 .57342 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .5546 Mtetra
.49168 .5546 .49761 .56059 .50831 .55735 .5024 .55134 Mtetra
.5024 .55134 .50831 .55735 .51905 .5541 .51317 .54806 Mtetra
.51317 .54806 .51905 .5541 .52983 .55083 .52398 .54477 Mtetra
.52398 .54477 .52983 .55083 .54066 .54756 .53484 .54147 Mtetra
.53484 .54147 .54066 .54756 .55153 .54426 .54573 .53815 Mtetra
.54573 .53815 .55153 .54426 .56244 .54096 .55667 .53483 Mtetra
.55667 .53483 .56244 .54096 .57339 .53764 .56766 .53149 Mtetra
.56766 .53149 .57339 .53764 .58439 .53431 .57868 .52813 Mtetra
.57868 .52813 .58439 .53431 .59543 .53097 .58975 .52476 Mtetra
.58975 .52476 .59543 .53097 .60652 .52761 .60087 .52138 Mtetra
.60087 .52138 .60652 .52761 .61765 .52424 .61203 .51799 Mtetra
.61203 .51799 .61765 .52424 .62882 .52086 .62323 .51458 Mtetra
.62323 .51458 .62882 .52086 .64004 .51746 .63448 .51115 Mtetra
.63448 .51115 .64004 .51746 .6513 .51405 .64578 .50772 Mtetra
.64578 .50772 .6513 .51405 .66261 .51063 .65712 .50427 Mtetra
.65712 .50427 .66261 .51063 .67397 .50719 .6685 .5008 Mtetra
.6685 .5008 .67397 .50719 .68537 .50374 .67993 .49733 Mtetra
.67993 .49733 .68537 .50374 .69682 .50027 .69141 .49383 Mtetra
.69141 .49383 .69682 .50027 .70831 .49679 .70294 .49033 Mtetra
.70294 .49033 .70831 .49679 .71985 .4933 .71451 .48681 Mtetra
.71451 .48681 .71985 .4933 .73144 .48979 .72613 .48327 Mtetra
.72613 .48327 .73144 .48979 .74307 .48626 .7378 .47972 Mtetra
.7378 .47972 .74307 .48626 .75475 .48273 .74951 .47616 Mtetra
.74951 .47616 .75475 .48273 .76648 .47918 .76127 .47258 Mtetra
.76127 .47258 .76648 .47918 .77826 .47561 .77309 .46899 Mtetra
.77309 .46899 .77826 .47561 .79008 .47203 .78495 .46538 Mtetra
.78495 .46538 .79008 .47203 .80196 .46843 .79686 .46176 Mtetra
.79686 .46176 .80196 .46843 .81388 .46482 .80881 .45812 Mtetra
.80881 .45812 .81388 .46482 .82585 .4612 .82082 .45446 Mtetra
.82082 .45446 .82585 .4612 .83788 .45756 .83288 .4508 Mtetra
.83288 .4508 .83788 .45756 .84995 .4539 .84499 .44711 Mtetra
.84499 .44711 .84995 .4539 .86207 .45023 .85715 .44341 Mtetra
.85715 .44341 .86207 .45023 .87424 .44654 .86936 .4397 Mtetra
.86936 .4397 .87424 .44654 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .5551 Mtetra
.46432 .5551 .47035 .56109 .48099 .55785 .47499 .55184 Mtetra
.47499 .55184 .48099 .55785 .49168 .5546 .4857 .54857 Mtetra
.4857 .54857 .49168 .5546 .5024 .55134 .49646 .54528 Mtetra
.49646 .54528 .5024 .55134 .51317 .54806 .50725 .54198 Mtetra
.50725 .54198 .51317 .54806 .52398 .54477 .51809 .53867 Mtetra
.51809 .53867 .52398 .54477 .53484 .54147 .52897 .53534 Mtetra
.52897 .53534 .53484 .54147 .54573 .53815 .5399 .532 Mtetra
.5399 .532 .54573 .53815 .55667 .53483 .55087 .52865 Mtetra
.55087 .52865 .55667 .53483 .56766 .53149 .56188 .52528 Mtetra
.56188 .52528 .56766 .53149 .57868 .52813 .57293 .5219 Mtetra
.57293 .5219 .57868 .52813 .58975 .52476 .58403 .51851 Mtetra
.58403 .51851 .58975 .52476 .60087 .52138 .59518 .5151 Mtetra
.59518 .5151 .60087 .52138 .61203 .51799 .60637 .51168 Mtetra
.60637 .51168 .61203 .51799 .62323 .51458 .6176 .50825 Mtetra
.6176 .50825 .62323 .51458 .63448 .51115 .62888 .5048 Mtetra
.62888 .5048 .63448 .51115 .64578 .50772 .64021 .50134 Mtetra
.64021 .50134 .64578 .50772 .65712 .50427 .65158 .49786 Mtetra
.65158 .49786 .65712 .50427 .6685 .5008 .663 .49437 Mtetra
.663 .49437 .6685 .5008 .67993 .49733 .67446 .49087 Mtetra
.67446 .49087 .67993 .49733 .69141 .49383 .68597 .48735 Mtetra
.68597 .48735 .69141 .49383 .70294 .49033 .69753 .48382 Mtetra
.69753 .48382 .70294 .49033 .71451 .48681 .70913 .48027 Mtetra
.70913 .48027 .71451 .48681 .72613 .48327 .72078 .47671 Mtetra
.72078 .47671 .72613 .48327 .7378 .47972 .73248 .47313 Mtetra
.73248 .47313 .7378 .47972 .74951 .47616 .74423 .46954 Mtetra
.74423 .46954 .74951 .47616 .76127 .47258 .75603 .46593 Mtetra
.75603 .46593 .76127 .47258 .77309 .46899 .76788 .46231 Mtetra
.76788 .46231 .77309 .46899 .78495 .46538 .77977 .45868 Mtetra
.77977 .45868 .78495 .46538 .79686 .46176 .79171 .45503 Mtetra
.79171 .45503 .79686 .46176 .80881 .45812 .80371 .45136 Mtetra
.80371 .45136 .80881 .45812 .82082 .45446 .81575 .44768 Mtetra
.81575 .44768 .82082 .45446 .83288 .4508 .82785 .44398 Mtetra
.82785 .44398 .83288 .4508 .84499 .44711 .83999 .44027 Mtetra
.83999 .44027 .84499 .44711 .85715 .44341 .85219 .43654 Mtetra
.85219 .43654 .85715 .44341 .86936 .4397 .86443 .4328 Mtetra
.86443 .4328 .86936 .4397 .88162 .43597 .87673 .42904 Mtetra
.87673 .42904 .88162 .43597 .89393 .43222 .88908 .42526 Mtetra
.88908 .42526 .89393 .43222 .9063 .42846 .90148 .42147 Mtetra
.90148 .42147 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .5556 Mtetra
.43698 .5556 .44311 .56159 .45369 .55835 .4476 .55234 Mtetra
.4476 .55234 .45369 .55835 .46432 .5551 .45825 .54907 Mtetra
.45825 .54907 .46432 .5551 .47499 .55184 .46895 .54579 Mtetra
.46895 .54579 .47499 .55184 .4857 .54857 .47968 .54249 Mtetra
.47968 .54249 .4857 .54857 .49646 .54528 .49046 .53918 Mtetra
.49046 .53918 .49646 .54528 .50725 .54198 .50129 .53585 Mtetra
.50129 .53585 .50725 .54198 .51809 .53867 .51215 .53251 Mtetra
.51215 .53251 .51809 .53867 .52897 .53534 .52306 .52916 Mtetra
.52306 .52916 .52897 .53534 .5399 .532 .53402 .5258 Mtetra
.53402 .5258 .5399 .532 .55087 .52865 .54501 .52242 Mtetra
.54501 .52242 .55087 .52865 .56188 .52528 .55606 .51903 Mtetra
.55606 .51903 .56188 .52528 .57293 .5219 .56714 .51563 Mtetra
.56714 .51563 .57293 .5219 .58403 .51851 .57827 .51221 Mtetra
.57827 .51221 .58403 .51851 .59518 .5151 .58944 .50878 Mtetra
.58944 .50878 .59518 .5151 .60637 .51168 .60066 .50533 Mtetra
.60066 .50533 .60637 .51168 .6176 .50825 .61193 .50187 Mtetra
.61193 .50187 .6176 .50825 .62888 .5048 .62324 .4984 Mtetra
.62324 .4984 .62888 .5048 .64021 .50134 .6346 .49491 Mtetra
.6346 .49491 .64021 .50134 .65158 .49786 .646 .49141 Mtetra
.646 .49141 .65158 .49786 .663 .49437 .65745 .48789 Mtetra
.65745 .48789 .663 .49437 .67446 .49087 .66894 .48436 Mtetra
.66894 .48436 .67446 .49087 .68597 .48735 .68049 .48082 Mtetra
.68049 .48082 .68597 .48735 .69753 .48382 .69208 .47726 Mtetra
.69208 .47726 .69753 .48382 .70913 .48027 .70371 .47368 Mtetra
.70371 .47368 .70913 .48027 .72078 .47671 .7154 .47009 Mtetra
.7154 .47009 .72078 .47671 .73248 .47313 .72713 .46649 Mtetra
.72713 .46649 .73248 .47313 .74423 .46954 .73891 .46287 Mtetra
.73891 .46287 .74423 .46954 .75603 .46593 .75075 .45924 Mtetra
.75075 .45924 .75603 .46593 .76788 .46231 .76263 .45559 Mtetra
.76263 .45559 .76788 .46231 .77977 .45868 .77455 .45193 Mtetra
.77455 .45193 .77977 .45868 .79171 .45503 .78653 .44825 Mtetra
.78653 .44825 .79171 .45503 .80371 .45136 .79856 .44455 Mtetra
.79856 .44455 .80371 .45136 .81575 .44768 .81064 .44084 Mtetra
.81064 .44084 .81575 .44768 .82785 .44398 .82277 .43712 Mtetra
.82277 .43712 .82785 .44398 .83999 .44027 .83495 .43338 Mtetra
.83495 .43338 .83999 .44027 .85219 .43654 .84719 .42962 Mtetra
.84719 .42962 .85219 .43654 .86443 .4328 .85947 .42585 Mtetra
.85947 .42585 .86443 .4328 .87673 .42904 .87181 .42206 Mtetra
.87181 .42206 .87673 .42904 .88908 .42526 .88419 .41825 Mtetra
.88419 .41825 .88908 .42526 .90148 .42147 .89664 .41443 Mtetra
.89664 .41443 .90148 .42147 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55284 Mtetra
.42022 .55284 .42641 .55885 .43698 .5556 .43081 .54957 Mtetra
.43081 .54957 .43698 .5556 .4476 .55234 .44145 .54629 Mtetra
.44145 .54629 .4476 .55234 .45825 .54907 .45213 .543 Mtetra
.45213 .543 .45825 .54907 .46895 .54579 .46286 .53969 Mtetra
.46286 .53969 .46895 .54579 .47968 .54249 .47362 .53636 Mtetra
.47362 .53636 .47968 .54249 .49046 .53918 .48443 .53303 Mtetra
.48443 .53303 .49046 .53918 .50129 .53585 .49528 .52968 Mtetra
.49528 .52968 .50129 .53585 .51215 .53251 .50617 .52632 Mtetra
.50617 .52632 .51215 .53251 .52306 .52916 .51711 .52294 Mtetra
.51711 .52294 .52306 .52916 .53402 .5258 .52809 .51955 Mtetra
.52809 .51955 .53402 .5258 .54501 .52242 .53912 .51615 Mtetra
.53912 .51615 .54501 .52242 .55606 .51903 .55019 .51274 Mtetra
.55019 .51274 .55606 .51903 .56714 .51563 .5613 .50931 Mtetra
.5613 .50931 .56714 .51563 .57827 .51221 .57246 .50586 Mtetra
.57246 .50586 .57827 .51221 .58944 .50878 .58367 .50241 Mtetra
.58367 .50241 .58944 .50878 .60066 .50533 .59492 .49893 Mtetra
.59492 .49893 .60066 .50533 .61193 .50187 .60621 .49545 Mtetra
.60621 .49545 .61193 .50187 .62324 .4984 .61755 .49195 Mtetra
.61755 .49195 .62324 .4984 .6346 .49491 .62894 .48843 Mtetra
.62894 .48843 .6346 .49491 .646 .49141 .64038 .48491 Mtetra
.64038 .48491 .646 .49141 .65745 .48789 .65186 .48136 Mtetra
.65186 .48136 .65745 .48789 .66894 .48436 .66338 .47781 Mtetra
.66338 .47781 .66894 .48436 .68049 .48082 .67496 .47423 Mtetra
.67496 .47423 .68049 .48082 .69208 .47726 .68658 .47065 Mtetra
.68658 .47065 .69208 .47726 .70371 .47368 .69825 .46705 Mtetra
.69825 .46705 .70371 .47368 .7154 .47009 .70997 .46343 Mtetra
.70997 .46343 .7154 .47009 .72713 .46649 .72174 .4598 Mtetra
.72174 .4598 .72713 .46649 .73891 .46287 .73355 .45615 Mtetra
.73355 .45615 .73891 .46287 .75075 .45924 .74542 .45249 Mtetra
.74542 .45249 .75075 .45924 .76263 .45559 .75733 .44881 Mtetra
.75733 .44881 .76263 .45559 .77455 .45193 .7693 .44512 Mtetra
.7693 .44512 .77455 .45193 .78653 .44825 .78131 .44141 Mtetra
.78131 .44141 .78653 .44825 .79856 .44455 .79338 .43769 Mtetra
.79338 .43769 .79856 .44455 .81064 .44084 .80549 .43395 Mtetra
.80549 .43395 .81064 .44084 .82277 .43712 .81766 .4302 Mtetra
.81766 .4302 .82277 .43712 .83495 .43338 .82988 .42643 Mtetra
.82988 .42643 .83495 .43338 .84719 .42962 .84215 .42264 Mtetra
.84215 .42264 .84719 .42962 .85947 .42585 .85447 .41884 Mtetra
.85447 .41884 .85947 .42585 .87181 .42206 .86684 .41502 Mtetra
.86684 .41502 .87181 .42206 .88419 .41825 .87927 .41119 Mtetra
.87927 .41119 .88419 .41825 .89664 .41443 .89175 .40734 Mtetra
.89175 .40734 .89664 .41443 .90913 .4106 .90428 .40347 Mtetra
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39958 Mtetra
.91687 .39958 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55984 Mtetra
.37189 .55984 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55284 .41397 .5468 Mtetra
.41397 .5468 .42022 .55284 .43081 .54957 .4246 .5435 Mtetra
.4246 .5435 .43081 .54957 .44145 .54629 .43526 .5402 Mtetra
.43526 .5402 .44145 .54629 .45213 .543 .44597 .53688 Mtetra
.44597 .53688 .45213 .543 .46286 .53969 .45672 .53354 Mtetra
.45672 .53354 .46286 .53969 .47362 .53636 .46751 .5302 Mtetra
.46751 .5302 .47362 .53636 .48443 .53303 .47835 .52684 Mtetra
.47835 .52684 .48443 .53303 .49528 .52968 .48923 .52346 Mtetra
.48923 .52346 .49528 .52968 .50617 .52632 .50015 .52008 Mtetra
.50015 .52008 .50617 .52632 .51711 .52294 .51112 .51668 Mtetra
.51112 .51668 .51711 .52294 .52809 .51955 .52213 .51326 Mtetra
.52213 .51326 .52809 .51955 .53912 .51615 .53318 .50983 Mtetra
.53318 .50983 .53912 .51615 .55019 .51274 .54428 .50639 Mtetra
.54428 .50639 .55019 .51274 .5613 .50931 .55543 .50294 Mtetra
.55543 .50294 .5613 .50931 .57246 .50586 .56661 .49947 Mtetra
.56661 .49947 .57246 .50586 .58367 .50241 .57785 .49599 Mtetra
.57785 .49599 .58367 .50241 .59492 .49893 .58913 .49249 Mtetra
.58913 .49249 .59492 .49893 .60621 .49545 .60045 .48898 Mtetra
.60045 .48898 .60621 .49545 .61755 .49195 .61183 .48545 Mtetra
.61183 .48545 .61755 .49195 .62894 .48843 .62325 .48191 Mtetra
.62325 .48191 .62894 .48843 .64038 .48491 .63471 .47835 Mtetra
.63471 .47835 .64038 .48491 .65186 .48136 .64622 .47478 Mtetra
.64622 .47478 .65186 .48136 .66338 .47781 .65778 .4712 Mtetra
.65778 .4712 .66338 .47781 .67496 .47423 .66939 .4676 Mtetra
.66939 .4676 .67496 .47423 .68658 .47065 .68105 .46399 Mtetra
.68105 .46399 .68658 .47065 .69825 .46705 .69275 .46036 Mtetra
.69275 .46036 .69825 .46705 .70997 .46343 .7045 .45671 Mtetra
.7045 .45671 .70997 .46343 .72174 .4598 .7163 .45306 Mtetra
.7163 .45306 .72174 .4598 .73355 .45615 .72815 .44938 Mtetra
.72815 .44938 .73355 .45615 .74542 .45249 .74005 .44569 Mtetra
.74005 .44569 .74542 .45249 .75733 .44881 .752 .44199 Mtetra
.752 .44199 .75733 .44881 .7693 .44512 .764 .43827 Mtetra
.764 .43827 .7693 .44512 .78131 .44141 .77605 .43453 Mtetra
.77605 .43453 .78131 .44141 .79338 .43769 .78815 .43078 Mtetra
.78815 .43078 .79338 .43769 .80549 .43395 .8003 .42701 Mtetra
.8003 .42701 .80549 .43395 .81766 .4302 .81251 .42323 Mtetra
.81251 .42323 .81766 .4302 .82988 .42643 .82476 .41943 Mtetra
.82476 .41943 .82988 .42643 .84215 .42264 .83707 .41561 Mtetra
.83707 .41561 .84215 .42264 .85447 .41884 .84943 .41178 Mtetra
.84943 .41178 .85447 .41884 .86684 .41502 .86184 .40793 Mtetra
.86184 .40793 .86684 .41502 .87927 .41119 .8743 .40406 Mtetra
.8743 .40406 .87927 .41119 .89175 .40734 .88682 .40018 Mtetra
.88682 .40018 .89175 .40734 .90428 .40347 .89939 .39628 Mtetra
.89939 .39628 .90428 .40347 .91687 .39958 .91202 .39237 Mtetra
.91202 .39237 .91687 .39958 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.35506 .5571 .36148 .56307 .37189 .55984 .3655 .55385 Mtetra
.3655 .55385 .37189 .55984 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .5435 .41834 .53739 Mtetra
.41834 .53739 .4246 .5435 .43526 .5402 .42903 .53406 Mtetra
.42903 .53406 .43526 .5402 .44597 .53688 .43976 .53071 Mtetra
.43976 .53071 .44597 .53688 .45672 .53354 .45054 .52735 Mtetra
.45054 .52735 .45672 .53354 .46751 .5302 .46136 .52398 Mtetra
.46136 .52398 .46751 .5302 .47835 .52684 .47222 .5206 Mtetra
.47222 .5206 .47835 .52684 .48923 .52346 .48313 .5172 Mtetra
.48313 .5172 .48923 .52346 .50015 .52008 .49408 .51379 Mtetra
.49408 .51379 .50015 .52008 .51112 .51668 .50508 .51036 Mtetra
.50508 .51036 .51112 .51668 .52213 .51326 .51612 .50692 Mtetra
.51612 .50692 .52213 .51326 .53318 .50983 .5272 .50347 Mtetra
.5272 .50347 .53318 .50983 .54428 .50639 .53833 .5 Mtetra
.53833 .5 .54428 .50639 .55543 .50294 .5495 .49652 Mtetra
.5495 .49652 .55543 .50294 .56661 .49947 .56072 .49303 Mtetra
.56072 .49303 .56661 .49947 .57785 .49599 .57199 .48952 Mtetra
.57199 .48952 .57785 .49599 .58913 .49249 .5833 .48599 Mtetra
.5833 .48599 .58913 .49249 .60045 .48898 .59465 .48245 Mtetra
.59465 .48245 .60045 .48898 .61183 .48545 .60606 .4789 Mtetra
.60606 .4789 .61183 .48545 .62325 .48191 .61751 .47533 Mtetra
.61751 .47533 .62325 .48191 .63471 .47835 .629 .47175 Mtetra
.629 .47175 .63471 .47835 .64622 .47478 .64055 .46816 Mtetra
.64055 .46816 .64622 .47478 .65778 .4712 .65214 .46454 Mtetra
.65214 .46454 .65778 .4712 .66939 .4676 .66378 .46092 Mtetra
.66378 .46092 .66939 .4676 .68105 .46399 .67547 .45728 Mtetra
.67547 .45728 .68105 .46399 .69275 .46036 .68721 .45362 Mtetra
.68721 .45362 .69275 .46036 .7045 .45671 .69899 .44995 Mtetra
.69899 .44995 .7045 .45671 .7163 .45306 .71083 .44626 Mtetra
.71083 .44626 .7163 .45306 .72815 .44938 .72271 .44256 Mtetra
.72271 .44256 .72815 .44938 .74005 .44569 .73465 .43884 Mtetra
.73465 .43884 .74005 .44569 .752 .44199 .74663 .4351 Mtetra
.74663 .4351 .752 .44199 .764 .43827 .75866 .43136 Mtetra
.75866 .43136 .764 .43827 .77605 .43453 .77075 .42759 Mtetra
.77075 .42759 .77605 .43453 .78815 .43078 .78289 .42381 Mtetra
.78289 .42381 .78815 .43078 .8003 .42701 .79507 .42001 Mtetra
.79507 .42001 .8003 .42701 .81251 .42323 .80731 .4162 Mtetra
.80731 .4162 .81251 .42323 .82476 .41943 .81961 .41237 Mtetra
.81961 .41237 .82476 .41943 .83707 .41561 .83195 .40852 Mtetra
.83195 .40852 .83707 .41561 .84943 .41178 .84435 .40466 Mtetra
.84435 .40466 .84943 .41178 .86184 .40793 .8568 .40078 Mtetra
.8568 .40078 .86184 .40793 .8743 .40406 .8693 .39689 Mtetra
.8693 .39689 .8743 .40406 .88682 .40018 .88186 .39297 Mtetra
.88186 .39297 .88682 .40018 .89939 .39628 .89447 .38904 Mtetra
.89447 .38904 .89939 .39628 .91202 .39237 .90713 .3851 Mtetra
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37715 Mtetra
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53457 Mtetra
.40135 .53457 .40769 .54071 .41834 .53739 .41203 .53123 Mtetra
.41203 .53123 .41834 .53739 .42903 .53406 .42275 .52787 Mtetra
.42275 .52787 .42903 .53406 .43976 .53071 .43351 .5245 Mtetra
.43351 .5245 .43976 .53071 .45054 .52735 .44432 .52112 Mtetra
.44432 .52112 .45054 .52735 .46136 .52398 .45516 .51772 Mtetra
.45516 .51772 .46136 .52398 .47222 .5206 .46605 .51431 Mtetra
.46605 .51431 .47222 .5206 .48313 .5172 .47699 .51089 Mtetra
.47699 .51089 .48313 .5172 .49408 .51379 .48797 .50745 Mtetra
.48797 .50745 .49408 .51379 .50508 .51036 .49899 .504 Mtetra
.49899 .504 .50508 .51036 .51612 .50692 .51006 .50054 Mtetra
.51006 .50054 .51612 .50692 .5272 .50347 .52117 .49706 Mtetra
.52117 .49706 .5272 .50347 .53833 .5 .53233 .49357 Mtetra
.53233 .49357 .53833 .5 .5495 .49652 .54353 .49006 Mtetra
.54353 .49006 .5495 .49652 .56072 .49303 .55478 .48654 Mtetra
.55478 .48654 .56072 .49303 .57199 .48952 .56608 .483 Mtetra
.56608 .483 .57199 .48952 .5833 .48599 .57742 .47945 Mtetra
.57742 .47945 .5833 .48599 .59465 .48245 .58881 .47588 Mtetra
.58881 .47588 .59465 .48245 .60606 .4789 .60024 .4723 Mtetra
.60024 .4723 .60606 .4789 .61751 .47533 .61172 .46871 Mtetra
.61172 .46871 .61751 .47533 .629 .47175 .62325 .4651 Mtetra
.62325 .4651 .629 .47175 .64055 .46816 .63483 .46148 Mtetra
.63483 .46148 .64055 .46816 .65214 .46454 .64645 .45784 Mtetra
.64645 .45784 .65214 .46454 .66378 .46092 .65813 .45418 Mtetra
.65813 .45418 .66378 .46092 .67547 .45728 .66985 .45051 Mtetra
.66985 .45051 .67547 .45728 .68721 .45362 .68162 .44683 Mtetra
.68162 .44683 .68721 .45362 .69899 .44995 .69344 .44313 Mtetra
.69344 .44313 .69899 .44995 .71083 .44626 .70531 .43941 Mtetra
.70531 .43941 .71083 .44626 .72271 .44256 .71723 .43568 Mtetra
.71723 .43568 .72271 .44256 .73465 .43884 .7292 .43193 Mtetra
.7292 .43193 .73465 .43884 .74663 .4351 .74122 .42817 Mtetra
.74122 .42817 .74663 .4351 .75866 .43136 .75329 .42439 Mtetra
.75329 .42439 .75866 .43136 .77075 .42759 .76541 .4206 Mtetra
.76541 .4206 .77075 .42759 .78289 .42381 .77758 .41679 Mtetra
.77758 .41679 .78289 .42381 .79507 .42001 .7898 .41296 Mtetra
.7898 .41296 .79507 .42001 .80731 .4162 .80208 .40912 Mtetra
.80208 .40912 .80731 .4162 .81961 .41237 .81441 .40526 Mtetra
.81441 .40526 .81961 .41237 .83195 .40852 .82679 .40138 Mtetra
.82679 .40138 .83195 .40852 .84435 .40466 .83923 .39749 Mtetra
.83923 .39749 .84435 .40466 .8568 .40078 .85171 .39358 Mtetra
.85171 .39358 .8568 .40078 .8693 .39689 .86426 .38965 Mtetra
.86426 .38965 .8693 .39689 .88186 .39297 .87685 .38571 Mtetra
.87685 .38571 .88186 .39297 .89447 .38904 .8895 .38175 Mtetra
.8895 .38175 .89447 .38904 .90713 .3851 .90221 .37777 Mtetra
.90221 .37777 .90713 .3851 .91985 .38114 .91497 .37377 Mtetra
.91497 .37377 .91985 .38114 .93263 .37715 .92778 .36976 Mtetra
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53508 Mtetra
.3737 .53508 .38013 .54122 .39072 .5379 .38431 .53174 Mtetra
.38431 .53174 .39072 .5379 .40135 .53457 .39497 .52839 Mtetra
.39497 .52839 .40135 .53457 .41203 .53123 .40568 .52502 Mtetra
.40568 .52502 .41203 .53123 .42275 .52787 .41642 .52164 Mtetra
.41642 .52164 .42275 .52787 .43351 .5245 .42721 .51825 Mtetra
.42721 .51825 .43351 .5245 .44432 .52112 .43804 .51484 Mtetra
.43804 .51484 .44432 .52112 .45516 .51772 .44892 .51142 Mtetra
.44892 .51142 .45516 .51772 .46605 .51431 .45984 .50798 Mtetra
.45984 .50798 .46605 .51431 .47699 .51089 .4708 .50453 Mtetra
.4708 .50453 .47699 .51089 .48797 .50745 .48181 .50107 Mtetra
.48181 .50107 .48797 .50745 .49899 .504 .49286 .49759 Mtetra
.49286 .49759 .49899 .504 .51006 .50054 .50396 .4941 Mtetra
.50396 .4941 .51006 .50054 .52117 .49706 .5151 .4906 Mtetra
.5151 .4906 .52117 .49706 .53233 .49357 .52629 .48708 Mtetra
.52629 .48708 .53233 .49357 .54353 .49006 .53752 .48355 Mtetra
.53752 .48355 .54353 .49006 .55478 .48654 .5488 .48 Mtetra
.5488 .48 .55478 .48654 .56608 .483 .56013 .47643 Mtetra
.56013 .47643 .56608 .483 .57742 .47945 .5715 .47286 Mtetra
.5715 .47286 .57742 .47945 .58881 .47588 .58292 .46926 Mtetra
.58292 .46926 .58881 .47588 .60024 .4723 .59438 .46566 Mtetra
.59438 .46566 .60024 .4723 .61172 .46871 .6059 .46203 Mtetra
.6059 .46203 .61172 .46871 .62325 .4651 .61746 .4584 Mtetra
.61746 .4584 .62325 .4651 .63483 .46148 .62907 .45475 Mtetra
.62907 .45475 .63483 .46148 .64645 .45784 .64072 .45108 Mtetra
.64072 .45108 .64645 .45784 .65813 .45418 .65243 .4474 Mtetra
.65243 .4474 .65813 .45418 .66985 .45051 .66418 .4437 Mtetra
.66418 .4437 .66985 .45051 .68162 .44683 .67599 .43998 Mtetra
.67599 .43998 .68162 .44683 .69344 .44313 .68784 .43626 Mtetra
.68784 .43626 .69344 .44313 .70531 .43941 .69975 .43251 Mtetra
.69975 .43251 .70531 .43941 .71723 .43568 .7117 .42875 Mtetra
.7117 .42875 .71723 .43568 .7292 .43193 .7237 .42497 Mtetra
.7237 .42497 .7292 .43193 .74122 .42817 .73576 .42118 Mtetra
.73576 .42118 .74122 .42817 .75329 .42439 .74786 .41737 Mtetra
.74786 .41737 .75329 .42439 .76541 .4206 .76002 .41355 Mtetra
.76002 .41355 .76541 .4206 .77758 .41679 .77223 .40971 Mtetra
.77223 .40971 .77758 .41679 .7898 .41296 .78449 .40585 Mtetra
.78449 .40585 .7898 .41296 .80208 .40912 .79681 .40198 Mtetra
.79681 .40198 .80208 .40912 .81441 .40526 .80917 .39809 Mtetra
.80917 .39809 .81441 .40526 .82679 .40138 .82159 .39418 Mtetra
.82159 .39418 .82679 .40138 .83923 .39749 .83406 .39025 Mtetra
.83406 .39025 .83923 .39749 .85171 .39358 .84659 .38631 Mtetra
.84659 .38631 .85171 .39358 .86426 .38965 .85917 .38236 Mtetra
.85917 .38236 .86426 .38965 .87685 .38571 .87181 .37838 Mtetra
.87181 .37838 .87685 .38571 .8895 .38175 .8845 .37439 Mtetra
.8845 .37439 .8895 .38175 .90221 .37777 .89724 .37038 Mtetra
.89724 .37038 .90221 .37777 .91497 .37377 .91004 .36635 Mtetra
.91004 .36635 .91497 .37377 .92778 .36976 .9229 .36231 Mtetra
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53508 .36722 .52891 Mtetra
.36722 .52891 .3737 .53508 .38431 .53174 .37786 .52554 Mtetra
.37786 .52554 .38431 .53174 .39497 .52839 .38855 .52216 Mtetra
.38855 .52216 .39497 .52839 .40568 .52502 .39928 .51877 Mtetra
.39928 .51877 .40568 .52502 .41642 .52164 .41005 .51537 Mtetra
.41005 .51537 .41642 .52164 .42721 .51825 .42087 .51195 Mtetra
.42087 .51195 .42721 .51825 .43804 .51484 .43173 .50851 Mtetra
.43173 .50851 .43804 .51484 .44892 .51142 .44263 .50507 Mtetra
.44263 .50507 .44892 .51142 .45984 .50798 .45358 .50161 Mtetra
.45358 .50161 .45984 .50798 .4708 .50453 .46457 .49813 Mtetra
.46457 .49813 .4708 .50453 .48181 .50107 .4756 .49464 Mtetra
.4756 .49464 .48181 .50107 .49286 .49759 .48668 .49114 Mtetra
.48668 .49114 .49286 .49759 .50396 .4941 .49781 .48762 Mtetra
.49781 .48762 .50396 .4941 .5151 .4906 .50898 .48409 Mtetra
.50898 .48409 .5151 .4906 .52629 .48708 .5202 .48054 Mtetra
.5202 .48054 .52629 .48708 .53752 .48355 .53146 .47698 Mtetra
.53146 .47698 .53752 .48355 .5488 .48 .54277 .47341 Mtetra
.54277 .47341 .5488 .48 .56013 .47643 .55413 .46982 Mtetra
.55413 .46982 .56013 .47643 .5715 .47286 .56553 .46621 Mtetra
.56553 .46621 .5715 .47286 .58292 .46926 .57698 .46259 Mtetra
.57698 .46259 .58292 .46926 .59438 .46566 .58848 .45896 Mtetra
.58848 .45896 .59438 .46566 .6059 .46203 .60002 .45531 Mtetra
.60002 .45531 .6059 .46203 .61746 .4584 .61162 .45164 Mtetra
.61162 .45164 .61746 .4584 .62907 .45475 .62326 .44796 Mtetra
.62326 .44796 .62907 .45475 .64072 .45108 .63495 .44427 Mtetra
.63495 .44427 .64072 .45108 .65243 .4474 .64669 .44056 Mtetra
.64669 .44056 .65243 .4474 .66418 .4437 .65848 .43683 Mtetra
.65848 .43683 .66418 .4437 .67599 .43998 .67031 .43309 Mtetra
.67031 .43309 .67599 .43998 .68784 .43626 .6822 .42933 Mtetra
.6822 .42933 .68784 .43626 .69975 .43251 .69414 .42556 Mtetra
.69414 .42556 .69975 .43251 .7117 .42875 .70613 .42177 Mtetra
.70613 .42177 .7117 .42875 .7237 .42497 .71817 .41796 Mtetra
.71817 .41796 .7237 .42497 .73576 .42118 .73026 .41414 Mtetra
.73026 .41414 .73576 .42118 .74786 .41737 .7424 .4103 Mtetra
.7424 .4103 .74786 .41737 .76002 .41355 .75459 .40644 Mtetra
.75459 .40644 .76002 .41355 .77223 .40971 .76684 .40257 Mtetra
.76684 .40257 .77223 .40971 .78449 .40585 .77914 .39869 Mtetra
.77914 .39869 .78449 .40585 .79681 .40198 .79149 .39478 Mtetra
.79149 .39478 .79681 .40198 .80917 .39809 .80389 .39086 Mtetra
.80389 .39086 .80917 .39809 .82159 .39418 .81635 .38692 Mtetra
.81635 .38692 .82159 .39418 .83406 .39025 .82886 .38297 Mtetra
.82886 .38297 .83406 .39025 .84659 .38631 .84143 .37899 Mtetra
.84143 .37899 .84659 .38631 .85917 .38236 .85405 .375 Mtetra
.85405 .375 .85917 .38236 .87181 .37838 .86672 .371 Mtetra
.86672 .371 .87181 .37838 .8845 .37439 .87945 .36697 Mtetra
.87945 .36697 .8845 .37439 .89724 .37038 .89224 .36293 Mtetra
.89224 .36293 .89724 .37038 .91004 .36635 .90508 .35887 Mtetra
.90508 .35887 .91004 .36635 .9229 .36231 .91798 .35479 Mtetra
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52268 Mtetra
.36069 .52268 .36722 .52891 .37786 .52554 .37136 .51929 Mtetra
.37136 .51929 .37786 .52554 .38855 .52216 .38207 .51589 Mtetra
.38207 .51589 .38855 .52216 .39928 .51877 .39283 .51247 Mtetra
.39283 .51247 .39928 .51877 .41005 .51537 .40363 .50904 Mtetra
.40363 .50904 .41005 .51537 .42087 .51195 .41447 .5056 Mtetra
.41447 .5056 .42087 .51195 .43173 .50851 .42536 .50214 Mtetra
.42536 .50214 .43173 .50851 .44263 .50507 .43629 .49867 Mtetra
.43629 .49867 .44263 .50507 .45358 .50161 .44727 .49518 Mtetra
.44727 .49518 .45358 .50161 .46457 .49813 .45829 .49168 Mtetra
.45829 .49168 .46457 .49813 .4756 .49464 .46935 .48816 Mtetra
.46935 .48816 .4756 .49464 .48668 .49114 .48046 .48463 Mtetra
.48046 .48463 .48668 .49114 .49781 .48762 .49162 .48109 Mtetra
.49162 .48109 .49781 .48762 .50898 .48409 .50282 .47753 Mtetra
.50282 .47753 .50898 .48409 .5202 .48054 .51406 .47396 Mtetra
.51406 .47396 .5202 .48054 .53146 .47698 .52536 .47037 Mtetra
.52536 .47037 .53146 .47698 .54277 .47341 .5367 .46677 Mtetra
.5367 .46677 .54277 .47341 .55413 .46982 .54809 .46315 Mtetra
.54809 .46315 .55413 .46982 .56553 .46621 .55952 .45952 Mtetra
.55952 .45952 .56553 .46621 .57698 .46259 .571 .45587 Mtetra
.571 .45587 .57698 .46259 .58848 .45896 .58253 .45221 Mtetra
.58253 .45221 .58848 .45896 .60002 .45531 .59411 .44853 Mtetra
.59411 .44853 .60002 .45531 .61162 .45164 .60573 .44484 Mtetra
.60573 .44484 .61162 .45164 .62326 .44796 .61741 .44113 Mtetra
.61741 .44113 .62326 .44796 .63495 .44427 .62913 .4374 Mtetra
.62913 .4374 .63495 .44427 .64669 .44056 .6409 .43366 Mtetra
.6409 .43366 .64669 .44056 .65848 .43683 .65272 .42991 Mtetra
.65272 .42991 .65848 .43683 .67031 .43309 .6646 .42614 Mtetra
.6646 .42614 .67031 .43309 .6822 .42933 .67652 .42235 Mtetra
.67652 .42235 .6822 .42933 .69414 .42556 .68849 .41855 Mtetra
.68849 .41855 .69414 .42556 .70613 .42177 .70051 .41473 Mtetra
.70051 .41473 .70613 .42177 .71817 .41796 .71259 .41089 Mtetra
.71259 .41089 .71817 .41796 .73026 .41414 .72471 .40704 Mtetra
.72471 .40704 .73026 .41414 .7424 .4103 .73689 .40317 Mtetra
.73689 .40317 .7424 .4103 .75459 .40644 .74912 .39928 Mtetra
.74912 .39928 .75459 .40644 .76684 .40257 .76141 .39538 Mtetra
.76141 .39538 .76684 .40257 .77914 .39869 .77374 .39146 Mtetra
.77374 .39146 .77914 .39869 .79149 .39478 .78613 .38753 Mtetra
.78613 .38753 .79149 .39478 .80389 .39086 .79857 .38358 Mtetra
.79857 .38358 .80389 .39086 .81635 .38692 .81107 .37961 Mtetra
.81107 .37961 .81635 .38692 .82886 .38297 .82362 .37562 Mtetra
.82362 .37562 .82886 .38297 .84143 .37899 .83622 .37161 Mtetra
.83622 .37161 .84143 .37899 .85405 .375 .84888 .36759 Mtetra
.84888 .36759 .85405 .375 .86672 .371 .8616 .36355 Mtetra
.8616 .36355 .86672 .371 .87945 .36697 .87437 .3595 Mtetra
.87437 .3595 .87945 .36697 .89224 .36293 .88719 .35542 Mtetra
.88719 .35542 .89224 .36293 .90508 .35887 .90008 .35133 Mtetra
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .5232 Mtetra
.33285 .5232 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52268 .35411 .51641 Mtetra
.35411 .51641 .36069 .52268 .37136 .51929 .36481 .513 Mtetra
.36481 .513 .37136 .51929 .38207 .51589 .37555 .50957 Mtetra
.37555 .50957 .38207 .51589 .39283 .51247 .38633 .50613 Mtetra
.38633 .50613 .39283 .51247 .40363 .50904 .39716 .50267 Mtetra
.39716 .50267 .40363 .50904 .41447 .5056 .40803 .4992 Mtetra
.40803 .4992 .41447 .5056 .42536 .50214 .41895 .49572 Mtetra
.41895 .49572 .42536 .50214 .43629 .49867 .42991 .49222 Mtetra
.42991 .49222 .43629 .49867 .44727 .49518 .44091 .48871 Mtetra
.44091 .48871 .44727 .49518 .45829 .49168 .45196 .48518 Mtetra
.45196 .48518 .45829 .49168 .46935 .48816 .46305 .48164 Mtetra
.46305 .48164 .46935 .48816 .48046 .48463 .47419 .47808 Mtetra
.47419 .47808 .48046 .48463 .49162 .48109 .48538 .47451 Mtetra
.48538 .47451 .49162 .48109 .50282 .47753 .49661 .47092 Mtetra
.49661 .47092 .50282 .47753 .51406 .47396 .50788 .46732 Mtetra
.50788 .46732 .51406 .47396 .52536 .47037 .51921 .46371 Mtetra
.51921 .46371 .52536 .47037 .5367 .46677 .53058 .46008 Mtetra
.53058 .46008 .5367 .46677 .54809 .46315 .542 .45643 Mtetra
.542 .45643 .54809 .46315 .55952 .45952 .55346 .45277 Mtetra
.55346 .45277 .55952 .45952 .571 .45587 .56497 .4491 Mtetra
.56497 .4491 .571 .45587 .58253 .45221 .57654 .44541 Mtetra
.57654 .44541 .58253 .45221 .59411 .44853 .58814 .4417 Mtetra
.58814 .4417 .59411 .44853 .60573 .44484 .5998 .43798 Mtetra
.5998 .43798 .60573 .44484 .61741 .44113 .61151 .43424 Mtetra
.61151 .43424 .61741 .44113 .62913 .4374 .62327 .43049 Mtetra
.62327 .43049 .62913 .4374 .6409 .43366 .63507 .42672 Mtetra
.63507 .42672 .6409 .43366 .65272 .42991 .64693 .42293 Mtetra
.64693 .42293 .65272 .42991 .6646 .42614 .65883 .41913 Mtetra
.65883 .41913 .6646 .42614 .67652 .42235 .67079 .41532 Mtetra
.67079 .41532 .67652 .42235 .68849 .41855 .6828 .41148 Mtetra
.6828 .41148 .68849 .41855 .70051 .41473 .69486 .40763 Mtetra
.69486 .40763 .70051 .41473 .71259 .41089 .70697 .40377 Mtetra
.70697 .40377 .71259 .41089 .72471 .40704 .71913 .39988 Mtetra
.71913 .39988 .72471 .40704 .73689 .40317 .73134 .39598 Mtetra
.73134 .39598 .73689 .40317 .74912 .39928 .74361 .39207 Mtetra
.74361 .39207 .74912 .39928 .76141 .39538 .75593 .38814 Mtetra
.75593 .38814 .76141 .39538 .77374 .39146 .7683 .38419 Mtetra
.7683 .38419 .77374 .39146 .78613 .38753 .78073 .38022 Mtetra
.78073 .38022 .78613 .38753 .79857 .38358 .79321 .37623 Mtetra
.79321 .37623 .79857 .38358 .81107 .37961 .80574 .37223 Mtetra
.80574 .37223 .81107 .37961 .82362 .37562 .81833 .36821 Mtetra
.81833 .36821 .82362 .37562 .83622 .37161 .83097 .36418 Mtetra
.83097 .36418 .83622 .37161 .84888 .36759 .84367 .36012 Mtetra
.84367 .36012 .84888 .36759 .8616 .36355 .85643 .35605 Mtetra
.85643 .35605 .8616 .36355 .87437 .3595 .86924 .35196 Mtetra
.86924 .35196 .87437 .3595 .88719 .35542 .88211 .34785 Mtetra
.88211 .34785 .88719 .35542 .90008 .35133 .89503 .34373 Mtetra
.89503 .34373 .90008 .35133 .91302 .34722 .90801 .33958 Mtetra
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .34346 .51982 .33681 .51353 Mtetra
.33681 .51353 .34346 .51982 .35411 .51641 .34749 .5101 Mtetra
.34749 .5101 .35411 .51641 .36481 .513 .35821 .50666 Mtetra
.35821 .50666 .36481 .513 .37555 .50957 .36898 .5032 Mtetra
.36898 .5032 .37555 .50957 .38633 .50613 .37979 .49974 Mtetra
.37979 .49974 .38633 .50613 .39716 .50267 .39065 .49625 Mtetra
.39065 .49625 .39716 .50267 .40803 .4992 .40154 .49276 Mtetra
.40154 .49276 .40803 .4992 .41895 .49572 .41249 .48925 Mtetra
.41249 .48925 .41895 .49572 .42991 .49222 .42347 .48572 Mtetra
.42347 .48572 .42991 .49222 .44091 .48871 .4345 .48218 Mtetra
.4345 .48218 .44091 .48871 .45196 .48518 .44558 .47863 Mtetra
.44558 .47863 .45196 .48518 .46305 .48164 .4567 .47506 Mtetra
.4567 .47506 .46305 .48164 .47419 .47808 .46787 .47148 Mtetra
.46787 .47148 .47419 .47808 .48538 .47451 .47909 .46788 Mtetra
.47909 .46788 .48538 .47451 .49661 .47092 .49035 .46427 Mtetra
.49035 .46427 .49661 .47092 .50788 .46732 .50166 .46064 Mtetra
.50166 .46064 .50788 .46732 .51921 .46371 .51301 .45699 Mtetra
.51301 .45699 .51921 .46371 .53058 .46008 .52441 .45334 Mtetra
.52441 .45334 .53058 .46008 .542 .45643 .53586 .44966 Mtetra
.53586 .44966 .542 .45643 .55346 .45277 .54736 .44598 Mtetra
.54736 .44598 .55346 .45277 .56497 .4491 .5589 .44227 Mtetra
.5589 .44227 .56497 .4491 .57654 .44541 .57049 .43855 Mtetra
.57049 .43855 .57654 .44541 .58814 .4417 .58214 .43482 Mtetra
.58214 .43482 .58814 .4417 .5998 .43798 .59383 .43107 Mtetra
.59383 .43107 .5998 .43798 .61151 .43424 .60557 .4273 Mtetra
.60557 .4273 .61151 .43424 .62327 .43049 .61736 .42352 Mtetra
.61736 .42352 .62327 .43049 .63507 .42672 .6292 .41972 Mtetra
.6292 .41972 .63507 .42672 .64693 .42293 .64109 .4159 Mtetra
.64109 .4159 .64693 .42293 .65883 .41913 .65303 .41207 Mtetra
.65303 .41207 .65883 .41913 .67079 .41532 .66502 .40823 Mtetra
.66502 .40823 .67079 .41532 .6828 .41148 .67706 .40436 Mtetra
.67706 .40436 .6828 .41148 .69486 .40763 .68915 .40048 Mtetra
.68915 .40048 .69486 .40763 .70697 .40377 .7013 .39659 Mtetra
.7013 .39659 .70697 .40377 .71913 .39988 .7135 .39267 Mtetra
.7135 .39267 .71913 .39988 .73134 .39598 .72575 .38874 Mtetra
.72575 .38874 .73134 .39598 .74361 .39207 .73805 .38479 Mtetra
.73805 .38479 .74361 .39207 .75593 .38814 .75041 .38083 Mtetra
.75041 .38083 .75593 .38814 .7683 .38419 .76282 .37685 Mtetra
.76282 .37685 .7683 .38419 .78073 .38022 .77528 .37285 Mtetra
.77528 .37285 .78073 .38022 .79321 .37623 .7878 .36883 Mtetra
.7878 .36883 .79321 .37623 .80574 .37223 .80037 .3648 Mtetra
.80037 .3648 .80574 .37223 .81833 .36821 .813 .36075 Mtetra
.813 .36075 .81833 .36821 .83097 .36418 .82568 .35668 Mtetra
.82568 .35668 .83097 .36418 .84367 .36012 .83842 .35259 Mtetra
.83842 .35259 .84367 .36012 .85643 .35605 .85122 .34849 Mtetra
.85122 .34849 .85643 .35605 .86924 .35196 .86407 .34436 Mtetra
.86407 .34436 .86924 .35196 .88211 .34785 .87698 .34022 Mtetra
.87698 .34022 .88211 .34785 .89503 .34373 .88994 .33606 Mtetra
.88994 .33606 .89503 .34373 .90801 .33958 .90297 .33188 Mtetra
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.34082 .50374 .34749 .5101 .35821 .50666 .35157 .50027 Mtetra
.35157 .50027 .35821 .50666 .36898 .5032 .36236 .49679 Mtetra
.36236 .49679 .36898 .5032 .37979 .49974 .3732 .4933 Mtetra
.3732 .4933 .37979 .49974 .39065 .49625 .38408 .48979 Mtetra
.38408 .48979 .39065 .49625 .40154 .49276 .39501 .48626 Mtetra
.39501 .48626 .40154 .49276 .41249 .48925 .40598 .48273 Mtetra
.40598 .48273 .41249 .48925 .42347 .48572 .41699 .47918 Mtetra
.41699 .47918 .42347 .48572 .4345 .48218 .42805 .47561 Mtetra
.42805 .47561 .4345 .48218 .44558 .47863 .43916 .47203 Mtetra
.43916 .47203 .44558 .47863 .4567 .47506 .45031 .46843 Mtetra
.45031 .46843 .4567 .47506 .46787 .47148 .46151 .46482 Mtetra
.46151 .46482 .46787 .47148 .47909 .46788 .47275 .4612 Mtetra
.47275 .4612 .47909 .46788 .49035 .46427 .48404 .45756 Mtetra
.48404 .45756 .49035 .46427 .50166 .46064 .49538 .4539 Mtetra
.49538 .4539 .50166 .46064 .51301 .45699 .50676 .45023 Mtetra
.50676 .45023 .51301 .45699 .52441 .45334 .5182 .44654 Mtetra
.5182 .44654 .52441 .45334 .53586 .44966 .52968 .44284 Mtetra
.52968 .44284 .53586 .44966 .54736 .44598 .5412 .43913 Mtetra
.5412 .43913 .54736 .44598 .5589 .44227 .55278 .43539 Mtetra
.55278 .43539 .5589 .44227 .57049 .43855 .56441 .43164 Mtetra
.56441 .43164 .57049 .43855 .58214 .43482 .57608 .42788 Mtetra
.57608 .42788 .58214 .43482 .59383 .43107 .5878 .4241 Mtetra
.5878 .4241 .59383 .43107 .60557 .4273 .59958 .4203 Mtetra
.59958 .4203 .60557 .4273 .61736 .42352 .6114 .41649 Mtetra
.6114 .41649 .61736 .42352 .6292 .41972 .62327 .41266 Mtetra
.62327 .41266 .6292 .41972 .64109 .4159 .6352 .40882 Mtetra
.6352 .40882 .64109 .4159 .65303 .41207 .64717 .40496 Mtetra
.64717 .40496 .65303 .41207 .66502 .40823 .6592 .40108 Mtetra
.6592 .40108 .66502 .40823 .67706 .40436 .67128 .39719 Mtetra
.67128 .39719 .67706 .40436 .68915 .40048 .6834 .39327 Mtetra
.6834 .39327 .68915 .40048 .7013 .39659 .69559 .38935 Mtetra
.69559 .38935 .7013 .39659 .7135 .39267 .70782 .3854 Mtetra
.70782 .3854 .7135 .39267 .72575 .38874 .72011 .38144 Mtetra
.72011 .38144 .72575 .38874 .73805 .38479 .73245 .37746 Mtetra
.73245 .37746 .73805 .38479 .75041 .38083 .74484 .37347 Mtetra
.74484 .37347 .75041 .38083 .76282 .37685 .75729 .36945 Mtetra
.75729 .36945 .76282 .37685 .77528 .37285 .76979 .36542 Mtetra
.76979 .36542 .77528 .37285 .7878 .36883 .78235 .36137 Mtetra
.78235 .36137 .7878 .36883 .80037 .3648 .79496 .35731 Mtetra
.79496 .35731 .80037 .3648 .813 .36075 .80763 .35322 Mtetra
.80763 .35322 .813 .36075 .82568 .35668 .82035 .34912 Mtetra
.82035 .34912 .82568 .35668 .83842 .35259 .83313 .345 Mtetra
.83313 .345 .83842 .35259 .85122 .34849 .84597 .34086 Mtetra
.84597 .34086 .85122 .34849 .86407 .34436 .85886 .3367 Mtetra
.85886 .3367 .86407 .34436 .87698 .34022 .87181 .33253 Mtetra
.87181 .33253 .87698 .34022 .88994 .33606 .88482 .32833 Mtetra
.88482 .32833 .88994 .33606 .90297 .33188 .89788 .32412 Mtetra
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .5008 Mtetra
.32336 .5008 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49383 Mtetra
.34487 .49383 .35157 .50027 .36236 .49679 .35569 .49033 Mtetra
.35569 .49033 .36236 .49679 .3732 .4933 .36656 .48681 Mtetra
.36656 .48681 .3732 .4933 .38408 .48979 .37746 .48327 Mtetra
.37746 .48327 .38408 .48979 .39501 .48626 .38842 .47972 Mtetra
.38842 .47972 .39501 .48626 .40598 .48273 .39942 .47616 Mtetra
.39942 .47616 .40598 .48273 .41699 .47918 .41046 .47258 Mtetra
.41046 .47258 .41699 .47918 .42805 .47561 .42155 .46899 Mtetra
.42155 .46899 .42805 .47561 .43916 .47203 .43268 .46538 Mtetra
.43268 .46538 .43916 .47203 .45031 .46843 .44386 .46176 Mtetra
.44386 .46176 .45031 .46843 .46151 .46482 .45509 .45812 Mtetra
.45509 .45812 .46151 .46482 .47275 .4612 .46637 .45446 Mtetra
.46637 .45446 .47275 .4612 .48404 .45756 .47769 .4508 Mtetra
.47769 .4508 .48404 .45756 .49538 .4539 .48905 .44711 Mtetra
.48905 .44711 .49538 .4539 .50676 .45023 .50047 .44341 Mtetra
.50047 .44341 .50676 .45023 .5182 .44654 .51193 .4397 Mtetra
.51193 .4397 .5182 .44654 .52968 .44284 .52344 .43597 Mtetra
.52344 .43597 .52968 .44284 .5412 .43913 .535 .43222 Mtetra
.535 .43222 .5412 .43913 .55278 .43539 .54661 .42846 Mtetra
.54661 .42846 .55278 .43539 .56441 .43164 .55827 .42468 Mtetra
.55827 .42468 .56441 .43164 .57608 .42788 .56998 .42089 Mtetra
.56998 .42089 .57608 .42788 .5878 .4241 .58173 .41708 Mtetra
.58173 .41708 .5878 .4241 .59958 .4203 .59354 .41325 Mtetra
.59354 .41325 .59958 .4203 .6114 .41649 .6054 .40941 Mtetra
.6054 .40941 .6114 .41649 .62327 .41266 .6173 .40555 Mtetra
.6173 .40555 .62327 .41266 .6352 .40882 .62926 .40168 Mtetra
.62926 .40168 .6352 .40882 .64717 .40496 .64127 .39779 Mtetra
.64127 .39779 .64717 .40496 .6592 .40108 .65333 .39388 Mtetra
.65333 .39388 .6592 .40108 .67128 .39719 .66545 .38995 Mtetra
.66545 .38995 .67128 .39719 .6834 .39327 .67761 .38601 Mtetra
.67761 .38601 .6834 .39327 .69559 .38935 .68983 .38205 Mtetra
.68983 .38205 .69559 .38935 .70782 .3854 .7021 .37807 Mtetra
.7021 .37807 .70782 .3854 .72011 .38144 .71442 .37408 Mtetra
.71442 .37408 .72011 .38144 .73245 .37746 .7268 .37007 Mtetra
.7268 .37007 .73245 .37746 .74484 .37347 .73923 .36604 Mtetra
.73923 .36604 .74484 .37347 .75729 .36945 .75172 .362 Mtetra
.75172 .362 .75729 .36945 .76979 .36542 .76426 .35793 Mtetra
.76426 .35793 .76979 .36542 .78235 .36137 .77685 .35385 Mtetra
.77685 .35385 .78235 .36137 .79496 .35731 .78951 .34975 Mtetra
.78951 .34975 .79496 .35731 .80763 .35322 .80221 .34563 Mtetra
.80221 .34563 .80763 .35322 .82035 .34912 .81498 .3415 Mtetra
.81498 .3415 .82035 .34912 .83313 .345 .82779 .33734 Mtetra
.82779 .33734 .83313 .345 .84597 .34086 .84067 .33317 Mtetra
.84067 .33317 .84597 .34086 .85886 .3367 .8536 .32898 Mtetra
.8536 .32898 .85886 .3367 .87181 .33253 .8666 .32477 Mtetra
.8666 .32477 .87181 .33253 .88482 .32833 .87965 .32054 Mtetra
.87965 .32054 .88482 .32833 .89788 .32412 .89275 .31629 Mtetra
.543 .312 .515 r
.28469 .65301 .30203 .50772 .31267 .50427 .29583 .64969 Mtetra
0 0 .161 r
.29583 .64969 .31267 .50427 .32336 .5008 .31656 .49437 Mtetra
.664 .741 .908 r
.31656 .49437 .32336 .5008 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49383 .33812 .48735 Mtetra
.33812 .48735 .34487 .49383 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36656 .48681 .35986 .48027 Mtetra
.35986 .48027 .36656 .48681 .37746 .48327 .3708 .47671 Mtetra
.3708 .47671 .37746 .48327 .38842 .47972 .38178 .47313 Mtetra
.38178 .47313 .38842 .47972 .39942 .47616 .39281 .46954 Mtetra
.39281 .46954 .39942 .47616 .41046 .47258 .40388 .46593 Mtetra
.40388 .46593 .41046 .47258 .42155 .46899 .415 .46231 Mtetra
.415 .46231 .42155 .46899 .43268 .46538 .42616 .45868 Mtetra
.42616 .45868 .43268 .46538 .44386 .46176 .43737 .45503 Mtetra
.43737 .45503 .44386 .46176 .45509 .45812 .44863 .45136 Mtetra
.44863 .45136 .45509 .45812 .46637 .45446 .45993 .44768 Mtetra
.45993 .44768 .46637 .45446 .47769 .4508 .47128 .44398 Mtetra
.47128 .44398 .47769 .4508 .48905 .44711 .48268 .44027 Mtetra
.48268 .44027 .48905 .44711 .50047 .44341 .49413 .43654 Mtetra
.49413 .43654 .50047 .44341 .51193 .4397 .50562 .4328 Mtetra
.50562 .4328 .51193 .4397 .52344 .43597 .51716 .42904 Mtetra
.51716 .42904 .52344 .43597 .535 .43222 .52876 .42526 Mtetra
.52876 .42526 .535 .43222 .54661 .42846 .5404 .42147 Mtetra
.5404 .42147 .54661 .42846 .55827 .42468 .55209 .41767 Mtetra
.55209 .41767 .55827 .42468 .56998 .42089 .56383 .41384 Mtetra
.56383 .41384 .56998 .42089 .58173 .41708 .57562 .41 Mtetra
.57562 .41 .58173 .41708 .59354 .41325 .58746 .40615 Mtetra
.58746 .40615 .59354 .41325 .6054 .40941 .59935 .40227 Mtetra
.59935 .40227 .6054 .40941 .6173 .40555 .61129 .39839 Mtetra
.61129 .39839 .6173 .40555 .62926 .40168 .62328 .39448 Mtetra
.62328 .39448 .62926 .40168 .64127 .39779 .63532 .39056 Mtetra
.63532 .39056 .64127 .39779 .65333 .39388 .64742 .38662 Mtetra
.64742 .38662 .65333 .39388 .66545 .38995 .65957 .38266 Mtetra
.65957 .38266 .66545 .38995 .67761 .38601 .67177 .37869 Mtetra
.67177 .37869 .67761 .38601 .68983 .38205 .68402 .3747 Mtetra
.68402 .3747 .68983 .38205 .7021 .37807 .69633 .37069 Mtetra
.69633 .37069 .7021 .37807 .71442 .37408 .70869 .36666 Mtetra
.70869 .36666 .71442 .37408 .7268 .37007 .72111 .36262 Mtetra
.72111 .36262 .7268 .37007 .73923 .36604 .73358 .35856 Mtetra
.73358 .35856 .73923 .36604 .75172 .362 .7461 .35448 Mtetra
.7461 .35448 .75172 .362 .76426 .35793 .75868 .35038 Mtetra
.75868 .35038 .76426 .35793 .77685 .35385 .77131 .34627 Mtetra
.77131 .34627 .77685 .35385 .78951 .34975 .78401 .34213 Mtetra
.78401 .34213 .78951 .34975 .80221 .34563 .79675 .33798 Mtetra
.79675 .33798 .80221 .34563 .81498 .3415 .80955 .33381 Mtetra
.80955 .33381 .81498 .3415 .82779 .33734 .82241 .32963 Mtetra
.82241 .32963 .82779 .33734 .84067 .33317 .83533 .32542 Mtetra
.83533 .32542 .84067 .33317 .8536 .32898 .84831 .32119 Mtetra
.84831 .32119 .8536 .32898 .8666 .32477 .86134 .31695 Mtetra
.86134 .31695 .8666 .32477 .87965 .32054 .87443 .31268 Mtetra
.87443 .31268 .87965 .32054 .89275 .31629 .88758 .3084 Mtetra
.651 .756 .927 r
.27743 .64688 .28469 .65301 .29583 .64969 .2886 .64354 Mtetra
.2886 .64354 .29583 .64969 .31656 .49437 .29981 .64018 Mtetra
0 0 .161 r
.29981 .64018 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.664 .741 .908 r
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .3708 .47671 .36408 .47009 Mtetra
.36408 .47009 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.37509 .46649 .38178 .47313 .39281 .46954 .38615 .46287 Mtetra
.38615 .46287 .39281 .46954 .40388 .46593 .39725 .45924 Mtetra
.39725 .45924 .40388 .46593 .415 .46231 .4084 .45559 Mtetra
.4084 .45559 .415 .46231 .42616 .45868 .41959 .45193 Mtetra
.41959 .45193 .42616 .45868 .43737 .45503 .43083 .44825 Mtetra
.43083 .44825 .43737 .45503 .44863 .45136 .44211 .44455 Mtetra
.44211 .44455 .44863 .45136 .45993 .44768 .45345 .44084 Mtetra
.45345 .44084 .45993 .44768 .47128 .44398 .46483 .43712 Mtetra
.46483 .43712 .47128 .44398 .48268 .44027 .47626 .43338 Mtetra
.47626 .43338 .48268 .44027 .49413 .43654 .48774 .42962 Mtetra
.48774 .42962 .49413 .43654 .50562 .4328 .49926 .42585 Mtetra
.49926 .42585 .50562 .4328 .51716 .42904 .51084 .42206 Mtetra
.51084 .42206 .51716 .42904 .52876 .42526 .52246 .41825 Mtetra
.52246 .41825 .52876 .42526 .5404 .42147 .53413 .41443 Mtetra
.53413 .41443 .5404 .42147 .55209 .41767 .54585 .4106 Mtetra
.54585 .4106 .55209 .41767 .56383 .41384 .55763 .40674 Mtetra
.55763 .40674 .56383 .41384 .57562 .41 .56945 .40287 Mtetra
.56945 .40287 .57562 .41 .58746 .40615 .58132 .39899 Mtetra
.58132 .39899 .58746 .40615 .59935 .40227 .59325 .39508 Mtetra
.59325 .39508 .59935 .40227 .61129 .39839 .60522 .39116 Mtetra
.60522 .39116 .61129 .39839 .62328 .39448 .61725 .38723 Mtetra
.61725 .38723 .62328 .39448 .63532 .39056 .62933 .38327 Mtetra
.62933 .38327 .63532 .39056 .64742 .38662 .64146 .3793 Mtetra
.64146 .3793 .64742 .38662 .65957 .38266 .65365 .37531 Mtetra
.65365 .37531 .65957 .38266 .67177 .37869 .66588 .37131 Mtetra
.66588 .37131 .67177 .37869 .68402 .3747 .67817 .36728 Mtetra
.67817 .36728 .68402 .3747 .69633 .37069 .69052 .36324 Mtetra
.69052 .36324 .69633 .37069 .70869 .36666 .70292 .35918 Mtetra
.70292 .35918 .70869 .36666 .72111 .36262 .71537 .35511 Mtetra
.71537 .35511 .72111 .36262 .73358 .35856 .72788 .35101 Mtetra
.72788 .35101 .73358 .35856 .7461 .35448 .74044 .3469 Mtetra
.74044 .3469 .7461 .35448 .75868 .35038 .75306 .34277 Mtetra
.75306 .34277 .75868 .35038 .77131 .34627 .76573 .33862 Mtetra
.76573 .33862 .77131 .34627 .78401 .34213 .77846 .33446 Mtetra
.77846 .33446 .78401 .34213 .79675 .33798 .79125 .33027 Mtetra
.79125 .33027 .79675 .33798 .80955 .33381 .80409 .32607 Mtetra
.80409 .32607 .80955 .33381 .82241 .32963 .81699 .32184 Mtetra
.81699 .32184 .82241 .32963 .83533 .32542 .82995 .3176 Mtetra
.82995 .3176 .83533 .32542 .84831 .32119 .84297 .31334 Mtetra
.84297 .31334 .84831 .32119 .86134 .31695 .85604 .30906 Mtetra
.85604 .30906 .86134 .31695 .87443 .31268 .86918 .30476 Mtetra
.86918 .30476 .87443 .31268 .88758 .3084 .88237 .30044 Mtetra
.651 .756 .927 r
.27011 .6407 .27743 .64688 .2886 .64354 .28131 .63734 Mtetra
.28131 .63734 .2886 .64354 .29981 .64018 .29255 .63396 Mtetra
.29255 .63396 .29981 .64018 .3205 .48436 .30384 .63056 Mtetra
.54 .307 .511 r
.30384 .63056 .3205 .48436 .33133 .48082 .31518 .62715 Mtetra
0 0 .169 r
.31518 .62715 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.664 .741 .908 r
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.34633 .46705 .35312 .47368 .36408 .47009 .35732 .46343 Mtetra
.35732 .46343 .36408 .47009 .37509 .46649 .36835 .4598 Mtetra
.36835 .4598 .37509 .46649 .38615 .46287 .37944 .45615 Mtetra
.37944 .45615 .38615 .46287 .39725 .45924 .39057 .45249 Mtetra
.39057 .45249 .39725 .45924 .4084 .45559 .40174 .44881 Mtetra
.40174 .44881 .4084 .45559 .41959 .45193 .41296 .44512 Mtetra
.41296 .44512 .41959 .45193 .43083 .44825 .42423 .44141 Mtetra
.42423 .44141 .43083 .44825 .44211 .44455 .43555 .43769 Mtetra
.43555 .43769 .44211 .44455 .45345 .44084 .44691 .43395 Mtetra
.44691 .43395 .45345 .44084 .46483 .43712 .45833 .4302 Mtetra
.45833 .4302 .46483 .43712 .47626 .43338 .46979 .42643 Mtetra
.46979 .42643 .47626 .43338 .48774 .42962 .48129 .42264 Mtetra
.48129 .42264 .48774 .42962 .49926 .42585 .49285 .41884 Mtetra
.49285 .41884 .49926 .42585 .51084 .42206 .50446 .41502 Mtetra
.50446 .41502 .51084 .42206 .52246 .41825 .51611 .41119 Mtetra
.51611 .41119 .52246 .41825 .53413 .41443 .52782 .40734 Mtetra
.52782 .40734 .53413 .41443 .54585 .4106 .53957 .40347 Mtetra
.53957 .40347 .54585 .4106 .55763 .40674 .55138 .39958 Mtetra
.55138 .39958 .55763 .40674 .56945 .40287 .56323 .39568 Mtetra
.56323 .39568 .56945 .40287 .58132 .39899 .57514 .39177 Mtetra
.57514 .39177 .58132 .39899 .59325 .39508 .5871 .38783 Mtetra
.5871 .38783 .59325 .39508 .60522 .39116 .59911 .38388 Mtetra
.59911 .38388 .60522 .39116 .61725 .38723 .61117 .37991 Mtetra
.61117 .37991 .61725 .38723 .62933 .38327 .62329 .37593 Mtetra
.62329 .37593 .62933 .38327 .64146 .3793 .63545 .37192 Mtetra
.63545 .37192 .64146 .3793 .65365 .37531 .64767 .3679 Mtetra
.64767 .3679 .65365 .37531 .66588 .37131 .65995 .36387 Mtetra
.65995 .36387 .66588 .37131 .67817 .36728 .67228 .35981 Mtetra
.67228 .35981 .67817 .36728 .69052 .36324 .68466 .35574 Mtetra
.68466 .35574 .69052 .36324 .70292 .35918 .69709 .35165 Mtetra
.69709 .35165 .70292 .35918 .71537 .35511 .70958 .34754 Mtetra
.70958 .34754 .71537 .35511 .72788 .35101 .72213 .34341 Mtetra
.72213 .34341 .72788 .35101 .74044 .3469 .73473 .33926 Mtetra
.73473 .33926 .74044 .3469 .75306 .34277 .74739 .3351 Mtetra
.74739 .3351 .75306 .34277 .76573 .33862 .7601 .33092 Mtetra
.7601 .33092 .76573 .33862 .77846 .33446 .77287 .32671 Mtetra
.77287 .32671 .77846 .33446 .79125 .33027 .7857 .32249 Mtetra
.7857 .32249 .79125 .33027 .80409 .32607 .79858 .31826 Mtetra
.79858 .31826 .80409 .32607 .81699 .32184 .81152 .314 Mtetra
.81152 .314 .81699 .32184 .82995 .3176 .82452 .30972 Mtetra
.82452 .30972 .82995 .3176 .84297 .31334 .83758 .30543 Mtetra
.83758 .30543 .84297 .31334 .85604 .30906 .8507 .30111 Mtetra
.8507 .30111 .85604 .30906 .86918 .30476 .86387 .29677 Mtetra
.86387 .29677 .86918 .30476 .88237 .30044 .87711 .29242 Mtetra
.651 .756 .927 r
.26274 .63448 .27011 .6407 .28131 .63734 .27396 .63108 Mtetra
.27396 .63108 .28131 .63734 .29255 .63396 .28523 .62768 Mtetra
.28523 .62768 .29255 .63396 .30384 .63056 .29655 .62425 Mtetra
.29655 .62425 .30384 .63056 .31518 .62715 .30792 .62082 Mtetra
.30792 .62082 .31518 .62715 .33538 .47065 .31934 .61737 Mtetra
0 0 .169 r
.31934 .61737 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.664 .741 .908 r
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45671 Mtetra
.3505 .45671 .35732 .46343 .36835 .4598 .36156 .45306 Mtetra
.36156 .45306 .36835 .4598 .37944 .45615 .37268 .44938 Mtetra
.37268 .44938 .37944 .45615 .39057 .45249 .38383 .44569 Mtetra
.38383 .44569 .39057 .45249 .40174 .44881 .39504 .44199 Mtetra
.39504 .44199 .40174 .44881 .41296 .44512 .40629 .43827 Mtetra
.40629 .43827 .41296 .44512 .42423 .44141 .41759 .43453 Mtetra
.41759 .43453 .42423 .44141 .43555 .43769 .42893 .43078 Mtetra
.42893 .43078 .43555 .43769 .44691 .43395 .44033 .42701 Mtetra
.44033 .42701 .44691 .43395 .45833 .4302 .45177 .42323 Mtetra
.45177 .42323 .45833 .4302 .46979 .42643 .46326 .41943 Mtetra
.46326 .41943 .46979 .42643 .48129 .42264 .4748 .41561 Mtetra
.4748 .41561 .48129 .42264 .49285 .41884 .48639 .41178 Mtetra
.48639 .41178 .49285 .41884 .50446 .41502 .49803 .40793 Mtetra
.49803 .40793 .50446 .41502 .51611 .41119 .50972 .40406 Mtetra
.50972 .40406 .51611 .41119 .52782 .40734 .52145 .40018 Mtetra
.52145 .40018 .52782 .40734 .53957 .40347 .53324 .39628 Mtetra
.53324 .39628 .53957 .40347 .55138 .39958 .54508 .39237 Mtetra
.54508 .39237 .55138 .39958 .56323 .39568 .55697 .38844 Mtetra
.55697 .38844 .56323 .39568 .57514 .39177 .56891 .38449 Mtetra
.56891 .38449 .57514 .39177 .5871 .38783 .5809 .38052 Mtetra
.5809 .38052 .5871 .38783 .59911 .38388 .59295 .37654 Mtetra
.59295 .37654 .59911 .38388 .61117 .37991 .60505 .37254 Mtetra
.60505 .37254 .61117 .37991 .62329 .37593 .6172 .36852 Mtetra
.6172 .36852 .62329 .37593 .63545 .37192 .6294 .36449 Mtetra
.6294 .36449 .63545 .37192 .64767 .3679 .64166 .36043 Mtetra
.64166 .36043 .64767 .3679 .65995 .36387 .65397 .35636 Mtetra
.65397 .35636 .65995 .36387 .67228 .35981 .66633 .35228 Mtetra
.66633 .35228 .67228 .35981 .68466 .35574 .67875 .34817 Mtetra
.67875 .34817 .68466 .35574 .69709 .35165 .69122 .34404 Mtetra
.69122 .34404 .69709 .35165 .70958 .34754 .70375 .3399 Mtetra
.70375 .3399 .70958 .34754 .72213 .34341 .71633 .33574 Mtetra
.71633 .33574 .72213 .34341 .73473 .33926 .72897 .33156 Mtetra
.72897 .33156 .73473 .33926 .74739 .3351 .74167 .32736 Mtetra
.74167 .32736 .74739 .3351 .7601 .33092 .75442 .32315 Mtetra
.75442 .32315 .7601 .33092 .77287 .32671 .76723 .31891 Mtetra
.76723 .31891 .77287 .32671 .7857 .32249 .7801 .31465 Mtetra
.7801 .31465 .7857 .32249 .79858 .31826 .79302 .31038 Mtetra
.79302 .31038 .79858 .31826 .81152 .314 .80601 .30609 Mtetra
.80601 .30609 .81152 .314 .82452 .30972 .81905 .30177 Mtetra
.81905 .30177 .82452 .30972 .83758 .30543 .83215 .29744 Mtetra
.83215 .29744 .83758 .30543 .8507 .30111 .84531 .29309 Mtetra
.84531 .29309 .8507 .30111 .86387 .29677 .85853 .28872 Mtetra
.85853 .28872 .86387 .29677 .87711 .29242 .87181 .28433 Mtetra
.651 .756 .927 r
.2553 .6282 .26274 .63448 .27396 .63108 .26655 .62478 Mtetra
.26655 .62478 .27396 .63108 .28523 .62768 .27786 .62135 Mtetra
.27786 .62135 .28523 .62768 .29655 .62425 .2892 .6179 Mtetra
.2892 .6179 .29655 .62425 .30792 .62082 .3006 .61443 Mtetra
.3006 .61443 .30792 .62082 .31934 .61737 .31205 .61095 Mtetra
.31205 .61095 .31934 .61737 .33948 .46036 .32355 .60746 Mtetra
.537 .303 .508 r
.32355 .60746 .33948 .46036 .3505 .45671 .3351 .60395 Mtetra
.564 .326 .514 r
.3351 .60395 .3505 .45671 .36156 .45306 .34609 .612 Mtetra
0 0 .192 r
.34609 .612 .36156 .45306 .37268 .44938 .36586 .44256 Mtetra
.664 .741 .908 r
.36586 .44256 .37268 .44938 .38383 .44569 .37705 .43884 Mtetra
.37705 .43884 .38383 .44569 .39504 .44199 .38828 .4351 Mtetra
.38828 .4351 .39504 .44199 .40629 .43827 .39956 .43136 Mtetra
.39956 .43136 .40629 .43827 .41759 .43453 .41089 .42759 Mtetra
.41089 .42759 .41759 .43453 .42893 .43078 .42227 .42381 Mtetra
.42227 .42381 .42893 .43078 .44033 .42701 .43369 .42001 Mtetra
.43369 .42001 .44033 .42701 .45177 .42323 .44517 .4162 Mtetra
.44517 .4162 .45177 .42323 .46326 .41943 .45669 .41237 Mtetra
.45669 .41237 .46326 .41943 .4748 .41561 .46826 .40852 Mtetra
.46826 .40852 .4748 .41561 .48639 .41178 .47988 .40466 Mtetra
.47988 .40466 .48639 .41178 .49803 .40793 .49155 .40078 Mtetra
.49155 .40078 .49803 .40793 .50972 .40406 .50327 .39689 Mtetra
.50327 .39689 .50972 .40406 .52145 .40018 .51504 .39297 Mtetra
.51504 .39297 .52145 .40018 .53324 .39628 .52686 .38904 Mtetra
.52686 .38904 .53324 .39628 .54508 .39237 .53873 .3851 Mtetra
.53873 .3851 .54508 .39237 .55697 .38844 .55066 .38114 Mtetra
.55066 .38114 .55697 .38844 .56891 .38449 .56263 .37715 Mtetra
.56263 .37715 .56891 .38449 .5809 .38052 .57466 .37316 Mtetra
.57466 .37316 .5809 .38052 .59295 .37654 .58674 .36914 Mtetra
.58674 .36914 .59295 .37654 .60505 .37254 .59887 .36511 Mtetra
.59887 .36511 .60505 .37254 .6172 .36852 .61106 .36106 Mtetra
.61106 .36106 .6172 .36852 .6294 .36449 .62329 .35699 Mtetra
.62329 .35699 .6294 .36449 .64166 .36043 .63559 .35291 Mtetra
.63559 .35291 .64166 .36043 .65397 .35636 .64793 .3488 Mtetra
.64793 .3488 .65397 .35636 .66633 .35228 .66033 .34468 Mtetra
.66033 .34468 .66633 .35228 .67875 .34817 .67279 .34054 Mtetra
.67279 .34054 .67875 .34817 .69122 .34404 .6853 .33638 Mtetra
.6853 .33638 .69122 .34404 .70375 .3399 .69787 .3322 Mtetra
.69787 .3322 .70375 .3399 .71633 .33574 .71049 .32801 Mtetra
.71049 .32801 .71633 .33574 .72897 .33156 .72317 .3238 Mtetra
.72317 .3238 .72897 .33156 .74167 .32736 .73591 .31956 Mtetra
.73591 .31956 .74167 .32736 .75442 .32315 .7487 .31531 Mtetra
.7487 .31531 .75442 .32315 .76723 .31891 .76155 .31104 Mtetra
.76155 .31104 .76723 .31891 .7801 .31465 .77446 .30675 Mtetra
.77446 .30675 .7801 .31465 .79302 .31038 .78742 .30244 Mtetra
.78742 .30244 .79302 .31038 .80601 .30609 .80045 .29811 Mtetra
.80045 .29811 .80601 .30609 .81905 .30177 .81353 .29376 Mtetra
.81353 .29376 .81905 .30177 .83215 .29744 .82667 .28939 Mtetra
.82667 .28939 .83215 .29744 .84531 .29309 .83988 .285 Mtetra
.83988 .285 .84531 .29309 .85853 .28872 .85314 .2806 Mtetra
.85314 .2806 .85853 .28872 .87181 .28433 .86646 .27617 Mtetra
.651 .756 .927 r
.24781 .62188 .2553 .6282 .26655 .62478 .25909 .61843 Mtetra
.25909 .61843 .26655 .62478 .27786 .62135 .27042 .61497 Mtetra
.27042 .61497 .27786 .62135 .2892 .6179 .2818 .61149 Mtetra
.2818 .61149 .2892 .6179 .3006 .61443 .29323 .608 Mtetra
.29323 .608 .3006 .61443 .31205 .61095 .3047 .60449 Mtetra
.3047 .60449 .31205 .61095 .32355 .60746 .31623 .60097 Mtetra
.31623 .60097 .32355 .60746 .3351 .60395 .32781 .59743 Mtetra
0 .184 .663 r
.32781 .59743 .3351 .60395 .34609 .612 .33881 .60547 Mtetra
.65 .758 .928 r
.33881 .60547 .34609 .612 .36586 .44256 .35053 .60192 Mtetra
.536 .303 .508 r
.35053 .60192 .36586 .44256 .37705 .43884 .3623 .59835 Mtetra
0 0 .199 r
.3623 .59835 .37705 .43884 .38828 .4351 .38147 .42817 Mtetra
.664 .741 .908 r
.38147 .42817 .38828 .4351 .39956 .43136 .39278 .42439 Mtetra
.39278 .42439 .39956 .43136 .41089 .42759 .40414 .4206 Mtetra
.40414 .4206 .41089 .42759 .42227 .42381 .41555 .41679 Mtetra
.41555 .41679 .42227 .42381 .43369 .42001 .427 .41296 Mtetra
.427 .41296 .43369 .42001 .44517 .4162 .43851 .40912 Mtetra
.43851 .40912 .44517 .4162 .45669 .41237 .45006 .40526 Mtetra
.45006 .40526 .45669 .41237 .46826 .40852 .46166 .40138 Mtetra
.46166 .40138 .46826 .40852 .47988 .40466 .47332 .39749 Mtetra
.47332 .39749 .47988 .40466 .49155 .40078 .48502 .39358 Mtetra
.48502 .39358 .49155 .40078 .50327 .39689 .49677 .38965 Mtetra
.49677 .38965 .50327 .39689 .51504 .39297 .50857 .38571 Mtetra
.50857 .38571 .51504 .39297 .52686 .38904 .52043 .38175 Mtetra
.52043 .38175 .52686 .38904 .53873 .3851 .53233 .37777 Mtetra
.53233 .37777 .53873 .3851 .55066 .38114 .54429 .37377 Mtetra
.54429 .37377 .55066 .38114 .56263 .37715 .5563 .36976 Mtetra
.5563 .36976 .56263 .37715 .57466 .37316 .56836 .36573 Mtetra
.56836 .36573 .57466 .37316 .58674 .36914 .58048 .36168 Mtetra
.58048 .36168 .58674 .36914 .59887 .36511 .59265 .35762 Mtetra
.59265 .35762 .59887 .36511 .61106 .36106 .60487 .35354 Mtetra
.60487 .35354 .61106 .36106 .62329 .35699 .61714 .34943 Mtetra
.61714 .34943 .62329 .35699 .63559 .35291 .62947 .34532 Mtetra
.62947 .34532 .63559 .35291 .64793 .3488 .64185 .34118 Mtetra
.64185 .34118 .64793 .3488 .66033 .34468 .65429 .33702 Mtetra
.65429 .33702 .66033 .34468 .67279 .34054 .66679 .33285 Mtetra
.66679 .33285 .67279 .34054 .6853 .33638 .67933 .32866 Mtetra
.67933 .32866 .6853 .33638 .69787 .3322 .69194 .32444 Mtetra
.69194 .32444 .69787 .3322 .71049 .32801 .7046 .32021 Mtetra
.7046 .32021 .71049 .32801 .72317 .3238 .71732 .31597 Mtetra
.71732 .31597 .72317 .3238 .73591 .31956 .73009 .3117 Mtetra
.73009 .3117 .73591 .31956 .7487 .31531 .74293 .30741 Mtetra
.74293 .30741 .7487 .31531 .76155 .31104 .75582 .3031 Mtetra
.75582 .3031 .76155 .31104 .77446 .30675 .76877 .29878 Mtetra
.76877 .29878 .77446 .30675 .78742 .30244 .78177 .29443 Mtetra
.78177 .29443 .78742 .30244 .80045 .29811 .79484 .29007 Mtetra
.79484 .29007 .80045 .29811 .81353 .29376 .80797 .28568 Mtetra
.80797 .28568 .81353 .29376 .82667 .28939 .82115 .28128 Mtetra
.82115 .28128 .82667 .28939 .83988 .285 .8344 .27685 Mtetra
.8344 .27685 .83988 .285 .85314 .2806 .8477 .2724 Mtetra
.8477 .2724 .85314 .2806 .86646 .27617 .86107 .26794 Mtetra
.651 .756 .927 r
.24026 .6155 .24781 .62188 .25909 .61843 .25157 .61203 Mtetra
.25157 .61203 .25909 .61843 .27042 .61497 .26292 .60854 Mtetra
.26292 .60854 .27042 .61497 .2818 .61149 .27433 .60503 Mtetra
.27433 .60503 .2818 .61149 .29323 .608 .28579 .60151 Mtetra
.28579 .60151 .29323 .608 .3047 .60449 .2973 .59798 Mtetra
.2973 .59798 .3047 .60449 .31623 .60097 .30886 .59443 Mtetra
.30886 .59443 .31623 .60097 .32781 .59743 .32047 .59086 Mtetra
.32047 .59086 .32781 .59743 .33881 .60547 .33213 .58728 Mtetra
.31 .359 .751 r
.33213 .58728 .33881 .60547 .35053 .60192 .34322 .59531 Mtetra
.65 .758 .928 r
.34322 .59531 .35053 .60192 .3623 .59835 .35502 .59171 Mtetra
.35502 .59171 .3623 .59835 .38147 .42817 .36688 .58809 Mtetra
.535 .3 .506 r
.36688 .58809 .38147 .42817 .39278 .42439 .37879 .58446 Mtetra
.37879 .58446 .39278 .42439 .40414 .4206 .39075 .58081 Mtetra
0 0 .215 r
.39075 .58081 .40414 .4206 .41555 .41679 .40878 .40971 Mtetra
.664 .741 .908 r
.40878 .40971 .41555 .41679 .427 .41296 .42026 .40585 Mtetra
.42026 .40585 .427 .41296 .43851 .40912 .4318 .40198 Mtetra
.4318 .40198 .43851 .40912 .45006 .40526 .44338 .39809 Mtetra
.44338 .39809 .45006 .40526 .46166 .40138 .45502 .39418 Mtetra
.45502 .39418 .46166 .40138 .47332 .39749 .4667 .39025 Mtetra
.4667 .39025 .47332 .39749 .48502 .39358 .47843 .38631 Mtetra
.47843 .38631 .48502 .39358 .49677 .38965 .49022 .38236 Mtetra
.49022 .38236 .49677 .38965 .50857 .38571 .50206 .37838 Mtetra
.50206 .37838 .50857 .38571 .52043 .38175 .51394 .37439 Mtetra
.51394 .37439 .52043 .38175 .53233 .37777 .52588 .37038 Mtetra
.52588 .37038 .53233 .37777 .54429 .37377 .53788 .36635 Mtetra
.53788 .36635 .54429 .37377 .5563 .36976 .54992 .36231 Mtetra
.54992 .36231 .5563 .36976 .56836 .36573 .56202 .35825 Mtetra
.56202 .35825 .56836 .36573 .58048 .36168 .57417 .35416 Mtetra
.57417 .35416 .58048 .36168 .59265 .35762 .58637 .35007 Mtetra
.58637 .35007 .59265 .35762 .60487 .35354 .59863 .34595 Mtetra
.59863 .34595 .60487 .35354 .61714 .34943 .61094 .34182 Mtetra
.61094 .34182 .61714 .34943 .62947 .34532 .6233 .33766 Mtetra
.6233 .33766 .62947 .34532 .64185 .34118 .63572 .33349 Mtetra
.63572 .33349 .64185 .34118 .65429 .33702 .6482 .3293 Mtetra
.6482 .3293 .65429 .33702 .66679 .33285 .66073 .32509 Mtetra
.66073 .32509 .66679 .33285 .67933 .32866 .67332 .32087 Mtetra
.67332 .32087 .67933 .32866 .69194 .32444 .68596 .31662 Mtetra
.68596 .31662 .69194 .32444 .7046 .32021 .69866 .31236 Mtetra
.69866 .31236 .7046 .32021 .71732 .31597 .71142 .30807 Mtetra
.71142 .30807 .71732 .31597 .73009 .3117 .72423 .30377 Mtetra
.72423 .30377 .73009 .3117 .74293 .30741 .73711 .29944 Mtetra
.73711 .29944 .74293 .30741 .75582 .3031 .75004 .2951 Mtetra
.75004 .2951 .75582 .3031 .76877 .29878 .76303 .29074 Mtetra
.76303 .29074 .76877 .29878 .78177 .29443 .77608 .28636 Mtetra
.77608 .28636 .78177 .29443 .79484 .29007 .78919 .28195 Mtetra
.78919 .28195 .79484 .29007 .80797 .28568 .80235 .27753 Mtetra
.80235 .27753 .80797 .28568 .82115 .28128 .81558 .27309 Mtetra
.81558 .27309 .82115 .28128 .8344 .27685 .82887 .26863 Mtetra
.82887 .26863 .8344 .27685 .8477 .2724 .84222 .26414 Mtetra
.84222 .26414 .8477 .2724 .86107 .26794 .85563 .25964 Mtetra
0 0 .496 r
.23555 .57492 .24026 .6155 .25157 .61203 .24398 .60557 Mtetra
.651 .756 .927 r
.24398 .60557 .25157 .61203 .26292 .60854 .25537 .60206 Mtetra
.25537 .60206 .26292 .60854 .27433 .60503 .26681 .59852 Mtetra
.26681 .59852 .27433 .60503 .28579 .60151 .27829 .59497 Mtetra
.27829 .59497 .28579 .60151 .2973 .59798 .28983 .59141 Mtetra
.28983 .59141 .2973 .59798 .30886 .59443 .30142 .58783 Mtetra
.30142 .58783 .30886 .59443 .32047 .59086 .31306 .58423 Mtetra
.31306 .58423 .32047 .59086 .33213 .58728 .32475 .58062 Mtetra
0 .192 .672 r
.32475 .58062 .33213 .58728 .34322 .59531 .33585 .58865 Mtetra
.65 .758 .928 r
.33585 .58865 .34322 .59531 .35502 .59171 .34769 .58502 Mtetra
.34769 .58502 .35502 .59171 .36688 .58809 .35957 .58138 Mtetra
.35957 .58138 .36688 .58809 .37879 .58446 .37151 .57771 Mtetra
.37151 .57771 .37879 .58446 .39075 .58081 .38351 .57403 Mtetra
.38351 .57403 .39075 .58081 .40878 .40971 .39556 .57034 Mtetra
.533 .298 .504 r
.39556 .57034 .40878 .40971 .42026 .40585 .40766 .56663 Mtetra
0 0 .222 r
.40766 .56663 .42026 .40585 .4318 .40198 .42503 .39478 Mtetra
.664 .741 .908 r
.42503 .39478 .4318 .40198 .44338 .39809 .43665 .39086 Mtetra
.43665 .39086 .44338 .39809 .45502 .39418 .44832 .38692 Mtetra
.44832 .38692 .45502 .39418 .4667 .39025 .46003 .38297 Mtetra
.46003 .38297 .4667 .39025 .47843 .38631 .4718 .37899 Mtetra
.4718 .37899 .47843 .38631 .49022 .38236 .48362 .375 Mtetra
.48362 .375 .49022 .38236 .50206 .37838 .49549 .371 Mtetra
.49549 .371 .50206 .37838 .51394 .37439 .50741 .36697 Mtetra
.50741 .36697 .51394 .37439 .52588 .37038 .51938 .36293 Mtetra
.51938 .36293 .52588 .37038 .53788 .36635 .53141 .35887 Mtetra
.961 .635 .341 r
.53141 .35887 .53788 .36635 .54992 .36231 .54407 .45458 Mtetra
0 0 .25 r
.54407 .45458 .54992 .36231 .56202 .35825 .55562 .3507 Mtetra
.664 .741 .908 r
.55562 .3507 .56202 .35825 .57417 .35416 .5678 .34658 Mtetra
.5678 .34658 .57417 .35416 .58637 .35007 .58004 .34245 Mtetra
.58004 .34245 .58637 .35007 .59863 .34595 .59233 .3383 Mtetra
.59233 .3383 .59863 .34595 .61094 .34182 .60468 .33414 Mtetra
.60468 .33414 .61094 .34182 .6233 .33766 .61708 .32995 Mtetra
.61708 .32995 .6233 .33766 .63572 .33349 .62954 .32574 Mtetra
.62954 .32574 .63572 .33349 .6482 .3293 .64206 .32152 Mtetra
.64206 .32152 .6482 .3293 .66073 .32509 .65462 .31728 Mtetra
.65462 .31728 .66073 .32509 .67332 .32087 .66725 .31301 Mtetra
.66725 .31301 .67332 .32087 .68596 .31662 .67993 .30873 Mtetra
.67993 .30873 .68596 .31662 .69866 .31236 .69267 .30443 Mtetra
.69267 .30443 .69866 .31236 .71142 .30807 .70547 .30011 Mtetra
.70547 .30011 .71142 .30807 .72423 .30377 .71832 .29577 Mtetra
.71832 .29577 .72423 .30377 .73711 .29944 .73124 .29141 Mtetra
.73124 .29141 .73711 .29944 .75004 .2951 .74421 .28703 Mtetra
.74421 .28703 .75004 .2951 .76303 .29074 .75724 .28263 Mtetra
.75724 .28263 .76303 .29074 .77608 .28636 .77033 .27821 Mtetra
.77033 .27821 .77608 .28636 .78919 .28195 .78348 .27377 Mtetra
.78348 .27377 .78919 .28195 .80235 .27753 .79669 .26932 Mtetra
.79669 .26932 .80235 .27753 .81558 .27309 .80997 .26483 Mtetra
.80997 .26483 .81558 .27309 .82887 .26863 .8233 .26033 Mtetra
.8233 .26033 .82887 .26863 .84222 .26414 .83669 .25581 Mtetra
.83669 .25581 .84222 .26414 .85563 .25964 .85015 .25127 Mtetra
.927 .551 .272 r
.22796 .56837 .23555 .57492 .24398 .60557 .23633 .59907 Mtetra
.651 .756 .927 r
.23633 .59907 .24398 .60557 .25537 .60206 .24775 .59552 Mtetra
.24775 .59552 .25537 .60206 .26681 .59852 .25922 .59196 Mtetra
.25922 .59196 .26681 .59852 .27829 .59497 .27074 .58838 Mtetra
.27074 .58838 .27829 .59497 .28983 .59141 .28231 .58479 Mtetra
.28231 .58479 .28983 .59141 .30142 .58783 .29393 .58118 Mtetra
.29393 .58118 .30142 .58783 .31306 .58423 .3056 .57755 Mtetra
.3056 .57755 .31306 .58423 .32475 .58062 .31732 .57391 Mtetra
.31732 .57391 .32475 .58062 .33585 .58865 .32909 .57025 Mtetra
.307 .358 .751 r
.32909 .57025 .33585 .58865 .34769 .58502 .34029 .57828 Mtetra
.65 .758 .928 r
.34029 .57828 .34769 .58502 .35957 .58138 .35221 .5746 Mtetra
.35221 .5746 .35957 .58138 .37151 .57771 .36418 .57091 Mtetra
.36418 .57091 .37151 .57771 .38351 .57403 .37621 .5672 Mtetra
.37621 .5672 .38351 .57403 .39556 .57034 .38829 .56347 Mtetra
.38829 .56347 .39556 .57034 .40766 .56663 .40043 .55973 Mtetra
.40043 .55973 .40766 .56663 .42503 .39478 .41262 .55597 Mtetra
.531 .295 .503 r
.41262 .55597 .42503 .39478 .43665 .39086 .42487 .55219 Mtetra
.315 .12 .449 r
.42487 .55219 .43665 .39086 .44832 .38692 .43898 .47879 Mtetra
.521 .273 .48 r
.43898 .47879 .44832 .38692 .46003 .38297 .45109 .4749 Mtetra
.45109 .4749 .46003 .38297 .4718 .37899 .46325 .47099 Mtetra
.46325 .47099 .4718 .37899 .48362 .375 .47547 .46707 Mtetra
.47547 .46707 .48362 .375 .49549 .371 .48774 .46313 Mtetra
.48774 .46313 .49549 .371 .50741 .36697 .50007 .45917 Mtetra
.50007 .45917 .50741 .36697 .51938 .36293 .51245 .45519 Mtetra
.51245 .45519 .51938 .36293 .53141 .35887 .52489 .4512 Mtetra
.52489 .4512 .53141 .35887 .54407 .45458 .53738 .44718 Mtetra
.656 .751 .92 r
.53738 .44718 .54407 .45458 .55562 .3507 .54993 .44315 Mtetra
.521 .273 .48 r
.54993 .44315 .55562 .3507 .5678 .34658 .56254 .4391 Mtetra
0 0 .257 r
.56254 .4391 .5678 .34658 .58004 .34245 .57366 .33478 Mtetra
.664 .741 .908 r
.57366 .33478 .58004 .34245 .59233 .3383 .58599 .33059 Mtetra
.58599 .33059 .59233 .3383 .60468 .33414 .59838 .32639 Mtetra
.59838 .32639 .60468 .33414 .61708 .32995 .61082 .32217 Mtetra
.61082 .32217 .61708 .32995 .62954 .32574 .62331 .31793 Mtetra
.62331 .31793 .62954 .32574 .64206 .32152 .63586 .31367 Mtetra
.63586 .31367 .64206 .32152 .65462 .31728 .64847 .30939 Mtetra
.64847 .30939 .65462 .31728 .66725 .31301 .66113 .30509 Mtetra
.66113 .30509 .66725 .31301 .67993 .30873 .67385 .30078 Mtetra
.67385 .30078 .67993 .30873 .69267 .30443 .68663 .29644 Mtetra
.68663 .29644 .69267 .30443 .70547 .30011 .69947 .29208 Mtetra
.69947 .29208 .70547 .30011 .71832 .29577 .71237 .28771 Mtetra
.71237 .28771 .71832 .29577 .73124 .29141 .72532 .28331 Mtetra
.72532 .28331 .73124 .29141 .74421 .28703 .73833 .2789 Mtetra
.73833 .2789 .74421 .28703 .75724 .28263 .75141 .27446 Mtetra
.75141 .27446 .75724 .28263 .77033 .27821 .76454 .27 Mtetra
.76454 .27 .77033 .27821 .78348 .27377 .77773 .26553 Mtetra
.77773 .26553 .78348 .27377 .79669 .26932 .79099 .26103 Mtetra
.79099 .26103 .79669 .26932 .80997 .26483 .8043 .25651 Mtetra
.8043 .25651 .80997 .26483 .8233 .26033 .81768 .25197 Mtetra
.81768 .25197 .8233 .26033 .83669 .25581 .83112 .24741 Mtetra
.83112 .24741 .83669 .25581 .85015 .25127 .84462 .24283 Mtetra
.654 .753 .922 r
.22032 .56177 .22796 .56837 .23633 .59907 .23161 .55817 Mtetra
0 0 .492 r
.23161 .55817 .23633 .59907 .24775 .59552 .24007 .58893 Mtetra
.651 .756 .927 r
.24007 .58893 .24775 .59552 .25922 .59196 .25157 .58534 Mtetra
.25157 .58534 .25922 .59196 .27074 .58838 .26312 .58173 Mtetra
.26312 .58173 .27074 .58838 .28231 .58479 .27472 .57811 Mtetra
.27472 .57811 .28231 .58479 .29393 .58118 .28637 .57447 Mtetra
.28637 .57447 .29393 .58118 .3056 .57755 .29807 .57082 Mtetra
.29807 .57082 .3056 .57755 .31732 .57391 .30982 .56715 Mtetra
.30982 .56715 .31732 .57391 .32909 .57025 .32163 .56346 Mtetra
0 .199 .68 r
.32163 .56346 .32909 .57025 .34029 .57828 .33283 .57148 Mtetra
.65 .758 .928 r
.33283 .57148 .34029 .57828 .35221 .5746 .34478 .56777 Mtetra
.34478 .56777 .35221 .5746 .36418 .57091 .35679 .56405 Mtetra
.35679 .56405 .36418 .57091 .37621 .5672 .36885 .5603 Mtetra
.36885 .5603 .37621 .5672 .38829 .56347 .38097 .55655 Mtetra
.38097 .55655 .38829 .56347 .40043 .55973 .39314 .55277 Mtetra
.39314 .55277 .40043 .55973 .41262 .55597 .40536 .54898 Mtetra
.40536 .54898 .41262 .55597 .42487 .55219 .41764 .54517 Mtetra
.945 .729 .579 r
.41764 .54517 .42487 .55219 .43898 .47879 .43195 .47159 Mtetra
.656 .751 .92 r
.43195 .47159 .43898 .47879 .45109 .4749 .44409 .46767 Mtetra
.44409 .46767 .45109 .4749 .46325 .47099 .45629 .46373 Mtetra
.45629 .46373 .46325 .47099 .47547 .46707 .46854 .45978 Mtetra
.46854 .45978 .47547 .46707 .48774 .46313 .48085 .4558 Mtetra
.48085 .4558 .48774 .46313 .50007 .45917 .49321 .45181 Mtetra
.49321 .45181 .50007 .45917 .51245 .45519 .50563 .4478 Mtetra
.50563 .4478 .51245 .45519 .52489 .4512 .51811 .44377 Mtetra
.51811 .44377 .52489 .4512 .53738 .44718 .53064 .43972 Mtetra
.53064 .43972 .53738 .44718 .54993 .44315 .54323 .43566 Mtetra
.54323 .43566 .54993 .44315 .56254 .4391 .55588 .43157 Mtetra
.55588 .43157 .56254 .4391 .57366 .33478 .56858 .42747 Mtetra
0 0 .257 r
.56858 .42747 .57366 .33478 .58599 .33059 .5796 .32282 Mtetra
.664 .741 .908 r
.5796 .32282 .58599 .33059 .59838 .32639 .59202 .31858 Mtetra
.59202 .31858 .59838 .32639 .61082 .32217 .60449 .31433 Mtetra
.60449 .31433 .61082 .32217 .62331 .31793 .61703 .31005 Mtetra
.61703 .31005 .62331 .31793 .63586 .31367 .62962 .30576 Mtetra
.62962 .30576 .63586 .31367 .64847 .30939 .64226 .30144 Mtetra
.64226 .30144 .64847 .30939 .66113 .30509 .65497 .29711 Mtetra
.65497 .29711 .66113 .30509 .67385 .30078 .66773 .29276 Mtetra
.66773 .29276 .67385 .30078 .68663 .29644 .68054 .28838 Mtetra
.68054 .28838 .68663 .29644 .69947 .29208 .69342 .28399 Mtetra
.69342 .28399 .69947 .29208 .71237 .28771 .70636 .27958 Mtetra
.70636 .27958 .71237 .28771 .72532 .28331 .71935 .27514 Mtetra
.71935 .27514 .72532 .28331 .73833 .2789 .73241 .27069 Mtetra
.73241 .27069 .73833 .2789 .75141 .27446 .74552 .26622 Mtetra
.74552 .26622 .75141 .27446 .76454 .27 .7587 .26172 Mtetra
.7587 .26172 .76454 .27 .77773 .26553 .77193 .25721 Mtetra
.77193 .25721 .77773 .26553 .79099 .26103 .78523 .25267 Mtetra
.78523 .25267 .79099 .26103 .8043 .25651 .79859 .24811 Mtetra
.79859 .24811 .8043 .25651 .81768 .25197 .81201 .24353 Mtetra
.81201 .24353 .81768 .25197 .83112 .24741 .82549 .23893 Mtetra
.82549 .23893 .83112 .24741 .84462 .24283 .83904 .23431 Mtetra
.654 .753 .922 r
.21261 .55512 .22032 .56177 .23161 .55817 .22392 .55149 Mtetra
.926 .549 .266 r
.22392 .55149 .23161 .55817 .24007 .58893 .23233 .58229 Mtetra
.651 .756 .927 r
.23233 .58229 .24007 .58893 .25157 .58534 .24386 .57867 Mtetra
.24386 .57867 .25157 .58534 .26312 .58173 .25544 .57503 Mtetra
.25544 .57503 .26312 .58173 .27472 .57811 .26707 .57138 Mtetra
.26707 .57138 .27472 .57811 .28637 .57447 .27875 .56771 Mtetra
.27875 .56771 .28637 .57447 .29807 .57082 .29048 .56403 Mtetra
.29048 .56403 .29807 .57082 .30982 .56715 .30227 .56033 Mtetra
.30227 .56033 .30982 .56715 .32163 .56346 .31411 .55661 Mtetra
.31411 .55661 .32163 .56346 .33283 .57148 .326 .55287 Mtetra
.304 .356 .751 r
.326 .55287 .33283 .57148 .34478 .56777 .33729 .56088 Mtetra
.65 .758 .928 r
.33729 .56088 .34478 .56777 .35679 .56405 .34933 .55713 Mtetra
.34933 .55713 .35679 .56405 .36885 .5603 .36143 .55335 Mtetra
.36143 .55335 .36885 .5603 .38097 .55655 .37358 .54956 Mtetra
.37358 .54956 .38097 .55655 .39314 .55277 .38578 .54576 Mtetra
.38578 .54576 .39314 .55277 .40536 .54898 .39804 .54193 Mtetra
.39804 .54193 .40536 .54898 .41764 .54517 .41036 .53809 Mtetra
.41036 .53809 .41764 .54517 .43195 .47159 .42274 .53423 Mtetra
0 0 .108 r
.42274 .53423 .43195 .47159 .44409 .46767 .43704 .46039 Mtetra
.656 .751 .92 r
.43704 .46039 .44409 .46767 .45629 .46373 .44927 .45642 Mtetra
.44927 .45642 .45629 .46373 .46854 .45978 .46156 .45243 Mtetra
.46156 .45243 .46854 .45978 .48085 .4558 .4739 .44842 Mtetra
.4739 .44842 .48085 .4558 .49321 .45181 .4863 .44439 Mtetra
.4863 .44439 .49321 .45181 .50563 .4478 .49875 .44035 Mtetra
.49875 .44035 .50563 .4478 .51811 .44377 .51127 .43629 Mtetra
.51127 .43629 .51811 .44377 .53064 .43972 .52384 .4322 Mtetra
.52384 .4322 .53064 .43972 .54323 .43566 .53646 .4281 Mtetra
.53646 .4281 .54323 .43566 .55588 .43157 .54915 .42398 Mtetra
.54915 .42398 .55588 .43157 .56858 .42747 .56189 .41985 Mtetra
.56189 .41985 .56858 .42747 .5796 .32282 .5747 .41569 Mtetra
0 0 .257 r
.5747 .41569 .5796 .32282 .59202 .31858 .58561 .31071 Mtetra
.664 .741 .908 r
.58561 .31071 .59202 .31858 .60449 .31433 .59812 .30642 Mtetra
.59812 .30642 .60449 .31433 .61703 .31005 .61069 .30211 Mtetra
.61069 .30211 .61703 .31005 .62962 .30576 .62332 .29778 Mtetra
.62332 .29778 .62962 .30576 .64226 .30144 .636 .29343 Mtetra
.636 .29343 .64226 .30144 .65497 .29711 .64874 .28906 Mtetra
.64874 .28906 .65497 .29711 .66773 .29276 .66155 .28467 Mtetra
.66155 .28467 .66773 .29276 .68054 .28838 .6744 .28026 Mtetra
.6744 .28026 .68054 .28838 .69342 .28399 .68732 .27583 Mtetra
.68732 .27583 .69342 .28399 .70636 .27958 .7003 .27138 Mtetra
.7003 .27138 .70636 .27958 .71935 .27514 .71333 .26691 Mtetra
.71333 .26691 .71935 .27514 .73241 .27069 .72643 .26241 Mtetra
.72643 .26241 .73241 .27069 .74552 .26622 .73959 .2579 Mtetra
.73959 .2579 .74552 .26622 .7587 .26172 .7528 .25337 Mtetra
.7528 .25337 .7587 .26172 .77193 .25721 .76608 .24881 Mtetra
.76608 .24881 .77193 .25721 .78523 .25267 .77942 .24424 Mtetra
.77942 .24424 .78523 .25267 .79859 .24811 .79283 .23964 Mtetra
.79283 .23964 .79859 .24811 .81201 .24353 .80629 .23502 Mtetra
.80629 .23502 .81201 .24353 .82549 .23893 .81982 .23039 Mtetra
.81982 .23039 .82549 .23893 .83904 .23431 .83341 .22572 Mtetra
.654 .753 .922 r
.20484 .54841 .21261 .55512 .22392 .55149 .21618 .54475 Mtetra
.21618 .54475 .22392 .55149 .23233 .58229 .22758 .54108 Mtetra
0 0 .488 r
.22758 .54108 .23233 .58229 .24386 .57867 .23608 .57194 Mtetra
.651 .756 .927 r
.23608 .57194 .24386 .57867 .25544 .57503 .24769 .56828 Mtetra
.24769 .56828 .25544 .57503 .26707 .57138 .25935 .5646 Mtetra
.25935 .5646 .26707 .57138 .27875 .56771 .27106 .5609 Mtetra
.27106 .5609 .27875 .56771 .29048 .56403 .28283 .55718 Mtetra
.28283 .55718 .29048 .56403 .30227 .56033 .29465 .55345 Mtetra
.29465 .55345 .30227 .56033 .31411 .55661 .30652 .5497 Mtetra
.30652 .5497 .31411 .55661 .326 .55287 .31844 .54593 Mtetra
0 .207 .688 r
.31844 .54593 .326 .55287 .33729 .56088 .32974 .55393 Mtetra
.65 .758 .928 r
.32974 .55393 .33729 .56088 .34933 .55713 .34181 .55015 Mtetra
.34181 .55015 .34933 .55713 .36143 .55335 .35394 .54634 Mtetra
.35394 .54634 .36143 .55335 .37358 .54956 .36613 .54252 Mtetra
.36613 .54252 .37358 .54956 .38578 .54576 .37837 .53868 Mtetra
.37837 .53868 .38578 .54576 .39804 .54193 .39066 .53483 Mtetra
.39066 .53483 .39804 .54193 .41036 .53809 .40302 .53095 Mtetra
.40302 .53095 .41036 .53809 .42274 .53423 .41543 .52706 Mtetra
.946 .729 .577 r
.41543 .52706 .42274 .53423 .43704 .46039 .42993 .45304 Mtetra
.656 .751 .92 r
.42993 .45304 .43704 .46039 .44927 .45642 .44219 .44904 Mtetra
.44219 .44904 .44927 .45642 .46156 .45243 .45452 .44501 Mtetra
.45452 .44501 .46156 .45243 .4739 .44842 .46689 .44097 Mtetra
.46689 .44097 .4739 .44842 .4863 .44439 .47933 .43691 Mtetra
.47933 .43691 .4863 .44439 .49875 .44035 .49182 .43283 Mtetra
.49182 .43283 .49875 .44035 .51127 .43629 .50437 .42874 Mtetra
.50437 .42874 .51127 .43629 .52384 .4322 .51698 .42462 Mtetra
.51698 .42462 .52384 .4322 .53646 .4281 .52964 .42048 Mtetra
.52964 .42048 .53646 .4281 .54915 .42398 .54237 .41633 Mtetra
.54237 .41633 .54915 .42398 .56189 .41985 .55515 .41216 Mtetra
.55515 .41216 .56189 .41985 .5747 .41569 .56799 .40796 Mtetra
.56799 .40796 .5747 .41569 .58561 .31071 .58089 .40375 Mtetra
0 0 .257 r
.58089 .40375 .58561 .31071 .59812 .30642 .59169 .29844 Mtetra
.664 .741 .908 r
.59169 .29844 .59812 .30642 .61069 .30211 .6043 .2941 Mtetra
.6043 .2941 .61069 .30211 .62332 .29778 .61697 .28973 Mtetra
.61697 .28973 .62332 .29778 .636 .29343 .62969 .28534 Mtetra
.62969 .28534 .636 .29343 .64874 .28906 .64247 .28094 Mtetra
.64247 .28094 .64874 .28906 .66155 .28467 .65531 .27651 Mtetra
.65531 .27651 .66155 .28467 .6744 .28026 .66821 .27206 Mtetra
.66821 .27206 .6744 .28026 .68732 .27583 .68117 .26759 Mtetra
.68117 .26759 .68732 .27583 .7003 .27138 .69419 .26311 Mtetra
.69419 .26311 .7003 .27138 .71333 .26691 .70726 .2586 Mtetra
.70726 .2586 .71333 .26691 .72643 .26241 .7204 .25407 Mtetra
.7204 .25407 .72643 .26241 .73959 .2579 .7336 .24952 Mtetra
.7336 .24952 .73959 .2579 .7528 .25337 .74686 .24494 Mtetra
.74686 .24494 .7528 .25337 .76608 .24881 .76018 .24035 Mtetra
.76018 .24035 .76608 .24881 .77942 .24424 .77357 .23574 Mtetra
.77357 .23574 .77942 .24424 .79283 .23964 .78702 .2311 Mtetra
.78702 .2311 .79283 .23964 .80629 .23502 .80053 .22644 Mtetra
.80053 .22644 .80629 .23502 .81982 .23039 .8141 .22176 Mtetra
.8141 .22176 .81982 .23039 .83341 .22572 .82774 .21706 Mtetra
.654 .753 .922 r
.197 .54164 .20484 .54841 .21618 .54475 .20838 .53796 Mtetra
.20838 .53796 .21618 .54475 .22758 .54108 .2198 .53426 Mtetra
.2198 .53426 .22758 .54108 .23608 .57194 .23128 .53054 Mtetra
0 0 .488 r
.23128 .53054 .23608 .57194 .24769 .56828 .23988 .56147 Mtetra
.651 .756 .927 r
.23988 .56147 .24769 .56828 .25935 .5646 .25157 .55775 Mtetra
.25157 .55775 .25935 .5646 .27106 .5609 .26332 .55402 Mtetra
.26332 .55402 .27106 .5609 .28283 .55718 .27511 .55028 Mtetra
.27511 .55028 .28283 .55718 .29465 .55345 .28696 .54651 Mtetra
.28696 .54651 .29465 .55345 .30652 .5497 .29887 .54273 Mtetra
.29887 .54273 .30652 .5497 .31844 .54593 .31082 .53894 Mtetra
.31082 .53894 .31844 .54593 .32974 .55393 .32284 .53512 Mtetra
.301 .354 .751 r
.32284 .53512 .32974 .55393 .34181 .55015 .33423 .54311 Mtetra
.65 .758 .928 r
.33423 .54311 .34181 .55015 .35394 .54634 .3464 .53928 Mtetra
.3464 .53928 .35394 .54634 .36613 .54252 .35861 .53542 Mtetra
.35861 .53542 .36613 .54252 .37837 .53868 .37089 .53155 Mtetra
.37089 .53155 .37837 .53868 .39066 .53483 .38322 .52766 Mtetra
.38322 .52766 .39066 .53483 .40302 .53095 .39561 .52375 Mtetra
.39561 .52375 .40302 .53095 .41543 .52706 .40805 .51983 Mtetra
.40805 .51983 .41543 .52706 .42993 .45304 .42056 .51588 Mtetra
0 0 .099 r
.42056 .51588 .42993 .45304 .44219 .44904 .43506 .44159 Mtetra
.656 .751 .92 r
.43506 .44159 .44219 .44904 .45452 .44501 .44741 .43754 Mtetra
.44741 .43754 .45452 .44501 .46689 .44097 .45983 .43346 Mtetra
.45983 .43346 .46689 .44097 .47933 .43691 .4723 .42937 Mtetra
.4723 .42937 .47933 .43691 .49182 .43283 .48483 .42525 Mtetra
.48483 .42525 .49182 .43283 .50437 .42874 .49742 .42112 Mtetra
.49742 .42112 .50437 .42874 .51698 .42462 .51006 .41697 Mtetra
.51006 .41697 .51698 .42462 .52964 .42048 .52276 .4128 Mtetra
.52276 .4128 .52964 .42048 .54237 .41633 .53553 .40861 Mtetra
.53553 .40861 .54237 .41633 .55515 .41216 .54835 .4044 Mtetra
.54835 .4044 .55515 .41216 .56799 .40796 .56123 .40017 Mtetra
.56123 .40017 .56799 .40796 .58089 .40375 .57417 .39592 Mtetra
.57417 .39592 .58089 .40375 .59169 .29844 .58717 .39165 Mtetra
0 0 .257 r
.58717 .39165 .59169 .29844 .6043 .2941 .59786 .28602 Mtetra
.664 .741 .908 r
.59786 .28602 .6043 .2941 .61697 .28973 .61056 .28162 Mtetra
.61056 .28162 .61697 .28973 .62969 .28534 .62333 .27719 Mtetra
.62333 .27719 .62969 .28534 .64247 .28094 .63615 .27275 Mtetra
.63615 .27275 .64247 .28094 .65531 .27651 .64903 .26828 Mtetra
.64903 .26828 .65531 .27651 .66821 .27206 .66197 .2638 Mtetra
.66197 .2638 .66821 .27206 .68117 .26759 .67496 .25929 Mtetra
.67496 .25929 .68117 .26759 .69419 .26311 .68802 .25477 Mtetra
.68802 .25477 .69419 .26311 .70726 .2586 .70114 .25022 Mtetra
.70114 .25022 .70726 .2586 .7204 .25407 .71432 .24565 Mtetra
.71432 .24565 .7204 .25407 .7336 .24952 .72756 .24106 Mtetra
.72756 .24106 .7336 .24952 .74686 .24494 .74087 .23645 Mtetra
.74087 .23645 .74686 .24494 .76018 .24035 .75423 .23182 Mtetra
.75423 .23182 .76018 .24035 .77357 .23574 .76766 .22716 Mtetra
.76766 .22716 .77357 .23574 .78702 .2311 .78115 .22248 Mtetra
.78115 .22248 .78702 .2311 .80053 .22644 .79471 .21779 Mtetra
.79471 .21779 .80053 .22644 .8141 .22176 .80833 .21306 Mtetra
.80833 .21306 .8141 .22176 .82774 .21706 .82201 .20832 Mtetra
.654 .753 .922 r
.1891 .53483 .197 .54164 .20838 .53796 .20051 .53111 Mtetra
.20051 .53111 .20838 .53796 .2198 .53426 .21196 .52738 Mtetra
.21196 .52738 .2198 .53426 .23128 .53054 .22347 .52363 Mtetra
.925 .544 .252 r
.22347 .52363 .23128 .53054 .23988 .56147 .23201 .5546 Mtetra
.651 .756 .927 r
.23201 .5546 .23988 .56147 .25157 .55775 .24373 .55086 Mtetra
.24373 .55086 .25157 .55775 .26332 .55402 .25551 .54709 Mtetra
.25551 .54709 .26332 .55402 .27511 .55028 .26734 .54332 Mtetra
.26734 .54332 .27511 .55028 .28696 .54651 .27922 .53952 Mtetra
.27922 .53952 .28696 .54651 .29887 .54273 .29115 .53571 Mtetra
.29115 .53571 .29887 .54273 .31082 .53894 .30314 .53188 Mtetra
.30314 .53188 .31082 .53894 .32284 .53512 .31519 .52803 Mtetra
0 .214 .695 r
.31519 .52803 .32284 .53512 .33423 .54311 .32659 .53602 Mtetra
.65 .758 .928 r
.32659 .53602 .33423 .54311 .3464 .53928 .33878 .53215 Mtetra
.33878 .53215 .3464 .53928 .35861 .53542 .35104 .52826 Mtetra
.35104 .52826 .35861 .53542 .37089 .53155 .36335 .52435 Mtetra
.36335 .52435 .37089 .53155 .38322 .52766 .37571 .52043 Mtetra
.37571 .52043 .38322 .52766 .39561 .52375 .38814 .51649 Mtetra
.38814 .51649 .39561 .52375 .40805 .51983 .40062 .51253 Mtetra
.40062 .51253 .40805 .51983 .42056 .51588 .41316 .50855 Mtetra
.948 .73 .575 r
.41316 .50855 .42056 .51588 .43506 .44159 .42786 .43409 Mtetra
.656 .751 .92 r
.42786 .43409 .43506 .44159 .44741 .43754 .44025 .43 Mtetra
.44025 .43 .44741 .43754 .45983 .43346 .4527 .42589 Mtetra
.4527 .42589 .45983 .43346 .4723 .42937 .46521 .42176 Mtetra
.46521 .42176 .4723 .42937 .48483 .42525 .47778 .41761 Mtetra
.47778 .41761 .48483 .42525 .49742 .42112 .4904 .41344 Mtetra
.4904 .41344 .49742 .42112 .51006 .41697 .50308 .40926 Mtetra
.50308 .40926 .51006 .41697 .52276 .4128 .51583 .40505 Mtetra
.51583 .40505 .52276 .4128 .53553 .40861 .52863 .40082 Mtetra
.52863 .40082 .53553 .40861 .54835 .4044 .54149 .39658 Mtetra
.54149 .39658 .54835 .4044 .56123 .40017 .55441 .39231 Mtetra
.55441 .39231 .56123 .40017 .57417 .39592 .56739 .38803 Mtetra
.56739 .38803 .57417 .39592 .58717 .39165 .58043 .38372 Mtetra
.58043 .38372 .58717 .39165 .59786 .28602 .59354 .37939 Mtetra
0 0 .257 r
.59354 .37939 .59786 .28602 .61056 .28162 .60411 .27343 Mtetra
.664 .741 .908 r
.60411 .27343 .61056 .28162 .62333 .27719 .61691 .26897 Mtetra
.61691 .26897 .62333 .27719 .63615 .27275 .62977 .26449 Mtetra
.62977 .26449 .63615 .27275 .64903 .26828 .64269 .25999 Mtetra
.64269 .25999 .64903 .26828 .66197 .2638 .65567 .25546 Mtetra
.65567 .25546 .66197 .2638 .67496 .25929 .66871 .25092 Mtetra
.66871 .25092 .67496 .25929 .68802 .25477 .68181 .24635 Mtetra
.68181 .24635 .68802 .25477 .70114 .25022 .69497 .24177 Mtetra
.69497 .24177 .70114 .25022 .71432 .24565 .70819 .23716 Mtetra
.70819 .23716 .71432 .24565 .72756 .24106 .72148 .23253 Mtetra
.72148 .23253 .72756 .24106 .74087 .23645 .73482 .22788 Mtetra
.73482 .22788 .74087 .23645 .75423 .23182 .74823 .2232 Mtetra
.74823 .2232 .75423 .23182 .76766 .22716 .7617 .21851 Mtetra
.7617 .21851 .76766 .22716 .78115 .22248 .77524 .21379 Mtetra
.77524 .21379 .78115 .22248 .79471 .21779 .78884 .20905 Mtetra
.78884 .20905 .79471 .21779 .80833 .21306 .80251 .20429 Mtetra
.80251 .20429 .80833 .21306 .82201 .20832 .81623 .19951 Mtetra
.654 .753 .922 r
.18114 .52795 .1891 .53483 .20051 .53111 .19257 .52421 Mtetra
.19257 .52421 .20051 .53111 .21196 .52738 .20406 .52044 Mtetra
.20406 .52044 .21196 .52738 .22347 .52363 .21559 .51666 Mtetra
.21559 .51666 .22347 .52363 .23201 .5546 .22718 .51287 Mtetra
0 0 .484 r
.22718 .51287 .23201 .5546 .24373 .55086 .23582 .5439 Mtetra
.651 .756 .927 r
.23582 .5439 .24373 .55086 .25551 .54709 .24763 .54011 Mtetra
.24763 .54011 .25551 .54709 .26734 .54332 .25949 .5363 Mtetra
.25949 .5363 .26734 .54332 .27922 .53952 .2714 .53247 Mtetra
.2714 .53247 .27922 .53952 .29115 .53571 .28337 .52863 Mtetra
.28337 .52863 .29115 .53571 .30314 .53188 .29539 .52476 Mtetra
.29539 .52476 .30314 .53188 .31519 .52803 .30747 .52088 Mtetra
.30747 .52088 .31519 .52803 .32659 .53602 .31961 .51699 Mtetra
.298 .352 .75 r
.31961 .51699 .32659 .53602 .33878 .53215 .33111 .52496 Mtetra
.65 .758 .928 r
.33111 .52496 .33878 .53215 .35104 .52826 .34339 .52104 Mtetra
.34339 .52104 .35104 .52826 .36335 .52435 .35574 .5171 Mtetra
.35574 .5171 .36335 .52435 .37571 .52043 .36814 .51314 Mtetra
.36814 .51314 .37571 .52043 .38814 .51649 .3806 .50917 Mtetra
.3806 .50917 .38814 .51649 .40062 .51253 .39312 .50517 Mtetra
.39312 .50517 .40062 .51253 .41316 .50855 .4057 .50116 Mtetra
.4057 .50116 .41316 .50855 .42786 .43409 .41833 .49713 Mtetra
0 0 .09 r
.41833 .49713 .42786 .43409 .44025 .43 .43303 .4224 Mtetra
.656 .751 .92 r
.43303 .4224 .44025 .43 .4527 .42589 .44552 .41825 Mtetra
.44552 .41825 .4527 .42589 .46521 .42176 .45806 .41408 Mtetra
.45806 .41408 .46521 .42176 .47778 .41761 .47066 .4099 Mtetra
.47066 .4099 .47778 .41761 .4904 .41344 .48333 .4057 Mtetra
.48333 .4057 .4904 .41344 .50308 .40926 .49605 .40147 Mtetra
.49605 .40147 .50308 .40926 .51583 .40505 .50883 .39723 Mtetra
.50883 .39723 .51583 .40505 .52863 .40082 .52167 .39297 Mtetra
.52167 .39297 .52863 .40082 .54149 .39658 .53457 .38869 Mtetra
.53457 .38869 .54149 .39658 .55441 .39231 .54753 .38438 Mtetra
.54753 .38438 .55441 .39231 .56739 .38803 .56055 .38006 Mtetra
.56055 .38006 .56739 .38803 .58043 .38372 .57364 .37572 Mtetra
.57364 .37572 .58043 .38372 .59354 .37939 .58678 .37135 Mtetra
.971 .725 .507 r
.58678 .37135 .59354 .37939 .60411 .27343 .59759 .26518 Mtetra
.664 .741 .908 r
.59759 .26518 .60411 .27343 .61691 .26897 .61043 .26068 Mtetra
.61043 .26068 .61691 .26897 .62977 .26449 .62333 .25616 Mtetra
.62333 .25616 .62977 .26449 .64269 .25999 .63629 .25162 Mtetra
.63629 .25162 .64269 .25999 .65567 .25546 .64932 .24706 Mtetra
.64932 .24706 .65567 .25546 .66871 .25092 .6624 .24247 Mtetra
.6624 .24247 .66871 .25092 .68181 .24635 .67554 .23787 Mtetra
.67554 .23787 .68181 .24635 .69497 .24177 .68874 .23324 Mtetra
.68874 .23324 .69497 .24177 .70819 .23716 .70201 .22859 Mtetra
.70201 .22859 .70819 .23716 .72148 .23253 .71533 .22393 Mtetra
.71533 .22393 .72148 .23253 .73482 .22788 .72872 .21923 Mtetra
.72872 .21923 .73482 .22788 .74823 .2232 .74218 .21452 Mtetra
.74218 .21452 .74823 .2232 .7617 .21851 .75569 .20978 Mtetra
.75569 .20978 .7617 .21851 .77524 .21379 .76928 .20502 Mtetra
.76928 .20502 .77524 .21379 .78884 .20905 .78292 .20024 Mtetra
.78292 .20024 .78884 .20905 .80251 .20429 .79663 .19544 Mtetra
.79663 .19544 .80251 .20429 .81623 .19951 .81041 .19061 Mtetra
.654 .753 .922 r
.17311 .52102 .18114 .52795 .19257 .52421 .18458 .51725 Mtetra
.18458 .51725 .19257 .52421 .20406 .52044 .19609 .51345 Mtetra
.19609 .51345 .20406 .52044 .21559 .51666 .20765 .50964 Mtetra
.20765 .50964 .21559 .51666 .22718 .51287 .21927 .50581 Mtetra
.925 .542 .245 r
.21927 .50581 .22718 .51287 .23582 .5439 .22785 .53688 Mtetra
.651 .756 .927 r
.22785 .53688 .23582 .5439 .24763 .54011 .23969 .53306 Mtetra
.23969 .53306 .24763 .54011 .25949 .5363 .25158 .52922 Mtetra
.25158 .52922 .25949 .5363 .2714 .53247 .26353 .52536 Mtetra
.26353 .52536 .2714 .53247 .28337 .52863 .27553 .52148 Mtetra
.27553 .52148 .28337 .52863 .29539 .52476 .28758 .51759 Mtetra
.28758 .51759 .29539 .52476 .30747 .52088 .29969 .51367 Mtetra
.29969 .51367 .30747 .52088 .31961 .51699 .31186 .50974 Mtetra
0 .221 .703 r
.31186 .50974 .31961 .51699 .33111 .52496 .32336 .51771 Mtetra
.65 .758 .928 r
.32336 .51771 .33111 .52496 .34339 .52104 .33569 .51375 Mtetra
.33569 .51375 .34339 .52104 .35574 .5171 .34807 .50978 Mtetra
.34807 .50978 .35574 .5171 .36814 .51314 .3605 .50579 Mtetra
.3605 .50579 .36814 .51314 .3806 .50917 .373 .50178 Mtetra
.373 .50178 .3806 .50917 .39312 .50517 .38555 .49775 Mtetra
.38555 .49775 .39312 .50517 .4057 .50116 .39817 .4937 Mtetra
.39817 .4937 .4057 .50116 .41833 .49713 .41084 .48964 Mtetra
.953 .722 .551 r
.41084 .48964 .41833 .49713 .43303 .4224 .42645 .39179 Mtetra
.165 .175 .624 r
.42645 .39179 .43303 .4224 .44552 .41825 .43827 .41055 Mtetra
.656 .751 .92 r
.43827 .41055 .44552 .41825 .45806 .41408 .45085 .40635 Mtetra
.45085 .40635 .45806 .41408 .47066 .4099 .46349 .40213 Mtetra
.46349 .40213 .47066 .4099 .48333 .4057 .47619 .39789 Mtetra
.47619 .39789 .48333 .4057 .49605 .40147 .48895 .39363 Mtetra
.48895 .39363 .49605 .40147 .50883 .39723 .50177 .38935 Mtetra
.50177 .38935 .50883 .39723 .52167 .39297 .51465 .38505 Mtetra
.51465 .38505 .52167 .39297 .53457 .38869 .52759 .38073 Mtetra
.52759 .38073 .53457 .38869 .54753 .38438 .54059 .37639 Mtetra
.54059 .37639 .54753 .38438 .56055 .38006 .55365 .37203 Mtetra
.55365 .37203 .56055 .38006 .57364 .37572 .56678 .36764 Mtetra
.56678 .36764 .57364 .37572 .58678 .37135 .57996 .36324 Mtetra
.971 .725 .507 r
.57996 .36324 .58678 .37135 .59759 .26518 .59102 .25686 Mtetra
.664 .741 .908 r
.59102 .25686 .59759 .26518 .61043 .26068 .60391 .25232 Mtetra
.60391 .25232 .61043 .26068 .62333 .25616 .61685 .24776 Mtetra
.61685 .24776 .62333 .25616 .63629 .25162 .62985 .24318 Mtetra
.62985 .24318 .63629 .25162 .64932 .24706 .64291 .23858 Mtetra
.64291 .23858 .64932 .24706 .6624 .24247 .65603 .23396 Mtetra
.65603 .23396 .6624 .24247 .67554 .23787 .66921 .22931 Mtetra
.66921 .22931 .67554 .23787 .68874 .23324 .68246 .22464 Mtetra
.68246 .22464 .68874 .23324 .70201 .22859 .69577 .21996 Mtetra
.69577 .21996 .70201 .22859 .71533 .22393 .70914 .21525 Mtetra
.70914 .21525 .71533 .22393 .72872 .21923 .72257 .21051 Mtetra
.72257 .21051 .72872 .21923 .74218 .21452 .73607 .20576 Mtetra
.73607 .20576 .74218 .21452 .75569 .20978 .74963 .20098 Mtetra
.74963 .20098 .75569 .20978 .76928 .20502 .76326 .19618 Mtetra
.76326 .19618 .76928 .20502 .78292 .20024 .77695 .19136 Mtetra
.77695 .19136 .78292 .20024 .79663 .19544 .79071 .18651 Mtetra
.79071 .18651 .79663 .19544 .81041 .19061 .80453 .18164 Mtetra
.654 .753 .922 r
.16502 .51404 .17311 .52102 .18458 .51725 .17651 .51023 Mtetra
.17651 .51023 .18458 .51725 .19609 .51345 .18805 .5064 Mtetra
.18805 .5064 .19609 .51345 .20765 .50964 .19965 .50256 Mtetra
.19965 .50256 .20765 .50964 .21927 .50581 .21129 .4987 Mtetra
.21129 .4987 .21927 .50581 .22785 .53688 .22299 .49482 Mtetra
0 0 .479 r
.22299 .49482 .22785 .53688 .23969 .53306 .23168 .52595 Mtetra
.651 .756 .927 r
.23168 .52595 .23969 .53306 .25158 .52922 .2436 .52208 Mtetra
.2436 .52208 .25158 .52922 .26353 .52536 .25558 .51819 Mtetra
.25558 .51819 .26353 .52536 .27553 .52148 .26761 .51428 Mtetra
.26761 .51428 .27553 .52148 .28758 .51759 .2797 .51035 Mtetra
.2797 .51035 .28758 .51759 .29969 .51367 .29185 .5064 Mtetra
.29185 .5064 .29969 .51367 .31186 .50974 .30405 .50244 Mtetra
.30405 .50244 .31186 .50974 .32336 .51771 .31631 .49846 Mtetra
.295 .351 .75 r
.31631 .49846 .32336 .51771 .33569 .51375 .32791 .5064 Mtetra
.65 .758 .928 r
.32791 .5064 .33569 .51375 .34807 .50978 .34033 .5024 Mtetra
.34033 .5024 .34807 .50978 .3605 .50579 .3528 .49837 Mtetra
.3528 .49837 .3605 .50579 .373 .50178 .36533 .49433 Mtetra
.36533 .49433 .373 .50178 .38555 .49775 .37792 .49026 Mtetra
.37792 .49026 .38555 .49775 .39817 .4937 .39057 .48618 Mtetra
.39057 .48618 .39817 .4937 .41084 .48964 .40329 .48208 Mtetra
.953 .722 .551 r
.40329 .48208 .41084 .48964 .42645 .39179 .41915 .38401 Mtetra
.658 .749 .917 r
.41915 .38401 .42645 .39179 .43827 .41055 .43163 .37977 Mtetra
.597 .467 .674 r
.43163 .37977 .43827 .41055 .45085 .40635 .44416 .37551 Mtetra
.17 .179 .626 r
.44416 .37551 .45085 .40635 .46349 .40213 .45625 .39428 Mtetra
.656 .751 .92 r
.45625 .39428 .46349 .40213 .47619 .39789 .46899 .39001 Mtetra
.46899 .39001 .47619 .39789 .48895 .39363 .48179 .38571 Mtetra
.48179 .38571 .48895 .39363 .50177 .38935 .49465 .38139 Mtetra
.49465 .38139 .50177 .38935 .51465 .38505 .50757 .37706 Mtetra
.50757 .37706 .51465 .38505 .52759 .38073 .52055 .3727 Mtetra
.52055 .3727 .52759 .38073 .54059 .37639 .53359 .36832 Mtetra
.53359 .36832 .54059 .37639 .55365 .37203 .54669 .36392 Mtetra
.54669 .36392 .55365 .37203 .56678 .36764 .55986 .3595 Mtetra
.55986 .3595 .56678 .36764 .57996 .36324 .57309 .35506 Mtetra
.57309 .35506 .57996 .36324 .59102 .25686 .58638 .3506 Mtetra
0 0 .243 r
.58638 .3506 .59102 .25686 .60391 .25232 .59732 .24389 Mtetra
.664 .741 .908 r
.59732 .24389 .60391 .25232 .61685 .24776 .6103 .23929 Mtetra
.6103 .23929 .61685 .24776 .62985 .24318 .62334 .23467 Mtetra
.62334 .23467 .62985 .24318 .64291 .23858 .63645 .23003 Mtetra
.63645 .23003 .64291 .23858 .65603 .23396 .64961 .22536 Mtetra
.64961 .22536 .65603 .23396 .66921 .22931 .66284 .22068 Mtetra
.66284 .22068 .66921 .22931 .68246 .22464 .67612 .21597 Mtetra
.67612 .21597 .68246 .22464 .69577 .21996 .68948 .21124 Mtetra
.68948 .21124 .69577 .21996 .70914 .21525 .70289 .20649 Mtetra
.70289 .20649 .70914 .21525 .72257 .21051 .71637 .20172 Mtetra
.71637 .20172 .72257 .21051 .73607 .20576 .72991 .19692 Mtetra
.72991 .19692 .73607 .20576 .74963 .20098 .74352 .1921 Mtetra
.74352 .1921 .74963 .20098 .76326 .19618 .75719 .18726 Mtetra
.75719 .18726 .76326 .19618 .77695 .19136 .77093 .18239 Mtetra
.77093 .18239 .77695 .19136 .79071 .18651 .78473 .1775 Mtetra
.78473 .1775 .79071 .18651 .80453 .18164 .7986 .17259 Mtetra
.654 .753 .922 r
.15686 .50699 .16502 .51404 .17651 .51023 .16838 .50315 Mtetra
.16838 .50315 .17651 .51023 .18805 .5064 .17995 .49929 Mtetra
.17995 .49929 .18805 .5064 .19965 .50256 .19158 .49542 Mtetra
.19158 .49542 .19965 .50256 .21129 .4987 .20325 .49152 Mtetra
.20325 .49152 .21129 .4987 .22299 .49482 .21498 .48761 Mtetra
.21498 .48761 .22299 .49482 .23168 .52595 .22677 .48369 Mtetra
0 0 .479 r
.22677 .48369 .23168 .52595 .2436 .52208 .23556 .51488 Mtetra
.651 .756 .927 r
.23556 .51488 .2436 .52208 .25558 .51819 .24757 .51095 Mtetra
.24757 .51095 .25558 .51819 .26761 .51428 .25963 .50701 Mtetra
.25963 .50701 .26761 .51428 .2797 .51035 .27176 .50305 Mtetra
.27176 .50305 .2797 .51035 .29185 .5064 .28393 .49907 Mtetra
.28393 .49907 .29185 .5064 .30405 .50244 .29617 .49507 Mtetra
.29617 .49507 .30405 .50244 .31631 .49846 .30846 .49105 Mtetra
.948 .606 .333 r
.30846 .49105 .31631 .49846 .32791 .5064 .31706 .54777 Mtetra
0 0 0 r
.31706 .54777 .32791 .5064 .34033 .5024 .33252 .49495 Mtetra
.65 .758 .928 r
.33252 .49495 .34033 .5024 .3528 .49837 .34503 .49089 Mtetra
.34503 .49089 .3528 .49837 .36533 .49433 .3576 .48681 Mtetra
.3576 .48681 .36533 .49433 .37792 .49026 .37023 .48271 Mtetra
.37023 .48271 .37792 .49026 .39057 .48618 .38291 .47859 Mtetra
.952 .722 .554 r
.38291 .47859 .39057 .48618 .40329 .48208 .39935 .38042 Mtetra
.553 .357 .569 r
.39935 .38042 .40329 .48208 .41915 .38401 .4118 .37617 Mtetra
.658 .749 .917 r
.4118 .37617 .41915 .38401 .43163 .37977 .42431 .37189 Mtetra
.42431 .37189 .43163 .37977 .44416 .37551 .43688 .36759 Mtetra
.43688 .36759 .44416 .37551 .45625 .39428 .4495 .36328 Mtetra
.596 .466 .674 r
.4495 .36328 .45625 .39428 .46899 .39001 .46219 .35894 Mtetra
.46219 .35894 .46899 .39001 .48179 .38571 .47493 .35458 Mtetra
.18 .186 .629 r
.47493 .35458 .48179 .38571 .49465 .38139 .48747 .37337 Mtetra
.656 .751 .92 r
.48747 .37337 .49465 .38139 .50757 .37706 .50042 .36899 Mtetra
.50042 .36899 .50757 .37706 .52055 .3727 .51344 .3646 Mtetra
.51344 .3646 .52055 .3727 .53359 .36832 .52653 .36018 Mtetra
.52653 .36018 .53359 .36832 .54669 .36392 .53967 .35574 Mtetra
.53967 .35574 .54669 .36392 .55986 .3595 .55288 .35128 Mtetra
.55288 .35128 .55986 .3595 .57309 .35506 .56615 .3468 Mtetra
.56615 .3468 .57309 .35506 .58638 .3506 .57948 .3423 Mtetra
.972 .725 .503 r
.57948 .3423 .58638 .3506 .59732 .24389 .59068 .23538 Mtetra
.664 .741 .908 r
.59068 .23538 .59732 .24389 .6103 .23929 .6037 .23074 Mtetra
.6037 .23074 .6103 .23929 .62334 .23467 .61678 .22608 Mtetra
.61678 .22608 .62334 .23467 .63645 .23003 .62993 .2214 Mtetra
.62993 .2214 .63645 .23003 .64961 .22536 .64313 .2167 Mtetra
.64313 .2167 .64961 .22536 .66284 .22068 .6564 .21197 Mtetra
.6564 .21197 .66284 .22068 .67612 .21597 .66973 .20722 Mtetra
.66973 .20722 .67612 .21597 .68948 .21124 .68313 .20245 Mtetra
.68313 .20245 .68948 .21124 .70289 .20649 .69659 .19766 Mtetra
.69659 .19766 .70289 .20649 .71637 .20172 .71011 .19284 Mtetra
.71011 .19284 .71637 .20172 .72991 .19692 .72369 .188 Mtetra
.72369 .188 .72991 .19692 .74352 .1921 .73735 .18314 Mtetra
.73735 .18314 .74352 .1921 .75719 .18726 .75106 .17826 Mtetra
.75106 .17826 .75719 .18726 .77093 .18239 .76485 .17335 Mtetra
.76485 .17335 .77093 .18239 .78473 .1775 .7787 .16841 Mtetra
.7787 .16841 .78473 .1775 .7986 .17259 .79262 .16346 Mtetra
.654 .753 .922 r
.14863 .49989 .15686 .50699 .16838 .50315 .16018 .49601 Mtetra
.16018 .49601 .16838 .50315 .17995 .49929 .17178 .49212 Mtetra
.17178 .49212 .17995 .49929 .19158 .49542 .18344 .48822 Mtetra
.18344 .48822 .19158 .49542 .20325 .49152 .19514 .48429 Mtetra
.19514 .48429 .20325 .49152 .21498 .48761 .2069 .48035 Mtetra
.2069 .48035 .21498 .48761 .22677 .48369 .21872 .47639 Mtetra
.924 .536 .23 r
.21872 .47639 .22677 .48369 .23556 .51488 .22744 .50762 Mtetra
.651 .756 .927 r
.22744 .50762 .23556 .51488 .24757 .51095 .23949 .50366 Mtetra
.23949 .50366 .24757 .51095 .25963 .50701 .25158 .49968 Mtetra
.25158 .49968 .25963 .50701 .27176 .50305 .26374 .49569 Mtetra
.26374 .49569 .27176 .50305 .28393 .49907 .27595 .49167 Mtetra
.27595 .49167 .28393 .49907 .29617 .49507 .28822 .48764 Mtetra
.28822 .48764 .29617 .49507 .30846 .49105 .30055 .48359 Mtetra
.948 .606 .333 r
.30055 .48359 .30846 .49105 .31706 .54777 .30902 .5404 Mtetra
.646 .762 .934 r
.30902 .5404 .31706 .54777 .33252 .49495 .32169 .53638 Mtetra
0 0 0 r
.32169 .53638 .33252 .49495 .34503 .49089 .33719 .48334 Mtetra
.65 .758 .928 r
.33719 .48334 .34503 .49089 .3576 .48681 .3498 .47923 Mtetra
.3498 .47923 .3576 .48681 .37023 .48271 .36246 .47509 Mtetra
.36246 .47509 .37023 .48271 .38291 .47859 .37519 .47094 Mtetra
.952 .722 .554 r
.37519 .47094 .38291 .47859 .39935 .38042 .39189 .37255 Mtetra
.658 .749 .917 r
.39189 .37255 .39935 .38042 .4118 .37617 .40438 .36826 Mtetra
.40438 .36826 .4118 .37617 .42431 .37189 .41693 .36394 Mtetra
.41693 .36394 .42431 .37189 .43688 .36759 .42953 .35961 Mtetra
.42953 .35961 .43688 .36759 .4495 .36328 .4422 .35526 Mtetra
.4422 .35526 .4495 .36328 .46219 .35894 .45492 .35088 Mtetra
.45492 .35088 .46219 .35894 .47493 .35458 .4677 .34649 Mtetra
.4677 .34649 .47493 .35458 .48747 .37337 .48054 .34207 Mtetra
.596 .466 .674 r
.48054 .34207 .48747 .37337 .50042 .36899 .49345 .33764 Mtetra
.49345 .33764 .50042 .36899 .51344 .3646 .50641 .33318 Mtetra
.189 .193 .632 r
.50641 .33318 .51344 .3646 .52653 .36018 .5194 .35197 Mtetra
.656 .751 .92 r
.5194 .35197 .52653 .36018 .53967 .35574 .53259 .34749 Mtetra
.53259 .34749 .53967 .35574 .55288 .35128 .54584 .34299 Mtetra
.54584 .34299 .55288 .35128 .56615 .3468 .55915 .33847 Mtetra
.55915 .33847 .56615 .3468 .57948 .3423 .57253 .33393 Mtetra
.57253 .33393 .57948 .3423 .59068 .23538 .58597 .32937 Mtetra
0 0 .236 r
.58597 .32937 .59068 .23538 .6037 .23074 .59704 .22212 Mtetra
.664 .741 .908 r
.59704 .22212 .6037 .23074 .61678 .22608 .61017 .21742 Mtetra
.61017 .21742 .61678 .22608 .62993 .2214 .62335 .2127 Mtetra
.62335 .2127 .62993 .2214 .64313 .2167 .6366 .20796 Mtetra
.6366 .20796 .64313 .2167 .6564 .21197 .64991 .20319 Mtetra
.64991 .20319 .6564 .21197 .66973 .20722 .66328 .1984 Mtetra
.66328 .1984 .66973 .20722 .68313 .20245 .67672 .19359 Mtetra
.67672 .19359 .68313 .20245 .69659 .19766 .69023 .18875 Mtetra
.69023 .18875 .69659 .19766 .71011 .19284 .70379 .18389 Mtetra
.70379 .18389 .71011 .19284 .72369 .188 .71742 .17901 Mtetra
.71742 .17901 .72369 .188 .73735 .18314 .73112 .1741 Mtetra
.73112 .1741 .73735 .18314 .75106 .17826 .74489 .16917 Mtetra
.74489 .16917 .75106 .17826 .76485 .17335 .75872 .16422 Mtetra
.75872 .16422 .76485 .17335 .7787 .16841 .77261 .15924 Mtetra
.77261 .15924 .7787 .16841 .79262 .16346 .78658 .15424 Mtetra
.654 .753 .922 r
.14033 .49272 .14863 .49989 .16018 .49601 .15191 .48882 Mtetra
.15191 .48882 .16018 .49601 .17178 .49212 .16354 .4849 Mtetra
.16354 .4849 .17178 .49212 .18344 .48822 .17523 .48096 Mtetra
.17523 .48096 .18344 .48822 .19514 .48429 .18697 .477 Mtetra
.18697 .477 .19514 .48429 .2069 .48035 .19876 .47302 Mtetra
.19876 .47302 .2069 .48035 .21872 .47639 .2106 .46903 Mtetra
.2106 .46903 .21872 .47639 .22744 .50762 .2225 .46501 Mtetra
0 0 .475 r
.2225 .46501 .22744 .50762 .23949 .50366 .23133 .4963 Mtetra
.651 .756 .927 r
.23133 .4963 .23949 .50366 .25158 .49968 .24347 .49229 Mtetra
.24347 .49229 .25158 .49968 .26374 .49569 .25566 .48826 Mtetra
.25566 .48826 .26374 .49569 .27595 .49167 .2679 .48421 Mtetra
.2679 .48421 .27595 .49167 .28822 .48764 .2802 .48015 Mtetra
.948 .607 .339 r
.2802 .48015 .28822 .48764 .30055 .48359 .28827 .537 Mtetra
.475 .191 .403 r
.28827 .537 .30055 .48359 .30902 .5404 .30091 .53296 Mtetra
.646 .762 .934 r
.30091 .53296 .30902 .5404 .32169 .53638 .31361 .52891 Mtetra
.31361 .52891 .32169 .53638 .33719 .48334 .32637 .52483 Mtetra
0 0 0 r
.32637 .52483 .33719 .48334 .3498 .47923 .34193 .47158 Mtetra
.65 .758 .928 r
.34193 .47158 .3498 .47923 .36246 .47509 .35463 .46741 Mtetra
.95 .721 .556 r
.35463 .46741 .36246 .47509 .37519 .47094 .37191 .36892 Mtetra
.55 .353 .567 r
.37191 .36892 .37519 .47094 .39189 .37255 .38438 .36461 Mtetra
.658 .749 .917 r
.38438 .36461 .39189 .37255 .40438 .36826 .3969 .36028 Mtetra
.3969 .36028 .40438 .36826 .41693 .36394 .40948 .35593 Mtetra
.40948 .35593 .41693 .36394 .42953 .35961 .42212 .35156 Mtetra
.42212 .35156 .42953 .35961 .4422 .35526 .43483 .34716 Mtetra
.43483 .34716 .4422 .35526 .45492 .35088 .44759 .34275 Mtetra
.44759 .34275 .45492 .35088 .4677 .34649 .46041 .33832 Mtetra
.46041 .33832 .4677 .34649 .48054 .34207 .47329 .33386 Mtetra
.47329 .33386 .48054 .34207 .49345 .33764 .48623 .32939 Mtetra
.48623 .32939 .49345 .33764 .50641 .33318 .49924 .32489 Mtetra
.49924 .32489 .50641 .33318 .5194 .35197 .51231 .32037 Mtetra
.595 .465 .673 r
.51231 .32037 .5194 .35197 .53259 .34749 .52544 .31583 Mtetra
.193 .197 .634 r
.52544 .31583 .53259 .34749 .54584 .34299 .53873 .33463 Mtetra
.656 .751 .92 r
.53873 .33463 .54584 .34299 .55915 .33847 .55209 .33007 Mtetra
.55209 .33007 .55915 .33847 .57253 .33393 .56551 .32549 Mtetra
.56551 .32549 .57253 .33393 .58597 .32937 .57899 .32088 Mtetra
.973 .725 .5 r
.57899 .32088 .58597 .32937 .59704 .22212 .59033 .21343 Mtetra
.664 .741 .908 r
.59033 .21343 .59704 .22212 .61017 .21742 .60349 .20869 Mtetra
.60349 .20869 .61017 .21742 .62335 .2127 .61672 .20392 Mtetra
.61672 .20392 .62335 .2127 .6366 .20796 .63001 .19914 Mtetra
.63001 .19914 .6366 .20796 .64991 .20319 .64336 .19433 Mtetra
.64336 .19433 .64991 .20319 .66328 .1984 .65678 .1895 Mtetra
.65678 .1895 .66328 .1984 .67672 .19359 .67026 .18464 Mtetra
.67026 .18464 .67672 .19359 .69023 .18875 .68381 .17976 Mtetra
.68381 .17976 .69023 .18875 .70379 .18389 .69742 .17486 Mtetra
.69742 .17486 .70379 .18389 .71742 .17901 .7111 .16993 Mtetra
.7111 .16993 .71742 .17901 .73112 .1741 .72484 .16498 Mtetra
.72484 .16498 .73112 .1741 .74489 .16917 .73865 .16001 Mtetra
.73865 .16001 .74489 .16917 .75872 .16422 .75253 .15501 Mtetra
.75253 .15501 .75872 .16422 .77261 .15924 .76647 .14999 Mtetra
.76647 .14999 .77261 .15924 .78658 .15424 .78049 .14494 Mtetra
.654 .753 .922 r
.13197 .4855 .14033 .49272 .15191 .48882 .14358 .48156 Mtetra
.14358 .48156 .15191 .48882 .16354 .4849 .15524 .47761 Mtetra
.15524 .47761 .16354 .4849 .17523 .48096 .16695 .47363 Mtetra
.16695 .47363 .17523 .48096 .18697 .477 .17872 .46964 Mtetra
.17872 .46964 .18697 .477 .19876 .47302 .19054 .46563 Mtetra
.19054 .46563 .19876 .47302 .2106 .46903 .20242 .4616 Mtetra
.20242 .4616 .2106 .46903 .2225 .46501 .21435 .45756 Mtetra
.21435 .45756 .2225 .46501 .23133 .4963 .22634 .45349 Mtetra
0 0 .475 r
.22634 .45349 .23133 .4963 .24347 .49229 .23528 .48484 Mtetra
.651 .756 .927 r
.23528 .48484 .24347 .49229 .25566 .48826 .2475 .48077 Mtetra
.2475 .48077 .25566 .48826 .2679 .48421 .25978 .47669 Mtetra
.25978 .47669 .2679 .48421 .2802 .48015 .27212 .47258 Mtetra
.948 .607 .339 r
.27212 .47258 .2802 .48015 .28827 .537 .28005 .52953 Mtetra
.646 .762 .934 r
.28005 .52953 .28827 .537 .30091 .53296 .29273 .52546 Mtetra
.29273 .52546 .30091 .53296 .31361 .52891 .30547 .52137 Mtetra
.30547 .52137 .31361 .52891 .32637 .52483 .31827 .51726 Mtetra
.31827 .51726 .32637 .52483 .34193 .47158 .33113 .51312 Mtetra
0 0 0 r
.33113 .51312 .34193 .47158 .35463 .46741 .34673 .45965 Mtetra
.95 .721 .556 r
.34673 .45965 .35463 .46741 .37191 .36892 .36429 .36095 Mtetra
.658 .749 .917 r
.36429 .36095 .37191 .36892 .38438 .36461 .37679 .3566 Mtetra
.37679 .3566 .38438 .36461 .3969 .36028 .38935 .35223 Mtetra
.38935 .35223 .3969 .36028 .40948 .35593 .40197 .34784 Mtetra
.40197 .34784 .40948 .35593 .42212 .35156 .41465 .34343 Mtetra
.41465 .34343 .42212 .35156 .43483 .34716 .42739 .339 Mtetra
.42739 .339 .43483 .34716 .44759 .34275 .44019 .33455 Mtetra
.44019 .33455 .44759 .34275 .46041 .33832 .45305 .33008 Mtetra
.45305 .33008 .46041 .33832 .47329 .33386 .46597 .32559 Mtetra
.46597 .32559 .47329 .33386 .48623 .32939 .47895 .32107 Mtetra
.47895 .32107 .48623 .32939 .49924 .32489 .492 .31653 Mtetra
.492 .31653 .49924 .32489 .51231 .32037 .50511 .31198 Mtetra
.50511 .31198 .51231 .32037 .52544 .31583 .51828 .3074 Mtetra
.51828 .3074 .52544 .31583 .53873 .33463 .53151 .30279 Mtetra
.594 .464 .673 r
.53151 .30279 .53873 .33463 .55209 .33007 .54481 .29817 Mtetra
.54481 .29817 .55209 .33007 .56551 .32549 .55817 .29352 Mtetra
.202 .203 .637 r
.55817 .29352 .56551 .32549 .57899 .32088 .57195 .31232 Mtetra
.973 .725 .5 r
.57195 .31232 .57899 .32088 .59033 .21343 .58355 .20466 Mtetra
.664 .741 .908 r
.58355 .20466 .59033 .21343 .60349 .20869 .59676 .19987 Mtetra
.59676 .19987 .60349 .20869 .61672 .20392 .61003 .19507 Mtetra
.61003 .19507 .61672 .20392 .63001 .19914 .62336 .19024 Mtetra
.62336 .19024 .63001 .19914 .64336 .19433 .63676 .18539 Mtetra
.63676 .18539 .64336 .19433 .65678 .1895 .65022 .18051 Mtetra
.65022 .18051 .65678 .1895 .67026 .18464 .66374 .17561 Mtetra
.66374 .17561 .67026 .18464 .68381 .17976 .67734 .17069 Mtetra
.67734 .17069 .68381 .17976 .69742 .17486 .69099 .16575 Mtetra
.69099 .16575 .69742 .17486 .7111 .16993 .70472 .16078 Mtetra
.70472 .16078 .7111 .16993 .72484 .16498 .7185 .15578 Mtetra
.7185 .15578 .72484 .16498 .73865 .16001 .73236 .15076 Mtetra
.73236 .15076 .73865 .16001 .75253 .15501 .74629 .14572 Mtetra
.74629 .14572 .75253 .15501 .76647 .14999 .76028 .14065 Mtetra
.76028 .14065 .76647 .14999 .78049 .14494 .77434 .13556 Mtetra
.654 .753 .922 r
.12353 .47822 .13197 .4855 .14358 .48156 .13517 .47425 Mtetra
.13517 .47425 .14358 .48156 .15524 .47761 .14686 .47026 Mtetra
.14686 .47026 .15524 .47761 .16695 .47363 .15861 .46625 Mtetra
.15861 .46625 .16695 .47363 .17872 .46964 .1704 .46223 Mtetra
.1704 .46223 .17872 .46964 .19054 .46563 .18226 .45818 Mtetra
.18226 .45818 .19054 .46563 .20242 .4616 .19417 .45412 Mtetra
.19417 .45412 .20242 .4616 .21435 .45756 .20613 .45004 Mtetra
.20613 .45004 .21435 .45756 .22634 .45349 .21815 .44594 Mtetra
.922 .531 .215 r
.21815 .44594 .22634 .45349 .23528 .48484 .22702 .47732 Mtetra
.651 .756 .927 r
.22702 .47732 .23528 .48484 .2475 .48077 .23928 .47322 Mtetra
.23928 .47322 .2475 .48077 .25978 .47669 .25159 .4691 Mtetra
.25159 .4691 .25978 .47669 .27212 .47258 .26396 .46496 Mtetra
.948 .607 .339 r
.26396 .46496 .27212 .47258 .28005 .52953 .27176 .522 Mtetra
.646 .762 .934 r
.27176 .522 .28005 .52953 .29273 .52546 .28447 .51789 Mtetra
.28447 .51789 .29273 .52546 .30547 .52137 .29725 .51376 Mtetra
.29725 .51376 .30547 .52137 .31827 .51726 .31008 .50961 Mtetra
.31008 .50961 .31827 .51726 .33113 .51312 .32298 .50544 Mtetra
.32298 .50544 .33113 .51312 .34673 .45965 .33594 .50125 Mtetra
.996 .796 .435 r
.33594 .50125 .34673 .45965 .36429 .36095 .35661 .3529 Mtetra
.658 .749 .917 r
.35661 .3529 .36429 .36095 .37679 .3566 .36915 .34852 Mtetra
.36915 .34852 .37679 .3566 .38935 .35223 .38174 .34411 Mtetra
.38174 .34411 .38935 .35223 .40197 .34784 .3944 .33969 Mtetra
.3944 .33969 .40197 .34784 .41465 .34343 .40712 .33524 Mtetra
.40712 .33524 .41465 .34343 .42739 .339 .41989 .33077 Mtetra
.41989 .33077 .42739 .339 .44019 .33455 .43273 .32628 Mtetra
.43273 .32628 .44019 .33455 .45305 .33008 .44563 .32177 Mtetra
.44563 .32177 .45305 .33008 .46597 .32559 .45859 .31723 Mtetra
.45859 .31723 .46597 .32559 .47895 .32107 .47161 .31268 Mtetra
.47161 .31268 .47895 .32107 .492 .31653 .4847 .3081 Mtetra
.4847 .3081 .492 .31653 .50511 .31198 .49785 .3035 Mtetra
.49785 .3035 .50511 .31198 .51828 .3074 .51106 .29888 Mtetra
.51106 .29888 .51828 .3074 .53151 .30279 .52433 .29424 Mtetra
.52433 .29424 .53151 .30279 .54481 .29817 .53767 .28957 Mtetra
.53767 .28957 .54481 .29817 .55817 .29352 .55108 .28488 Mtetra
.55108 .28488 .55817 .29352 .57195 .31232 .56455 .28017 Mtetra
.594 .463 .673 r
.56455 .28017 .57195 .31232 .58355 .20466 .57808 .27544 Mtetra
0 0 .184 r
.57808 .27544 .58355 .20466 .59676 .19987 .58996 .19098 Mtetra
.664 .741 .908 r
.58996 .19098 .59676 .19987 .61003 .19507 .60328 .18614 Mtetra
.60328 .18614 .61003 .19507 .62336 .19024 .61665 .18126 Mtetra
.61665 .18126 .62336 .19024 .63676 .18539 .63009 .17637 Mtetra
.63009 .17637 .63676 .18539 .65022 .18051 .6436 .17145 Mtetra
.6436 .17145 .65022 .18051 .66374 .17561 .65717 .16651 Mtetra
.65717 .16651 .66374 .17561 .67734 .17069 .6708 .16154 Mtetra
.6708 .16154 .67734 .17069 .69099 .16575 .68451 .15655 Mtetra
.68451 .15655 .69099 .16575 .70472 .16078 .69828 .15154 Mtetra
.69828 .15154 .70472 .16078 .7185 .15578 .71211 .1465 Mtetra
.71211 .1465 .7185 .15578 .73236 .15076 .72601 .14144 Mtetra
.72601 .14144 .73236 .15076 .74629 .14572 .73999 .13635 Mtetra
.73999 .13635 .74629 .14572 .76028 .14065 .75403 .13123 Mtetra
.75403 .13123 .76028 .14065 .77434 .13556 .76814 .12609 Mtetra
.654 .753 .922 r
.11502 .47087 .12353 .47822 .13517 .47425 .12669 .46687 Mtetra
.12669 .46687 .13517 .47425 .14686 .47026 .13841 .46285 Mtetra
.13841 .46285 .14686 .47026 .15861 .46625 .15019 .4588 Mtetra
.15019 .4588 .15861 .46625 .1704 .46223 .16202 .45474 Mtetra
.16202 .45474 .1704 .46223 .18226 .45818 .1739 .45067 Mtetra
.1739 .45067 .18226 .45818 .19417 .45412 .18584 .44657 Mtetra
.18584 .44657 .19417 .45412 .20613 .45004 .19784 .44245 Mtetra
.19784 .44245 .20613 .45004 .21815 .44594 .20989 .43831 Mtetra
.20989 .43831 .21815 .44594 .22702 .47732 .222 .43416 Mtetra
0 0 .47 r
.222 .43416 .22702 .47732 .23928 .47322 .23098 .4656 Mtetra
.651 .756 .927 r
.23098 .4656 .23928 .47322 .25159 .4691 .24333 .46144 Mtetra
.24333 .46144 .25159 .4691 .26396 .46496 .25573 .45726 Mtetra
.948 .607 .339 r
.25573 .45726 .26396 .46496 .27176 .522 .26339 .5144 Mtetra
.646 .762 .934 r
.26339 .5144 .27176 .522 .28447 .51789 .27614 .51025 Mtetra
.27614 .51025 .28447 .51789 .29725 .51376 .28895 .50609 Mtetra
.28895 .50609 .29725 .51376 .31008 .50961 .30183 .5019 Mtetra
.30183 .5019 .31008 .50961 .32298 .50544 .31476 .49769 Mtetra
.31476 .49769 .32298 .50544 .33594 .50125 .32777 .49347 Mtetra
.954 .712 .532 r
.32777 .49347 .33594 .50125 .35661 .3529 .34886 .34479 Mtetra
.658 .749 .917 r
.34886 .34479 .35661 .3529 .36915 .34852 .36143 .34037 Mtetra
.36143 .34037 .36915 .34852 .38174 .34411 .37406 .33592 Mtetra
.37406 .33592 .38174 .34411 .3944 .33969 .38676 .33146 Mtetra
.38676 .33146 .3944 .33969 .40712 .33524 .39951 .32697 Mtetra
.39951 .32697 .40712 .33524 .41989 .33077 .41233 .32246 Mtetra
.41233 .32246 .41989 .33077 .43273 .32628 .4252 .31793 Mtetra
.4252 .31793 .43273 .32628 .44563 .32177 .43814 .31338 Mtetra
.43814 .31338 .44563 .32177 .45859 .31723 .45114 .30881 Mtetra
.45114 .30881 .45859 .31723 .47161 .31268 .4642 .30421 Mtetra
.4642 .30421 .47161 .31268 .4847 .3081 .47733 .29959 Mtetra
.47733 .29959 .4847 .3081 .49785 .3035 .49052 .29495 Mtetra
.49052 .29495 .49785 .3035 .51106 .29888 .50377 .29029 Mtetra
.50377 .29029 .51106 .29888 .52433 .29424 .51709 .28561 Mtetra
.51709 .28561 .52433 .29424 .53767 .28957 .53047 .2809 Mtetra
.53047 .2809 .53767 .28957 .55108 .28488 .54392 .27617 Mtetra
.54392 .27617 .55108 .28488 .56455 .28017 .55743 .27141 Mtetra
.55743 .27141 .56455 .28017 .57808 .27544 .57101 .26664 Mtetra
.972 .735 .52 r
.57101 .26664 .57808 .27544 .58996 .19098 .58311 .18202 Mtetra
.664 .741 .908 r
.58311 .18202 .58996 .19098 .60328 .18614 .59647 .17712 Mtetra
.59647 .17712 .60328 .18614 .61665 .18126 .60989 .17221 Mtetra
.60989 .17221 .61665 .18126 .63009 .17637 .62337 .16727 Mtetra
.62337 .16727 .63009 .17637 .6436 .17145 .63692 .16231 Mtetra
.63692 .16231 .6436 .17145 .65717 .16651 .65053 .15732 Mtetra
.65053 .15732 .65717 .16651 .6708 .16154 .66421 .15231 Mtetra
.66421 .15231 .6708 .16154 .68451 .15655 .67796 .14728 Mtetra
.67796 .14728 .68451 .15655 .69828 .15154 .69178 .14222 Mtetra
.69178 .14222 .69828 .15154 .71211 .1465 .70566 .13713 Mtetra
.70566 .13713 .71211 .1465 .72601 .14144 .71961 .13202 Mtetra
.71961 .13202 .72601 .14144 .73999 .13635 .73363 .12689 Mtetra
.73363 .12689 .73999 .13635 .75403 .13123 .74772 .12173 Mtetra
.74772 .12173 .75403 .13123 .76814 .12609 .76188 .11654 Mtetra
.654 .753 .922 r
.10644 .46347 .11502 .47087 .12669 .46687 .11814 .45943 Mtetra
.11814 .45943 .12669 .46687 .13841 .46285 .12989 .45537 Mtetra
.12989 .45537 .13841 .46285 .15019 .4588 .1417 .45129 Mtetra
.1417 .45129 .15019 .4588 .16202 .45474 .15356 .4472 Mtetra
.15356 .4472 .16202 .45474 .1739 .45067 .16547 .44309 Mtetra
.16547 .44309 .1739 .45067 .18584 .44657 .17745 .43895 Mtetra
.17745 .43895 .18584 .44657 .19784 .44245 .18947 .4348 Mtetra
.18947 .4348 .19784 .44245 .20989 .43831 .20156 .43063 Mtetra
.922 .531 .215 r
.20156 .43063 .20989 .43831 .222 .43416 .21028 .46208 Mtetra
.404 .067 .277 r
.21028 .46208 .222 .43416 .23098 .4656 .22261 .45791 Mtetra
.651 .756 .927 r
.22261 .45791 .23098 .4656 .24333 .46144 .23499 .45372 Mtetra
.23499 .45372 .24333 .46144 .25573 .45726 .24743 .4495 Mtetra
.24743 .4495 .25573 .45726 .26339 .5144 .25993 .44527 Mtetra
0 0 .37 r
.25993 .44527 .26339 .5144 .27614 .51025 .26774 .50255 Mtetra
.646 .762 .934 r
.26774 .50255 .27614 .51025 .28895 .50609 .28059 .49834 Mtetra
.28059 .49834 .28895 .50609 .30183 .5019 .2935 .49412 Mtetra
.2935 .49412 .30183 .5019 .31476 .49769 .30647 .48987 Mtetra
.30647 .48987 .31476 .49769 .32777 .49347 .31951 .48561 Mtetra
.954 .712 .532 r
.31951 .48561 .32777 .49347 .34886 .34479 .34104 .33661 Mtetra
.658 .749 .917 r
.34104 .33661 .34886 .34479 .36143 .34037 .35365 .33215 Mtetra
.35365 .33215 .36143 .34037 .37406 .33592 .36632 .32766 Mtetra
.36632 .32766 .37406 .33592 .38676 .33146 .37905 .32316 Mtetra
.37905 .32316 .38676 .33146 .39951 .32697 .39184 .31863 Mtetra
.39184 .31863 .39951 .32697 .41233 .32246 .40469 .31408 Mtetra
.40469 .31408 .41233 .32246 .4252 .31793 .41761 .30951 Mtetra
.41761 .30951 .4252 .31793 .43814 .31338 .43059 .30492 Mtetra
.43059 .30492 .43814 .31338 .45114 .30881 .44363 .30031 Mtetra
.44363 .30031 .45114 .30881 .4642 .30421 .45673 .29567 Mtetra
.45673 .29567 .4642 .30421 .47733 .29959 .46989 .29101 Mtetra
.46989 .29101 .47733 .29959 .49052 .29495 .48312 .28633 Mtetra
.48312 .28633 .49052 .29495 .50377 .29029 .49642 .28162 Mtetra
.49642 .28162 .50377 .29029 .51709 .28561 .50978 .2769 Mtetra
.50978 .2769 .51709 .28561 .53047 .2809 .5232 .27215 Mtetra
.5232 .27215 .53047 .2809 .54392 .27617 .53669 .26737 Mtetra
.53669 .26737 .54392 .27617 .55743 .27141 .55025 .26258 Mtetra
.55025 .26258 .55743 .27141 .57101 .26664 .56388 .25775 Mtetra
.56388 .25775 .57101 .26664 .58311 .18202 .57757 .25291 Mtetra
0 0 .176 r
.57757 .25291 .58311 .18202 .59647 .17712 .5896 .16803 Mtetra
.664 .741 .908 r
.5896 .16803 .59647 .17712 .60989 .17221 .60306 .16307 Mtetra
.60306 .16307 .60989 .17221 .62337 .16727 .61659 .15809 Mtetra
.61659 .15809 .62337 .16727 .63692 .16231 .63018 .15308 Mtetra
.63018 .15308 .63692 .16231 .65053 .15732 .64384 .14805 Mtetra
.64384 .14805 .65053 .15732 .66421 .15231 .65757 .143 Mtetra
.65757 .143 .66421 .15231 .67796 .14728 .67136 .13792 Mtetra
.67136 .13792 .67796 .14728 .69178 .14222 .68522 .13281 Mtetra
.68522 .13281 .69178 .14222 .70566 .13713 .69915 .12768 Mtetra
.69915 .12768 .70566 .13713 .71961 .13202 .71315 .12252 Mtetra
.71315 .12252 .71961 .13202 .73363 .12689 .72722 .11734 Mtetra
.72722 .11734 .73363 .12689 .74772 .12173 .74135 .11213 Mtetra
.74135 .11213 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.654 .753 .922 r
.09779 .456 .10644 .46347 .11814 .45943 .10952 .45192 Mtetra
.10952 .45192 .11814 .45943 .12989 .45537 .1213 .44783 Mtetra
.1213 .44783 .12989 .45537 .1417 .45129 .13313 .44372 Mtetra
.13313 .44372 .1417 .45129 .15356 .4472 .14503 .43959 Mtetra
.14503 .43959 .15356 .4472 .16547 .44309 .15697 .43544 Mtetra
.15697 .43544 .16547 .44309 .17745 .43895 .16898 .43127 Mtetra
.16898 .43127 .17745 .43895 .18947 .4348 .18104 .42708 Mtetra
.18104 .42708 .18947 .4348 .20156 .43063 .19315 .42288 Mtetra
.922 .531 .215 r
.19315 .42288 .20156 .43063 .21028 .46208 .20181 .45436 Mtetra
.651 .756 .927 r
.20181 .45436 .21028 .46208 .22261 .45791 .21416 .45015 Mtetra
.21416 .45015 .22261 .45791 .23499 .45372 .22658 .44592 Mtetra
.22658 .44592 .23499 .45372 .24743 .4495 .23906 .44167 Mtetra
.23906 .44167 .24743 .4495 .25993 .44527 .2516 .4374 Mtetra
.2516 .4374 .25993 .44527 .26774 .50255 .26419 .43311 Mtetra
0 0 .37 r
.26419 .43311 .26774 .50255 .28059 .49834 .27214 .49053 Mtetra
.646 .762 .934 r
.27214 .49053 .28059 .49834 .2935 .49412 .28509 .48626 Mtetra
.28509 .48626 .2935 .49412 .30647 .48987 .2981 .48198 Mtetra
.2981 .48198 .30647 .48987 .31951 .48561 .31118 .47768 Mtetra
.31118 .47768 .31951 .48561 .34104 .33661 .32433 .47335 Mtetra
0 0 .098 r
.32433 .47335 .34104 .33661 .35365 .33215 .3458 .32385 Mtetra
.658 .749 .917 r
.3458 .32385 .35365 .33215 .36632 .32766 .3585 .31933 Mtetra
.3585 .31933 .36632 .32766 .37905 .32316 .37127 .31478 Mtetra
.37127 .31478 .37905 .32316 .39184 .31863 .3841 .31022 Mtetra
.3841 .31022 .39184 .31863 .40469 .31408 .39699 .30563 Mtetra
.39699 .30563 .40469 .31408 .41761 .30951 .40995 .30102 Mtetra
.40995 .30102 .41761 .30951 .43059 .30492 .42296 .29638 Mtetra
.42296 .29638 .43059 .30492 .44363 .30031 .43604 .29173 Mtetra
.43604 .29173 .44363 .30031 .45673 .29567 .44919 .28705 Mtetra
.44919 .28705 .45673 .29567 .46989 .29101 .46239 .28235 Mtetra
.46239 .28235 .46989 .29101 .48312 .28633 .47567 .27763 Mtetra
.47567 .27763 .48312 .28633 .49642 .28162 .489 .27288 Mtetra
.489 .27288 .49642 .28162 .50978 .2769 .5024 .26811 Mtetra
.5024 .26811 .50978 .2769 .5232 .27215 .51587 .26331 Mtetra
.51587 .26331 .5232 .27215 .53669 .26737 .52941 .2585 Mtetra
.52941 .2585 .53669 .26737 .55025 .26258 .54301 .25366 Mtetra
.54301 .25366 .55025 .26258 .56388 .25775 .55668 .24879 Mtetra
.55668 .24879 .56388 .25775 .57757 .25291 .57041 .2439 Mtetra
.57041 .2439 .57757 .25291 .5896 .16803 .58422 .23899 Mtetra
0 0 .176 r
.58422 .23899 .5896 .16803 .60306 .16307 .59617 .15386 Mtetra
.664 .741 .908 r
.59617 .15386 .60306 .16307 .61659 .15809 .60974 .14883 Mtetra
.60974 .14883 .61659 .15809 .63018 .15308 .62338 .14378 Mtetra
.62338 .14378 .63018 .15308 .64384 .14805 .63708 .1387 Mtetra
.63708 .1387 .64384 .14805 .65757 .143 .65086 .1336 Mtetra
.65086 .1336 .65757 .143 .67136 .13792 .6647 .12847 Mtetra
.6647 .12847 .67136 .13792 .68522 .13281 .6786 .12332 Mtetra
.6786 .12332 .68522 .13281 .69915 .12768 .69258 .11814 Mtetra
.69258 .11814 .69915 .12768 .71315 .12252 .70663 .11294 Mtetra
.70663 .11294 .71315 .12252 .72722 .11734 .72074 .10771 Mtetra
.72074 .10771 .72722 .11734 .74135 .11213 .73493 .10245 Mtetra
.73493 .10245 .74135 .11213 .75556 .1069 .74918 .09717 Mtetra
.654 .753 .922 r
.08906 .44846 .09779 .456 .10952 .45192 .10082 .44435 Mtetra
.10082 .44435 .10952 .45192 .1213 .44783 .11263 .44023 Mtetra
.11263 .44023 .1213 .44783 .13313 .44372 .1245 .43608 Mtetra
.1245 .43608 .13313 .44372 .14503 .43959 .13642 .43191 Mtetra
.13642 .43191 .14503 .43959 .15697 .43544 .1484 .42773 Mtetra
.1484 .42773 .15697 .43544 .16898 .43127 .16044 .42352 Mtetra
.16044 .42352 .16898 .43127 .18104 .42708 .17253 .4193 Mtetra
.923 .534 .223 r
.17253 .4193 .18104 .42708 .19315 .42288 .18092 .4508 Mtetra
.395 .055 .266 r
.18092 .4508 .19315 .42288 .20181 .45436 .19325 .44658 Mtetra
.651 .756 .927 r
.19325 .44658 .20181 .45436 .21416 .45015 .20565 .44233 Mtetra
.20565 .44233 .21416 .45015 .22658 .44592 .2181 .43806 Mtetra
.2181 .43806 .22658 .44592 .23906 .44167 .23061 .43377 Mtetra
.23061 .43377 .23906 .44167 .2516 .4374 .24318 .42946 Mtetra
.24318 .42946 .2516 .4374 .26419 .43311 .25581 .42514 Mtetra
.25581 .42514 .26419 .43311 .27214 .49053 .26851 .42079 Mtetra
0 0 .37 r
.26851 .42079 .27214 .49053 .28509 .48626 .27661 .47834 Mtetra
.646 .762 .934 r
.27661 .47834 .28509 .48626 .2981 .48198 .28966 .47402 Mtetra
.28966 .47402 .2981 .48198 .31118 .47768 .30278 .46967 Mtetra
.30278 .46967 .31118 .47768 .32433 .47335 .31596 .46531 Mtetra
.956 .712 .529 r
.31596 .46531 .32433 .47335 .3458 .32385 .33788 .31548 Mtetra
.658 .749 .917 r
.33788 .31548 .3458 .32385 .3585 .31933 .35062 .31092 Mtetra
.35062 .31092 .3585 .31933 .37127 .31478 .36343 .30634 Mtetra
.36343 .30634 .37127 .31478 .3841 .31022 .3763 .30173 Mtetra
.3763 .30173 .3841 .31022 .39699 .30563 .38923 .2971 Mtetra
.38923 .2971 .39699 .30563 .40995 .30102 .40222 .29245 Mtetra
.40222 .29245 .40995 .30102 .42296 .29638 .41527 .28777 Mtetra
.41527 .28777 .42296 .29638 .43604 .29173 .42839 .28307 Mtetra
.42839 .28307 .43604 .29173 .44919 .28705 .44158 .27835 Mtetra
.44158 .27835 .44919 .28705 .46239 .28235 .45483 .27361 Mtetra
.45483 .27361 .46239 .28235 .47567 .27763 .46814 .26884 Mtetra
.46814 .26884 .47567 .27763 .489 .27288 .48152 .26405 Mtetra
.48152 .26405 .489 .27288 .5024 .26811 .49496 .25924 Mtetra
.49496 .25924 .5024 .26811 .51587 .26331 .50847 .2544 Mtetra
.50847 .2544 .51587 .26331 .52941 .2585 .52205 .24954 Mtetra
.52205 .24954 .52941 .2585 .54301 .25366 .53569 .24466 Mtetra
.53569 .24466 .54301 .25366 .55668 .24879 .54941 .23975 Mtetra
.54941 .23975 .55668 .24879 .57041 .2439 .56319 .23481 Mtetra
.56319 .23481 .57041 .2439 .58422 .23899 .57704 .22985 Mtetra
.974 .736 .514 r
.57704 .22985 .58422 .23899 .59617 .15386 .58922 .14455 Mtetra
.664 .741 .908 r
.58922 .14455 .59617 .15386 .60974 .14883 .60283 .13948 Mtetra
.60283 .13948 .60974 .14883 .62338 .14378 .61652 .13438 Mtetra
.61652 .13438 .62338 .14378 .63708 .1387 .63027 .12926 Mtetra
.63027 .12926 .63708 .1387 .65086 .1336 .64408 .12411 Mtetra
.64408 .12411 .65086 .1336 .6647 .12847 .65797 .11894 Mtetra
.65797 .11894 .6647 .12847 .6786 .12332 .67193 .11374 Mtetra
.67193 .11374 .6786 .12332 .69258 .11814 .68595 .10851 Mtetra
.68595 .10851 .69258 .11814 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.654 .753 .922 r
.08026 .44086 .08906 .44846 .10082 .44435 .09204 .43672 Mtetra
.09204 .43672 .10082 .44435 .11263 .44023 .10389 .43256 Mtetra
.10389 .43256 .11263 .44023 .1245 .43608 .11579 .42837 Mtetra
.11579 .42837 .1245 .43608 .13642 .43191 .12774 .42417 Mtetra
.12774 .42417 .13642 .43191 .1484 .42773 .13975 .41995 Mtetra
.13975 .41995 .1484 .42773 .16044 .42352 .15182 .41571 Mtetra
.15182 .41571 .16044 .42352 .17253 .4193 .16394 .41145 Mtetra
.923 .534 .223 r
.16394 .41145 .17253 .4193 .18092 .4508 .17226 .44298 Mtetra
.651 .756 .927 r
.17226 .44298 .18092 .4508 .19325 .44658 .18463 .43872 Mtetra
.18463 .43872 .19325 .44658 .20565 .44233 .19705 .43443 Mtetra
.19705 .43443 .20565 .44233 .2181 .43806 .20954 .43013 Mtetra
.20954 .43013 .2181 .43806 .23061 .43377 .22209 .4258 Mtetra
.22209 .4258 .23061 .43377 .24318 .42946 .23469 .42146 Mtetra
.23469 .42146 .24318 .42946 .25581 .42514 .24736 .41709 Mtetra
.24736 .41709 .25581 .42514 .26851 .42079 .26009 .4127 Mtetra
.26009 .4127 .26851 .42079 .27661 .47834 .27289 .40829 Mtetra
.552 .367 .585 r
.27289 .40829 .27661 .47834 .28966 .47402 .28574 .40385 Mtetra
0 0 .376 r
.28574 .40385 .28966 .47402 .30278 .46967 .29429 .46159 Mtetra
.646 .762 .934 r
.29429 .46159 .30278 .46967 .31596 .46531 .30752 .45719 Mtetra
.956 .712 .529 r
.30752 .45719 .31596 .46531 .33788 .31548 .32988 .30704 Mtetra
.658 .749 .917 r
.32988 .30704 .33788 .31548 .35062 .31092 .34267 .30244 Mtetra
.34267 .30244 .35062 .31092 .36343 .30634 .35551 .29781 Mtetra
.35551 .29781 .36343 .30634 .3763 .30173 .36842 .29316 Mtetra
.36842 .29316 .3763 .30173 .38923 .2971 .38139 .28849 Mtetra
.38139 .28849 .38923 .2971 .40222 .29245 .39442 .2838 Mtetra
.39442 .2838 .40222 .29245 .41527 .28777 .40751 .27908 Mtetra
.40751 .27908 .41527 .28777 .42839 .28307 .42067 .27434 Mtetra
.42067 .27434 .42839 .28307 .44158 .27835 .4339 .26958 Mtetra
.4339 .26958 .44158 .27835 .45483 .27361 .44719 .26479 Mtetra
.44719 .26479 .45483 .27361 .46814 .26884 .46054 .25998 Mtetra
.46054 .25998 .46814 .26884 .48152 .26405 .47396 .25515 Mtetra
.47396 .25515 .48152 .26405 .49496 .25924 .48745 .25029 Mtetra
.48745 .25029 .49496 .25924 .50847 .2544 .501 .24541 Mtetra
.501 .24541 .50847 .2544 .52205 .24954 .51463 .2405 Mtetra
.51463 .2405 .52205 .24954 .53569 .24466 .52832 .23557 Mtetra
.52832 .23557 .53569 .24466 .54941 .23975 .54207 .23062 Mtetra
.54207 .23062 .54941 .23975 .56319 .23481 .5559 .22564 Mtetra
.5559 .22564 .56319 .23481 .57704 .22985 .5698 .22063 Mtetra
.5698 .22063 .57704 .22985 .58922 .14455 .58376 .2156 Mtetra
0 0 .168 r
.58376 .2156 .58922 .14455 .60283 .13948 .59586 .13005 Mtetra
.664 .741 .908 r
.59586 .13005 .60283 .13948 .61652 .13438 .60959 .12491 Mtetra
.60959 .12491 .61652 .13438 .63027 .12926 .62339 .11974 Mtetra
.62339 .11974 .63027 .12926 .64408 .12411 .63725 .11454 Mtetra
.63725 .11454 .64408 .12411 .65797 .11894 .65119 .10932 Mtetra
.65119 .10932 .65797 .11894 .67193 .11374 .66519 .10407 Mtetra
.66519 .10407 .67193 .11374 .68595 .10851 .67926 .0988 Mtetra
.67926 .0988 .68595 .10851 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.654 .753 .922 r
.07138 .4332 .08026 .44086 .09204 .43672 .0832 .42902 Mtetra
.0832 .42902 .09204 .43672 .10389 .43256 .09507 .42482 Mtetra
.09507 .42482 .10389 .43256 .11579 .42837 .107 .4206 Mtetra
.107 .4206 .11579 .42837 .12774 .42417 .11899 .41636 Mtetra
.11899 .41636 .12774 .42417 .13975 .41995 .13103 .4121 Mtetra
.13103 .4121 .13975 .41995 .15182 .41571 .14313 .40782 Mtetra
.924 .536 .23 r
.14313 .40782 .15182 .41571 .16394 .41145 .15118 .43938 Mtetra
.386 .042 .254 r
.15118 .43938 .16394 .41145 .17226 .44298 .16352 .43509 Mtetra
.651 .756 .927 r
.16352 .43509 .17226 .44298 .18463 .43872 .17592 .43079 Mtetra
.17592 .43079 .18463 .43872 .19705 .43443 .18838 .42647 Mtetra
.18838 .42647 .19705 .43443 .20954 .43013 .2009 .42213 Mtetra
.2009 .42213 .20954 .43013 .22209 .4258 .21348 .41776 Mtetra
.21348 .41776 .22209 .4258 .23469 .42146 .22613 .41337 Mtetra
.22613 .41337 .23469 .42146 .24736 .41709 .23883 .40897 Mtetra
.23883 .40897 .24736 .41709 .26009 .4127 .2516 .40454 Mtetra
.2516 .40454 .26009 .4127 .27289 .40829 .26443 .40009 Mtetra
.26443 .40009 .27289 .40829 .28574 .40385 .27732 .39561 Mtetra
.27732 .39561 .28574 .40385 .29429 .46159 .29028 .39112 Mtetra
0 0 .376 r
.29028 .39112 .29429 .46159 .30752 .45719 .29899 .44899 Mtetra
.956 .712 .529 r
.29899 .44899 .30752 .45719 .32988 .30704 .32182 .29853 Mtetra
.658 .749 .917 r
.32182 .29853 .32988 .30704 .34267 .30244 .33464 .29388 Mtetra
.33464 .29388 .34267 .30244 .35551 .29781 .34752 .28921 Mtetra
.34752 .28921 .35551 .29781 .36842 .29316 .36047 .28452 Mtetra
.36047 .28452 .36842 .29316 .38139 .28849 .37348 .27981 Mtetra
.37348 .27981 .38139 .28849 .39442 .2838 .38655 .27507 Mtetra
.38655 .27507 .39442 .2838 .40751 .27908 .39969 .27031 Mtetra
.39969 .27031 .40751 .27908 .42067 .27434 .41289 .26553 Mtetra
.41289 .26553 .42067 .27434 .4339 .26958 .42615 .26072 Mtetra
.42615 .26072 .4339 .26958 .44719 .26479 .43948 .25589 Mtetra
.43948 .25589 .44719 .26479 .46054 .25998 .45288 .25104 Mtetra
.45288 .25104 .46054 .25998 .47396 .25515 .46634 .24616 Mtetra
.46634 .24616 .47396 .25515 .48745 .25029 .47987 .24126 Mtetra
.47987 .24126 .48745 .25029 .501 .24541 .49347 .23633 Mtetra
.49347 .23633 .501 .24541 .51463 .2405 .50713 .23138 Mtetra
.50713 .23138 .51463 .2405 .52832 .23557 .52087 .2264 Mtetra
.52087 .2264 .52832 .23557 .54207 .23062 .53467 .2214 Mtetra
.53467 .2214 .54207 .23062 .5559 .22564 .54854 .21638 Mtetra
.54854 .21638 .5559 .22564 .5698 .22063 .56249 .21132 Mtetra
.56249 .21132 .5698 .22063 .58376 .2156 .5765 .20625 Mtetra
.5765 .20625 .58376 .2156 .59586 .13005 .59058 .20114 Mtetra
0 0 .168 r
.59058 .20114 .59586 .13005 .60959 .12491 .60261 .11534 Mtetra
.664 .741 .908 r
.60261 .11534 .60959 .12491 .62339 .11974 .61645 .11012 Mtetra
.61645 .11012 .62339 .11974 .63725 .11454 .63036 .10488 Mtetra
.63036 .10488 .63725 .11454 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09431 Mtetra
.65839 .09431 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.654 .753 .922 r
.06242 .42547 .07138 .4332 .0832 .42902 .07427 .42125 Mtetra
.07427 .42125 .0832 .42902 .09507 .42482 .08618 .41702 Mtetra
.08618 .41702 .09507 .42482 .107 .4206 .09814 .41276 Mtetra
.09814 .41276 .107 .4206 .11899 .41636 .11015 .40848 Mtetra
.11015 .40848 .11899 .41636 .13103 .4121 .12223 .40419 Mtetra
.12223 .40419 .13103 .4121 .14313 .40782 .13436 .39987 Mtetra
.924 .536 .23 r
.13436 .39987 .14313 .40782 .15118 .43938 .14233 .43146 Mtetra
.651 .756 .927 r
.14233 .43146 .15118 .43938 .16352 .43509 .1547 .42714 Mtetra
.1547 .42714 .16352 .43509 .17592 .43079 .16714 .4228 Mtetra
.16714 .4228 .17592 .43079 .18838 .42647 .17963 .41843 Mtetra
.17963 .41843 .18838 .42647 .2009 .42213 .19219 .41405 Mtetra
.19219 .41405 .2009 .42213 .21348 .41776 .20481 .40965 Mtetra
.20481 .40965 .21348 .41776 .22613 .41337 .21749 .40522 Mtetra
.21749 .40522 .22613 .41337 .23883 .40897 .23023 .40077 Mtetra
.23023 .40077 .23883 .40897 .2516 .40454 .24303 .3963 Mtetra
.24303 .3963 .2516 .40454 .26443 .40009 .2559 .39181 Mtetra
.2559 .39181 .26443 .40009 .27732 .39561 .26883 .3873 Mtetra
.26883 .3873 .27732 .39561 .29028 .39112 .28182 .38276 Mtetra
.28182 .38276 .29028 .39112 .29899 .44899 .29488 .3782 Mtetra
0 0 .376 r
.29488 .3782 .29899 .44899 .32182 .29853 .30376 .43621 Mtetra
0 0 .07 r
.30376 .43621 .32182 .29853 .33464 .29388 .32655 .28525 Mtetra
.658 .749 .917 r
.32655 .28525 .33464 .29388 .34752 .28921 .33947 .28054 Mtetra
.33947 .28054 .34752 .28921 .36047 .28452 .35245 .2758 Mtetra
.35245 .2758 .36047 .28452 .37348 .27981 .3655 .27105 Mtetra
.3655 .27105 .37348 .27981 .38655 .27507 .37861 .26627 Mtetra
.37861 .26627 .38655 .27507 .39969 .27031 .39178 .26146 Mtetra
.39178 .26146 .39969 .27031 .41289 .26553 .40503 .25664 Mtetra
.40503 .25664 .41289 .26553 .42615 .26072 .41833 .25179 Mtetra
.41833 .25179 .42615 .26072 .43948 .25589 .4317 .24691 Mtetra
.4317 .24691 .43948 .25589 .45288 .25104 .44514 .24201 Mtetra
.44514 .24201 .45288 .25104 .46634 .24616 .45865 .23709 Mtetra
.45865 .23709 .46634 .24616 .47987 .24126 .47222 .23214 Mtetra
.47222 .23214 .47987 .24126 .49347 .23633 .48586 .22717 Mtetra
.48586 .22717 .49347 .23633 .50713 .23138 .49957 .22217 Mtetra
.49957 .22217 .50713 .23138 .52087 .2264 .51335 .21715 Mtetra
.51335 .21715 .52087 .2264 .53467 .2214 .5272 .2121 Mtetra
.5272 .2121 .53467 .2214 .54854 .21638 .54112 .20703 Mtetra
.54112 .20703 .54854 .21638 .56249 .21132 .55511 .20193 Mtetra
.55511 .20193 .56249 .21132 .5765 .20625 .56917 .19681 Mtetra
.56917 .19681 .5765 .20625 .59058 .20114 .5833 .19165 Mtetra
.977 .736 .506 r
.5833 .19165 .59058 .20114 .60261 .11534 .59555 .10569 Mtetra
.664 .741 .908 r
.59555 .10569 .60261 .11534 .61645 .11012 .60944 .10042 Mtetra
.60944 .10042 .61645 .11012 .63036 .10488 .6234 .09513 Mtetra
.6234 .09513 .63036 .10488 .64434 .09961 .63742 .08981 Mtetra
.63742 .08981 .64434 .09961 .65839 .09431 .65152 .08447 Mtetra
.65152 .08447 .65839 .09431 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.654 .753 .922 r
.05339 .41767 .06242 .42547 .07427 .42125 .06527 .41342 Mtetra
.06527 .41342 .07427 .42125 .08618 .41702 .0772 .40914 Mtetra
.0772 .40914 .08618 .41702 .09814 .41276 .0892 .40485 Mtetra
.0892 .40485 .09814 .41276 .11015 .40848 .10124 .40054 Mtetra
.10124 .40054 .11015 .40848 .12223 .40419 .11335 .3962 Mtetra
.11335 .3962 .12223 .40419 .13436 .39987 .12551 .39185 Mtetra
.924 .536 .23 r
.12551 .39185 .13436 .39987 .14233 .43146 .1334 .42346 Mtetra
.651 .756 .927 r
.1334 .42346 .14233 .43146 .1547 .42714 .14581 .41911 Mtetra
.14581 .41911 .1547 .42714 .16714 .4228 .15827 .41473 Mtetra
.15827 .41473 .16714 .4228 .17963 .41843 .1708 .41033 Mtetra
.1708 .41033 .17963 .41843 .19219 .41405 .1834 .4059 Mtetra
.1834 .4059 .19219 .41405 .20481 .40965 .19605 .40146 Mtetra
.19605 .40146 .20481 .40965 .21749 .40522 .20876 .39699 Mtetra
.20876 .39699 .21749 .40522 .23023 .40077 .22154 .3925 Mtetra
.22154 .3925 .23023 .40077 .24303 .3963 .23438 .38799 Mtetra
.23438 .38799 .24303 .3963 .2559 .39181 .24729 .38346 Mtetra
.24729 .38346 .2559 .39181 .26883 .3873 .26026 .37891 Mtetra
.26026 .37891 .26883 .3873 .28182 .38276 .27329 .37433 Mtetra
.27329 .37433 .28182 .38276 .29488 .3782 .28639 .36973 Mtetra
.28639 .36973 .29488 .3782 .30376 .43621 .29955 .3651 Mtetra
.806 .561 .567 r
.29955 .3651 .30376 .43621 .32655 .28525 .31838 .27653 Mtetra
.658 .749 .917 r
.31838 .27653 .32655 .28525 .33947 .28054 .33133 .27178 Mtetra
.33133 .27178 .33947 .28054 .35245 .2758 .34436 .267 Mtetra
.34436 .267 .35245 .2758 .3655 .27105 .35744 .26221 Mtetra
.35744 .26221 .3655 .27105 .37861 .26627 .3706 .25738 Mtetra
.3706 .25738 .37861 .26627 .39178 .26146 .38381 .25254 Mtetra
.38381 .25254 .39178 .26146 .40503 .25664 .39709 .24767 Mtetra
.39709 .24767 .40503 .25664 .41833 .25179 .41044 .24277 Mtetra
.41044 .24277 .41833 .25179 .4317 .24691 .42385 .23785 Mtetra
.42385 .23785 .4317 .24691 .44514 .24201 .43734 .23291 Mtetra
.43734 .23291 .44514 .24201 .45865 .23709 .45088 .22794 Mtetra
.45088 .22794 .45865 .23709 .47222 .23214 .4645 .22294 Mtetra
.4645 .22294 .47222 .23214 .48586 .22717 .47819 .21793 Mtetra
.47819 .21793 .48586 .22717 .49957 .22217 .49194 .21288 Mtetra
.49194 .21288 .49957 .22217 .51335 .21715 .50576 .20781 Mtetra
.50576 .20781 .51335 .21715 .5272 .2121 .51966 .20272 Mtetra
.51966 .20272 .5272 .2121 .54112 .20703 .53362 .1976 Mtetra
.53362 .1976 .54112 .20703 .55511 .20193 .54766 .19245 Mtetra
.54766 .19245 .55511 .20193 .56917 .19681 .56177 .18728 Mtetra
.56177 .18728 .56917 .19681 .5833 .19165 .57595 .18208 Mtetra
.57595 .18208 .5833 .19165 .59555 .10569 .5902 .17685 Mtetra
0 0 .16 r
.5902 .17685 .59555 .10569 .60944 .10042 .60237 .09063 Mtetra
.664 .741 .908 r
.60237 .09063 .60944 .10042 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63742 .08981 .63045 .07992 Mtetra
.63045 .07992 .63742 .08981 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.654 .753 .922 r
.04428 .4098 .05339 .41767 .06527 .41342 .05619 .40551 Mtetra
.05619 .40551 .06527 .41342 .0772 .40914 .06815 .4012 Mtetra
.06815 .4012 .0772 .40914 .0892 .40485 .08018 .39687 Mtetra
.08018 .39687 .0892 .40485 .10124 .40054 .09226 .39252 Mtetra
.09226 .39252 .10124 .40054 .11335 .3962 .10439 .38815 Mtetra
.10439 .38815 .11335 .3962 .12551 .39185 .11659 .38375 Mtetra
.924 .536 .23 r
.11659 .38375 .12551 .39185 .1334 .42346 .12439 .4154 Mtetra
.651 .756 .927 r
.12439 .4154 .1334 .42346 .14581 .41911 .13683 .411 Mtetra
.13683 .411 .14581 .41911 .15827 .41473 .14933 .40658 Mtetra
.14933 .40658 .15827 .41473 .1708 .41033 .1619 .40214 Mtetra
.1619 .40214 .1708 .41033 .1834 .4059 .17452 .39768 Mtetra
.17452 .39768 .1834 .4059 .19605 .40146 .18721 .3932 Mtetra
.18721 .3932 .19605 .40146 .20876 .39699 .19996 .38869 Mtetra
.19996 .38869 .20876 .39699 .22154 .3925 .21278 .38416 Mtetra
.21278 .38416 .22154 .3925 .23438 .38799 .22566 .37961 Mtetra
.22566 .37961 .23438 .38799 .24729 .38346 .2386 .37503 Mtetra
.2386 .37503 .24729 .38346 .26026 .37891 .25161 .37044 Mtetra
.25161 .37044 .26026 .37891 .27329 .37433 .26468 .36582 Mtetra
.26468 .36582 .27329 .37433 .28639 .36973 .27782 .36117 Mtetra
.27782 .36117 .28639 .36973 .29955 .3651 .29102 .35651 Mtetra
.29102 .35651 .29955 .3651 .31838 .27653 .30429 .35182 Mtetra
0 0 0 r
.30429 .35182 .31838 .27653 .33133 .27178 .32313 .26295 Mtetra
.658 .749 .917 r
.32313 .26295 .33133 .27178 .34436 .267 .33619 .25813 Mtetra
.33619 .25813 .34436 .267 .35744 .26221 .34932 .25328 Mtetra
.34932 .25328 .35744 .26221 .3706 .25738 .36251 .24842 Mtetra
.36251 .24842 .3706 .25738 .38381 .25254 .37577 .24352 Mtetra
.37577 .24352 .38381 .25254 .39709 .24767 .38909 .23861 Mtetra
.38909 .23861 .39709 .24767 .41044 .24277 .40248 .23367 Mtetra
.40248 .23367 .41044 .24277 .42385 .23785 .41593 .2287 Mtetra
.41593 .2287 .42385 .23785 .43734 .23291 .42946 .22371 Mtetra
.42946 .22371 .43734 .23291 .45088 .22794 .44305 .2187 Mtetra
.44305 .2187 .45088 .22794 .4645 .22294 .45671 .21366 Mtetra
.45671 .21366 .4645 .22294 .47819 .21793 .47044 .20859 Mtetra
.47044 .20859 .47819 .21793 .49194 .21288 .48424 .2035 Mtetra
.48424 .2035 .49194 .21288 .50576 .20781 .49811 .19839 Mtetra
.49811 .19839 .50576 .20781 .51966 .20272 .51205 .19324 Mtetra
.51205 .19324 .51966 .20272 .53362 .1976 .52606 .18807 Mtetra
.52606 .18807 .53362 .1976 .54766 .19245 .54014 .18288 Mtetra
.54014 .18288 .54766 .19245 .56177 .18728 .55429 .17765 Mtetra
.55429 .17765 .56177 .18728 .57595 .18208 .56852 .17241 Mtetra
.56852 .17241 .57595 .18208 .5902 .17685 .58282 .16713 Mtetra
.58282 .16713 .5902 .17685 .60237 .09063 .5972 .16182 Mtetra
0 0 .16 r
.5972 .16182 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.664 .741 .908 r
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.654 .753 .922 r
.03509 .40187 .04428 .4098 .05619 .40551 .04702 .39754 Mtetra
.04702 .39754 .05619 .40551 .06815 .4012 .05902 .39319 Mtetra
.05902 .39319 .06815 .4012 .08018 .39687 .07108 .38882 Mtetra
.07108 .38882 .08018 .39687 .09226 .39252 .08319 .38443 Mtetra
.08319 .38443 .09226 .39252 .10439 .38815 .09536 .38002 Mtetra
.09536 .38002 .10439 .38815 .11659 .38375 .10759 .37559 Mtetra
.924 .536 .23 r
.10759 .37559 .11659 .38375 .12439 .4154 .11529 .40727 Mtetra
.651 .756 .927 r
.11529 .40727 .12439 .4154 .13683 .411 .12777 .40283 Mtetra
.12777 .40283 .13683 .411 .14933 .40658 .14031 .39837 Mtetra
.14031 .39837 .14933 .40658 .1619 .40214 .15291 .39389 Mtetra
.15291 .39389 .1619 .40214 .17452 .39768 .16557 .38938 Mtetra
.16557 .38938 .17452 .39768 .18721 .3932 .17829 .38486 Mtetra
.17829 .38486 .18721 .3932 .19996 .38869 .19108 .38031 Mtetra
.19108 .38031 .19996 .38869 .21278 .38416 .20393 .37574 Mtetra
.20393 .37574 .21278 .38416 .22566 .37961 .21685 .37115 Mtetra
.21685 .37115 .22566 .37961 .2386 .37503 .22983 .36653 Mtetra
.22983 .36653 .2386 .37503 .25161 .37044 .24287 .36189 Mtetra
.24287 .36189 .25161 .37044 .26468 .36582 .25599 .35723 Mtetra
.25599 .35723 .26468 .36582 .27782 .36117 .26916 .35254 Mtetra
.26916 .35254 .27782 .36117 .29102 .35651 .28241 .34783 Mtetra
.28241 .34783 .29102 .35651 .30429 .35182 .29572 .3431 Mtetra
.953 .727 .559 r
.29572 .3431 .30429 .35182 .32313 .26295 .31485 .25403 Mtetra
.658 .749 .917 r
.31485 .25403 .32313 .26295 .33619 .25813 .32795 .24917 Mtetra
.32795 .24917 .33619 .25813 .34932 .25328 .34112 .24428 Mtetra
.34112 .24428 .34932 .25328 .36251 .24842 .35435 .23937 Mtetra
.35435 .23937 .36251 .24842 .37577 .24352 .36765 .23443 Mtetra
.36765 .23443 .37577 .24352 .38909 .23861 .38101 .22947 Mtetra
.38101 .22947 .38909 .23861 .40248 .23367 .39444 .22448 Mtetra
.39444 .22448 .40248 .23367 .41593 .2287 .40794 .21947 Mtetra
.40794 .21947 .41593 .2287 .42946 .22371 .4215 .21444 Mtetra
.4215 .21444 .42946 .22371 .44305 .2187 .43514 .20938 Mtetra
.43514 .20938 .44305 .2187 .45671 .21366 .44884 .20429 Mtetra
.44884 .20429 .45671 .21366 .47044 .20859 .46262 .19917 Mtetra
.46262 .19917 .47044 .20859 .48424 .2035 .47646 .19404 Mtetra
.47646 .19404 .48424 .2035 .49811 .19839 .49038 .18887 Mtetra
.49038 .18887 .49811 .19839 .51205 .19324 .50436 .18368 Mtetra
.50436 .18368 .51205 .19324 .52606 .18807 .51842 .17846 Mtetra
.51842 .17846 .52606 .18807 .54014 .18288 .53255 .17321 Mtetra
.53255 .17321 .54014 .18288 .55429 .17765 .54675 .16794 Mtetra
.54675 .16794 .55429 .17765 .56852 .17241 .56103 .16264 Mtetra
.56103 .16264 .56852 .17241 .58282 .16713 .57538 .15732 Mtetra
.57538 .15732 .58282 .16713 .5972 .16182 .5898 .15196 Mtetra
.979 .737 .499 r
.5898 .15196 .5972 .16182 .60929 .07536 .60213 .06534 Mtetra
.664 .741 .908 r
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.654 .753 .922 r
.02581 .39386 .03509 .40187 .04702 .39754 .03778 .3895 Mtetra
.03778 .3895 .04702 .39754 .05902 .39319 .04981 .38511 Mtetra
.04981 .38511 .05902 .39319 .07108 .38882 .0619 .3807 Mtetra
.0619 .3807 .07108 .38882 .08319 .38443 .07404 .37627 Mtetra
.07404 .37627 .08319 .38443 .09536 .38002 .08624 .37182 Mtetra
.08624 .37182 .09536 .38002 .10759 .37559 .0985 .36735 Mtetra
.924 .536 .23 r
.0985 .36735 .10759 .37559 .11529 .40727 .10612 .39906 Mtetra
.651 .756 .927 r
.10612 .39906 .11529 .40727 .12777 .40283 .11863 .39458 Mtetra
.11863 .39458 .12777 .40283 .14031 .39837 .1312 .39008 Mtetra
.1312 .39008 .14031 .39837 .15291 .39389 .14384 .38556 Mtetra
.14384 .38556 .15291 .39389 .16557 .38938 .15654 .38101 Mtetra
.15654 .38101 .16557 .38938 .17829 .38486 .1693 .37644 Mtetra
.1693 .37644 .17829 .38486 .19108 .38031 .18212 .37185 Mtetra
.18212 .37185 .19108 .38031 .20393 .37574 .19501 .36724 Mtetra
.19501 .36724 .20393 .37574 .21685 .37115 .20796 .3626 Mtetra
.20796 .3626 .21685 .37115 .22983 .36653 .22098 .35795 Mtetra
.22098 .35795 .22983 .36653 .24287 .36189 .23406 .35326 Mtetra
.23406 .35326 .24287 .36189 .25599 .35723 .24721 .34856 Mtetra
.24721 .34856 .25599 .35723 .26916 .35254 .26043 .34383 Mtetra
.26043 .34383 .26916 .35254 .28241 .34783 .27371 .33907 Mtetra
.27371 .33907 .28241 .34783 .29572 .3431 .28706 .33429 Mtetra
.28706 .33429 .29572 .3431 .31485 .25403 .30048 .32949 Mtetra
0 0 0 r
.30048 .32949 .31485 .25403 .32795 .24917 .31963 .24012 Mtetra
.658 .749 .917 r
.31963 .24012 .32795 .24917 .34112 .24428 .33284 .23519 Mtetra
.33284 .23519 .34112 .24428 .35435 .23937 .34611 .23023 Mtetra
.34611 .23023 .35435 .23937 .36765 .23443 .35945 .22525 Mtetra
.35945 .22525 .36765 .23443 .38101 .22947 .37286 .22025 Mtetra
.37286 .22025 .38101 .22947 .39444 .22448 .38633 .21521 Mtetra
.38633 .21521 .39444 .22448 .40794 .21947 .39987 .21016 Mtetra
.39987 .21016 .40794 .21947 .4215 .21444 .41348 .20507 Mtetra
.41348 .20507 .4215 .21444 .43514 .20938 .42716 .19996 Mtetra
.42716 .19996 .43514 .20938 .44884 .20429 .44091 .19483 Mtetra
.44091 .19483 .44884 .20429 .46262 .19917 .45472 .18967 Mtetra
.45472 .18967 .46262 .19917 .47646 .19404 .46861 .18448 Mtetra
.46861 .18448 .47646 .19404 .49038 .18887 .48257 .17926 Mtetra
.48257 .17926 .49038 .18887 .50436 .18368 .49661 .17402 Mtetra
.49661 .17402 .50436 .18368 .51842 .17846 .51071 .16876 Mtetra
.51071 .16876 .51842 .17846 .53255 .17321 .52489 .16346 Mtetra
.52489 .16346 .53255 .17321 .54675 .16794 .53914 .15814 Mtetra
.53914 .15814 .54675 .16794 .56103 .16264 .55346 .15279 Mtetra
.55346 .15279 .56103 .16264 .57538 .15732 .56786 .14741 Mtetra
.56786 .14741 .57538 .15732 .5898 .15196 .58234 .142 Mtetra
.58234 .142 .5898 .15196 .60213 .06534 .59689 .13657 Mtetra
0 0 .152 r
.59689 .13657 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.664 .741 .908 r
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.654 .753 .922 r
.01646 .38579 .02581 .39386 .03778 .3895 .02846 .38138 Mtetra
.02846 .38138 .03778 .3895 .04981 .38511 .04052 .37695 Mtetra
.04052 .37695 .04981 .38511 .0619 .3807 .05263 .37251 Mtetra
.05263 .37251 .0619 .3807 .07404 .37627 .06481 .36804 Mtetra
.06481 .36804 .07404 .37627 .08624 .37182 .07704 .36355 Mtetra
.07704 .36355 .08624 .37182 .0985 .36735 .08934 .35904 Mtetra
.924 .536 .23 r
.08934 .35904 .0985 .36735 .10612 .39906 .09686 .39077 Mtetra
.651 .756 .927 r
.09686 .39077 .10612 .39906 .11863 .39458 .10941 .38625 Mtetra
.10941 .38625 .11863 .39458 .1312 .39008 .12201 .38171 Mtetra
.12201 .38171 .1312 .39008 .14384 .38556 .13468 .37715 Mtetra
.13468 .37715 .14384 .38556 .15654 .38101 .14742 .37256 Mtetra
.14742 .37256 .15654 .38101 .1693 .37644 .16021 .36795 Mtetra
.16021 .36795 .1693 .37644 .18212 .37185 .17307 .36332 Mtetra
.17307 .36332 .18212 .37185 .19501 .36724 .186 .35866 Mtetra
.186 .35866 .19501 .36724 .20796 .3626 .19899 .35398 Mtetra
.19899 .35398 .20796 .3626 .22098 .35795 .21205 .34928 Mtetra
.21205 .34928 .22098 .35795 .23406 .35326 .22517 .34455 Mtetra
.22517 .34455 .23406 .35326 .24721 .34856 .23836 .3398 Mtetra
.23836 .3398 .24721 .34856 .26043 .34383 .25161 .33503 Mtetra
.25161 .33503 .26043 .34383 .27371 .33907 .26494 .33023 Mtetra
.26494 .33023 .27371 .33907 .28706 .33429 .27833 .32541 Mtetra
.27833 .32541 .28706 .33429 .30048 .32949 .29179 .32056 Mtetra
.954 .727 .557 r
.29179 .32056 .30048 .32949 .31963 .24012 .31124 .231 Mtetra
.658 .749 .917 r
.31124 .231 .31963 .24012 .33284 .23519 .32449 .22602 Mtetra
.32449 .22602 .33284 .23519 .34611 .23023 .3378 .22102 Mtetra
.3378 .22102 .34611 .23023 .35945 .22525 .35118 .21599 Mtetra
.35118 .21599 .35945 .22525 .37286 .22025 .36463 .21094 Mtetra
.36463 .21094 .37286 .22025 .38633 .21521 .37814 .20586 Mtetra
.37814 .20586 .38633 .21521 .39987 .21016 .39172 .20075 Mtetra
.39172 .20075 .39987 .21016 .41348 .20507 .40538 .19562 Mtetra
.40538 .19562 .41348 .20507 .42716 .19996 .4191 .19046 Mtetra
.4191 .19046 .42716 .19996 .44091 .19483 .43289 .18528 Mtetra
.43289 .18528 .44091 .19483 .45472 .18967 .44675 .18007 Mtetra
.44675 .18007 .45472 .18967 .46861 .18448 .46069 .17483 Mtetra
.46069 .17483 .46861 .18448 .48257 .17926 .4747 .16957 Mtetra
.4747 .16957 .48257 .17926 .49661 .17402 .48877 .16428 Mtetra
.48877 .16428 .49661 .17402 .51071 .16876 .50293 .15896 Mtetra
.50293 .15896 .51071 .16876 .52489 .16346 .51715 .15361 Mtetra
.51715 .15361 .52489 .16346 .53914 .15814 .53145 .14824 Mtetra
.53145 .14824 .53914 .15814 .55346 .15279 .54582 .14283 Mtetra
.54582 .14283 .55346 .15279 .56786 .14741 .56027 .1374 Mtetra
.56027 .1374 .56786 .14741 .58234 .142 .5748 .13195 Mtetra
.5748 .13195 .58234 .142 .59689 .13657 .5894 .12646 Mtetra
.5894 .12646 .59689 .13657 .60913 .0497 .60408 .12094 Mtetra
0 0 .152 r
.60408 .12094 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.664 .741 .908 r
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 154.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000VR000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00QOooool2o`000<Cooooo0_l0
0013ooooo`00P_ooool3o`000003ooooool0003ooooo0<3ooooo0ol000000ooooooo0000ooooo`12
ooooo`00P?ooool2o`0000Cooooo0_l0002nooooo`;o00000oooool00`2Y_NSo0000o`000012oooo
o`00OOooool3o`0000Kooooo00?o0000ooooool00000^_ooool3o`0000?ooooo0`2Y_NP00ol0003o
ooooo`000011ooooo`00N_ooool3o`0000Wooooo00?o0000ooooool00000^?ooool2o`0000?ooooo
1P2Y_NP00ol00000ZKgXo`000011ooooo`00N?ooool2o`0000cooooo00Co0000oooooooooooo0000
]?ooool3o`0000;ooooo2@2Y_NP01?l00000ZKgX0:Vmj?l00010ooooo`00MOooool3o`0000kooooo
00Go0000ooooooooooooooooo`00002`ooooo`?o00000oooool;0:Vmj005o`00002Y_NP0ZKgX0:Vm
j?l00000?oooool007?ooooo0_l0000Aooooo`05o`000?ooooooooooooooool00000[_ooool2o`00
00Cooooo3@2Y_NP01Ol00000ZKgX0:Vmj02Y_NSo000003oooooo001`ooooo`?o00000_ooool00`2Y
_NSoooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Z?ooool3o`00
00Kooooo00<0000V0:Vmj02Y_NP02`2Y_NP01Ol00000ZKgX0:Vmj02Y_NSo000003kooooo001^oooo
o`;o00000oooool30:Vmj13ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Uoooo
o`;o00002Oooool>0:Vmj006o`00002Y_NP0ZKgX0:Vmj?oooooo0000?Oooool006_ooooo0ol00002
ooooo`H0ZKgX00<0001booooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0:;ooooo0ol0000:ooooo`0300009P2Y_NP0ZKgX00`0ZKgX00?o00000:Vmj02Y_NP00P2Y_NP0
0ol0003oooooooooo`0kooooo`00J?ooool3o`0000?ooooo202Y_NP00`0007;oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Woooool2o`0000gooooo00<0000V0:Vm
j02Y_NP0302Y_NP00ol00000ZKgX0:Vmj0020:Vmj003ooooool0003ooooo03_ooooo001Vooooo`;o
00000oooool<0:Vmj13ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Looooo`?o
00003Oooool200009Pl0ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00ooooooo0000ooooo`0jooooo`00
Hoooool3o`0000;ooooo3@2Y_NP00`000780ZKgXooooo`0?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0VOooool2o`00013ooooo0P0002H?0:Vmj003o`00002Y_NP0ZKgX00@0ZKgX
00?o0000ooooooooool0>Oooool0067ooooo0_l00003ooooo`l0ZKgX00<0001b0:Vmj00007803ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Gooooo0ol0000Booooo`80000V3`2Y
_NP00ol00000ZKgX0:Vmj0050:Vmj003o`000?oooooooooo03Sooooo001Nooooo`?o00000_oooolD
0:Vmj0030000L_oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2C
ooooo`;o00005Oooool00`0002H0Z;oZ0000:00>0:Vmj003o`00002Y_NP0ZKgX00H0ZKgX00?o0000
ooooooooool0=oooool005cooooo0_l00003oooooaH0ZKgX00<0001booooooooool03?ooool00`2X
_n[o0000ooooo`07ooooo`03o`000?oooooooooo08oooooo0ol0000Gooooo`0300009P2X_nX0ZKgX
00h0ZKgX00?o00000:Vmj02Y_NP01P2Y_NP00ol0003oooooooooo`0gooooo`00FOooool3o`0000?o
oooo5`2Y_NP20000LP_ooooo102X_nX00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08_o
oooo0ol0000Iooooo`030:RojP0002H0000V00l0ZKgX00?o00000:Vmj02Y_NP01`2Y_NP00ol0003o
ooooooooo`0fooooo`00Eoooool2o`0000?ooooo6P2Y_NP20000LPSooooo1`2X_nX00ol00000Z;oZ
ooooo`07ooooo`03o`000?oooooooooo08Wooooo0_l0000Looooo`030:RojP0002H0000V00l0ZKgX
00?o00000:Vmj02Y_NP01`2Y_NP00ooooooo0000ooooo`0fooooo`00E?ooool3o`0000?ooooo702Y
_NP00`000780ZKgX0000LP05ooooo`T0Z;oZ00?o00000:RojP2X_nX02?ooool00ol0003ooooooooo
o`25ooooo`?o00007_ooool00`2X_nX0000V0:Vmj00?0:Vmj003o`00002Y_NP0ZKgX00P0ZKgX00?o
0000ooooooooool0=Oooool0057ooooo0ol000000oooool0ZKgX0:Vmj00M0:Vmj0050000L`2Y_NP0
001b0:Vmj00007800_ooool<0:RojP04o`00002X_nX0Z;oZ0:RojPSooooo00?o0000ooooooooool0
P_ooool2o`00027ooooo00<0Z;oZ00009P2Y_NP03`2Y_NP00ol00000ZKgX0:Vmj0080:Vmj003oooo
ool0003ooooo03Gooooo001?ooooo`;o000000?ooooo0:Vmj02Y_NP0802Y_NP00`0007<0ZKgX0000
LP040000LP`0Z;oZ00Co00000:RojP2X_nX0Z;oZ2?ooool00ol0003oooooooooo`1oooooo`?o0000
8oooool00`2X_nX0000V0:Vmj00?0:Vmj003o`00002Y_NP0ZKgX00T0ZKgX00?oooooo`000?ooool0
=?ooool004cooooo0ol000000oooool0ZKgX0:Vmj00R0:Vmj0030000L`2Y_NP0ZKgX00<0001b3@2X
_nX00ol00000Z;oZ0:RojP020:RojPSooooo00?o0000ooooooooool0O?ooool2o`0002Kooooo00<0
Z;oZ0?ZlO`0002/03`2Y_NP00ol00000ZKgX0:Vmj00:0:Vmj003o`000?oooooooooo03?ooooo001:
ooooo`;o00000_oooolV0:Vmj0040000L`2Y_NP0ZKgX0000LPl0Z;oZ00?o00000:RojP2X_nX00P2X
_nX9ooooo`03o`000?oooooooooo07Sooooo0ol0000Vooooo`<0Z;oZ00<0n[ao0:Vmj02Y_NP03`2Y
_NP00ol00000ZKgX0:Vmj00:0:Vmj003o`000?oooooooooo03;ooooo0017ooooo`?o000000?ooooo
0:Vmj02Y_NP09`2Y_NP30000L`80001b3P2X_nX00ol00000Z;oZ0:RojP030:RojPSooooo00?o0000
ooooooooool0M_ooool2o`0002Oooooo1@2X_nX00`3j_7l0ZKgX0:Vmj00?0:Vmj003o`00002Y_NP0
ZKgX00/0ZKgX00?o0000ooooooooool0<Oooool004Gooooo0_l00002ooooob`0ZKgX0P0007<00`00
0780Z;oZ0:RojP0=0:RojP03o`00002X_nX0Z;oZ00<0Z;oZ2Oooool00ol0003oooooooooo`1boooo
o`?o00009_ooool70:RojP80n[ao4@2Y_NP00ol00000ZKgX0:Vmj00;0:Vmj003o`000?oooooooooo
037ooooo0012ooooo`?o00000_ooool^0:Vmj080001c402X_nX00ol00000Z;oZ0:RojP040:RojPWo
oooo00?o0000ooooooooool0Koooool2o`0002Kooooo2@2X_nX30?ZlOa40ZKgX00?o00000:Vmj02Y
_NP0302Y_NP00ol0003oooooooooo`0`ooooo`00?oooool3o`0000;ooooo<@2Y_NP00`0007<0ZKgX
0000L`0?0:RojP03o`00002X_nX0Z;oZ00D0Z;oZ2?ooool00ol0003oooooooooo`1/ooooo`?o0000
9_ooool;0:RojP80n[ao4P2Y_NP00ol00000ZKgX0:Vmj00=0:Vmj003o`000?oooooooooo02oooooo
000mooooo`;o00000ooooola0:Vmj0050000M02Y_NP0001c0:Vmj00007<03`2X_nX00ol00000Z;oZ
0:RojP060:RojPSooooo00?o0000ooooooooool0JOooool2o`0002Kooooo3`2X_nX00`3j_7l0ZKgX
0:Vmj00@0:Vmj003o`00002Y_NP0ZKgX00d0ZKgX00?o0000ooooooooool0;oooool003[ooooo0ol0
0003oooooc<0ZKgX00<0001d0:Vmj00007<00`0007<>0:RojP03o`00002X_nX0Z;oZ00L0Z;oZ2?oo
ool00ol0003oooooooooo`1Uooooo`?o00009_oooolB0:RojP030000;@2Y_NP0ZKgX00l0ZKgX00?o
00000:Vmj02Y_NP03P2Y_NP00ol0003oooooooooo`0^ooooo`00>?ooool2o`0000?ooooo=P2Y_NP0
0`0007@0ZKgX0000L`020000L`l0Z;oZ00?o00000:RojP2X_nX01`2X_nX8ooooo`03o`000?oooooo
oooo06;ooooo0ol0000Voooooa@0Z;oZ00<0000]0:Vmj02Y_NP0402Y_NP00ol00000ZKgX0:Vmj00>
0:Vmj003ooooool0003ooooo02kooooo000eooooo`?o000000?ooooo0:Vmj02Y_NP0>02Y_NP01000
07@0ZKgX0000L`0007<@0:RojP03o`00002X_nX0Z;oZ00L0Z;oZ2Oooool00ol0003oooooooooo`1O
ooooo`;o00009ooooolE0:RojP030?ZlP@2Y_NP0ZKgX0140ZKgX00?o00000:Vmj02Y_NP03`2Y_NP0
0ol0003oooooooooo`0]ooooo`00<oooool2o`000003ooooo`2Y_NP0ZKgX03d0ZKgX0`0007<?0:Ro
jP03o`00002X_nX0Z;oZ00P0Z;oZ2?ooool00ol0003oooooooooo`1Looooo`?o00009_oooolH0:Ro
jP030?ZlP@2Y_NP0ZKgX0140ZKgX00?o00000:Vmj02Y_NP0402Y_NP00ol0003oooooooooo`0/oooo
o`00<?ooool3o`000003ooooo`2Y_NP0ZKgX03l0ZKgX00<0001d0:RojP2X_nX03`2X_nX00ol00000
Z;oZ0:RojP050:RojP<0?XGY2Oooool00ol0003oooooooooo`1Iooooo`;o00009ooooolI0:RojP80
n[b14`2Y_NP00ol00000ZKgX0:Vmj00@0:Vmj003ooooool0003ooooo02cooooo000]ooooo`?o0000
0_oooom30:Vmj080001d4@2X_nX00ol00000Z;oZ0:RojP050:RojP<0?XGY2Oooool00ol0003ooooo
ooooo`1Eooooo`?o00009_oooolL0:RojP80n[b14`2Y_NP00ol00000ZKgX0:Vmj00A0:Vmj003o`00
0?oooooooooo02_ooooo000[ooooo`;o00000ooooom20:Vmj0030040M@2Y_NP0001d0080001d4@2X
_nX00ol00000Z;oZ0:RojP070:RojP0303j5jOoooooooooo00Oooooo00?o0000ooooooooool0Dooo
ool2o`0002Oooooo7P2X_nX00`3j_840000_0:Vmj00B0:Vmj003o`00002Y_NP0ZKgX0140ZKgX00?o
ooooo`000?ooool0:oooool002Sooooo0ol00002ooooodD0ZKgX00<00@1e0:Vmj00007@00`0007@@
0:RojP03o`00002X_nX0Z;oZ00L0Z;oZ0P1[L/P9ooooo`03o`000?oooooooooo04oooooo0ol0000V
ooooob80Z;oZ0P0002lB0:Vmj003o`00002Y_NP0ZKgX0180ZKgX00?oooooo`000?ooool0:_ooool0
02Kooooo0_l00003ooooodL0ZKgX00<00@1e0:Vmj00007@00P0007@A0:RojP03o`00002X_nX0Z;oZ
00L0Z;oZ0P1[L/P:ooooo`03o`000?oooooooooo04cooooo0_l0000Wooooob<0Z;oZ00<0nKb30000
;`2Y_NP04P2Y_NP00ol00000ZKgX0:Vmj00C0:Vmj003o`000?oooooooooo02Wooooo000Sooooo`?o
000000?ooooo0:Vmj02Y_NP0B@2Y_NP00`0107D0ZKgX0000M0020000M140Z;oZ00?o00000:RojP2X
_nX0202X_nX206]bb0Wooooo00?o0000ooooooooool0BOooool3o`0002Kooooo9P2X_nX00`3i_8<0
ZKgX0:Vmj00C0:Vmj003o`00002Y_NP0ZKgX0180ZKgX00?oooooo`000?ooool0:Oooool0027ooooo
0_l00002ooooodl0ZKgX0P0007@B0:RojP03o`00002X_nX0Z;oZ00D0Z;oZ0`0mQ>T00`1[L/P0Z;oZ
0:RojP09ooooo`03o`000?oooooooooo04Kooooo0_l0000WooooobP0Z;oZ00<0nKb30?ViO`2Y_NP0
4`2Y_NP00ol00000ZKgX0:Vmj00C0:Vmj003ooooool0003ooooo02Sooooo000Nooooo`?o000000?o
oooo0:Vmj02Y_NP0D02Y_NP00`0107D0Z;oZ0:RojP0A0:RojP03o`00002X_nX0Z;oZ00H0Z;oZ0`0m
Q>T30:RojPWooooo00?o0000ooooooooool0@_ooool3o`0002Kooooo:P2X_nX20?VlP`80nKUo4`2Y
_NP00ol00000ZKgX0:Vmj00D0:Vmj003o`000?oooooooooo02Oooooo000Looooo`;o00000_oooomD
0:Vmj0800@1e4P2X_nX00ol00000Z;oZ0:RojP060:RojP<0K7;8102X_nX8ooooo`03o`000?oooooo
oooo03oooooo0ol0000Tooooobl0Z;oZ00D0nKb30?ViO`3i^Gl0nKUo0000?00B0:Vmj003o`00002Y
_NP0ZKgX01@0ZKgX00?oooooo`000?ooool09oooool001Wooooo0ol00002oooooeD0ZKgX0`0107DB
0:RojP03o`00002X_nX0Z;oZ00L0Z;oZ0`1/L/P30:RojPWooooo00?o0000ooooooooool0??ooool2
o`0002Kooooo00<0m;Z>0:RojP2X_nX0;@2X_nX0103i_8<0nKUo0?ViO`3i^GlC0:Vmj003o`00002Y
_NP0ZKgX01D0ZKgX00?o0000ooooooooool09_ooool001Kooooo0ol000000oooool0ZKgX0:Vmj01G
0:Vmj0@00@1e4@2X_nX00ol00000Z;oZ0:RojP050:RojP<0?8CY00<0K7;80:RojP2X_nX00`2X_nX9
ooooo`03o`000?oooooooooo03Sooooo0ol0000Xooooo`80m;Z>;`2X_nX30?ViOa<0ZKgX00?o0000
0:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Uooooo`005?ooool2o`0000;oooooF`2Y_NP30040
MA40Z;oZ0_l000080:RojP80?8CY1P2X_nX9ooooo`03o`000?oooooooooo03Kooooo0_l0000[oooo
o`80m;Z>;P2X_nX0103h_8D0nKUo0?ViO`3i^GlB0:Vmj0;o0000602Y_NP00ooooooo0000ooooo`0U
ooooo`004Oooool3o`0000;oooooG@2Y_NP30040M@h0Z;oZ0ol000000`2X_n[o00000:RojP080:Ro
jP80?8CY1P2X_nX9ooooo`03o`000?oooooooooo03;ooooo0ol0000]ooooo`80m;Z>00<000000:Ro
jP2X_nX0:`2X_nX01@3h_8D0nKUo0?ViO`3i^Gl0000n00h0ZKgX0ol000000`2Y_NSo00000:Vmj00H
0:Vmj003o`000?oooooooooo02Cooooo000@ooooo`;o000000?ooooo0:Vmj02Y_NP0GP2Y_NP20040
M@`0Z;oZ0ol000050:RojP03o`00002X_nX0Z;oZ00H0Z;oZ0`1/L/P60:RojPWooooo00?o0000oooo
ooooool0<?ooool2o`0002kooooo0`3d^Xh]0:RojP80n;b50`3i^Gl<0:Vmj0?o00001@2Y_NP00ol0
0000ZKgX0:Vmj00G0:Vmj003o`000?oooooooooo02?ooooo000@ooooo`03o`00002Y_NP0ZKgX0600
ZKgX2`2X_nX3o`0000T0Z;oZ00?o00000:RojP2X_nX01@2X_nX306abb0H0Z;oZ2Oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooo000002gooooo0P3d^Xh00`3c^Xl0Z;oZ0:RojP0[0:RojP05
0?RlQ@3i^Gl0nKUo0?ViO`3h^H002@2Y_NP3o`0000T0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ooo
oooo0000ooooo`0Sooooo`004?ooool00ol0003ooooo0:Vmj01P0:Vmj00300<0MP2X_nX0Z;oZ00D0
Z;oZ0ol0000=0:RojP03o`00002X_nX0Z;oZ00D0Z;oZ0`1/L/P60:RojPWooooo00?o0000oooooooo
ool0;oooool01?l0003oooooooooool0000/ooooo`80m;Z>00<0lkZ?0000002X_nX0:`2X_nX01@3h
_8D0nKUo0?ViO`3i^Gl0n;V000H0ZKgX0ol0000=0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX00?o0000
ooooooooool08_ooool0013ooooo00?o0000ooooo`2Y_NP0H02Y_NP300<0MP80Z;oZ0ol0000@0:Ro
jP03o`00002X_nX0Z;oZ00@0Z;oZ00<0>h?Y06abb01/L/P0202X_nX8ooooo`03o`000?oooooooooo
02oooooo00Go0000ooooooooooooooooo`00000[ooooo`80m;Z>00<0lkZ?000000000000;02X_nX3
0?ViO`040?RiP03h^H40ZKgX0:Vmj0?o0000402Y_NP00ol00000ZKgX0:Vmj00G0:Vmj003o`000?oo
oooooooo027ooooo000?ooooo`04o`000?ooooooooooooooof00ZKgX0P0307H3o`0001@0Z;oZ00?o
00000:RojP2X_nX00`2X_nX206ecb0T0Z;oZ2Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0:?ooool20?BjSP030?>jS`000000Z;oZ02/0Z;oZ00D0
V7J/0?ViO`3i^Gl0nKUo0?RiP003o`0001@0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ooooooo0000
ooooo`0Qooooo`003oooool00ol0003oooooooooo`03oooooeh0ZKgX0_l0000H0:RojP03o`00002X
_nX0Z;oZ0080Z;oZ0`1]LlP90:RojPWooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02Kooooo0P3d^Xh20?>jS`030<j?T@2X_nX0Z;oZ02T0Z;oZ0P2H
MZ`01@3i^Goo0000o`000?l00000n;V101L0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0003ooooo
ooooo`0Pooooo`003oooool00ol0003oooooooooo`04oooooeX0ZKgX0ol000000`2Y_NP0Z;oZ0:Ro
jP0H0:RojP03o`00002X_nX0Z;oZ0080Z;oZ0`1]LlP90:RojPSooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo0P3d^Xh00`3c^Xl0cXnA0<j?
T@0[0:RojP?o00000P3i^Gl20?RiPAL0ZKgX00?o00000:Vmj02Y_NP05`2Y_NP00ol0003ooooooooo
o`0Oooooo`003oooool00ol0003oooooooooo`05oooooeH0ZKgX0ol000040:Vmj0801P1h602X_nX0
1Ol00000Z;oZ0:RojP2X_nX0>H?Y0080KG?82P2X_nX9ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`80m;Z>00@0lkZ?0<j?T@3>Si40000A
:02X_nX2o`00000309Qf[03i^Gl0nKUo0080nKUo0P3h^H4H0:Vmj003o`00002Y_NP0ZKgX01H0ZKgX
00?oooooo`000?ooool07oooool000oooooo00?o0000ooooooooool01_oooomB0:Vmj0?o00001`2Y
_NP200H0N1T0Z;oZ00?o00000:RojP2X_nX00P1]LlP<0:RojPWooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo0P3d^Xh00`3c^Xl0cXnA0<j?
T@0V0:RojP?o000000<0V7J/0:RojP2X_nX0103i^Gl20?RiPAT0ZKgX00?o00000:Vmj02Y_NP05P2Y
_NP00ol0003oooooooooo`0Nooooo`003oooool00ol0003oooooooooo`08ooooodd0ZKgX0ol00009
0:Vmj00405ddQP0607P01P1h00H0N1T0Z;oZ00Co00000:RojP1]LlP0KG?8302X_nX9ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`030?Bj
SP3c^Xl0lkZ?0080cXnA8`2X_nX3o`0000@0V7J/00<0<c>S0:RojP3i^Gl00`3i^Gl20?RiPAX0ZKgX
00?o00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0Mooooo`003oooool00ol0003ooooooooo
o`08ooooodX0ZKgX0ol0000<0:Vmj00305ddQP0607P01P1h01/0Z;oZ00Co00000:RojP1]LlP0KG?8
302X_nX9ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Pooooo`80m;Z>0P3c^Xl00`3>Si40m;J70?BfQ`0O0:RojP?o00000P2X_nX609Qf[00603<c
X`3i^Gl0nKUo0?ViO`3h^H00n;V16`2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003ooooool0003ooooo
01gooooo000>ooooo`03o`000?oooooooooo00[oooooAP2Y_NP3o`0000l0ZKgX00<0GCB60:Vmj008
07T06`2X_nX00ol00000>8?X06ecb00>0:RojPWooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01oooooo0P3d^Xh00`3c^Xl0cXnA0<j?T@030?BfQa/0
Z;oZ0ol000050:RojPH0V7J/00H0<c>S0?ViO`3i^Gl0nKUo0?RiP03h^H4L0:Vmj003o`00002Y_NP0
ZKgX01H0ZKgX00?o0000ooooooooool07?ooool000kooooo00?o0000ooooooooool03?oooom10:Vm
j0?o00004P2Y_NP00`1M=8H0ZKgX00P0N@0K0:RojP0303R3j?l00000>8?X00l0Z;oZ2?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07Oooool0102V
`Nd0m;Z>0?BjSP3c^Xl20<j?T@@0m;J75`2X_nX3o`0000@0Z;oZ0`2HMj`20:RojPD0V7J/0P0c<j<2
0?ViO`030?RiP03h^H40ZKgX01`0ZKgX00?o00000:Vmj02Y_NP05P2Y_NP00ol0003oooooooooo`0K
ooooo`003_ooool00ol0003oooooooooo`0<ooooocl0ZKgX0_l0000E0:Vmj080GCB60P0807TK0:Ro
jP0303R3j?l00000Z;oZ00l0Z;oZ2?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool06Oooool50:K1k@80lkZ?0P3>Si440?BfQ`0300006@2X_nX0Z;oZ
0140Z;oZ0ol000080:RojP80V7N/00<0<C:R0:RojP2HMZ`00`2HMZ`50:O0j`030?RiP03h^H40ZKgX
01d0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ooooooo0000ooooo`0Kooooo`003_ooool00ol0003o
ooooooooo`0=oooooc/0ZKgX0ol0000F0:Vmj0030000JP1M=8H0GCB601d0Z;oZ00<0KW?7o`00001^
LlL0402X_nX8ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Fooooo`L0Y/7]0P3c^Xl20<j?T@@0m;J70P0001T?0:RojP?o00002`2X_nX309Qg[003
034bXP2HMZ`0Yl3[00H0Yl3[00<0n;V00?RiP@3h^H407P2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003
o`000?oooooooooo01[ooooo000>ooooo`03o`000?oooooooooo00oooooo=P2Y_NP3o`0001T0ZKgX
00@0001Z0:Vmj01M=8H0305k7@2X_nX00`1^LlOo000006ica`0?0:RojPSooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0?ooooo`;o00004oooool:0:K1k@80lkZ?0P3>Si440?BfQ`h0
Z;oZ0ol0000;0:RojP0309Qg[00`<J40Z;oZ00<0V7N/00<0<C:R0:O0j`2W`>/01@2W`>/20?RiP080
n;V17`2Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`000?oooooooooo01Wooooo000>ooooo`03o`00
0?oooooooooo013ooooo<P2Y_NP3o`0001P0ZKgX00<0SUV>0:Vmj02Y_NP00P0006X0102Y_NP0GCB6
0:Vmj00<0G/K0:RojP80=h;X00<0KW?7o`00002X_nX03`2X_nX8ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`/0Y/7]0P3c^Xl30<j?T@@0
m;J700<0m;J80:RojP2X_nX02@2X_nX2o`0000/0Z;oZ1@2HMj`0100`<J40Z;oZ09Qg[02HMj`2034b
XPL0Yl3[00<0n;V00?RiP@3h^H40802Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`000?oooooooooo
01Sooooo000>ooooo`03o`000?oooooooooo017ooooo;P2Y_NP3o`0001L0ZKgX00<0TfJJ0:Vmj02Y
_NP00P2>FHh20:Vmj0060000JP2Y_NP0ZKgX05ddQP2Y_NP0305k6`2X_nX306ica`030:Roj_l00000
Z;oZ00l0Z;oZ2?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool02oooool?0:K1k@80cXnA103d]XL30?BfR0L0Z;oZ0ol0000=0:RojPD0V7N/0P0`<J40
0`2HMj`0Yl3[0:O0j`090:O0j`80n;V1802Y_NP00ol00000ZKgX0:Vmj00F0:Vmj003o`000?oooooo
oooo01Sooooo000=ooooo`03o`000?oooooooooo01?ooooo:P2Y_NP3o`0001L0ZKgX1@2CIYX00`2Y
_NP0SUV>08iISP020:Vmj0030000JP2Y_NP0ZKgX0080GCB60P0<0G/J0:RojP<0KW?700<0Z;oZo`00
002X_nX0402X_nX7ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`05oooooa<0Y/7]0`3>Si440?BfQ`<0m;J800@0o/]_0:RojP2X_nX0Z;oZ0ol0000@
0:RojPD0V7N/0P0`<J4;0:O0j`<0n;V18@2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003ooooool0003o
oooo01Sooooo000=ooooo`03o`000?oooooooooo01Cooooo9P2Y_NP3o`0001H0ZKgX2@2CIYX01@2Y
_NP0SUV>08iISP2Y_NP0001Z00<0ZKgX0P1M=8H00`0<0G/0SUbA08iLT@0J0:RojP<0KW?700<0Z;oZ
o`00002X_nX03`2X_nX8ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02?ooool0
0`2W`>`0k8Tjooooo`0:ooooo`03o`000?oooooooooo00;ooooo5@2V`Nd30<j?T@@0m;J70`3d]XP0
103nbfoo0000o`000?l0000>0:RojP@0V7N/0P2X_nX509Qg[080<36Q2P2W`>/20?RiPB<0ZKgX00?o
00000:Vmj02Y_NP05@2Y_NP00ooooooo0000ooooo`0Gooooo`003Oooool00ol0003oooooooooo`0F
ooooob80ZKgX0_l0000G0:Vmj0/0TfJJ00D0ZKgX08iISP2>FHh0ZKgX0000JP030:Vmj080GCB60`2>
G94I0:RojP0303J2j01^LlL0KW?700<0Z;oZ00?o00000:RojP2X_nX03P2X_nX8ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool01_ooool30:O0k080k8Tj2oooool00ol00000Y/7]0:K1
k@0F0:K1k@<0cXnA103d]XL01`3d]XSo0000o`000?l00000o/]_0?>hSP2X_nX00P2<FY4;0:RojPD0
V7N/00<0;RnQ0:RojP2HMj`00`2HMj`=0:O0j`80n;V1902Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003
o`000?oooooooooo01Kooooo000=ooooo`03o`000?oooooooooo01Kooooo7`2Y_NP3o`0001L0ZKgX
3@2CIYX00`2Y_NP0SUV>08iISP020000JP<0ZKgX0P1M=8H308iLT@030?RiP02X_nX0Z;oZ0080SefB
502X_nX203J2j0D0Z;oZ00?o00000:RojP2X_nX0302X_nX00onX_n[oooooooooo`06ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool01?ooool50:O0k0<0k8Tj2OoooolJ0:K1k@<0cXnA
0P3d]XL3o`000080m;J80P3nbfl00`3c^8h0S5ZA08aJT@0208aJT@X0Z;oZ1P2HMj`00`0^;j40V7N/
0:O0j`0@0:O0j`030?RiP@2Y_NP0ZKgX0280ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ooooooo0000
ooooo`0Fooooo`003Oooool00ol0003oooooooooo`0Goooooa/0ZKgX0ol0000E0:Vmj140TfJJ00D0
lkfE0:Vmj02>FHh0SUV>0000JP040:Vmj080GCB60`2>G9400`3h^H00SefB08mMTP0208mMTQD0Z;oZ
0P0fP^P40:RojP03o`00002X_nX0Z;oZ00L0Z;oZ1_nX_nX9ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool00_ooool90:O0k0<0k8Tj1_oooolL0:K1k@80cXnA0ol000020?BfQ`<0m;J8
0P3nbfl00`3c^8h0S5ZA08aJT@0208aJT@040?>hS@2X_nX0SE^A08eKT@@0Z;oZ00<0V7N/0:RojP2H
Mj`01@2HMj`202h_XA80Yl3[9@2Y_NP00ol00000ZKgX0:Vmj00E0:Vmj003ooooool0003ooooo01Go
oooo000=ooooo`03o`000?oooooooooo01Sooooo5`2Y_NP3o`0001H0ZKgX4`2CIYX01@3c_ID0ZKgX
08iISP2>FHh0001Z00@0ZKgX0P1M=8H308iLT@030?RiP02?GI80SefB0080SefB00<0nKUo0:RojP2?
GI800P2?GI8@0:RojP80KgC71@2X_nX00ol00000Z;oZ0:RojP030:RojP[oZ;oZ2?ooool00ol0003o
ooooooooo`0Nooooo`03o`00002W`>`0Yl3/00/0Yl3/103/RCXP0:K1k@?o000000<0cXnA0?BfQ`3d
]XL00P3d]XL20?BfR080o/]_0P3c^8h408aJT@030?>hS@2=Fi40SE^A0080SE^A0P2X_nX209Qg[003
02/]X02X_nX0V7N/00@0V7N/00<0;RnQ0:O0j`2W`>/0402W`>/W0:Vmj003o`00002Y_NP0ZKgX01D0
ZKgX00?o0000ooooooooool05?ooool000gooooo00?o0000ooooooooool06_oooolB0:Vmj0?o0000
5`2Y_NPE09=VVP050?>mU@2Y_NP0SUV>08iISP0006X0102Y_NP205ddQP<0SUbA00<0n;V008mMTP2?
GI800P2?GI800`3i^Gl0SefB08mMTP0208mMTQ40Z;oZ0P1_M<L50:RojP03o`00002X_nX0Z;oZ00go
Z;oZ2?ooool00ol0003oooooooooo`0Mooooo`03o`00002W`>`0Yl3/00/0Yl3/0P3/RCXP0:K1k@;o
000000<0Y/7]0<j?T@3>Si40103d]XL30?BfR080o/]_0P3c^8h408aJT@030?>hS@2=Fi40SE^A0080
SE^A00H0lkR=0:RojP2HMj`0V7N/02/]X02X_nX409Qg[1@0Yl3[:02Y_NP00ol00000ZKgX0:Vmj00E
0:Vmj003o`000?oooooooooo01?ooooo000<ooooo`03o`000?oooooooooo01_ooooo3`2Y_NP3o`00
01T0ZKgX5P2CIYX01@3c_ID0ZKgX08iISP2>FHh0001Z00<0ZKgX00<0001Z05ddQP1M=8H00`2>G940
0`3h^H00SefB08mMTP0208mMTP030?ViO`2?GI80SefB0080SefB00@0nKUn0:RojP2@GY<0T5jC1`2X
_nX00`2@G940Z;oZ0:RojP020:RojP0303B1j01_M<L0Z;oZ00D0Z;oZ00?oZ;oZo`000?nX_nX03OnX
_nX9ooooo`03o`000?oooooooooo01cooooo00?o0000ooooo`2W`>`0302W`>`N0:K1k@?o00000P2V
`Nd00`000600cXnA0<j?T@040?BfQ`<0m;J80P3nbfl20?>hSP@0S5ZA00<0lkR=08eKT@2=Fi400P2=
Fi400`3c^8d0Z;oZ09Qg[00209Qg[00302/]X02HMj`0V7N/01D0Yl3[:@2Y_NP00ol00000ZKgX0:Vm
j00E0:Vmj003ooooool0003ooooo01?ooooo000<ooooo`03o`000?oooooooooo01cooooo2`2Y_NP3
o`0001`0ZKgX5P2CIYX01@3c_ID0ZKgX08iISP2>FHh0001Z00<0ZKgX00<0001Z05ddQP1M=8H00P2>
G9420?RiP0@0SefB00<0nKUo08mMTP2?GI800P2?GI80103i^Gh0T5jC091NT`2@GY<408mLT@030:Ro
jP2@G940T5bA0080T5bA0P2X_nX00on@GI7oReVAoh]IT@020:RojPGoZ;oZ00?o0000ojRoj_nX_nX0
3OnX_nX8ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03@2W`>`J0:K1k@?o0000
1@2V`Nd00`000600Y/7]0<j?T@040?BfQ`<0m;J80P3nbfl20?>hSP<0S5ZA0P3c^8d408eKT@030?>h
S@0Z;9l0Z;oZ0080V7N/0`0[;J0E0:O0jbX0ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ol0003ooooo
ooooo`0Booooo`003?ooool00ol0003oooooooooo`0Nooooo`L0ZKgX0_l0000L0:Vmj080TfJK00<0
ZKgX09=VVP2CIYX04`2CIYX30?>mU@80SUV>00<0001Z0:Vmj02Y_NP00P0006X205ddQP80SUbA0`3h
^H0308mMTP030?ViO`2?GI80SefB0080SefB00@0nKUn091NT`2@GY<0T5jC102?G945091LT@?oT5fA
0on;FI47ojRojP03o`000?nX_n[oZ;oZ00goZ;oZ2?ooool00ol0003oooooooooo`0Kooooo`04o`00
0?ooooooooooooooo`h0Yl3/5@2V`Nd3o`0000D0Y/7]00H0SEfE0:K1k@2V`Nd0001P0:K1k@3>Si44
0?BfQ`<0m;J80P3nbfl20?>hSP<0S5ZA0P3c^8d408eKT@030?>hS@0Z;9l0Z;oZ0080V7N/0P0[;J0E
0:O0jb`0ZKgX00?o00000:Vmj02Y_NP0502Y_NP00ooooooo0000ooooo`0Booooo`003?ooool00ol0
003oooooooooo`0Oooooo`<0ZKgX0ol0000N0:Vmj080TfJK00<0ZKgX09=VVP2CIYX04`2CIYX30?>m
U@80SUV>00<0001Z0:Vmj02Y_NP00P0006X205ddQP80SUbA0`3h^H0208mMTP80nKUo102?GI80103i
^Gh0T5jC091NT`2@GY<408mLT@D0T5bA0on@GI43oh]IT@SoZ;oZ00?o0000ojRoj_nX_nX03OnX_nX8
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool=0:O0k180Y/7]0ol00007
0:K1k@80SEfE00D0Y/7]0000H0000600Y/7]0<j?T@040?BfQ`<0m;J800@0o/]_0?>hSP3c^8h0lkR>
0`2<FY420?>hS@<0SE^A0`3c^8d00`0Z;9l0V7N/0:O0j`0G0:O0jb`0ZKgX00?o00000:Vmj02Y_NP0
5@2Y_NP00ooooooo0000ooooo`0Aooooo`003?ooool00ol0003oooooooooo`0Oooooo`?o00007`2Y
_NP01@2CIY/0ZKgX09=VV`2CIY/0001i01@0TfJJ0P2X_^T20?>mU@80SUV>00<0001Z0:Vmj00006X0
0P0006X205ddQP80SUbA0`3h^H0208mMTP<0nKUo0`2?GI80103i^Gh0T5jC091NT`2@GY<408mLT@D0
T5bA0on@GI43oh]IT@03oo^gLonX_n[oZ;oZ00;oTEjB1?nX_nX00ol0003oZ;oZojRojP0<ojRojPSo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo``0Yl3/3P2V`Nd3o`0000X0
Y/7]0P2=GID01@2V`Nd0001P0:K1k@2V`Nd0cXnA00@0m;J70`3d]XP0103nbfl0lkR>0?>hSP3c^8h3
08aJT@80lkR=0`2=Fi430?>hS@80:RbO602W`>/]0:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?o0000
ooooooooool04?ooool000cooooo00?o0000ooooooooool07?ooool3o`000003ooooo`2Y_NP0ZKgX
01d0ZKgX0`2CIY/01@2Y_NP0TfJK09=VV`0007T0ZKgX0100TfJJ1`2X_^T208iISP030000JP2Y_NP0
001Z0080001Z0`1M=8H0102>G940n;V00?RiP03h^H0208mMTP<0nKUo0P2?GI820?ViOP<0T5jC102?
G945091LT@?oT5fA0on;FI400ook]g?oTEjBoi5NTP02oi5NTPCoZ;oZ00?o0000ojRoj_nX_nX03OnX
_nX8ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool=0:O0k0T0Y/7]0ol0
000=0:K1k@80SEfE0P0006000`2V`Nd0001P0<j?T@040?BfQ`<0m;J800<0o/]_0?>hSP3c^8h00P3c
^8h208aJT@80lkR=0`2=Fi430?>hS@0302X/W`2W`>/0Yl3[01D0Yl3[<02Y_NP00ol00000ZKgX0:Vm
j00D0:Vmj003ooooool0003ooooo013ooooo000<ooooo`03o`000?oooooooooo01Wooooo0ol00006
oooooa`0ZKgX102CIY/01@0007P0TfJK09=VV`0007T0ZKgX00`0TfJJ2`2X_^T208iISPD0001Z0`1M
=8H0102>G940n;V00?RiP03h^H0208mMTP<0nKUo0P2?GI830?ViOP80T5jC00@0nKUm08mLT@2?G940
SebA1@2@G944oi1MT@;oReVA00?onkMcoi5NT_nAGY800_nAGY801_ok]g7oZ;oZoi5OTonAGi?oZ;oZ
o`0000ooZ;oZ1_ooool3o`0001Wooooo00?o0000ooooooooool01oooool>0:O0k0@0Y/7]0ol0000@
0:K1k@80SEfE00@0001P0:K1k@2V`Nd0001P103d]XL40?BfR0030?k;K`3c^8h0lkR>0080lkR>0P2<
FY420?>hS@<0SE^A0`3c^8d00`0001L0Yl3[0:O0j`0E0:O0jc40ZKgX00?o00000:Vmj02Y_NP0502Y
_NP2o`00013ooooo000;ooooo`03o`000?oooooooooo01Oooooo0ol0000:oooooa/0ZKgX102CIY/0
1@0007P0ZKgX09=VV`2CIY/0ZKgX00X0TfJJ3@2X_^T308iISP@0001Z00@0ZKgX05ddQP1M=8H0SUbA
0`3h^H0208mMTP<0nKUo0P2?GI830?ViOP80T5jC00@0nKUm08mLT@2?G940SebA1@2@G9401?oj]gCo
T5fAoi1MTOn@GI42oh]IT@03oo^gLonAGY;oTEjB00;oTEjB00ConkMaoi5OTonAGi?oTEnC0_nX_nX0
0ol0003oZ;oZojRojP0=ojRojP;ooooo0ol00002ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool02?ooool=0:O0k0040:K1kOl0003o0000o`0001<0Y/7]0P2=GID010000600Y/7]0:K1
k@0006040?BfQ`<0m;J800<0o/]_0?>hSP3c^8h00`3c^8h00`2<FY40lkR=0?>hS@020?>hS@80SE^A
0`3c^8dG0:O0jc80ZKgX00?o00000:Vmj02Y_NP05@2Y_NP00ol0003oooooooooo`0>ooooo`002ooo
ool00ol0003oooooooooo`0Dooooo`?o00003_oooolG0:Vmj080U6NK00<0ZKgX09=VV`2CIY/00P2C
IY/01@0007P0ZKgX09=VV`2CIY/0ZKgX00D0TfJJ4P2X_^T00`2Y_NP0SUV>08iISP040000JP040:Vm
j01M=8H0GCB608iLT@<0n;V00P2?GI830?ViO`80SefB0`3i^Gh2091NT`040?ViO@2?G940SebA08mL
T@D0T5bA00Con[Mdoi1MTOn@GI7oT5fA0_n;FI400ook]g?oTEjBoi5NTP02oi5NTP08oo^gLOnAGi?o
TEnCoi5OTook]g3oZ;oZoi9PTol0000>ojRojP;o00001Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00Wooooo2`2W`>`2o`0000030:K1k@2W`>`0Yl3/0180Y/7]00H0001N08eMU@2=
GID0SEfE0:K1k@0006050?BfQ`<0m;J800<0o/]_0?>hSP3c^8h00`3c^8h00`2<FY40lkR=0?>hS@02
0?>hS@80SE^A0`3c^8dG0:O0jc<0ZKgX00?o00000:Vmj02Y_NP04`2Y_NP00ooooooo0000ooooo`0?
ooooo`002oooool00ol0003oooooooooo`0Aooooo`?o00004_oooolF0:Vmj080U6NK00<0ZKgX09=V
V`2CIY/00`2CIY/0102Y_NP0TfJK09=VV`0007T309=VVQ@0Z;kY00<0ZKgX08iISP2>FHh00`0006X2
0:Vmj080GCB600@0SUbA0?RiP03h^H00n;V00P2?GI830?ViO`80SefB0`3i^Gh2091NT`050?ViO@2?
G940SebA08mLT@3j]gH0102@G9401?oj]gCoT5fAoi1MTOn@GI42oh]IT@;onkMc0onAGY801Ook]g7o
TEnCoi5OTonAGi?onkM`00;oTV2C00?o0000ojRoj_nX_nX03OnX_nX6ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool02oooool70:O0k0?o00001P2W`>`A0:K1k@060000GP2V`Nd0SEfE
08eMU@2V`Nd0001P1@3d]XL30?BfR0030?k;K`3c^8h0lkR>00<0lkR>00<0S5ZA0?>hS@3c^8d00P3c
^8d01P2=Fi40lkR=0?>hS@3c^8d0l[ZC00006AD0Yl3[=@2Y_NP00ol00000ZKgX0:Vmj00=0:Vmj0Ko
oooo00?o0000ooooooooool03_ooool000_ooooo00?o0000ooooooooool03oooool2o`0001Kooooo
502Y_NP309AWV`030000MP2CIY/0TfJK00<0TfJK00D0ZKgX09=VV`2CIY/0001i09=VVP0D0:Rnj@;o
Z;kY00<0ZKgX08iISP2>FHh00`0006X20:Vmj080GCB600@0SUbA0?RiP03h^H00n;V00P2?GI830?Vi
O`80SefB0`3i^Gh2091NT`050?ViO@2?G940SebA08mLT@3j]gH0102@G9401?oj]gCoT5fAoi1MTOn@
GI42oh]IT@;onkMc0onAGY801Ook]g7oTEnCoi5OTonAGi?onkM`00?oTV2C00Co0000ojRoj_nX_n[o
TV6D3?nX_nX6ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool30:O0k0?o
00002`2W`>`00`2V`Nd0Yl3/0:K1k@0<0:K1k@040000GP2V`Nd0SEfE08eMU@80001P1@3d]XL30?Bf
R0030?k;K`3c^8h0lkR>00<0lkR>00<0S5ZA0?>hS@3c^8d00P3c^8d01@2=Fi40lkR=0?>hS@3c^8d0
l[ZC0080000I402W`>/00`2Y_NP0Yl3[0:Vmj00g0:Vmj003o`00002Y_NP0ZKgX00X0ZKgX2?ooool0
0ol0003oooooooooo`0>ooooo`002oooool00ol0003oooooooooo`0<ooooo`?o00006Oooool?0:Vm
j003ojVmj?nDIi_oU6NK00@0U6NK00<0001f0:Vmj02CIY/00`2CIY/00`0007P0TfJK09=VV`020000
NA00Z;kY1_nX_^T00`2Y_NP0SUV>08iISP020000JP80ZKgX00<0001Z05ddQP1M=8H0103h^H0208mM
TP<0nKUo0P2?GI830?ViOP80T5jC00D0nKUm08mLT@2?G940SebA0?ZgMP04091LT@04ooZgM?n@GI7o
T5fAoi1MT@;oReVA0_ok]g<3oi5NTP;onkMa0_nAGi<01_ok]g3oTV2Coi9PTonBH9?onkM_o`0000;o
TV6D3OnX_nX5ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool3o`000140
Yl3/302V`Nd0100005h0Y/7]08eMU@2=GID30000H0@0m;J70`3d]XP00`3nbfl0lkR>0?>hSP030?>h
SP0308aJT@3c^8d0lkR=0080lkR=00D0SE^A0?>hS@3c^8d0lkR=0?:jT`0@0:O0jc`0ZKgX00?o0000
0:Vmj02Y_NP01P2Y_NP=ooooo`03o`000?oooooooooo00gooooo000;ooooo`03o`000?oooooooooo
00Wooooo0ol0000Mooooo``0ZKgX0onY_NP2oiAWV`@0U6NK00<0001f0:Vmj02CIY/00`2CIY/00`00
07P0TfJK0:Rnj@0@0:Rnj@SoZ;kY00<0ZKgX08iISP2>FHh00P0006X20:Vmj0030000JP1M=8H0GCB6
00D0n;V000@0SefB0?ViO`3i^Gl0nKUo0P2?GI830?ViOP03091NT`3i^Gd0nKUm00<0SebA00<0n[Mf
091LT@2@G9400P2@G9401?oj]gCoT5fAoi1MTOn@GI42oh]IT@;onkMc0onAGY82oo^gL@;oTEnC00Ko
nkM`oi9PTonBH9?oTV2Coo^gKol00002oi9QU003oo^gKOnX_n[oZ;oZ00;oTf6D2?nX_nX5ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool3o`0000?ooooo4`2W`>`00`2V`Nd0
Yl3/0:O0k0090:K1k@80SEfE0P0006020:G3k`<0m;J70`3d]XP60?>hSP0308aJT@3c^8d0lkR=0080
lkR=00@0SE^A0?>hS@3c^8d0lkR=0P3b^Y<:0:O0jd80ZKgX00?o00000:Vmj02Y_NP00P2Y_NP@oooo
o`03o`000?oooooooooo00gooooo000;ooooo`03o`000?oooooooooo00Kooooo0ol0000Rooooo`H0
ZKgX1onY_NP2oiAWV`80U6NK00@0ZKgX09AWV`2DIi/0ZKgX102CIY/20000N0h0Z;kY2onX_^T00`2Y
_NP0SUV>08iISP020000JP030:Vmj00006X0001Z0080GCB61@3h^H040?ViO`80SefB0`3i^Gh00`2@
GY<0nKUm0?ViO@0308mLT@030?ZgMP2@G940T5bA0080T5bA00Con[Mdoi1MTOn@GI7oT5fA0_n;FI42
oo^gL`?oTEjB0_ok]g42oi5OT`;onkM`0_nBH9<01Ook]fooTV6Do`000?nBHIConkM]00CoTf6D00?o
o;M/ojRoj_nX_nX01_nX_nX4ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_oo
ool3o`0000Oooooo5@2W`>`00`0007P0Y/7]0:K1k@040:K1k@80001N0P2=GID30000H080YL?_00<0
m;J70?BfR03d]XP00P3d]XP2000000@0lkR>1@3c^8d00`2=Fi40lkR=0?>hS@030?:jT`0300006`2W
`>/0Yl3[00D0Yl3[A@2Y_NP00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo000:
ooooo`03o`000?oooooooooo00Cooooo0ol0000Vooooo`<0ZKgX2OnY_NP2oiAWV`80U6NK00@0001d
09AWV`2DIi/0001f102CIY/00`0007P0Z;kY0:Rnj@090:Rnj@ooZ;kY00@0ZKgX08iISP2>FHh0001Z
0P2Y_NP20000JP80GCB61@3h^H050?ViO`0508mMTP3i^Gh0nKUn0?ViOP2@GY<00P3i^Gd308mLT@03
0?ZgMP2@G940T5bA0080T5bA00Con[Mdoi1MTOn@GI7oT5fA0_n;FI42oo^gL`?oTEjB0_ok]g42oi5O
T`;onkM`0_nBH9<2oo^gK`03oi9QU?l0003onkM]00CoTf6D00Coo;M/oi=RUOnCHYGoTf:E1OnX_nX4
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool3o`0000_ooooo4`2W`>`0
0`0007T0001h0000N0050:K1k@80001N0P2=GID20000H0@0YL?_103d]XP00`000000Y/;]0:K2k@03
0?>hSPD0lkR=00<0SE^A0?>hS@3c^8d00`3b^Y<60:O0jdD0ZKgX0_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00gooooo000:ooooo`04o`000?ooooooooooooooo`?o0000:Oooool9
ojVmj003oiAXW?nY_NSoZKgX00;oU6NK0P2DIi/0100007@0U6NK09AWV`0007H309=VV`/0Z;kY4OnX
_^T01@2Y_NP0SUV>08iISP0006X0ZKgX00<0001Z00<0GCB60:K2k@2V`^d0103h^H050?ViO`@0nKUn
00@0T5jC0?ViO@3i^Gd0nKUm0P2?G9400`3j]gH0T5bA091LT@02091LT@03ooZgM?n@GI7oT5fA00;o
T5fA00?oReVAoo^gLook]g<00onAGY82oo^gL@;oTEnC0_ok]g02oi9PT`;onkM_0_nBHI@00ol0003o
Tf6Doi=QU002oi=QU005oobgK?nCHYGoTf:Eoi=RUOol]V/01OnX_nX3ooooo`03o`000?oooooooooo
01Cooooo00Co0000oooooooooooooooo0ol0000?oooooa80Yl3/00<0001i0000N02V`Nd0102V`Nd3
0000GP0308eMU@2U`nl0YL?_00D0YL?_103d]XP00`000000Y/;]0:K2k@040:K2k@L0lkR=0`3b^Y<0
0`2W`>/0ZKgX0:Vmj0140:Vmj0Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=
ooooo`002_ooool4o`0002gooooo1onY_NP2oiAXW0;oZKgX0_nDIi/209AWV`040000M02DIi/0U6NK
0000MPX0Z;kY5OnX_^T01@2Y_NP0SUV>08iISP0006X0ZKgX00@0001Z0`2V`^d30?RiP0D0nKUo1@3i
^Gh30?ViO@0308mLT@3j]gH0n[Mf00@0T5bA0_oj]g@3oi1MT@03oh]ITOok]g?onkMc00?oTEjB0_ok
]g42oi5OT`;onkM`0_nBH9<2oo^gK`;oTV6D00?o0000oo^gKOnCHI@00_nCHI@01Ool]fcoTf:Eoi=R
UOnCHYGoo;I[00?oU6>E0onX_nX2ooooo`03o`000?oooooooooo01Cooooo1?l0000Doooooa00Yl3/
00<0001i0:O0k02V`Nd0102V`Nd40000GPL0YL?_0`3d]XP00`3nbfl0Y/;]0:K2k@060:K2k@H0lkR=
0P3b^Y<00`3a^Y@0ZKgX0:Vmj0100:Vmj0gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0=ooooo`002_ooool2o`00033ooooo1_nY_NP2oiAXW0;o001b0_nDIi/209AWV`030000M02D
Ii/0U6NK0080001f1`2X_^TCojRnj@;oWGnb0onX_^T208iISPD0001Z1@2V`^d00`3h^H00Y/;]0?Vi
O`040?ViO`D0nKUn0`3i^Gd00`2?G940n[Mf0?ZgMP04091LT@;on[Md0on@GI400on;FI7onkMcoo^g
L`03oi5NTP;onkMa0_nAGi<2oo^gL0;oTV2C0_ok]fl2oi9QU003oo^gKOl0003oTf6D00;oTf6D00Go
o;M/oi=RUOnCHYGoTf:EoobfJ`03oiASU@03oobfJOnX_n[oU6>F00?ooooo00?o0000ooooooooool0
4oooool2o`0001Oooooo402W`>`30000N@<0Y/7]0`0005h80:G3k`<0m;J800<000000:K2k@2V`^d0
2P2V`^d20?>hS@80l[ZC00<0lKZD0:Vmj02Y_NP0?P2Y_NP@ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool000cooooo00?o0000ooooooooool0;oooool4ojVmj0;oU6RL00Co
001bojVmj?nDIi_oU6NK0P2DIi/00`0007@0U6NK0:Rnj@050:RnjA?oZ;kY2OnMOk8208iISPD0001Z
202V`^d40?ViO`D0nKUn0`3i^Gd00`2?G940n[Mf0?ZgMP04091LT@;on[Md0on@GI401?n;FI7onkMc
oo^gLook]g<2oi5NTP;onkMa0_nAGi<2oo^gL0;oTV2C0_ok]fl2oi9QU0;onkM]00?o0000oi=QU?nC
HI@00_ol]f`2oi=RU@05oobfJonDHiGoU6>EoiASUOol]VT00onDHiH2ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool05Oooool?0:O0k080001i102V`Nd40000GPP0YL?_0P3d]XP>0:K2
k@<0l[ZC00<0lKZD0:Vmj02Y_NP0>P2Y_NPDooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool000gooooo00?o0000ooooooooool0;oooool00onY_NSoTfBHojVmj002oiAXW004
o`00L_nY_NSoU6NKoiAWV`80U6NK0P0007@40:RnjA?oZ;kY2onMOk8208iISP@0001Z2`2V`^d00`3i
^Gl0Y/;]0?ViOP040?ViOP<0nKUm00<0SebA0?ZgMP3j]gH0102@G942ooZgM0?oT5fA00GoReVAoo^g
Look]g?onkMcoi5NTP03oo^gL@;oTEnC0_ok]g02oi9PT`;onkM_0_nBHI@2oo^gK@03oi=QU?l0003o
Tf6D00;oo;M/0_nCHYD2oobfJ`;oU6>E00Ooo;IYoiASU_nDHiKoU6>FoobfIooooooo000001Sooooo
00?o0000ooooooooool05Oooool>0:O0k080001i102V`Nd30000GP/0YL?_3P2V`^d30?:jT`030?6j
U02Y_NP0ZKgX03P0ZKgX5oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo
000>ooooo`03o`000?oooooooooo02kooooo0_nCI9P01OnY_NSoU6RLoiAXW?nDJ9coZKgX00;oU6NK
0P2DIi/00`0007CoZ;kYojRnj@0BojRnj@_oWGnb0_oTaKP2oieo/P80SUV>0`0006X?0:K2k@@0nKUn
0`3i^Gd00`2?G940n[Mf0?ZgMP04091LT@;on[Md0on@GI401On;FI7onkMcoo^gLook]g?oTEjB00Co
nkMa00?oTEnCoo^gL?ok]g000_nBH9<3oo^gK`06oi9QU?ok]fgonkM]oi=QU?l0003oTf6D0_ol]f`2
oi=RU@;oo;I[0_nDHiD01ool]VWoU6>FoiASU_nDHiKoo;IWooooool000006Oooool00ol0003ooooo
ooooo`0Eooooo``0Yl3/00<0001j0000N@2V`Nd0102V`Nd20000GP`0YL?_3@2V`^d30?:jT`030?6j
U02Y_NP0ZKgX03D0ZKgX7?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
000?ooooo`;o0000;_ooool2oi=TV0;oZKgX0_nDJ9`01?nY_NSoU6NKoiAWV`2DIi/DojRnj@goWGnb
0_oTaKP2oieo/P80SUV>100006X?0:K2k@80nKUn00D0Y/;]0?ViO@3i^Gd0nKUm08mLT@020?ZgMP@0
T5bA0_oj]g@3oi1MT@05oh]ITOok]g?onkMcoo^gLonAGY801?ok]g400onAGi?onkM`oo^gL002oi9P
T`?onkM_00?oTV6Doo^gKOok]fd00_nCHI@00ol0003oo;M/oobgK002oi=RU@;oo;I[0_nDHiD2oobf
J@;oU6>F00?oo;IWooooool000006_ooool2o`0001Oooooo2P2W`>`00`0007X0Yl3/0:K1k@040:K1
k@<0001N2P2U`nl?0:K2k@80l[ZC00<0lKZD0:Vmj02Y_NP0<`2Y_NPNooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool0017ooooo00?o0000ooooooooool0:oooool2oi=TV004
ojVmj?l0077oU6RLoiAXW0?o001b4?nX_^T@oieo/P04ojRoj_oTaKSoi<FhonC5^0;oWGnb0P2>FHh2
0000JQD0Y/;]0P3i^Gd00`2?G940n[Mf0?ZgMP04091LT@;on[Md0on@GI401On;FI7onkMcoo^gLook
]g?oTEjB00ConkMa00GoTEnCoo^gL?ok]g3onkM`oi9PT`03oo^gK`04oi9QU?ok]fgonkM]oo^gK@;o
Tf6D00Co0000oobgK?nCHYGoTf:E0_ol]V/2oiASU@;oo;IY0_nDHiH00ool]VOoooooo`00000Loooo
o`03o`000?oooooooooo01Cooooo302W`>`00`0007X0Y/7]0:K1k@030:K1k@`0YL?_402V`^d00`3b
^Y<0lKZD0:Vmj00_0:Vmj2Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`004_ooool00ol0003oooooooooo`0Zooooo`;oTfBH00Co9a5oo`00LOnDJ9coU6RL0_l0078:ojRn
j@;oWGnb0onX_^T@oieo/PCoZ;oZ00Coi<FhojRoj_nX_n[oZ;oZ0P2>FHh30000JQ@0Y/;]0P3i^Gd0
102?G940n[Mf0?ZgMP3j]gH3091LT@;on[Md0on@GI401On;FI7onkMcoo^gLook]g?oTEjB00ConkMa
00GoTEnCoo^gL?ok]g3onkM`oi9PT`03oo^gK`;oTV6D0_ok]fd2oi=QU004oobgK?l0003oTf:Eoi=R
U@;oo;I[0_nDHiD2oobfJ@;oU6>F0_ol]VL00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01Cooooo2P2W`>`30000NPD0Y/7]2P2U`nl00`1<F[l0Y/;]0:K2k@0=0:K2k@80l[ZC00<0lKZD0:Vm
j02Y_NP0:P2Y_NPYooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool001?o
oooo00?o0000ooooooooool0:Oooool2oi=TV004obLAOol0077oU6RLoiAXW0;o001b1_nX_^TEoieo
/PcoZ;oZ00<0SUV>ojRoj_nX_nX05P2V`^d00`0^9YD0nKUm0?ViO@030?ZgMP<0T5bA0_oj]g@4oi1M
T@?onkMc00?oTEjBoo^gLOok]g400_ok]g401OnAGi?onkM`oo^gL?ok]g3oTV2C00?onkM_0_nBHI@2
oo^gK@;oTf6D00Coo;M/o`000?nCHYGoTf:E0_ol]V/2oiASU@;oo;IY0_nDHiH2oobfI`03ooooool0
003ooooo01cooooo00?o0000ooooooooool05Oooool80:O0k0030000NP2V`Nd0Y/7]00H0Y/7]2@2U
`nl00`1<F[l0Y/;]0:K2k@0=0:K2k@80l[ZC00<0lKZD0:Vmj02Y_NP0:02Y_NP/ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03?ooool001Cooooo00?o0000ooooooooool0:?ooool2
oi=TV005obLAOol0077oU6RLoiAXW?l007801OnX_^TEoieo/Q;oZ;oZ402V`^d4ojK2k@040:K2k@0^
9YD0nKUm0?ViO@<0n[Mf0`2@G943ooZgM0?oT5fA0ook]g<00onAGY;onkMaoo^gL@02oo^gL@05oi5O
Took]g3onkM`oo^gL?nBH9<00ook]fl2oi9QU0;onkM]0_nCHI@2oobgK004o`000?nCHYGoo;I[oobf
J`;oU6>E0_ol]VT2oiASUP;oo;IW00?oooooo`000?ooool07Oooool2o`0001Kooooo1`2W`>`20000
NPT0Y/7]1P2U`nl00`00=[40C5Zo04aJ_`0?0:K2k@80lKZD9P2Y_NP`ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03?ooool001Gooooo0_l0000Xooooo`;oTfBH00?o9a5oo`00LOnX
_^T00onX_^T;oieo/P;ohL:i2?nMOk8GojRojPd0Y/;]1_nV`^d01?l^9YD0;RJE02hVU@3i^Gd30?Zg
MP<0T5bA0ooj]g@3oi1MT@?onkMc00?oTEjBoo^gLOok]g400_ok]g401OnAGi?onkM`oo^gL?ok]g3o
TV2C00?onkM_0_nBHI@2oo^gK@;oTf6D0_ol]f`00onCHYGo0000oobfJ`02oobfJ`03oiASUOol]VWo
o;IY00;oU6>F0_ol]VL00ooooooo0000ooooo`0Oooooo`03o`000?oooooooooo01Cooooo1P2W`>`?
0:K1k@80YL?_00<0CE[00:K2k@2V`^d03`2V`^d20?6jU280ZKgX=Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00cooooo000Gooooo`03o`000?oooooooooo02Gooooo0_nCI9P01?lW
4Goo001ao`00LOnX_^T=oieo/P;ohL:i1?nMOk8LojRojPL0Y/;]2onV`^d01?l^9YD0Y/;]02hVU@3i
^Gd30?ZgMP<0T5bA0ooj]g@3oi1MT@ConkMc1?ok]g401OnAGi?onkM`oo^gL?ok]g3oTV2C00ConkM_
00?oTV6Doo^gKOok]fd00_nCHI@3oobgK005oi=RUOl0003oo;I[oobfJonDHiD00_ol]VT2oiASUP;o
o;IW00?oooooo`000?ooool08?ooool00ol0003oooooooooo`0Dooooo`H0Yl3/402V`Nd204eJ`0l0
Y/;]0P3a^Y@Q0:Vmj3Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`00
6?ooool00ol0003oooooooooo`0Tooooo`;oTfBH00?o9a5ooieo/_nMOk803?nMOk82ojRojP;ohL:i
0_nMOk8OojRojP@0Y/;]3OnV`^d01?l^9YD0Y/;]02hVU@0^9YD30?ZgMP<0T5bA0ooj]g@3oi1MT@Co
nkMc1?ok]g401OnAGi?onkM`oo^gL?ok]g3oTV2C00ConkM_00?oTV6Doo^gKOok]fd00_nCHI@3oobg
K005oi=RUOl0003oo;I[oobfJonDHiD00ool]VT01OnDHiKoo;IWoobfIooooooo000002;ooooo00?o
0000ooooooooool05?ooool40:O0k0030000O00007/0001k00l0Y/7]0`1=F/0?0:K2kAd0ZKgX?Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooo
oooo02?ooooo0_nCI9P00olW4GooWGnboieo/P08oieo/R[oZ;oZ0_lC1Wd00onW`NcoY/;]ojO1k003
ojO1k0;oY/;]0_nW`N`2ojO0j`?oY/;]00Co;RJE02hVU@0^9YD0;RJE0P3j]gH2091LT@;oYL?_0_oj
]g@2oi1MT@;oYL?_0ook]g<5oo^gL@?onkM`00?oTV2Coo^gKook]fl00_ok]fl01OnBHIConkM]oo^g
KOok]fgoTf6D00?oo;M/00CoTf:EoobfJol0003oo;I[0_nDHiD2oobfJ@05oiASU_ol]VOoo;IWoobf
Iol000008oooool2o`0001Gooooo0`2W`>`00`0007`0001k0:K1k@0?0:K1k@80CE[03`2V`^dJ0:Vm
j47ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`006_ooool2o`0002?o
oooo0_nCI9P2obLAO`OoWGnb;OnX_nX9ojO1k0CoYl3[0onV`^d00ol^9YD0;RJE02hVU@0=ojG3k`?o
nkMc1Ook]g43oo^gL003oi9PTook]foonkM_00;onkM_00GoTV6Doo^gKOok]fgonkM]oi=QU003oobg
K004oi=RUOol]V_oo;I[o`0000;oU6>E0_ol]VT01_nDHiKoo;IWoobfIool]VOoooooo`0002Cooooo
00?o0000ooooooooool05?ooool00`2W`>`0001l0:O0k00@0:K1k@80CE_0302V`^dK0:Vmj4Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003ooooooooo
o`0Pooooo`;oTfBH0_lW4Gl3oieo/SGoZ;oZ00CoYl7/ojRoj_nX_n[oZ;oZ1_nW`>/2ojK2k@;o;RJE
3onU`nl00ook]g?oYL?_ojG3k`04oo^gL@ConkM`1?ok]fl01OnBHIConkM]oo^gKOok]fgoTf6D00?o
o;M/00KoTf:EoobfJool]V_oo;I[o`000?nDHiD2oobfJ@;oU6>F0_ol]VL00ooooooo0000ooooo`0T
ooooo`03o`000?oooooooooo01Cooooo00@0Yl3/0000O00007`0001l3`2V`Nd204eK`0/0Y/;]602Y
_NQ8ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool001gooooo00?o0000
ooooooooool07oooool2oi=TV0;o9a5o00?oWGnbojRoj_nX_nX0>_nX_nX5ojO0j`03ojK2kOl_9iKo
;RJE01CoYL?_0ook]g44oo^gL0ConkM_00GoTV6Doo^gKOok]fgonkM]oi=QU003oobgK006oi=RUOol
]V_oo;I[oobfJol0003oU6>E0_ol]VT2oiASUP;oo;IW00?oooooo`000?ooool09Oooool00ol0003o
ooooooooo`0Cooooo`030:O0k00007`0001l00l0Y/7]00<0CU_004eK`02V`^d0202V`^dG0:Vmj4co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`007_ooool00ol0003ooooo
ooooo`0Nooooo`03oi=TV?nX_n[oZ;oZ03ooZ;oZ1OnW`>/2oblWUQSoYL?_0ook]g05oo^gK`?onkM]
00GoTf6DoobgK?ol]fcoo;M/oi=RU@04oobfJ`03o`000?ol]VWoo;IY00;oU6>F0_ol]VL00ooooooo
0000ooooo`0Vooooo`03o`000?oooooooooo01?ooooo0P0007`@0:K1k@0304iK`02V`^d0Y/;]00L0
Y/;]4`2Y_NQAooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool001oooooo
00?o0000ooooooooool07ooooom1ojRojPCoYl3[00?oY/;]oblWU_nU`nl06?nU`nl2oo^gL0GonkM_
0ook]fd01OnCHICoo;M/oobgK?ol]fcoTf:E00Coo;I[00GoU6>Eo`000?ol]VWoo;IYoiASUP02oobf
I`03ooooool0003ooooo02Oooooo0_l0000Cooooo`030000O02V`Nd0Y/7]00h0Y/7]00@0036/04iK
`01>Fl00CU_01P2V`^d00oooool0ZKgX0:Vmj00?0:Vmj5Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0;ooooo`008?ooool2o`00023ooooo@OnX_nX4ojO0j`;o;bNF6onU`nl4oo^g
K`ConkM]0ool]f`00onCHYGoo;I[oobfJ`02oobfJ`05oiASUOl0003oo;IYoobfJOnDHiH00_ol]VL0
0ooooooo0000ooooo`0Yooooo`03o`000?oooooooooo013ooooo00<0Yl3/0:K1k@2V`Nd03`2V`Nd0
0`00<J`0CU_00:K2k@040:K2k@Cooooo302Y_NQIooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool002;ooooo00?o0000ooooooooool07_oooom0ojRojP04oooooonW`>_oYl3[
ojO0jakoYL?_0_ok]fl00onU`noonkM]oo^gK@02oo^gK@Coo;M/1?ol]V/01OnDHiGoo;IYo`000?ol
]VWoU6>F00?oo;IW00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`030000OP00
07d0001m00l0Y/7]0P1?Fl030:K2k@Oooooo202Y_NQLooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool07_oooolmojRojPCooooo0onW`>/Q
ojG3k`?onkM]1?ol]f`4oobfJ`05oiASUOol]VWoo;IYo`000?nDHiH00ool]VL00ooooooo0000oooo
o`0Zooooo`03o`000?oooooooooo00oooooo00<0001m0:K1k@2V`Nd03@2V`Nd01000;jT0Y/7]04mK
`01?Fl020:K2k@Sooooo0`2Y_NQQooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2_ooool002Cooooo00?o0000ooooooooool07ooooolfojRojPWooooo1?nW`>/2ojG3k`;oYl3[7OnU
`nl00ook]fgoYL?_ojG3k`03oobgK0Coo;I[00GoU6>EoobfJOol]VWoo;IYo`000003oobfI`03oooo
ool0003ooooo02_ooooo0_l0000?ooooo`030000OP2V`Nd0Y/7]00h0Y/7]00<002nY04mK`?ooool0
2_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2_ooool002Gooooo0_l0000Poooooc7oZ;oZ3_ooool7ojO0jb3oYL?_0ool]f`5oobfJ`?oo;IY00Ko
0000oobfIool]VOoo;IWooooool0000^ooooo`03o`000?oooooooooo00cooooo0P0007h=0:K1k@oo
oooo00?o0000ooooooooool0Hoooool01Ol0003ooooooooooooooooo000000cooooo000Wooooo`03
o`000?oooooooooo01kooooo;_nX_nXAooooo`OoYl3[00?oYL?_ooooooooool07OnU`nl00ool]fco
YL?_ojG3k`04oobfJ`?oo;IY00KoU6>Fo`000?ol]VOoo;IWooooool0000_ooooo`03o`000?oooooo
oooo00_ooooo00<0001n0:K1k@2V`Nd0302V`Nd?ooooo`03o`000?oooooooooo06?ooooo00Go0000
ooooooooooooooooo`00000<ooooo`00:?ooool00ol0003oooooooooo`0NooooobWoZ;oZ5_ooool0
0onW`>_oooooooooo`09ooooo`;oYL?_0_ooool4ojG3k`;ooooo5?nU`nl3oobfJ`Coo;IY00Goo;IW
o`000?ol]VOoooooo`00000`ooooo`03o`000?oooooooooo00cooooo302V`Nd@ooooo`03o`000?oo
oooooooo06Cooooo00Co0000oooooooooooo00003?ooool002Wooooo00?o0000ooooooooool07Ooo
oolUojRojS?ooooo00?oYL?_ooooooooool04OnU`nl4oobfJ@;oo;IW00?o0000oobfIol00000<Ooo
ool2o`0000gooooo2`2V`Nd@ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooool000003?oo
ool002[ooooo00?o0000ooooooooool07OoooolPojRojSkooooo00?oYL?_ooooooooool02onU`nl3
oobfJ@;oo;IW00?o0000oobfIol00000<oooool00ol0003oooooooooo`0;ooooo`L0Y/7]4oooool0
0ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0000_ooooo000[ooooo`;o00007_oooolM
ojRojTKooooo0_nU`nl2ooooo`SoYL?_0_ol]VL00ol0003oooooo`00000cooooo`03o`000?oooooo
oooo00cooooo1@2V`NdCooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool000002oooool0
02gooooo00?o0000ooooooooool07OoooolHojRojU3ooooo00?oYL?_oooooonU`nl00onU`nl01?ol
]VOoYL?_o`000?l0000dooooo`03o`000?oooooooooo00cooooo0`2V`NdDooooo`03o`000?oooooo
oooo06Oooooo0_l0000;ooooo`00;_ooool00ol0003oooooooooo`0Moooooa?oZ;oZEoooool2ojG3
k`03oooooonU`nooYL?_00;o0000=Oooool2o`0000gooooo0P2V`NdDooooo`03o`000?oooooooooo
06Kooooo0ol0000;ooooo`00;oooool00ol0003oooooooooo`0Mooooo`koZ;oZFoooool4o`0003[o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Rooooo`Co00003_ooool0033ooooo
0_l0000Nooooo`WoZ;oZG?ooool3o`0003oooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`1Oooooo`?o00004_ooool003;ooooo00?o0000ooooooooool07?ooool6ojRojU[ooooo1?l0
0013ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Foooool4o`0001Gooooo000c
ooooo`03o`000?oooooooooo01cooooo00?oZ;oZooooooooool0F?ooool4o`0004Sooooo0_l0000N
ooooo`03o`000?oooooooooo05Oooooo1?l0000Iooooo`00=?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo05Cooooo1?l0001>ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0E?ooool3o`0001gooooo000eooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0DOooool3o`0005?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1@ooooo`Co
00008?ooool003Kooooo0_l0000Jooooo`03o`000?oooooooooo04gooooo1?l0001Gooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0C?ooool4o`0002Cooooo000hooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0BOooool4o`0005cooooo0_l0000Iooooo`03o`000?oo
oooooooo04Sooooo1?l0000Xooooo`00>Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo04Gooooo1?l0001Rooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0AOooool3
o`0002cooooo000jooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool3o`00
06Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`11ooooo`Co0000;oooool003_o
oooo0_l0000Eooooo`03o`000?oooooooooo03kooooo1?l0001[ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0?_ooool4o`0003?ooooo000mooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0>_ooool4o`00073ooooo0_l0000Cooooo`03o`000?oooooooooo03[ooooo
1?l0000gooooo`00?_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Kooooo1?l0
001fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=oooool3o`0003_ooooo000o
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool4o`0007_ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0cooooo`Co0000?_ooool0043ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0_ooooo`?o0000P?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02oooooo1?l00012ooooo`00@Oooool2o`0000oooooo00?o0000oooooooo
ool0:oooool4o`0008Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`?o
0000A_ooool004?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`Co0000
ROooool2o`0000gooooo00?o0000ooooooooool0:?ooool4o`0004Wooooo0014ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool08oooool4o`0008oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Tooooo`Co0000COooool004Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Pooooo`?o0000U?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo023ooooo1?l0001Aooooo`00A_ooool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`00
09Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`?o0000EOooool004So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`Co0000WOooool2o`0000So
oooo00?o0000ooooooooool06Oooool4o`0005Sooooo0019ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05Oooool4o`000:?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Eooooo`Co0000G?ooool004[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Booooo`?o0000Z?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo1?l0
001Pooooo`00Boooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002/
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool3o`0006Cooooo001<oooo
o`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000/Oooool2o`0000?ooooo00?o0000oooo
ooooool02_ooool4o`0006Oooooo001>ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002goooo
o`04o`000?ooooooooooo`0000Sooooo1?l0001[ooooo`00Coooool00ol0003oooooo`000005oooo
o`?o0000_?ooool00ol0003oooooo`000005ooooo`?o0000Koooool0053ooooo0_l000000ooooooo
0000o`000002o`000<3ooooo0_l000000ooooooo0000o`000002o`0007;ooooo001Aooooo`;o0000
aOooool2o`0007Kooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {153.5, 0}} -> {-0.0542361, -0.0193168, \
0.0052844, 0.0052844}, {{10.25, 190.438}, {149.812, 3.625}} -> {-0.0541935, \
0.0451583, 0.00528671, 0.00528671}, {{208.5, 388.688}, {149.812, 3.625}} -> \
{-1.10228, 0.0451583, 0.00528671, 0.00528671}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New classification of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gdnoFrame\  = \ 
        Show[gd, \ Frame \[Rule] False, \ nS];\)\), "\[IndentingNewLine]", 
    \(\(gclass\  = \ 
        DrawHistogramClass[{h1, h2}, \ {class1Color, class2Color}, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{gdnoFrame, gclass}], yS, \ imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.49505 0.5 0.49505 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.76921 .64295 Mdot
.56704 .69013 Mdot
.75295 .59186 Mdot
.68704 .57554 Mdot
.7077 .64248 Mdot
.72536 .69368 Mdot
.56743 .81534 Mdot
.6185 .66989 Mdot
.7966 .59181 Mdot
.91874 .53216 Mdot
.63443 .74925 Mdot
.67714 .58782 Mdot
.68619 .65385 Mdot
.63347 .67867 Mdot
.78301 .68453 Mdot
.431 .75982 Mdot
.83512 .58625 Mdot
.62213 .69227 Mdot
.65099 .52892 Mdot
.68982 .60815 Mdot
.62373 .60539 Mdot
.70365 .5862 Mdot
.46149 .7704 Mdot
.96423 .55213 Mdot
.58757 .75816 Mdot
.66269 .50089 Mdot
.77416 .67256 Mdot
.64296 .68883 Mdot
.68658 .64317 Mdot
.6796 .62759 Mdot
.59038 .7189 Mdot
.93142 .57169 Mdot
.43749 .63803 Mdot
.69974 .72659 Mdot
.69326 .67323 Mdot
.77793 .6757 Mdot
.78924 .5041 Mdot
.4401 .83425 Mdot
.58603 .51263 Mdot
.78866 .65554 Mdot
.44366 .65311 Mdot
.727 .70103 Mdot
.62042 .75592 Mdot
.80902 .64126 Mdot
.51964 .63381 Mdot
.6647 .635 Mdot
.51329 .73266 Mdot
.65075 .59886 Mdot
.47075 .68029 Mdot
.56864 .73715 Mdot
.80079 .49161 Mdot
.67625 .72883 Mdot
.65021 .77721 Mdot
.97719 .52753 Mdot
.73793 .59678 Mdot
.73021 .58639 Mdot
.56985 .75537 Mdot
.73744 .60898 Mdot
.6851 .61125 Mdot
.61857 .83447 Mdot
.62482 .71998 Mdot
.79441 .52571 Mdot
.50075 .76869 Mdot
.51028 .57576 Mdot
.75974 .68296 Mdot
.40991 .62938 Mdot
.70963 .69078 Mdot
.59779 .56609 Mdot
.65813 .63733 Mdot
.5929 .59807 Mdot
.94806 .4805 Mdot
.49059 .76358 Mdot
.5947 .59351 Mdot
.26742 .80621 Mdot
.55099 .89452 Mdot
.67095 .62172 Mdot
.72009 .64925 Mdot
.65949 .66589 Mdot
.85005 .50774 Mdot
.53748 .70428 Mdot
.83179 .61265 Mdot
.72058 .50966 Mdot
.83562 .62877 Mdot
.59405 .70406 Mdot
.56972 .71403 Mdot
.69442 .59167 Mdot
.71954 .64562 Mdot
.71914 .61218 Mdot
.65898 .61832 Mdot
.73796 .61888 Mdot
.6014 .78205 Mdot
.79683 .55767 Mdot
.62126 .66387 Mdot
.77326 .50924 Mdot
.8496 .62908 Mdot
.51148 .73852 Mdot
.63201 .75524 Mdot
.60299 .71066 Mdot
.63009 .7393 Mdot
.59565 .71558 Mdot
0 0 1 r
.1162 .19077 Mdot
.24801 .25894 Mdot
.30902 .37049 Mdot
.18551 .28447 Mdot
.21993 .14635 Mdot
.02549 .16303 Mdot
.08225 .09379 Mdot
.37208 .31797 Mdot
.21305 .25985 Mdot
.22133 .20287 Mdot
.39469 .36398 Mdot
.10113 .29615 Mdot
.20089 .20862 Mdot
.51363 .42542 Mdot
.1511 .2407 Mdot
.23301 .18202 Mdot
.16033 .11693 Mdot
.2447 .32645 Mdot
.5096 .43276 Mdot
.25586 .29169 Mdot
.20055 .12342 Mdot
.24726 .24881 Mdot
.19842 .19721 Mdot
.26062 .2788 Mdot
.29485 .27788 Mdot
.28462 .29833 Mdot
.13895 .13094 Mdot
.064 .19115 Mdot
.49848 .34485 Mdot
.2812 .30219 Mdot
.50266 .28702 Mdot
.26402 .2562 Mdot
.28044 .30149 Mdot
.24434 .25201 Mdot
.39987 .44812 Mdot
.46729 .35465 Mdot
.33173 .26109 Mdot
.21507 .22824 Mdot
.36508 .28363 Mdot
.09954 .2719 Mdot
.38085 .3301 Mdot
.04621 .21355 Mdot
.30535 .23911 Mdot
.49027 .39152 Mdot
.23274 .29061 Mdot
.43262 .23807 Mdot
.25424 .1969 Mdot
.29699 .25132 Mdot
.2794 .24928 Mdot
.22965 .26337 Mdot
.41048 .29125 Mdot
.33432 .28509 Mdot
.31801 .25888 Mdot
.14785 .18068 Mdot
.53255 .43691 Mdot
.11549 .17091 Mdot
.27123 .17228 Mdot
.17499 .14652 Mdot
.35782 .30983 Mdot
.28877 .2093 Mdot
.30443 .31716 Mdot
.14287 .20794 Mdot
.27211 .34369 Mdot
.18753 .21951 Mdot
.18918 .27159 Mdot
.4538 .31739 Mdot
.22019 .29944 Mdot
.16333 .23401 Mdot
.04671 .13445 Mdot
.25109 .1515 Mdot
.11931 .18207 Mdot
.35414 .28788 Mdot
.20382 .26025 Mdot
.3703 .36834 Mdot
.48294 .35325 Mdot
.27007 .2202 Mdot
.29123 .27611 Mdot
.04322 .15197 Mdot
.1047 .11027 Mdot
.26397 .25715 Mdot
.2582 .25228 Mdot
.10358 .19648 Mdot
.41186 .28622 Mdot
.34047 .33201 Mdot
.07782 .20346 Mdot
.45474 .34458 Mdot
.01792 .17003 Mdot
.29718 .34707 Mdot
.05681 .20874 Mdot
.19923 .12606 Mdot
.26693 .23785 Mdot
.23707 .14248 Mdot
.2935 .26349 Mdot
.23856 .28659 Mdot
.37127 .31719 Mdot
.36967 .41544 Mdot
.09343 .12923 Mdot
.27573 .28996 Mdot
.40644 .40736 Mdot
.40734 .32038 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.0238095 0.0186741 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
153 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00e?oooonI
o`00oaCoo`003oooool00=CoooooVOl00?lDool000oooooo003DoooooiWo003o5?oo000?ooooo`00
e?oooonEo`00oaSoo`003oooool00=CoooooUOl00?lHool000oooooo003DoooooiGo003o6?oo000?
ooooo`00e?oooonEo`00oaSoo`003oooool00=CoooooT_l00?lKool000oooooo003Doooooi;o003o
6ooo000?ooooo`00e?oooonBo`00oa_oo`003oooool00=CoooooT_l00?lKool000oooooo000Goooo
o`?o003o^_oooonBo`00oa_oo`003oooool001Oooooo0ol00?njoooooi;o003o6ooo000?ooooo`00
5oooool3o`00ok[oooooSol00?lNool000oooooo000Kooooo`?o003o]_oooon?o`00oakoo`003ooo
ool001_ooooo0ol00?l7ooooo`?o003o[?oooon?o`00oakoo`003oooool001_ooooo0ol00?l7oooo
o`?o003o1?ooool3o`00ojGoooooSol00?lNool000oooooo000Iooooo`?o003o1Oooool3o`00o`04
ooooool00?oo003oo`00o`Cooooo0ol00?nUoooooh_o003o8_oo000?ooooo`004Oooool3o`00o`Go
oooo0ol00?l5ooooo`?o003o2?ooool3o`00ojGoooooRol00?lRool000oooooo000Aooooo`?o003o
1Oooool3o`00o`Gooooo0ol00?l8ooooo`?o003oYOoooon;o`00ob;oo`003oooool0017ooooo0ol0
0?lDooooo`?o003o1Oooool6o`00oikoooooRol00?lRool000oooooo000@ooooo`?o003o5Oooool3
o`00o`Gooooo2Ol00?nKoooooh_o003o8_oo000?ooooo`004?ooool3o`00oaGooooo0ol00?l5oooo
o`Wo003oVooooon;o`00ob;oo`003oooool000gooooo1_l00?lSooooo`?o003oVooooon8o`00obGo
o`003oooool000gooooo0ol00?o4ooooohSo003o9Ooo000?ooooo`003?ooool4o`00o`gooooo0ol0
0?lIooooo`?o003oV?oooon8o`00obGoo`003oooool000cooooo0ol00?l>ooooo`?o003o0oooool3
o`00oa?ooooo0ol00?nHooooohSo003o9Ooo000?ooooo`003?ooool3o`00o`kooooo1?l00?l2oooo
o`?o003o3?ooool3o`00o`Cooooo0ol00?nHooooohCo003o:Ooo000?ooooo`005?ooool3o`00o`Ko
oooo1?l00?l2ooooo`?o003o3?ooool3o`00oiooooooQ?l00?lYool000oooooo000Dooooo`?o003o
1?ooool6o`00o`_ooooo0ol00?l3ooooo`?o003o00Coooooo`00ool00?oo003oVooooon4o`00obWo
o`003oooool001Cooooo0ol00?l4ooooo`Go003o3?ooool3o`00o`04ooooool00?oo003oo`00o`?o
oooo0ol00?nKooooohCo003o:Ooo000?ooooo`005_ooool3o`00o`;ooooo0ol00?l4ooooo`?o003o
1oooool3o`00o`04ooooool00?oo003oo`00o`?ooooo0ol00?nKooooohCo003o:Ooo000?ooooo`00
4Oooool8o`00o`Wooooo0ol00?l8ooooo`Ko003o2Oooool3o`00oiGoooooQ?l00?lYool000oooooo
000Aooooo`So003o2Oooool3o`00o`Gooooo1_l00?l<ooooo`?o003oUOoooon1o`00obcoo`003ooo
ool0017ooooo1Ol00?lDooooo`Ko003o2Oooool6o`00oiGoooooPOl00?l/ool000oooooo000Zoooo
o`?o003o0_ooool3o`00o`Oooooo0ol00?nHoooooh7o003o;?oo000?ooooo`009_ooool3o`00o`Ko
oooo0ol00?l7ooooo`?o003oV?oooon1o`00obcoo`003oooool002Cooooo1Ol00?l6ooooo`?o003o
1_ooool3o`00o`Cooooo0ol00?lDooooo`?o003oNooooomno`00obooo`003oooool002Cooooo1Ol0
0?l?ooooo`?o003o1?ooool3o`00oaCooooo0ol00?mkooooogko003o;ooo000?ooooo`009?ooool3
o`00o`gooooo3_l00?lDooooo`?o003oNooooomno`00obooo`003oooool003Cooooo3Ol00?nCoooo
ogko003o;ooo000?ooooo`00;OoooolDo`00o`03ooooool00?oo003o00?o003oSOoooomno`00oboo
o`003oooool002gooooo3_l00?l2ooooo`?o003o0_ooool5o`00ohgoooooO_l00?l_ool000oooooo
000Jooooo`?o003o3Oooool>o`00o`Gooooo0ol00?l2ooooo`Go003oSOoooomjo`00oc?oo`003ooo
ool001[ooooo0ol00?l=ooooo`?o003o2_ooool3o`00o`?ooooo0ol00?nDooooog[o003o<ooo000?
ooooo`006_ooool3o`00o`gooooo0ol00?l:ooooo`?o003o0oooool3o`00o`Gooooo0ol00?l2oooo
o`?o003oQooooomjo`00oc?oo`003oooool002[ooooo0ol00?l5ooooo`ko003o1Oooool8o`00o`Go
oooo1?l00?l=ooooo`?o003oK_oooomjo`00oc?oo`003oooool001_ooooo0ol00?l<ooooo`?o003o
1Oooool7o`00o`04ooooool00?oo003oo`00o`Sooooo2?l00?l5ooooo`Co003o3Oooool3o`00ofko
ooooN_l00?lcool000oooooo000Kooooo`?o003o4_ooool9o`00o`03ooooool00?oo003o00?o003o
2Oooool3o`00o`Oooooo1?l00?l=ooooo`?o003oK_oooomjo`00oc?oo`003oooool001_ooooo0ol0
0?lBooooo`?o003o2?ooool4o`00oiGoooooN_l00?lcool000oooooo000`ooooo`?o003o2?ooool4
o`00o`[ooooo0ol00?n8ooooog[o003o<ooo000?ooooo`00?oooool3o`00o`Oooooo1Ol00?l<oooo
o`?o003oMooooomjo`00oc?oo`003oooool003oooooo0ol00?l7ooooo`Go003o1?ooool3o`00o`Go
oooo0ol00?mgooooog[o003o<ooo000?ooooo`00=?ooool3o`00o`Sooooo0ol00?l9ooooo`Go003o
0_ooool3o`00o`Gooooo0ol00?mgooooog[o003o<ooo000?ooooo`00=?ooool3o`00o`oooooo0ol0
0?l4ooooo`?o003o0_ooool3o`00ogooooooMol00?lfool000oooooo000dooooo`?o003o3oooool3
o`00o`Cooooo0ol00?n4ooooogOo003o=_oo000?ooooo`00>Oooool3o`00o`;ooooo0ol00?l5oooo
o`?o003o4Oooool3o`00o`Gooooo0ol00?m_ooooogOo003o=_oo000?ooooo`00>Oooool3o`00o`;o
oooo0ol00?lIooooo`?o003o1Oooool3o`00ofooooooMol00?lfool000oooooo000iooooo`?o003o
0_ooool3o`00oaWooooo2ol00?m_ooooogOo003o=_oo000?ooooo`00GOooool5o`00og;oooooMol0
0?lfool000oooooo001;ooooo`?o003o0_ooool3o`00o`[ooooo1Ol00?mbooooog?o003o>_oo000?
ooooo`00@?ooool3o`00o`Sooooo0ol00?l2ooooo`?o003oPOoooomco`00oc[oo`003oooool0043o
oooo0ol00?l8ooooo`?o003o0_ooool3o`00oh7oooooLol00?ljool000oooooo0010ooooo`?o003o
TOoooomco`00oc[oo`003oooool0067ooooo0ol00?m`ooooog?o003o>_oo000?ooooo`00HOooool3
o`00og3oooooLol00?ljool000oooooo001Qooooo`?o003oL?oooomco`00oc[oo`003oooool005;o
oooo0ol00?moooooog?o003o>_oo000?ooooo`00D_ooool3o`00ogooooooLol00?ljool000oooooo
001;ooooo`?o003o1?ooool3o`00ogooooooLol00?ljool000oooooo001;ooooo`?o003oQ_oooom`
o`00ocgoo`003oooool004_ooooo0ol00?lGooooo`?o003oK?oooom`o`00ocgoo`003oooool006Co
oooo1?l00?m/ooooog3o003o?Ooo000?ooooo`00I?ooool7o`00ofWoooooL?l00?lmool000oooooo
001Tooooo`?o003o00Coooooo`00ool00?oo003oJOoooom]o`00od3oo`003oooool0053ooooo0ol0
0?lEooooo`?o003oJOoooom]o`00od3oo`003oooool0053ooooo0ol00?n1ooooofgo003o@?oo000?
ooooo`00D?ooool3o`00oh7oooooJOl00?m4ool000oooooo003DooooofWo003oA?oo000?ooooo`00
e?oooomYo`00odCoo`003oooool00=CoooooI_l00?m7ool000oooooo002cooooo`?oo`007_oooomV
o`00odOoo`003oooool00;?ooooo0ooo000NooooofKo003oAooo000?ooooo`00VOooool3ool001Oo
oooo0ooo000NooooofKo003oAooo000?ooooo`00P?ooool3ool001Kooooo0ooo000hooooof?o003o
B_oo000?ooooo`00P?ooool3ool001Cooooo1Ooo0006ooooo`?oo`00;ooooomSo`00od[oo`003ooo
ool007;ooooo0ooo000;ooooo`?oo`001oooool3ool000Oooooo1_oo0008ooooo`?oo`00;ooooomS
o`00od[oo`003oooool007;ooooo0ooo000Eooooo`?oo`001oooool6ool000Sooooo0ooo000_oooo
ocOo003o8Ooo0004o`00oe7oo`003oooool007;ooooo0ooo000Eooooo`?oo`001oooool3ool003go
oooo=ol00?lQool000Co003oDOoo000?ooooo`00O_ooool3ool001Oooooo0ooo000Nooooo`?oo`00
6?oooolgo`00ob7oo`001?l00?mAool000oooooo001nooooo`?oo`005oooool3ool001?ooooo0ooo
0008ooooo`?oo`006?ooool`o`00oggoo`003oooool007kooooo0ooo000Gooooo`?oo`004oooool3
ool000Sooooo0ooo000Hoooooc3o003oOOoo000?ooooo`00[_ooool3ool002?ooooo<?l00?mmool0
00oooooo002fooooo`?oo`006oooool`o`00oggoo`003oooool009Sooooo0ooo000Kooooo`?oo`00
6ooooolVo`00ohOoo`003oooool009Sooooo0ooo000Kooooo`?oo`006ooooolVo`00ohOoo`003ooo
ool007Cooooo0ooo000Qooooo`?oo`00>OoooolVo`00ohOoo`003oooool007Cooooo0ooo000ioooo
o`?oo`008OoooolOo`00ohkoo`003oooool006Cooooo0ooo000=ooooo`?oo`003Oooool3ool002Wo
oooo0ooo000Qoooooaoo003oS_oo000?ooooo`00I?ooool3ool001gooooo0ooo000Yooooo`?oo`00
8OoooolOo`00ohkoo`003oooool006Cooooo0ooo000Kooooo`Soo`000_ooool3ool0013ooooo0ooo
000boooooaGo003oV?oo000?ooooo`00M?ooool3ool000_ooooo0ooo00000oooooooo`00ool00002
ool000;ooooo0ooo00001?ooooooo`00ool00?oo0005ooooo`?oo`001?ooool3ool003;ooooo5Ol0
0?nHool000oooooo001cooooo`Coo`001oooool3ool00005oooooooo003oo`00ool00?ooool01?oo
0002ooooo`Ooo`001Oooool3ool000Cooooo0ooo000boooooaGo003oV?oo000?ooooo`00Loooool4
ool000;ooooo0ooo0002ooooo`?oo`001Oooool3ool000Cooooo1_oo0005ooooo`?oo`00>OoooolE
o`00oiSoo`003oooool007?ooooo0ooo0003ooooo`?oo`000_ooool3ool000?ooooo1?oo0002oooo
o`Koo`003_ooool3ool003?ooooo4Ol00?nLool000oooooo001iooooo`?oo`000oooool3ool000;o
oooo1?oo0002ooooo`Koo`003_ooool3ool003?ooooo4Ol00?nLool000oooooo001oooooo`Woo`00
0_ooool6ool000kooooo0ooo000coooooa7o003oW?oo000?ooooo`00D_ooool3ool002[ooooo1ooo
0007ooooo`?oo`003oooool6ool002oooooo2_l00?nSool000oooooo001Booooo`?oo`004Oooool3
ool001Oooooo1_oo0007ooooo`?oo`003oooool6ool002oooooo2_l00?nSool000oooooo001Boooo
o`?oo`000_ooool3ool000cooooo0ooo000Fooooo`Ooo`006Oooool6ool002oooooo2_l00?nSool0
00oooooo001Gooooo`?oo`003?ooool3ool001Kooooo1?oo00001Oooooooo`00ool00?oo003ooooo
00Goo`001_ooool3ool000Cooooo0ooo000gooooo`Oo003oY_oo000?ooooo`00Eoooool3ool002Go
oooo0ooo0002ooooo`?oo`0000?oooooool00?oo00000ooo0006ooooo`?oo`001?ooool3ool003Oo
oooo1ol00?nVool000oooooo001Hooooo`?oo`00:Oooool3ool00003oooooooo003oo`0000?oo`00
1_ooool3ool00003oooooooo003oo`0000Coo`00=oooool7o`00ojKoo`003oooool005Sooooo0ooo
000Yooooo`?oo`000oooool3ool000[ooooo0ooo000jooooo`Oo003oY_oo000?ooooo`00F?ooool3
ool001gooooo0ooo0004ooooo`?oo`000_ooool3ool0013ooooo0ooo000jooooojgoo`003oooool0
07Sooooo0ooo0004ooooo`?oo`000oooool3ool000cooooo0ooo000mooooojgoo`003oooool007So
oooo1_oo00001?ooooooo`00ool00?oo0003ooooo`?oo`003?ooool4ool003cooooo[Ooo000?oooo
o`00GOooool3ool001Sooooo1_oo0007ooooo`?oo`002Oooool8ool003_ooooo[Ooo000?ooooo`00
GOooool3ool000oooooo0ooo0009ooooo`Coo`002Oooool3ool000Kooooo0ooo00000oooooooo`00
ool00002ool003_ooooo[Ooo000?ooooo`00GOooool3ool000oooooo0ooo0007ooooo`Koo`002Ooo
ool6ool000?ooooo0ooo0002ooooo`?oo`00>ooooon]ool000oooooo001_ooooo`?oo`001oooool6
ool000Wooooo1_oo0016ooooojgoo`003oooool006Wooooo0ooo0007ooooo`?oo`000oooool3ool0
00oooooo0ooo0016ooooojgoo`003oooool006Wooooo0ooo0007ooooo`Goo`004oooool3ool004Ko
oooo[Ooo000?ooooo`00JOooool3ool000?ooooo0ooo00000oooooooo`00ool00003ool005cooooo
[Ooo000?ooooo`00Koooool3ool00003oooooooo003oo`0000?oo`0000Coooooool00?oo003oo`00
F?oooon]ool000oooooo001_ooooo`?oo`0000?oooooool00?oo00000_oo0002ooooo`?oo`001_oo
ool3ool000;ooooo0ooo001:ooooojgoo`003oooool006Gooooo0ooo000;ooooo`?oo`000oooool3
ool000Kooooo0ooo0002ooooo`?oo`00B_oooon]ool000oooooo001Uooooo`?oo`001oooool3ool0
00Sooooo0ooo0005ooooo`?oo`000_ooool3ool004[ooooo[Ooo000?ooooo`00IOooool3ool000Oo
oooo0ooo0008ooooo`?oo`00Eooooon]ool000oooooo001Uooooo`?oo`001oooool3ool000Sooooo
1?oo001Fooooojgoo`003oooool006oooooo0ooo0006ooooo`Koo`00E_oooon]ool000oooooo001F
ooooo`?oo`005_ooool6ool000?ooooo1_oo001Fooooojgoo`003oooool005Kooooo0ooo0008oooo
o`?oo`002oooool6ool000?ooooo1Ooo001Gooooojgoo`003oooool005Kooooo0ooo0003ooooo`?o
o`000_ooool5ool000cooooo0ooo001Oooooojgoo`003oooool005cooooo0ooo0002ooooo`Goo`00
6?ooool3ool005?ooooo[Ooo000?ooooo`00G?ooool3ool000Cooooo0ooo000?ooooo`?oo`001_oo
ool3ool005?ooooo[Ooo000?ooooo`00MOooool3ool000Kooooo0ooo001Cooooojgoo`003oooool0
07Gooooo0ooo001Looooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00>Oooool3ool009Sooooo
[Ooo000?ooooo`00>Oooool3ool009Sooooo[Ooo000?ooooo`00>Oooool3ool003?ooooo0ooo001R
ooooojgoo`003oooool006oooooo0ooo001Rooooojgoo`003oooool006oooooo0ooo001Rooooojgo
o`003oooool005Sooooo0ooo000Mooooo`?oo`00FOoooon]ool000oooooo001Hooooo`?oo`007Ooo
ool3ool005Wooooo[Ooo000?ooooo`00F?ooool3ool001gooooo0ooo001Iooooojgoo`003oooool0
0=Cooooo[Ooo000?ooooo`00e?oooon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo
000?ooooo`00e?oooon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00
e?oooon]ool000oooooo001/ooooo`?oo`00IOoooon]ool000oooooo001/ooooo`?oo`00IOoooon]
ool000oooooo001/ooooo`?oo`00IOoooon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo
[Ooo000?ooooo`00e?oooon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?oooo
o`00e?oooon]ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00e?oooon]
ool000oooooo003Dooooojgoo`003oooool00=Cooooo[Ooo000?ooooo`00e?oooon]ool000oooooo
003Dooooojgoo`003oooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-1.1227, \
-1.0611, 0.011199, 0.011199}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-63.1851, -2.62981, 0.296885, 0.296885}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 828}},
WindowSize->{668, 600},
WindowMargins->{{19, Automatic}, {Automatic, 9}},
ShowSelection->True,
CellLabelAutoDelete->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 51, 0, 62, "Title"],

Cell[CellGroupData[{
Cell[1830, 55, 27, 0, 59, "Section"],
Cell[1860, 57, 347, 7, 46, "Text"],
Cell[2210, 66, 496, 8, 82, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2743, 79, 42, 0, 59, "Section"],
Cell[2788, 81, 36, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2849, 85, 53, 0, 49, "Subsection"],
Cell[2905, 87, 234, 5, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3176, 97, 53, 0, 49, "Subsection"],
Cell[3232, 99, 278, 5, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3547, 109, 40, 0, 49, "Subsection"],
Cell[3590, 111, 73, 1, 47, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3712, 118, 51, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3788, 122, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3873, 126, 55, 0, 43, "Subsubsection"],
Cell[3931, 128, 157, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4125, 137, 39, 0, 43, "Subsubsection"],
Cell[4167, 139, 244, 6, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4448, 150, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[4512, 154, 287, 6, 79, "Input"],
Cell[4802, 162, 29992, 577, 296, 4497, 258, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34855, 746, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[34922, 750, 62, 0, 43, "Subsubsection"],
Cell[34987, 752, 110, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35134, 760, 64, 0, 43, "Subsubsection"],
Cell[35201, 762, 138, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35376, 770, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[35440, 774, 149, 3, 63, "Input"],
Cell[35592, 779, 16577, 270, 296, 1024, 73, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[52230, 1056, 48, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[52303, 1060, 70, 0, 43, "Subsubsection"],
Cell[52376, 1062, 160, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52573, 1069, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[52647, 1073, 317, 7, 79, "Input"],
Cell[52967, 1082, 354246, 6145, 163, 321764, 5741, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[407274, 7234, 51, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[407350, 7238, 329, 6, 95, "Input"],
Cell[407682, 7246, 34712, 730, 199, 21291, 561, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[442455, 7983, 60, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[442540, 7987, 76, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[442641, 7991, 55, 0, 43, "Subsubsection"],
Cell[442699, 7993, 157, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[442893, 8002, 52, 0, 43, "Subsubsection"],
Cell[442948, 8004, 282, 5, 95, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[443267, 8014, 39, 0, 43, "Subsubsection"],
Cell[443309, 8016, 184, 3, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[443530, 8024, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[443594, 8028, 287, 6, 79, "Input"],
Cell[443884, 8036, 30118, 579, 296, 4497, 258, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[474063, 8622, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[474130, 8626, 62, 0, 43, "Subsubsection"],
Cell[474195, 8628, 110, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[474342, 8636, 64, 0, 43, "Subsubsection"],
Cell[474409, 8638, 138, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[474584, 8646, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[474648, 8650, 149, 3, 63, "Input"],
Cell[474800, 8655, 15990, 257, 296, 875, 66, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[490851, 8919, 48, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[490924, 8923, 70, 0, 43, "Subsubsection"],
Cell[490997, 8925, 160, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[491194, 8932, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[491268, 8936, 313, 7, 79, "Input"],
Cell[491584, 8945, 352821, 6073, 163, 320930, 5676, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[844466, 15025, 51, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[844542, 15029, 329, 6, 95, "Input"],
Cell[844874, 15037, 34266, 724, 199, 21291, 561, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[879189, 15767, 71, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[879285, 15771, 135, 5, 43, "Subsubsection"],
Cell[879423, 15778, 101, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[879561, 15786, 57, 0, 43, "Subsubsection"],
Cell[879621, 15788, 190, 3, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[879848, 15796, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[879912, 15800, 144, 3, 63, "Input"],
Cell[880059, 15805, 15775, 254, 296, 878, 65, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[895895, 16066, 69, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[895989, 16070, 204, 4, 63, "Input"],
Cell[896196, 16076, 31189, 508, 296, 1842, 141, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[927434, 16590, 52, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[927511, 16594, 77, 0, 43, "Subsubsection"],
Cell[927591, 16596, 150, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[927778, 16603, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[927852, 16607, 317, 7, 79, "Input"],
Cell[928172, 16616, 360323, 6261, 163, 322009, 5785, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1288556, 22884, 55, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1288636, 22888, 329, 6, 95, "Input"],
Cell[1288968, 22896, 34469, 727, 199, 21291, 561, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1323498, 23630, 52, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[1323575, 23634, 61, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1323661, 23638, 48, 0, 43, "Subsubsection"],
Cell[1323712, 23640, 203, 5, 63, "Input"],
Cell[1323918, 23647, 213, 5, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1324168, 23657, 55, 0, 43, "Subsubsection"],
Cell[1324226, 23659, 157, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1324420, 23668, 39, 0, 43, "Subsubsection"],
Cell[1324462, 23670, 229, 5, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1324728, 23680, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1324792, 23684, 287, 6, 79, "Input"],
Cell[1325082, 23692, 27621, 548, 296, 4499, 258, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1352764, 24247, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1352831, 24251, 62, 0, 43, "Subsubsection"],
Cell[1352896, 24253, 110, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1353043, 24261, 64, 0, 43, "Subsubsection"],
Cell[1353110, 24263, 138, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1353285, 24271, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1353349, 24275, 147, 3, 63, "Input"],
Cell[1353499, 24280, 16577, 270, 296, 1024, 73, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1370137, 24557, 48, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1370210, 24561, 70, 0, 43, "Subsubsection"],
Cell[1370283, 24563, 160, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1370480, 24570, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1370554, 24574, 317, 7, 79, "Input"],
Cell[1370874, 24583, 352422, 6008, 163, 319462, 5598, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1723357, 30598, 51, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1723433, 30602, 329, 6, 95, "Input"],
Cell[1723765, 30610, 32559, 703, 199, 21293, 561, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1756373, 31319, 71, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1756469, 31323, 135, 5, 43, "Subsubsection"],
Cell[1756607, 31330, 101, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1756745, 31338, 57, 0, 43, "Subsubsection"],
Cell[1756805, 31340, 190, 3, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1757032, 31348, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1757096, 31352, 144, 3, 63, "Input"],
Cell[1757243, 31357, 16285, 266, 296, 1028, 73, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1773589, 31630, 69, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1773683, 31634, 204, 4, 63, "Input"],
Cell[1773890, 31640, 49967, 818, 296, 3242, 237, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1823906, 32464, 52, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1823983, 32468, 77, 0, 43, "Subsubsection"],
Cell[1824063, 32470, 150, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1824250, 32477, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1824324, 32481, 313, 7, 79, "Input"],
Cell[1824640, 32490, 373294, 6550, 163, 324831, 5949, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2197995, 39047, 55, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2198075, 39051, 329, 6, 95, "Input"],
Cell[2198407, 39059, 32855, 707, 199, 21293, 561, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2231323, 39773, 62, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[2231410, 39777, 61, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2231496, 39781, 48, 0, 43, "Subsubsection"],
Cell[2231547, 39783, 203, 5, 63, "Input"],
Cell[2231753, 39790, 201, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2231991, 39799, 55, 0, 43, "Subsubsection"],
Cell[2232049, 39801, 157, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2232243, 39810, 39, 0, 43, "Subsubsection"],
Cell[2232285, 39812, 229, 5, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2232551, 39822, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2232615, 39826, 287, 6, 79, "Input"],
Cell[2232905, 39834, 28288, 556, 296, 4490, 258, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2261254, 40397, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2261321, 40401, 62, 0, 43, "Subsubsection"],
Cell[2261386, 40403, 110, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2261533, 40411, 64, 0, 43, "Subsubsection"],
Cell[2261600, 40413, 138, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2261775, 40421, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2261839, 40425, 111, 2, 47, "Input"],
Cell[2261953, 40429, 24543, 617, 296, 4305, 363, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2286557, 41053, 48, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2286630, 41057, 70, 0, 43, "Subsubsection"],
Cell[2286703, 41059, 160, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2286900, 41066, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2286974, 41070, 313, 7, 79, "Input"],
Cell[2287290, 41079, 352119, 6005, 163, 319475, 5599, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2639470, 47091, 51, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2639546, 47095, 329, 6, 95, "Input"],
Cell[2639878, 47103, 32514, 703, 199, 21284, 561, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2672441, 47812, 71, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2672537, 47816, 135, 5, 43, "Subsubsection"],
Cell[2672675, 47823, 101, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2672813, 47831, 57, 0, 43, "Subsubsection"],
Cell[2672873, 47833, 190, 3, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2673100, 47841, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2673164, 47845, 144, 3, 63, "Input"],
Cell[2673311, 47850, 16244, 265, 296, 1028, 73, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2689616, 48122, 69, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2689710, 48126, 193, 3, 63, "Input"],
Cell[2689906, 48131, 49655, 817, 296, 3282, 240, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2739610, 48954, 52, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2739687, 48958, 77, 0, 43, "Subsubsection"],
Cell[2739767, 48960, 150, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2739954, 48967, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2740028, 48971, 313, 7, 79, "Input"],
Cell[2740344, 48980, 368771, 6447, 163, 323795, 5889, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3109176, 55434, 55, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3109256, 55438, 329, 6, 95, "Input"],
Cell[3109588, 55446, 32737, 706, 199, 21284, 561, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

